Index: maintenance/language/messages.inc
===================================================================
--- maintenance/language/messages.inc	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ maintenance/language/messages.inc	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -2670,7 +2670,7 @@
 	'upload-errors'       => '',
 	'upload-curl-errors'  => 'Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>',
 	'licenses'            => '',
-	'imagelist'           => 'Special:Imagelist',
+	'imagelist'           => 'Special:ImageList',
 	'imagedesciption'     => 'Image description page',
 	'filerevert'          => 'File reversion',
 	'filedelete'          => 'File deletion',
@@ -2690,10 +2690,10 @@
 	'booksources'         => 'Book sources',
 	'magicwords'          => 'Magic words',
 	'logpages'            => 'Special:Log',
-	'allpages'            => 'Special:Allpages',
+	'allpages'            => 'Special:AllPages',
 	'categories'          => 'Special:Categories',
-	'listusers'           => 'Special:Listusers',
-	'listgrouprights'     => 'Special:Listgrouprights',
+	'listusers'           => 'Special:ListUsers',
+	'listgrouprights'     => 'Special:ListGroupRights',
 	'emailuser'           => 'E-mail user',
 	'watchlist'           => 'Watchlist',
 	'watching'            => 'Displayed when you click the "watch" button and it is in the process of watching',
@@ -2727,7 +2727,7 @@
 	'patrol-log'          => 'Patrol log',
 	'imagedeletion'       => 'Image deletion',
 	'browsediffs'         => 'Browsing diffs',
-	'newimages'           => 'Special:Newimages',
+	'newimages'           => 'Special:NewImages',
 	'video-info'          => 'Video information, used by Language::formatTimePeriod() to format lengths in the above messages',
 	'badimagelist'        => 'Bad image list',
 	'variantname-zh'      => "Short names for language variants used for language conversion links.
@@ -2799,10 +2799,10 @@
 	'signatures'            => 'Signatures',
 	'CoreParserFunctions'   => 'Core parser functions',
 	'version'               => 'Special:Version',
-	'filepath'              => 'Special:Filepath',
+	'filepath'              => 'Special:FilePath',
 	'fileduplicatesearch'   => 'Special:FileDuplicateSearch',
 	'special-specialpages'  => 'Special:SpecialPages',
-	'special-blank'         => 'Special:Blankpage',
+	'special-blank'         => 'Special:BlankPage',
 );
 
 /** Short comments for standalone messages */
Index: maintenance/language/messageTypes.inc
===================================================================
--- maintenance/language/messageTypes.inc	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ maintenance/language/messageTypes.inc	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -87,7 +87,6 @@
 	'noarticletextanon',
 	'number_of_watching_users_RCview',
 	'pagecategorieslink',
-	'patrol-log-header',
 	'pubmedurl',
 	'randompage-url',
 	'recentchanges-url',
Index: includes/SearchEngine.php
===================================================================
--- includes/SearchEngine.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/SearchEngine.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -290,6 +290,8 @@
 	 * Load up the appropriate search engine class for the currently
 	 * active database backend, and return a configured instance.
 	 *
+	 * @fixme Ask the database class for his default search class
+	 * instead of knowing about every backend here.
 	 * @return SearchEngine
 	 */
 	public static function create() {
@@ -494,6 +496,9 @@
 
 
 /**
+ * @fixme This class is horribly factored. It would probably be better to have
+ * a useful base class to which you pass some standard information, then let
+ * the fancy self-highlighters extend that.
  * @ingroup Search
  */
 class SearchResult {
@@ -1139,16 +1144,11 @@
 }
 
 /**
+ * Dummy class to be used when non-supported Database engine is present.
+ * @fixme Dummy class should probably try something at least mildly useful,
+ * such as a LIKE search through titles.
  * @ingroup Search
  */
-class SearchEngineDummy {
-	function search( $term ) {
-		return null;
-	}
-	function setLimitOffset($l, $o) {}
-	function legalSearchChars() {}
-	function update() {}
-	function setnamespaces() {}
-	function searchtitle() {}
-	function searchtext() {}
+class SearchEngineDummy extends SearchEngine {
+	// no-op
 }
Index: includes/db/DatabasePostgres.php
===================================================================
--- includes/db/DatabasePostgres.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/db/DatabasePostgres.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1167,6 +1167,16 @@
 	function fieldInfo( $table, $field ) {
 		return PostgresField::fromText($this, $table, $field);
 	}
+	
+	/**
+	 * pg_field_type() wrapper
+	 */
+	function fieldType( $res, $index ) {
+		if ( $res instanceof ResultWrapper ) {
+			$res = $res->result;
+		}
+		return pg_field_type( $res, $index );
+	}
 
 	function begin( $fname = 'DatabasePostgres::begin' ) {
 		$this->query( 'BEGIN', $fname );
Index: includes/Setup.php
===================================================================
--- includes/Setup.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/Setup.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -114,6 +114,13 @@
 	}
 }
 
+/**
+ * Workaround for http://bugs.php.net/bug.php?id=45132
+ * escapeshellarg() destroys non-ASCII characters if LANG is not a UTF-8 locale
+ */
+putenv( 'LC_CTYPE=en_US.UTF-8' );
+setlocale( LC_CTYPE, 'en_US.UTF-8' );
+
 if ( !class_exists( 'AutoLoader' ) ) {
 	require_once( "$IP/includes/AutoLoader.php" );
 }
Index: includes/UserMailer.php
===================================================================
--- includes/UserMailer.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/UserMailer.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -314,7 +314,7 @@
 	 */
 	function actuallyNotifyOnPageChange($editor, $title, $timestamp, $summary, $minorEdit, $oldid=false) {
 
-		# we use $wgEmergencyContact as sender's address
+		# we use $wgPasswordSender as sender's address
 		global $wgEnotifWatchlist;
 		global $wgEnotifMinorEdits, $wgEnotifUserTalk, $wgShowUpdatedMarker;
 		global $wgEnotifImpersonal;
@@ -420,7 +420,7 @@
 	 * @private
 	 */
 	function composeCommonMailtext() {
-		global $wgEmergencyContact, $wgNoReplyAddress;
+		global $wgPasswordSender, $wgNoReplyAddress;
 		global $wgEnotifFromEditor, $wgEnotifRevealEditorAddress;
 		global $wgEnotifImpersonal;
 
@@ -477,7 +477,7 @@
 		# global configuration level.
 		$editor = $this->editor;
 		$name    = $editor->getName();
-		$adminAddress = new MailAddress( $wgEmergencyContact, 'WikiAdmin' );
+		$adminAddress = new MailAddress( $wgPasswordSender, 'WikiAdmin' );
 		$editorAddress = new MailAddress( $editor );
 		if( $wgEnotifRevealEditorAddress
 		    && ( $editor->getEmail() != '' )
Index: includes/DoubleRedirectJob.php
===================================================================
--- includes/DoubleRedirectJob.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/DoubleRedirectJob.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -66,6 +66,13 @@
 			return true;
 		}
 
+		# Check for a suppression tag (used e.g. in periodically archived discussions)
+		$mw = MagicWord::get( 'staticredirect' );
+		if ( $mw->match( $text ) ) {
+			wfDebug( __METHOD__.": skipping: suppressed with __STATICREDIRECT__\n" );
+			return true;
+		}
+
 		# Find the current final destination
 		$newTitle = self::getFinalDestination( $this->redirTitle );
 		if ( !$newTitle ) {
@@ -78,11 +85,15 @@
 			wfDebug( __METHOD__.": skipping, already good\n" );
 		}
 
+		# Preserve fragment (bug 14904)
+		$newTitle = Title::makeTitle( $newTitle->getNamespace(), $newTitle->getDBkey(), 
+			$currentDest->getFragment() );
+
 		# Fix the text
 		# Remember that redirect pages can have categories, templates, etc.,
 		# so the regex has to be fairly general
 		$newText = preg_replace( '/ \[ \[  [^\]]*  \] \] /x', 
-			'[[' . $newTitle->getPrefixedText() . ']]',
+			'[[' . $newTitle->getFullText() . ']]',
 			$text, 1 );
 
 		if ( $newText === $text ) {
Index: includes/api/ApiQueryUsers.php
===================================================================
--- includes/api/ApiQueryUsers.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/api/ApiQueryUsers.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -100,7 +100,7 @@
 			if(isset($this->prop['editcount']))
 				$data[$r->user_name]['editcount'] = $r->user_editcount;
 			if(isset($this->prop['registration']))
-				$data[$r->user_name]['registration'] = wfTimestamp(TS_ISO_8601, $r->user_registration);
+				$data[$r->user_name]['registration'] = wfTimestampOrNull(TS_ISO_8601, $r->user_registration);
 			if(isset($this->prop['groups']))
 				// This row contains only one group, others will be added from other rows
 				if(!is_null($r->ug_group))
Index: includes/MagicWord.php
===================================================================
--- includes/MagicWord.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/MagicWord.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -153,6 +153,7 @@
 		'noeditsection',
 		'newsectionlink',
 		'hiddencat',
+		'staticredirect',
 	);
 
 
Index: includes/Title.php
===================================================================
--- includes/Title.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/Title.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -250,12 +250,13 @@
 	 *
 	 * @param int $ns the namespace of the article
 	 * @param string $title the unprefixed database key form
+	 * @param string $fragment The link fragment (after the "#")
 	 * @return Title the new object
 	 */
-	public static function &makeTitle( $ns, $title ) {
+	public static function &makeTitle( $ns, $title, $fragment = '' ) {
 		$t = new Title();
 		$t->mInterwiki = '';
-		$t->mFragment = '';
+		$t->mFragment = $fragment;
 		$t->mNamespace = $ns = intval( $ns );
 		$t->mDbkeyform = str_replace( ' ', '_', $title );
 		$t->mArticleID = ( $ns >= 0 ) ? -1 : 0;
@@ -271,11 +272,12 @@
 	 *
 	 * @param int $ns the namespace of the article
 	 * @param string $title the database key form
+	 * @param string $fragment The link fragment (after the "#")
 	 * @return Title the new object, or NULL on an error
 	 */
-	public static function makeTitleSafe( $ns, $title ) {
+	public static function makeTitleSafe( $ns, $title, $fragment = '' ) {
 		$t = new Title();
-		$t->mDbkeyform = Title::makeName( $ns, $title );
+		$t->mDbkeyform = Title::makeName( $ns, $title, $fragment );
 		if( $t->secureAndSplit() ) {
 			return $t;
 		} else {
@@ -391,13 +393,18 @@
 	 * Make a prefixed DB key from a DB key and a namespace index
 	 * @param int $ns numerical representation of the namespace
 	 * @param string $title the DB key form the title
+	 * @param string $fragment The link fragment (after the "#")
 	 * @return string the prefixed form of the title
 	 */
-	public static function makeName( $ns, $title ) {
+	public static function makeName( $ns, $title, $fragment = '' ) {
 		global $wgContLang;
 
-		$n = $wgContLang->getNsText( $ns );
-		return $n == '' ? $title : "$n:$title";
+		$namespace = $wgContLang->getNsText( $ns );
+		$name = $namespace == '' ? $title : "$namespace:$title";
+		if ( strval( $fragment ) != '' ) {
+			$name .= '#' . $fragment;
+		}
+		return $name;
 	}
 
 	/**
Index: includes/DefaultSettings.php
===================================================================
--- includes/DefaultSettings.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/DefaultSettings.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -31,7 +31,7 @@
 $wgConf = new SiteConfiguration;
 
 /** MediaWiki version number */
-$wgVersion			= '1.13.0rc1';
+$wgVersion			= '1.13.0rc2';
 
 /** Name of the site. It must be changed in LocalSettings.php */
 $wgSitename         = 'MediaWiki';
Index: includes/specials/SpecialMovepage.php
===================================================================
--- includes/specials/SpecialMovepage.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/specials/SpecialMovepage.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -67,12 +67,13 @@
 		$this->reason = $wgRequest->getText( 'wpReason' );
 		if ( $wgRequest->wasPosted() ) {
 			$this->moveTalk = $wgRequest->getBool( 'wpMovetalk', false );
+			$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', false );
 		} else {
 			$this->moveTalk = $wgRequest->getBool( 'wpMovetalk', true );
+			$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', true );
 		}
 		$this->moveSubpages = $wgRequest->getBool( 'wpMovesubpages', false );
 		$this->deleteAndMove = $wgRequest->getBool( 'wpDeleteAndMove' ) && $wgRequest->getBool( 'wpConfirm' );
-		$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', true );
 		$this->watch = $wgRequest->getCheck( 'wpWatch' );
 	}
 
Index: includes/specials/SpecialSearch.php
===================================================================
--- includes/specials/SpecialSearch.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/specials/SpecialSearch.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -139,9 +139,9 @@
 
 		global $wgDisableTextSearch;
 		if ( $wgDisableTextSearch ) {
-			global $wgForwardSearchUrl;
-			if( $wgForwardSearchUrl ) {
-				$url = str_replace( '$1', urlencode( $term ), $wgForwardSearchUrl );
+			global $wgSearchForwardUrl;
+			if( $wgSearchForwardUrl ) {
+				$url = str_replace( '$1', urlencode( $term ), $wgSearchForwardUrl );
 				$wgOut->redirect( $url );
 				return;
 			}
Index: includes/zhtable/toCN.manual
===================================================================
--- includes/zhtable/toCN.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/toCN.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -67,7 +67,6 @@
 資料庫	数据库
 乳酪	奶酪
 鉅賈	巨商
-手電筒	手电
 萬曆	万历
 永曆	永历
 辭彙	词汇
@@ -271,7 +270,6 @@
 华乐	民乐
 中樂	民乐
 屋价	房价
-的士	出租车
 計程車	出租车
 公車	公共汽车
 單車	自行车
@@ -287,6 +285,8 @@
 衛生	卫生
 賓士	奔驰
 平治	奔驰
+平治之亂	平治之乱
+平治之乱	平治之乱
 積架	捷豹
 福斯	大众
 福士	大众
Index: includes/zhtable/trad2simp.manual
===================================================================
--- includes/zhtable/trad2simp.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/trad2simp.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -16,3 +16,10 @@
 U+095e2闢|U+08f9f辟|
 U+05bc0寀|U+091c7采|
 U+08518蔘|U+053c2参|
+U+06b05欅|U+06989榉|
+U+07343獃|U+05446呆|
+U+09918餘|U+04f59余|U+09980馀|
+U+09592閒|U+095f2闲|
+U+08b6d譭|U+06bc1毁|
+U+071ec燬|U+06bc1毁|
+U+08457著|U+08457著|U+07740着|
Index: includes/zhtable/toHK.manual
===================================================================
--- includes/zhtable/toHK.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/toHK.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -2,6 +2,10 @@
 “	「
 ‘	『
 ’	』
+凶殺	兇殺
+凶殘	兇殘
+緝凶	緝兇
+買凶	買兇
 打印机	打印機
 印表機	打印機
 字节	位元組
Index: includes/zhtable/simp2trad.manual
===================================================================
--- includes/zhtable/simp2trad.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/simp2trad.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -29,6 +29,7 @@
 U+054b8咸|U+054b8咸|U+09e79鹹|
 U+05411向|U+05411向|U+056ae嚮|U+066cf曏|
 U+04f59余|U+04f59余|U+09918餘|
+U+09980馀|U+09918餘|
 U+090c1郁|U+090c1郁|U+09b31鬱|
 U+05fa1御|U+05fa1御|U+079a6禦|
 U+0613f愿|U+09858願|U+0613f愿|
@@ -169,7 +170,6 @@
 U+09605阅|U+095b1閱|U+095b2閲|
 U+09893颓|U+09839頹|U+0983d頽|
 U+0989c颜|U+0984f顏|U+09854顔|
-U+09980馀|U+09918餘|
 U+09a82骂|U+07f75罵|U+099e1駡|
 U+09c87鲇|U+09bf0鯰|U+09b8e鮎|
 U+09c9e鲞|U+09bd7鯗|U+09b9d鮝|
@@ -196,3 +196,9 @@
 U+04ed1仑|U+04f96侖|U+05d19崙|
 U+06817栗|U+06817栗|U+06144慄|
 U+05742坂|U+05742坂|U+0962a阪|
+U+096d5雕|U+096d5雕|U+09d70鵰|
+U+05398厘|U+05398厘|U+091d0釐|
+U+06881梁|U+06881梁|U+06a11樑|
+U+05e84庄|U+05e84庄|U+0838a莊|
+U+062fc拼|U+062fc拼|U+062da拚|
+U+08d5e赞|U+08d0a贊|U+08b9a讚|
Index: includes/zhtable/toSimp.manual
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: includes/zhtable/tradphrases.manual
===================================================================
--- includes/zhtable/tradphrases.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/tradphrases.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -22,6 +22,8 @@
 千多隻
 萬多隻
 億多隻
+數天後
+幾天後
 多天後
 零天後
 一天後
@@ -59,9 +61,141 @@
 ７天後
 ８天後
 ９天後
+後印
+萬象
 並存著
 乾絲
 乾著急
+乾魚
+魚乾
+乾梅
+糕乾
+黃乾黑廋
+馬乾
+香乾
+趲幹
+謀幹
+詞幹
+蟶乾
+薄幹
+腦幹
+營幹
+老乾
+老幹部
+管幹
+盲幹
+煨乾
+海乾
+乾漆
+淚乾
+沒幹
+沒乾沒淨
+枝不得大於榦
+杯乾
+朝乾夕惕
+打幹
+打乾噦
+徐幹
+府幹
+乾館
+乾顙
+幹革命
+乾霍亂
+乾雷
+乾阿奶
+乾量
+乾醋
+乾逼
+乾貨
+乾衣
+幹蠱
+乾虔
+乾落
+幹營生
+乾茶錢
+乾茨臘
+乾苔
+乾花
+乾肥
+乾耗
+幹缺
+乾繃
+乾結
+乾餱
+乾篾片
+乾稿
+乾禮
+乾瞪眼
+乾白兒
+乾疥
+乾生子
+乾生受
+幹父之蠱
+乾熬
+乾燈盞
+乾濕
+乾澀
+幹濟
+乾沒
+乾死
+乾村沙
+乾暖
+乾料
+乾敲梆子不賣油
+乾支支
+乾支剌
+乾擦
+乾撇下
+乾撂台
+乾折
+乾急
+幹當
+乾式
+乾屎橛
+幹家
+乾奴才
+幹頭
+乾塢
+乾圓潔淨
+乾回付
+乾啼
+乾哭
+乾噦
+乾咽
+乾和
+幹吏
+乾吊著下巴
+乾號
+乾颱
+乾卦
+乾剝剝
+乾刻版
+乾芻
+幹人
+乾產
+乾喬
+夯幹
+大目乾連
+國之楨榦
+唇乾
+單幹
+勾幹
+不幹性油
+不幹不淨
+豆乾
+果乾
+如果幹
+乾麵
+乾柴
+枯乾
+晒乾
+顛乾倒坤
+強幹
+乾著
+乾眼
+幹的停當
+乾巴
+偎乾
 借著
 偷雞不著
 几絲
@@ -165,6 +299,7 @@
 被覆著
 覆著
 覆蓋著
+反覆
 訴說著
 說著
 請參閱
@@ -240,13 +375,14 @@
 併兼
 併除
 併疊
-併力
 忙併
 打併
 並發表
 並發現
 並發展
 並發動
+舉手表
+揮手表
 併一不二
 連三併四
 相併
@@ -258,6 +394,7 @@
 提摩太後書
 當家纔知柴米價
 剛纔一載
+裏海
 骨頭裡掙出來的錢纔做得肉
 恰纔
 遠縣纔至
@@ -272,6 +409,7 @@
 披榛採蘭
 謬採虛聲
 採樵人
+回採
 觀採
 開採
 揪採
@@ -325,12 +463,31 @@
 採鹽
 採區
 採運
+採風
 官地為寀
 寮寀
 蔘綏
 人蔘
 蕭蔘
-蔘綏
+人參與
+人參選
+人參觀
+人參考
+人參展
+人參加
+人參議
+人參謀
+人參酌
+人參照
+人參政
+人參戰
+人參拜
+人參閱
+人參禪
+人參贊
+人參見
+人參透
+人參看
 東衝西突
 天克地衝
 六衝
@@ -377,12 +534,7 @@
 不嫌母醜
 一爭兩醜
 惡直醜正
-小醜跳樑
-跳樑小醜
-怨在小醜
-跳樑猖獗之小醜
-么麼小醜
-小醜跳樑
+么麼小丑
 齣電影
 齣卡通
 齣戲
@@ -499,7 +651,13 @@
 張三丰
 復始
 複分析
+複輔音
+複元音
+複平面
+複流
+反複製
 顛覆
+答覆
 覆沒
 覆亡
 覆水難收
@@ -629,6 +787,13 @@
 裏勾外連
 裏手
 水里鄉
+二里頭
+年歷史
+西歷史
+國歷史
+國歷代
+新歷史
+夏歷史
 百花曆
 寶曆
 穆罕默德曆
@@ -699,6 +864,7 @@
 澒濛
 瀰山遍野
 瀰瀰
+冷麵
 撈麵
 煮麵
 炆麵
@@ -745,6 +911,7 @@
 意大利麵
 湯下麵
 茶麵
+冷面相
 糞穢衊面
 湟潦生苹
 食野之苹
@@ -801,6 +968,7 @@
 斫雕為樸
 斲雕為樸
 斲雕為樸
+質樸
 誠樸
 純樸
 曾樸
@@ -810,6 +978,7 @@
 樸鈍
 樸直
 見素抱樸
+掣籤
 標籤
 書籤
 發籤
@@ -840,6 +1009,7 @@
 捨實
 棄捨
 捨安就危
+施舍之道
 瀋河
 瀋水
 瀋州
@@ -884,7 +1054,6 @@
 錦綉花園
 籲天
 勃鬱
-芬鬱
 怫鬱
 氣鬱
 沉鬱
@@ -958,6 +1127,7 @@
 种放
 种師道
 种師中
+後庄
 舊庄
 正官庄
 龜山庄
@@ -973,6 +1143,14 @@
 韶山衝
 衝車
 書獃子
+相干
+府干預
+府干涉
+府干政
+府干擾
+府干犯
+府干卿
+一干人
 未乾
 抹乾
 餅乾
@@ -1027,17 +1205,49 @@
 乾乾淨淨
 乾柴烈火
 乾乾兒的
+桑乾
+撈乾
+搭乾鋪
+揩乾
+敢幹
 幹探
 幹事
 幹什麼
 幹細胞
+悶著頭兒幹
+配水幹管
+繐幃飄井幹
+站乾岸兒
+秋陰入井幹
+沒梢幹
+楨幹
+據榦而窺井底
+井榦摧敗
+杰特
 李連杰
 周杰倫
 稜鏡
 稜角
 稜台
 稜錐
+觚稜
+稜子
+稜層
+稜柱
+盧稜伽
+波稜菜
+菠稜菜
+稜縫
+稜等登
+稜稜
+嶒稜
+蹭稜子
+稜體
+二不稜登
+有稜有角
+威稜
 負債纍纍
+傷痕纍纍
 儒略曆
 伊斯蘭曆
 寶曆
@@ -1051,6 +1261,7 @@
 輓曲
 敬輓
 万俟
+万旗
 鬚鯨
 鬚鯊
 兇手
@@ -1069,8 +1280,168 @@
 叶韻
 叶音
 叶恭弘
+叶 恭弘
+叶　恭弘
 於夫羅
 於梨華
+置於
+佈於
+散於
+播於
+國於
+敗於
+於一役
+畢於
+畢業於
+寒於
+任於
+拘於
+插於
+中於
+於市
+於野
+敏於
+聽於
+短於
+成於
+樊於期
+淡於
+於陸
+於密
+於盡
+禍於
+格於
+猛於
+施於
+於牆
+於物
+於己
+於你
+於我
+於他
+於她
+於它
+於祂
+拒人於
+拒於
+潰於
+窮於
+相於
+形於
+半於
+於始
+於終
+詢於
+美於
+醜於
+好於
+坏於
+強於
+弱於
+差於
+劣於
+於美
+於醜
+於好
+於坏
+於強
+於弱
+於差
+於劣
+於垂
+染指於
+於火
+存十一於千百
+於勤
+隱於
+藏於
+嚴於
+寬於
+於幕
+給於
+於穆
+於呼哀哉
+於時
+於該
+危於
+於伏
+於何
+於家
+於國
+於潛縣
+於焉
+於征
+離於
+於畢
+麗於
+下於
+亞於
+同於
+屑於
+絕於
+致於
+於行
+遜於
+任教於
+教於
+自於
+來於
+附於
+於人
+於世
+阻於
+於民
+於盲
+於色
+囿於
+直於
+建於
+都於
+於農
+於樂
+於前
+役於
+於心
+於法
+於事
+助於
+害於
+損於
+益於
+從於
+隨於
+順於
+汲於
+溺於
+迷於
+醉於
+行於
+泥於
+身於
+足於
+溢於
+於衷
+畏於
+視於
+衷於
+狃於
+疲於
+通於
+於途
+老於
+耿於
+於懷
+服於
+致於
+臻於
+匿於
+因於
+似於
+遷於
+怒於
+心於
+集於
+容於
 髒詞
 髒心
 新紮
@@ -1158,3 +1529,128 @@
 原子鐘
 泳氣鐘
 電子鐘
+射鵰
+神鵰
+神雕像
+采石磯
+采石之戰
+采石之役
+聊齋志異
+不斷發
+部落發
+角落發
+村落發
+蛇髮女妖
+畢生發展
+對華發動
+中美發表
+尸魂界
+樹樑
+屋樑
+樑柱
+柱樑
+昇陽
+僥倖
+夏遊
+秋遊
+冬遊
+黑奴籲天錄
+林郁方
+讚歌
+編餘
+三餘
+餘墨
+唾餘
+餘韻
+歸餘
+公餘
+寬餘
+餘糧
+餘慶
+餘殃
+餘燼
+劫餘
+結餘
+燼餘
+淨餘
+餕餘
+餘暉
+餘輝
+羨餘
+餘悸
+心餘
+刑餘
+緒餘
+血餘
+朱慶餘
+諸餘
+餘論
+茶餘
+廚餘
+餘裕
+餘氣
+詩餘
+詞餘
+餘僇
+餘辜
+餘責
+餘罪
+無餘
+耳餘
+餘烈
+餘思
+鹽餘
+嬴餘
+贏餘
+王餘魚
+紆餘
+餘波
+餘杯
+餘步
+餘妙
+餘音
+餘聲
+餘明
+餘風
+餘黨
+餘毒
+餘桃
+餘桶
+餘利
+餘瀝
+餘膏
+餘光
+餘杭
+餘竅
+餘缺
+餘暇
+餘閒
+餘羨
+餘響
+餘興
+餘蓄
+餘緒
+餘珍
+餘眾
+餘酲
+餘喘
+餘食
+餘熱
+餘刃
+餘閏
+餘存
+餘業
+餘姚
+餘蔭
+餘映
+餘外
+餘威
+餘味
+餘溫
+餘勇
+多餘
+剩餘
+餘生
+有餘
+余光生
+余光中
Index: includes/zhtable/simp2trad_supp_set.manual
===================================================================
--- includes/zhtable/simp2trad_supp_set.manual	(.../REL1_13_0RC1/phase3)	(revision 0)
+++ includes/zhtable/simp2trad_supp_set.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -0,0 +1,2 @@
+余	餘
+着	著

Property changes on: includes/zhtable/simp2trad_supp_set.manual
___________________________________________________________________
Name: svn:eol-style
   + native

Index: includes/zhtable/trad2simp_supp_set.manual
===================================================================
--- includes/zhtable/trad2simp_supp_set.manual	(.../REL1_13_0RC1/phase3)	(revision 0)
+++ includes/zhtable/trad2simp_supp_set.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -0,0 +1 @@
+著	着

Property changes on: includes/zhtable/trad2simp_supp_set.manual
___________________________________________________________________
Name: svn:eol-style
   + native

Index: includes/zhtable/tradphrases_exclude.manual
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: includes/zhtable/trad2simp_supp_unset.manual
===================================================================

Property changes on: includes/zhtable/trad2simp_supp_unset.manual
___________________________________________________________________
Name: svn:eol-style
   + native

Index: includes/zhtable/toTrad.manual
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: includes/zhtable/toTW.manual
===================================================================
--- includes/zhtable/toTW.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/toTW.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,6 +3,22 @@
 ‘	『
 ’	』
 着	著
+元凶	元凶
+凶器	凶器
+凶徒	凶徒
+凶手	凶手
+凶案	凶案
+凶残	凶殘
+凶杀	凶殺
+疑凶	疑凶
+真凶	真凶
+缉凶	緝凶
+行凶	行凶
+行凶后	行凶後
+买凶	買凶
+追凶	追凶
+复苏	復甦
+復蘇	復甦
 缺省	預設
 串行	串列
 以太网	乙太網
@@ -20,10 +36,12 @@
 脱机	離線
 声卡	音效卡
 老字号	老字號
+连字号	連字號
 字号	字型大小
 字库	字型檔
 字段	欄位
 字符	字元
+字符集	字符集
 存盘	存檔
 寻址	定址
 尾注	章節附註
@@ -40,6 +58,9 @@
 磁盘	磁碟
 磁道	磁軌
 程控	程式控制
+远程控制	遠程控制
+遠程控制	遠程控制
+行程控制	行程控制
 端口	埠
 算子	運算元
 算法	演算法
@@ -71,11 +92,13 @@
 奶酪	乳酪
 巨商	鉅賈
 手电	手電筒
+手电筒	手電筒
 万历	萬曆
 永历	永曆
 词汇	辭彙
 习用	慣用
 元音	母音
+宋元	宋元
 任意球	自由球
 头球	頭槌
 入球	進球
@@ -100,6 +123,7 @@
 網絡	網路
 人工智能	人工智慧
 航天飞机	太空梭
+航天大学	航天大學
 穿梭機	太空梭
 因特网	網際網路
 互聯網	網際網路
@@ -276,6 +300,8 @@
 雪糕	冰淇淋
 卫生	衛生
 衞生	衛生
+平治之亂	平治之亂
+平治之乱	平治之亂
 平治	賓士
 奔驰	賓士
 積架	捷豹
Index: includes/zhtable/simpphrases.manual
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream
Index: includes/zhtable/Makefile
===================================================================
--- includes/zhtable/Makefile	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/Makefile	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -142,7 +142,10 @@
 tradphrases.t: tradphrases.manual tradphrases_2.t tradphrases_3.t tradphrases_4.t t2s_1tomany.t
 	cat tradphrases.manual tradphrases_2.t tradphrases_3.t tradphrases_4.t |sort | uniq > tradphrases.t
 	for i in `$(SED) 's/"\(.\).*/\1/' t2s_1tomany.t ` ; do $(GREP) $$i tradphrases.t ; done | $(DIFF) tradphrases.t - | $(GREP) '<' | $(SED) 's/< //' > t
+	for i in `$(SED) 's/"\(..\)..*/\1/' t2s_1tomany.t ` ; do $(GREP) $$i tradphrases.t ; done | $(DIFF) tradphrases.t - | $(GREP) '<' | $(SED) 's/< //' >> t
 	mv t tradphrases.t
+	cat tradphrases.t | sort | uniq > t
+	mv t tradphrases.t
 
 tradphrases.notsure: tradphrases_2.t tradphrases_3.t tradphrases_4.t t2s_1tomany.t
 	cat tradphrases_2.t tradphrases_3.t tradphrases_4.t |sort | uniq > t
@@ -189,9 +192,11 @@
 simpphrases.t: simpphrases.manual simpphrases_2.t simpphrases_3.t simpphrases_4.t t2s_1tomany.t
 	cat simpphrases.manual simpphrases_2.t simpphrases_3.t simpphrases_4.t > simpphrases.t
 	for i in `$(SED) 's/"\(.\).*/\1/' t2s_1tomany.t ` ; do $(GREP) $$i simpphrases.t ; done | $(DIFF) simpphrases.t - | $(GREP) '<' | $(SED) 's/< //' > t
+	for i in `$(SED) 's/"\(..\)..*/\1/' t2s_1tomany.t ` ; do $(GREP) $$i simpphrases.t ; done | $(DIFF) simpphrases.t - | $(GREP) '<' | $(SED) 's/< //' >> t
 	mv t simpphrases.t
+	cat simpphrases.t | sort | uniq > t
+	mv t simpphrases.t
 
-
 simpphrases.notsure: simpphrases_2.t simpphrases_3.t simpphrases_4.t t2s_1tomany.t
 	cat simpphrases_2.t simpphrases_3.t simpphrases_4.t > t
 	for i in `$(SED) 's/"\(.\).*/\1/' t2s_1tomany.t ` ; do $(GREP) $$i t ; done | $(DIFF) t - | $(GREP) '>' | $(SED) 's/> //' > simpphrases.notsure
@@ -212,24 +217,30 @@
 	cat simp2trad1to1.t | $(GREP) -vf simp2trad_noconvert.manual > tt
 	mv tt simp2trad1to1.t
 
-trad2simp.php: trad2simp1to1.t tradphrases.t
+trad2simp.php: trad2simp1to1.t tradphrases.t trad2simp_supp_unset.manual
 	printf '<?php\n$$trad2simp=array(' > trad2simp.php
 	cat trad2simp1to1.t >> trad2simp.php
 	printf ');\n$$str=\n"' >> trad2simp.php
 	cat tradphrases.t >> trad2simp.php
 	printf '";\n$$t=strtr($$str, $$trad2simp);\necho $$t;\n?>' >> trad2simp.php
+	cat trad2simp1to1.t | $(GREP) -vf trad2simp_supp_unset.manual > tt
+	mv tt trad2simp1to1.t
 
-simp2trad.php: simp2trad1to1.t simpphrases.t
+simp2trad.php: simp2trad1to1.t simpphrases.t simp2trad_supp_set.manual
 	printf '<?php\n$$simp2trad=array(' > simp2trad.php
 	cat simp2trad1to1.t >> simp2trad.php
+	$(SED) 's/\(.*\)\t\(.*\)/"\1" => "\2",/' simp2trad_supp_set.manual >> simp2trad.php
 	printf ');\n$$str=\n"' >> simp2trad.php
 	cat simpphrases.t >> simp2trad.php
 	printf '";\n$$t=strtr($$str, $$simp2trad);\necho $$t;\n?>' >> simp2trad.php
 
-simp2trad.phrases.t: trad2simp.php tradphrases.t
+simp2trad.phrases.t: trad2simp.php tradphrases.t simp2trad_supp_set.manual
 	php -f trad2simp.php | $(SED)  's/\(.*\)/"\1" => /' > tmp1
 	cat tradphrases.t | $(SED)  's/\(.*\)/"\1",/' > tmp2
 	paste tmp1 tmp2 > simp2trad.phrases.t
+	colrm 3 < simp2trad_supp_set.manual > simp2trad_supp_noconvert.t
+	cat trad2simp.php | $(GREP) -vf simp2trad_supp_noconvert.t > trad2simp.tt
+	mv trad2simp.tt trad2simp.php
 
 trad2simp.phrases.t: simp2trad.php simpphrases.t
 	php -f simp2trad.php | $(SED)  's/\(.*\)/"\1" => /' > tmp1
Index: includes/zhtable/trad2simp_noconvert.manual
===================================================================
--- includes/zhtable/trad2simp_noconvert.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/trad2simp_noconvert.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,2 +1,4 @@
+"余"=>
 碁
 藉
+=>"獃"
Index: includes/zhtable/simp2trad_noconvert.manual
===================================================================
--- includes/zhtable/simp2trad_noconvert.manual	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/zhtable/simp2trad_noconvert.manual	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1 +1,4 @@
 著
+竈
+彞
+余
Index: includes/ZhConversion.php
===================================================================
--- includes/ZhConversion.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ includes/ZhConversion.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -114,6 +114,7 @@
 "鸡"=>"雞",
 "鹚"=>"鶿",
 "仑"=>"侖",
+"赞"=>"贊",
 "荡"=>"盪",
 "锤"=>"錘",
 "㟆"=>"㠏",
@@ -270,7 +271,6 @@
 "厌"=>"厭",
 "厍"=>"厙",
 "厐"=>"龎",
-"厘"=>"釐",
 "厢"=>"廂",
 "厣"=>"厴",
 "厦"=>"廈",
@@ -489,7 +489,6 @@
 "帻"=>"幘",
 "帼"=>"幗",
 "幂"=>"冪",
-"庄"=>"莊",
 "庆"=>"慶",
 "庐"=>"廬",
 "庑"=>"廡",
@@ -509,7 +508,6 @@
 "弹"=>"彈",
 "强"=>"強",
 "归"=>"歸",
-"彝"=>"彞",
 "彦"=>"彥",
 "彻"=>"徹",
 "径"=>"徑",
@@ -859,7 +857,6 @@
 "灭"=>"滅",
 "灯"=>"燈",
 "灵"=>"靈",
-"灶"=>"竈",
 "灾"=>"災",
 "灿"=>"燦",
 "炀"=>"煬",
@@ -1662,7 +1659,6 @@
 "赚"=>"賺",
 "赛"=>"賽",
 "赜"=>"賾",
-"赞"=>"贊",
 "赟"=>"贇",
 "赠"=>"贈",
 "赡"=>"贍",
@@ -2550,10 +2546,12 @@
 "一地里" => 	"一地裡",
 "一伙" => 	"一夥",
 "一天后" => 	"一天後",
+"一干人" => 	"一干人",
 "一别头" => 	"一彆頭",
 "一树百获" => 	"一樹百穫",
 "一准" => 	"一準",
 "一争两丑" => 	"一爭兩醜",
+"一箭双雕" => 	"一箭雙鵰",
 "一扎" => 	"一紮",
 "一冲" => 	"一衝",
 "一锅面" => 	"一鍋麵",
@@ -2567,17 +2565,21 @@
 "七扎" => 	"七紮",
 "七只" => 	"七隻",
 "万俟" => 	"万俟",
-"三元里" => 	"三元裡",
+"万旗" => 	"万旗",
 "三天后" => 	"三天後",
 "三棱锥" => 	"三稜錐",
 "三扎" => 	"三紮",
 "三统历" => 	"三統曆",
 "三复" => 	"三複",
 "三只" => 	"三隻",
+"三余" => 	"三餘",
+"上梁" => 	"上樑",
 "上签" => 	"上籤",
 "上药" => 	"上藥",
+"下于" => 	"下於",
 "下签" => 	"下籤",
 "下药" => 	"下藥",
+"下余" => 	"下餘",
 "不下于" => 	"不下於",
 "不亚于" => 	"不亞於",
 "不占" => 	"不佔",
@@ -2587,7 +2589,10 @@
 "不嫌母丑" => 	"不嫌母醜",
 "不寒而栗" => 	"不寒而慄",
 "不屑于" => 	"不屑於",
+"不干不净" => 	"不幹不淨",
+"不干性油" => 	"不幹性油",
 "不采" => 	"不採",
+"不断发" => 	"不斷發",
 "不准" => 	"不準",
 "不为牛后" => 	"不為牛後",
 "不知就里" => 	"不知就裡",
@@ -2611,6 +2616,8 @@
 "并发表" => 	"並發表",
 "中仑" => 	"中崙",
 "中岳" => 	"中嶽",
+"中于" => 	"中於",
+"中美发表" => 	"中美發表",
 "中药" => 	"中藥",
 "丰仪" => 	"丰儀",
 "丰南" => 	"丰南",
@@ -2628,9 +2635,10 @@
 "丹药" => 	"丹藥",
 "主仆" => 	"主僕",
 "主干" => 	"主幹",
-"么么小丑" => 	"么麼小醜",
+"么么小丑" => 	"么麼小丑",
 "之后" => 	"之後",
 "之于" => 	"之於",
+"之余" => 	"之餘",
 "九世之雠" => 	"九世之讎",
 "九划" => 	"九劃",
 "九天后" => 	"九天後",
@@ -2649,15 +2657,29 @@
 "干儿子" => 	"乾兒子",
 "干冰" => 	"乾冰",
 "干冷" => 	"乾冷",
+"干刻版" => 	"乾刻版",
+"干剥剥" => 	"乾剝剝",
+"干卦" => 	"乾卦",
+"干吊着下巴" => 	"乾吊著下巴",
+"干和" => 	"乾和",
 "干咳" => 	"乾咳",
+"干咽" => 	"乾咽",
 "干哥" => 	"乾哥",
+"干哭" => 	"乾哭",
 "干唱" => 	"乾唱",
+"干啼" => 	"乾啼",
+"干乔" => 	"乾喬",
 "干呕" => 	"乾嘔",
+"干哕" => 	"乾噦",
 "干嚎" => 	"乾嚎",
+"干回付" => 	"乾回付",
+"干圆洁净" => 	"乾圓潔淨",
 "干地" => 	"乾地",
 "干坤" => 	"乾坤",
+"干坞" => 	"乾塢",
 "干女" => 	"乾女",
 "干女儿" => 	"乾女兒",
+"干奴才" => 	"乾奴才",
 "干妹" => 	"乾妹",
 "干姊" => 	"乾姊",
 "干娘" => 	"乾娘",
@@ -2665,20 +2687,37 @@
 "干子" => 	"乾子",
 "干季" => 	"乾季",
 "干尸" => 	"乾屍",
+"干屎橛" => 	"乾屎橛",
+"干巴" => 	"乾巴",
 "干巴巴" => 	"乾巴巴",
+"干式" => 	"乾式",
 "干弟" => 	"乾弟",
 "干得" => 	"乾得",
+"干急" => 	"乾急",
 "干性" => 	"乾性",
 "干打雷" => 	"乾打雷",
+"干折" => 	"乾折",
 "干掉" => 	"乾掉",
+"干撂台" => 	"乾撂台",
+"干撇下" => 	"乾撇下",
+"干擦" => 	"乾擦",
+"干支剌" => 	"乾支剌",
+"干支支" => 	"乾支支",
+"干敲梆子不卖油" => 	"乾敲梆子不賣油",
+"干料" => 	"乾料",
 "干旱" => 	"乾旱",
+"干暖" => 	"乾暖",
 "干材" => 	"乾材",
+"干村沙" => 	"乾村沙",
 "干杯" => 	"乾杯",
 "干果" => 	"乾果",
 "干枯" => 	"乾枯",
 "干柴" => 	"乾柴",
 "干柴烈火" => 	"乾柴烈火",
+"干梅" => 	"乾梅",
+"干死" => 	"乾死",
 "干池" => 	"乾池",
+"干没" => 	"乾沒",
 "干洗" => 	"乾洗",
 "干涸" => 	"乾涸",
 "干凉" => 	"乾涼",
@@ -2686,54 +2725,96 @@
 "干渠" => 	"乾渠",
 "干渴" => 	"乾渴",
 "干沟" => 	"乾溝",
+"干漆" => 	"乾漆",
+"干涩" => 	"乾澀",
+"干湿" => 	"乾濕",
+"干熬" => 	"乾熬",
 "干热" => 	"乾熱",
+"干灯盏" => 	"乾燈盞",
 "干燥" => 	"乾燥",
 "干爸" => 	"乾爸",
 "干爹" => 	"乾爹",
 "干爽" => 	"乾爽",
 "干片" => 	"乾片",
+"干生受" => 	"乾生受",
+"干生子" => 	"乾生子",
+"干产" => 	"乾產",
 "干田" => 	"乾田",
+"干疥" => 	"乾疥",
 "干瘦" => 	"乾瘦",
 "干瘪" => 	"乾癟",
 "干癣" => 	"乾癬",
+"干白儿" => 	"乾白兒",
 "干的" => 	"乾的",
+"干眼" => 	"乾眼",
 "干眼病" => 	"乾眼病",
 "干瞪眼" => 	"乾瞪眼",
 "干礼" => 	"乾禮",
+"干稿" => 	"乾稿",
 "干笑" => 	"乾笑",
 "干等" => 	"乾等",
+"干篾片" => 	"乾篾片",
 "干粉" => 	"乾粉",
 "干粮" => 	"乾糧",
+"干结" => 	"乾結",
 "干丝" => 	"乾絲",
+"干绷" => 	"乾繃",
+"干耗" => 	"乾耗",
 "干肉片" => 	"乾肉片",
 "干股" => 	"乾股",
+"干肥" => 	"乾肥",
 "干脆" => 	"乾脆",
+"干花" => 	"乾花",
+"干刍" => 	"乾芻",
+"干苔" => 	"乾苔",
+"干茨腊" => 	"乾茨臘",
+"干茶钱" => 	"乾茶錢",
 "干草" => 	"乾草",
 "干菜" => 	"乾菜",
+"干落" => 	"乾落",
+"干着" => 	"乾著",
 "干着急" => 	"乾著急",
 "干姜" => 	"乾薑",
 "干薪" => 	"乾薪",
+"干虔" => 	"乾虔",
+"干号" => 	"乾號",
+"干衣" => 	"乾衣",
 "干裂" => 	"乾裂",
 "干亲" => 	"乾親",
 "干贝" => 	"乾貝",
+"干货" => 	"乾貨",
 "干躁" => 	"乾躁",
+"干逼" => 	"乾逼",
 "干酪" => 	"乾酪",
 "干酵母" => 	"乾酵母",
+"干醋" => 	"乾醋",
+"干量" => 	"乾量",
+"干阿奶" => 	"乾阿奶",
 "干隆" => 	"乾隆",
 "干雷" => 	"乾雷",
 "干电" => 	"乾電",
 "干电池" => 	"乾電池",
+"干霍乱" => 	"乾霍亂",
+"干颡" => 	"乾顙",
+"干台" => 	"乾颱",
 "干饭" => 	"乾飯",
+"干馆" => 	"乾館",
+"干糇" => 	"乾餱",
 "干馏" => 	"乾餾",
+"干鱼" => 	"乾魚",
 "干鲜" => 	"乾鮮",
+"干面" => 	"乾麵",
 "乱发" => 	"亂髮",
 "乱哄" => 	"亂鬨",
 "乱哄不过来" => 	"亂鬨不過來",
 "事后" => 	"事後",
+"二不棱登" => 	"二不稜登",
 "二划" => 	"二劃",
 "二天后" => 	"二天後",
 "二缶钟惑" => 	"二缶鐘惑",
+"二里头" => 	"二里頭",
 "二只" => 	"二隻",
+"于余曲折" => 	"于餘曲折",
 "云乎" => 	"云乎",
 "云云" => 	"云云",
 "云为" => 	"云為",
@@ -2748,6 +2829,8 @@
 "五行生克" => 	"五行生剋",
 "五只" => 	"五隻",
 "五出" => 	"五齣",
+"井干摧败" => 	"井榦摧敗",
+"亚于" => 	"亞於",
 "交于" => 	"交於",
 "交讬" => 	"交託",
 "交游广阔" => 	"交遊廣闊",
@@ -2755,6 +2838,25 @@
 "亮丑" => 	"亮醜",
 "亮钟" => 	"亮鐘",
 "人云亦云" => 	"人云亦云",
+"人参加" => 	"人參加",
+"人参展" => 	"人參展",
+"人参战" => 	"人參戰",
+"人参拜" => 	"人參拜",
+"人参政" => 	"人參政",
+"人参照" => 	"人參照",
+"人参看" => 	"人參看",
+"人参禅" => 	"人參禪",
+"人参考" => 	"人參考",
+"人参与" => 	"人參與",
+"人参见" => 	"人參見",
+"人参观" => 	"人參觀",
+"人参谋" => 	"人參謀",
+"人参议" => 	"人參議",
+"人参赞" => 	"人參贊",
+"人参透" => 	"人參透",
+"人参选" => 	"人參選",
+"人参酌" => 	"人參酌",
+"人参阅" => 	"人參閱",
 "人后" => 	"人後",
 "人欲" => 	"人慾",
 "人物志" => 	"人物誌",
@@ -2762,13 +2864,12 @@
 "什锦面" => 	"什錦麵",
 "什么" => 	"什麼",
 "今后" => 	"今後",
-"介系词" => 	"介係詞",
 "介于" => 	"介於",
-"介系词" => 	"介繫詞",
 "付讬" => 	"付託",
 "仙药" => 	"仙藥",
 "以后" => 	"以後",
 "任教于" => 	"任教於",
+"任于" => 	"任於",
 "仿制" => 	"仿製",
 "企划" => 	"企劃",
 "伊府面" => 	"伊府麵",
@@ -2777,7 +2878,9 @@
 "伊郁" => 	"伊鬱",
 "伏几" => 	"伏几",
 "伙头" => 	"伙頭",
+"似于" => 	"似於",
 "但云" => 	"但云",
+"布于" => 	"佈於",
 "位于" => 	"位於",
 "低于" => 	"低於",
 "占上风" => 	"佔上風",
@@ -2796,7 +2899,6 @@
 "占取" => 	"佔取",
 "占在" => 	"佔在",
 "占地" => 	"佔地",
-"占城" => 	"佔城",
 "占多数" => 	"佔多數",
 "占好" => 	"佔好",
 "占得" => 	"佔得",
@@ -2812,21 +2914,20 @@
 "占超过" => 	"佔超過",
 "占过" => 	"佔過",
 "占领" => 	"佔領",
+"余光中" => 	"余光中",
+"余光生" => 	"余光生",
 "佛罗棱萨" => 	"佛羅稜薩",
 "作奸犯科" => 	"作姦犯科",
 "作准" => 	"作準",
+"作庄" => 	"作莊",
 "你才子发昏" => 	"你纔子發昏",
 "并一不二" => 	"併一不二",
 "并入" => 	"併入",
 "并兼" => 	"併兼",
-"并列" => 	"併列",
 "并到" => 	"併到",
-"并力" => 	"併力",
 "并合" => 	"併合",
 "并名" => 	"併名",
 "并吞" => 	"併吞",
-"并在" => 	"併在",
-"并成" => 	"併成",
 "并拢" => 	"併攏",
 "并案" => 	"併案",
 "并流" => 	"併流",
@@ -2843,6 +2944,7 @@
 "并购" => 	"併購",
 "并除" => 	"併除",
 "并骨" => 	"併骨",
+"来于" => 	"來於",
 "来自于" => 	"來自於",
 "来复" => 	"來複",
 "侍仆" => 	"侍僕",
@@ -2874,9 +2976,11 @@
 "假药" => 	"假藥",
 "假讬" => 	"假託",
 "假发" => 	"假髮",
+"偎干" => 	"偎乾",
 "偎干就湿" => 	"偎乾就濕",
 "偏后" => 	"偏後",
 "偏于" => 	"偏於",
+"做庄" => 	"做莊",
 "停停当当" => 	"停停當當",
 "停征" => 	"停徵",
 "停制" => 	"停製",
@@ -2893,6 +2997,7 @@
 "佣懒" => 	"傭懶",
 "佣书" => 	"傭書",
 "佣金" => 	"傭金",
+"伤痕累累" => 	"傷痕纍纍",
 "傻里傻气" => 	"傻裡傻氣",
 "倾向于" => 	"傾向於",
 "倾家荡产" => 	"傾家蕩產",
@@ -2992,6 +3097,8 @@
 "公干" => 	"公幹",
 "公历" => 	"公曆",
 "公诸于世" => 	"公諸於世",
+"公厘" => 	"公釐",
+"公余" => 	"公餘",
 "六划" => 	"六劃",
 "六天后" => 	"六天後",
 "六扎" => 	"六紮",
@@ -3000,6 +3107,7 @@
 "六出" => 	"六齣",
 "其后" => 	"其後",
 "其次辟地" => 	"其次辟地",
+"其余" => 	"其餘",
 "典范" => 	"典範",
 "兼并" => 	"兼併",
 "冉有仆" => 	"冉有僕",
@@ -3007,7 +3115,10 @@
 "冤雠" => 	"冤讎",
 "冥蒙" => 	"冥濛",
 "冬山庄" => 	"冬山庄",
+"冬游" => 	"冬遊",
 "冶游" => 	"冶遊",
+"冷面相" => 	"冷面相",
+"冷面" => 	"冷麵",
 "凌蒙初" => 	"凌濛初",
 "凌藉" => 	"凌藉",
 "几几" => 	"几几",
@@ -3026,7 +3137,7 @@
 "分布" => 	"分佈",
 "分占" => 	"分佔",
 "分钟" => 	"分鐘",
-"切面" => 	"切麵",
+"刑余" => 	"刑餘",
 "划着" => 	"划著",
 "划着走" => 	"划著走",
 "划龙舟" => 	"划龍舟",
@@ -3052,7 +3163,6 @@
 "削面" => 	"削麵",
 "克制" => 	"剋制",
 "克星" => 	"剋星",
-"克服" => 	"剋服",
 "克死" => 	"剋死",
 "克薄" => 	"剋薄",
 "前仰后合" => 	"前仰後合",
@@ -3065,6 +3175,7 @@
 "刚干" => 	"剛乾",
 "刚雇" => 	"剛僱",
 "刚才一载" => 	"剛纔一載",
+"剩余" => 	"剩餘",
 "剪牡丹喂牛" => 	"剪牡丹喂牛",
 "剪䌽" => 	"剪綵",
 "剪发" => 	"剪髮",
@@ -3099,10 +3210,14 @@
 "力争上游" => 	"力爭上遊",
 "功致" => 	"功緻",
 "加害于" => 	"加害於",
+"加工余量" => 	"加工餘量",
 "加卷" => 	"加捲",
 "加于" => 	"加於",
 "加药" => 	"加藥",
 "加注" => 	"加註",
+"劣于" => 	"劣於",
+"助于" => 	"助於",
+"劫余" => 	"劫餘",
 "勃郁" => 	"勃鬱",
 "勇于" => 	"勇於",
 "动荡" => 	"動蕩",
@@ -3110,6 +3225,7 @@
 "劳力士表" => 	"勞力士錶",
 "勤仆" => 	"勤僕",
 "勤朴" => 	"勤樸",
+"勾干" => 	"勾幹",
 "勾心斗角" => 	"勾心鬥角",
 "勿施于人" => 	"勿施於人",
 "包谷" => 	"包穀",
@@ -3119,6 +3235,7 @@
 "北回铁路" => 	"北迴鐵路",
 "匡复" => 	"匡複",
 "匪干" => 	"匪幹",
+"匿于" => 	"匿於",
 "区划" => 	"區劃",
 "十划" => 	"十劃",
 "十多只" => 	"十多隻",
@@ -3136,6 +3253,7 @@
 "千钧一发" => 	"千鈞一髮",
 "千只" => 	"千隻",
 "午后" => 	"午後",
+"半于" => 	"半於",
 "半只" => 	"半隻",
 "南岳" => 	"南嶽",
 "南筑" => 	"南筑",
@@ -3146,6 +3264,7 @@
 "博采" => 	"博採",
 "印累绶若" => 	"印纍綬若",
 "印制" => 	"印製",
+"危于" => 	"危於",
 "卷发" => 	"卷髮",
 "卷须" => 	"卷鬚",
 "厂部" => 	"厂部",
@@ -3168,7 +3287,8 @@
 "反于" => 	"反於",
 "反朴" => 	"反樸",
 "反冲" => 	"反衝",
-"反复" => 	"反複",
+"反复制" => 	"反複製",
+"反复" => 	"反覆",
 "取信于" => 	"取信於",
 "取舍" => 	"取捨",
 "取材于" => 	"取材於",
@@ -3199,6 +3319,8 @@
 "台制" => 	"台製",
 "右后" => 	"右後",
 "叶恭弘" => 	"叶恭弘",
+"叶 恭弘" => 	"叶 恭弘",
+"叶　恭弘" => 	"叶　恭弘",
 "叶音" => 	"叶音",
 "叶韵" => 	"叶韻",
 "吃板刀面" => 	"吃板刀麵",
@@ -3225,8 +3347,8 @@
 "吊裤带" => 	"吊褲帶",
 "吊钟" => 	"吊鐘",
 "同伙" => 	"同夥",
+"同于" => 	"同於",
 "名闻于世" => 	"名聞於世",
-"名表" => 	"名錶",
 "后发座" => 	"后髮座",
 "向后" => 	"向後",
 "向着" => 	"向著",
@@ -3234,13 +3356,12 @@
 "吟游" => 	"吟遊",
 "吹干" => 	"吹乾",
 "吹发" => 	"吹髮",
-"獃致致" => 	"呆緻緻",
-"獃里獃气" => 	"呆裡呆氣",
+"呆致致" => 	"呆緻緻",
+"呆里呆气" => 	"呆裡呆氣",
 "周历" => 	"周曆",
 "周杰伦" => 	"周杰倫",
 "周游" => 	"周遊",
 "呼吁" => 	"呼籲",
-"和面" => 	"和麵",
 "咬姜呷醋" => 	"咬薑呷醋",
 "咯当" => 	"咯噹",
 "咳嗽药" => 	"咳嗽藥",
@@ -3249,8 +3370,10 @@
 "员山庄" => 	"員山庄",
 "哪里" => 	"哪裡",
 "哭脏" => 	"哭髒",
+"唇干" => 	"唇乾",
 "唱游" => 	"唱遊",
 "唾面自干" => 	"唾面自乾",
+"唾余" => 	"唾餘",
 "商历" => 	"商曆",
 "问政于民" => 	"問政於民",
 "问道于盲" => 	"問道於盲",
@@ -3260,8 +3383,8 @@
 "喜形于色" => 	"喜形於色",
 "喧哄" => 	"喧鬨",
 "丧钟" => 	"喪鐘",
+"单干" => 	"單幹",
 "单打独斗" => 	"單打獨鬥",
-"单于" => 	"單於",
 "单只" => 	"單隻",
 "嗑药" => 	"嗑藥",
 "嗣后" => 	"嗣後",
@@ -3276,8 +3399,8 @@
 "向往" => 	"嚮往",
 "向应" => 	"嚮應",
 "向迩" => 	"嚮邇",
+"严于" => 	"嚴於",
 "严丝合缝" => 	"嚴絲合縫",
-"严复" => 	"嚴複",
 "嚼谷" => 	"嚼穀",
 "囉囉苏苏" => 	"囉囉囌囌",
 "囉苏" => 	"囉囌",
@@ -3288,20 +3411,28 @@
 "四扎" => 	"四紮",
 "四只" => 	"四隻",
 "四出" => 	"四齣",
+"回采" => 	"回採",
 "回历" => 	"回曆",
 "回丝" => 	"回絲",
 "回着" => 	"回著",
 "回荡" => 	"回蕩",
 "回游" => 	"回遊",
+"因于" => 	"因於",
 "困于" => 	"困於",
 "困兽之斗" => 	"困獸之鬥",
 "困兽犹斗" => 	"困獸猶鬥",
 "固于" => 	"固於",
+"囿于" => 	"囿於",
 "囿于一时" => 	"囿於一時",
 "囿于成见" => 	"囿於成見",
 "圈子里" => 	"圈子裡",
+"圈梁" => 	"圈樑",
 "圈里" => 	"圈裡",
+"国之桢干" => 	"國之楨榦",
+"国于" => 	"國於",
 "国历" => 	"國曆",
+"国历代" => 	"國歷代",
+"国历史" => 	"國歷史",
 "国雠" => 	"國讎",
 "园里" => 	"園裡",
 "园游会" => 	"園遊會",
@@ -3311,6 +3442,7 @@
 "在于" => 	"在於",
 "地志" => 	"地誌",
 "地丑德齐" => 	"地醜德齊",
+"坏于" => 	"坏於",
 "坐钟" => 	"坐鐘",
 "坑里" => 	"坑裡",
 "坤范" => 	"坤範",
@@ -3345,6 +3477,8 @@
 "寿面" => 	"壽麵",
 "夏天里" => 	"夏天裡",
 "夏历" => 	"夏曆",
+"夏历史" => 	"夏歷史",
+"夏游" => 	"夏遊",
 "外强中干" => 	"外強中乾",
 "外制" => 	"外製",
 "多划" => 	"多劃",
@@ -3353,6 +3487,7 @@
 "多冲" => 	"多衝",
 "多丑" => 	"多醜",
 "多只" => 	"多隻",
+"多余" => 	"多餘",
 "多么" => 	"多麼",
 "夜光表" => 	"夜光錶",
 "夜里" => 	"夜裡",
@@ -3370,11 +3505,12 @@
 "大于" => 	"大於",
 "大明历" => 	"大明曆",
 "大历" => 	"大曆",
+"大梁" => 	"大樑",
+"大目干连" => 	"大目乾連",
 "大衍历" => 	"大衍曆",
 "大言非夸" => 	"大言非夸",
 "大丑" => 	"大醜",
 "大锤" => 	"大鎚",
-"大坂" => 	"大阪",
 "大只" => 	"大隻",
 "天干物燥" => 	"天乾物燥",
 "天克地冲" => 	"天克地衝",
@@ -3386,6 +3522,7 @@
 "天复地载" => 	"天覆地載",
 "太仆" => 	"太僕",
 "太初历" => 	"太初曆",
+"夯干" => 	"夯幹",
 "失信于人" => 	"失信於人",
 "失于" => 	"失於",
 "夸人" => 	"夸人",
@@ -3406,9 +3543,11 @@
 "奴仆" => 	"奴僕",
 "好干" => 	"好乾",
 "好家伙" => 	"好傢夥",
+"好于" => 	"好於",
 "好签" => 	"好籤",
 "好丑" => 	"好醜",
 "如于" => 	"如於",
+"如果干" => 	"如果幹",
 "如法泡制" => 	"如法泡製",
 "妙药" => 	"妙藥",
 "始于" => 	"始於",
@@ -3422,6 +3561,7 @@
 "奸污" => 	"姦汙",
 "奸淫" => 	"姦淫",
 "奸邪" => 	"姦邪",
+"威棱" => 	"威稜",
 "婚后" => 	"婚後",
 "婢仆" => 	"婢僕",
 "嫁于" => 	"嫁於",
@@ -3429,9 +3569,11 @@
 "嫌好道丑" => 	"嫌好道醜",
 "娴于" => 	"嫻於",
 "嬉游" => 	"嬉遊",
+"嬴余" => 	"嬴餘",
 "子之丰兮" => 	"子之丰兮",
 "字汇" => 	"字彙",
 "字里行间" => 	"字裡行間",
+"存十一于千百" => 	"存十一於千百",
 "存折" => 	"存摺",
 "季后赛" => 	"季後賽",
 "孤寡不谷" => 	"孤寡不穀",
@@ -3445,6 +3587,7 @@
 "宗周钟" => 	"宗周鐘",
 "官地为采" => 	"官地為寀",
 "官历" => 	"官曆",
+"官庄" => 	"官莊",
 "定于" => 	"定於",
 "定准" => 	"定準",
 "定制" => 	"定製",
@@ -3452,55 +3595,64 @@
 "宜于" => 	"宜於",
 "宦游" => 	"宦遊",
 "宫里" => 	"宮裡",
+"害于" => 	"害於",
 "宴游" => 	"宴遊",
 "家仆" => 	"家僕",
+"家庄" => 	"家莊",
 "家里" => 	"家裡",
 "家丑" => 	"家醜",
 "容后说明" => 	"容後說明",
+"容于" => 	"容於",
 "容范" => 	"容範",
 "寄于" => 	"寄於",
 "寄讬" => 	"寄託",
 "寇雠" => 	"寇讎",
 "富于" => 	"富於",
+"富余" => 	"富餘",
 "寒栗" => 	"寒慄",
+"寒于" => 	"寒於",
 "寓兵于农" => 	"寓兵於農",
 "寓教于乐" => 	"寓教於樂",
 "寓于" => 	"寓於",
 "寡欲" => 	"寡慾",
 "实干" => 	"實幹",
 "写字台" => 	"寫字檯",
+"宽于" => 	"寬於",
+"宽余" => 	"寬餘",
 "宽松" => 	"寬鬆",
 "寮采" => 	"寮寀",
 "宝山庄" => 	"寶山庄",
 "宝历" => 	"寶曆",
 "封面里" => 	"封面裡",
+"射雕" => 	"射鵰",
 "将于" => 	"將於",
 "专美于前" => 	"專美於前",
 "专注" => 	"專註",
 "对折" => 	"對摺",
 "对于" => 	"對於",
 "对准" => 	"對準",
+"对华发动" => 	"對華發動",
 "对表" => 	"對錶",
 "导游" => 	"導遊",
 "小仆" => 	"小僕",
 "小伙子" => 	"小夥子",
 "小于" => 	"小於",
 "小米面" => 	"小米麵",
-"小丑" => 	"小醜",
-"小丑跳樑" => 	"小醜跳樑",
 "小只" => 	"小隻",
 "少采" => 	"少採",
 "少于" => 	"少於",
 "就于" => 	"就於",
 "就范" => 	"就範",
 "就读于" => 	"就讀於",
+"尸魂界" => 	"尸魂界",
 "尼克松" => 	"尼克鬆",
-"尼采" => 	"尼採",
 "局里" => 	"局裡",
 "居于" => 	"居於",
 "屈服于" => 	"屈服於",
 "屋子里" => 	"屋子裡",
+"屋梁" => 	"屋樑",
 "屋里" => 	"屋裡",
+"屑于" => 	"屑於",
 "屡顾尔仆" => 	"屢顧爾僕",
 "属意于" => 	"屬意於",
 "属于" => 	"屬於",
@@ -3509,11 +3661,14 @@
 "山崩钟应" => 	"山崩鐘應",
 "山岳" => 	"山嶽",
 "山后" => 	"山後",
+"山梁" => 	"山樑",
+"山庄" => 	"山莊",
 "山药" => 	"山藥",
 "山里" => 	"山裡",
 "峰回" => 	"峰迴",
 "崑仑" => 	"崑崙",
 "仑背" => 	"崙背",
+"嶒棱" => 	"嶒稜",
 "岳麓山" => 	"嶽麓山",
 "川谷" => 	"川穀",
 "巡回" => 	"巡迴",
@@ -3525,6 +3680,7 @@
 "巧妇做不得无面馎饦" => 	"巧婦做不得無麵餺飥",
 "巧干" => 	"巧幹",
 "巧历" => 	"巧曆",
+"差于" => 	"差於",
 "已于" => 	"已於",
 "巴尔干" => 	"巴爾幹",
 "巷里" => 	"巷裡",
@@ -3545,6 +3701,7 @@
 "平准" => 	"平準",
 "年后" => 	"年後",
 "年历" => 	"年曆",
+"年历史" => 	"年歷史",
 "年谷" => 	"年穀",
 "年里" => 	"年裡",
 "并州" => 	"并州",
@@ -3553,14 +3710,17 @@
 "干了" => 	"幹了",
 "干事" => 	"幹事",
 "干些" => 	"幹些",
+"干人" => 	"幹人",
 "干什么" => 	"幹什麼",
 "干个" => 	"幹個",
 "干劲" => 	"幹勁",
+"干吏" => 	"幹吏",
 "干员" => 	"幹員",
 "干吗" => 	"幹嗎",
 "干嘛" => 	"幹嘛",
 "干坏事" => 	"幹壞事",
 "干完" => 	"幹完",
+"干家" => 	"幹家",
 "干得" => 	"幹得",
 "干性油" => 	"幹性油",
 "干才" => 	"幹才",
@@ -3569,28 +3729,48 @@
 "干校" => 	"幹校",
 "干活" => 	"幹活",
 "干流" => 	"幹流",
+"干济" => 	"幹濟",
+"干营生" => 	"幹營生",
+"干父之蛊" => 	"幹父之蠱",
 "干球温度" => 	"幹球溫度",
+"干当" => 	"幹當",
+"干的停当" => 	"幹的停當",
 "干细胞" => 	"幹細胞",
 "干线" => 	"幹線",
 "干练" => 	"幹練",
+"干缺" => 	"幹缺",
+"干蛊" => 	"幹蠱",
 "干警" => 	"幹警",
 "干起来" => 	"幹起來",
 "干路" => 	"幹路",
 "干道" => 	"幹道",
 "干部" => 	"幹部",
+"干革命" => 	"幹革命",
+"干头" => 	"幹頭",
 "干么" => 	"幹麼",
 "几划" => 	"幾劃",
+"几天后" => 	"幾天後",
 "几于" => 	"幾於",
 "几丝" => 	"幾絲",
 "几只" => 	"幾隻",
 "几出" => 	"幾齣",
 "广部" => 	"广部",
+"府干卿" => 	"府干卿",
+"府干扰" => 	"府干擾",
+"府干政" => 	"府干政",
+"府干涉" => 	"府干涉",
+"府干犯" => 	"府干犯",
+"府干预" => 	"府干預",
+"府干" => 	"府幹",
 "府后" => 	"府後",
 "座钟" => 	"座鐘",
 "康采恩" => 	"康採恩",
+"康庄" => 	"康莊",
+"厨余" => 	"廚餘",
 "庙里" => 	"廟裡",
 "广舍" => 	"廣捨",
 "延后" => 	"延後",
+"建于" => 	"建於",
 "建都于" => 	"建都於",
 "弄干" => 	"弄乾",
 "弄丑" => 	"弄醜",
@@ -3611,17 +3791,19 @@
 "吊民伐罪" => 	"弔民伐罪",
 "吊祭" => 	"弔祭",
 "弘历" => 	"弘曆",
+"弱于" => 	"弱於",
 "弱硷" => 	"弱鹼",
 "张三丰" => 	"張三丰",
 "强占" => 	"強佔",
 "强奸" => 	"強姦",
+"强干" => 	"強幹",
+"强于" => 	"強於",
 "强硷" => 	"強鹼",
 "别口气" => 	"彆口氣",
 "别强" => 	"彆強",
 "别扭" => 	"彆扭",
 "别拗" => 	"彆拗",
 "别气" => 	"彆氣",
-"别脚" => 	"彆腳",
 "别着" => 	"彆著",
 "弹子台" => 	"彈子檯",
 "弹药" => 	"彈藥",
@@ -3632,6 +3814,8 @@
 "汇辑" => 	"彙輯",
 "汇集" => 	"彙集",
 "形单影只" => 	"形單影隻",
+"形于" => 	"形於",
+"役于" => 	"役於",
 "役于外物" => 	"役於外物",
 "往来于" => 	"往來於",
 "往后" => 	"往後",
@@ -3661,6 +3845,7 @@
 "后勤" => 	"後勤",
 "后区" => 	"後區",
 "后半" => 	"後半",
+"后印" => 	"後印",
 "后去" => 	"後去",
 "后台" => 	"後台",
 "后向" => 	"後向",
@@ -3684,6 +3869,7 @@
 "后市" => 	"後市",
 "后年" => 	"後年",
 "后几" => 	"後幾",
+"后庄" => 	"後庄",
 "后序" => 	"後序",
 "后座" => 	"後座",
 "后悔" => 	"後悔",
@@ -3713,7 +3899,6 @@
 "后果" => 	"後果",
 "后桅" => 	"後桅",
 "后梁" => 	"後梁",
-"后樑" => 	"後樑",
 "后桥" => 	"後橋",
 "后步" => 	"後步",
 "后段" => 	"後段",
@@ -3797,10 +3982,12 @@
 "后魏" => 	"後魏",
 "后点" => 	"後點",
 "后龙" => 	"後龍",
+"徐干" => 	"徐幹",
 "徒讬空言" => 	"徒託空言",
 "得于" => 	"得於",
 "徜徉于" => 	"徜徉於",
 "从事于" => 	"從事於",
+"从于" => 	"從於",
 "从里到外" => 	"從裡到外",
 "从里向外" => 	"從裡向外",
 "复始" => 	"復始",
@@ -3832,10 +4019,12 @@
 "征集" => 	"徵集",
 "征验出" => 	"徵驗出",
 "心愿" => 	"心愿",
+"心于" => 	"心於",
 "心细如发" => 	"心細如髮",
 "心荡神驰" => 	"心蕩神馳",
 "心药" => 	"心藥",
 "心里" => 	"心裡",
+"心余" => 	"心餘",
 "志于" => 	"志於",
 "忙并" => 	"忙併",
 "忙于" => 	"忙於",
@@ -3850,6 +4039,7 @@
 "怎么" => 	"怎麼",
 "怎么着" => 	"怎麼著",
 "怒形于色" => 	"怒形於色",
+"怒于" => 	"怒於",
 "怒发冲冠" => 	"怒髮衝冠",
 "思前思后" => 	"思前思後",
 "思前想后" => 	"思前想後",
@@ -3857,7 +4047,6 @@
 "急冲而下" => 	"急衝而下",
 "性征" => 	"性徵",
 "性欲" => 	"性慾",
-"怨在小丑" => 	"怨在小醜",
 "怪里怪气" => 	"怪裡怪氣",
 "怫郁" => 	"怫鬱",
 "息谷" => 	"息穀",
@@ -3866,6 +4055,7 @@
 "悒郁" => 	"悒鬱",
 "悒郁寡欢" => 	"悒鬱寡歡",
 "悠游" => 	"悠遊",
+"闷着头儿干" => 	"悶著頭兒幹",
 "悸栗" => 	"悸慄",
 "情欲" => 	"情慾",
 "惇朴" => 	"惇樸",
@@ -3906,10 +4096,13 @@
 "懒于" => 	"懶於",
 "怀里" => 	"懷裡",
 "怀表" => 	"懷錶",
+"悬梁" => 	"懸樑",
+"悬臂梁" => 	"懸臂樑",
 "悬钟" => 	"懸鐘",
 "惧于" => 	"懼於",
 "懿范" => 	"懿範",
 "恋恋不舍" => 	"戀戀不捨",
+"成于" => 	"成於",
 "成药" => 	"成藥",
 "或于" => 	"或於",
 "戬谷" => 	"戩穀",
@@ -3927,8 +4120,11 @@
 "手表" => 	"手錶",
 "手松" => 	"手鬆",
 "才干" => 	"才幹",
+"打干哕" => 	"打乾噦",
 "打并" => 	"打併",
 "打卡钟" => 	"打卡鐘",
+"打干" => 	"打幹",
+"打拼" => 	"打拚",
 "打谷" => 	"打穀",
 "打钟" => 	"打鐘",
 "打斗" => 	"打鬥",
@@ -3963,13 +4159,18 @@
 "拈须" => 	"拈鬚",
 "拉纤" => 	"拉縴",
 "拉面" => 	"拉麵",
+"拒人于" => 	"拒人於",
+"拒于" => 	"拒於",
 "拓朴" => 	"拓樸",
 "拗别" => 	"拗彆",
+"拘于" => 	"拘於",
 "拘泥于" => 	"拘泥於",
 "拙于" => 	"拙於",
 "拙朴" => 	"拙樸",
-"拚舍" => 	"拚捨",
-"拚斗" => 	"拚鬥",
+"拼命" => 	"拚命",
+"拼舍" => 	"拚捨",
+"拼死" => 	"拚死",
+"拼斗" => 	"拚鬥",
 "拜讬" => 	"拜託",
 "括发" => 	"括髮",
 "拭干" => 	"拭乾",
@@ -4059,7 +4260,6 @@
 "采拾" => 	"採拾",
 "采挖" => 	"採挖",
 "采掘" => 	"採掘",
-"采采" => 	"採採",
 "采摘" => 	"採摘",
 "采摭" => 	"採摭",
 "采择" => 	"採擇",
@@ -4111,24 +4311,31 @@
 "采录" => 	"採錄",
 "采铁" => 	"採鐵",
 "采集" => 	"採集",
+"采风" => 	"採風",
 "采风问俗" => 	"採風問俗",
 "采食" => 	"採食",
 "采盐" => 	"採鹽",
+"掣签" => 	"掣籤",
 "接着说" => 	"接著說",
 "推讬" => 	"推託",
 "提子干" => 	"提子乾",
 "提心吊胆" => 	"提心弔膽",
 "提摩太后书" => 	"提摩太後書",
+"插于" => 	"插於",
 "插足于" => 	"插足於",
 "换签" => 	"換籤",
 "换药" => 	"換藥",
 "换只" => 	"換隻",
 "换发" => 	"換髮",
+"揩干" => 	"揩乾",
 "揪采" => 	"揪採",
 "揭丑" => 	"揭醜",
+"挥手表" => 	"揮手表",
 "搋面" => 	"搋麵",
+"损于" => 	"損於",
 "搏斗" => 	"搏鬥",
 "摇荡" => 	"搖蕩",
+"搭干铺" => 	"搭乾鋪",
 "搭伙" => 	"搭夥",
 "抢占" => 	"搶佔",
 "搽药" => 	"搽藥",
@@ -4147,6 +4354,7 @@
 "折篷" => 	"摺篷",
 "折纸" => 	"摺紙",
 "折裙" => 	"摺裙",
+"捞干" => 	"撈乾",
 "捞面" => 	"撈麵",
 "撚须" => 	"撚鬚",
 "撞木钟" => 	"撞木鐘",
@@ -4156,6 +4364,7 @@
 "撤并" => 	"撤併",
 "撤后" => 	"撤後",
 "拨谷" => 	"撥穀",
+"播于" => 	"播於",
 "扑冬" => 	"撲鼕",
 "擀面" => 	"擀麵",
 "擅于" => 	"擅於",
@@ -4165,6 +4374,7 @@
 "担着" => 	"擔著",
 "担负着" => 	"擔負著",
 "据云" => 	"據云",
+"据干而窥井底" => 	"據榦而窺井底",
 "挤身于" => 	"擠身於",
 "擢发" => 	"擢髮",
 "擢发难数" => 	"擢髮難數",
@@ -4180,23 +4390,26 @@
 "改征" => 	"改徵",
 "改于" => 	"改於",
 "攻占" => 	"攻佔",
-"攻克" => 	"攻剋",
 "放蒙挣" => 	"放懞掙",
 "放荡" => 	"放蕩",
 "放松" => 	"放鬆",
 "故于" => 	"故於",
+"敏于" => 	"敏於",
+"败于" => 	"敗於",
 "叙说着" => 	"敘說著",
+"教于" => 	"教於",
+"敢干" => 	"敢幹",
 "敢于" => 	"敢於",
 "散伙" => 	"散夥",
+"散于" => 	"散於",
 "散荡" => 	"散蕩",
-"散发" => 	"散髮",
 "敦朴" => 	"敦樸",
 "敬挽" => 	"敬輓",
 "敲钟" => 	"敲鐘",
 "整只" => 	"整隻",
-"整出" => 	"整齣",
 "敌后" => 	"敵後",
 "敷药" => 	"敷藥",
+"数天后" => 	"數天後",
 "数罪并罚" => 	"數罪併罰",
 "数与虏确" => 	"數與虜确",
 "文汇报" => 	"文匯報",
@@ -4206,30 +4419,90 @@
 "料斗" => 	"料鬥",
 "斫雕为朴" => 	"斫雕為樸",
 "新历" => 	"新曆",
+"新历史" => 	"新歷史",
 "新扎" => 	"新紮",
+"新庄" => 	"新莊",
 "斲雕为朴" => 	"斲雕為樸",
 "断后" => 	"斷後",
 "断发" => 	"斷髮",
 "方便面" => 	"方便麵",
 "方几" => 	"方几",
+"于一役" => 	"於一役",
 "于七" => 	"於七",
+"于世" => 	"於世",
+"于事" => 	"於事",
 "于事无补" => 	"於事無補",
+"于人" => 	"於人",
 "于今" => 	"於今",
+"于他" => 	"於他",
+"于伏" => 	"於伏",
+"于何" => 	"於何",
+"于你" => 	"於你",
+"于前" => 	"於前",
+"于劣" => 	"於劣",
+"于勤" => 	"於勤",
+"于呼哀哉" => 	"於呼哀哉",
+"于国" => 	"於國",
+"于坏" => 	"於坏",
+"于垂" => 	"於垂",
 "于夫罗" => 	"於夫羅",
+"于她" => 	"於她",
+"于好" => 	"於好",
+"于始" => 	"於始",
+"于它" => 	"於它",
+"于家" => 	"於家",
+"于密" => 	"於密",
 "于左" => 	"於左",
+"于差" => 	"於差",
+"于己" => 	"於己",
+"于市" => 	"於市",
+"于幕" => 	"於幕",
 "于幼华" => 	"於幼華",
+"于弱" => 	"於弱",
+"于强" => 	"於強",
+"于征" => 	"於征",
 "于后" => 	"於後",
+"于心" => 	"於心",
 "于心何忍" => 	"於心何忍",
 "于思" => 	"於思",
+"于怀" => 	"於懷",
+"于我" => 	"於我",
 "于斯" => 	"於斯",
 "于于" => 	"於於",
 "于是" => 	"於是",
+"于时" => 	"於時",
 "于梨华" => 	"於梨華",
+"于乐" => 	"於樂",
 "于此" => 	"於此",
+"于民" => 	"於民",
+"于法" => 	"於法",
 "于法无据" => 	"於法無據",
+"于潜县" => 	"於潛縣",
+"于火" => 	"於火",
+"于焉" => 	"於焉",
+"于墙" => 	"於牆",
+"于物" => 	"於物",
 "于田" => 	"於田",
+"于毕" => 	"於畢",
+"于尽" => 	"於盡",
+"于盲" => 	"於盲",
+"于祂" => 	"於祂",
+"于穆" => 	"於穆",
+"于终" => 	"於終",
+"于美" => 	"於美",
+"于色" => 	"於色",
+"于行" => 	"於行",
+"于衷" => 	"於衷",
+"于该" => 	"於該",
+"于农" => 	"於農",
+"于途" => 	"於途",
+"于丑" => 	"於醜",
+"于野" => 	"於野",
+"于陆" => 	"於陸",
 "于飞" => 	"於飛",
 "施舍" => 	"施捨",
+"施于" => 	"施於",
+"施舍之道" => 	"施舍之道",
 "施药" => 	"施藥",
 "旁征博引" => 	"旁徵博引",
 "旁注" => 	"旁註",
@@ -4245,6 +4518,7 @@
 "旱干" => 	"旱乾",
 "昆仑" => 	"昆崙",
 "升平" => 	"昇平",
+"升阳" => 	"昇陽",
 "明征" => 	"明徵",
 "明于" => 	"明於",
 "明窗净几" => 	"明窗淨几",
@@ -4311,11 +4585,15 @@
 "有求于人" => 	"有求於人",
 "有奖征答" => 	"有獎徵答",
 "有益于" => 	"有益於",
+"有棱有角" => 	"有稜有角",
 "有只" => 	"有隻",
+"有余" => 	"有餘",
 "有发头陀寺" => 	"有髮頭陀寺",
 "服务于" => 	"服務於",
 "服从于" => 	"服從於",
+"服于" => 	"服於",
 "服药" => 	"服藥",
+"朝干夕惕" => 	"朝乾夕惕",
 "朝后" => 	"朝後",
 "朝钟" => 	"朝鐘",
 "朦胧" => 	"朦朧",
@@ -4324,10 +4602,15 @@
 "未干" => 	"未乾",
 "末药" => 	"末藥",
 "术赤" => 	"朮赤",
+"朱庆余" => 	"朱慶餘",
 "朱理安历" => 	"朱理安曆",
 "李连杰" => 	"李連杰",
+"村庄" => 	"村莊",
+"村落发" => 	"村落發",
 "村里" => 	"村裡",
 "束发" => 	"束髮",
+"杯干" => 	"杯乾",
+"杰特" => 	"杰特",
 "东岳" => 	"東嶽",
 "东冲西突" => 	"東衝西突",
 "东游" => 	"東遊",
@@ -4338,37 +4621,53 @@
 "枕经藉史" => 	"枕經藉史",
 "枕藉" => 	"枕藉",
 "林宏岳" => 	"林宏嶽",
+"林郁方" => 	"林郁方",
 "林钟" => 	"林鐘",
+"果干" => 	"果乾",
 "果子干" => 	"果子乾",
 "果于" => 	"果於",
+"枝不得大于干" => 	"枝不得大於榦",
 "枝干" => 	"枝幹",
 "枯干" => 	"枯乾",
-"枯干" => 	"枯幹",
 "某只" => 	"某隻",
+"染指于" => 	"染指於",
 "染发" => 	"染髮",
 "柜上" => 	"柜上",
 "柜台" => 	"柜台",
 "柜子" => 	"柜子",
+"柱梁" => 	"柱樑",
 "校准" => 	"校準",
 "校雠学" => 	"校讎學",
+"格于" => 	"格於",
 "格范" => 	"格範",
 "格斗" => 	"格鬥",
 "桂圆干" => 	"桂圓乾",
 "案发后" => 	"案發後",
 "桌历" => 	"桌曆",
+"桑干" => 	"桑乾",
 "条干" => 	"條幹",
 "梨干" => 	"梨乾",
 "械斗" => 	"械鬥",
 "弃舍" => 	"棄捨",
 "棉制" => 	"棉製",
 "棒子面" => 	"棒子麵",
+"枣庄" => 	"棗莊",
+"栋梁" => 	"棟樑",
 "棫朴" => 	"棫樸",
 "栖于" => 	"棲於",
 "植发" => 	"植髮",
 "椰枣干" => 	"椰棗乾",
+"楚庄王" => 	"楚莊王",
+"桢干" => 	"楨幹",
+"业余" => 	"業餘",
 "榨干" => 	"榨乾",
 "乐意于" => 	"樂意於",
 "乐于" => 	"樂於",
+"樊于期" => 	"樊於期",
+"梁上" => 	"樑上",
+"梁子" => 	"樑子",
+"梁书" => 	"樑書",
+"梁柱" => 	"樑柱",
 "标志着" => 	"標志著",
 "标标致致" => 	"標標致致",
 "标准" => 	"標準",
@@ -4403,8 +4702,11 @@
 "朴鲁" => 	"樸魯",
 "树干" => 	"樹幹",
 "树干" => 	"樹榦",
+"树梁" => 	"樹樑",
+"桥梁" => 	"橋樑",
 "机绣" => 	"機繡",
 "横征暴敛" => 	"橫徵暴斂",
+"横梁" => 	"橫樑",
 "横冲" => 	"橫衝",
 "台子" => 	"檯子",
 "台布" => 	"檯布",
@@ -4436,12 +4738,14 @@
 "归罪于" => 	"歸罪於",
 "归随于" => 	"歸隨於",
 "归顺于" => 	"歸順於",
+"归余" => 	"歸餘",
 "死伤相藉" => 	"死傷相藉",
 "死后" => 	"死後",
 "死于" => 	"死於",
 "死里求生" => 	"死裡求生",
 "死里逃生" => 	"死裡逃生",
 "殖谷" => 	"殖穀",
+"残余" => 	"殘餘",
 "杀虫药" => 	"殺虫藥",
 "杀虫药" => 	"殺蟲藥",
 "壳里" => 	"殼裡",
@@ -4456,6 +4760,7 @@
 "比划" => 	"比劃",
 "毛姜" => 	"毛薑",
 "毛发" => 	"毛髮",
+"毫厘" => 	"毫釐",
 "毫发" => 	"毫髮",
 "气郁" => 	"氣鬱",
 "氤郁" => 	"氤鬱",
@@ -4474,6 +4779,7 @@
 "污蔑" => 	"汙衊",
 "池里" => 	"池裡",
 "污蔑" => 	"污衊",
+"汲于" => 	"汲於",
 "汲汲于" => 	"汲汲於",
 "决斗" => 	"決鬥",
 "沈淀" => 	"沈澱",
@@ -4485,7 +4791,10 @@
 "沉迷于" => 	"沉迷於",
 "沉醉于" => 	"沉醉於",
 "沉郁" => 	"沉鬱",
+"没干没净" => 	"沒乾沒淨",
 "没事干" => 	"沒事幹",
+"没干" => 	"沒幹",
+"没梢干" => 	"沒梢幹",
 "没样范" => 	"沒樣範",
 "没药" => 	"沒藥",
 "冲冠发怒" => 	"沖冠髮怒",
@@ -4497,7 +4806,9 @@
 "油面" => 	"油麵",
 "泛游" => 	"泛遊",
 "泡面" => 	"泡麵",
+"波棱菜" => 	"波稜菜",
 "波发藻" => 	"波髮藻",
+"泥于" => 	"泥於",
 "注云" => 	"注云",
 "泱郁" => 	"泱鬱",
 "泳气钟" => 	"泳氣鐘",
@@ -4522,7 +4833,7 @@
 "浮荡" => 	"浮蕩",
 "浮游" => 	"浮遊",
 "浮松" => 	"浮鬆",
-"海里" => 	"海裡",
+"海干" => 	"海乾",
 "浸于" => 	"浸於",
 "涂着" => 	"涂著",
 "涂谨申" => 	"涂謹申",
@@ -4534,9 +4845,12 @@
 "涸干" => 	"涸乾",
 "凉面" => 	"涼麵",
 "淑范" => 	"淑範",
+"泪干" => 	"淚乾",
 "泪如泉涌" => 	"淚如泉湧",
+"淡于" => 	"淡於",
 "淡蒙蒙" => 	"淡濛濛",
 "淡朱" => 	"淡硃",
+"净余" => 	"淨餘",
 "净发" => 	"淨髮",
 "淫欲" => 	"淫慾",
 "淫荡" => 	"淫蕩",
@@ -4587,9 +4901,11 @@
 "准话" => 	"準話",
 "准头" => 	"準頭",
 "溟蒙" => 	"溟濛",
+"溢于" => 	"溢於",
 "溢于言表" => 	"溢於言表",
 "溲面" => 	"溲麵",
 "溶于" => 	"溶於",
+"溺于" => 	"溺於",
 "滃郁" => 	"滃鬱",
 "滑藉" => 	"滑藉",
 "汇丰" => 	"滙豐",
@@ -4612,6 +4928,7 @@
 "潜水钟" => 	"潛水鐘",
 "潭里" => 	"潭裡",
 "潮涌" => 	"潮湧",
+"溃于" => 	"潰於",
 "澄澹精致" => 	"澄澹精致",
 "澒蒙" => 	"澒濛",
 "泽渗漓而下降" => 	"澤滲灕而下降",
@@ -4621,7 +4938,6 @@
 "激荡" => 	"激蕩",
 "浓于" => 	"濃於",
 "浓发" => 	"濃髮",
-"湿地松" => 	"濕地鬆",
 "蒙汜" => 	"濛汜",
 "蒙蒙细雨" => 	"濛濛細雨",
 "蒙雾" => 	"濛霧",
@@ -4667,10 +4983,12 @@
 "无可救药" => 	"無可救藥",
 "无后" => 	"無後",
 "无损于" => 	"無損於",
+"无梁楼盖" => 	"無樑樓蓋",
 "无济于事" => 	"無濟於事",
 "无畏于" => 	"無畏於",
 "无补于事" => 	"無補於事",
 "无视于" => 	"無視於",
+"无余" => 	"無餘",
 "然后" => 	"然後",
 "然身死才数月耳" => 	"然身死纔數月耳",
 "炼药" => 	"煉藥",
@@ -4684,6 +5002,7 @@
 "照占" => 	"照佔",
 "照入签" => 	"照入籤",
 "照准" => 	"照準",
+"煨干" => 	"煨乾",
 "煮面" => 	"煮麵",
 "熔于" => 	"熔於",
 "熨斗" => 	"熨鬥",
@@ -4697,6 +5016,8 @@
 "燕游" => 	"燕遊",
 "烫发" => 	"燙髮",
 "烫面" => 	"燙麵",
+"营干" => 	"營幹",
+"烬余" => 	"燼餘",
 "争先恐后" => 	"爭先恐後",
 "争奇斗艳" => 	"爭奇鬥艷",
 "争奇斗豔" => 	"爭奇鬥豔",
@@ -4715,15 +5036,16 @@
 "特征" => 	"特徵",
 "特效药" => 	"特效藥",
 "特于" => 	"特於",
-"特里" => 	"特裡",
 "特制" => 	"特製",
 "牵一发" => 	"牽一髮",
 "牵系" => 	"牽繫",
 "荦确" => 	"犖确",
 "狂并潮" => 	"狂併潮",
+"狃于" => 	"狃於",
 "狃于成见" => 	"狃於成見",
 "狐藉虎威" => 	"狐藉虎威",
 "狼藉" => 	"狼藉",
+"猛于" => 	"猛於",
 "猛冲" => 	"猛衝",
 "猜三划五" => 	"猜三划五",
 "奖杯" => 	"獎盃",
@@ -4733,6 +5055,8 @@
 "献丑" => 	"獻醜",
 "率团参加" => 	"率團參加",
 "玉历" => 	"玉曆",
+"王庄" => 	"王莊",
+"王余鱼" => 	"王餘魚",
 "班里" => 	"班裡",
 "理发" => 	"理髮",
 "琴钟" => 	"琴鐘",
@@ -4753,12 +5077,17 @@
 "用药" => 	"用藥",
 "甩发" => 	"甩髮",
 "田谷" => 	"田穀",
+"田庄" => 	"田莊",
 "田里" => 	"田裡",
 "由于" => 	"由於",
 "男仆" => 	"男僕",
 "男用表" => 	"男用錶",
+"畏于" => 	"畏於",
 "留后" => 	"留後",
 "留发" => 	"留髮",
+"毕于" => 	"畢於",
+"毕业于" => 	"畢業於",
+"毕生发展" => 	"畢生發展",
 "划着" => 	"畫著",
 "异于" => 	"異於",
 "当一天和尚撞一天钟" => 	"當一天和尚撞一天鐘",
@@ -4769,6 +5098,7 @@
 "疏于" => 	"疏於",
 "疏松" => 	"疏鬆",
 "疑凶" => 	"疑兇",
+"疲于" => 	"疲於",
 "疲于奔命" => 	"疲於奔命",
 "疲困" => 	"疲睏",
 "病后" => 	"病後",
@@ -4797,10 +5127,10 @@
 "百拙千丑" => 	"百拙千醜",
 "百扎" => 	"百紮",
 "百花历" => 	"百花曆",
-"百里" => 	"百裡",
 "百只" => 	"百隻",
 "皇历" => 	"皇曆",
 "皇极历" => 	"皇極曆",
+"皇庄" => 	"皇莊",
 "皓发" => 	"皓髮",
 "皮里阳秋" => 	"皮裏陽秋",
 "皮里春秋" => 	"皮裡春秋",
@@ -4808,19 +5138,27 @@
 "皮松" => 	"皮鬆",
 "皱别" => 	"皺彆",
 "皱折" => 	"皺摺",
+"盈余" => 	"盈餘",
+"益于" => 	"益於",
 "盒里" => 	"盒裡",
 "盛德遗范" => 	"盛德遺範",
 "盛行于" => 	"盛行於",
+"盛赞" => 	"盛讚",
 "盗采" => 	"盜採",
 "盗钟" => 	"盜鐘",
 "监制" => 	"監製",
 "盘里" => 	"盤裡",
 "盘回" => 	"盤迴",
+"卢棱伽" => 	"盧稜伽",
+"盲干" => 	"盲幹",
 "直接参与" => 	"直接參与",
+"直于" => 	"直於",
 "直冲" => 	"直衝",
 "相并" => 	"相併",
 "相克" => 	"相剋",
 "相同于" => 	"相同於",
+"相干" => 	"相干",
+"相于" => 	"相於",
 "相冲" => 	"相衝",
 "相斗" => 	"相鬥",
 "看准" => 	"看準",
@@ -4850,6 +5188,7 @@
 "蒙头转" => 	"矇頭轉",
 "蒙骗" => 	"矇騙",
 "瞩讬" => 	"矚託",
+"短于" => 	"短於",
 "短发" => 	"短髮",
 "石棱棱" => 	"石稜稜",
 "石英表" => 	"石英錶",
@@ -4878,13 +5217,17 @@
 "祝发" => 	"祝髮",
 "神荼郁垒" => 	"神荼鬱壘",
 "神游" => 	"神遊",
+"神雕像" => 	"神雕像",
+"神雕" => 	"神鵰",
 "祭吊" => 	"祭弔",
 "禁欲" => 	"禁慾",
 "禁药" => 	"禁藥",
+"祸于" => 	"禍於",
 "御侮" => 	"禦侮",
 "御寇" => 	"禦寇",
 "御寒" => 	"禦寒",
 "御敌" => 	"禦敵",
+"礼赞" => 	"禮讚",
 "禾谷" => 	"禾穀",
 "秃妃之发" => 	"禿妃之髮",
 "秃发" => 	"禿髮",
@@ -4895,6 +5238,8 @@
 "秋天里" => 	"秋天裡",
 "秋后" => 	"秋後",
 "秋裤" => 	"秋褲",
+"秋游" => 	"秋遊",
+"秋阴入井干" => 	"秋陰入井幹",
 "秋发" => 	"秋髮",
 "种师中" => 	"种師中",
 "种师道" => 	"种師道",
@@ -4905,12 +5250,20 @@
 "稀松" => 	"稀鬆",
 "稍后" => 	"稍後",
 "棱台" => 	"稜台",
+"棱子" => 	"稜子",
+"棱层" => 	"稜層",
+"棱柱" => 	"稜柱",
+"棱棱" => 	"稜稜",
 "棱棱睁睁" => 	"稜稜睜睜",
+"棱等登" => 	"稜等登",
 "棱线" => 	"稜線",
+"棱缝" => 	"稜縫",
 "棱角" => 	"稜角",
 "棱锥" => 	"稜錐",
 "棱镜" => 	"稜鏡",
+"棱体" => 	"稜體",
 "种谷" => 	"種穀",
+"称赞" => 	"稱讚",
 "稻谷" => 	"稻穀",
 "稽征" => 	"稽徵",
 "谷仓" => 	"穀倉",
@@ -4942,16 +5295,20 @@
 "稳扎" => 	"穩紮",
 "空荡" => 	"空蕩",
 "空钟" => 	"空鐘",
+"空余" => 	"空餘",
 "窗帘" => 	"窗帘",
 "窗明几净" => 	"窗明几淨",
 "窗台" => 	"窗檯",
 "窝里" => 	"窩裡",
+"穷于" => 	"窮於",
 "穷追不舍" => 	"窮追不捨",
 "窃钟掩耳" => 	"竊鐘掩耳",
 "立于" => 	"立於",
 "立范" => 	"立範",
+"站干岸儿" => 	"站乾岸兒",
 "竟于" => 	"竟於",
 "童仆" => 	"童僕",
+"端庄" => 	"端莊",
 "竞斗" => 	"競鬥",
 "竹签" => 	"竹籤",
 "笆斗" => 	"笆鬥",
@@ -4971,11 +5328,14 @@
 "筑西" => 	"筑西",
 "筑邦" => 	"筑邦",
 "筑阳" => 	"筑陽",
+"答复" => 	"答覆",
 "策划" => 	"策劃",
 "筵几" => 	"筵几",
 "箕斗" => 	"箕鬥",
 "算发" => 	"算髮",
+"管干" => 	"管幹",
 "节欲" => 	"節慾",
+"节余" => 	"節餘",
 "范例" => 	"範例",
 "范围" => 	"範圍",
 "范式" => 	"範式",
@@ -5007,6 +5367,7 @@
 "精辟" => 	"精闢",
 "精松" => 	"精鬆",
 "糊里糊涂" => 	"糊裡糊塗",
+"糕干" => 	"糕乾",
 "粪秽蔑面" => 	"糞穢衊面",
 "团子" => 	"糰子",
 "系着" => 	"系著",
@@ -5015,6 +5376,7 @@
 "红发" => 	"紅髮",
 "红霉素" => 	"紅黴素",
 "纡回" => 	"紆迴",
+"纡余" => 	"紆餘",
 "纡郁" => 	"紆鬱",
 "纯朴" => 	"純樸",
 "纯硷" => 	"純鹼",
@@ -5044,11 +5406,14 @@
 "结伴同游" => 	"結伴同遊",
 "结伙" => 	"結夥",
 "结扎" => 	"結紮",
+"结余" => 	"結餘",
 "结发" => 	"結髮",
 "绝对参照" => 	"絕對參照",
 "绝后" => 	"絕後",
+"绝于" => 	"絕於",
 "绞干" => 	"絞乾",
 "络绎于途" => 	"絡繹於途",
+"给于" => 	"給於",
 "丝来线去" => 	"絲來線去",
 "丝布" => 	"絲布",
 "丝恩发怨" => 	"絲恩髮怨",
@@ -5063,6 +5428,7 @@
 "綑扎" => 	"綑紮",
 "绿发" => 	"綠髮",
 "绿霉素" => 	"綠黴素",
+"绸缎庄" => 	"綢緞莊",
 "维系" => 	"維繫",
 "绾发" => 	"綰髮",
 "网里" => 	"網裡",
@@ -5070,9 +5436,11 @@
 "紧绷" => 	"緊繃",
 "紧绷着" => 	"緊繃著",
 "紧追不舍" => 	"緊追不捨",
+"绪余" => 	"緒餘",
 "缉凶" => 	"緝兇",
 "编制" => 	"編製",
 "编钟" => 	"編鐘",
+"编余" => 	"編餘",
 "编发" => 	"編髮",
 "缓征" => 	"緩徵",
 "缓冲" => 	"緩衝",
@@ -5096,6 +5464,8 @@
 "绷着脸" => 	"繃著臉",
 "绷着脸儿" => 	"繃著臉兒",
 "绷开" => 	"繃開",
+"繐帏飘井干" => 	"繐幃飄井幹",
+"绕梁" => 	"繞樑",
 "绣得" => 	"繡得",
 "绣房" => 	"繡房",
 "绣毯" => 	"繡毯",
@@ -5126,29 +5496,38 @@
 "累臣" => 	"纍臣",
 "缠斗" => 	"纏鬥",
 "才则" => 	"纔則",
+"才可容颜十五余" => 	"纔可容顏十五餘",
 "才得两年" => 	"纔得兩年",
 "才此" => 	"纔此",
 "坛子" => 	"罈子",
 "坛坛罐罐" => 	"罈罈罐罐",
 "坛騞" => 	"罈騞",
+"置于" => 	"置於",
 "骂着" => 	"罵著",
 "美仑" => 	"美崙",
+"美于" => 	"美於",
 "美制" => 	"美製",
 "美丑" => 	"美醜",
 "美发" => 	"美髮",
 "羞于" => 	"羞於",
 "群丑" => 	"群醜",
+"羨余" => 	"羨餘",
 "义仆" => 	"義僕",
 "义形于色" => 	"義形於色",
+"义庄" => 	"義莊",
 "习于" => 	"習於",
 "翕辟" => 	"翕闢",
 "翱游" => 	"翱遊",
 "翻涌" => 	"翻湧",
 "翻云复雨" => 	"翻雲覆雨",
 "翻松" => 	"翻鬆",
+"老干" => 	"老乾",
 "老仆" => 	"老僕",
+"老干部" => 	"老幹部",
 "老蒙" => 	"老懞",
+"老于" => 	"老於",
 "老于世故" => 	"老於世故",
+"老庄" => 	"老莊",
 "老姜" => 	"老薑",
 "老板" => 	"老闆",
 "考后" => 	"考後",
@@ -5158,13 +5537,16 @@
 "耕佣" => 	"耕傭",
 "耕获" => 	"耕穫",
 "耳后" => 	"耳後",
+"耳余" => 	"耳餘",
 "耽于" => 	"耽於",
+"耿于" => 	"耿於",
 "耿耿于怀" => 	"耿耿於懷",
-"聊斋志异" => 	"聊齋誌異",
+"聊斋志异" => 	"聊齋志異",
 "联系" => 	"聯係",
 "联于" => 	"聯於",
 "联系" => 	"聯繫",
 "声如洪钟" => 	"聲如洪鐘",
+"听于" => 	"聽於",
 "肉干" => 	"肉乾",
 "肉欲" => 	"肉慾",
 "肉丝面" => 	"肉絲麵",
@@ -5185,12 +5567,14 @@
 "胡里胡涂" => 	"胡裡胡塗",
 "能干" => 	"能幹",
 "脉冲" => 	"脈衝",
+"脊梁" => 	"脊樑",
 "脱谷机" => 	"脫穀機",
 "脱发" => 	"脫髮",
 "腊味" => 	"腊味",
 "腊笔" => 	"腊筆",
 "腐干" => 	"腐乾",
 "脑子里" => 	"腦子裡",
+"脑干" => 	"腦幹",
 "脑后" => 	"腦後",
 "腰里" => 	"腰裡",
 "脚注" => 	"腳註",
@@ -5199,14 +5583,18 @@
 "臣服于" => 	"臣服於",
 "卧游" => 	"臥遊",
 "臧谷亡羊" => 	"臧穀亡羊",
+"自于" => 	"自於",
 "自制" => 	"自製",
 "自觉自愿" => 	"自覺自愿",
 "自鸣钟" => 	"自鳴鐘",
 "至于" => 	"至於",
 "致力于" => 	"致力於",
+"致于" => 	"致於",
+"臻于" => 	"臻於",
 "臻于完善" => 	"臻於完善",
 "舂谷" => 	"舂穀",
 "兴致" => 	"興緻",
+"举手表" => 	"舉手表",
 "旧庄" => 	"舊庄",
 "旧历" => 	"舊曆",
 "旧药" => 	"舊藥",
@@ -5221,7 +5609,6 @@
 "艸木丰丰" => 	"艸木丰丰",
 "芍药" => 	"芍藥",
 "芒果干" => 	"芒果乾",
-"芬郁" => 	"芬鬱",
 "花拳绣腿" => 	"花拳繡腿",
 "花卷" => 	"花捲",
 "花盆里" => 	"花盆裡",
@@ -5238,15 +5625,31 @@
 "苹萦" => 	"苹縈",
 "茵藉" => 	"茵藉",
 "茶几" => 	"茶几",
+"茶庄" => 	"茶莊",
+"茶余" => 	"茶餘",
 "茶面" => 	"茶麵",
 "草丛里" => 	"草叢裡",
 "草药" => 	"草藥",
 "荷花淀" => 	"荷花澱",
+"庄主" => 	"莊主",
+"庄周" => 	"莊周",
+"庄员" => 	"莊員",
+"庄严" => 	"莊嚴",
+"庄园" => 	"莊園",
+"庄子" => 	"莊子",
+"庄家" => 	"莊家",
+"庄户" => 	"莊戶",
+"庄敬" => 	"莊敬",
+"庄田" => 	"莊田",
+"庄稼" => 	"莊稼",
 "庄里" => 	"莊裡",
+"庄重" => 	"莊重",
+"庄院" => 	"莊院",
 "茎干" => 	"莖幹",
 "莽荡" => 	"莽蕩",
 "菌丝体" => 	"菌絲體",
 "菜干" => 	"菜乾",
+"菠棱菜" => 	"菠稜菜",
 "菠萝干" => 	"菠蘿乾",
 "华发" => 	"華髮",
 "菸硷" => 	"菸鹼",
@@ -5255,7 +5658,9 @@
 "万历" => 	"萬曆",
 "万签插架" => 	"萬籤插架",
 "万扎" => 	"萬紮",
+"万象" => 	"萬象",
 "万只" => 	"萬隻",
+"万余" => 	"萬餘",
 "落后" => 	"落後",
 "落于" => 	"落於",
 "落发" => 	"落髮",
@@ -5293,6 +5698,7 @@
 "荡荡" => 	"蕩蕩",
 "萧参" => 	"蕭蔘",
 "薄幸" => 	"薄倖",
+"薄干" => 	"薄幹",
 "姜是老的辣" => 	"薑是老的辣",
 "姜末" => 	"薑末",
 "姜桂" => 	"薑桂",
@@ -5323,6 +5729,7 @@
 "藉藉" => 	"藉藉",
 "藉资" => 	"藉資",
 "藏匿于" => 	"藏匿於",
+"藏于" => 	"藏於",
 "藏历" => 	"藏曆",
 "藏蒙歌儿" => 	"藏矇歌兒",
 "藤制" => 	"藤製",
@@ -5396,12 +5803,16 @@
 "处于" => 	"處於",
 "号志" => 	"號誌",
 "虫部" => 	"虫部",
+"蛇发女妖" => 	"蛇髮女妖",
 "蛔虫药" => 	"蛔蟲藥",
 "蜂涌" => 	"蜂湧",
+"蛏干" => 	"蟶乾",
 "蛮干" => 	"蠻幹",
+"血余" => 	"血餘",
 "行事历" => 	"行事曆",
 "行凶" => 	"行兇",
 "行凶后" => 	"行兇後",
+"行于" => 	"行於",
 "胡同" => 	"衚衕",
 "冲上" => 	"衝上",
 "冲下" => 	"衝下",
@@ -5451,15 +5862,16 @@
 "冲风" => 	"衝風",
 "表征" => 	"表徵",
 "表里" => 	"表裡",
+"衷于" => 	"衷於",
 "袖里" => 	"袖裡",
 "被里" => 	"被裡",
 "被复" => 	"被複",
 "被复着" => 	"被覆著",
-"被发" => 	"被髮",
 "裁并" => 	"裁併",
 "裁制" => 	"裁製",
 "里勾外连" => 	"裏勾外連",
 "里手" => 	"裏手",
+"里海" => 	"裏海",
 "里面" => 	"裏面",
 "补药" => 	"補藥",
 "补血药" => 	"補血藥",
@@ -5472,9 +5884,6 @@
 "里带" => 	"裡帶",
 "里弦" => 	"裡弦",
 "里应外合" => 	"裡應外合",
-"里拉" => 	"裡拉",
-"里斯" => 	"裡斯",
-"里海" => 	"裡海",
 "里脊" => 	"裡脊",
 "里衣" => 	"裡衣",
 "里通外国" => 	"裡通外國",
@@ -5511,6 +5920,7 @@
 "复以百万" => 	"複以百萬",
 "复位" => 	"複位",
 "复信" => 	"複信",
+"复元音" => 	"複元音",
 "复分数" => 	"複分數",
 "复分析" => 	"複分析",
 "复列" => 	"複列",
@@ -5527,6 +5937,7 @@
 "复字键" => 	"複字鍵",
 "复审" => 	"複審",
 "复写" => 	"複寫",
+"复平面" => 	"複平面",
 "复式" => 	"複式",
 "复复" => 	"複復",
 "复数" => 	"複數",
@@ -5537,7 +5948,7 @@
 "复次" => 	"複次",
 "复比" => 	"複比",
 "复决" => 	"複決",
-"复活" => 	"複活",
+"复流" => 	"複流",
 "复测" => 	"複測",
 "复亩珍" => 	"複畝珍",
 "复发" => 	"複發",
@@ -5557,6 +5968,7 @@
 "复议" => 	"複議",
 "复变函数" => 	"複變函數",
 "复赛" => 	"複賽",
+"复辅音" => 	"複輔音",
 "复述" => 	"複述",
 "复选" => 	"複選",
 "复钱" => 	"複錢",
@@ -5567,6 +5979,7 @@
 "衬里" => 	"襯裡",
 "西岳" => 	"西嶽",
 "西历" => 	"西曆",
+"西历史" => 	"西歷史",
 "西药" => 	"西藥",
 "西游" => 	"西遊",
 "要冲" => 	"要衝",
@@ -5587,8 +6000,11 @@
 "见钟不打" => 	"見鐘不打",
 "规划" => 	"規劃",
 "规范" => 	"規範",
+"视于" => 	"視於",
 "观采" => 	"觀採",
+"角落发" => 	"角落發",
 "角落里" => 	"角落裡",
+"觚棱" => 	"觚稜",
 "解雇" => 	"解僱",
 "解痛药" => 	"解痛藥",
 "解药" => 	"解藥",
@@ -5640,12 +6056,17 @@
 "注释" => 	"註釋",
 "注销" => 	"註銷",
 "评注" => 	"評註",
+"词干" => 	"詞幹",
 "词汇" => 	"詞彙",
+"词余" => 	"詞餘",
+"询于" => 	"詢於",
 "诗云" => 	"詩云",
 "诗钟" => 	"詩鐘",
+"诗余" => 	"詩餘",
 "话里有话" => 	"話裡有話",
 "该于" => 	"該於",
 "详注" => 	"詳註",
+"夸赞" => 	"誇讚",
 "志哀" => 	"誌哀",
 "志喜" => 	"誌喜",
 "志庆" => 	"誌慶",
@@ -5659,10 +6080,13 @@
 "说着" => 	"說著",
 "课后" => 	"課後",
 "课征" => 	"課徵",
+"课余" => 	"課餘",
 "调准" => 	"調準",
 "调制" => 	"調製",
 "请参阅" => 	"請參閱",
 "请讬" => 	"請託",
+"诸余" => 	"諸餘",
+"谋干" => 	"謀幹",
 "谢绝参观" => 	"謝絕參觀",
 "谬采虚声" => 	"謬採虛聲",
 "謷丑" => 	"謷醜",
@@ -5674,9 +6098,25 @@
 "读后" => 	"讀後",
 "变丑" => 	"變醜",
 "雠隙" => 	"讎隙",
+"赞不绝口" => 	"讚不絕口",
+"赞佩" => 	"讚佩",
+"赞同" => 	"讚同",
+"赞叹" => 	"讚嘆",
+"赞扬" => 	"讚揚",
+"赞乐" => 	"讚樂",
+"赞歌" => 	"讚歌",
+"赞歎" => 	"讚歎",
+"赞美" => 	"讚美",
+"赞羨" => 	"讚羨",
+"赞许" => 	"讚許",
+"赞词" => 	"讚詞",
+"赞誉" => 	"讚譽",
+"赞赏" => 	"讚賞",
+"赞辞" => 	"讚辭",
+"赞颂" => 	"讚頌",
+"豆干" => 	"豆乾",
 "豆腐干" => 	"豆腐乾",
 "竖着" => 	"豎著",
-"丰富多采" => 	"豐富多採",
 "丰滨" => 	"豐濱",
 "丰滨乡" => 	"豐濱鄉",
 "象征" => 	"象徵",
@@ -5691,26 +6131,30 @@
 "质朴" => 	"質樸",
 "赌台" => 	"賭檯",
 "赖于" => 	"賴於",
+"賸余" => 	"賸餘",
 "购并" => 	"購併",
 "购买欲" => 	"購買慾",
-"赤松" => 	"赤鬆",
+"赢余" => 	"贏餘",
 "走后" => 	"走後",
 "起因于" => 	"起因於",
 "起复" => 	"起複",
 "起哄" => 	"起鬨",
 "赶制" => 	"趕製",
 "赶面棍" => 	"趕麵棍",
+"赵庄" => 	"趙莊",
 "趋于" => 	"趨於",
+"趱干" => 	"趲幹",
+"足于" => 	"足於",
 "跌荡" => 	"跌蕩",
 "跟前跟后" => 	"跟前跟後",
 "路签" => 	"路籤",
-"跳樑小丑" => 	"跳樑小醜",
-"跳樑猖獗之小丑" => 	"跳樑猖獗之小醜",
 "跳荡" => 	"跳蕩",
 "跳表" => 	"跳錶",
+"蹭棱子" => 	"蹭稜子",
 "躁郁" => 	"躁鬱",
 "躏藉" => 	"躪藉",
 "身后" => 	"身後",
+"身于" => 	"身於",
 "躯干" => 	"軀幹",
 "车库里" => 	"車庫裡",
 "车站里" => 	"車站裡",
@@ -5729,13 +6173,13 @@
 "轮回" => 	"輪迴",
 "转台" => 	"轉檯",
 "转讬" => 	"轉託",
-"辛丑" => 	"辛醜",
 "辟谷" => 	"辟穀",
 "办公台" => 	"辦公檯",
 "辞汇" => 	"辭彙",
 "辫发" => 	"辮髮",
 "农历" => 	"農曆",
 "农民历" => 	"農民曆",
+"农庄" => 	"農莊",
 "农药" => 	"農藥",
 "迂回" => 	"迂迴",
 "近似于" => 	"近似於",
@@ -5766,6 +6210,7 @@
 "回响" => 	"迴響",
 "回风" => 	"迴風",
 "迷幻药" => 	"迷幻藥",
+"迷于" => 	"迷於",
 "迷蒙" => 	"迷濛",
 "迷药" => 	"迷藥",
 "迷魂药" => 	"迷魂藥",
@@ -5782,6 +6227,7 @@
 "这么着" => 	"這麼著",
 "通奸" => 	"通姦",
 "通心面" => 	"通心麵",
+"通于" => 	"通於",
 "通历" => 	"通曆",
 "速食面" => 	"速食麵",
 "连三并四" => 	"連三併四",
@@ -5789,6 +6235,7 @@
 "连采" => 	"連採",
 "连于" => 	"連於",
 "连系" => 	"連繫",
+"连庄" => 	"連莊",
 "周游" => 	"週遊",
 "进占" => 	"進佔",
 "逼并" => 	"逼併",
@@ -5807,7 +6254,7 @@
 "游憩" => 	"遊憩",
 "游戏" => 	"遊戲",
 "游手好闲" => 	"遊手好閑",
-"游手好閒" => 	"遊手好閒",
+"游手好闲" => 	"遊手好閒",
 "游星" => 	"遊星",
 "游乐" => 	"遊樂",
 "游标卡尺" => 	"遊標卡尺",
@@ -5841,6 +6288,7 @@
 "过于" => 	"過於",
 "过水面" => 	"過水麵",
 "道范" => 	"道範",
+"逊于" => 	"遜於",
 "递回" => 	"遞迴",
 "远于" => 	"遠於",
 "远县才至" => 	"遠縣纔至",
@@ -5849,7 +6297,9 @@
 "适于" => 	"適於",
 "遮丑" => 	"遮醜",
 "迁怒于" => 	"遷怒於",
+"迁于" => 	"遷於",
 "遗范" => 	"遺範",
+"遗余" => 	"遺餘",
 "辽沈" => 	"遼瀋",
 "避孕药" => 	"避孕藥",
 "还占" => 	"還佔",
@@ -5865,11 +6315,12 @@
 "郁朴" => 	"郁樸",
 "郊游" => 	"郊遊",
 "郘钟" => 	"郘鐘",
+"部落发" => 	"部落發",
+"都于" => 	"都於",
 "乡愿" => 	"鄉愿",
-"乡里" => 	"鄉裡",
 "郑凯云" => 	"鄭凱云",
-"邻里" => 	"鄰裡",
 "配合着" => 	"配合著",
+"配水干管" => 	"配水幹管",
 "配药" => 	"配藥",
 "配制" => 	"配製",
 "酒后" => 	"酒後",
@@ -5881,6 +6332,7 @@
 "酸硷" => 	"酸鹼",
 "醇朴" => 	"醇樸",
 "醉心于" => 	"醉心於",
+"醉于" => 	"醉於",
 "醋坛" => 	"醋罈",
 "丑丫头" => 	"醜丫頭",
 "丑事" => 	"醜事",
@@ -5900,6 +6352,7 @@
 "丑巴怪" => 	"醜巴怪",
 "丑恶" => 	"醜惡",
 "丑态" => 	"醜態",
+"丑于" => 	"醜於",
 "丑末" => 	"醜末",
 "丑样" => 	"醜樣",
 "丑死" => 	"醜死",
@@ -5921,6 +6374,9 @@
 "医药" => 	"醫藥",
 "酿制" => 	"釀製",
 "衅钟" => 	"釁鐘",
+"采石之役" => 	"采石之役",
+"采石之战" => 	"采石之戰",
+"采石矶" => 	"采石磯",
 "釉药" => 	"釉藥",
 "里程表" => 	"里程錶",
 "重划" => 	"重劃",
@@ -5933,6 +6389,11 @@
 "重锤" => 	"重鎚",
 "野姜" => 	"野薑",
 "野游" => 	"野遊",
+"厘出" => 	"釐出",
+"厘定" => 	"釐定",
+"厘正" => 	"釐正",
+"厘清" => 	"釐清",
+"厘订" => 	"釐訂",
 "金仆姑" => 	"金僕姑",
 "金仑溪" => 	"金崙溪",
 "金表" => 	"金錶",
@@ -5949,10 +6410,12 @@
 "铜制" => 	"銅製",
 "铜钟" => 	"銅鐘",
 "铝制" => 	"鋁製",
+"钢梁" => 	"鋼樑",
 "钢制" => 	"鋼製",
 "录着" => 	"錄著",
 "录制" => 	"錄製",
 "钱谷" => 	"錢穀",
+"钱庄" => 	"錢莊",
 "锦心绣口" => 	"錦心繡口",
 "锦绣花园" => 	"錦綉花園",
 "锦绣" => 	"錦繡",
@@ -5965,7 +6428,6 @@
 "表蒙子" => 	"錶蒙子",
 "表针" => 	"錶針",
 "表链" => 	"錶鏈",
-"表面" => 	"錶面",
 "锻鍊出" => 	"鍛鍊出",
 "锲而不舍" => 	"鍥而不捨",
 "钟表" => 	"鍾錶",
@@ -6021,9 +6483,9 @@
 "开药" => 	"開藥",
 "开辟" => 	"開闢",
 "开哄" => 	"開鬨",
-"閒情逸致" => 	"閒情逸緻",
-"閒荡" => 	"閒蕩",
-"閒游" => 	"閒遊",
+"闲情逸致" => 	"閒情逸緻",
+"闲荡" => 	"閒蕩",
+"闲游" => 	"閒遊",
 "间不容发" => 	"間不容髮",
 "闵采尔" => 	"閔採爾",
 "合府" => 	"閤府",
@@ -6045,14 +6507,13 @@
 "辟筑" => 	"闢築",
 "辟谣" => 	"闢謠",
 "辟辟" => 	"闢辟",
-"辟邪" => 	"闢邪",
 "辟邪以律" => 	"闢邪以律",
-"坂田" => 	"阪田",
 "防御" => 	"防禦",
 "防范" => 	"防範",
 "防锈" => 	"防鏽",
 "防台" => 	"防颱",
-"阿里" => 	"阿裡",
+"阻于" => 	"阻於",
+"附于" => 	"附於",
 "附注" => 	"附註",
 "降压药" => 	"降壓藥",
 "降于" => 	"降於",
@@ -6067,7 +6528,9 @@
 "阳春面" => 	"陽春麵",
 "阳历" => 	"陽曆",
 "随后" => 	"隨後",
+"随于" => 	"隨於",
 "隐几" => 	"隱几",
+"隐于" => 	"隱於",
 "只字" => 	"隻字",
 "只影" => 	"隻影",
 "只手遮天" => 	"隻手遮天",
@@ -6076,10 +6539,12 @@
 "只身" => 	"隻身",
 "雅范" => 	"雅範",
 "雅致" => 	"雅緻",
+"集于" => 	"集於",
 "集于一身" => 	"集於一身",
 "集游法" => 	"集遊法",
 "雇佣" => 	"雇傭",
 "雇于" => 	"雇於",
+"雕梁划栋" => 	"雕樑畫棟",
 "双折" => 	"雙摺",
 "双胜类" => 	"雙胜類",
 "杂合面儿" => 	"雜合麵兒",
@@ -6090,6 +6555,7 @@
 "鸡丝面" => 	"雞絲麵",
 "鸡腿面" => 	"雞腿麵",
 "鸡只" => 	"雞隻",
+"离于" => 	"離於",
 "难容于" => 	"難容於",
 "难舍" => 	"難捨",
 "难于" => 	"難於",
@@ -6133,6 +6599,8 @@
 "音准" => 	"音準",
 "音声如钟" => 	"音聲如鐘",
 "韶山冲" => 	"韶山衝",
+"顺于" => 	"順於",
+"颂赞" => 	"頌讚",
 "预制" => 	"預製",
 "领袖欲" => 	"領袖慾",
 "头里" => 	"頭裡",
@@ -6140,6 +6608,7 @@
 "颊须" => 	"頰鬚",
 "额我略历" => 	"額我略曆",
 "颜范" => 	"顏範",
+"颠干倒坤" => 	"顛乾倒坤",
 "颠复" => 	"顛覆",
 "类似于" => 	"類似於",
 "顾藉" => 	"顧藉",
@@ -6172,8 +6641,99 @@
 "饭后" => 	"飯後",
 "饭后钟" => 	"飯後鐘",
 "饭团" => 	"飯糰",
+"饭庄" => 	"飯莊",
 "饲喂" => 	"飼餵",
 "饼干" => 	"餅乾",
+"馂余" => 	"餕餘",
+"余下" => 	"餘下",
+"余事" => 	"餘事",
+"余人" => 	"餘人",
+"余值" => 	"餘值",
+"余僇" => 	"餘僇",
+"余光" => 	"餘光",
+"余函数" => 	"餘函數",
+"余刃" => 	"餘刃",
+"余切" => 	"餘切",
+"余利" => 	"餘利",
+"余剩" => 	"餘剩",
+"余割" => 	"餘割",
+"余力" => 	"餘力",
+"余勇" => 	"餘勇",
+"余味" => 	"餘味",
+"余喘" => 	"餘喘",
+"余地" => 	"餘地",
+"余址" => 	"餘址",
+"余墨" => 	"餘墨",
+"余外" => 	"餘外",
+"余妙" => 	"餘妙",
+"余姚" => 	"餘姚",
+"余威" => 	"餘威",
+"余存" => 	"餘存",
+"余孽" => 	"餘孽",
+"余巾" => 	"餘巾",
+"余式定理" => 	"餘式定理",
+"余弦" => 	"餘弦",
+"余思" => 	"餘思",
+"余悸" => 	"餘悸",
+"余庆" => 	"餘慶",
+"余数" => 	"餘數",
+"余日" => 	"餘日",
+"余明" => 	"餘明",
+"余映" => 	"餘映",
+"余暇" => 	"餘暇",
+"余晖" => 	"餘暉",
+"余杭" => 	"餘杭",
+"余杯" => 	"餘杯",
+"余桃" => 	"餘桃",
+"余桶" => 	"餘桶",
+"余业" => 	"餘業",
+"余款" => 	"餘款",
+"余步" => 	"餘步",
+"余殃" => 	"餘殃",
+"余毒" => 	"餘毒",
+"余气" => 	"餘氣",
+"余氯" => 	"餘氯",
+"余波" => 	"餘波",
+"余温" => 	"餘溫",
+"余泽" => 	"餘澤",
+"余沥" => 	"餘瀝",
+"余烈" => 	"餘烈",
+"余热" => 	"餘熱",
+"余烬" => 	"餘燼",
+"余珍" => 	"餘珍",
+"余生" => 	"餘生",
+"余留" => 	"餘留",
+"余众" => 	"餘眾",
+"余窍" => 	"餘竅",
+"余粮" => 	"餘糧",
+"余绪" => 	"餘緒",
+"余缺" => 	"餘缺",
+"余罪" => 	"餘罪",
+"余羨" => 	"餘羨",
+"余声" => 	"餘聲",
+"余膏" => 	"餘膏",
+"余兴" => 	"餘興",
+"余蓄" => 	"餘蓄",
+"余荫" => 	"餘蔭",
+"余裕" => 	"餘裕",
+"余角" => 	"餘角",
+"余论" => 	"餘論",
+"余责" => 	"餘責",
+"余辉" => 	"餘輝",
+"余辜" => 	"餘辜",
+"余酲" => 	"餘酲",
+"余钱" => 	"餘錢",
+"余闰" => 	"餘閏",
+"余闲" => 	"餘閒",
+"余震" => 	"餘震",
+"余音" => 	"餘音",
+"余韵" => 	"餘韻",
+"余响" => 	"餘響",
+"余额" => 	"餘額",
+"余风" => 	"餘風",
+"余食" => 	"餘食",
+"余香" => 	"餘香",
+"余党" => 	"餘黨",
 "馄饨面" => 	"餛飩麵",
 "馆谷" => 	"館穀",
 "喂乳" => 	"餵乳",
@@ -6198,14 +6758,15 @@
 "饥饱" => 	"饑飽",
 "饥馑" => 	"饑饉",
 "首当其冲" => 	"首當其衝",
-"馥郁" => 	"馥鬱",
+"香干" => 	"香乾",
+"马干" => 	"馬乾",
 "马后" => 	"馬後",
-"马里" => 	"馬裡",
 "马表" => 	"馬錶",
 "驻扎" => 	"駐紮",
 "骀荡" => 	"駘蕩",
 "骀藉" => 	"駘藉",
 "腾冲" => 	"騰衝",
+"惊赞" => 	"驚讚",
 "骨子里" => 	"骨子裡",
 "骨干" => 	"骨幹",
 "骨灰坛" => 	"骨灰罈",
@@ -6253,7 +6814,6 @@
 "发癣" => 	"髮癬",
 "发短心长" => 	"髮短心長",
 "发禁" => 	"髮禁",
-"发端" => 	"髮端",
 "发笺" => 	"髮箋",
 "发纱" => 	"髮紗",
 "发结" => 	"髮結",
@@ -6289,13 +6849,9 @@
 "松懈" => 	"鬆懈",
 "松手" => 	"鬆手",
 "松散" => 	"鬆散",
-"松林" => 	"鬆林",
 "松柔" => 	"鬆柔",
-"松毛虫" => 	"鬆毛蟲",
 "松气" => 	"鬆氣",
 "松浮" => 	"鬆浮",
-"松涛" => 	"鬆濤",
-"松节油" => 	"鬆節油",
 "松绑" => 	"鬆綁",
 "松紧" => 	"鬆緊",
 "松缓" => 	"鬆緩",
@@ -6401,13 +6957,16 @@
 "郁郁葱葱" => 	"鬱鬱蔥蔥",
 "郁黑" => 	"鬱黑",
 "魏征" => 	"魏徵",
+"鱼干" => 	"魚乾",
 "鱼松" => 	"魚鬆",
 "鲸须" => 	"鯨鬚",
+"鲇鱼" => 	"鯰魚",
 "鸠占鹊巢" => 	"鳩佔鵲巢",
 "凤梨干" => 	"鳳梨乾",
 "鸣钟" => 	"鳴鐘",
 "鸿范" => 	"鴻範",
 "鹄发" => 	"鵠髮",
+"雕悍" => 	"鵰悍",
 "鹤发" => 	"鶴髮",
 "咸味" => 	"鹹味",
 "咸嘴淡舌" => 	"鹹嘴淡舌",
@@ -6434,8 +6993,24 @@
 "咸鸭蛋" => 	"鹹鴨蛋",
 "咸卤" => 	"鹹鹵",
 "咸咸" => 	"鹹鹹",
+"硷化" => 	"鹼化",
+"硷土金属" => 	"鹼土金屬",
+"硷地" => 	"鹼地",
+"硷度" => 	"鹼度",
+"硷性" => 	"鹼性",
+"硷水" => 	"鹼水",
+"硷液" => 	"鹼液",
+"硷熔" => 	"鹼熔",
+"硷石灰" => 	"鹼石灰",
+"硷纤维素" => 	"鹼纖維素",
+"硷金属" => 	"鹼金屬",
+"硷类" => 	"鹼類",
 "盐打怎么咸" => 	"鹽打怎麼鹹",
 "盐卤" => 	"鹽滷",
+"盐余" => 	"鹽餘",
+"盐硷土" => 	"鹽鹼土",
+"盐硷滩" => 	"鹽鹼灘",
+"丽于" => 	"麗於",
 "麴霉" => 	"麴黴",
 "面人儿" => 	"麵人兒",
 "面价" => 	"麵價",
@@ -6468,12 +7043,13 @@
 "麻醉药" => 	"麻醉藥",
 "麻酱面" => 	"麻醬麵",
 "麻雀在后" => 	"麻雀在後",
+"黄干黑廋" => 	"黃乾黑廋",
 "黄历" => 	"黃曆",
 "黄钟" => 	"黃鐘",
 "黄雀在后" => 	"黃雀在後",
 "黄发垂髫" => 	"黃髮垂髫",
+"黑奴吁天录" => 	"黑奴籲天錄",
 "黑发" => 	"黑髮",
-"黑松" => 	"黑鬆",
 "点钟" => 	"點鐘",
 "霉毒" => 	"黴毒",
 "霉菌" => 	"黴菌",
@@ -6482,6 +7058,7 @@
 "鼓里" => 	"鼓裡",
 "冬冬" => 	"鼕鼕",
 "鼠药" => 	"鼠藥",
+"鼻梁" => 	"鼻樑",
 "鼻准" => 	"鼻準",
 "齐王舍牛" => 	"齊王捨牛",
 "齿危发秀" => 	"齒危髮秀",
@@ -6496,11 +7073,6 @@
 "龙虎斗" => 	"龍虎鬥",
 "龙须" => 	"龍鬚",
 "龟山庄" => 	"龜山庄",
-"多余" => "多餘",
-"剩余" => "剩餘",
-"余生" => "餘生",
-"余年" => "餘年",
-"有余" => "有餘",
 "手塚治虫" => "手塚治虫",
 "校仇" => "校讎",
 "仇校" => "讎校",
@@ -6521,14 +7093,36 @@
 "鄭凱云" => "鄭凱云",
 "筑陽" => "筑陽",
 "筑後" => "筑後",
+"采石磯" => "采石磯",
+"采石之戰" => "采石之戰",
+"張三丰" => "張三丰",
+"丰韻" => "丰韻",
+"丰儀" => "丰儀",
+"丰標不凡" => "丰標不凡",
+"干細胞" => "幹細胞",
+"干熱" => "乾熱",
+"二里頭" => "二里頭",
+"水里鄉" => "水里鄉",
+"蒙胧" => "朦朧",
+"酒曲" => "酒麴",
+"呆里呆气" => "呆裡呆氣",
+"拜托" => "拜託",
+"委托书" => "委託書",
+"委托" => "委託",
+"挽詞" => "輓詞",
+"挽聯" => "輓聯",
+"挽詩" => "輓詩",
+"於夫罗" => "於夫羅",
+"府干預" => "府干預",
+"府干擾" => "府干擾",
 );
 
 $zh2Hans = array(
+"餘"=>"余",
 "瀋"=>"沈",
 "畫"=>"划",
 "鍾"=>"钟",
 "靦"=>"腼",
-"餘"=>"余",
 "鯰"=>"鲇",
 "鹼"=>"硷",
 "㠏"=>"㟆",
@@ -6548,7 +7142,6 @@
 "佈"=>"布",
 "体"=>"体",
 "佔"=>"占",
-"余"=>"馀",
 "併"=>"并",
 "來"=>"来",
 "侖"=>"仑",
@@ -6679,7 +7272,6 @@
 "吳"=>"吴",
 "吶"=>"呐",
 "呂"=>"吕",
-"呆"=>"獃",
 "咼"=>"呙",
 "員"=>"员",
 "唄"=>"呗",
@@ -7012,6 +7604,7 @@
 "戶"=>"户",
 "担"=>"担",
 "拋"=>"抛",
+"拚"=>"拼",
 "挩"=>"捝",
 "挾"=>"挟",
 "捨"=>"舍",
@@ -7159,6 +7752,7 @@
 "樁"=>"桩",
 "樂"=>"乐",
 "樅"=>"枞",
+"樑"=>"梁",
 "樓"=>"楼",
 "標"=>"标",
 "樞"=>"枢",
@@ -7201,6 +7795,7 @@
 "櫸"=>"榉",
 "櫻"=>"樱",
 "欄"=>"栏",
+"欅"=>"榉",
 "權"=>"权",
 "欏"=>"椤",
 "欒"=>"栾",
@@ -7378,6 +7973,7 @@
 "燜"=>"焖",
 "營"=>"营",
 "燦"=>"灿",
+"燬"=>"毁",
 "燭"=>"烛",
 "燴"=>"烩",
 "燶"=>"㶶",
@@ -7887,7 +8483,6 @@
 "萵"=>"莴",
 "葉"=>"叶",
 "葒"=>"荭",
-"著"=>"着",
 "葤"=>"荮",
 "葦"=>"苇",
 "葯"=>"药",
@@ -8199,6 +8794,7 @@
 "譚"=>"谭",
 "譜"=>"谱",
 "譫"=>"谵",
+"譭"=>"毁",
 "譯"=>"译",
 "議"=>"议",
 "譴"=>"谴",
@@ -8214,6 +8810,7 @@
 "讓"=>"让",
 "讕"=>"谰",
 "讖"=>"谶",
+"讚"=>"赞",
 "讜"=>"谠",
 "讞"=>"谳",
 "豈"=>"岂",
@@ -8714,6 +9311,7 @@
 "閎"=>"闳",
 "閏"=>"闰",
 "閑"=>"闲",
+"閒"=>"闲",
 "間"=>"间",
 "閔"=>"闵",
 "閘"=>"闸",
@@ -9170,6 +9768,7 @@
 "鵬"=>"鹏",
 "鵮"=>"鹐",
 "鵯"=>"鹎",
+"鵰"=>"雕",
 "鵲"=>"鹊",
 "鵷"=>"鹓",
 "鵾"=>"鹍",
@@ -9280,80 +9879,405 @@
 "龕"=>"龛",
 "龜"=>"龟",
 
-"乾坤 " => 	"乾坤 ",
-"乾隆" => 	"乾隆",
-"旋乾轉坤" => 	"旋乾转坤",
-"名著" => 	"名著",
-"土著" => 	"土著",
-"編著" => 	"编著",
-"合著" => 	"合著",
-"論著" => 	"论著",
-"巨著" => 	"巨著",
-"鉅著" => 	"钜著",
-"昭著" => 	"昭著",
-"專著" => 	"专著",
-"撰著" => 	"撰著",
-"原著" => 	"原著",
-"卓著" => 	"卓著",
-"拙著" => 	"拙著",
-"譯著" => 	"译著",
-"遺著" => 	"遗著",
-"著作" => 	"著作",
-"著名" => 	"著名",
-"著錄" => 	"著录",
-"著稱" => 	"著称",
-"著述" => 	"著述",
-"著書" => 	"著书",
-"於乎" => 	"於乎",
-"於戲" => 	"於戏",
-"魏徵" => 	"魏徵",
-"柳詒徵" => 	"柳诒徵",
-"於姓" => 	"於姓",
-"於氏" => 	"於氏",
-"於夫羅" => 	"於夫罗",
-"於梨華" => 	"於梨华",
-"卷舌" => 	"卷舌",
 "一畫" => 	"一画",
+"一著不慎" => 	"一着不慎",
+"三聯畫" => 	"三联画",
 "上畫" => 	"上画",
+"不著" => 	"不着",
+"不著痕跡" => 	"不着痕迹",
+"不著邊際" => 	"不着边际",
+"與著" => 	"与着",
+"與著作" => 	"与著作",
+"與著名" => 	"与著名",
+"與著者" => 	"与著者",
+"丑著" => 	"丑着",
+"臨著" => 	"临着",
+"為著" => 	"为着",
+"麗著" => 	"丽着",
+"舉著" => 	"举着",
+"樂著" => 	"乐着",
+"樂著作" => 	"乐著作",
+"乘著" => 	"乘着",
 "書畫" => 	"书画",
+"乾乾" => 	"乾乾",
+"乾元;" => 	"乾元;",
+"乾卦;" => 	"乾卦;",
+"乾縣" => 	"乾县",
+"乾嘉" => 	"乾嘉",
+"乾圖" => 	"乾图",
+"乾坤 " => 	"乾坤 ",
+"乾宅;" => 	"乾宅;",
+"乾斷" => 	"乾断",
+"乾旦" => 	"乾旦",
+"乾曜;" => 	"乾曜;",
+"乾清宮" => 	"乾清宫",
+"乾盛世" => 	"乾盛世",
+"乾紅" => 	"乾红",
+"乾綱" => 	"乾纲",
+"乾象;" => 	"乾象;",
+"乾造;" => 	"乾造;",
+"乾陵" => 	"乾陵",
+"乾隆" => 	"乾隆",
+"爭著" => 	"争着",
+"交叉著" => 	"交叉着",
+"亮著" => 	"亮着",
+"仗著" => 	"仗着",
+"代表著" => 	"代表着",
+"代表著作" => 	"代表著作",
+"代表著名" => 	"代表著名",
+"代表著者" => 	"代表著者",
+"仰著" => 	"仰着",
+"傷著" => 	"伤着",
+"伴著" => 	"伴着",
+"低著" => 	"低着",
+"住著" => 	"住着",
+"佛頭著糞" => 	"佛头着粪",
 "作畫" => 	"作画",
+"側著" => 	"侧着",
+"保障著" => 	"保障着",
+"保障著作" => 	"保障著作",
+"保障著名" => 	"保障著名",
+"保障著者" => 	"保障著者",
+"信著" => 	"信着",
+"候著" => 	"候着",
+"借著" => 	"借着",
+"偎著" => 	"偎着",
+"做著" => 	"做着",
+"停著" => 	"停着",
+"偷著" => 	"偷着",
+"先人著鞭" => 	"先人着鞭",
+"先我著鞭" => 	"先我着鞭",
+"光著" => 	"光着",
+"光著作" => 	"光著作",
 "入畫" => 	"入画",
+"關著" => 	"关着",
+"關著作" => 	"关著作",
+"關著名" => 	"关著名",
+"關著者" => 	"关著者",
+"冀著" => 	"冀着",
+"冒著" => 	"冒着",
+"寫生畫" => 	"写生画",
+"寫著" => 	"写着",
+"寫著作" => 	"写著作",
+"寫著名" => 	"写著名",
+"沖著" => 	"冲着",
+"涼著" => 	"凉着",
 "幾畫" => 	"几画",
+"憑著" => 	"凭着",
+"制著" => 	"制着",
 "刻畫" => 	"刻画",
+"刻著" => 	"刻着",
+"剃著" => 	"剃着",
+"剪著" => 	"剪着",
+"辦著" => 	"办着",
 "動畫" => 	"动画",
+"動著" => 	"动着",
+"努力著" => 	"努力着",
+"努著" => 	"努着",
 "勾畫" => 	"勾画",
+"包著" => 	"包着",
+"單色畫" => 	"单色画",
 "賣畫" => 	"卖画",
+"卡通畫" => 	"卡通画",
 "鹵鹼" => 	"卤碱",
+"印著" => 	"印着",
+"卷舌" => 	"卷舌",
+"壓著" => 	"压着",
 "原畫" => 	"原画",
+"去著" => 	"去着",
+"受著" => 	"受着",
+"受著作" => 	"受著作",
+"受著名" => 	"受著名",
+"受著者" => 	"受著者",
+"變著" => 	"变着",
 "口鹼" => 	"口碱",
 "古畫" => 	"古画",
+"叫喊著說" => 	"叫喊着说",
+"叫著" => 	"叫着",
+"吃著" => 	"吃着",
 "名畫" => 	"名画",
+"向著" => 	"向着",
+"嚇著" => 	"吓着",
+"含著" => 	"含着",
+"含著作" => 	"含著作",
+"含著名" => 	"含著名",
+"含著者" => 	"含著者",
+"聽著" => 	"听着",
+"聽著作" => 	"听著作",
+"聽著名" => 	"听著名",
+"聽著者" => 	"听著者",
+"吸著劑" => 	"吸着剂",
+"吸著物" => 	"吸着物",
+"吹著" => 	"吹着",
+"呆著" => 	"呆着",
+"嗆著" => 	"呛着",
+"味著" => 	"味着",
+"咧著" => 	"咧着",
+"咬著" => 	"咬着",
+"響著" => 	"响着",
+"哭喪著臉" => 	"哭丧着脸",
+"哭著" => 	"哭着",
+"哼著唱" => 	"哼着唱",
+"唱著" => 	"唱着",
+"啃著" => 	"啃着",
+"喝著" => 	"喝着",
+"噙著" => 	"噙着",
+"嚷著" => 	"嚷着",
+"囔著" => 	"囔着",
+"因著" => 	"因着",
+"困著" => 	"困着",
+"圍著" => 	"围着",
+"固著" => 	"固着",
 "國畫" => 	"国画",
 "圖畫" => 	"图画",
+"在著" => 	"在着",
+"在著作" => 	"在著作",
+"在著名" => 	"在著名",
+"在著者" => 	"在著者",
+"坐著" => 	"坐着",
+"墊著" => 	"垫着",
+"埋著" => 	"埋着",
 "壁畫" => 	"壁画",
+"備著" => 	"备着",
+"失著" => 	"失着",
+"夾著" => 	"夹着",
 "奇畫" => 	"奇画",
 "如畫" => 	"如画",
 "字畫" => 	"字画",
+"孤著" => 	"孤着",
+"學著" => 	"学着",
+"學著作" => 	"学著作",
+"守著" => 	"守着",
+"定著" => 	"定着",
+"定著作" => 	"定著作",
+"宣傳畫" => 	"宣传画",
+"對著" => 	"对着",
+"對著干" => 	"对着干",
+"對著作" => 	"对著作",
+"對著名" => 	"对著名",
+"對著者" => 	"对著者",
+"尋著" => 	"寻着",
+"就著" => 	"就着",
+"展著" => 	"展着",
+"帶著" => 	"带着",
+"幫著" => 	"帮着",
 "年畫" => 	"年画",
+"幽默畫" => 	"幽默画",
+"應著" => 	"应着",
+"康乾" => 	"康乾",
+"康著" => 	"康着",
+"開著" => 	"开着",
+"弄著" => 	"弄着",
+"引著" => 	"引着",
+"張法乾" => 	"张法乾",
 "弱鹼" => 	"弱碱",
+"彈著點 " => 	"弹着点 ",
+"歸著 " => 	"归着 ",
+"當著" => 	"当着",
+"當著 " => 	"当着 ",
 "彩畫" => 	"彩画",
+"待著" => 	"待着",
+"得著" => 	"得着",
+"得著作" => 	"得著作",
+"得著名" => 	"得著名",
+"得著者" => 	"得著者",
+"循著" => 	"循着",
+"心著" => 	"心着",
+"忍著" => 	"忍着",
+"志著" => 	"志着",
+"忙著" => 	"忙着",
+"念著" => 	"念着",
+"懷著" => 	"怀着",
+"怎么著" => 	"怎么着",
+"急著" => 	"急着",
+"性著" => 	"性着",
+"性著作" => 	"性著作",
+"性著名" => 	"性著名",
+"性著者" => 	"性著者",
+"性著述" => 	"性著述",
+"戀著" => 	"恋着",
+"悠著" => 	"悠着",
+"懸著" => 	"悬着",
+"惦著" => 	"惦着",
+"慣著" => 	"惯着",
+"想著" => 	"想着",
+"意味著" => 	"意味着",
+"愣著" => 	"愣着",
+"慢著" => 	"慢着",
+"憋著" => 	"憋着",
+"戰著" => 	"战着",
+"戴著" => 	"戴着",
 "所畫" => 	"所画",
 "扉畫" => 	"扉画",
+"扎著" => 	"扎着",
+"打著" => 	"打着",
+"托著" => 	"托着",
+"扛著" => 	"扛着",
+"執著" => 	"执着",
+"扭著" => 	"扭着",
+"找不著" => 	"找不着",
+"找著 " => 	"找着 ",
+"抓著" => 	"抓着",
+"抗著" => 	"抗着",
+"搶著" => 	"抢着",
+"披著" => 	"披着",
+"抬著" => 	"抬着",
+"抱著" => 	"抱着",
+"押著" => 	"押着",
+"拄著" => 	"拄着",
+"拉著" => 	"拉着",
+"拍著" => 	"拍着",
+"拎著" => 	"拎着",
+"拎著 " => 	"拎着 ",
+"拖著" => 	"拖着",
+"拙著" => 	"拙着",
+"擁著" => 	"拥着",
+"拼著" => 	"拼着",
+"拽著" => 	"拽着",
+"拿著" => 	"拿着",
+"持著" => 	"持着",
+"掛著" => 	"挂着",
 "指畫" => 	"指画",
+"指著" => 	"指着",
+"按著" => 	"按着",
+"挎著" => 	"挎着",
+"挑著" => 	"挑着",
+"擋著" => 	"挡着",
+"掙著" => 	"挣着",
+"擠著" => 	"挤着",
+"揮著" => 	"挥着",
+"挨著" => 	"挨着",
+"挺著" => 	"挺着",
+"捂著" => 	"捂着",
+"捆著" => 	"捆着",
+"捏著" => 	"捏着",
+"撈著" => 	"捞着",
+"撿著" => 	"捡着",
+"捧著" => 	"捧着",
+"據著" => 	"据着",
+"據著作" => 	"据著作",
+"據著名" => 	"据著名",
+"據著者" => 	"据著者",
+"掖著" => 	"掖着",
+"接著" => 	"接着",
+"推著" => 	"推着",
+"揉著" => 	"揉着",
 "描畫" => 	"描画",
+"提著" => 	"提着",
 "插畫" => 	"插画",
+"握著" => 	"握着",
+"摟著" => 	"搂着",
+"擺著" => 	"摆着",
+"搖著" => 	"摇着",
+"摸著" => 	"摸着",
+"撼著" => 	"撼着",
+"擎著" => 	"擎着",
+"擘畫 " => 	"擘画 ",
+"攀著" => 	"攀着",
+"攥著" => 	"攥着",
+"支著" => 	"支着",
+"放著" => 	"放着",
 "教畫" => 	"教画",
+"敞著" => 	"敞着",
+"數著" => 	"数着",
+"斗著" => 	"斗着",
+"斥著" => 	"斥着",
+"新著龍虎門" => 	"新著龙虎门",
+"於乎" => 	"於乎",
+"於夫羅" => 	"於夫罗",
+"於姓" => 	"於姓",
+"於戲" => 	"於戏",
+"於梨華" => 	"於梨华",
+"於氏" => 	"於氏",
+"於潛縣" => 	"於潜县",
+"於菟" => 	"於菟",
+"旋乾轉坤" => 	"旋乾转坤",
+"無著" => 	"无着",
+"昂著" => 	"昂着",
+"映著" => 	"映着",
 "春畫" => 	"春画",
+"昧著" => 	"昧着",
+"晃著" => 	"晃着",
+"暗著" => 	"暗着",
+"有著" => 	"有着",
+"有著作" => 	"有著作",
+"有著名" => 	"有著名",
+"有著者" => 	"有著者",
+"望著" => 	"望着",
+"朝著" => 	"朝着",
+"本著" => 	"本着",
+"本著作" => 	"本著作",
+"本著名" => 	"本著名",
+"本著者" => 	"本著者",
+"機械畫" => 	"机械画",
+"雜著" => 	"杂着",
+"李乾德;" => 	"李乾德;",
+"來著" => 	"来着",
+"板著臉" => 	"板着脸",
+"枕著" => 	"枕着",
+"柳詒徵" => 	"柳诒徵",
+"標志著" => 	"标志着",
+"夢著" => 	"梦着",
+"梳著" => 	"梳着",
+"棋高一著" => 	"棋高一着",
+"樊於期" => 	"樊於期",
+"歇著" => 	"歇着",
+"歪打正著" => 	"歪打正着",
+"比畫 " => 	"比画 ",
+"比著" => 	"比着",
 "水鹼" => 	"水碱",
+"水粉畫" => 	"水粉画",
+"求著" => 	"求着",
+"沉著" => 	"沉着",
 "油畫" => 	"油画",
+"沿著" => 	"沿着",
 "洋鹼" => 	"洋碱",
+"活著" => 	"活着",
+"流著" => 	"流着",
+"浮著" => 	"浮着",
+"海景畫" => 	"海景画",
 "塗畫" => 	"涂画",
+"塗著" => 	"涂着",
+"涎著臉" => 	"涎着脸",
+"潤著" => 	"润着",
+"涵著" => 	"涵着",
+"涵著作" => 	"涵著作",
+"涵著名" => 	"涵著名",
+"涵著者" => 	"涵著者",
+"渴著" => 	"渴着",
+"溢著" => 	"溢着",
+"演著" => 	"演着",
+"演著作" => 	"演著作",
+"演著名" => 	"演著名",
+"演著者" => 	"演著者",
 "漫畫" => 	"漫画",
+"漫著" => 	"漫着",
+"潛伏著 " => 	"潜伏着 ",
 "炭畫" => 	"炭画",
 "點畫" => 	"点画",
+"點著" => 	"点着",
 "煙鹼" => 	"烟碱",
+"烤著" => 	"烤着",
+"燒著" => 	"烧着",
 "燒鹼" => 	"烧碱",
+"照著" => 	"照着",
+"照著作" => 	"照著作",
+"照著名" => 	"照著名",
+"照著者" => 	"照著者",
+"愛著" => 	"爱着",
+"愛鬧著玩" => 	"爱闹着玩",
 "版畫" => 	"版画",
+"牽著" => 	"牵着",
+"犯不著" => 	"犯不着",
+"獨著" => 	"独着",
+"猜著" => 	"猜着",
+"猜著 " => 	"猜着 ",
+"玩著" => 	"玩着",
+"甜著" => 	"甜着",
+"用不著" => 	"用不着",
+"用著" => 	"用着",
+"用著作" => 	"用著作",
+"畫  " => 	"画  ",
 "畫一" => 	"画一",
 "畫上" => 	"画上",
 "畫下" => 	"画下",
@@ -9378,9 +10302,11 @@
 "畫外" => 	"画外",
 "畫室" => 	"画室",
 "畫家" => 	"画家",
+"畫屏 " => 	"画屏 ",
 "畫展" => 	"画展",
 "畫工" => 	"画工",
 "畫布" => 	"画布",
+"畫師 " => 	"画师 ",
 "畫帖" => 	"画帖",
 "畫幅" => 	"画幅",
 "畫廊" => 	"画廊",
@@ -9390,6 +10316,7 @@
 "畫押" => 	"画押",
 "畫景" => 	"画景",
 "畫本" => 	"画本",
+"畫板 " => 	"画板 ",
 "畫架" => 	"画架",
 "畫框" => 	"画框",
 "畫法" => 	"画法",
@@ -9414,10 +10341,77 @@
 "畫貼" => 	"画贴",
 "畫軸" => 	"画轴",
 "畫院" => 	"画院",
+"畫集 " => 	"画集 ",
 "畫面" => 	"画面",
 "畫頁" => 	"画页",
+"留著" => 	"留着",
+"疑著" => 	"疑着",
+"皺著" => 	"皱着",
 "鹽鹼" => 	"盐碱",
+"盛著" => 	"盛着",
+"盯著" => 	"盯着",
+"直著" => 	"直着",
+"盼著" => 	"盼着",
+"盾著" => 	"盾着",
+"看著" => 	"看着",
+"眯著" => 	"眯着",
+"著   " => 	"着   ",
+"著絲" => 	"着丝",
+"著人先鞭" => 	"着人先鞭",
+"著什么急" => 	"着什么急",
+"著他" => 	"着他",
+"著你" => 	"着你",
+"著兒" => 	"着儿",
+"著涼" => 	"着凉",
+"著力" => 	"着力",
+"著呢 " => 	"着呢 ",
+"著地" => 	"着地",
+"著墨" => 	"着墨",
+"著她" => 	"着她",
+"著妳" => 	"着妳",
+"著它" => 	"着它",
+"著實" => 	"着实",
+"著床" => 	"着床",
+"著錄" => 	"着录",
+"著忙" => 	"着忙",
+"著急" => 	"着急",
+"著惱" => 	"着恼",
+"著想" => 	"着想",
+"著意" => 	"着意",
+"著慌" => 	"着慌",
+"著我" => 	"着我",
+"著手" => 	"着手",
+"著數" => 	"着数",
+"著棋 " => 	"着棋 ",
+"著法" => 	"着法",
+"著火" => 	"着火",
+"著眼" => 	"着眼",
+"著祂" => 	"着祂",
+"著筆" => 	"着笔",
+"著緊" => 	"着紧",
+"著腳" => 	"着脚",
+"著艦" => 	"着舰",
+"著色" => 	"着色",
+"著花" => 	"着花",
+"著落" => 	"着落",
+"著衣" => 	"着衣",
+"著裝" => 	"着装",
+"著迷" => 	"着迷",
+"著重" => 	"着重",
+"著陸" => 	"着陆",
+"著鞭" => 	"着鞭",
+"著魔" => 	"着魔",
+"睜著" => 	"睁着",
+"睡不著" => 	"睡不着",
+"睡著" => 	"睡着",
+"瞄著" => 	"瞄着",
+"瞅著" => 	"瞅着",
+"瞞著" => 	"瞒着",
+"瞧著" => 	"瞧着",
+"瞪著" => 	"瞪着",
+"知疼著熱" => 	"知疼着热",
 "硝鹼" => 	"硝碱",
+"硬著" => 	"硬着",
 "鹼 " => 	"碱 ",
 "鹼化" => 	"碱化",
 "鹼場" => 	"碱场",
@@ -9428,54 +10422,169 @@
 "鹼熔" => 	"碱熔",
 "鹼類" => 	"碱类",
 "磁畫" => 	"磁画",
+"福著" => 	"福着",
+"積著" => 	"积着",
+"空著" => 	"空着",
+"穿著" => 	"穿着",
+"立著" => 	"立着",
+"豎著" => 	"竖着",
+"站著" => 	"站着",
+"端著" => 	"端着",
+"笑著" => 	"笑着",
 "筆畫" => 	"笔画",
+"等著" => 	"等着",
 "策畫" => 	"策画",
+"管著" => 	"管着",
+"粘著" => 	"粘着",
+"系著" => 	"系着",
+"緊著" => 	"紧着",
 "純鹼" => 	"纯碱",
 "組畫" => 	"组画",
+"細密畫" => 	"细密画",
+"綁著" => 	"绑着",
+"繞著" => 	"绕着",
 "繪畫" => 	"绘画",
 "絹畫" => 	"绢画",
+"綳著勁" => 	"绷着劲",
+"綳著臉 " => 	"绷着脸 ",
+"纏著" => 	"缠着",
+"罩著" => 	"罩着",
+"美著" => 	"美着",
+"美著作" => 	"美著作",
+"美著名" => 	"美著名",
+"美著者" => 	"美著者",
+"耀著" => 	"耀着",
+"老著臉皮" => 	"老着脸皮",
+"考著" => 	"考着",
 "耐鹼" => 	"耐碱",
+"聊著" => 	"聊着",
 "肉鹼" => 	"肉碱",
+"肖像畫" => 	"肖像画",
+"背著" => 	"背着",
 "膠畫" => 	"胶画",
+"膠著" => 	"胶着",
+"腆著" => 	"腆着",
+"舞著" => 	"舞着",
+"藝著" => 	"艺着",
+"苦著" => 	"苦着",
 "茶鹼" => 	"茶碱",
+"獲著" => 	"获着",
+"蕭乾" => 	"萧乾",
+"落著" => 	"落着",
+"蒙著" => 	"蒙着",
+"藏著" => 	"藏着",
+"蘸著" => 	"蘸着",
+"行著" => 	"行着",
+"衣著" => 	"衣着",
+"裝著" => 	"装着",
+"裸體畫" => 	"裸体画",
+"裹著" => 	"裹着",
+"西洋畫" => 	"西洋画",
 "西畫" => 	"西画",
+"見著" => 	"见着",
+"覺著" => 	"觉着",
+"記著" => 	"记着",
+"講著" => 	"讲着",
+"試著" => 	"试着",
+"該著" => 	"该着",
+"語著" => 	"语着",
+"說著" => 	"说着",
+"豫著" => 	"豫着",
+"貞著" => 	"贞着",
 "貼畫" => 	"贴画",
+"貼著" => 	"贴着",
+"貿著之仇" => 	"贸着之仇",
+"走著" => 	"走着",
+"趕著" => 	"赶着",
+"起著" => 	"起着",
+"趁著" => 	"趁着",
+"趴著" => 	"趴着",
+"躍著" => 	"跃着",
+"跐著腳 " => 	"跐着脚 ",
+"跑著" => 	"跑着",
+"跟著" => 	"跟着",
+"跪著" => 	"跪着",
+"跳著" => 	"跳着",
+"踏著" => 	"踏着",
+"踩著" => 	"踩着",
+"蹲著 " => 	"蹲着 ",
+"身著" => 	"身着",
+"躺著" => 	"躺着",
+"轉著" => 	"转着",
+"載著" => 	"载着",
+"達著" => 	"达着",
+"過著" => 	"过着",
+"邁著" => 	"迈着",
+"迎著" => 	"迎着",
 "返鹼" => 	"返碱",
+"這么著" => 	"这么着",
+"遠著" => 	"远着",
+"連環畫" => 	"连环画",
+"連著" => 	"连着",
+"連著作" => 	"连著作",
+"連著名" => 	"连著名",
+"連著者" => 	"连著者",
+"追著" => 	"追着",
+"逆著" => 	"逆着",
+"透著" => 	"透着",
+"透視畫" => 	"透视画",
+"逼著" => 	"逼着",
+"遇著" => 	"遇着",
+"那么著" => 	"那么着",
+"郭子乾" => 	"郭子乾",
+"配著" => 	"配着",
 "酸鹼" => 	"酸碱",
+"釀著" => 	"酿着",
+"醒著" => 	"醒着",
+"鋪著" => 	"铺着",
+"鍾  " => 	"锺  ",
 "鍾鍛" => 	"锺锻",
 "鍛鍾" => 	"锻锺",
+"長著" => 	"长着",
+"閉著" => 	"闭着",
+"問著" => 	"问着",
+"閑著" => 	"闲着",
+"鬧著玩兒" => 	"闹着玩儿",
+"附著" => 	"附着",
+"陋著" => 	"陋着",
+"陪著" => 	"陪着",
+"隨著" => 	"随着",
+"隔著" => 	"隔着",
+"雅著" => 	"雅着",
 "雕畫" => 	"雕画",
-"鯰 " => 	"鲶 ",
-"鯰魚" => 	"鲶鱼",
-"三聯畫" => 	"三联画",
-"寫生畫" => 	"写生画",
-"單色畫" => 	"单色画",
-"卡通畫" => 	"卡通画",
-"宣傳畫" => 	"宣传画",
-"幽默畫" => 	"幽默画",
-"擘畫 " => 	"擘画 ",
-"機械畫" => 	"机械画",
-"比畫 " => 	"比画 ",
-"水粉畫" => 	"水粉画",
-"海景畫" => 	"海景画",
-"畫  " => 	"画  ",
-"畫屏 " => 	"画屏 ",
-"畫師 " => 	"画师 ",
-"畫板 " => 	"画板 ",
-"畫集 " => 	"画集 ",
-"細密畫" => 	"细密画",
-"肖像畫" => 	"肖像画",
-"裸體畫" => 	"裸体画",
-"西洋畫" => 	"西洋画",
-"連環畫" => 	"连环画",
-"透視畫" => 	"透视画",
-"鍾  " => 	"锺  ",
 "靜物畫" => 	"静物画",
+"靠著" => 	"靠着",
+"面對著 " => 	"面对着 ",
+"頂著" => 	"顶着",
+"順著" => 	"顺着",
+"顧著" => 	"顾着",
+"領著" => 	"领着",
 "風景畫" => 	"风景画",
+"飄著" => 	"飘着",
 "餘  " => 	"馀  ",
+"餘年" => 	"馀年",
+"駕著" => 	"驾着",
+"罵著" => 	"骂着",
+"騎著" => 	"骑着",
+"騙著" => 	"骗着",
+"高著" => 	"高着",
+"髭著" => 	"髭着",
+"魏徵" => 	"魏徵",
+"鯰 " => 	"鲶 ",
+"鯰魚" => 	"鲶鱼",
+"黏著" => 	"黏着",
+"龕著" => 	"龛着",
+"乾县" => "乾县",
+"萧乾" => "萧乾",
+"乾断" => "乾断",
+"乾图" => "乾图",
+"乾纲" => "乾纲",
+"乾红" => "乾红",
+"乾清宫" => "乾清宫",
 "柳诒徵" => "柳诒徵",
 "於夫罗" => "於夫罗",
 "於梨华" => "於梨华",
+"于潜县" => "於潜县",
 "憑藉" => "凭借",
 "藉端" => "借端",
 "藉故" => "借故",
@@ -9494,6 +10603,22 @@
 "‘" => "『",
 "’" => "』",
 "着" => "著",
+"元凶" => "元凶",
+"凶器" => "凶器",
+"凶徒" => "凶徒",
+"凶手" => "凶手",
+"凶案" => "凶案",
+"凶残" => "凶殘",
+"凶杀" => "凶殺",
+"疑凶" => "疑凶",
+"真凶" => "真凶",
+"缉凶" => "緝凶",
+"行凶" => "行凶",
+"行凶后" => "行凶後",
+"买凶" => "買凶",
+"追凶" => "追凶",
+"复苏" => "復甦",
+"復蘇" => "復甦",
 "缺省" => "預設",
 "串行" => "串列",
 "以太网" => "乙太網",
@@ -9511,10 +10636,12 @@
 "脱机" => "離線",
 "声卡" => "音效卡",
 "老字号" => "老字號",
+"连字号" => "連字號",
 "字号" => "字型大小",
 "字库" => "字型檔",
 "字段" => "欄位",
 "字符" => "字元",
+"字符集" => "字符集",
 "存盘" => "存檔",
 "寻址" => "定址",
 "尾注" => "章節附註",
@@ -9531,6 +10658,9 @@
 "磁盘" => "磁碟",
 "磁道" => "磁軌",
 "程控" => "程式控制",
+"远程控制" => "遠程控制",
+"遠程控制" => "遠程控制",
+"行程控制" => "行程控制",
 "端口" => "埠",
 "算子" => "運算元",
 "算法" => "演算法",
@@ -9562,11 +10692,13 @@
 "奶酪" => "乳酪",
 "巨商" => "鉅賈",
 "手电" => "手電筒",
+"手电筒" => "手電筒",
 "万历" => "萬曆",
 "永历" => "永曆",
 "词汇" => "辭彙",
 "习用" => "慣用",
 "元音" => "母音",
+"宋元" => "宋元",
 "任意球" => "自由球",
 "头球" => "頭槌",
 "入球" => "進球",
@@ -9591,6 +10723,7 @@
 "網絡" => "網路",
 "人工智能" => "人工智慧",
 "航天飞机" => "太空梭",
+"航天大学" => "航天大學",
 "穿梭機" => "太空梭",
 "因特网" => "網際網路",
 "互聯網" => "網際網路",
@@ -9767,6 +10900,8 @@
 "雪糕" => "冰淇淋",
 "卫生" => "衛生",
 "衞生" => "衛生",
+"平治之亂" => "平治之亂",
+"平治之乱" => "平治之亂",
 "平治" => "賓士",
 "奔驰" => "賓士",
 "積架" => "捷豹",
@@ -9792,6 +10927,10 @@
 "“" => "「",
 "‘" => "『",
 "’" => "』",
+"凶殺" => "兇殺",
+"凶殘" => "兇殘",
+"緝凶" => "緝兇",
+"買凶" => "買兇",
 "打印机" => "打印機",
 "印表機" => "打印機",
 "字节" => "位元組",
@@ -10071,7 +11210,6 @@
 "資料庫" => "数据库",
 "乳酪" => "奶酪",
 "鉅賈" => "巨商",
-"手電筒" => "手电",
 "萬曆" => "万历",
 "永曆" => "永历",
 "辭彙" => "词汇",
@@ -10275,7 +11413,6 @@
 "华乐" => "民乐",
 "中樂" => "民乐",
 "屋价" => "房价",
-"的士" => "出租车",
 "計程車" => "出租车",
 "公車" => "公共汽车",
 "單車" => "自行车",
@@ -10291,6 +11428,8 @@
 "衛生" => "卫生",
 "賓士" => "奔驰",
 "平治" => "奔驰",
+"平治之亂" => "平治之乱",
+"平治之乱" => "平治之乱",
 "積架" => "捷豹",
 "福斯" => "大众",
 "福士" => "大众",
Index: languages/messages/MessagesIo.php
===================================================================
--- languages/messages/MessagesIo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,11 @@
  * @ingroup Language
  * @file
  *
- * @author Malafaya
- * @author Lakaoso
- * @author SPQRobin
- * @author לערי ריינהארט
- * @author Siebrand
- * @author Jon Harald Søby
  * @author Albonio
  * @author Artomo
+ * @author Lakaoso
+ * @author Malafaya
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -244,7 +241,7 @@
 'nosuchspecialpage' => 'Ne existas tala specala pagino',
 'nospecialpagetext' => "<big>'''Vu demandis specala pagino qua ne existas.'''</big>
 
-A list of valid special pages can be found at [[Special:Specialpages|{{int:specialpages}}]].",
+A list of valid special pages can be found at [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'               => 'Eroro',
@@ -369,10 +366,6 @@
 'blockedtitle'         => 'La uzanto esas blokusita',
 'whitelistedittitle'   => 'On mustas enskribar por redaktar',
 'whitelistedittext'    => 'Vu mustas $1 por redaktar pagini.',
-'whitelistreadtitle'   => 'On mustas enskribar por lektar',
-'whitelistreadtext'    => 'Vu mustas [[Special:Userlogin|enirar]] por lektar artikli.',
-'whitelistacctitle'    => 'Vu ne havas permiso por krear konto',
-'whitelistacctext'     => 'Por darfar krear konti en ica Wiki, vu mustas [[Special:Userlogin|enirar]] e havar la necesa permisi.',
 'loginreqtitle'        => 'Eniro esas postulata',
 'loginreqlink'         => 'enirar',
 'accmailtitle'         => 'Kontrolajo sendita.',
@@ -474,7 +467,7 @@
 'preferences'        => 'Preferaji',
 'mypreferences'      => 'Mea preferaji',
 'prefsnologin'       => 'Vu ne eniris',
-'prefsnologintext'   => 'Vu mustas [[Special:Userlogin|enirir]] por establisar la preferaji.',
+'prefsnologintext'   => 'Vu mustas [[Special:UserLogin|enirir]] por establisar la preferaji.',
 'prefsreset'         => 'La preferaji riestablisesis da la depozeyo.',
 'qbsettings'         => 'Preferaji pri "Quickbar"',
 'qbsettings-none'    => 'Nula',
@@ -567,7 +560,7 @@
 'reupload'          => 'Ri-adkargar',
 'reuploaddesc'      => 'Retrovenar al adkargo-formularo.',
 'uploadnologin'     => 'Vu ne eniris',
-'uploadnologintext' => 'Vu mustas [[Special:Userlogin|enirir]] por adkargar arkivi.',
+'uploadnologintext' => 'Vu mustas [[Special:UserLogin|enirir]] por adkargar arkivi.',
 'uploaderror'       => 'Eroro dum adkargo',
 'uploadlog'         => 'Adkargo-log',
 'uploadlogpagetext' => 'Infre esas listo di la plu recenta adkargaji.',
@@ -586,7 +579,7 @@
 'uploadedimage'     => 'adkargita "[[$1]]"',
 'uploaddisabled'    => 'Pardonez, la adkargo esas desaktiva.',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'arkivo',
 'imagelist'      => 'Listo di imaji',
 'imagelist_date' => 'Dato',
@@ -686,7 +679,7 @@
 'speciallogtitlelabel' => 'Titulo:',
 'log-search-submit'    => 'Irar',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Omna pagini',
 'alphaindexline'    => '$1 til $2',
 'nextpage'          => 'Sequanta pagino ($1)',
@@ -703,12 +696,12 @@
 # Special:Categories
 'categories' => 'Kategorii',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group' => 'Grupo',
 
 # E-mail user
 'mailnologin'     => 'Ne sendar adreso',
-'mailnologintext' => 'Vu mustas [[Special:Userlogin|enirir]] e havar valida e-adreso en vua [[Special:Preferences|preferaji]] por sendar e-posto ad altra uzanti.',
+'mailnologintext' => 'Vu mustas [[Special:UserLogin|enirir]] e havar valida e-adreso en vua [[Special:Preferences|preferaji]] por sendar e-posto ad altra uzanti.',
 'emailuser'       => 'Sendar e-posto a ca uzanto',
 'emailpage'       => 'E-posto ad uzanto',
 'defemailsubject' => 'E-posto di {{SITENAME}}',
@@ -727,9 +720,9 @@
 'watchlistfor'         => "(por '''$1''')",
 'nowatchlist'          => 'Vu ne havas objekti en vua listo di surveyaji.',
 'watchnologin'         => 'Vu ne startis sesiono',
-'watchnologintext'     => 'Vu mustas [[Special:Userlogin|enirir]] por modifikar vua surveyaji.',
+'watchnologintext'     => 'Vu mustas [[Special:UserLogin|enirir]] por modifikar vua surveyaji.',
 'addedwatch'           => 'Adjuntita a la listo de surveyaji',
-'addedwatchtext'       => "La pagino \"<nowiki>\$1</nowiki>\" atachesis a vua [[Special:Watchlist|listo de surveyaji]]. Futura chanji di ica pagino ed olua relatata debato-pagini montresos ibe, ed la pagino aparos per '''dika literi''' en la [[Special:Recentchanges|listo de recenta chanji]] por faciligar sua trovebleso.
+'addedwatchtext'       => "La pagino \"<nowiki>\$1</nowiki>\" atachesis a vua [[Special:Watchlist|listo de surveyaji]]. Futura chanji di ica pagino ed olua relatata debato-pagini montresos ibe, ed la pagino aparos per '''dika literi''' en la [[Special:RecentChanges|listo de recenta chanji]] por faciligar sua trovebleso.
 
 <p> Se vu volas efacar la pagino de vua listo de surveyaji pose, presez \"Ne plus surveyar\" en la selektaro.",
 'removedwatch'         => 'Efacita de surveyo-listo',
@@ -843,7 +836,7 @@
 'badipaddress'       => 'IP-adreso ne esas valida',
 'blockipsuccesssub'  => 'Blokusado sucesis',
 'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] blokusesis.<br />
-Videz [[Special:Ipblocklist|IP-blokuslisto]] por revizor blokusadi.',
+Videz [[Special:IPBlockList|IP-blokuslisto]] por revizor blokusadi.',
 'unblockip'          => 'Desblokusar uzanto',
 'unblockiptext'      => 'Uzez la sequanta formularo por restaurar la skribo-aceso ad IP-adreso qua blokusesis antee.',
 'ipusubmit'          => 'Desblokusar ica IP-adreso',
@@ -871,7 +864,7 @@
 'lockdbsuccesssub'    => 'Datumaro blokusita sucese',
 'unlockdbsuccesssub'  => 'La desblokuso facesis sucese',
 'lockdbsuccesstext'   => 'La datumaro blokusesis.<br />
-Memorez [[Special:Unlockdb|efacar la blokuso]] kande vua mantenado finos.',
+Memorez [[Special:UnlockDB|efacar la blokuso]] kande vua mantenado finos.',
 'unlockdbsuccesstext' => 'La datumaro desblokusesis.',
 
 # Move page
@@ -890,8 +883,6 @@
 Ica povas esar drastika chanjo e ne-esperinda por populara pagino.
 Voluntez certigar ke vu komprenas la konsequi qui eventos ante durar adavane.",
 'movearticle'             => 'Movar pagino',
-'movenologin'             => 'Sesiono ne iniciata',
-'movenologintext'         => 'Vu mustas esar registragita uzanto ed [[Special:Userlogin|enirir]] por rinomizar pagino.',
 'newtitle'                => 'a nova titulo',
 'movepagebtn'             => 'Movar pagino',
 'pagemovedsub'            => 'Rinomizita sucese',
@@ -993,7 +984,7 @@
 # Media information
 'widthheightpage' => '$1×$2, $3 pagini',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Galerio di nova arkivi',
 'imagelisttext' => "Infre esas listo di '''$1''' {{PLURAL:$1|arkivo|arkivi}} rangizita $2.",
 'showhidebots'  => '($1 bot-i)',
@@ -1046,7 +1037,7 @@
 'confirmemail_needlogin' => 'Vu mustas $1 pro konfirmar vua adreso di e-posto.',
 
 # HTML dump
-'redirectingto' => 'Ridirektante ad [[$1]]...',
+'redirectingto' => 'Ridirektante ad [[:$1]]...',
 
 # AJAX search
 'articletitles' => "Pagini komencanta per ''$1''",
@@ -1087,7 +1078,7 @@
 'version-license'          => 'Licenco',
 'version-software-version' => 'Versiono',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Arkivo:',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesEt.php
===================================================================
--- languages/messages/MessagesEt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Võrok
  * @author WikedKentaur
- * @author SPQRobin
- * @author Siebrand
- * @author M.M.S.
  * @author לערי ריינהארט
- * @author Võrok
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -489,10 +485,6 @@
 Teie praegune IP on $3 ning blokeeringu number on #$5. Lisage vähemalt üks nendest kõigile järelpärimistele, mida kavatsete teha.",
 'whitelistedittitle'       => 'Redigeerimiseks tuleb sisse logida',
 'whitelistedittext'        => 'Lehekülgede toimetamiseks peate $1.',
-'whitelistreadtitle'       => 'Lugemiseks peate olema sisse logitud',
-'whitelistreadtext'        => 'Lehekülgede lugemiseks peate [[Special:Userlogin|sisse logima]].',
-'whitelistacctitle'        => 'Teil pole õigust kasutajakontot luua',
-'whitelistacctext'         => 'Et selles Vikis kontosid luua, peate olema [[Special:Userlogin|sisse logitud]] ja omama vastavaid õigusi.',
 'loginreqtitle'            => 'Vajalik on sisselogimine',
 'loginreqlink'             => 'sisse logima',
 'loginreqpagetext'         => 'Lehekülgede vaatamiseks peate $1.',
@@ -503,12 +495,12 @@
 Lehekülje loomiseks hakake kirjutama all olevasse tekstikasti
 (lisainfo saamiseks vaadake [[{{MediaWiki:Helppage}}|juhendit]]).
 Kui sattusite siia kogemata, klõpsake lihtsalt brauseri ''back''-nupule või lingile ''tühista''.",
-'anontalkpagetext'         => "---- ''See on arutelulehekülg anonüümse kasutaja kohta, kes ei ole loonud kontot või ei kasuta seda. Sellepärast tuleb meil kasutaja identifitseerimiseks kasutada tema IP-aadressi. See IP-aadress võib olla mitmele kasutajale ühine. Kui olete anonüümne kasutaja ning leiate, et kommentaarid sellel leheküljel ei ole mõeldud Teile, siis palun [[Special:Userlogin|looge konto või logige sisse]], et edaspidi arusaamatusi vältida.''",
+'anontalkpagetext'         => "---- ''See on arutelulehekülg anonüümse kasutaja kohta, kes ei ole loonud kontot või ei kasuta seda. Sellepärast tuleb meil kasutaja identifitseerimiseks kasutada tema IP-aadressi. See IP-aadress võib olla mitmele kasutajale ühine. Kui olete anonüümne kasutaja ning leiate, et kommentaarid sellel leheküljel ei ole mõeldud Teile, siis palun [[Special:UserLogin|looge konto või logige sisse]], et edaspidi arusaamatusi vältida.''",
 'noarticletext'            => "<div style=\"border: 1px solid #ccc; padding: 7px; background-color: #fff; color: #000\">
 '''Sellise pealkirjaga lehekülge ei ole.'''
 * <span class=\"plainlinks\">'''[{{fullurl:{{FULLPAGENAME}}|action=edit}} Alusta seda lehekülge]''' või</span>
 * <span class=\"plainlinks\">[[{{ns:special}}:Search/{{PAGENAMEE}}|Otsi väljendit \"{{PAGENAME}}]]\" teistest artiklitest või</span>
-* [[Special:Whatlinkshere/{{NAMESPACE}}:{{PAGENAMEE}}|Vaata lehekülgi, mis siia viitavad]].
+* [[Special:WhatLinksHere/{{NAMESPACE}}:{{PAGENAMEE}}|Vaata lehekülgi, mis siia viitavad]].
 </div>",
 'clearyourcache'           => "'''Märkus:''' Pärast salvestamist pead sa muudatuste nägemiseks oma brauseri puhvri tühjendama: '''Mozilla:''' ''ctrl-shift-r'', '''IE:''' ''ctrl-f5'', '''Safari:''' ''cmd-shift-r'', '''Konqueror''' ''f5''.",
 'usercssjsyoucanpreview'   => "<strong>Vihje:</strong> Kasuta nuppu 'Näita eelvaadet' oma uue css/js testimiseks enne salvestamist.",
@@ -612,7 +604,7 @@
 'preferences'             => 'Eelistused',
 'mypreferences'           => 'eelistused',
 'prefsnologin'            => 'Te ei ole sisse loginud',
-'prefsnologintext'        => 'Et oma eelistusi seada, [[Special:Userlogin|tuleb Teil]]
+'prefsnologintext'        => 'Et oma eelistusi seada, [[Special:UserLogin|tuleb Teil]]
 sisse logida.',
 'prefsreset'              => 'Teie eelistused on arvutimälu järgi taastatud.',
 'qbsettings'              => 'Kiirriba sätted',
@@ -718,13 +710,13 @@
 'reupload'             => 'Uuesti üleslaadimine',
 'reuploaddesc'         => 'Tagasi üleslaadimise vormi juurde.',
 'uploadnologin'        => 'sisse logimata',
-'uploadnologintext'    => 'Kui Te soovite faile üles laadida, peate [[Special:Userlogin|sisse logima]].',
+'uploadnologintext'    => 'Kui Te soovite faile üles laadida, peate [[Special:UserLogin|sisse logima]].',
 'uploaderror'          => 'Faili laadimine ebaõnnestus',
 'uploadtext'           => '<strong>STOPP!</strong> Enne kui sooritad üleslaadimise,
 peaksid tagama, et see järgib siinset [[{{MediaWiki:Policy-url}}|piltide kasutamise korda]].
 
 Et näha või leida eelnevalt üleslaetud pilte,
-mine vaata [[Special:Imagelist|piltide nimekirja]].
+mine vaata [[Special:ImageList|piltide nimekirja]].
 Üleslaadimised ning kustutamised logitakse [[Special:Log/upload|üleslaadimise logis]].
 
 Järgneva vormi abil saad laadida üles uusi pilte
@@ -784,7 +776,7 @@
 'license'   => 'Litsents:',
 'nolicense' => 'pole valitud',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Piltide loend',
 
 # Image description page
@@ -848,7 +840,7 @@
 Seega keskmiselt '''$5''' redigeerimist lehekülje kohta ja '''$6''' lehekülje vaatamist ühe redigeerimise kohta.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Töö järjekorra] pikkus on '''$7'''.",
-'userstatstext' => "Registreeritud [[Special:Listusers|kasutajate]] arv: '''$1''', kelledest '''$2''' (ehk '''$4%''') on $5 õigused.",
+'userstatstext' => "Registreeritud [[Special:ListUsers|kasutajate]] arv: '''$1''', kelledest '''$2''' (ehk '''$4%''') on $5 õigused.",
 
 'disambiguations' => 'Täpsustusleheküljed',
 
@@ -912,7 +904,7 @@
 'alllogstext'          => 'See on kombineeritud vaade üleslaadimise, kustutamise, kaitsmise, blokeerimise ja administraatorilogist. Valiku kitsendamiseks vali soovitav logitüüp, sisesta kasutajanimi või huvi pakkuva lehekülge pealkiri.',
 'logempty'             => 'Logides vastavad kirjed puuduvad.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Kõik artiklid',
 'alphaindexline'    => '$1 kuni $2',
 'nextpage'          => 'Järgmine lehekülg ($1)',
@@ -929,7 +921,7 @@
 'categoriespagetext' => 'Vikis on järgmised kategooriad.',
 
 # E-mail user
-'mailnologintext' => 'Te peate olema [[Special:Userlogin|sisse logitud]] ja teil peab [[Special:Preferences|eelistustes]] olema kehtiv e-posti aadress, et saata teistele kasutajatele e-kirju.',
+'mailnologintext' => 'Te peate olema [[Special:UserLogin|sisse logitud]] ja teil peab [[Special:Preferences|eelistustes]] olema kehtiv e-posti aadress, et saata teistele kasutajatele e-kirju.',
 'emailuser'       => 'Saada sellele kasutajale e-kiri',
 'emailpage'       => 'Saada kasutajale e-kiri',
 'emailpagetext'   => 'Kui see kasutaja on oma eelistuste lehel sisestanud e-posti aadressi, siis saate alloleva vormi kaudu talle kirja saata. Et kasutaja saaks vastata, täidetakse kirja saatja väli "kellelt" e-posti aadressiga, mille olete sisestanud oma eelistuste lehel.',
@@ -948,11 +940,11 @@
 'nowatchlist'          => 'Teie jälgimisloend on tühi.',
 'watchlistanontext'    => 'Et näha ja muuta oma jälgimisloendit, peate $1.',
 'watchnologin'         => 'Ei ole sisse logitud',
-'watchnologintext'     => 'Jälgimisloendi muutmiseks peate [[Special:Userlogin|sisse logima]].',
+'watchnologintext'     => 'Jälgimisloendi muutmiseks peate [[Special:UserLogin|sisse logima]].',
 'addedwatch'           => 'Lisatud jälgimisloendile',
 'addedwatchtext'       => 'Lehekülg "<nowiki>$1</nowiki>" on lisatud Teie [[Special:Watchlist|jälgimisloendile]].
 
-Edasised muudatused käesoleval lehel ja sellega seotud aruteluküljel reastatakse jälgimisloendis ning [[Special:Recentchanges|viimaste muudatuste lehel]] tuuakse jälgitava lehe pealkiri esile <b>rasvase</b> kirja abil.
+Edasised muudatused käesoleval lehel ja sellega seotud aruteluküljel reastatakse jälgimisloendis ning [[Special:RecentChanges|viimaste muudatuste lehel]] tuuakse jälgitava lehe pealkiri esile <b>rasvase</b> kirja abil.
 
 Kui tahad seda lehte hiljem jälgimisloendist eemaldada, klõpsa päisenupule "Lõpeta jälgimine".',
 'removedwatch'         => 'Jälgimisloendist kustutatud',
@@ -1015,7 +1007,7 @@
 'editcomment'                 => 'Artikli sisu oli: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Tühistati [[Eri:Contributions/$2|$2]] ([[Kasutaja arutelu:$2|arutelu]]) muudatus ning pöörduti tagasi viimasele muudatusele, mille tegi [[Kasutaja:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'protectlogpage'              => 'Kaitsmise logi',
-'protectlogtext'              => 'Allpool on loetletud lehekülgede kaitsmised ja kaitsete eemaldamised. Praegu kaitstud lehekülgi vaata [[Special:Protectedpages|kaitstud lehtede loetelust]].',
+'protectlogtext'              => 'Allpool on loetletud lehekülgede kaitsmised ja kaitsete eemaldamised. Praegu kaitstud lehekülgi vaata [[Special:ProtectedPages|kaitstud lehtede loetelust]].',
 'protectedarticle'            => 'kaitses lehekülje "[[$1]]"',
 'unprotectedarticle'          => 'eemaldas lehekülje "[[$1]]" kaitse',
 'protect-title'               => '"$1" kaitsmine',
@@ -1107,7 +1099,7 @@
 'badipaddress'       => 'The IP address is badly formed.',
 'blockipsuccesssub'  => 'Blokeerimine õnnestus',
 'blockipsuccesstext' => 'IP-aadress "$1" on blokeeritud.
-<br />Kehtivaid blokeeringuid vaata [[Special:Ipblocklist|blokeeringute nimekirjast]].',
+<br />Kehtivaid blokeeringuid vaata [[Special:IPBlockList|blokeeringute nimekirjast]].',
 'unblockip'          => 'Lõpeta IP aadressi blokeerimine',
 'unblockiptext'      => 'Kasutage allpool olevat vormi redigeerimisõiguste taastamiseks varem blokeeritud IP aadressile.',
 'ipblocklist'        => 'Blokeeritud IP-aadresside loend',
@@ -1120,7 +1112,7 @@
 'autoblocker'        => 'Autoblokeeritud kuna teie IP aadress on hiljut kasutatud "[[User:$1|$1]]" poolt. $1-le antud bloki põhjus on "\'\'\'$2\'\'\'"',
 'blocklogpage'       => 'Blokeerimise logi',
 'blocklogentry'      => 'blokeeris "[[$1]]". Blokeeringu aegumistähtaeg on $2 $3',
-'blocklogtext'       => 'See on kasutajate blokeerimiste ja blokeeringute eemaldamiste nimekiri. Automaatselt blokeeritud IP aadresse siin ei näidata. Hetkel aktiivsete blokeeringute ja redigeerimiskeeldude nimekirja vaata [[Special:Ipblocklist|IP blokeeringute nimekirja]] leheküljelt.',
+'blocklogtext'       => 'See on kasutajate blokeerimiste ja blokeeringute eemaldamiste nimekiri. Automaatselt blokeeritud IP aadresse siin ei näidata. Hetkel aktiivsete blokeeringute ja redigeerimiskeeldude nimekirja vaata [[Special:IPBlockList|IP blokeeringute nimekirja]] leheküljelt.',
 'unblocklogentry'    => '"$1" blokeerimine lõpetatud',
 'proxyblockreason'   => 'Teie IP aadress on blokeeritud, sest see on anonüümne proxy server. Palun kontakteeruga oma internetiteenuse pakkujaga või tehnilise toega ning informeerige neid sellest probleemist.',
 'proxyblocksuccess'  => 'Tehtud.',
@@ -1158,9 +1150,6 @@
 
 Neil juhtudel teisaldage arutelulehekülg soovi korral eraldi või ühendage ta omal käel uue aruteluleheküljega.",
 'movearticle'             => 'Teisalda artiklilehekülg',
-'movenologin'             => 'Te ei ole sisse loginud',
-'movenologintext'         => 'Et lehekülge teisaldada, peate registreeruma
-kasutajaks ja [[Special:Userlogin|sisse logima]]',
 'newtitle'                => 'Uue pealkirja alla',
 'move-watch'              => 'Jälgi seda lehekülge',
 'movepagebtn'             => 'Teisalda artikkel',
@@ -1285,7 +1274,7 @@
 'show-big-image'       => 'Originaalsuurus',
 'show-big-image-thumb' => '<small>Selle eelvaate suurus on: $1 × $2 pikselit</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Uute meediafailide galerii',
 'imagelisttext'         => 'Failide arv järgnevas loendis: $1. Sorteeritud $2.',
 'showhidebots'          => '($1 bottide kaastööd)',
@@ -1305,7 +1294,7 @@
 
 # External editor support
 'edit-externally'      => 'Töötle faili välise programmiga',
-'edit-externally-help' => 'Lisainfot loe leheküljelt [http://meta.wikimedia.org/wiki/Help:External_editors meta:väliste redaktorite kasutamine]',
+'edit-externally-help' => 'Lisainfot loe leheküljelt [http://www.mediawiki.org/wiki/Manual:External_editors meta:väliste redaktorite kasutamine]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kõik',
@@ -1342,7 +1331,7 @@
 'deletedwhileediting' => 'Hoiatus: Sel ajal, kui Te artiklit redigeerisite, on keegi selle kustutanud!',
 
 # HTML dump
-'redirectingto' => 'Ümbersuunamine lehele [[$1]]...',
+'redirectingto' => 'Ümbersuunamine lehele [[:$1]]...',
 
 # Auto-summaries
 'autosumm-blank'   => 'Kustutatud kogu lehekülje sisu',
Index: languages/messages/MessagesAy.php
===================================================================
--- languages/messages/MessagesAy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -82,7 +82,7 @@
 
 'license' => 'Iyawsawi:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_date'        => 'Uru jakhu',
 'imagelist_user'        => 'Apnaqiri',
 'imagelist_description' => 'Uñt’ayawi',
@@ -98,7 +98,7 @@
 'speciallogtitlelabel' => 'Titulu:',
 'log-search-submit'    => 'Saraña',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Uñachayaña',
 
 # Watchlist
Index: languages/messages/MessagesMn.php
===================================================================
--- languages/messages/MessagesMn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Chinneeb
  * @author לערי ריינהארט
- * @author Siebrand
- * @author SPQRobin
  */
 
 $linkTrail = '/^([a-zабвгдеёжзийклмнопрстуфхцчшщъыьэюя“»]+)(.*)$/sDu';
@@ -289,7 +287,7 @@
 'nosuchspecialpage' => 'Тийм тусгай хуудас байхгүй байна',
 'nospecialpagetext' => "<big>'''Та хүчингүй тусгай хуудас руу орох гэсэн үйлдлийг хийлээ.'''</big>
 
-Тусгай хуудсуудын жагсаалтыг [[Special:Specialpages|{{int:specialpages}}]] хуудаснаас харна уу.",
+Тусгай хуудсуудын жагсаалтыг [[Special:SpecialPages|{{int:specialpages}}]] хуудаснаас харна уу.",
 
 # General errors
 'error'                => 'Aлдаа',
@@ -540,10 +538,6 @@
 'blockededitsource'         => "Таны '''$1'''-д хийж байгаа '''засваруудын''' текстийг доор үзүүлэв:",
 'whitelistedittitle'        => 'Засварлахын тулд холбогдох шаардлагатай',
 'whitelistedittext'         => 'Хуудсуудад засвар хийхийн тулд та урьдаар $1 хэрэгтэй.',
-'whitelistreadtitle'        => 'Уншихийн тулд та нэвтрэх хэрэгтэй',
-'whitelistreadtext'         => 'Та хуудсуудыг уншихын тулд [[Special:Userlogin|нэвтрэх]] хэрэгтэй.',
-'whitelistacctitle'         => 'Та бүртгэл үүсгэх эрхгүй байна',
-'whitelistacctext'          => '{{SITENAME}}-д хэрэглэгчийн бүртгэл үүсгэхэд та [[Special:Userlogin|нэвтрэн]] орж, зохих зөвшөөрлийг авах шаардлагатай.',
 'confirmedittitle'          => 'Засварлахын тулд мэйлийн баталгаа шаардлагатай',
 'confirmedittext'           => 'Та хуудсуудыг засварлахдаа мэйл хаягаа баталгаажуулах хэрэгтэй.
 [[Special:Preferences|Хэрэглэгчийн тохиргоо]] хэсэгт өөрийнхөө мэйл хаягийг оруулж, баталгаажуулна уу.',
@@ -560,7 +554,7 @@
 нгүй мэдээллийг [[{{MediaWiki:Helppage}}|тусламжийн хуудсаас]] авч болно).
 Хэрэв та энд санамсаргүйгээр орж ирсэн бол броузерийнхаа '''back''' товчийг дар.",
 'anontalkpagetext'          => "----''Энэ нь хараахан бүртгүүлээгүй байгаа буюу хэрэглэгчийн нэр хэрэглэхгүй байгаа хэрэглэгчийн хэлэлцүүлгийн хуудас болно. Бид ийм хэрэглэгчдийг тогтоохын тулд IP хаягийг нь ашигладаг.
-Нэг IP хаягийг хэд хэдэн хэрэглэгч хамтран ашиглаж байх магадлалтай. Хэрвээ таны IP хаягт ирсэн санал хүсэлтүүд танд хандаагүй бөгөөд та цаашид ийм байдал үүсэхээс сэргийлье гэвэл [[Special:Userlogin|бүртгүүлэх буюу нэвтрэхийг]] хүсье.''",
+Нэг IP хаягийг хэд хэдэн хэрэглэгч хамтран ашиглаж байх магадлалтай. Хэрвээ таны IP хаягт ирсэн санал хүсэлтүүд танд хандаагүй бөгөөд та цаашид ийм байдал үүсэхээс сэргийлье гэвэл [[Special:UserLogin|бүртгүүлэх буюу нэвтрэхийг]] хүсье.''",
 'noarticletext'             => 'Одоогийн байдлаар энэ хуудсанд текст алга. Та нэг бол энэ хуудасны нэрээр бусад хуудсуудад [[Special:Search/{{PAGENAME}}|хайлт хийх]], эсвэл энэ хуудсыг [{{fullurl:{{FULLPAGENAME}}|action=edit}} засварлаж] болно.',
 'userpage-userdoesnotexist' => '"$1" хэрэглэгчийн бүртгэл бүртгэгдээгүй байна. Та энэ хуудсыг үүсгэх/засварлах тухайгаа дахин тунгааж бодно уу.',
 'clearyourcache'            => "'''Санамж:''' Хадгалсныхаа дараа шинэ тохиргоогоо харахын тулд броузерынхаа кешийг орхих хэрэгтэй болж магадгүй. '''Мозилла / Файрфокс / Сафари:''' ''Shift''-г дарж байхдаа ''Reload'' дээр дар, эсвэл ''Ctrl-Shift-R'' гэж дар (Макинтош дээр ''Cmd-Shift-R''); '''Интернэт Эксплорер:''' ''Ctrl'' -г дарж байхдаа ''Refresh'' дээр дар, эсвэл ''Ctrl-F5'' гэж дар; '''Конкерор:''' ''Reload'' товч дээр л дар, эсвэл ''F5''-г дар; '''Опера'''-гийн хэрэглэгчид кешийг ''Tools→Preferences'' дээр бүрэн арилгах шаардлагатай болж магадгүй.",
@@ -622,7 +616,7 @@
 'hiddencategories'          => 'Энэ хуудас нь $1 нуугдсан ангилалд багтаж байна:',
 'nocreatetitle'             => 'Хуудасны үүсгэл хязгаарлагдсан байна',
 'nocreatetext'              => '{{SITENAME}} нь шинэ хуудас үүсгэх явдлыг хаасан байна.
-Та буцаад хуучин байсан хуудсыг засварлах, эсвэл [[Special:Userlogin|нэвтэрч орох буюу бүртгүүлж болно]].',
+Та буцаад хуучин байсан хуудсыг засварлах, эсвэл [[Special:UserLogin|нэвтэрч орох буюу бүртгүүлж болно]].',
 'nocreate-loggedin'         => 'Таньд {{SITENAME}} дээр шинэ хуудас үүсгэх зөвшөөрөл байхгүй байна.',
 'permissionserrors'         => 'Зөвшөөрлүүдийн алдаанууд',
 'permissionserrorstext'     => 'Таньд үүнийг хийх зөвшөөрөл байхгүй байна. {{PLURAL:$1|Шалтгаан|Шалтгаанууд}} нь:',
@@ -731,7 +725,7 @@
 # Suppression log
 'suppressionlog'     => 'Хязгаарлалтын лог',
 'suppressionlogtext' => 'Доорх нь сиестемийн операторуудаас нууцалсан агуулгатай холбоотой устгал ба түгжээнүүдийн жагсаалт юм.
-[[Special:Ipblocklist|IP түгжээний жагсаалтыг]] үзэж одоо хэрэгжиж буй хорио ба түгжээг харна уу.',
+[[Special:IPBlockList|IP түгжээний жагсаалтыг]] үзэж одоо хэрэгжиж буй хорио ба түгжээг харна уу.',
 
 # History merging
 'mergehistory'                     => 'Хуудсуудын түүхийг нэгтгэх',
@@ -815,7 +809,7 @@
 'mypreferences'            => 'Миний тохиргоо',
 'prefs-edits'              => 'Засваруудын тоо:',
 'prefsnologin'             => 'Нэвтрээгүй байна',
-'prefsnologintext'         => 'Хэрэглэгчийн тохиргоогоо тохируулахын тулд та [[Special:Userlogin|нэвтэрсэн байх]] шаардлагатай.',
+'prefsnologintext'         => 'Хэрэглэгчийн тохиргоогоо тохируулахын тулд та [[Special:UserLogin|нэвтэрсэн байх]] шаардлагатай.',
 'prefsreset'               => 'Тохиргоонуудыг анхны байдалд нь орууллаа.',
 'qbsettings'               => 'Шуурхай тавцан',
 'qbsettings-none'          => 'Байхгүй',
@@ -888,7 +882,7 @@
 'userrights-reason'           => 'Өөрчилсөн шалтгаан:',
 'userrights-no-interwiki'     => 'Таньд өөр викинүүдэд хэрэглэгчдийн эрхийг өөрчлөх зөвшөөрөл байхгүй.',
 'userrights-nodatabase'       => '$1 мэдээллийн сан байхгүй, эсвэл дотоодынх биш байна.',
-'userrights-nologin'          => 'Та хэрэглэгчдийн эрхийг хуваарилахбн тулд администраторын бүртгэлтэйгээр [[Special:Userlogin|нэвтэрч орох]] шаардлагатай.',
+'userrights-nologin'          => 'Та хэрэглэгчдийн эрхийг хуваарилахбн тулд администраторын бүртгэлтэйгээр [[Special:UserLogin|нэвтэрч орох]] шаардлагатай.',
 'userrights-notallowed'       => 'Таны бүртгэл хэрэглэгчдийн эрхийг хуваарилах зөвшөөрөлгүй байна.',
 'userrights-changeable-col'   => 'Таны өөрчилж болох бүлгүүд',
 'userrights-unchangeable-col' => 'Таны өөрчилж болохгүй бүлгүүд',
@@ -965,11 +959,11 @@
 'reupload'                    => 'Дахин оруулах',
 'reuploaddesc'                => 'Файл оруулалтыг цуцалж оруулах маягт руу буцах',
 'uploadnologin'               => 'Нэвтрээгүй байна',
-'uploadnologintext'           => 'Та файл оруулахын тулд [[Special:Userlogin|нэвтэрч орсон]] байх шаардлагатай.',
+'uploadnologintext'           => 'Та файл оруулахын тулд [[Special:UserLogin|нэвтэрч орсон]] байх шаардлагатай.',
 'upload_directory_read_only'  => 'Файл оруулах каталог ($1) нь вэбсерверт бичигдэх боломгүй байна.',
 'uploaderror'                 => 'Файл оруулахад алдаа гарлаа',
 'uploadtext'                  => "Доорх маягтыг хэрэглэж файлыг оруулна уу.
-Өмнө нь оруулсан файлуудыг [[Special:Imagelist|оруулсан файлуудын жагсаалтаас]] харна уу. Оруулсан ба устгасан файлуудын жагсаалт нь мөн [[Special:Log/upload|файл оруулалтын логт]] бий.
+Өмнө нь оруулсан файлуудыг [[Special:ImageList|оруулсан файлуудын жагсаалтаас]] харна уу. Оруулсан ба устгасан файлуудын жагсаалт нь мөн [[Special:Log/upload|файл оруулалтын логт]] бий.
 
 Хуудсанд файл оруулахад дараахийг хэрэглэнэ үү:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Файл.jpg]]</nowiki>''',
@@ -1070,7 +1064,7 @@
 'upload_source_url'  => ' (хүчинтэй, нийтэд нээлттэй URL)',
 'upload_source_file' => '(таны компьютер доторх файл)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Энэ тусгай хуудсанд бүх оруулагдсан файлыг харуулсан байгаа.
 Хамгийн сүүлд оруулсан файлууд жагсаалтын хамгийн дээр байгаа.
 Баганын гарчиг дээр дарвал жагсаалт өөрчлөгдөнө.',
@@ -1110,11 +1104,11 @@
 # File reversion
 'filerevert'                => '$1-г буцаах',
 'filerevert-legend'         => 'Файлыг буцаах',
-'filerevert-intro'          => '<span class="plainlinks">Та \'\'\'[[Media:$1|$1]]\'\'\'-г [$3, $2-ий байдлаарх $4 хувилбар] руу буцааж байна.</span>',
+'filerevert-intro'          => "Та '''[[Media:$1|$1]]'''-г [$3, $2-ий байдлаарх $4 хувилбар] руу буцааж байна.",
 'filerevert-comment'        => 'Тайлбар:',
 'filerevert-defaultcomment' => '$2, $1-ий байдлаарх хувилбар руу буцаалаа',
 'filerevert-submit'         => 'Буцаах',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' нь [$3, $2-ий байдлаарх $4 хувилбар руу] буцаагдлаа.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' нь [$3, $2-ий байдлаарх $4 хувилбар руу] буцаагдлаа.",
 'filerevert-badversion'     => 'Өгөгдсөн огнооны тэмдэгтэй энэ файлын дотоод хувилбар байхгүй байна.',
 
 # File deletion
@@ -1176,7 +1170,7 @@
 Эдгээрийг тооцвол дунджаар хуудас тутмыг '''\$5''' удаа засварлаж, засвар тус бүрт '''\$6''' удаа хандсан байна.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Ажлын цувааны урт] одоогийн байдлаар '''\$7''' байна.",
-'userstatstext'          => "Нийт {{PLURAL:$1|'''1''' бүртгэгдсэн [[Special:Listusers|хэрэглэгч]]|'''$1''' хэрэглэгч [[Special:Listusers|хэрэглэгч]]}} байгаа бөгөөд үүнээс '''$2''' буюу '''$4%''' нь $5 гэсэн эрхтэй.",
+'userstatstext'          => "Нийт {{PLURAL:$1|'''1''' бүртгэгдсэн [[Special:ListUsers|хэрэглэгч]]|'''$1''' хэрэглэгч [[Special:ListUsers|хэрэглэгч]]}} байгаа бөгөөд үүнээс '''$2''' буюу '''$4%''' нь $5 гэсэн эрхтэй.",
 'statistics-mostpopular' => 'Хамгийн олон удаа үзсэн хуудсууд',
 
 'disambiguations'      => 'Салаа утгатай үгнүүд',
@@ -1266,7 +1260,7 @@
 'logempty'             => 'Логт тохирох зүйл алга.',
 'log-title-wildcard'   => 'Энэ текстээр эхлэсэн гарчигуудыг хайх',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Бүх хуудас',
 'alphaindexline'    => '$1-с $2 хүртэл',
 'nextpage'          => 'Дараагийн хуудас ($1)',
@@ -1288,12 +1282,12 @@
 'special-categories-sort-count' => 'тоогоор ялгах',
 'special-categories-sort-abc'   => 'үсгийн дарааллаар ялгах',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Дараахь тэмдэгтээр эхэлсэн нэртэй хэрэглэгчдийг харуул:',
 'listusers-submit'   => 'Үзүүлэх',
 'listusers-noresult' => 'Хэрэглэгч олдсонгүй.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Хэрэглэгчийн бүлгийн эрхүүд',
 'listgrouprights-summary'  => 'Дараах нь энэ вики дээрх хэрэглэгчийн бүлгүүд болон тэдгээрийн эрх, зөвшөөрлүүдийн жагсаалт юм.',
 'listgrouprights-group'    => 'Бүлэг',
@@ -1302,7 +1296,7 @@
 
 # E-mail user
 'mailnologin'     => 'илгээх хаяг байхгүй',
-'mailnologintext' => 'Та бусад хэрэглэгчдэд мэйл явуулахын тулд өөрийн [[Special:Preferences|хувийн тохируулгадаа]] мэйлээ оруулсан, мөн [[Special:Userlogin|нэвтэрсэн]] байх шаардлагатай.',
+'mailnologintext' => 'Та бусад хэрэглэгчдэд мэйл явуулахын тулд өөрийн [[Special:Preferences|хувийн тохируулгадаа]] мэйлээ оруулсан, мөн [[Special:UserLogin|нэвтэрсэн]] байх шаардлагатай.',
 'emailuser'       => 'Энэ хэрэглэгчид мэйл илгээх',
 'emailpage'       => 'мэйл хэрэглэгч',
 'emailpagetext'   => 'Энэ хэрэглэгч нь тохиргоондоо хүчинтэй мэйл хаяг оруулсан бол доорх формоос мэйл илгээж болно. Таны тохиргоонд оруулсан мэйл хаяг нь илгээж буй мэйлний “Хэнээс” гэдэг дээр гарч ирэх тул хүлээн авагч нь хариуг илгээх боломжтой.',
@@ -1327,10 +1321,10 @@
 'nowatchlist'          => 'Танд хянаж буй зүйл байхгүй.',
 'watchlistanontext'    => 'Та өөрийн хянах листийг өөрчлөх буюу үзэхийг хүсвэл $1 хэрэгтэй.',
 'watchnologin'         => 'Нэвтрээгүй байна.',
-'watchnologintext'     => 'Та өөрийн хянаж буй хуудаснуудын жагсаалтыг өөрчлөхийн тулд [[Special:Userlogin|нэвтэрсэн байх]] шаардлагатай.',
+'watchnologintext'     => 'Та өөрийн хянаж буй хуудаснуудын жагсаалтыг өөрчлөхийн тулд [[Special:UserLogin|нэвтэрсэн байх]] шаардлагатай.',
 'addedwatch'           => 'Хянах жагсаалтанд нэмэгдлээ',
 'addedwatchtext'       => "\"[[:\$1]]\" гэсэн хуудас таны [[Special:Watchlist|хянах жагсаалтанд]] нэмэгдлээ.
-Энэ хуудас эсвэл түүний хэлэлцүүлгийн хуудас засварлагдахад тэдгээр нь [[Special:Recentchanges|сүүлийн засваруудын жагсаалтад]] '''тодруулалттай''' харагдах болно.",
+Энэ хуудас эсвэл түүний хэлэлцүүлгийн хуудас засварлагдахад тэдгээр нь [[Special:RecentChanges|сүүлийн засваруудын жагсаалтад]] '''тодруулалттай''' харагдах болно.",
 'removedwatch'         => 'Хянах жагсаалтнаас хасагдлаа',
 'removedwatchtext'     => '"[[:$1]]" хуудас нь таны хянаж буй хуудсуудын жагсаалтаас хасагдлаа.',
 'watch'                => 'Хянах',
@@ -1574,7 +1568,7 @@
 'badipaddress'                => 'Хүчингүй IP хаяг',
 'blockipsuccesssub'           => 'Түгжээ амжилттай боллоо.',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] түгжигдсэн.
-<br />Түгжилтийн тоймыг [[Special:Ipblocklist|түгжигдсэн IP-ийн жагсаалт]]аас үзнэ үү.',
+<br />Түгжилтийн тоймыг [[Special:IPBlockList|түгжигдсэн IP-ийн жагсаалт]]аас үзнэ үү.',
 'ipb-edit-dropdown'           => 'Түгжих шалтгаануудыг засварлах',
 'ipb-unblock-addr'            => '$1-н түгжээг тайлах',
 'ipb-unblock'                 => 'Хэрэглэгчийн нэр эсвэл IP хаягийн түгжээг тайлах',
@@ -1606,7 +1600,7 @@
 'blocklogentry'               => '[[$1]] нь $2 $3 хугацаатайгаар түгжигдсэн',
 'blocklogtext'                => 'Энэ нь хэрэглэгчийг түгжсэн болон тайлсан үйлдлийн лог юм.
 Автоматаар түгжигдсэн IP хаягууд жагсаагдаагүй.
-[[Special:Ipblocklist|IP хаягийн түгжээний жагсаалтыг]] харж одоо түгжигдсэн хаягуудыг харна уу.',
+[[Special:IPBlockList|IP хаягийн түгжээний жагсаалтыг]] харж одоо түгжигдсэн хаягуудыг харна уу.',
 'unblocklogentry'             => '$1 идэвхтэй',
 'block-log-flags-anononly'    => 'зөвхөн нэргүй хэрэглэгчид',
 'block-log-flags-nocreate'    => 'Бүртгэл үүсгэх боломжгүй',
@@ -1642,7 +1636,7 @@
 'lockdbsuccesssub'    => 'Мэдээллийн баазыг амжилттайгаар түгжлээ.',
 'unlockdbsuccesssub'  => 'Мэдээллийн сангийн цоожийг авлаа',
 'lockdbsuccesstext'   => 'Мэдээллийн баазыг түгжлээ.
-<br />Та засвараа хийж дууссаны дараа [[Special:Unlockdb|түгжээг тайлах]]аа мартуузай.',
+<br />Та засвараа хийж дууссаны дараа [[Special:UnlockDB|түгжээг тайлах]]аа мартуузай.',
 'unlockdbsuccesstext' => 'Мэдээллийн сангийн цоожийг тайллаа.',
 'lockfilenotwritable' => 'Мэдээллийн сан цоожлоход файл бичигдэхгүй болно. Мэдээллийн санг цоожлох болон тайлах нь файл хуулж болох вэб сервер тусламжтай хийгдэнэ.',
 'databasenotlocked'   => 'Мэдээллийн сан нь түгжигдээгүй байна.',
@@ -1663,8 +1657,6 @@
 
 Эдгээр тохиолдлуудад уг хуудсыг гар аргаар зөөх эсвэл нэгтгэх шаардлагатай болно.",
 'movearticle'             => 'Хуудсыг зөөх:',
-'movenologin'             => 'нэвтрээгүй байна',
-'movenologintext'         => 'Та хуудсыг зөөхийн тулд бүртгэлтэй бөгөөд [[Special:Userlogin|холбогдсон]] байх ёстой.',
 'movenotallowed'          => 'Таньд {{SITENAME}} дээрх хуудсуудыг зөөх зөвшөөрөл байхгүй байна.',
 'newtitle'                => 'Шинээр нэрлэх:',
 'move-watch'              => 'Энэ хуудсыг хянах',
@@ -1685,7 +1677,7 @@
 'movereason'              => 'Шалтгаан:',
 'revertmove'              => 'буцаах',
 'delete_and_move'         => 'Устгах ба Зөөх',
-'delete_and_move_text'    => '==устгахыг шаардав== Энэ "[[$1]]" нь урьд нь оруулсан байна. Та зөөвөрлөлтөнд зам үүсгэхийн тулд устгахыг хүсэж байна уу？',
+'delete_and_move_text'    => '==устгахыг шаардав== Энэ "[[:$1]]" нь урьд нь оруулсан байна. Та зөөвөрлөлтөнд зам үүсгэхийн тулд устгахыг хүсэж байна уу？',
 'delete_and_move_confirm' => 'Тийм, Хуудсыг устгана.',
 'delete_and_move_reason'  => 'зөөвөрлөлтөнд зам үүсгэхийн тулд устгагдсан.',
 'selfmove'                => 'Зөөгдөх гэж байгаа хуудас болон шинээр нэрлэх гэж байгаа хуудасны нэрүүд ижил байна;
@@ -1896,10 +1888,10 @@
 'show-big-image'       => 'Хамгийн сайн чанартай хувилбар',
 'show-big-image-thumb' => '<small>Файлын одоогоор харагдаж буй хэмжээ: $1 × $2 пиксел</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Шинэ файлуудын галерэй',
 'imagelisttext'         => "Доорх нь $2-р ангилсан '''$1''' файлын жагсаалт юм.",
-'newimages-summary'     => 'Энэ тусгай хуудсанд хамгийн сүүлд оруулагдсан файлуудыг үзүүлнэ',
+'newimages-summary'     => 'Энэ тусгай хуудсанд хамгийн сүүлд оруулагдсан файлуудыг үзүүлнэ.',
 'showhidebots'          => '(Роботуудыг $1)',
 'noimages'              => 'Харах юмгүй.',
 'ilsubmit'              => 'Хайлт',
@@ -2061,7 +2053,7 @@
 
 # External editor support
 'edit-externally'      => 'Гадны программыг ашиглан энэ файлыг засварлах',
-'edit-externally-help' => '[http://meta.wikimedia.org/wiki/Help:External_editors Тохируулгын заавраас] дэлгэрэнгүй мэдээллийг авна уу.',
+'edit-externally-help' => '[http://www.mediawiki.org/wiki/Manual:External_editors Тохируулгын заавраас] дэлгэрэнгүй мэдээллийг авна уу.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'Бүгд',
@@ -2103,7 +2095,7 @@
 'recreate'            => 'Дахин үүсгэх',
 
 # HTML dump
-'redirectingto' => '[[$1]]-тэй шууд холбогдсон',
+'redirectingto' => '[[:$1]]-тэй шууд холбогдсон',
 
 # action=purge
 'confirm_purge'        => 'энэ хуудасны нөөц хувилбарыг устгах уу?
@@ -2153,7 +2145,7 @@
 'version-software'         => 'Суулгасан программ',
 'version-software-version' => 'Хувилбар',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'      => 'файлын зам',
 'filepath-page' => 'Файл:',
 
Index: languages/messages/MessagesIs.php
===================================================================
--- languages/messages/MessagesIs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,18 +4,14 @@
  * @ingroup Language
  * @file
  *
+ * @author Cessator
+ * @author Friðrik Bragi Dýrfjörð
+ * @author Jóna Þórunn
+ * @author Krun
  * @author S.Örvarr.S
+ * @author Spacebirdy
  * @author Steinninn
- * @author Jóna Þórunn
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Spacebirdy
- * @author Krun
- * @author Friðrik Bragi Dýrfjörð
- * @author Cessator
- * @author SPQRobin
- * @author M.M.S.
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -502,7 +498,7 @@
 'nosuchaction'      => 'Aðgerð ekki til',
 'nosuchactiontext'  => 'Aðgerðin sem veffangið tilgreinir þekkir er ekki þekkt af wiki',
 'nosuchspecialpage' => 'Kerfissíðan er ekki til',
-'nospecialpagetext' => 'Þú hefur beðið um kerfissíðu sem ekki er til. Listi yfir gildar kerfissíður er að finna á [[Special:Specialpages|kerfissíður]].',
+'nospecialpagetext' => 'Þú hefur beðið um kerfissíðu sem ekki er til. Listi yfir gildar kerfissíður er að finna á [[Special:SpecialPages|kerfissíður]].',
 
 # General errors
 'error'                => 'Villa',
@@ -591,7 +587,7 @@
 'loginproblem'               => '<b>Það kom upp villa í innskráningunni.</b><br />Reyndu aftur!',
 'login'                      => 'Innskrá',
 'nav-login-createaccount'    => 'Innskrá / Búa til aðgang',
-'loginprompt'                => 'Þú verður að leyfa vefkökur til þess að geta skráð þig inn á {{SITENAME}}.',
+'loginprompt'                => 'Þú verður að leyfa vefkökur til þess að geta [[Special:UserLogin|skráð þig inn á {{SITENAME}}]].',
 'userlogin'                  => 'Innskrá / Búa til aðgang',
 'logout'                     => 'Útskráning',
 'userlogout'                 => 'Útskrá',
@@ -738,10 +734,6 @@
 'blockededitsource'                => "Texti '''þinna breytinga''' á '''$1''' eru sýndar að neðan:",
 'whitelistedittitle'               => 'Innskráningar er krafist til að breyta',
 'whitelistedittext'                => 'Þú þarft að $1 til að breyta síðum.',
-'whitelistreadtitle'               => 'Innskráningar er krafist til að lesa',
-'whitelistreadtext'                => 'Þú verður að [[Special:Userlogin|skrá þig inn]] til að lesa síður.',
-'whitelistacctitle'                => 'Þér er óheimilt að búa til aðgang',
-'whitelistacctext'                 => 'Til að geta búið til aðganga á {{SITENAME}} verður þú að [[Special:Userlogin|innskrá]] þig og hafa viðkomandi réttindi.',
 'confirmedittitle'                 => 'Netfang þarf að staðfesta til að breyta',
 'confirmedittext'                  => 'Þú verður að staðfesta netfangið þitt áður en þú getur breytt síðum. Vinsamlegast stilltu og staðfestu netfangið þitt í gegnum [[Special:Preferences|stillingarnar]].',
 'nosuchsectiontitle'               => 'Hluti ekki til',
@@ -756,7 +748,7 @@
 Þú getur búið til síðu með þessu nafni með því að skrifa í formið fyrir neðan
 (meiri upplýsingar í [[{{MediaWiki:Helppage}}|hjálpinni]]).
 Ef þú hefur óvart villst hingað geturðu notað '''til baka'''-hnappinn í vafranum þínum.",
-'anontalkpagetext'                 => "----''Þetta er spjallsíða fyrir óskráðan notanda sem hefur ekki búið til aðgang ennþá eða notar hann ekki, slíkir notendur þekkjast á vistfangi sínu. Það kemur fyrir að margir notendur deili sama vistfangi þannig að athugasemdum sem beint er til eins notanda geta birst á spjallsíðu annars. Vinsamlegast [[Special:Userlogin|skráðu þig sem notanda]] til að koma í veg fyrir slíkan misskilning.''",
+'anontalkpagetext'                 => "----''Þetta er spjallsíða fyrir óskráðan notanda sem hefur ekki búið til aðgang ennþá eða notar hann ekki, slíkir notendur þekkjast á vistfangi sínu. Það kemur fyrir að margir notendur deili sama vistfangi þannig að athugasemdum sem beint er til eins notanda geta birst á spjallsíðu annars. Vinsamlegast [[Special:UserLogin|skráðu þig sem notanda]] til að koma í veg fyrir slíkan misskilning.''",
 'noarticletext'                    => 'Það er enginn texti á þessari síðu en sem komið er, þú getur [[Special:Search/{{PAGENAME}}|leitað í öðrum síðum]] eða [{{fullurl:{{FULLPAGENAMEE}}|action=edit}} breytt henni sjálfur].',
 'clearyourcache'                   => "'''Athugaðu - Eftir vistun, má vera að þú þurfir að komast hjá flýtiminni vafrans þíns til að sjá breytingarnar.''' '''Mozilla / Firefox / Safari:''' haltu niðri ''Shift'' og smelltu á ''Reload,'' eða ýttu á annaðhvort ''Ctrl-F5'' eða ''Ctrl-R'' (''Command-R'' á Macintosh); '''Konqueror: '''smelltu á ''Reload'' eða ýttu á ''F5;'' '''Opera:''' hreinsaðu flýtiminnið í ''Tools → Prefernces;'' '''Internet Explorer:''' haltu niðri ''Ctrl'' og smelltu á ''Refresh,'' eða ýttu á ''Ctrl-F5.''",
 'usercssjsyoucanpreview'           => '<strong>Ath:</strong> Hægt er að nota „Forskoða“ hnappinn til að prófa CSS og JavaScript-kóða áður en hann er vistaður.',
@@ -797,7 +789,7 @@
 'template-semiprotected'           => '(hálfvernduð)',
 'nocreatetitle'                    => 'Síðugerð takmörkuð',
 'nocreatetext'                     => '{{SITENAME}} hefur takmarkað eiginleikann að gera nýjar síður.
-Þú getur farið til baka og breytt núverandi síðum, eða [[Special:Userlogin|skráð þið inn eða búið til aðgang]].',
+Þú getur farið til baka og breytt núverandi síðum, eða [[Special:UserLogin|skráð þið inn eða búið til aðgang]].',
 'nocreate-loggedin'                => 'Þú hefur ekki heimild til að búa til nýjar síður á {{SITENAME}}.',
 'permissionserrors'                => 'Leyfisvillur',
 'permissionserrorstext'            => 'Þú hefur ekki leyfi til að gera þetta, af eftirfarandi {{PLURAL:$1|ástæðu|ástæðum}}:',
@@ -907,6 +899,7 @@
 'search-mwsuggest-enabled'  => 'með uppástungum',
 'search-mwsuggest-disabled' => 'engar uppástungur',
 'search-relatedarticle'     => 'Tengt',
+'mwsuggest-disable'         => 'Gera AJAX-uppástungur óvirkar',
 'searchrelated'             => 'tengt',
 'searchall'                 => 'öllum',
 'showingresults'            => "Sýni {{PLURAL:$1|'''1''' niðurstöðu|'''$1''' niðurstöður}} frá og með #'''$2'''.",
@@ -923,7 +916,7 @@
 'mypreferences'           => 'Stillingar',
 'prefs-edits'             => 'Fjöldi breytinga:',
 'prefsnologin'            => 'Ekki innskráður',
-'prefsnologintext'        => 'Þú þarft að vera [[Special:Userlogin|innskráð(ur)]] til að breyta notandastillingum.',
+'prefsnologintext'        => 'Þú þarft að vera [[Special:UserLogin|innskráð(ur)]] til að breyta notandastillingum.',
 'prefsreset'              => 'Stillingum hefur verið breytt yfir í þær stillingar sem eru í minni.',
 'qbsettings'              => 'Valblað',
 'qbsettings-none'         => 'Sleppa',
@@ -988,7 +981,7 @@
 * Óvalinn reitur þýðir að notandinn er ekki í hópnum.
 * Stjarnan (*) þýðir að þú getur ekki fært hópinn eftir að þú hefur breytt honum, eða öfugt.',
 'userrights-reason'           => 'Ástæða fyrir breytingunni:',
-'userrights-nologin'          => 'Þú verður að [[Special:Userlogin|innskrá]] þig á möppudýraaðgang til að geta útdeilt notandaréttindum.',
+'userrights-nologin'          => 'Þú verður að [[Special:UserLogin|innskrá]] þig á möppudýraaðgang til að geta útdeilt notandaréttindum.',
 'userrights-notallowed'       => 'Þinn aðgangur hefur ekki réttindi til að útdeila notandaréttindum.',
 'userrights-changeable-col'   => 'Hópar sem þú getur breytt',
 'userrights-unchangeable-col' => 'Hópar sem þú getur ekki breytt',
@@ -1075,11 +1068,11 @@
 'reupload'          => 'Hlaða aftur inn',
 'reuploaddesc'      => 'Aftur á innhlaðningarformið.',
 'uploadnologin'     => 'Óinnskráð(ur)',
-'uploadnologintext' => 'Þú verður að vera [[Special:Userlogin|skráð(ur) inn]]
+'uploadnologintext' => 'Þú verður að vera [[Special:UserLogin|skráð(ur) inn]]
 til að hlaða inn skrám.',
 'uploaderror'       => 'Villa í innhlaðningu',
 'uploadtext'        => "Notaðu eyðublaðið hér fyrir neðan til að hlaða upp skrám.
-Farðu á [[Special:Imagelist|skráarlistann]] til að skoða eða leita að áður upphlöðnum skrám, einnig má finna í [[Special:Log/upload|innhlaðningarskránni]] skrár sem hafa verið hlaðið upp og eytt.
+Farðu á [[Special:ImageList|skráarlistann]] til að skoða eða leita að áður upphlöðnum skrám, einnig má finna í [[Special:Log/upload|innhlaðningarskránni]] skrár sem hafa verið hlaðið upp og eytt.
 
 Til að tengja í skrána frá síðu, notaðu eftirfarandi aðferðir
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Skráarheiti.jpg]]</nowiki>''',
@@ -1127,7 +1120,7 @@
 'nolicense'          => 'Ekkert valið',
 'upload_source_file' => '(skrá á tölvunni þinni)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'skrá',
 'imagelist'             => 'Skráalisti',
 'imagelist_date'        => 'Dagsetning',
@@ -1215,7 +1208,7 @@
 Sem gerir að meðaltali '''$5''' breytingar á hverja síðu og '''$6''' skoðanir á hverja breytingu.
 
 Lengdin á [http://www.mediawiki.org/wiki/Manual:Job_queue vinnsluröðinni] er '''$7'''.",
-'userstatstext'          => "Hér {{PLURAL:$1|er '''1''' skráður [[Special:Listusers|notandi]]|eru '''$1''' skráðir [[Special:Listusers|notendur]]}}, þar af '''$2''' (eða '''$4%''') {{PLURAL:$2|hefur|hafa}} $5 stjórnendaréttindi.",
+'userstatstext'          => "Hér {{PLURAL:$1|er '''1''' skráður [[Special:ListUsers|notandi]]|eru '''$1''' skráðir [[Special:ListUsers|notendur]]}}, þar af '''$2''' (eða '''$4%''') {{PLURAL:$2|hefur|hafa}} $5 stjórnendaréttindi.",
 'statistics-mostpopular' => 'Mest skoðuðu síður',
 
 'disambiguations'      => 'Tenglar í aðgreiningarsíður',
@@ -1303,7 +1296,7 @@
 'logempty'             => 'Engin slík aðgerð fannst.',
 'log-title-wildcard'   => 'Leita að titlum sem byrja á þessum texta',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Allar síður',
 'alphaindexline'    => '$1 til $2',
 'nextpage'          => 'Næsta síða ($1)',
@@ -1326,12 +1319,12 @@
 'special-categories-sort-count' => 'raða eftir fjölda',
 'special-categories-sort-abc'   => 'raða eftir stafrófinu',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Sýna notendur sem byrja á:',
 'listusers-submit'   => 'Sýna',
 'listusers-noresult' => 'Enginn notandi fannst.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Notandahópréttindi',
 'listgrouprights-group'    => 'Hópur',
 'listgrouprights-rights'   => 'Réttindi',
@@ -1340,7 +1333,7 @@
 
 # E-mail user
 'mailnologin'     => 'Ekkert netfang til að senda á',
-'mailnologintext' => 'Þú verður að vera [[Special:Userlogin|innskráð(ur)]] auk þess að hafa gilt netfang í [[Special:Preferences|stillingunum]] þínum til að senda tölvupóst til annara notenda.',
+'mailnologintext' => 'Þú verður að vera [[Special:UserLogin|innskráð(ur)]] auk þess að hafa gilt netfang í [[Special:Preferences|stillingunum]] þínum til að senda tölvupóst til annara notenda.',
 'emailuser'       => 'Senda þessum notanda tölvupóst',
 'emailpage'       => 'Senda tölvupóst',
 'emailpagetext'   => 'Hafi notandi þessi fyllt út gild tölvupóstfang í stillingum sínum er hægt að senda póst til hans hér. Póstfangið sem þú fylltir út í stillingum þínum mun birtast í „From:“ hlutanum svo viðtakandinn geti svarað.',
@@ -1363,12 +1356,12 @@
 'nowatchlist'          => 'Vaktlistinn er tómur.',
 'watchlistanontext'    => 'Vinsamlegast $1 til að skoða eða breyta vaktlistanum þínum.',
 'watchnologin'         => 'Óinnskráð(ur)',
-'watchnologintext'     => 'Þú verður að vera [[Special:Userlogin|innskáð(ur)]] til að geta breytt vaktlistanum.',
+'watchnologintext'     => 'Þú verður að vera [[Special:UserLogin|innskáð(ur)]] til að geta breytt vaktlistanum.',
 'addedwatch'           => 'Bætt á vaktlistann',
 'addedwatchtext'       => "Síðunni „[[:$1]]“ hefur verið bætt á [[Special:Watchlist|Vaktlistann]] þinn.
-Frekari breytingar á henni eða spallsíðu hennar munu verða sýndar þar, og síðan mun vera '''feitletruð''' í [[Special:Recentchanges|Nýlegum breytingum]] svo auðveldara sé að finna hana.",
+Frekari breytingar á henni eða spallsíðu hennar munu verða sýndar þar, og síðan mun vera '''feitletruð''' í [[Special:RecentChanges|Nýlegum breytingum]] svo auðveldara sé að finna hana.",
 'removedwatch'         => 'Fjarlægt af vaktlistanum',
-'removedwatchtext'     => 'Síðan „[[:$1]]“ hefur verið fjarlægð af vaktlistanum þínum.',
+'removedwatchtext'     => 'Síðan „[[:$1]]“ hefur verið fjarlægð af [[Special:Watchlist|vaktlistanum þínum]].',
 'watch'                => 'Vakta',
 'watchthispage'        => 'Vakta þessa síðu',
 'unwatch'              => 'Afvakta',
@@ -1445,7 +1438,7 @@
 'rollback-success'            => 'Tók til baka breytingar eftir $1; núverandi $2.',
 'protectlogpage'              => 'Verndunarskrá',
 'protectlogtext'              => 'Fyrir neðan er listi yfir síðuverndanir og -afverndanir.
-Sjáðu [[Special:Protectedpages|listann yfir verndaðar síður]] fyrir núverandi lista yfir verndaðar síður.',
+Sjáðu [[Special:ProtectedPages|listann yfir verndaðar síður]] fyrir núverandi lista yfir verndaðar síður.',
 'protectedarticle'            => 'verndaði „[[$1]]“',
 'modifiedarticleprotection'   => 'breytti verndunarstigi fyrir "[[$1]]"',
 'unprotectedarticle'          => 'afverndaði „[[$1]]“',
@@ -1552,6 +1545,7 @@
 'whatlinkshere-hidetrans'  => '$1 ítengingar',
 'whatlinkshere-hidelinks'  => '$1 tenglar',
 'whatlinkshere-hideimages' => '$1 myndatenglar',
+'whatlinkshere-filters'    => 'Síur',
 
 # Block/unblock
 'blockip'                     => 'Banna notanda',
@@ -1586,7 +1580,7 @@
 'badipaddress'                => 'Ógilt vistfang',
 'blockipsuccesssub'           => 'Bann tókst',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] hefur verið bannaður/bönnuð.<br />
-Sjá [[Special:Ipblocklist|bannaðar notendur og vistföng]] fyrir yfirlit yfir núverandi bönn.',
+Sjá [[Special:IPBlockList|bannaðar notendur og vistföng]] fyrir yfirlit yfir núverandi bönn.',
 'ipb-edit-dropdown'           => 'Breyta ástæðu fyrir banni',
 'ipb-unblock-addr'            => 'Afbanna $1',
 'ipb-unblock'                 => 'Afbanna notanda eða vistfang',
@@ -1619,7 +1613,7 @@
 'blocklogentry'               => 'bannaði „[[$1]]“; rennur út eftir: $2 $3',
 'blocklogtext'                => 'Þetta er skrá yfir bönn sem lögð hafa verið á notendur eða bönn sem hafa verið numin úr gildi.
 Vistföng sem sett hafa verið í bann sjálfvirkt birtast ekki hér.
-Sjá [[Special:Ipblocklist|ítarlegri lista]] fyrir öll núgildandi bönn.',
+Sjá [[Special:IPBlockList|ítarlegri lista]] fyrir öll núgildandi bönn.',
 'unblocklogentry'             => 'afbannaði $1',
 'block-log-flags-anononly'    => 'bara ónefndir notendur',
 'block-log-flags-nocreate'    => 'gerð aðganga bönnuð',
@@ -1643,7 +1637,7 @@
 'lockdbsuccesssub'    => 'Læsing á gagnagrunninum tóks',
 'unlockdbsuccesssub'  => 'Læsing á gagnagrunninum hefur verið fjarlægð',
 'lockdbsuccesstext'   => 'Gagnagrunninum hefur verið læst.<br />
-Mundu að [[Special:Unlockdb|opna hann aftur]] þegar þú hefur lokið viðgerðum.',
+Mundu að [[Special:UnlockDB|opna hann aftur]] þegar þú hefur lokið viðgerðum.',
 'unlockdbsuccesstext' => 'Gagnagrunnurinn hefur verið opnaður.',
 'databasenotlocked'   => 'Gagnagrunnurinn er ekki læstur.',
 
@@ -1672,8 +1666,6 @@
 * Þú veljir að færa hana ekki
 Í þeim tilfellum verður að færa hana handvirkt.',
 'movearticle'             => 'Færa síðu:',
-'movenologin'             => 'Óinnskráð(ur)',
-'movenologintext'         => 'Þú verður að vera [[Special:Userlogin|innskráð(ur)]] til að geta fært síður.',
 'movenotallowed'          => 'Þú hefur ekki leyfi til að færa síður á {{SITENAME}}.',
 'newtitle'                => 'Á nýja titilinn:',
 'move-watch'              => 'Vakta þessa síðu',
@@ -1697,10 +1689,11 @@
 'delete_and_move'         => 'Eyða og flytja',
 'delete_and_move_text'    => '==Beiðni um eyðingu==
 
-Síðan „[[$1]]“ er þegar til. Viltu eyða henni til þess að rýma til fyrir flutningi?',
+Síðan „[[:$1]]“ er þegar til. Viltu eyða henni til þess að rýma til fyrir flutningi?',
 'delete_and_move_confirm' => 'Já, eyða síðunni',
 'delete_and_move_reason'  => 'Eytt til að rýma til fyrir flutning',
 'selfmove'                => 'Nýja nafnið er það sama og gamla, þú verður að velja annað nafn.',
+'fix-double-redirects'    => 'Uppfæra tilvísanir sem vísa á upphaflegan titil',
 
 # Export
 'export'            => 'Flytja út síður',
@@ -1881,10 +1874,10 @@
 'show-big-image'       => 'Mesta upplausn',
 'show-big-image-thumb' => '<small>Myndin er í upplausninni $1 × $2 </small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Myndasafn nýlegra skráa',
 'imagelisttext'         => 'Hér fyrir neðan er {{PLURAL:$1|einni skrá|$1 skrám}} raðað $2.',
-'newimages-summary'     => 'Þessi kerfissíða sýnir nýlega innhlaðnar skrár',
+'newimages-summary'     => 'Þessi kerfissíða sýnir nýlega innhlaðnar skrár.',
 'showhidebots'          => '($1 vélmenni)',
 'noimages'              => 'Ekkert að sjá.',
 'ilsubmit'              => 'Leita',
@@ -1954,7 +1947,7 @@
 
 # External editor support
 'edit-externally'      => 'Breyta þessari skrá með utanaðkomandi hugbúnaði',
-'edit-externally-help' => 'Sjá [http://meta.wikimedia.org/wiki/Help:External_editors leiðbeiningar] fyrir meiri upplýsingar.',
+'edit-externally-help' => 'Sjá [http://www.mediawiki.org/wiki/Manual:External_editors leiðbeiningar] fyrir meiri upplýsingar.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'allt',
@@ -2021,7 +2014,7 @@
 'recreate'            => 'Endurvekja',
 
 # HTML dump
-'redirectingto' => 'Tilvísun á [[$1]]...',
+'redirectingto' => 'Tilvísun á [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Hreinsa skyndiminni þessarar síðu?
@@ -2101,7 +2094,7 @@
 'version-software-product' => 'Vara',
 'version-software-version' => 'Útgáfa',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Slóð skráar',
 'filepath-page'   => 'Skrá:',
 'filepath-submit' => 'Slóð',
@@ -2124,4 +2117,7 @@
 'specialpages-group-users'       => 'Notendur og réttindi',
 'specialpages-group-highuse'     => 'Mest notaðar síður',
 
+# Special:BlankPage
+'blankpage' => 'Tóm síða',
+
 );
Index: languages/messages/MessagesMr.php
===================================================================
--- languages/messages/MessagesMr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,17 +4,15 @@
  * @ingroup Language
  * @file
  *
- * @author Mahitgar
- * @author Kaustubh
- * @author Siebrand
- * @author SPQRobin
- * @author प्रणव कुलकर्णी
  * @author Angela
- * @author Hemanshu
  * @author Harshalhayat
- * @author कोलࣿहापࣿरी
+ * @author Hemanshu
+ * @author Kaustubh
+ * @author Mahitgar
  * @author Sankalpdravid
  * @author अभय नातू
+ * @author कोलࣿहापࣿरी
+ * @author प्रणव कुलकर्णी
  * @author शࣿरीहरि
  */
 
@@ -434,7 +432,7 @@
 'nosuchspecialpage' => 'असे कोणतेही विशेष पृष्ठ अस्तित्वात नाही',
 'nospecialpagetext' => "<big>'''आपण केलेली विनंती अयोग्य विशेषपानासंबंधी आहे.'''</big>
 
-योग्य विशेषपानांची यादी  [[Special:Specialpages|{{int:specialpages}}]] येथे उपलब्ध होऊ शकते.",
+योग्य विशेषपानांची यादी  [[Special:SpecialPages|{{int:specialpages}}]] येथे उपलब्ध होऊ शकते.",
 
 # General errors
 'error'                => 'त्रुटी',
@@ -670,10 +668,6 @@
 'blockededitsource'                => "'''$1'''ला '''तुमची संपादने'''चा मजकुर खाली दाखवला आहे:",
 'whitelistedittitle'               => 'संपादनासाठी सदस्य म्हणून प्रवेश आवश्यक आहे.',
 'whitelistedittext'                => 'लेखांचे संपादन करण्यासाठी आधी $1 करा.',
-'whitelistreadtitle'               => 'हा लेख वाचण्यासाठी सदस्य म्हणून प्रवेश करावा लागेल',
-'whitelistreadtext'                => 'हा लेख वाचण्यासाठी [[Special:Userlogin|सदस्य म्हणून प्रवेश करावा लागेल]].',
-'whitelistacctitle'                => 'आपणास नवीन खात्याची नोंदणी करण्यास मनाई आहे.',
-'whitelistacctext'                 => '{{SITENAME}} नवीन सदस्य नोंदणी करता, तुम्ही [[Special:Userlogin|प्रवेश]] केलेला असणे आवश्यक आहे तसेच तुम्हांला योग्य ते अधिकार असले पाहिजेत.',
 'confirmedittitle'                 => 'संपादनाकरिता विपत्राने शाबीत करणे आवश्यक',
 'confirmedittext'                  => 'तुम्ही संपादने करण्यापुर्वी तुमचा विपत्र पत्ता शाबीत करणे आवश्यक आहे.Please set and validate तुमचा विपत्र पत्ता तुमच्या[[Special:Preferences|सदस्य पसंती]]तून लिहा व सिद्ध करा.',
 'nosuchsectiontitle'               => 'असा विभाग नाही.',
@@ -687,7 +681,7 @@
 'newarticletext'                   => 'तुम्हाला अपेक्षित असलेला लेख अजून लिहिला गेलेला नाही. हा लेख लिहिण्यासाठी खालील पेटीत मजकूर लिहा. मदतीसाठी [[{{MediaWiki:Helppage}}|येथे]] टिचकी द्या.
 
 जर येथे चुकून आला असाल तर ब्राउझरच्या बॅक (back) कळीवर टिचकी द्या.',
-'anontalkpagetext'                 => "---- ''हे बोलपान अशा अज्ञात सदस्यासाठी आहे ज्यांनी खाते तयार केलेले नाही किंवा त्याचा वापर करत नाहीत. त्यांच्या ओळखीसाठी आम्ही आंतरजाल अंकपत्ता वापरतो आहोत. असा अंकपत्ता बर्‍याच लोकांचा एकच असू शकतो जर आपण अज्ञात सदस्य असाल आणि आपल्याला काही अप्रासंगिक संदेश मिळाला असेल तर कृपया [[Special:Userlogin| खाते तयार करा किंवा प्रवेश करा]] ज्यामुळे पुढे असे गैरसमज होणार नाहीत.''",
+'anontalkpagetext'                 => "---- ''हे बोलपान अशा अज्ञात सदस्यासाठी आहे ज्यांनी खाते तयार केलेले नाही किंवा त्याचा वापर करत नाहीत. त्यांच्या ओळखीसाठी आम्ही आंतरजाल अंकपत्ता वापरतो आहोत. असा अंकपत्ता बर्‍याच लोकांचा एकच असू शकतो जर आपण अज्ञात सदस्य असाल आणि आपल्याला काही अप्रासंगिक संदेश मिळाला असेल तर कृपया [[Special:UserLogin| खाते तयार करा किंवा प्रवेश करा]] ज्यामुळे पुढे असे गैरसमज होणार नाहीत.''",
 'noarticletext'                    => 'या लेखात सध्या काहीही मजकूर नाही. तुम्ही विकिपिडीयावरील इतर लेखांमध्ये या [[Special:Search/{{PAGENAME}}|मथळ्याच्या शोध घेऊ शकता]] किंवा हा लेख [{{fullurl:{{FULLPAGENAME}}|action=edit}} लिहू शकता].',
 'userpage-userdoesnotexist'        => '"$1" सदस्य खाते नोंदीकॄत नाही.कृपया हे पान तुम्ही संपादीत किंवा नव्याने तयार करू इच्छिता का या बद्दल विचार करा.',
 'clearyourcache'                   => "'''सूचना:''' जतन केल्यानंतर, बदल पहाण्याकरिता तुम्हाला तुमच्या विचरकाची सय टाळायला लागू शकते. '''मोझील्ला/फायरफॉक्स /सफारी:''' ''Reload''करताना ''Shift''दाबून ठेवा किंवा ''Ctrl-Shift-R'' दाबा
@@ -743,7 +737,7 @@
 'template-semiprotected'           => '(अर्ध-सुरक्षीत)',
 'hiddencategories'                 => 'हे पान खालील {{PLURAL:$1|एका लपविलेल्या वर्गामध्ये|$1 लपविलेल्या वर्गांमध्ये}} आहे:',
 'nocreatetitle'                    => 'पान निर्मीतीस मर्यादा',
-'nocreatetext'                     => '{{SITENAME}}वर नवीन लेख लिहिण्यास मज्जाव करण्यात आलेला आहे. आपण परत जाऊन अस्तित्वात असलेल्या लेखांचे संपादन करू शकता अथवा [[Special:Userlogin|नवीन सदस्यत्व घ्या/ प्रवेश करा]].',
+'nocreatetext'                     => '{{SITENAME}}वर नवीन लेख लिहिण्यास मज्जाव करण्यात आलेला आहे. आपण परत जाऊन अस्तित्वात असलेल्या लेखांचे संपादन करू शकता अथवा [[Special:UserLogin|नवीन सदस्यत्व घ्या/ प्रवेश करा]].',
 'nocreate-loggedin'                => '{{SITENAME}}वर तुम्हाला नवीन पाने बनवण्याची परवानगी नाही.',
 'permissionserrors'                => 'परवानगीतील त्रूटी',
 'permissionserrorstext'            => 'खालील{{PLURAL:$1|कारणामुळे|कारणांमुळे}} तुम्हाला तसे करण्याची परवानगी नाही:',
@@ -865,7 +859,7 @@
 
 # Suppression log
 'suppressionlog'     => 'सप्रेशन नोंद',
-'suppressionlogtext' => 'खाली सर्वात अलीकडील ब्लॉक तसेच प्रबंधकांपासून लपविलेला मजकूर वगळण्याची यादी आहे. सध्या अस्तित्वात असेलेले प्रतिबंध पाहण्यासाठी [[Special:Ipblocklist|IP ब्लॉक यादी]] पहा.',
+'suppressionlogtext' => 'खाली सर्वात अलीकडील ब्लॉक तसेच प्रबंधकांपासून लपविलेला मजकूर वगळण्याची यादी आहे. सध्या अस्तित्वात असेलेले प्रतिबंध पाहण्यासाठी [[Special:IPBlockList|IP ब्लॉक यादी]] पहा.',
 
 # History merging
 'mergehistory'                     => 'पान ईतिहासांचे एकत्रिकरण करा',
@@ -948,7 +942,7 @@
 'mypreferences'            => 'माझ्या पसंती',
 'prefs-edits'              => 'संपादनांची संख्या:',
 'prefsnologin'             => 'प्रवेश केलेला नाही',
-'prefsnologintext'         => 'सदस्य पसंती बदलण्यासाठी [[Special:Userlogin|प्रवेश]] करावा लागेल.',
+'prefsnologintext'         => 'सदस्य पसंती बदलण्यासाठी [[Special:UserLogin|प्रवेश]] करावा लागेल.',
 'prefsreset'               => 'पसंती पूर्ववत करण्यात आल्या आहेत.',
 'qbsettings'               => 'शीघ्रपट',
 'qbsettings-none'          => 'नाही',
@@ -1022,7 +1016,7 @@
 'userrights-reason'           => 'बदलाचे कारण:',
 'userrights-no-interwiki'     => 'इतर विकींवरचे सदस्य अधिकार बदलण्याची परवानगी तुम्हाला नाही.',
 'userrights-nodatabase'       => 'विदा $1 अस्तीत्वात नाही अथवा स्थानिक नाही.',
-'userrights-nologin'          => 'सदस्य अधिकार देण्यासाठी तुम्ही प्रबंधक म्हणून [[Special:Userlogin|प्रवेश केलेला]] असणे आवश्यक आहे.',
+'userrights-nologin'          => 'सदस्य अधिकार देण्यासाठी तुम्ही प्रबंधक म्हणून [[Special:UserLogin|प्रवेश केलेला]] असणे आवश्यक आहे.',
 'userrights-notallowed'       => 'तुमच्या सदस्य खात्यास सदस्य अधिकारांची निश्चिती करण्याची परवानगी नाही.',
 'userrights-changeable-col'   => 'गट जे तुम्ही बदलू शकता',
 'userrights-unchangeable-col' => 'गट जे तुम्ही बदलू शकत नाही',
@@ -1152,12 +1146,12 @@
 'reupload'                    => 'पुन्हा चढवा',
 'reuploaddesc'                => 'चढवायच्या पानाकडे परता',
 'uploadnologin'               => 'प्रवेश केलेला नाही',
-'uploadnologintext'           => 'संचिका चढविण्यासाठी तुम्हाला [[Special:Userlogin|प्रवेश]] करावा लागेल.',
+'uploadnologintext'           => 'संचिका चढविण्यासाठी तुम्हाला [[Special:UserLogin|प्रवेश]] करावा लागेल.',
 'upload_directory_missing'    => 'अपलोड डिरेक्टरी ($1) सापडली नाही तसेच वेबसर्व्हर ती तयार करू शकलेला नाही.',
 'upload_directory_read_only'  => '$1 या डिरेक्टरी मध्ये सर्व्हर लिहू शकत नाही.',
 'uploaderror'                 => 'चढवण्यात चुक',
 'uploadtext'                  => "खालील अर्ज नवीन संचिका चढविण्यासाठी वापरा.
-पूर्वी चढविलेल्या संचिका पाहण्यासाठी अथवा शोधण्यासाठी [[Special:Imagelist|चढविलेल्या संचिकांची यादी]] पहा. चढविलेल्या तसेच वगळलेल्या संचिकांची यादी पहाण्यासाठी [[Special:Log/upload|सूची]] पहा.
+पूर्वी चढविलेल्या संचिका पाहण्यासाठी अथवा शोधण्यासाठी [[Special:ImageList|चढविलेल्या संचिकांची यादी]] पहा. चढविलेल्या तसेच वगळलेल्या संचिकांची यादी पहाण्यासाठी [[Special:Log/upload|सूची]] पहा.
 
 एखाद्या लेखात ही संचिका वापरण्यासाठी खालीलप्रमाणे दुवा द्या
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1242,7 +1236,7 @@
 'upload_source_url'  => '(एक सुयोग्य,सार्वजनिकरित्या उपलब्ध URL)',
 'upload_source_file' => '(तुमच्या संगणकावरील एक संचिका)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'हे विशेष पान सर्व चढविलेल्या संचिका दर्शिविते.
 सर्वसाधारणपणे सगळ्यात शेवटी बदल झालेल्या संचिका सर्वात वर दिसतात.
 रकान्याच्या नावापुढे टिचकी देऊन संचिकांचा अनुक्रम बदलता येतो.',
@@ -1270,7 +1264,7 @@
 'imagelinks'                     => 'चित्र दुवे',
 'linkstoimage'                   => 'खालील पाने या चित्राशी जोडली आहेत:',
 'nolinkstoimage'                 => 'या चित्राशी जोडलेली पृष्ठे नाही आहेत.',
-'morelinkstoimage'               => 'या संचिकेचे [[Special:Whatlinkshere/$1|अधिक दुवे]] पहा.',
+'morelinkstoimage'               => 'या संचिकेचे [[Special:WhatLinksHere/$1|अधिक दुवे]] पहा.',
 'redirectstofile'                => 'खालील संचिका या संचिकेकडे पुनर्निर्देशन करतात:',
 'duplicatesoffile'               => 'खालील संचिका या दिलेल्या संचिकेच्या प्रती आहेत:',
 'sharedupload'                   => 'ही संचिका इतरही प्रकल्पांमध्ये वापरली गेल्याची शक्यता आहे.',
@@ -1289,18 +1283,18 @@
 # File reversion
 'filerevert'                => '$1 पूर्वपद',
 'filerevert-legend'         => 'संचिका पूर्वपदास',
-'filerevert-intro'          => '<span class="plainlinks">तुम्ही [$3, $2 प्रमाणे आवर्तन$4 कडे] [[Media:$1|$1]]  उलटवत आहात.</span>',
+'filerevert-intro'          => 'तुम्ही [$3, $2 प्रमाणे आवर्तन$4 कडे] [[Media:$1|$1]]  उलटवत आहात.',
 'filerevert-comment'        => 'प्रतिक्रीया:',
 'filerevert-defaultcomment' => '$2, $1 च्या आवृत्तीत पूर्वपदास',
 'filerevert-submit'         => 'पूर्वपद',
-'filerevert-success'        => '<span class="plainlinks"> [$3, $2 प्रमाणे आवर्तन $4]कडे \'\'\'[[Media:$1|$1]]\'\'\' उलटवण्यात आली.</span>',
+'filerevert-success'        => "[$3, $2 प्रमाणे आवर्तन $4]कडे '''[[Media:$1|$1]]''' उलटवण्यात आली.",
 'filerevert-badversion'     => 'दिलेलेल्या वेळ मापनानुसार,या संचिकेकरिता कोणतीही पूर्वीची स्थानिक आवृत्ती नाही.',
 
 # File deletion
 'filedelete'                  => '$1 वगळा',
 'filedelete-legend'           => 'संचिका वगळा',
 'filedelete-intro'            => "तुम्ही '''[[Media:$1|$1]]''' वगळत आहात.",
-'filedelete-intro-old'        => '<span class="plainlinks">[$4 $3, $2]च्या वेळेचे \'\'\'[[Media:$1|$1]]\'\'\'चे आवर्तन तुम्ही वगळत आहात.</span>',
+'filedelete-intro-old'        => "[$4 $3, $2]च्या वेळेचे '''[[Media:$1|$1]]'''चे आवर्तन तुम्ही वगळत आहात.",
 'filedelete-comment'          => 'वगळ्ण्याची कारणे:',
 'filedelete-submit'           => 'वगळा',
 'filedelete-success'          => "'''$1'''वगळण्यात आले.",
@@ -1355,7 +1349,7 @@
 त्याची सरासरी संपादने  '''$5'''प्रतिपान,आणि '''$6''' भेटी प्रति संपादन.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]लांबी'''$7'''आहे.",
-'userstatstext'          => "सध्या {{PLURAL:$1|is '''1''' registered [[Special:Listusers|user]]| '''$1''' नोंदीकृत  [[Special:Listusers|सदस्य]]}} आहेत, पैकी'''$2''' (किंवा '''$4%''')सदस्यांना $5 अधिकार {{PLURAL:$2|आहे|आहेत }} .",
+'userstatstext'          => "सध्या {{PLURAL:$1|is '''1''' registered [[Special:ListUsers|user]]| '''$1''' नोंदीकृत  [[Special:ListUsers|सदस्य]]}} आहेत, पैकी'''$2''' (किंवा '''$4%''')सदस्यांना $5 अधिकार {{PLURAL:$2|आहे|आहेत }} .",
 'statistics-mostpopular' => 'सर्वाधिक बघितली जाणारी पाने',
 
 'disambiguations'      => 'नि:संदिग्धकरण पृष्ठे',
@@ -1448,7 +1442,7 @@
 'logempty'             => 'नोंदीत अशी बाब नाही.',
 'log-title-wildcard'   => 'या मजकुरापासून सुरू होणारी शिर्षके शोधा.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'सर्व पृष्ठे',
 'alphaindexline'    => '$1 पासून $2 पर्यंत',
 'nextpage'          => 'पुढील पान ($1)',
@@ -1471,12 +1465,12 @@
 'special-categories-sort-count' => 'क्रमानुसार लावा',
 'special-categories-sort-abc'   => 'अक्षरांप्रमाणे लावा',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'पुढील शब्दापासुन सुरू होणारे सदस्य दाखवा:',
 'listusers-submit'   => 'दाखवा',
 'listusers-noresult' => 'एकही सदस्य सापडला नाही.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'सदस्य गट अधिकार',
 'listgrouprights-summary'  => 'खाली या विकिवर दिलेली सदस्य गटांची यादी त्यांच्या अधिकारांसकट दर्शविलेली आहे. प्रत्येकाच्या अधिकारांची अधिक माहिती [[{{MediaWiki:Listgrouprights-helppage}}|इथे]] दिलेली आहे.',
 'listgrouprights-group'    => 'गट',
@@ -1486,7 +1480,7 @@
 
 # E-mail user
 'mailnologin'     => 'पाठविण्याचा पत्ता नाही',
-'mailnologintext' => 'इतर सदस्यांना विपत्र(ईमेल) पाठवण्याकरिता तुम्ही [[Special:Userlogin|प्रवेश केलेला]] असणे आणि  शाबीत विपत्र पत्ता तुमच्या [[Special:Preferences|पसंतीत]] नमुद असणे आवश्यक आहे.',
+'mailnologintext' => 'इतर सदस्यांना विपत्र(ईमेल) पाठवण्याकरिता तुम्ही [[Special:UserLogin|प्रवेश केलेला]] असणे आणि  शाबीत विपत्र पत्ता तुमच्या [[Special:Preferences|पसंतीत]] नमुद असणे आवश्यक आहे.',
 'emailuser'       => 'या सदस्याला इमेल पाठवा',
 'emailpage'       => 'विपत्र (ईमेल) उपयोगकर्ता',
 'emailpagetext'   => 'जर या सदस्याने शाबीत विपत्र (ईमेल)पत्ता तीच्या अथवा त्याच्या सदस्य पसंतीत नमुद केला असेल,तर खालील सारणी तुम्हाला एक(च) संदेश पाठवेल.तुम्ही तुमच्या सदस्य पसंतीत नमुद केलेला विपत्र पत्ता "कडून" पत्त्यात येईल म्हणजे  प्राप्तकरता आपल्याला उत्तर देऊ शकेल.',
@@ -1511,9 +1505,9 @@
 'nowatchlist'          => 'तुमची पहार्‍याची सूची रिकामी आहे.',
 'watchlistanontext'    => 'तुमच्या पहार्‍याच्या सूचीतील बाबी पाहण्याकरता किंवा संपादित करण्याकरता, कृपया $1.',
 'watchnologin'         => 'प्रवेश केलेला नाही',
-'watchnologintext'     => 'तुमची पहार्‍याची सूची बदलावयाची असेल तर तुम्ही [[Special:Userlogin|प्रवेश केलेला]] असलाच पाहीजे.',
+'watchnologintext'     => 'तुमची पहार्‍याची सूची बदलावयाची असेल तर तुम्ही [[Special:UserLogin|प्रवेश केलेला]] असलाच पाहीजे.',
 'addedwatch'           => 'हे पान पहार्‍याच्या सूचीत घातले.',
-'addedwatchtext'       => '"[[:$1]]"  हे पान तुमच्या  [[Special:Watchlist|पहार्‍याच्या सूचीत]] टाकले आहे. या पानावरील तसेच त्याच्या चर्चा पानावरील पुढील बदल येथे दाखवले जातील, आणि   [[Special:Recentchanges|अलीकडील बदलांमध्ये]] पान ठळक दिसेल.
+'addedwatchtext'       => '"[[:$1]]"  हे पान तुमच्या  [[Special:Watchlist|पहार्‍याच्या सूचीत]] टाकले आहे. या पानावरील तसेच त्याच्या चर्चा पानावरील पुढील बदल येथे दाखवले जातील, आणि   [[Special:RecentChanges|अलीकडील बदलांमध्ये]] पान ठळक दिसेल.
 
 पहार्‍याच्या सूचीतून पान काढायचे असेल तर "पहारा काढा" वर टिचकी द्या.',
 'removedwatch'         => 'पहार्‍याच्या सूचीतून वगळले',
@@ -1623,7 +1617,7 @@
 'rollback-success'            => '$1 ने उलटवलेली संपादने;$2 च्या आवृत्तीस परत नेली.',
 'sessionfailure'              => 'तुमच्या दाखल सत्रात काही समस्या दिसते;सत्र अपहारणा पासून काळजी घेण्याच्या दृष्टीने ही कृती रद्द केली गेली आहे.कपया आपल्या विचरकाच्या "back" कळीवर टिचकी मारा आणि तुम्ही ज्या पानावरून आला ते पुन्हा चढवा,आणि प्रत प्रयत्न करा.',
 'protectlogpage'              => 'सुरक्षा नोंदी',
-'protectlogtext'              => 'पानांना लावलेल्या ताळ्यांची आणि ताळे उघडण्याबद्दलच्या पानाची खाली सूची दिली आहे.सध्याच्या सुरक्षीत पानांबद्दलच्या माहितीकरिता [[Special:Protectedpages|सुरक्षीत पानांची सूची]] पहा.',
+'protectlogtext'              => 'पानांना लावलेल्या ताळ्यांची आणि ताळे उघडण्याबद्दलच्या पानाची खाली सूची दिली आहे.सध्याच्या सुरक्षीत पानांबद्दलच्या माहितीकरिता [[Special:ProtectedPages|सुरक्षीत पानांची सूची]] पहा.',
 'protectedarticle'            => '"[[$1]]" सुरक्षित केला',
 'modifiedarticleprotection'   => '"[[$1]]"करिता सुरक्षापातळी बदलली',
 'unprotectedarticle'          => '"[[$1]]" असुरक्षित केला.',
@@ -1781,7 +1775,7 @@
 'badipaddress'                => 'अंकपत्ता बरोबर नाही.',
 'blockipsuccesssub'           => 'अडवणूक यशस्वी झाली',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]ला प्रतिबंधीत केले.<br />
-प्रतिबंधनांचा आढावा घेण्याकरिता [[Special:Ipblocklist|अंकपत्ता प्रतिबंधन सूची]] पहा.',
+प्रतिबंधनांचा आढावा घेण्याकरिता [[Special:IPBlockList|अंकपत्ता प्रतिबंधन सूची]] पहा.',
 'ipb-edit-dropdown'           => 'प्रतिबंधाची कारणे संपादा',
 'ipb-unblock-addr'            => '$1चा प्रतिबंध उठवा',
 'ipb-unblock'                 => 'सदस्यनाव आणि अंकपत्त्यावरचे प्रतिबंधन उठवा',
@@ -1813,7 +1807,7 @@
 'blocklogentry'               => '[[$1]] ला $2 $3 पर्यंत ब्लॉक केलेले आहे',
 'blocklogtext'                => 'ही सदस्यांच्या प्रतिबंधनाची आणि प्रतिबंधने उठवल्याची नोंद आहे.
 आपोआप प्रतिबंधीत केलेले अंकपत्ते नमूद केलेले नाहीत.
-सध्या लागू असलेली बंदी व प्रतिबंधनांच्या यादीकरिता [[Special:Ipblocklist|अंकपत्ता प्रतिबंधन सूची]] पहा.',
+सध्या लागू असलेली बंदी व प्रतिबंधनांच्या यादीकरिता [[Special:IPBlockList|अंकपत्ता प्रतिबंधन सूची]] पहा.',
 'unblocklogentry'             => 'प्रतिबंधन $1 हटवले',
 'block-log-flags-anononly'    => 'केवळ अनामिक सदस्य',
 'block-log-flags-nocreate'    => 'खाते तयारकरणे अवरूद्ध केले',
@@ -1849,7 +1843,7 @@
 'lockdbsuccesssub'    => 'विदागरास ताळे यशस्वी',
 'unlockdbsuccesssub'  => 'विदागाराचे ताळे काढले',
 'lockdbsuccesstext'   => 'विदागारास ताळे ठोकण्यात आले आहे.<br />
-तुमच्याकडून भरण-पोषण पूर्ण झाल्या नंतर [[Special:Unlockdb|ताळे उघडण्याचे]] लक्षात ठेवा.',
+तुमच्याकडून भरण-पोषण पूर्ण झाल्या नंतर [[Special:UnlockDB|ताळे उघडण्याचे]] लक्षात ठेवा.',
 'unlockdbsuccesstext' => 'विदागाराचे ताळे उघडण्यात आले आहे.',
 'lockfilenotwritable' => 'विदा ताळे संचिका लेखनीय नाही.विदेस ताळे लावण्याकरिता किंवा उघडण्याकरिता, ती आंतरजाल विदादात्याकडून लेखनीय असावयास हवी.',
 'databasenotlocked'   => 'विदागारास ताळे नही',
@@ -1875,8 +1869,6 @@
 
 या बाबतीत तुम्हाला स्वतःला ही पाने एकत्र करावी लागतील.",
 'movearticle'             => 'पृष्ठाचे स्थानांतरण',
-'movenologin'             => 'प्रवेश केलेला नाही',
-'movenologintext'         => 'पान स्थानांतरित करण्यासाठी तुम्हाला [[Special:Userlogin|प्रवेश]] करावा लागेल.',
 'movenotallowed'          => '{{SITENAME}}वरील पाने स्थानांतरीत करण्याची आपल्यापाशी परवानगी नाही.',
 'newtitle'                => 'नवीन शीर्षकाकडे:',
 'move-watch'              => 'या पानावर लक्ष ठेवा',
@@ -1906,7 +1898,7 @@
 'delete_and_move'         => 'वगळा आणि स्थानांतरित करा',
 'delete_and_move_text'    => '==वगळण्याची आवशकता==
 
-लक्ष्यपान  "[[$1]]" आधीच अस्तीत्वात आहे.स्थानांतराचा मार्ग मोकळाकरण्या करिता तुम्हाला ते वगळावयाचे आहे काय?',
+लक्ष्यपान  "[[:$1]]" आधीच अस्तीत्वात आहे.स्थानांतराचा मार्ग मोकळाकरण्या करिता तुम्हाला ते वगळावयाचे आहे काय?',
 'delete_and_move_confirm' => 'होय, पान वगळा',
 'delete_and_move_reason'  => 'आधीचे पान वगळून स्थानांतर केले',
 'selfmove'                => 'स्रोत आणि लक्ष्य पाने समान आहेत; एखादे पान स्वत:च्याच जागी स्थानांतरीत करता येत नाही.',
@@ -2131,7 +2123,7 @@
 'show-big-image'       => 'संपूर्ण रिजोल्यूशन',
 'show-big-image-thumb' => '<small>या झलकेचा आकार: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'नवीन संचिकांची यादी',
 'imagelisttext'         => "खाली '''$1''' संचिका {{PLURAL:$1|दिली आहे.|$2 क्रमाने दिल्या आहेत.}}",
 'newimages-summary'     => 'हे विशेष पान शेवटी चढविलेल्या संचिका दर्शविते',
@@ -2413,7 +2405,7 @@
 
 # External editor support
 'edit-externally'      => 'बाहेरील संगणक प्रणाली वापरून ही संचिका संपादा.',
-'edit-externally-help' => 'अधिक माहितीसाठी [http://meta.wikimedia.org/wiki/Help:External_editors स्थापन करण्याच्या सूचना] पहा.',
+'edit-externally-help' => 'अधिक माहितीसाठी [http://www.mediawiki.org/wiki/Manual:External_editors स्थापन करण्याच्या सूचना] पहा.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'सर्व',
@@ -2473,7 +2465,7 @@
 'recreate'            => 'पुनर्निर्माण',
 
 # HTML dump
-'redirectingto' => '[[$1]]कडे पुनर्निर्देशीत...',
+'redirectingto' => '[[:$1]]कडे पुनर्निर्देशीत...',
 
 # action=purge
 'confirm_purge'        => 'यापानाची सय रिकामी करावयाची आहे?
@@ -2569,7 +2561,7 @@
 'version-software-product'         => 'उत्पादन',
 'version-software-version'         => 'आवृत्ती(Version)',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'संचिका मार्ग',
 'filepath-page'    => 'संचिका:',
 'filepath-submit'  => 'मार्ग',
Index: languages/messages/MessagesLfn.php
===================================================================
--- languages/messages/MessagesLfn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLfn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Cgboeree
  * @author Malafaya
- * @author Siebrand
- * @author SPQRobin
  */
 
 $messages = array(
@@ -365,7 +363,7 @@
 'template-protected'     => '(protejeda)',
 'template-semiprotected' => '(proteje en parte)',
 'nocreatetext'           => '{{SITENAME}} ave un restringe a la capas per crea pajes nova.
-Tu pote vade a retro e edita un paje esistente, o  [[Special:Userlogin|sinia per entra o crea un conta]].',
+Tu pote vade a retro e edita un paje esistente, o  [[Special:UserLogin|sinia per entra o crea un conta]].',
 'recreate-deleted-warn'  => "'''Avisa: Tu es recrea un paje ce ia es sutraed en la pasada.'''
 Tu debe pensa ce es bon continua edita esta paje.
 La arcivo de sutraes per esta paje es asi per conveni:",
@@ -485,7 +483,7 @@
 
 'upload-file-error' => 'Era interna',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'fix',
 'imagelist'      => 'Lista de imajes',
 'imagelist_name' => 'Nom',
@@ -579,7 +577,7 @@
 'all-logs-page'        => 'Tota catalogos',
 'log-search-submit'    => 'Vade',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Tota pajes',
 'alphaindexline' => '$1 a $2',
 'nextpage'       => 'Paje seguente ($1)',
@@ -595,7 +593,7 @@
 'categories'         => 'Categorias',
 'categoriespagetext' => 'Es la categorias seguente en la vici.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group' => 'Grupo',
 
 # E-mail user
@@ -610,7 +608,7 @@
 'nowatchlist'          => 'Tu ave no cosas en tu lista oservada',
 'addedwatch'           => 'Juntada a la lista de pajes oservada',
 'addedwatchtext'       => "La paje \"[[:\$1]]\" ia es juntada a tu [[Special:Watchlist|lista de pajes oservada]].
-Cambias future a esta paje e se paje de discutes va es listada ala, e la paje va apera en leteras '''forte''' en la [[Special:Recentchanges|lista de cambias resente]] per es plu fasil oservada.
+Cambias future a esta paje e se paje de discutes va es listada ala, e la paje va apera en leteras '''forte''' en la [[Special:RecentChanges|lista de cambias resente]] per es plu fasil oservada.
 
 Si tu vole sutrae la paje de tu lista de pajes oservada en la futur, clica a \"no oserva\" en la bara a la lado.",
 'removedwatch'         => 'Sutraeda de la lista de pajes oservada',
@@ -829,7 +827,7 @@
 'show-big-image'       => 'Densia masima',
 'show-big-image-thumb' => '<small>Grandia de eesta previde: $1 × $2 pixeles</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Imajes nova',
 'ilsubmit'  => 'Xerca',
 
@@ -859,7 +857,7 @@
 
 # External editor support
 'edit-externally'      => 'Edita esta fix con un programa esterna',
-'edit-externally-help' => 'Vide la [http://meta.wikimedia.org/wiki/Help:External_editors instruis per comensa] per plu instruis.',
+'edit-externally-help' => 'Vide la [http://www.mediawiki.org/wiki/Manual:External_editors instruis per comensa] per plu instruis.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'tota',
Index: languages/messages/MessagesPfl.php
===================================================================
--- languages/messages/MessagesPfl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPfl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -112,7 +112,7 @@
 # Miscellaneous special pages
 'move' => 'Verschiewe',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Zeiche',
 
 # E-mail user
@@ -165,7 +165,7 @@
 # Special:Import
 'import-interwiki-submit' => 'Impordiere',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Such',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesTyv.php
===================================================================
--- languages/messages/MessagesTyv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTyv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Sborsody
- * @author Siebrand
- * @author לערי ריינהארט
  * @author Krice from Tyvanet.com
+ * @author Sborsody
  * @author friends at tyvawiki.org
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -418,7 +417,7 @@
 'upload-file-error' => 'Иштики алдаг',
 'upload-misc-error' => 'Билбес кииреринге алдаг',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'файл',
 'imagelist'             => 'Файл даңзызы',
 'imagelist_name'        => 'Ат',
@@ -508,7 +507,7 @@
 'speciallogtitlelabel' => 'Ат:',
 'log-search-submit'    => 'Чоруур',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Шупту арыннар',
 'nextpage'       => 'Соонда арын ($1)',
 'prevpage'       => 'Бүрүнгү арын ($1)',
@@ -520,7 +519,7 @@
 # Special:Categories
 'categories' => 'Бөлүктер',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Көргүзер',
 
 # E-mail user
@@ -668,7 +667,7 @@
 'previousdiff' => '← Бүрүнгү ылгал',
 'nextdiff'     => 'Соонда ылгал →',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '(боцду $1)',
 'noimages'     => 'Чуруклар чок.',
 'ilsubmit'     => 'Дилээр',
Index: languages/messages/MessagesShi.php
===================================================================
--- languages/messages/MessagesShi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesShi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Zanatos
- * @author Siebrand
  */
 
 $fallback = 'ar';
@@ -179,7 +178,7 @@
 # Upload
 'upload' => 'sΥlid afaylu',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 ar $2',
 
 # Special:Categories
Index: languages/messages/MessagesIlo.php
===================================================================
--- languages/messages/MessagesIlo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIlo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Saluyot
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Siebrand
  */
 
 $messages = array(
@@ -281,7 +279,7 @@
 'nosuchspecialpage' => 'Awan ti kasta a naiduma a panid',
 'nospecialpagetext' => "<big>'''Saan a mabalin ti kiniddawmo a naiduma a panid.'''</big>
 
-Masarakan ti listaan dagiti mabalin a a naiduma a pampanid iti [[Special:Specialpages|{{int:specialpages}}]].",
+Masarakan ti listaan dagiti mabalin a a naiduma a pampanid iti [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Biddut',
@@ -481,10 +479,6 @@
 'blockededitsource'                => "Makita iti baba '''dagiti panangbalbaliwmo''' iti '''$1''':",
 'whitelistedittitle'               => 'Masapul a nakastrekka tapno makaeditka',
 'whitelistedittext'                => 'Nasken a $1 ka tapno makaeditka iti pampanid.',
-'whitelistreadtitle'               => 'Masapul a nakastrekka tapno makabasaka',
-'whitelistreadtext'                => 'Masapul a [[Special:Userlogin|sumrekka]] tapno makabasaka iti pampanid.',
-'whitelistacctitle'                => 'Saanka a mapalubosan a mangaramid iti account',
-'whitelistacctext'                 => 'Tapno mapalubosanka a mangaramid iti accounts iti {{SITENAME}} masapul a [[Special:Userlogin|sumrekka]] ken maaddaan kadagiti mainugot a pammalubos.',
 'confirmedittitle'                 => 'Masapul ti pammasingked ti email tapno makaedit',
 'nosuchsectiontitle'               => 'Awan ti kasta a benneg',
 'nosuchsectiontext'                => 'Pinadasmo nga editen ti maysa a benneg nga awan pay.
@@ -530,7 +524,7 @@
 'hiddencategories'                 => 'Daytoy a panid ket kameng ti {{PLURAL:$1|1 a nakalemmeng a categoria|$1 a nakalemmeng a catcategoria}}:',
 'nocreatetitle'                    => 'Limitado ti panagaramid iti panid',
 'nocreatetext'                     => 'Pinaritan ti {{SITENAME}} ti kabalinan a makapartuat iti kabarbaro a pampanid.
-Mabalinmo ti agsubli ken agedit iti adda a panid, wenno [[Special:Userlogin|sumrek wenno mangaramid iti account]].',
+Mabalinmo ti agsubli ken agedit iti adda a panid, wenno [[Special:UserLogin|sumrek wenno mangaramid iti account]].',
 'nocreate-loggedin'                => 'Awananka iti pammalubos a mangaramid iti kabarbaro a pampanid iti {{SITENAME}}.',
 'permissionserrors'                => 'Bidbiddut iti Pammalubos',
 'permissionserrorstext'            => 'Awananka iti pammalubos a mangaramid iti dayta, gapu iti sumaganad a {{PLURAL:$1|rason|rasrason}}:',
@@ -820,7 +814,7 @@
 'uploadbtn'              => 'Ipan ti file',
 'reupload'               => 'I-upload manen',
 'uploadnologin'          => 'Saan a nakastrek',
-'uploadnologintext'      => 'Nasken a [[Special:Userlogin|nakaserrekka]] tapno makaipanka iti files.',
+'uploadnologintext'      => 'Nasken a [[Special:UserLogin|nakaserrekka]] tapno makaipanka iti files.',
 'uploaderror'            => 'Kammali iti panangipan',
 'upload-permitted'       => 'Dagiti mapalubosan a tipo ti file: $1.',
 'upload-preferred'       => 'Dagiti mabalbalin a file types: $1.',
@@ -870,7 +864,7 @@
 'upload_source_url'  => ' (maysa a valido, ken maakses ti publico nga URL)',
 'upload_source_file' => ' (file iti kompiutermo)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Agsapul iti nagan ti media:',
 'imgfile'               => 'file',
 'imagelist'             => 'Listaan ti file',
@@ -895,7 +889,7 @@
 'imagelinks'                     => 'Dagiti kasilpo',
 'linkstoimage'                   => 'Dagiti sumaganad a panid ket nakasilpo itoy a file:',
 'nolinkstoimage'                 => 'Awan ti pampanid a nakasilpo iti daytoy a file.',
-'morelinkstoimage'               => 'Kitaen ti [[Special:Whatlinkshere/$1|ad-adu pay a panilpo]] kadaytoy a file.',
+'morelinkstoimage'               => 'Kitaen ti [[Special:WhatLinksHere/$1|ad-adu pay a panilpo]] kadaytoy a file.',
 'redirectstofile'                => 'Dagiti sumaganad a files ket ag-redirect iti daytoy a file:',
 'duplicatesoffile'               => 'Dagiti sumaganad a files ket duplikado daytoy a file:',
 'sharedupload'                   => 'Daytoy a file ket pagraranudan nga upload ket mabalin nga aramaten ti sabsabali pay a projectos.',
@@ -1030,7 +1024,7 @@
 'log-search-submit'    => 'Inkan',
 'log-title-wildcard'   => 'Agsapul iti titulos nga agrugi iti daytoy a texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Amin a panid',
 'alphaindexline'    => '$1 iti $2',
 'nextpage'          => 'sumaruno a panid ($1)',
@@ -1051,12 +1045,12 @@
 'special-categories-sort-count' => 'urnosen babaen ti bilang',
 'special-categories-sort-abc'   => 'urnosen nga alfabetikal',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Iparang dagiti agar-aramat mangrugi iti:',
 'listusers-submit'   => 'Ipakita',
 'listusers-noresult' => 'Awan nasarakan nga agar-aramat.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'   => 'Grupo',
 'listgrouprights-rights'  => 'Dagiti Karbengan',
 'listgrouprights-members' => '(listaan dagiti kameng)',
@@ -1083,10 +1077,10 @@
 'watchlistfor'         => "(para ken ni '''$1''')",
 'nowatchlist'          => 'Awan ti pampanid iti listaan dagiti bambantayam.',
 'watchnologin'         => 'Saan a nakastrek',
-'watchnologintext'     => 'Nasken a [[Special:Userlogin|naka-loginka]] tapno mabaliwam dagiti bambantayam a panid.',
+'watchnologintext'     => 'Nasken a [[Special:UserLogin|naka-loginka]] tapno mabaliwam dagiti bambantayam a panid.',
 'addedwatch'           => 'Nainayon kadagiti bambantayan',
 'addedwatchtext'       => "Nainayonen ti panid a \"[[:\$1]]\" iti [[Special:Watchlist|listaan ti bambantayam]].
-Mailistanto ditoy dagiti pannkabalbaliw daytoy a panid iti masakbayan agraman ti kanaigna a panid-tungtongan, ket agparang ti panid a kas '''napuskol''' iti [[Special:Recentchanges|listaan ti naudi a balbaliw]] tapno nalaklaka a malasin.",
+Mailistanto ditoy dagiti pannkabalbaliw daytoy a panid iti masakbayan agraman ti kanaigna a panid-tungtongan, ket agparang ti panid a kas '''napuskol''' iti [[Special:RecentChanges|listaan ti naudi a balbaliw]] tapno nalaklaka a malasin.",
 'removedwatch'         => 'Naikkaten kadagiti bambantayan',
 'removedwatchtext'     => 'Naikkaten ti panid a "[[:$1]]" iti listaan ti bambantayam.',
 'watch'                => 'bantayan',
@@ -1323,7 +1317,7 @@
 'lockdbsuccesssub'    => 'Balligi ti pannakabalunet ti database',
 'unlockdbsuccesssub'  => 'Naikkaten ti balunet ti database',
 'lockdbsuccesstext'   => 'Nabalunetan ti database.<br />
-Laglagipem nga [[Special:Unlockdb|ikkaten ti balunetna]] kalpasan a makompletom ti maintenance.',
+Laglagipem nga [[Special:UnlockDB|ikkaten ti balunetna]] kalpasan a makompletom ti maintenance.',
 'unlockdbsuccesstext' => 'Naluktanen ti database.',
 'databasenotlocked'   => 'Saan a nabalunetan ti database.',
 
@@ -1347,8 +1341,6 @@
 
 Kadagitoy a kaso, masapul nga iyakar wenno itiponmo a manual ti panid no kayatmo.",
 'movearticle'             => 'Iyakar ti panid',
-'movenologin'             => 'Saan a nakastrek',
-'movenologintext'         => 'Nasken a nakarehistroka nga agar-aramat ken [[Special:Userlogin|nakastrek]] tapno makaiyakarka iti panid.',
 'movenotallowed'          => 'Awanka iti pammalubos nga agiyakar iti pampanid iti {{SITENAME}}.',
 'newtitle'                => 'Iti baro a titulo:',
 'move-watch'              => 'Bantayan daytoy a panid',
@@ -1512,7 +1504,7 @@
 'show-big-image'       => 'Sibubukel a resolusion',
 'show-big-image-thumb' => '<small>Rukod daytoy a preview: $1 × $2 a pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria dagiti kabarbaro a files',
 'imagelisttext'         => "Adda iti baba ti listaan ti '''$1''' {{PLURAL:$1|a file|a files}} a naurnos kas $2.",
 'showhidebots'          => '($1 bots)',
@@ -1778,7 +1770,7 @@
 
 # External editor support
 'edit-externally'      => 'Editen daytoy a file babaen ti akinruar nga aplikasion',
-'edit-externally-help' => 'Kitaen ti [http://meta.wikimedia.org/wiki/Help:External_editors instruksion iti panangikabil] para iti ad-adu pay nga informasion.',
+'edit-externally-help' => 'Kitaen ti [http://www.mediawiki.org/wiki/Manual:External_editors instruksion iti panangikabil] para iti ad-adu pay nga informasion.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'amin',
@@ -1818,7 +1810,7 @@
 'recreate'            => 'Partuaten manen',
 
 # HTML dump
-'redirectingto' => 'Maibawbaw-ing iti [[$1]]...',
+'redirectingto' => 'Maibawbaw-ing iti [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Dalusan ti cache daytoy a panid?
@@ -1909,7 +1901,7 @@
 'version-software-product'         => 'Produkto',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Dalanan ti file',
 'filepath-page'   => 'File:',
 'filepath-submit' => 'Dalan ti file',
Index: languages/messages/MessagesHif_latn.php
===================================================================
--- languages/messages/MessagesHif_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHif_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author Girmitya
- * @author Siebrand
- * @author M.M.S.
  */
 
 $messages = array(
@@ -286,7 +284,7 @@
 'nosuchspecialpage' => 'Aisan koi khaas panna nai hai',
 'nospecialpagetext' => "<big>'''Aap ek galat ghaas panna ke maanga hai.'''</big>
 
-Sahi khaas panna ke suchi [[Special:Specialpages|{{int:specialpages}}]]pe mili.",
+Sahi khaas panna ke suchi [[Special:SpecialPages|{{int:specialpages}}]]pe mili.",
 
 # General errors
 'error'                => 'Galti',
@@ -312,7 +310,7 @@
 'readonlytext'         => 'Database abhi nawaa badlao khatir band hai, saait database me mamuli kaam khatir lekin iske baad fir pahile jaise chale lagi.
 
 Jon administrator database ke band karis rahaa, ii kaaran diis hai: $1',
-'missing-article'      => 'Database, panna me likha akchhar, jiske naam "$1" $2 hai, ke nai pais.
+'missing-article'      => 'Database, panna me likha akchhar, jiske naam "$1" hai, ke nai pais $2 .
 
 Iske kaaran ii hoe sake ki aap ek purana antar nai to itihaas waala jorr ke use karaa jiske mitae dewa gais hai.
 
@@ -372,12 +370,12 @@
 'logouttitle'                => 'Sadasya logout',
 'logouttext'                 => '<strong>Aap abhi logged out hai.</strong>
 
-Aap bina naam ke {{SITENAME}} ke kaam me lae sakta hai, nai to aap wahi sadasya ke naam se nai to duusra sadasya ke naam se log in kare sakta hai.
+Aap bina naam ke {{SITENAME}} ke kaam me lae sakta hai, nai to aap wahi sadasya ke naam se nai to duusra sadasya ke naam se [[Special:UserLogin|log in kare sakta hai]].
 
 Yaad rakhna ki kuch panna wahi rakam se dekhai jaise ki aap log in bhaya hai, jab tak ki browser ke cache safaa nai hoe jaae.',
 'welcomecreation'            => '== Swagat, $1! ==
 Aap ke account banae dewa gais hai.
-Aapan {{SITENAME}} pasand ke badle nai bhulna.',
+Aapan [[Special:Preferences|{{SITENAME}} pasand]]  ke badle nai bhulna.',
 'loginpagetitle'             => 'Sadasya login',
 'yourname'                   => 'Username:',
 'yourpassword'               => 'Password:',
@@ -388,7 +386,7 @@
 'loginproblem'               => '<b>Aap ke login me karrbarr hai.</b><br />Fir se kosis karo!',
 'login'                      => 'Log in karo',
 'nav-login-createaccount'    => 'Log in karo/ nawaa account banao',
-'loginprompt'                => '{{SITENAME}} pe login kare ke khatir aap ke cookies ke laabu kare ke chaahi.',
+'loginprompt'                => 'Login kare ke khatir  {{SITENAME}} cookies ke laabu kare ke chaahi.',
 'userlogin'                  => 'Log in karo/ nawaa account banao',
 'logout'                     => 'Log out',
 'userlogout'                 => 'Log out',
@@ -408,6 +406,7 @@
 'prefs-memberingroups'       => '{{PLURAL:$1|group|groups}} ke member:',
 'yourrealname'               => 'Asli naam:',
 'yourlanguage'               => 'Bhasa:',
+'yourvariant'                => 'Variant:',
 'yournick'                   => 'Signature:',
 'badsig'                     => 'Invalid raw signature; HTML tags ke check karo.',
 'badsiglength'               => 'Signature bahut lambaa hai.
@@ -500,18 +499,26 @@
 'hr_tip'          => 'Samthar line (bahut jaada nai kaam me laana)',
 
 # Edit pages
-'summary'                => 'Sanchhipt',
-'subject'                => 'Subject/headline',
-'minoredit'              => 'Ii chhota badlao hai',
-'watchthis'              => 'Ii panna ke dhyaan rakho',
-'savearticle'            => 'Save panna',
-'preview'                => 'Jhalak dekhao',
-'showpreview'            => 'Preview dekhao',
-'showdiff'               => 'Badlao dekhao',
-'anoneditwarning'        => "'''Sawadhaan:''' Aap login nai karaa hai
+'summary'                   => 'Sanchhipt',
+'subject'                   => 'Subject/headline',
+'minoredit'                 => 'Ii chhota badlao hai',
+'watchthis'                 => 'Ii panna ke dhyaan rakho',
+'savearticle'               => 'Save panna',
+'preview'                   => 'Jhalak dekhao',
+'showpreview'               => 'Preview dekhao',
+'showlivepreview'           => 'Abhi ke jhalak',
+'showdiff'                  => 'Badlao dekhao',
+'anoneditwarning'           => "'''Sawadhaan:''' Aap login nai karaa hai
 Aap ke IP address ii panna ke edit itihaas me record karaa jaai.",
-'summary-preview'        => 'Sanchhep jhalak',
-'blockedtext'            => "<big>'''Aapke user name yah IP address ke rok dewa gae hai.'''</big>
+'missingsummary'            => "'''Suchna:''' Aap badlao ke sanchhit me nai likha hai.
+Agar aap Save ke fir se click karaa tab, aap ke badlao bina summary ke save kar lewa jaai.",
+'missingcommenttext'        => 'Meharbani kar ke niche aapan vichar deo.',
+'missingcommentheader'      => "'''Suchna:''' Aap ii vichar ke vishay nai likha hai.
+Agar aap Save pe click karaa tab bina vishay ke iske save kar lewa jaai.",
+'summary-preview'           => 'Sanchhep jhalak',
+'subject-preview'           => 'Suchi ke jhalak',
+'blockedtitle'              => 'Sadasya ke rok dewa gais hai',
+'blockedtext'               => "<big>'''Aapke user name yah IP address ke rok dewa gae hai.'''</big>
 
 Roke waala hai $1. Iske kaaran hai ''$2''.
 
@@ -522,27 +529,65 @@
 Aap $1 ke mile saktaa hai nai to duusra [[{{MediaWiki:Grouppage-sysop}}|administrator]] se rukawat ke baare me baat karo.
 Aap ii sadasya ke 'email this user' feature ke kaam me lae ke baat nai kare saktaa hai jab tak ki ek kanuni email address aapke [[Special:Preferences|account preferences]] me nai hai aur aap ke iske kaam me laae ke roka nai gae hai.
 Aap ke abhi ke IP address $3 hai, aur roka gae ID hai #$5. Meharbani kar ke chahe ek nai to duno ke aapan sawaal me rakho.",
-'blockednoreason'        => 'koi kaaran nai dewa gais hai',
-'newarticle'             => '(Nawaa)',
-'newarticletext'         => "Aap ek link follow kara jon ki koi panna me nai jae.
+'autoblockedtext'           => "Aap ke IP address ke apne se rok dewa gais hai kahe ki koi duusra sadasya iske kaam me kawat rahaa, jiske $1 rokis hai.
+
+Iske khatir kaaran hai:
+:''$2''
+
+* Roke ke suruu: $8
+* Roke kab khatam hoi: $6
+
+Aap $1 ke mile saktaa hai nai to duusra [[{{MediaWiki:Grouppage-sysop}}|administrator]] se rukawat ke baare me baat karo.
+
+Aap ii sadasya ke 'email this user' feature ke kaam me lae ke baat nai kare saktaa hai jab tak ki ek kanuni email address aapke [[Special:Preferences|account preferences]] me nai hai aur aap ke iske kaam me laae ke roka nai gae hai.
+
+Aap ke abhi ke IP address $3 hai, aur roka gae ID hai #$5. 
+Meharbani kar ke chahe ek nai to duno ke aapan sawaal me rakho.",
+'blockednoreason'           => 'koi kaaran nai dewa gais hai',
+'blockedoriginalsource'     => "'''$1''' ke kahaan se suruu bhais hai, niche likha hai:",
+'blockededitsource'         => "Aap ke '''$1 ke badlao''' ke akchhar niche likha hai:",
+'whitelistedittitle'        => 'Badle khatir [[Special:UserLogin|Login required]]',
+'whitelistedittext'         => 'Aap ke panna badle khatir $1 kare ke parri.',
+'confirmedittitle'          => 'Badle khatir E-mail confirmation ke jaruri hai',
+'confirmedittext'           => 'Panna ke badle se pahile aap ke aapan e-mail ke confirm kare ke parri.
+Meharbani kar ke aap aapan e-mail ke aapan [[Special:Preferences|user preferences]] se validate karna.',
+'nosuchsectiontitle'        => 'Aisan koi section nai hai',
+'nosuchsectiontext'         => 'Aap ek section jon ki nai hai, ke badle ke kosis karaa hai.
+Jab ki koi section $1 nai hai, tab aap ke badlao ke save kare ke koi jagah nai hai.',
+'loginreqtitle'             => 'Login Jaruri Hai',
+'loginreqlink'              => 'log in karo',
+'loginreqpagetext'          => 'Duusra panna ke dekhe ke khatir aap ke $1 kare ke parri.',
+'accmailtitle'              => 'Password bhej dewa gais hai.',
+'accmailtext'               => '"$1" ke password ke $2 ke lage bhej dewa gais hai.',
+'newarticle'                => '(Nawaa)',
+'newarticletext'            => "Aap ek link follow kara jon ki koi panna me nai jae.
 Ii panna banae khatir, niche box me type karo (see the [[{{MediaWiki:Helppage}}|help page]] for more info).
 Agar jo aap hian par galti se aae hai tab aapan browser ke '''back''' button pe click karo.",
-'noarticletext'          => 'Ii time pe ii panna me kuch likhaa nai hai, aap saktaa hai [[Special:Search/{{PAGENAME}}|ii panna ke title khoje]] duusra panna me nai to [{{fullurl:{{FULLPAGENAME}}|action=edit}} ii panna ke badlo].',
-'previewnote'            => '<strong>Ii khali ek jhalak dekhae hai; badlao abhi save nai bhae hai!</strong>',
-'editing'                => '$1 badlawa jae hai',
-'editingsection'         => 'Sampadan $1 (bhaag)',
-'copyrightwarning'       => 'Dhyann me rakho ki {{SITENAME}} ke sab yog daan $2 ($1 ke dekho aur kaankari khatir) ke niche dewa gae hai. Agar aap nai mangtaa ki aap ke likha gae koi chij ke duusra logan badle tab hain par nahii likho.<br />
+'anontalkpagetext'          => "----''Ii salah kare waala panna uu anonymous sadasya ke baare me jon abhi account nai banais hai, nai to account ke kaam me nai lawe hai. 
+Ii kaaran se ham log ke IP address kaam me lae ke ii sadasya ke jaana jae hai.
+
+Ii rakam ke IP address ke dher sadasya kaam me lae sake hai.
+Agar aap ek anonymous user hai aur ii sochta hai ki bekar baat aap ke baare me karaa gais hai, tab
+[[Special:UserLogin/signup|create an account]] or [[Special:UserLogin|log in]] aage ke garrbarri roke khatir aur duusra anonymous users se mistake nai kare ke khatir .''",
+'noarticletext'             => 'Ii time pe ii panna me kuch likhaa nai hai, aap saktaa hai [[Special:Search/{{PAGENAME}}|ii panna ke title khoje]] duusra panna me nai to [{{fullurl:{{FULLPAGENAME}}|action=edit}} ii panna ke badlo].',
+'userpage-userdoesnotexist' => 'User account "$1" abi registered nai hai.
+Check karo ki Ii panna ke aap banae/badle mangta hai.',
+'clearyourcache'            => "'''Note - Save kare ke baad, aap ke sait browser ke cache ke bypass kare ke parri badlao ke dekhe khatir.''' '''Mozilla / Firefox / Safari:''' hold ''Shift'' while clicking ''Reload,'' or press either ''Ctrl-F5'' or ''Ctrl-R'' (''Command-R'' on a Macintosh); '''Konqueror: '''click ''Reload'' or press ''F5;'' '''Opera:''' clear the cache in ''Tools → Preferences;'' '''Internet Explorer:''' hold ''Ctrl'' while clicking ''Refresh,'' or press ''Ctrl-F5.''",
+'previewnote'               => '<strong>Ii khali ek jhalak dekhae hai; badlao abhi save nai bhae hai!</strong>',
+'editing'                   => '$1 badlawa jae hai',
+'editingsection'            => 'Sampadan $1 (bhaag)',
+'copyrightwarning'          => 'Dhyann me rakho ki {{SITENAME}} ke sab yog daan $2 ($1 ke dekho aur kaankari khatir) ke niche dewa gae hai. Agar aap nai mangtaa ki aap ke likha gae koi chij ke duusra logan badle tab hain par nahii likho.<br />
 Aap ii bhi waada kartaa hai ki iske aap likha hai aur koi duusra jagah se copy nahi karaa hai.
 <strong>COPYRIGHT CHIJ KE BINA ANUMATI KE HIAN PAR NAHI SUBMIT KARNA!</strong>',
-'longpagewarning'        => '<strong>Sawadhan: Ii panna $1 kilobytes lamba hai; kuch browsers sait etna barra panna ke khole nai pai.
+'longpagewarning'           => '<strong>Sawadhan: Ii panna $1 kilobytes lamba hai; kuch browsers sait etna barra panna ke khole nai pai.
 Meherbani kar ke ii page ke chotachota tukrra me kar do.</strong>',
-'templatesused'          => 'Ii panna me kaam me lawa gae templates:',
-'templatesusedpreview'   => 'Ii jhalak me jon template kaam me lawa gais hai',
-'template-protected'     => '(surakchhit)',
-'template-semiprotected' => '(aadha-surakchhit)',
-'nocreatetext'           => '{{SITENAME}} me nawaa panna banae ke rukawat hai.
-Aap pichhe jae ke ek panna jon hai ke sampadan kare sakta hai, nai to  [[Special:Userlogin|log in or create an account]].',
-'recreate-deleted-warn'  => "'''Chetawani: Jon panna ke pahile hatae dewa gae rahaa ke aap fir se banata hai.'''
+'templatesused'             => 'Ii panna me kaam me lawa gae templates:',
+'templatesusedpreview'      => 'Ii jhalak me jon template kaam me lawa gais hai',
+'template-protected'        => '(surakchhit)',
+'template-semiprotected'    => '(aadha-surakchhit)',
+'nocreatetext'              => '{{SITENAME}} me nawaa panna banae ke rukawat hai.
+Aap pichhe jae ke ek panna jon hai ke sampadan kare sakta hai, nai to  [[Special:UserLogin|log in or create an account]].',
+'recreate-deleted-warn'     => "'''Chetawani: Jon panna ke pahile hatae dewa gae rahaa ke aap fir se banata hai.'''
 
 Aap soco ki ii pann ake sampadan aap ke karte rahe ke chaahi ki nai.
 Aap ke aaram khatir hatae waala suchi hian pe dewa jae hai:",
@@ -629,7 +674,7 @@
 'uploadlogpage' => 'Suchi ke upload karo',
 'uploadedimage' => '"[[$1]]" ke upload kar dewa gae',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Chapa ke suchi',
 
 # Image description page
@@ -716,7 +761,7 @@
 'log'                  => 'Suchi',
 'all-logs-page'        => 'Sab suchi',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Sab panna',
 'alphaindexline' => '$1 se $2',
 'nextpage'       => 'Aglaa panna ($1)',
@@ -739,7 +784,7 @@
 'addedwatch'           => 'Dhyan suchi me jorro',
 'addedwatchtext'       => "Panna \"[[:\$1]]\" ke aap ke [[Special:Watchlist|watchlist]] me jorr dewa gais hai.
 Ii panna ke aage ke badlao
-Future changes to this page and its associated talk page will be listed there, and the page will appear '''bolded''' in the [[Special:Recentchanges|list of recent changes]] to make it easier to pick out.",
+Future changes to this page and its associated talk page will be listed there, and the page will appear '''bolded''' in the [[Special:RecentChanges|list of recent changes]] to make it easier to pick out.",
 'removedwatch'         => 'Dhyan suchi me se hatao',
 'removedwatchtext'     => 'Panna "[[:$1]]" ke aap ke dhyan suchi se hatae dewa gae hai.',
 'watch'                => 'Dekho',
@@ -929,7 +974,7 @@
 'show-big-image'       => 'Puura resolution',
 'show-big-image-thumb' => '<small>Ii preview ke size: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Nawaa files ke gallery',
 
 # Bad image list
@@ -953,7 +998,7 @@
 
 # External editor support
 'edit-externally'      => 'Edit this file using an external application',
-'edit-externally-help' => 'Aur jaankari khatir [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] ke dekho.',
+'edit-externally-help' => 'Aur jaankari khatir [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] ke dekho.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'sab',
Index: languages/messages/MessagesQu.php
===================================================================
--- languages/messages/MessagesQu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesQu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,7 @@
  * @file
  *
  * @author AlimanRuna
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $fallback = 'es';
@@ -47,7 +44,7 @@
 'tog-editondblclick'          => "P'anqakunata llamk'apuy iskaylla ñit'iywan (JavaScript)",
 'tog-editsection'             => "Rakirilla llamk'apuyta saqillay [qillqay] t'inkiwan",
 'tog-editsectiononrightclick' => "Rakirilla llamk'apuyta saqillay paña butunta rakirip sutinpi ñit'ispa (JavaScript)",
-'tog-showtoc'                 => "Yuyarinata rikuchiy (kimsamanta aswan uma siq'iyuq p'anqakunapaq)",
+'tog-showtoc'                 => "Yuyarina wachuchasqata rikuchiy (kimsamanta aswan uma siq'iyuq p'anqakunapaq)",
 'tog-rememberpassword'        => "Yaykuna rimata yuyaykuy llamk'ay tiyaypura",
 'tog-editwidth'               => "Llamk'apuna k'itiqa lliwmanta aswan sunim",
 'tog-watchcreations'          => "Qallarisqay p'anqakunata watiqay.",
@@ -313,7 +310,7 @@
 'nosuchspecialpage' => "Kay hina sapaq p'anqaqa manam kanchu",
 'nospecialpagetext' => "<big>'''Mana kaq sapaq p'anqatam munanki.'''</big>
 
-Allin sapaq p'anqakunataqa tarinki [[Special:Specialpages|Sapaq p'anqakuna]] nisqa p'anqapim.",
+Allin sapaq p'anqakunataqa tarinki [[Special:SpecialPages|Sapaq p'anqakuna]] nisqa p'anqapim.",
 
 # General errors
 'error'                => 'Pantasqa',
@@ -341,7 +338,7 @@
 Kayqa sapsilla hamun manaña kachkaq wakin kay (diff) nisqamanta icha qullusqa p'anqaman t'inkimuq wiñay kawsay t'inkimanta.
 
 Mana kay hina kaptinqa, llamp'u kaqpi wakichiy pantasqatachá tarirqanki.
-Ama hina kaspa, huk kamachiqman willariy, URL nisqa llika tiyaytapas willaspa.",
+Ama hina kaspa, huk [[Special:ListUsers/sysop|kamachiqman]] willariy, URL nisqa llika tiyaytapas willaspa.",
 'missingarticle-rev'   => '(musuqchasqa#: $1)',
 'missingarticle-diff'  => '(wakin kay: $1, $2)',
 'readonly_lag'         => "Willañiqintinqa mit'alla hark'asqam, sirwiqkuna kikinpachachastin.",
@@ -390,11 +387,12 @@
 
 # Login and logout pages
 'logouttitle'                => "Llamk'apuy tiyaypa puchukaynin",
-'logouttext'                 => "<strong>Llamk'apuy tiyayniykiqa puchukasqañam.</strong><br />
-Sutinnaq kaspaykipas {{SITENAME}}pi wamp'uytam atinki. Mana hinataq munaspaykiqa, musuqmanta yaykuy ñawpaq icha huk sutiwan. Huk p'anqakunaqa kaqllam rikch'akunqa, ''cache'' nisqa pakasqa hallch'ata mana ch'usaqchaptiykiqa.",
+'logouttext'                 => "<strong>Llamk'apuy tiyayniykiqa puchukasqañam.</strong>
+
+Sutinnaq kaspaykipas {{SITENAME}}pi wamp'uytam atinki. Mana hinataq munaspaykiqa, [[Special:UserLogin|musuqmanta yaykuy]] ñawpaq icha huk sutiwan. Huk p'anqakunaqa kaqllam rikch'akunqa, ''cache'' nisqa pakasqa hallch'ata mana ch'usaqchaptiykiqa.",
 'welcomecreation'            => '== Allinmi hamusqayki $1! ==
 Rakiqunaykiqa kicharisqañam.
-Ama qunqaychu allinkachinaykikunata kikinchayta.',
+Ama qunqaychu [[Special:Preferences|{{SITENAME}} allinkachinaykikunata]] kikinchayta.',
 'loginpagetitle'             => 'Yaykuy',
 'yourname'                   => 'Ruraq sutiyki',
 'yourpassword'               => 'Yaykuna rimayki',
@@ -534,26 +532,24 @@
 
 Hark'aymanta rimanakunapaqqa $1-man icha huk [[{{MediaWiki:Grouppage-sysop}}|kamachiqman]] willariy.
 Manam saqillasunkichu 'Kay ruraqman e-chaskita kachay' nisqata llamk'achiyta manaraq allin e-chaski imamaytaykita [[Special:Preferences|allinkachinaykikunaman]] quptiyki manaraqpas chaymanta hark'asqa kaptiyki.
-Kunan IP huchhaykiqa $3 nisqam, hark'ay huchhataq #$5 nisqam. Mañakuspaykiqa chay huchhakunata willay.",
+Kunan IP huchhaykiqa $3 nisqam, hark'ay huchhataq #$5 nisqam. Mañakuspaykiqa kay p'anqapi tukuy nisqakunata willay.",
 'autoblockedtext'                  => "IP huchhaykiqa kikinmanta hark'asqam, $1-pa hark'asqan ruraqpa llamk'achisqan kaptinmi. Hark'asqaqa kayraykum:
 
 :''$2''
 
 * Hark'aypa qallarisqan: $8
 * Hark'aypa puchukanan: $6
+* Awaytiyasqa hark'ana ruraq: $7
 
 Hark'aymanta rimanakunapaqqa $1-man icha huk [[{{MediaWiki:Grouppage-sysop}}|kamachiqman]] willariy.
 Manam saqillasunkichu 'Kay ruraqman e-chaskita kachay' nisqata llamk'achiyta manaraq allin e-chaski imamaytaykita [[Special:Preferences|allinkachinaykikunaman]] quptiyki manaraqpas chaymanta hark'asqa kaptiyki.
-Hark'ay huchhaykiqa $5 nisqam. Mañakuspaykiqa chay huchhata willay.",
+
+Kunan IP huchhaykiqa $3 nisqam, hark'ay huchhataq #$5 nisqam. Mañakuspaykiqa kay p'anqapi tukuy nisqakunata willay.",
 'blockednoreason'                  => "hark'aqqa manam ninchu imarayku",
 'blockedoriginalsource'            => "'''$1'''-pa pukyu qillqanqa kaymi:",
 'blockededitsource'                => "'''$1'''-pi '''llamk'apusqaykikuna''' nisqapi qillqasqaqa kaymi:",
 'whitelistedittitle'               => "Yaykuspallaykim llamk'apuyta atinki.",
 'whitelistedittext'                => "$1ta ruranaykim tiyan qillqakunata llamk'apunaykipaq.",
-'whitelistreadtitle'               => 'Yaykuspallaykim ñawiriyta atinki',
-'whitelistreadtext'                => '[[Special:Userlogin|Yaykuspallaykim]] qillqakunata ñawiriyta atinki.',
-'whitelistacctitle'                => 'Rakiqunata kichariyqa manam saqillasqachu',
-'whitelistacctext'                 => '{{SITENAME}}pi rakiqunakunata kicharinaykipaqqa sapaqta saqillasqa kaspayki [[Special:Userlogin|yaykunaykim]] tiyan.',
 'confirmedittitle'                 => "E-chaski imamaytaykita takyachiy llamk'apunaykipaq",
 'confirmedittext'                  => "P'anqakunata llamk'apunaykipaqqa e-chaski imamaytaykita takyachinaykim tiyan. Ama hina kaspa, e-chaski imamaytata kicharispa takyachiy [[Special:Preferences|allinkachinaykikunapi]].",
 'nosuchsectiontitle'               => 'Manam kanchu chay raki',
@@ -565,7 +561,7 @@
 'accmailtext'                      => '«$1»-paq yaykuna rimaqa $2-manmi kachasqa.',
 'newarticle'                       => '(Musuq)',
 'newarticletext'                   => "Manaraq kachkaq p'anqatam llamk'apuchkanki. Musuq p'anqata kamariyta munaspaykiqa, qillqarillay. Astawan ñawiriyta munaspaykiqa, [[{{MediaWiki:Helppage}}|yanapana p'anqata]] qhaway. Mana munaspaykitaq, ñawpaq p'anqaman ripuy.",
-'anontalkpagetext'                 => "---- ''Kayqa huk sutinnaq icha mana sutinta llamk'achiq ruraqpa rimanakuyninmi. IP huchhantam hallch'asunchik payta sutinchanapaq. Achka ruraqkunam huklla IP huchhanta llamk'achiyta atin. Sutinnaq ruraq kaspaykiqa, mana qampa rurasqaykimanta willamusqakunata rikuspaykiqa, ama hina kaspa [[Special:Userlogin|ruraqpa sutiykita kamariy icha yaykuy]] huk sutinnaq ruraqkunawan ama pantasqa kanaykipaq.''",
+'anontalkpagetext'                 => "---- ''Kayqa huk sutinnaq icha mana sutinta llamk'achiq ruraqpa rimanakuyninmi. IP huchhantam hallch'asunchik payta sutinchanapaq. Achka ruraqkunam huklla IP huchhanta llamk'achiyta atin. Sutinnaq ruraq kaspaykiqa, mana qampa rurasqaykimanta willamusqakunata rikuspaykiqa, ama hina kaspa [[Special:UserLogin|ruraqpa sutiykita kamariy icha yaykuy]] huk sutinnaq ruraqkunawan ama pantasqa kanaykipaq.''",
 'noarticletext'                    => "Kay p'anqaqa ch'usaqmi. Kaytam rurayta atinkiman: {{PAGENAME}} nisqata [[Special:Search/{{PAGENAME}}|huk qillqakunapi maskay]] icha [{{fullurl:{{FULLPAGENAME}}|action=edit}} musuq qillqata qallariy].",
 'userpage-userdoesnotexist'        => '"$1" sutiyuq ruraqpa rakiqunanqa manam kanchu. Ama hina kaspa, llanchikuy kay p\'anqata kamarinaykimanta.',
 'clearyourcache'                   => "'''Paqtataq''': Willañiqita waqaycharquspaykiqa, wamp'unaykip ''cache'' nisqa pakasqa waqaychananta ch'usaqchanaykichá tiyanman hukchasqaykikunata rikunaykipaq:
@@ -578,12 +574,12 @@
 'note'                             => '<strong>Musyay:</strong>',
 'previewnote'                      => '<strong>Yuyaykuy: Kayqa manaraq waqaychaspa qhawariymi!</strong>',
 'previewconflict'                  => "Rikuchkanki kay p'anqataqa, ima hinachus waqaychasqa kanqa.",
-'session_fail_preview'             => "<strong>Achachaw! Llamk'apusqaykiqa manam waqaychasqachu, llamk'ana tiyaypa willankuna chinkaptinmi. Ama hina kaspa, musuqmanta ruraykachay. Mana atispaykiqa, lluqsispa musuqmanta yaykuy.</strong>",
+'session_fail_preview'             => "<strong>Achachaw! Llamk'apusqaykiqa manam waqaychasqachu, llamk'ana tiyaypa willankuna chinkaptinmi. Ama hina kaspa, musuqmanta ruraykachay. Mana atispaykiqa, [[Special:UserLogout|lluqsispa]] musuqmanta yaykuy.</strong>",
 'session_fail_preview_html'        => "<strong>Achachaw! Llamk'apusqaykiqa manam waqaychasqachu, llamk'ana tiyaypa willankuna chinkaptinmi.</strong>
 
 ''{{SITENAME}} llump'aq HTML nisqawan llamk'achkaptinmi, ñawpaq qhawariyqa pakasqam kachkan JavaScript nisqawan wankhayta hark'anapaq.''
 
-<strong>Allin sunquwan kamarirqaspaykiqa, musuqmanta ruraykachay. Mana atispaykiqa, lluqsispa musuqmanta yaykuspa ruraykachay.</strong>",
+<strong>Allin sunquwan kamarirqaspaykiqa, musuqmanta ruraykachay. Mana atispaykiqa, [[Special:UserLogout|lluqsispa]] musuqmanta yaykuspa ruraykachay.</strong>",
 'token_suffix_mismatch'            => "<strong>Llamk'apusqaykimanqa ama nisqam, mink'akuqniyki llamk'apuy willaypi sapaq sananchakunata arwiptinmi. Ama nisqa karqanqa qillqata waqlliymantam amachanapaq.
 Kayqa maykunapi tukukun, mana allin wakichisqa proxy sirwiytam llamk'achiptiyki.</strong>",
 'editing'                          => "$1-ta llamk'apuspa",
@@ -622,7 +618,7 @@
 'template-semiprotected'           => '(rakilla amachasqa)',
 'hiddencategories'                 => "Kay p'anqaqa {{PLURAL:$1|1 pakasqa katiguriya|$1 pakasqa katiguriyakuna}}manmi kapun:",
 'nocreatetitle'                    => "P'anqa kamariyqa saywachasqam",
-'nocreatetext'                     => "{{SITENAME}}piqa saywachasqam musuq p'anqakunata kamariy. Ñawpaqman kutiytam atinkiman kachkaqña p'anqata llamk'apuspa. Astawantaq, [[Special:Userlogin|yaykuy icha musuq rakiqunata kichariy]].",
+'nocreatetext'                     => "{{SITENAME}}piqa saywachasqam musuq p'anqakunata kamariy. Ñawpaqman kutiytam atinkiman kachkaqña p'anqata llamk'apuspa. Astawantaq, [[Special:UserLogin|yaykuy icha musuq rakiqunata kichariy]].",
 'nocreate-loggedin'                => "Manam saqillasunkichu {{SITENAME}}pi musuq p'anqakunata kamariyta.",
 'permissionserrors'                => 'Saqillay pantasqakuna',
 'permissionserrorstext'            => 'Manam saqillasunkichu, {{PLURAL:$1|kayraykum|kayraykum}}:',
@@ -741,7 +737,7 @@
 
 # Suppression log
 'suppressionlog'     => "Ñit'ipay hallch'asqa",
-'suppressionlogtext' => "Kay qatiq sutisuyupiqa ñaqha qullusqakunatam hark'asqakunatapas rikunki, kamachiqkunamanta pakasqa samiqniyuq. [[Special:Ipblocklist|IP hark'ay sutisuyuta]] qhaway kunan hark'asqakunata rikunaykipaq.",
+'suppressionlogtext' => "Kay qatiq sutisuyupiqa ñaqha qullusqakunatam hark'asqakunatapas rikunki, kamachiqkunamanta pakasqa samiqniyuq. [[Special:IPBlockList|IP hark'ay sutisuyuta]] qhaway kunan hark'asqakunata rikunaykipaq.",
 
 # History merging
 'mergehistory'                     => "P'anqa wiñay kawsaykunata huñuy",
@@ -751,7 +747,7 @@
 'mergehistory-from'                => "Pukyu p'anqa:",
 'mergehistory-into'                => "Taripana p'anqa:",
 'mergehistory-list'                => 'Huñunalla wiñay kawsay',
-'mergehistory-merge'               => "[[:$1]] nisqamantaqa kay qatiq llamk'apusqakuna huñunallam [[:$2]]-man. Radyu ñit'ina tunuta llamk'achiy akllasqayki pachallapi chay pachakamallapas llamk'apusqakunata huñumunapaq. Musyariy: Wamp'una t'inkikunata ñit'ispaykiqa kay tunuta kutichinkim.",
+'mergehistory-merge'               => "[[:$1]] nisqamantaqa kay qatiq llamk'apusqakuna huñunallam [[:$2]]-man. Radyu ñit'ina wachuta llamk'achiy akllasqayki pachallapi chay pachakamallapas llamk'apusqakunata huñumunapaq. Musyariy: Wamp'una t'inkikunata ñit'ispaykiqa kay wachuta kutichinkim.",
 'mergehistory-go'                  => "Huñunalla llamk'apusqakunata rikuchiy",
 'mergehistory-submit'              => "Llamk'apusqakunata huñuy",
 'mergehistory-empty'               => "Manam atinichu llamk'apusqakunata huñuyta.",
@@ -781,7 +777,7 @@
 # Search results
 'searchresults'             => 'Maskaymanta tarisqakuna',
 'searchresulttext'          => '{{SITENAME}}pi maskaymanta astawan ñawirinaykipaqqa, [[{{MediaWiki:Helppage}}|{{int:help}}]] nisqapi qhaway.',
-'searchsubtitle'            => "'''[[:$1]]''' nisqatam maskanki",
+'searchsubtitle'            => '\'\'\'[[:$1]]\'\'\' nisqatam maskanki ([[Special:Prefixindex/$1|tukuy "$1" nisqawan qallariq p\'anqakuna]] | [[Special:WhatLinksHere/$1|tukuy "$1" nisqaman t\'inkimuq p\'anqakuna]])',
 'searchsubtitleinvalid'     => '"$1" nisqatam maskanki',
 'noexactmatch'              => "'''Manam kanchu \"\$1\" sutiyuq p'anqa.''' Munaspaykiqa [[:\$1|kamarillay]].",
 'noexactmatch-nocreate'     => "'''\"\$1\" sutiyuq p'anqaqa manam kanchu.'''",
@@ -824,7 +820,7 @@
 'mypreferences'            => 'Allinkachinaykuna',
 'prefs-edits'              => 'Hukchasqakunap yupaynin:',
 'prefsnologin'             => 'Manam yaykurqankichu',
-'prefsnologintext'         => '[[Special:Userlogin|Yaykunaykim]] tiyan allinkachinaykikunata hukchanaykipaq.',
+'prefsnologintext'         => '[[Special:UserLogin|Yaykunaykim]] tiyan allinkachinaykikunata hukchanaykipaq.',
 'prefsreset'               => 'Allinkachinakunaqa qallariy kachkaykunaman kutisqañam.',
 'qbsettings'               => 'Utqaytawna ("Quickbar") allinkachinakuna',
 'qbsettings-none'          => 'Mana imapas',
@@ -859,8 +855,8 @@
 'newpassword'              => 'Musuq yaykuna rima:',
 'retypenew'                => 'Musuq yaykuna rimaykita takyachiy:',
 'textboxsize'              => "Llamk'apusqa",
-'rows'                     => "Siq'ikuna:",
-'columns'                  => 'Tunukuna:',
+'rows'                     => 'Sinrukuna:',
+'columns'                  => 'Wachukuna:',
 'searchresultshead'        => 'Maskay',
 'resultsperpage'           => "Huk p'anqapi hayk'a tarinakuna:",
 'contextlines'             => "Siq'ikuna taripasqaman:",
@@ -898,7 +894,7 @@
 'userrights-reason'           => 'Imarayku hukchasqa:',
 'userrights-no-interwiki'     => 'Manam saqillasunkichu huk wikikunapi ruraqkunap hayñinkunata hukchayta.',
 'userrights-nodatabase'       => '$1 sutiyuq willañiqintinqa manam kanchu icha manam kayllapichu.',
-'userrights-nologin'          => 'Kamachiqpa rakiqunaykiwan [[Special:Userlogin|yaykunaykim]] tiyan ruraqkunap hayñinkunata rurapunaykipaq.',
+'userrights-nologin'          => 'Kamachiqpa rakiqunaykiwan [[Special:UserLogin|yaykunaykim]] tiyan ruraqkunap hayñinkunata rurapunaykipaq.',
 'userrights-notallowed'       => 'Qampa rakiqunaykiwanqa manam ruraqkunap hayñinkunata rurapuyta atinkichu.',
 'userrights-changeable-col'   => 'Hukchanayki huñukuna',
 'userrights-unchangeable-col' => 'Mana hukchanayki huñukuna',
@@ -1027,20 +1023,23 @@
 'reupload'                    => 'Huk kutita churkuy',
 'reuploaddesc'                => "Churkuna hunt'ana p'anqaman kutimuy.",
 'uploadnologin'               => 'Manaraqmi yaykurqunkichu',
-'uploadnologintext'           => '[[Special:Userlogin|Yaykunaykim]] tiyan willañiqikunata churkunaykipaq.',
+'uploadnologintext'           => '[[Special:UserLogin|Yaykunaykim]] tiyan willañiqikunata churkunaykipaq.',
 'upload_directory_missing'    => 'Churkuna willañiqi churanaqa ($1) manam kanchu. Llika sirwiqpas manam atinchu churkuna willañiqi churanata kamariyta.',
 'upload_directory_read_only'  => "Llika sirwiqqa manam atinchu churkuna hallch'aman ($1) qillqayta.",
 'uploaderror'                 => 'Willañiqita churkunayaptiyki pantasqam tukurqan',
-'uploadtext'                  => "Willañiqita churkunaykipaqqa kay qatiqpi kaq hunt'ana p'anqata llamk'achiy. Churkusqaña rikchakunatataq qhawanaykipaq icha maskanaykipaqqa [[Special:Imagelist|rikchakuna p'anqaman]] riy. Churkusqakunata qullusqakunatapas [[Special:Log/upload|churkuy hallch'apim]] rikunki.
+'uploadtext'                  => "Willañiqita churkunaykipaqqa kay qatiqpi kaq hunt'ana p'anqata llamk'achiy.
+Churkusqaña rikchakunatataq qhawanaykipaq icha maskanaykipaqqa [[Special:ImageList|rikchakuna p'anqaman]] riy. Churkusqakunata [[Special:Log/upload|churkuy hallch'apim]], qullusqakunatataq [[Special:Log/delete|qulluy hallch'apim]] rikunki.
 
-Rikchata huk p'anqaman ch'aqtanaykipaqqa kay hunt'ana p'anqapi t'inkita llamk'achiy: '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Willañiqi.jpg]]</nowiki>''', '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Willañiqi.png|huk qillqa]]</nowiki>''' icha
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Willañiqi.ogg]]</nowiki>''' (willañiqiman chiqalla t'inkinapaq).",
+Rikchata huk p'anqaman ch'aqtanaykipaqqa kay hunt'ana p'anqapi t'inkita llamk'achiy:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Willañiqi.jpg]]</nowiki></tt>''', willañiqip hunt'a musuqchasqan llamk'achinapaq
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Willañiqi.png|huk qillqa]]</nowiki></tt>''', lluq'i manyapi kaq kahapi 200 iñu suni rikch'achisqata llamk'achinapaq
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Willañiqi.ogg]]</nowiki></tt>''', willañiqiman chiqalla t'inkinapaq, willañiqita mana rikuchispa",
 'upload-permitted'            => 'Saqillasqa willañiqi layakuna: $1.',
 'upload-preferred'            => 'Astawan munasqa willañiqi layakuna: $1.',
 'upload-prohibited'           => 'Mana saqillasqa willañiqi layakuna: $1.',
 'uploadlog'                   => "churkuy hallch'a",
 'uploadlogpage'               => 'Churkusqa willañiqikuna',
-'uploadlogpagetext'           => 'Kay qatiqpiqa ñaqha willañiqi churkusqakunam. Pachakunaqa sirwiqpa rurasqanmi.',
+'uploadlogpagetext'           => 'Kay qatiqpiqa ñaqha willañiqi churkusqakunam. [[Special:NewImages|Musuq willañiqikunayuq suyu-suyuta]] qhaway rikchachakunata rikunaykipaq.',
 'filename'                    => 'Willañiqip sutin',
 'filedesc'                    => 'Pisichay',
 'fileuploadsummary'           => "T'iktu:",
@@ -1104,9 +1103,9 @@
 'upload-proto-error'      => 'Tantari qillqaqa manam allinchu',
 'upload-proto-error-text' => "Huk p'anqamanta willañiqita churkunapaqqa URL tiyaypa <code>http://</code> icha <code>ftp://</code> nisqawan qallarinanmi.",
 'upload-file-error'       => 'Ukhu pantasqa',
-'upload-file-error-text'  => "Ukhu pantasqam tukurqan sirwiqpi mit'alla willañiqita kamariykachaptiyki. Ama hina kaspa, llika kamachiqta tapuy.",
+'upload-file-error-text'  => "Ukhu pantasqam tukurqan sirwiqpi mit'alla willañiqita kamariykachaptiyki. Ama hina kaspa, llika [[Special:ListUsers/sysop|kamachiqta]] tapuy.",
 'upload-misc-error'       => 'Mana riqsisqa churkuy pantasqa',
-'upload-misc-error-text'  => 'Churkuchkaptiyki mana riqsisqa pantasqam tukurqan. Ama hina kaspa, URL tiyay allinchu chayanallachu chaymanta llanchispa musuqmanta ruraykachay. Mana allinyaptinqa, llika kamachiqta tapuy.',
+'upload-misc-error-text'  => 'Churkuchkaptiyki mana riqsisqa pantasqam tukurqan. Ama hina kaspa, URL tiyay allinchu chayanallachu chaymanta llanchispa musuqmanta ruraykachay. Mana allinyaptinqa, llika [[Special:ListUsers/sysop|kamachiqta]] tapuy.',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Manam taripanichu URL tiyayta',
@@ -1120,10 +1119,10 @@
 'upload_source_url'  => ' (allin, sapsi chayanalla URL tiyay)',
 'upload_source_file' => ' (antañiqiqniykipi willañiqi)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Kay sapaq p'anqapiqa tukuy churkusqa willañiqikunatam rikunki.
 Kikinmantaqa ñaqha churkusqa willañiqikunatam sutisuyup patanpi rikunki.
-Tunup umanpi ñit'ispaqa allichaytam hukchanki.",
+Wachup umanpi ñit'ispaqa allichaytam hukchanki.",
 'imagelist_search_for'  => 'Rikchap sutinta maskay:',
 'imgfile'               => 'willañiqi',
 'imagelist'             => 'Rikchakuna',
@@ -1148,7 +1147,7 @@
 'imagelinks'                     => "Rikchaman t'inkimuq",
 'linkstoimage'                   => "Kay rikchamanqa kay qatiq {{PLURAL:$1|p'anqam|$1 p'anqakunam}} t'inkimun:",
 'nolinkstoimage'                 => "Kay rikchamanqa manam ima p'anqakunachu t'inkimun.",
-'morelinkstoimage'               => "Kay willañiqiman [[Special:Whatlinkshere/$1|aswan t'inkimuqkunata]] qhaway.",
+'morelinkstoimage'               => "Kay willañiqiman [[Special:WhatLinksHere/$1|aswan t'inkimuqkunata]] qhaway.",
 'redirectstofile'                => "Kay qatiq {{PLURAL:$1|p'anqam|$1 p'anqakunam}} kay willañiqiman pusampun:",
 'duplicatesoffile'               => 'Kay willañiqimanta iskaychasqa {{PLURAL:$1|willañiqim|$1 willañiqikunam}} kay qatiqpi:',
 'sharedupload'                   => "Kay p'anqaqa rakinakusqallam churkusqa huk ruraykamaykunapipas llamk'achinapaq.",
@@ -1167,18 +1166,18 @@
 # File reversion
 'filerevert'                => '$1-ta kutichiy',
 'filerevert-legend'         => 'Willañiqita kutichiy',
-'filerevert-intro'          => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' nisqatam [$3, $2 pachapi $4 llamk\'apusqaman] kutichichkanki.</span>',
+'filerevert-intro'          => "'''[[Media:$1|$1]]''' nisqatam [$3, $2 pachapi $4 llamk'apusqaman] kutichichkanki.",
 'filerevert-comment'        => 'Willayniyki:',
 'filerevert-defaultcomment' => '$2, $1 nisqa musuqchasqaman kutichisqa',
 'filerevert-submit'         => 'Kutichiy',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' nisqaqa [$3, $2 pachapi $4 llamk\'apusqaman] kutichisqañam.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' nisqaqa [$3, $2 pachapi $4 llamk'apusqaman] kutichisqañam.",
 'filerevert-badversion'     => "Kay willañiqimanta qusqayki pachayuq tiyaylla llamk'apusqaqa manam kanchu.",
 
 # File deletion
 'filedelete'                  => '$1-ta qulluy',
 'filedelete-legend'           => 'Willañiqita qulluy',
 'filedelete-intro'            => "'''[[Media:$1|$1]]'''-tam qulluchkanki.",
-'filedelete-intro-old'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' musuqchasqatam qulluchkanki [$4 $3, $2] nisqamanta.</span>',
+'filedelete-intro-old'        => "'''[[Media:$1|$1]]''' musuqchasqatam qulluchkanki [$4 $3, $2] nisqamanta.",
 'filedelete-comment'          => 'Willapuy:',
 'filedelete-submit'           => 'Qulluy',
 'filedelete-success'          => "'''$1''' qullusqañam.",
@@ -1240,9 +1239,11 @@
 'disambiguationspage'  => "Plantilla:Sut'ichana qillqa",
 'disambiguations-text' => "Kay qatiq p'anqakunam t'inkimun '''sut'ichana qillqaman'''. Chiqap, hukchanasqa p'anqaman t'inkichun.<br />Tukuy [[MediaWiki:Disambiguationspage]] plantillayuq p'anqakunaqa sut'ichana qillqam.",
 
-'doubleredirects'     => 'Iskaylla pusapunakuna',
-'doubleredirectstext' => "<b>Paqtataq:</b> Kay p'anqapiqa pantasqalla p'anqa sutikunachá rikuchisqa kayta atinman, ñawpaq kaq #REDIRECT nisqap qhipanpi t'inkiyuq p'anqakuna.<br />
-Kay p'anqapiqa huk pusapuna p'anqaman pusapuq p'anqakunap sutinkunatam rikunki. Sapa siq'ipiqa ñawpaq ñiqin, iskay ñiqinpas pusapunaman t'inkikunam, iskay ñiqin pusapunap taripananpa qallariyninpas, sapsilla chiqap allin qillqam.",
+'doubleredirects'            => 'Iskaylla pusapunakuna',
+'doubleredirectstext'        => "<b>Paqtataq:</b> Kay p'anqapiqa pantasqalla p'anqa sutikunachá rikuchisqa kayta atinman, ñawpaq kaq #REDIRECT nisqap qhipanpi t'inkiyuq p'anqakuna.<br />
+Kay p'anqapiqa huk pusapuna p'anqaman pusapuq p'anqakunap sutinkunatam rikunki. Sapa sinrupiqa ñawpaq ñiqin, iskay ñiqinpas pusapunaman t'inkikunam, iskay ñiqin pusapunap taripananpa qallariyninpas, sapsilla chiqap allin qillqam.",
+'double-redirect-fixed-move' => '[[$1]] nisqaqa astasqam, kunantaq [[$2]] nisqaman pusapunam',
+'double-redirect-fixer'      => 'Pusapuna allinchaq',
 
 'brokenredirects'        => 'Panta pusapunakuna',
 'brokenredirectstext'    => "Kay pusapuna p'anqakunaqa mana kachkaq p'anqamanmi pusapuchkan.",
@@ -1328,7 +1329,7 @@
 'logempty'             => "Manam hallch'asqakuna kachkanchu.",
 'log-title-wildcard'   => "Kaywan qallariq p'anqa sutikunata maskay",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => "Tukuy p'anqakuna",
 'alphaindexline'    => '$1-ta $2-man',
 'nextpage'          => "Qatiq p'anqa ($1)",
@@ -1351,12 +1352,12 @@
 'special-categories-sort-count' => 'yupaykama allichay',
 'special-categories-sort-abc'   => 'qallarina sanampakama allichay',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Kaywan qallariq ruraqkunata rikuchiy:',
 'listusers-submit'   => 'Rikuchiy',
 'listusers-noresult' => 'Ruraqqa manam tarisqachu.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Ruraq huñup hayñinkuna',
 'listgrouprights-summary'  => "Kay qatiq sutisuyupiqa kay wikipi sut'ichasqa ruraq huñukunatam, kikinpa chayamuna hayñinkunatawan rikunki.
 Chay kikinkunap hayñinkunamanta astawan ñawirinaykipaqqa [[{{MediaWiki:Listgrouprights-helppage}}|kaypi qhaway]].",
@@ -1367,7 +1368,7 @@
 
 # E-mail user
 'mailnologin'     => 'Imamaytataqa ama kachaychu',
-'mailnologintext' => '[[Special:Userlogin|Yaykunaykim]], [[Special:Preferences|allinkachinaykikunapi]] chaniyuq e-chaski imamaytappas kananmi tiyan huk ruraqkunaman e-chaskita kachanaykipaq.',
+'mailnologintext' => '[[Special:UserLogin|Yaykunaykim]], [[Special:Preferences|allinkachinaykikunapi]] chaniyuq e-chaski imamaytappas kananmi tiyan huk ruraqkunaman e-chaskita kachanaykipaq.',
 'emailuser'       => 'Kay ruraqman e-chaskita kachay',
 'emailpage'       => 'E-chaski kay ruraqman:',
 'emailpagetext'   => "Kay ruraq e-chaski imamaytanta allinkachinankunapi qillqakamachiptinqa, kay simihunt'anatam llamk'achiyta atinki e-chaskita kachanaykipaq.
@@ -1394,9 +1395,9 @@
 'nowatchlist'          => 'Manam watiqasqakunachu kachkan.',
 'watchlistanontext'    => 'Ama hina kaspa, $1 watiqana sutisuyuykipi imakunatapas qhawanaykipaq icha hukchanaykipaq.',
 'watchnologin'         => 'Manam yaykurqankichu',
-'watchnologintext'     => '[[Special:Userlogin|Yaykunaykim]] tiyan watiqana sutisuyuykita hukchanaykipaq.',
+'watchnologintext'     => '[[Special:UserLogin|Yaykunaykim]] tiyan watiqana sutisuyuykita hukchanaykipaq.',
 'addedwatch'           => 'Watiqasqaykunaman yapasqa',
-'addedwatchtext'       => "Kunanqa «[[:\$1]]» sutiyuq p'anqa [[Special:Watchlist|watiqanykipim]] kachkañam. Chay p'anqapi rimachinanpipas hukchanakunaqa kay watiqana p'anqapim rikunki. Watiqasqayki p'anqaqa [[Special:Recentchanges|ñaqha hukchasqakunapi]] '''yanasapa''' qillqasqa rikuchisqa kanqa aswan sikllalla tarinaykipaq. <p>Manaña watiqayta munaptiykiqa, uma siq'ipi \"amaña watiqaychu\" ñit'iy.",
+'addedwatchtext'       => "Kunanqa «[[:\$1]]» sutiyuq p'anqa [[Special:Watchlist|watiqanykipim]] kachkañam. Chay p'anqapi rimachinanpipas hukchanakunaqa kay watiqana p'anqapim rikunki. Watiqasqayki p'anqaqa [[Special:RecentChanges|ñaqha hukchasqakunapi]] '''yanasapa''' qillqasqa rikuchisqa kanqa aswan sikllalla tarinaykipaq. <p>Manaña watiqayta munaptiykiqa, uma siq'ipi \"amaña watiqaychu\" ñit'iy.",
 'removedwatch'         => 'Watiqasqakunamanta qullusqa',
 'removedwatchtext'     => '"[[:$1]]" sutiyuq p\'anqaqa watiqasqakunamanta qullusqam.',
 'watch'                => 'Watiqay',
@@ -1495,7 +1496,9 @@
 'rollbacklink'                => 'Kutichiy',
 'rollbackfailed'              => 'Manam kutichiyta atinchu',
 'cantrollback'                => "Manam atinichu llamk'apusqata kutichiyta; qhipaq kaq llamk'apuqqa kay p'anqap hukllam ruraqnin.",
-'alreadyrolled'               => "Manam atinichu [[User:$2|$2]]-pa ([[User talk:$2|rimanakuy]]) [[$1]] nisqa qhipaq llamk'apusqanta kutichiyta; pipas kay p'anqataqa llamk'apurqunñam icha kutichirqunñam. Qhipaq kaq llamk'apusqaqa [[User:$3|$3]]-pa ([[User talk:$3|rimanakuy]]) rurasqanmi.",
+'alreadyrolled'               => "Manam atinichu [[User:$2|$2]]-pa ([[User talk:$2|rimanakuy]]) [[$1]] nisqa qhipaq llamk'apusqanta kutichiyta; pipas kay p'anqataqa llamk'apurqunñam icha kutichirqunñam.
+
+Qhipaq kaq llamk'apusqaqa [[User:$3|$3]]-pa ([[User talk:$3|rimanakuy]] | [[Special:Contributions/$3|{{int:contribslink}}]]) rurasqanmi.",
 'editcomment'                 => 'Llamk\'apusqamantaqa kaymi willasqa: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => '[[Special:Contributions/$2|$2]] ([[User talk:$2|rimachina]]) sutiyuq ruraqpa hukchasqankunaqa kutichisqam [[User:$1|$1]]-pa ñawpaq hukchasqanman', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => "$1-pa hukchasqankunaqa kutichisqañam $2-pa ñawpaq llamk'apusqanta paqarichispa.",
@@ -1503,7 +1506,7 @@
 kay rurayqa t'ipisqam karqan millay runap llullaspa yaykunanta hark'anapaq.
 Ama hina kaspa, llika wamp'unaykipi \"Ñawpaqman\" (\"Back\") ñit'ispa ñawpaq p'anqata musuqmanta chaqnamuspa huk kutita yaykuykachay.",
 'protectlogpage'              => "P'anqa amachasqakuna",
-'protectlogtext'              => "Kay qatiqpiqa p'anqata amachasqakunatam paskasqakunatapas rikunki. [[Special:Protectedpages|Amachasqa p'anqakunata]] qhaway astawan willasunaykipaq.",
+'protectlogtext'              => "Kay qatiqpiqa p'anqata amachasqakunatam paskasqakunatapas rikunki. [[Special:ProtectedPages|Amachasqa p'anqakunata]] qhaway astawan willasunaykipaq.",
 'protectedarticle'            => 'amachan [[$1]]-ta',
 'modifiedarticleprotection'   => 'hukchan kay p\'anqap amachasqa kachkayninta: "[[$1]]"',
 'unprotectedarticle'          => 'paskan amachasqa [[$1]]-ta',
@@ -1660,7 +1663,7 @@
 'ipbwatchuser'                    => "Kay ruraqpa p'anqanta rimachinantapas watiqay",
 'badipaddress'                    => 'IP huchhaqa manam allinchu.',
 'blockipsuccesssub'               => "Ruraqqa hark'asqañam",
-'blockipsuccesstext'              => "IP \"\$1\"-niyuq tiyayqa hark'asqañam. <br />[[Special:Ipblocklist|Hark'asqakunamanta p'anqata]] qhaway hark'akunata hukchanaykipaq.",
+'blockipsuccesstext'              => "IP \"\$1\"-niyuq tiyayqa hark'asqañam. <br />[[Special:IPBlockList|Hark'asqakunamanta p'anqata]] qhaway hark'akunata hukchanaykipaq.",
 'ipb-edit-dropdown'               => "Hark'aypa hamunta llamk'apuy",
 'ipb-unblock-addr'                => "Hark'asqa $1-ta qispichiy",
 'ipb-unblock'                     => "Hark'asqa ruraqta icha IP huchhata qispichiy",
@@ -1690,7 +1693,7 @@
 'autoblocker'                     => 'Kikinmanta hark\'asqam kanki, "[[User:$1|$1]]" sutiyuq ruraq IP huchhaykita ñaqha llamk\'arquptinmi. Hark\'aqqa "[[User:$1|$1]]"-ta hark\'aspa kaytam nirqan, kayrayku: "$2".',
 'blocklogpage'                    => "Ruraq hark'asqakuna",
 'blocklogentry'                   => "hark'an [[$1]]-ta kay pachakama: $2 $3",
-'blocklogtext'                    => "Kayqa ruraqta hark'asqakunap qispichisqakunappas hallch'anmi. Kikinmanta hark'asqa tiyaykunataqa manam kaypi rikunkichu. [[Special:Ipblocklist|Hark'asqakunamanta p'anqata]] qhaway kunan hark'asqakunata rikunaykipaq.",
+'blocklogtext'                    => "Kayqa ruraqta hark'asqakunap qispichisqakunappas hallch'anmi. Kikinmanta hark'asqa tiyaykunataqa manam kaypi rikunkichu. [[Special:IPBlockList|Hark'asqakunamanta p'anqata]] qhaway kunan hark'asqakunata rikunaykipaq.",
 'unblocklogentry'                 => 'paskan "$1"-ta hark\'asqa kaymanta',
 'block-log-flags-anononly'        => 'sutinnaqlla',
 'block-log-flags-nocreate'        => 'rakiquna kichariyman ama nisqa',
@@ -1725,7 +1728,7 @@
 'lockdbsuccesssub'    => "Willañiqintinqa hark'asqañam",
 'unlockdbsuccesssub'  => 'Willañiqintinqa paskasqañam',
 'lockdbsuccesstext'   => "{{SITENAME}}pi willañiqintinqa hark'asqam.
-<br />Yuyariy, ruranaykita tukuspayki [[Special:Unlockdb|willañiqintinta paskay]].",
+<br />Yuyariy, ruranaykita tukuspayki [[Special:UnlockDB|willañiqintinta paskay]].",
 'unlockdbsuccesstext' => '{{SITENAME}}pi willañiqintinqa paskasqam.',
 'lockfilenotwritable' => "Willañiqintinqa manam qillqanapaqchu. Willañiqintinta hark'anapaqqa icha paskanapaqqa, sirwiqpa qillqananpaq kananmi tiyan.",
 'databasenotlocked'   => "Willañiqintinqa manam hark'asqachu.",
@@ -1750,8 +1753,6 @@
 
 Hinaptinqa, kay rimachina p'anqap samiqninta makiykiwan astanaykim tiyanqa.",
 'movearticle'             => "P'anqata astay",
-'movenologin'             => "Manam qallarisqachu llamk'apuy tiyayniyki",
-'movenologintext'         => "P'anqata astanaykipaqqa hallch'asqa ruraqmi kanayki [[Special:Userlogin|llamk'apuy tiyay qallarinaykipas]] tiyan.",
 'movenotallowed'          => "Kay wikipi p'anqata astayniykiqa manam saqillasqachu.",
 'newtitle'                => 'Kay musuq sutiman',
 'move-watch'              => "Kay p'anqata watiqay",
@@ -1778,7 +1779,7 @@
 'delete_and_move'         => 'Qulluspa astay',
 'delete_and_move_text'    => '==Qullunam tiyan==
 
-Tukuna p\'anqaqa ("[[$1]]") kachkañam. Astanapaq qulluyta munankichu?',
+Tukuna p\'anqaqa ("[[:$1]]") kachkañam. Astanapaq qulluyta munankichu?',
 'delete_and_move_confirm' => "Arí, kay p'anqata qulluy",
 'delete_and_move_reason'  => 'Astanapaq qullusqa',
 'selfmove'                => "Qallarinawan taripana sutikunaqa kaqllam kachkan. Manam atinchu p'anqata kikinman astay.",
@@ -1786,6 +1787,7 @@
 'imagenocrossnamespace'   => "Manam atinichu p'anqata astayta mana willañiqipaq suti k'itiman",
 'imagetypemismatch'       => "Willañiqip musuq mast'arinanqa kay layapaq manam allinchu",
 'imageinvalidfilename'    => 'Taripana willañiqip sutinqa manam allinchu',
+'fix-double-redirects'    => 'Qallariy sutiman astamuq tukuy pusapunakunata musuqchay',
 
 # Export
 'export'            => "P'anqakunata hawaman quy",
@@ -1831,7 +1833,7 @@
 'import-interwiki-history'   => "Kay p'anqapaq tukuy wiñay kawsaynintinta iskaychay",
 'import-interwiki-submit'    => 'Hawamanta chaskiy',
 'import-interwiki-namespace' => "P'anqakunata kay suti k'itiman churay:",
-'importtext'                 => "Ama hina kaspa, willañiqita qallariy wikimanta Special:Export nisqa llamk'anawan hawaman quy antañiqiqniykipi waqaychaspa, chaymantataq kaypi churkuy.",
+'importtext'                 => "Ama hina kaspa, willañiqita qallariy wikimanta [[Special:Export|hawaman quna llamk'anawan]] hawaman quy antañiqiqniykipi waqaychaspa, chaymantataq kaypi churkuy.",
 'importstart'                => "P'anqakunatam hawamanta chaskichkani...",
 'import-revision-count'      => "$1 {{PLURAL:$1|llamk'apusqa|llamk'apusqakuna}}",
 'importnopages'              => "Manam kanchu hawamanta chaskina p'anqakuna.",
@@ -1981,9 +1983,10 @@
 'markedaspatrollederror-noautopatrol' => "Manam saqillasunkichu qampa llamk'apusqaykikunata qhawakipasqaman sananchayta.",
 
 # Patrol log
-'patrol-log-page' => "Qhawakipay hallch'a",
-'patrol-log-line' => '$1 sananchasqa $2-manta qhawakipasqa $3',
-'patrol-log-auto' => '(kikinmanta)',
+'patrol-log-page'   => "Qhawakipay hallch'a",
+'patrol-log-header' => "Kayqa patrullasqa musuqchasqakunamanta hallch'asqam.",
+'patrol-log-line'   => '$1 sananchasqa $2-manta qhawakipasqa $3',
+'patrol-log-auto'   => '(kikinmanta)',
 
 # Image deletion
 'deletedrevision'                 => "Qullusqam mawk'a qhawakipasqa $1",
@@ -2012,10 +2015,10 @@
 'show-big-image'       => 'Qallariy huyaku',
 'show-big-image-thumb' => '<small>Kay ñawpaq qhawariypa chhikan kaynin: $1 × $2 iñu</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Musuq rikchakunap suyu-suyun',
 'imagelisttext'         => "Kay qatiqpiqa '''$1''' {{PLURAL:$1|rikchatam|rikchakunatam}} rikunki, $2-kama ñiqichasqa.",
-'newimages-summary'     => "Kay sapaq p'anqapiqa ñaqha churkusqa willañiqikunatam rikunki",
+'newimages-summary'     => "Kay sapaq p'anqapiqa ñaqha churkusqa willañiqikunatam rikunki.",
 'showhidebots'          => '($1 rurana antacha)',
 'noimages'              => 'Manam ima rikunallapas kanchu.',
 'ilsubmit'              => 'Maskay',
@@ -2033,7 +2036,7 @@
 'metadata-help'     => "Kay willañiqipiqa aswan sapaqlla willaymi, iliktruniku rikchahap'inawanchá, iskanirwanchá icha rikcharurana wakichiwanchá yapasqa. Willañiqi chaymantapacha hukchasqa kaptinqa, huk sapaq samiqninkuna chinkasqachá.",
 'metadata-expand'   => 'Aswan sapaqlla willakunata rikuchiy',
 'metadata-collapse' => 'Sapaqlla willakunata pakay',
-'metadata-fields'   => "Kay willaypi rikuchisqa EXIF metadatapaq k'itichakunaqa rikcha p'anqapim ch'aqtasqa kanqa, metadata tawla mana rikch'akuptinpas. Huk k'itikunaqa kikinmantam pakasqa kanqa.
+'metadata-fields'   => "Kay willaypi rikuchisqa EXIF metadatapaq k'itichakunaqa rikcha p'anqapim ch'aqtasqa kanqa, metadata wachuchasqa mana rikch'akuptinpas. Huk k'itikunaqa kikinmantam pakasqa kanqa.
 * make
 * model
 * datetimeoriginal
@@ -2056,7 +2059,7 @@
 'exif-yresolution'                 => "Sayaqpa ch'irkukun",
 'exif-resolutionunit'              => "X, Y ch'irkukup tupun",
 'exif-stripoffsets'                => 'Rikcha willa churamuy',
-'exif-rowsperstrip'                => "Siq'ikuna ch'imiman",
+'exif-rowsperstrip'                => "Sinrukuna ch'imiman",
 'exif-stripbytecounts'             => "Bytekuna mat'isqa ch'imiman",
 'exif-jpeginterchangeformat'       => 'Ithiy JPEG SOI nisqaman',
 'exif-jpeginterchangeformatlength' => 'JPEG willa bytekuna',
@@ -2294,7 +2297,7 @@
 
 # External editor support
 'edit-externally'      => "Kay willañiqita hawa rurana wakichiwan llamk'apuy",
-'edit-externally-help' => 'Astawan willasunaykipaqqa [http://meta.wikimedia.org/wiki/Help:External_editors tiyachina yanapata] (inlish simipi) ñawiriy.',
+'edit-externally-help' => 'Astawan willasunaykipaqqa [http://www.mediawiki.org/wiki/Manual:External_editors tiyachina yanapata] (inlish simipi) ñawiriy.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tukuy',
@@ -2359,7 +2362,7 @@
 'recreate'            => 'Musuqta paqarichiy',
 
 # HTML dump
-'redirectingto' => '[[$1]]-man pusapuspa...',
+'redirectingto' => '[[:$1]]-man pusapuspa...',
 
 # action=purge
 'confirm_purge'        => "Kay p'anqap ''cache'' nisqa pakasqa hallch'an ch'usaqchasqa kachunchu?
@@ -2406,8 +2409,8 @@
 Sapsilla ñawpaq qhawariyta tukuykachay.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => "Qhipaq $1 sikundupi hukchasqakunaqa manachá rikch'akunqachu kay sutisuyupi.",
-'lag-warn-high'   => "Willañiqintin sirwiq nisyuta ruranayuq kachkaptinmi, qhipaq $1 sikundupi hukchasqakunaqa manachá rikch'akunqachu kay sutisuyupi.",
+'lag-warn-normal' => "Qhipaq $1 {{PLURAL:$1|sikundupi|sikundukunapi}} hukchasqakunaqa manachá rikch'akunqachu kay sutisuyupi.",
+'lag-warn-high'   => "Willañiqintin sirwiq nisyuta ruranayuq kachkaptinmi, qhipaq $1 {{PLURAL:$1|sikundupi|sikundukunapi}} hukchasqakunaqa manachá rikch'akunqachu kay sutisuyupi.",
 
 # Watchlist editor
 'watchlistedit-numitems'       => "Watiqana sutisuyuykiqa {{PLURAL:$1|huk p'anqayuqmi|$1 p'anqayuqmi}} kachkan, rimanakuy p'anqakunata mana yupaptinchik.",
@@ -2455,7 +2458,7 @@
 'version-software-product'         => 'Ruruchisqa',
 'version-software-version'         => 'Musuqchasqa',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Willañiqi ñan',
 'filepath-page'    => 'Willañiqi:',
 'filepath-submit'  => 'Ñan',
@@ -2494,7 +2497,7 @@
 'specialpages-group-redirects'   => "Pusapunapaq sapaq p'anqakuna",
 'specialpages-group-spam'        => "Spam nisqa millay rurayta hark'anapaq llamk'anakuna",
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => "Ch'usaq p'anqa",
 'intentionallyblankpage' => "Kay p'anqaqa munaylla ch'usaqmi kachun",
 
Index: languages/messages/MessagesFrp.php
===================================================================
--- languages/messages/MessagesFrp.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFrp.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,7 @@
  * @file
  *
  * @author ChrisPtDe
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Jon Harald Søby
- * @author SPQRobin
  */
 
 $fallback = 'fr';
@@ -346,7 +343,7 @@
 'nosuchspecialpage' => 'Pâge spèciâla pas ègzistenta',
 'nospecialpagetext' => "<big>'''Vos éd demandâ una pâge spèciâla qu’est pas recognua per lo vouiqui.'''</big>
 
-Una lista de les pâges spèciâles pôt étre trovâ dessus [[Special:Specialpages]].",
+Una lista de les pâges spèciâles pôt étre trovâ dessus [[Special:SpecialPages]].",
 
 # General errors
 'error'                => 'Èrror',
@@ -576,10 +573,6 @@
 'blockededitsource'         => "Lo contegnu de '''voutres modificacions''' aplicâs a '''$1''' est endicâ ce-desot :",
 'whitelistedittitle'        => 'Enregistrament nècèssèro por modifiar lo contegnu',
 'whitelistedittext'         => 'Vos dête étre $1 por avêr la pèrmission de modifiar lo contegnu.',
-'whitelistreadtitle'        => 'Enregistrament nècèssèro por liére lo contegnu',
-'whitelistreadtext'         => 'Vos dête étre [[Special:Userlogin|conèctâ]] por liére lo contegnu.',
-'whitelistacctitle'         => 'Vos éte pas ôtorisâ a crèar un compto.',
-'whitelistacctext'          => 'Por povêr crèar un compto dessus {{SITENAME}}, vos dête étre [[Special:Userlogin|conèctâ]] et avêr les pèrmissions que vont avouéc.',
 'confirmedittitle'          => 'Validacion de l’adrèce de mèl nècèssèra por modifiar lo contegnu',
 'confirmedittext'           => 'Vos dête confirmar voutra adrèce de mèl devant que modifiar {{SITENAME}}. Volyéd entrar et validar voutra adrèce èlèctronica avouéc la pâge [[Special:Preferences|prèferences]].',
 'nosuchsectiontitle'        => 'Sèccion manquenta',
@@ -591,7 +584,7 @@
 'accmailtext'               => 'Lo mot de pâssa de « $1 » at étâ emmandâ a l’adrèce $2.',
 'newarticle'                => '(Novél)',
 'newarticletext'            => "Vos éd siuvu un lim vers una pâge qu’ègziste p’oncor. Por crèar cela pâge, entrâd voutron tèxte dens la bouèta ce-desot (vos pouede consultar la [[{{MediaWiki:Helppage}}|pâge d’éde]] por més d’enformacion). Se vos éte arrevâ ice per èrror, clicâd sur lo boton '''retôrn''' de voutron navigator.",
-'anontalkpagetext'          => "---- ''Vos éte sur la pâge de discussion d’un utilisator pas enregistrâ qu’at p’oncor crèâ un compto ou que l’utilise pas. Por cela rêson, nos devens utilisar son adrèce IP por l’identifiar. Una adrèce IP pôt étre partagiê per plusiors utilisators. Se vos éte un utilisator pas enregistrâ et se vos constatâd que des comentèros que vos regârdont pas vos ont étâ adrèciês, vos pouede vos [[Special:Userlogin|conèctar ou crèar un compto]] por èvitar tota confusion futura avouéc d’ôtros contributors pas enregistrâs.''",
+'anontalkpagetext'          => "---- ''Vos éte sur la pâge de discussion d’un utilisator pas enregistrâ qu’at p’oncor crèâ un compto ou que l’utilise pas. Por cela rêson, nos devens utilisar son adrèce IP por l’identifiar. Una adrèce IP pôt étre partagiê per plusiors utilisators. Se vos éte un utilisator pas enregistrâ et se vos constatâd que des comentèros que vos regârdont pas vos ont étâ adrèciês, vos pouede vos [[Special:UserLogin|conèctar ou crèar un compto]] por èvitar tota confusion futura avouéc d’ôtros contributors pas enregistrâs.''",
 'noarticletext'             => 'Y at por lo moment gins de tèxte sur ceta pâge ; vos pouede [[Special:Search/{{PAGENAME}}|fâre una rechèrche sur lo titro de ceta pâge]] ou ben [{{fullurl:{{NAMESPACE}}:{{FULLPAGENAME}}|action=edit}} la modifiar].',
 'userpage-userdoesnotexist' => 'Lo compto utilisator « $1 » est pas enregistrâ. Endicâd se vos voléd crèar ou ben èditar cela pâge.',
 'clearyourcache'            => "'''Nota :''' aprés avêr sôvâ, vos dête forciér lo rechargement de la pâge por vêre los changements : '''Mozilla / Firefox :''' ''Shift-Ctrl-R'' (''Shift-Cmd-R'' en '''Apple Mac'''), '''IE :''' ''Ctrl-F5'', '''Opera :''' ''F5'', '''Safari :''' ''⌘-R'', '''Konqueror :''' ''Ctrl-R''.",
@@ -650,7 +643,7 @@
 'edittools'                 => '<!-- Tot tèxte entrâ ique serat afichiê desot les bouètes d’èdicion ou d’impôrt de fichiér. -->',
 'nocreatetitle'             => 'Crèacion de pâge limitâ',
 'nocreatetext'              => '{{SITENAME}} at rètrent la possibilitât de crèar de novèles pâges.
-Vos pouede tornar arriér et pués modifiar una pâge ègzistenta, ou ben vos [[Special:Userlogin|conèctar ou crèar un compto]].',
+Vos pouede tornar arriér et pués modifiar una pâge ègzistenta, ou ben vos [[Special:UserLogin|conèctar ou crèar un compto]].',
 'nocreate-loggedin'         => 'Vos avéd pas la pèrmission de crèar de novèles pâges dessus {{SITENAME}}.',
 'permissionserrors'         => 'Èrror de pèrmissions',
 'permissionserrorstext'     => 'Vos avéd pas la pèrmission de fâre l’opèracion demandâ por {{PLURAL:$1|la rêson siuventa|les rêsons siuventes}} :',
@@ -807,7 +800,7 @@
 'mypreferences'            => 'Prèferences',
 'prefs-edits'              => 'Nombro d’èdicions :',
 'prefsnologin'             => 'Pas conèctâ',
-'prefsnologintext'         => 'Vos dête étre [[Special:Userlogin|conèctâ]] por modifiar voutres prèferences d’utilisator.',
+'prefsnologintext'         => 'Vos dête étre [[Special:UserLogin|conèctâ]] por modifiar voutres prèferences d’utilisator.',
 'prefsreset'               => 'Les prèferences ont étâ rètablies dês la vèrsion enregistrâ.',
 'qbsettings'               => 'Bârra d’outils',
 'qbsettings-none'          => 'Niona',
@@ -875,7 +868,7 @@
 'userrights-reason'        => 'Rêson du changement :',
 'userrights-no-interwiki'  => 'Vos avéd pas la pèrmission de modifiar los drêts des utilisators dessus d’ôtros vouiquis.',
 'userrights-nodatabase'    => 'La bâsa de balyês « $1 » ègziste pas ou ben el est pas una bâsa de balyês locala.',
-'userrights-nologin'       => 'Vos dête vos [[Special:Userlogin|conèctar]] avouéc un compto administrator por balyér los drêts d’utilisator.',
+'userrights-nologin'       => 'Vos dête vos [[Special:UserLogin|conèctar]] avouéc un compto administrator por balyér los drêts d’utilisator.',
 'userrights-notallowed'    => 'Voutron compto at pas la pèrmission de balyér des drêts d’utilisator.',
 
 # Groups
@@ -941,10 +934,10 @@
 'reupload'                    => 'Relevar',
 'reuploaddesc'                => 'Retôrn u formulèro.',
 'uploadnologin'               => 'Pas conèctâ',
-'uploadnologintext'           => 'Vos dête étre [[Special:Userlogin|conèctâ]] por copiyér des fichiérs sur lo sèrvior.',
+'uploadnologintext'           => 'Vos dête étre [[Special:UserLogin|conèctâ]] por copiyér des fichiérs sur lo sèrvior.',
 'upload_directory_read_only'  => 'Lo sèrvior Vouèbe pôt pas ècrire dens lo dossiér ciba ($1).',
 'uploaderror'                 => 'Èrror',
-'uploadtext'                  => "Utilisâd ceti formulèro por copiyér des fichiérs, por vêre ou rechèrchiér des émâges prècèdament copiyês consultâd la [[Special:Imagelist|lista de fichiérs copiyês]], les copies et suprèssions sont asse-ben enregistrâs dens lo [[Special:Log/upload|jornal de les copies]].
+'uploadtext'                  => "Utilisâd ceti formulèro por copiyér des fichiérs, por vêre ou rechèrchiér des émâges prècèdament copiyês consultâd la [[Special:ImageList|lista de fichiérs copiyês]], les copies et suprèssions sont asse-ben enregistrâs dens lo [[Special:Log/upload|jornal de les copies]].
 
 Por encllure una émâge dens una pâge, utilisâd un lim de la fôrma :
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fichiér.jpg]]</nowiki>'''
@@ -1041,7 +1034,7 @@
 'upload_source_url'  => ' (una URL valida et accèssibla publicament)',
 'upload_source_file' => ' (un fichiér sur voutron ordenator)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Rechèrche por l’émâge apelâ :',
 'imgfile'               => 'fichiér',
 'imagelist'             => 'Lista de les émâges',
@@ -1077,18 +1070,18 @@
 # File reversion
 'filerevert'                => 'Rèvocar $1',
 'filerevert-legend'         => 'Rèvocar lo fichiér',
-'filerevert-intro'          => '<span class="plainlinks">Vos voléd rèvocar \'\'\'[[Media:$1|$1]]\'\'\' tant qu’a [$4 la vèrsion du $2 a $3].</span>',
+'filerevert-intro'          => "Vos voléd rèvocar '''[[Media:$1|$1]]''' tant qu’a [$4 la vèrsion du $2 a $3].",
 'filerevert-comment'        => 'Comentèro :',
 'filerevert-defaultcomment' => 'Rèvocâ tant qu’a la vèrsion du $1 a $2',
 'filerevert-submit'         => 'Rèvocar',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' at étâ rèvocâ tant qu’a [$4 la vèrsion du $2 a $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' at étâ rèvocâ tant qu’a [$4 la vèrsion du $2 a $3].",
 'filerevert-badversion'     => 'Y at pas de vèrsion ples vielye du fichiér avouéc la dâta balyê.',
 
 # File deletion
 'filedelete'                  => 'Suprime $1',
 'filedelete-legend'           => 'Suprimar lo fichiér',
 'filedelete-intro'            => "Vos éte aprés suprimar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Vos éte aprés èfaciér la vèrsion de \'\'\'[[Media:$1|$1]]\'\'\' du [$4 $2 a $3].</span>',
+'filedelete-intro-old'        => "Vos éte aprés èfaciér la vèrsion de '''[[Media:$1|$1]]''' du [$4 $2 a $3].",
 'filedelete-comment'          => 'Comentèro :',
 'filedelete-submit'           => 'Suprimar',
 'filedelete-success'          => "'''$1''' at étâ suprimâ.",
@@ -1144,7 +1137,7 @@
 Cen reprèsente una moyena de {{PLURAL:$5|'''1''' modificacion|'''$5''' modificacions}} per pâge et de {{PLURAL:$6|'''1''' consulta|'''$6''' consultes}} por una modificacion.</p>
 
 <p>Y at ora {{PLURAL:$7|'''1''' ovrâjo|'''$7''' ovrâjos}} dens la [http://www.mediawiki.org/wiki/Manual:Job_queue fela d’atenta des travâlys].</p>",
-'userstatstext'          => "Y at {{PLURAL:$1|'''1''' [[Special:Listusers|utilisator enregistrâ]]|'''$1''' [[Special:Listusers|utilisators enregistrâs]]}}. Permié cetos, '''$2''' (ou ben '''$4%''') {{PLURAL:$2|est|sont}} $5.",
+'userstatstext'          => "Y at {{PLURAL:$1|'''1''' [[Special:ListUsers|utilisator enregistrâ]]|'''$1''' [[Special:ListUsers|utilisators enregistrâs]]}}. Permié cetos, '''$2''' (ou ben '''$4%''') {{PLURAL:$2|est|sont}} $5.",
 'statistics-mostpopular' => 'Pâges les ples consultâs',
 
 'disambiguations'      => 'Pâges d’homonimia',
@@ -1232,7 +1225,7 @@
 'logempty'             => 'Y at ren dens l’historico por ceta pâge.',
 'log-title-wildcard'   => 'Chèrchiér los titros comencient per lo tèxte siuvent',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Totes les pâges',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Pâge siuventa ($1)',
@@ -1254,14 +1247,14 @@
 'special-categories-sort-count' => 'tri per compto',
 'special-categories-sort-abc'   => 'tri alfabètico',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Afichiér los utilisators dês :',
 'listusers-submit'   => 'Montrar',
 'listusers-noresult' => 'Nion utilisator trovâ. Controlâd asse-ben les variantes en grantes lètres / petiôtes lètres.',
 
 # E-mail user
 'mailnologin'     => 'Pas d’adrèce',
-'mailnologintext' => 'Vos dête étre [[Special:Userlogin|conèctâ]]
+'mailnologintext' => 'Vos dête étre [[Special:UserLogin|conèctâ]]
 et avêr endicâ una adrèce èlèctronica valida dens voutres [[Special:Preferences|prèferences]]
 por avêr la pèrmission d’emmandar un mèssâjo a un ôtro utilisator.',
 'emailuser'       => 'Emmandar un mèssâjo a ceti utilisator',
@@ -1291,11 +1284,11 @@
 'nowatchlist'          => 'Voutra lista de siuvu contint gins d’articllo.',
 'watchlistanontext'    => 'Por povêr afichiér ou èditar los èlèments de voutra lista de siuvu, vos dête vos $1.',
 'watchnologin'         => 'Pas conèctâ',
-'watchnologintext'     => 'Vos dête étre [[Special:Userlogin|conèctâ]] por modifiar voutra lista de siuvu.',
+'watchnologintext'     => 'Vos dête étre [[Special:UserLogin|conèctâ]] por modifiar voutra lista de siuvu.',
 'addedwatch'           => 'Apondua a la lista de siuvu',
 'addedwatchtext'       => "La pâge « [[:$1]] » at étâ apondua a voutra [[Special:Watchlist|lista de siuvu]].
 
-Les modificacions que vegnont de cela pâge et de la pâge de discussion associyê y seront listâs, et la pâge aparètrat '''en grâs''' dens la [[Special:Recentchanges|lista des dèrriérs changements]] por étre repèrâ ples facilament.
+Les modificacions que vegnont de cela pâge et de la pâge de discussion associyê y seront listâs, et la pâge aparètrat '''en grâs''' dens la [[Special:RecentChanges|lista des dèrriérs changements]] por étre repèrâ ples facilament.
 
 Por suprimar cela pâge de voutra lista de siuvu, clicâd dessus « pas més siuvre » dens lo câdro de navigacion.",
 'removedwatch'         => 'Enlevâ de la lista de siuvu',
@@ -1405,7 +1398,7 @@
 cela accion at étâ anulâ en prèvencion d’un piratâjo de sèssion.
 Clicâd dessus « Prècèdent » et rechargiéd la pâge de yô que vos vegnéd, et pués tornâd èprovar.',
 'protectlogpage'              => 'Historico de les protèccions',
-'protectlogtext'              => 'Vêde les [[Special:Protectedpages|dirèctives]] por més d’enformacion.',
+'protectlogtext'              => 'Vêde les [[Special:ProtectedPages|dirèctives]] por més d’enformacion.',
 'protectedarticle'            => 'at protègiê « [[$1]] »',
 'modifiedarticleprotection'   => 'at modifiâ lo nivô de protèccion de « [[$1]] »',
 'unprotectedarticle'          => 'at dèprotègiê « [[$1]] »',
@@ -1561,7 +1554,7 @@
 'badipaddress'                => 'L’adrèce IP est fôssa.',
 'blockipsuccesssub'           => 'Blocâjo reussi',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] at étâ blocâ.
-<br />Vos pouede consultar la [[Special:Ipblocklist|lista des comptos et de les adrèces IP blocâs]].',
+<br />Vos pouede consultar la [[Special:IPBlockList|lista des comptos et de les adrèces IP blocâs]].',
 'ipb-edit-dropdown'           => 'Modifiâd les rêsons de blocâjo per dèfôt',
 'ipb-unblock-addr'            => 'Dèblocâd $1',
 'ipb-unblock'                 => 'Dèblocâd un compto utilisator ou una adrèce IP',
@@ -1592,7 +1585,7 @@
 'autoblocker'                 => 'Vos avéd étâ blocâ ôtomaticament perce que voutra adrèce IP at étâ dèrriérement utilisâ per « [[User:$1|$1]] ». La rêson fornia por lo blocâjo de $1 est : « $2 ».',
 'blocklogpage'                => 'Historico des blocâjos',
 'blocklogentry'               => 'at blocâ « [[$1]] » - durâ : $2 $3',
-'blocklogtext'                => 'Cen est l’historico des blocâjos et dèblocâjos des utilisators. Les adrèces IP ôtomaticament blocâs sont pas listâs. Consultâd la [[Special:Ipblocklist|lista des utilisators blocâs]] por vêre qui est en èfèt blocâ houé.',
+'blocklogtext'                => 'Cen est l’historico des blocâjos et dèblocâjos des utilisators. Les adrèces IP ôtomaticament blocâs sont pas listâs. Consultâd la [[Special:IPBlockList|lista des utilisators blocâs]] por vêre qui est en èfèt blocâ houé.',
 'unblocklogentry'             => 'at dèblocâ « $1 »',
 'block-log-flags-anononly'    => 'utilisators pas enregistrâs solament',
 'block-log-flags-nocreate'    => 'crèacion de compto dèfendua',
@@ -1629,7 +1622,7 @@
 'lockdbsuccesssub'    => 'Vèrrolyâjo de la bâsa reussi.',
 'unlockdbsuccesssub'  => 'Bâsa dèvèrrolyê.',
 'lockdbsuccesstext'   => 'La bâsa de balyês de {{SITENAME}} est vèrrolyê.
-<br />Oubliâd pas de [[Special:Unlockdb|la dèvèrrolyér]] quand vos aréd chavonâ voutra opèracion de mantegnence.',
+<br />Oubliâd pas de [[Special:UnlockDB|la dèvèrrolyér]] quand vos aréd chavonâ voutra opèracion de mantegnence.',
 'unlockdbsuccesstext' => 'La bâsa de balyês de {{SITENAME}} est dèvèrrolyê.',
 'lockfilenotwritable' => 'Lo fichiér de blocâjo de la bâsa de balyês est pas enscriptiblo. Por blocar ou dèblocar la bâsa de balyês, vos dête povêr ècrire sur lo sèrvior Vouèbe.',
 'databasenotlocked'   => 'La bâsa de balyês est pas vèrrolyê.',
@@ -1656,8 +1649,6 @@
 
 Dens cél câs, vos devréd renomar ou fusionar la pâge manuèlament se vos lo dèsirâd.',
 'movearticle'             => 'Renomar l’articllo :',
-'movenologin'             => 'Pas conèctâ',
-'movenologintext'         => 'Por povêr renomar una pâge, vos dête étre [[Special:Userlogin|conèctâ]] a titro d’utilisator enregistrâ et voutron compto dêt avêr una ancianatât sufisenta.',
 'movenotallowed'          => 'Vos avéd pas la pèrmission de renomar des pâges dessus {{SITENAME}}.',
 'newtitle'                => 'Novél titro :',
 'move-watch'              => 'Siuvre ceta pâge',
@@ -1679,7 +1670,7 @@
 'delete_and_move'         => 'Suprimar et renomar',
 'delete_and_move_text'    => '== Suprèssion requisa ==
 
-L’articllo de dèstinacion « [[$1]] » ègziste ja. Voléd-vos lo suprimar por pèrmetre lo renomâjo ?',
+L’articllo de dèstinacion « [[:$1]] » ègziste ja. Voléd-vos lo suprimar por pèrmetre lo renomâjo ?',
 'delete_and_move_confirm' => 'Ouè, j/y’accèpto de suprimar la pâge de dèstinacion por pèrmetre lo renomâjo.',
 'delete_and_move_reason'  => 'Pâge suprimâ por pèrmetre un renomâjo',
 'selfmove'                => 'Los titros d’origina et de dèstinacion sont los mémos : empossiblo de renomar una pâge sur lyé-méma.',
@@ -1910,7 +1901,7 @@
 'show-big-image'       => 'Émâge en rèsolucion ples hôta',
 'show-big-image-thumb' => '<small>Talye de ceta vua : $1 × $2 pixèles</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerie des novéls fichiérs',
 'imagelisttext'         => "Vê-que una lista de '''$1''' {{PLURAL:$1|fichiér cllassiê|fichiérs cllassiês}} $2.",
 'showhidebots'          => '($1 bots)',
@@ -2197,7 +2188,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifiar ceti fichiér en utilisent una aplicacion de defôr',
-'edit-externally-help' => 'Vêde les [http://meta.wikimedia.org/wiki/Help:External_editors enstruccions] por més d’enformacions.',
+'edit-externally-help' => 'Vêde les [http://www.mediawiki.org/wiki/Manual:External_editors enstruccions] por més d’enformacions.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'totes',
@@ -2255,7 +2246,7 @@
 'recreate'            => 'Recrèar',
 
 # HTML dump
-'redirectingto' => 'Redirèccion vers [[$1]]...',
+'redirectingto' => 'Redirèccion vers [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Voléd-vos rafrèchir ceta pâge (purgiér lo cache) ?
@@ -2400,7 +2391,7 @@
 'version-software-product'         => 'Produit',
 'version-software-version'         => 'Vèrsion',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Chemin d’accès d’un fichiér',
 'filepath-page'    => 'Fichiér :',
 'filepath-submit'  => 'Chemin d’accès',
Index: languages/messages/MessagesYo.php
===================================================================
--- languages/messages/MessagesYo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesYo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,12 +5,8 @@
  * @file
  *
  * @author Demmy
- * @author SPQRobin
- * @author Siebrand
  */
 
-
-
 $messages = array(
 # User preference toggles
 'tog-underline'            => 'Underline links:',
@@ -62,10 +58,13 @@
 'go'               => 'Ó yá',
 'searcharticle'    => 'Ó yá',
 'edit'             => 'Àtúnṣe',
+'create'           => "Ṣè'dá",
 'editthispage'     => "S'àtúnṣe ojúewé yi",
+'create-this-page' => "Ṣè'dá ojúewé yìí",
 'delete'           => 'Paarẹ́',
 'deletethispage'   => 'Pa ojúewé yi rẹ́',
 'protect'          => 'Dábòbò',
+'protectthispage'  => 'Dá àbò bo ojúewé yìí',
 'newpage'          => 'Ojúewé tuntun',
 'talkpage'         => 'Kábárawasọ̀rọ̀ nípa ojúewé yi',
 'talkpagelinktext' => 'Kábárawasọ̀rọ̀',
@@ -77,6 +76,8 @@
 'jumptonavigation' => 'atọ́ka',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'aboutsite'            => 'Nípa {{SITENAME}}',
+'currentevents'        => 'Ìròhìn nísinsìnyí',
 'edithelp'             => "Ìrànlọ́wọ́ láti s'àtúnṣe",
 'edithelppage'         => 'Help:Àtúnṣe',
 'mainpage'             => 'Ojúewé Àkọ́kọ́',
@@ -86,6 +87,7 @@
 
 'badaccess-group0' => "A kò gbàyín l'áyè l'áti ṣe ohun tí ẹ bèrè fún.",
 
+'youhavenewmessages'      => 'Ẹ ní $1 ($2).',
 'newmessageslink'         => 'ìfọ̀rọ̀ránsẹ́ tuntun',
 'youhavenewmessagesmulti' => 'Ẹ ní ìfọ̀rọ̀ránsẹ́ tuntun ni $1',
 'editsection'             => "s'àtúnṣe",
@@ -99,6 +101,7 @@
 'nstab-media'     => 'Ojúewé amóhùnmáwòrán',
 'nstab-special'   => 'Pàtàkì',
 'nstab-mediawiki' => 'Ìfọ̀rọ̀ránsẹ',
+'nstab-category'  => 'Ẹ̀yà',
 
 # General errors
 'viewsource'        => 'Àfihàn ọ̀rọ̀àmì',
@@ -107,36 +110,51 @@
 'titleprotected'    => "This title has been protected from creation by [[User:$1|$1]]. The reason given is ''$2''.",
 
 # Login and logout pages
-'logouttitle'        => 'Ẹnitínṣe tibọsóde',
-'welcomecreation'    => "== Ẹ kú àbọ̀, $1! ==
+'logouttitle'             => 'Ẹnitínṣe tibọsóde',
+'welcomecreation'         => "== Ẹ kú àbọ̀, $1! ==
 
 A ti fi orúkọ yín s'ílẹ̀. Ẹ mọ́ gbàgbé l'áti s'àtúnṣe àwọn ìfẹ́ràn {{SITENAME}} yín.",
-'loginpagetitle'     => 'Ẹnitínṣe tiwọlé',
-'yourname'           => 'Orúkọ ẹnitínṣe (username):',
-'yourpassword'       => 'Ọ̀rọ̀ìpamọ́:',
-'yourpasswordagain'  => 'Tẹkíkọ ọ̀rọ̀ìpamọ́ lẹ́ẹ̀kansí:',
-'remembermypassword' => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi (cookies)",
-'login'              => "Ẹ w'ọlé",
-'userlogin'          => "Ẹ w'ọlé / ẹ fi orúkọ sílẹ̀",
-'logout'             => "Ẹ bọ́s'óde",
-'userlogout'         => "Ẹ ti bọ́s'óde",
-'notloggedin'        => "Ẹ kò tí w'ọlé",
-'nologinlink'        => 'Ẹ fi orúkọ sílẹ̀',
-'createaccount'      => 'Ẹ fi orúkọ sílẹ̀',
-'gotaccountlink'     => "Ẹ w'ọlé",
-'uid'                => 'Nọmba ìdámọ̀ fún ẹnitínṣe:',
-'yourlanguage'       => 'Èdè:',
-'accountcreated'     => 'Ẹ ti fi orúkọ sílẹ̀',
-'accountcreatedtext' => 'A ti fi orúkọ ẹnitínṣe sílẹ̀ fún $1',
-'loginlanguagelabel' => 'Èdè: $1',
+'loginpagetitle'          => 'Ẹnitínṣe tiwọlé',
+'yourname'                => 'Orúkọ ẹnitínṣe (username):',
+'yourpassword'            => 'Ọ̀rọ̀ìpamọ́:',
+'yourpasswordagain'       => 'Tẹkíkọ ọ̀rọ̀ìpamọ́ lẹ́ẹ̀kansí:',
+'remembermypassword'      => "Sè'rántí ọ̀rọ̀ìpamí mi lórí kọmputa yi (cookies)",
+'loginproblem'            => '<b>Ẹ ní ìṣòro láti wọlé.</b><br />Ẹ gbìyànjú lẹ́kan sí!',
+'login'                   => "Ẹ w'ọlé",
+'nav-login-createaccount' => 'Ẹ wọlẹ́ / Ẹ fi orúkọ sílẹ̀',
+'userlogin'               => "Ẹ w'ọlé / ẹ fi orúkọ sílẹ̀",
+'logout'                  => "Ẹ bọ́s'óde",
+'userlogout'              => "Ẹ ti bọ́s'óde",
+'notloggedin'             => "Ẹ kò tí w'ọlé",
+'nologinlink'             => 'Ẹ fi orúkọ sílẹ̀',
+'createaccount'           => 'Ẹ fi orúkọ sílẹ̀',
+'gotaccountlink'          => "Ẹ w'ọlé",
+'createaccountmail'       => 'pẹ̀lú e-mail',
+'uid'                     => 'Nọmba ìdámọ̀ fún ẹnitínṣe:',
+'yourlanguage'            => 'Èdè:',
+'accountcreated'          => 'Ẹ ti fi orúkọ sílẹ̀',
+'accountcreatedtext'      => 'A ti fi orúkọ ẹnitínṣe sílẹ̀ fún $1',
+'loginlanguagelabel'      => 'Èdè: $1',
 
 # Edit pages
-'savearticle' => 'Ẹ fi pamọ́',
-'preview'     => 'Àyẹ̀wò',
-'showpreview' => 'Àyẹ̀wò',
-'showdiff'    => 'Àfihàn àwọn àyípadà',
-'newarticle'  => '(Tuntun)',
+'minoredit'        => 'Àtúnṣe kékeré nìyí',
+'watchthis'        => "M'ójútó ojúewé yìí",
+'savearticle'      => 'Ẹ fi pamọ́',
+'preview'          => 'Àyẹ̀wò',
+'showpreview'      => 'Àyẹ̀wò',
+'showdiff'         => 'Àfihàn àwọn àyípadà',
+'anoneditwarning'  => "'''Ìkìlọ̀:''' Ẹ ò tíì wọlé.
+Á ṣe àkọsílẹ̀ ojúọ̀nà IP yín ninu ìwé àtúnṣe ojúewé yìí.",
+'newarticle'       => '(Tuntun)',
+'note'             => '<strong>Àkíyèsí:</strong>',
+'copyrightwarning' => 'Ẹ jọ̀wọ́ ẹ kíyèsi wípé gbogbo àwọn àfikún sí {{SITENAME}} jẹ́ bẹ̀ lábẹ́  $2 (Ẹ wo $1 fún ẹkunrẹrẹ ).
+If you do not want your writing to be edited mercilessly and redistributed at will, then do not submit it here.<br />
+You are also promising us that you wrote this yourself, or copied it from a public domain or similar free resource.
+<strong>Ẹ mọ́ fi iṣẹ́ ẹlòmíràn sílẹ̀ láì gbàṣẹ!</strong>',
 
+# Revision deletion
+'rev-delundel' => 'fihàn/fipamọ́',
+
 # Search results
 'powersearch' => 'Ṣe àwáàrí',
 
@@ -147,7 +165,7 @@
 # Recent changes
 'recentchanges' => 'Àwọn àtúnṣe tuntun',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Orúkọ',
 'imagelist_user' => 'Ẹnitínṣe',
 
@@ -163,13 +181,15 @@
 'specialloguserlabel'  => 'Ẹnitínṣe:',
 'speciallogtitlelabel' => 'Àkọlé:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Gbogbo ojúewé',
 'allarticles'       => 'Gbogbo ojúewé',
 'allinnamespace'    => 'Gbogbo ojúewé ($1 namespace)',
 'allnotinnamespace' => 'Gbogbo ojúewé (tí kòsí ní $1 namespace)',
 
 # Watchlist
+'watchlist'       => 'Ìmójútó mi',
+'mywatchlist'     => 'Ìmójútó mi',
 'watch'           => "M'ójútó",
 'watchthispage'   => "M'ójútó ojúewé yi",
 'unwatch'         => "Já'wọ́ ìmójútó",
@@ -183,6 +203,7 @@
 'mycontris'     => 'Àwọn àfikún mi',
 
 # What links here
+'whatlinkshere'      => 'Ìjápọ̀ mọ́ ojúewé yí',
 'whatlinkshere-page' => 'Ojúewé:',
 
 # Namespace 8 related
Index: languages/messages/MessagesKab.php
===================================================================
--- languages/messages/MessagesKab.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKab.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,7 @@
  * @file
  *
  * @author Agurzil
- * @author Siebrand
- * @author SPQRobin
  * @author Agzennay
- * @author Jon Harald Søby
  * @author Teak
  */
 
@@ -281,7 +278,7 @@
 'nosuchaction'      => 'Tigawt ulac-itt',
 'nosuchactiontext'  => 'Wiki ur teɛqil ara tigawt-nni n URL',
 'nosuchspecialpage' => 'Asebter uslig am wagi ulac-it.',
-'nospecialpagetext' => 'Tseqsiḍ ɣef usebter uslig ulac-it, tzemreḍ ad tafeḍ isebtar usligen n ṣṣeḥ deg [[Special:Specialpages|wumuɣ n isebtar usligen]].',
+'nospecialpagetext' => 'Tseqsiḍ ɣef usebter uslig ulac-it, tzemreḍ ad tafeḍ isebtar usligen n ṣṣeḥ deg [[Special:SpecialPages|wumuɣ n isebtar usligen]].',
 
 # General errors
 'error'                => 'Agul',
@@ -475,10 +472,6 @@
 'blockededitsource'         => "Aḍris n '''ubeddel inek''' i '''$1''' hat deg ukessar:",
 'whitelistedittitle'        => 'Yessefk ad tkecmeḍ iwakken ad tbeddleḍ',
 'whitelistedittext'         => 'Yessefk ad $1 iwakken ad tbeddleḍ isebtar.',
-'whitelistreadtitle'        => 'Yessefk ad tkecmeḍ iwakken ad teqqareḍ',
-'whitelistreadtext'         => 'Yessefk ad [[Special:Userlogin|tkecmeḍ]] iwakken ad teɣriḍ isebtar.',
-'whitelistacctitle'         => 'Ur tettalaseḍ ara ad txelqeḍ isem n wemseqdac',
-'whitelistacctext'          => 'Akken ad txelqeḍ isem n wemseqdac deg wiki-yagi yessefk ad [[Special:Userlogin|tkecmeḍ]] u tesɛa izerfan usligen.',
 'confirmedittitle'          => 'Yessef ad tsentmeḍ e-mail inek iwakken ad tbeddleḍ',
 'confirmedittext'           => 'Yessefk ad tsentmeḍ tansa e-mail inek uqbel abeddel. Xtar tansa e-mail di [[Special:Preferences|isemyifiyen n wemseqdac]].',
 'nosuchsectiontitle'        => 'Amur ulac-it',
@@ -493,7 +486,7 @@
 Akken ad txelqeḍ asebter-nni, aru deg tenkult i tella deg ukessar
 (ẓer [[{{MediaWiki:Helppage}}|asebter n tallat]] akken ad tessneḍ kter).
 Ma tɣelṭeḍ, wekki kan ɣef tqeffalt "Back/Précédent" n browser/explorateur inek.',
-'anontalkpagetext'          => "----''Wagi d asebter n umyennan n wemseqdac adrig. Ihi, yessef ad as nefk ID, nesseqdac tansa IP ines akken a t-neɛqel. Tansa IP nni ahat tettuseqdac sɣur aṭṭas n yimdanen. Lukan ula d kečč aqla-k amseqdac adrig u ur tebɣiḍ ara ad tettwabcreḍ izen am wigini, ihi [[Special:Userlogin|xleq isem n wemseqdac neɣ kcem]].''",
+'anontalkpagetext'          => "----''Wagi d asebter n umyennan n wemseqdac adrig. Ihi, yessef ad as nefk ID, nesseqdac tansa IP ines akken a t-neɛqel. Tansa IP nni ahat tettuseqdac sɣur aṭṭas n yimdanen. Lukan ula d kečč aqla-k amseqdac adrig u ur tebɣiḍ ara ad tettwabcreḍ izen am wigini, ihi [[Special:UserLogin|xleq isem n wemseqdac neɣ kcem]].''",
 'noarticletext'             => 'Ulac aḍris deg usebter-agi, tzemreḍ ad [[Special:Search/{{PAGENAME}}|tnadiḍ ɣef wezwel n usebter-agi]] deg isebtar wiyaḍ neɣ [{{fullurl:{{FULLPAGENAME}}|action=edit}} tettbeddileḍ asebter-agi].',
 'clearyourcache'            => "'''Tamawt:''' Beɛd asmekti, ahat yessefk ad temḥuḍ lkac n browser/explorateur inek akken teẓriḍ ibeddlen. '''Mozilla / Firefox / Safari:''' qqim twekkiḍ ''Shift'' u wekki ɣef ''Reload/Recharger'', neɣ wekki ɣef ''Ctrl-Shift-R'' (''Cmd-Shift-R'' deg Apple Mac); '''IE:''' qqim twekkiḍ ɣef ''Ctrl'' u wekki ɣef ''Refresh/Actualiser'', neɣ wekki ɣef ''Ctrl-F5''; '''Konqueror:''': wekki kan ɣef taqeffalt ''Reload'', neɣ wekki ɣef ''F5''; '''Opera''' yessefk ad tesseqdceḍ ''Tools→Preferences/Outils→Préférences'' akken ad temḥud akk lkac.",
 'usercssjsyoucanpreview'    => "<strong>Tixidest:</strong> Sseqdec taqeffalt 'Ssken pre-timeẓriwt' iwakken ad tɛerḍeḍ CSS/JS amynut inek uqbel ad tesmektiḍ.",
@@ -549,7 +542,7 @@
 'edittools'                 => '<!-- Aḍris yettbanen-d seddaw talɣa n ubeddil d uzen. -->',
 'nocreatetitle'             => 'Axleq n isebtar meḥdud',
 'nocreatetext'              => 'Adeg n internet agi iḥedded axleq n isebtar imaynuten.
-Tzemreḍ a d-uɣaleḍ u tbeddleḍ asebter i yellan, neɣ ad [[Special:Userlogin|tkecmeḍ neɣ ad txelqeḍ isem n wemseqdac]].',
+Tzemreḍ a d-uɣaleḍ u tbeddleḍ asebter i yellan, neɣ ad [[Special:UserLogin|tkecmeḍ neɣ ad txelqeḍ isem n wemseqdac]].',
 
 # "Undo" feature
 'undo-success' => 'Tzemreḍ ad tessefsuḍ abeddil. Ssenqed asidmer akken ad tessneḍ ayen tebɣiḍ ad txdmeḍ d ṣṣeḥ, umbeɛd smekti ibeddlen u tkemmleḍ ad tessefsuḍ abeddil.',
@@ -665,7 +658,7 @@
 'preferences'              => 'Isemyifiyen',
 'mypreferences'            => 'Isemyifiyen inu',
 'prefsnologin'             => 'Ur tekcimeḍ ara',
-'prefsnologintext'         => 'Yessefk ad [[Special:Userlogin|tkecmeḍ]] iwakken textareḍ isemyifiyen inek.',
+'prefsnologintext'         => 'Yessefk ad [[Special:UserLogin|tkecmeḍ]] iwakken textareḍ isemyifiyen inek.',
 'prefsreset'               => 'Iɛawed ad yexdem isemyifiyen inek.',
 'qbsettings'               => 'Tanuga taǧiḥbuṭ',
 'qbsettings-none'          => 'Ulaḥedd',
@@ -777,11 +770,11 @@
 'reupload'                    => 'Ɛiwed azen',
 'reuploaddesc'                => 'Uɣal-d ar talɣa n tuznin.',
 'uploadnologin'               => 'Ur tekcimeḍ ara',
-'uploadnologintext'           => 'Yessefk [[Special:Userlogin|ad tkecmeḍ]]
+'uploadnologintext'           => 'Yessefk [[Special:UserLogin|ad tkecmeḍ]]
 iwakken ad tazneḍ afaylu.',
 'upload_directory_read_only'  => 'Weserver/serveur Web ur yezmir ara ad yaru deg ($1).',
 'uploaderror'                 => 'Agul deg usekcam',
-'uploadtext'                  => "Sseqdec talɣa deg ukessar akken ad tazeneḍ tugnawin, akken ad teẓred neɣ ad tnadiḍ tugnawin yettwaznen, ruḥ ɣer [[Special:Imagelist|umuɣ n usekcam n tugnawin]], Amezruy n usekcam d umḥay hatent daɣen deg [[Special:Log/upload|amezruy n usekcam]].
+'uploadtext'                  => "Sseqdec talɣa deg ukessar akken ad tazeneḍ tugnawin, akken ad teẓred neɣ ad tnadiḍ tugnawin yettwaznen, ruḥ ɣer [[Special:ImageList|umuɣ n usekcam n tugnawin]], Amezruy n usekcam d umḥay hatent daɣen deg [[Special:Log/upload|amezruy n usekcam]].
 
 Akken ad tessekcmeḍ tugna deg usebter, seqdec azay am wagi
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Afaylu.jpg]]</nowiki>''',
@@ -849,7 +842,7 @@
 'upload_source_url'  => ' (URL saḥiḥ)',
 'upload_source_file' => ' (afaylu deg uselkim inek)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Nadi ɣef yisem n tugna:',
 'imgfile'               => 'afaylu',
 'imagelist'             => 'Umuɣ n tugniwin',
@@ -990,7 +983,7 @@
 'logempty'             => 'Ur yufi ara deg uɣmis.',
 'log-title-wildcard'   => 'Nadi ɣef izwal i yebdan s uḍris-agi',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Akk isebtar',
 'alphaindexline'    => '$1 ar $2',
 'nextpage'          => 'Asebter ameḍfir ($1)',
@@ -1010,14 +1003,14 @@
 'categories'         => 'Taggayin',
 'categoriespagetext' => 'Llant taggayin-agi deg wiki-yagi.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Ssken imseqdacen seg:',
 'listusers-submit'   => 'Ssken',
 'listusers-noresult' => 'Ur yufi ḥedd (amseqdac).',
 
 # E-mail user
 'mailnologin'     => 'Ur yufi ḥedd (tansa)',
-'mailnologintext' => 'Yessefk ad [[Special:Userlogin|tkecmeḍ]] u tesɛiḍ tansa e-mail ṭaṣhiḥt deg [[Special:Preferences|isemyifiyen]] inek
+'mailnologintext' => 'Yessefk ad [[Special:UserLogin|tkecmeḍ]] u tesɛiḍ tansa e-mail ṭaṣhiḥt deg [[Special:Preferences|isemyifiyen]] inek
 iwakken ad tazneḍ email i imseqdacen wiyaḍ.',
 'emailuser'       => 'Azen e-mail i wemseqdac-agi',
 'emailpage'       => 'Azen e-mail i wemseqdac',
@@ -1046,11 +1039,11 @@
 'nowatchlist'          => 'Umuɣ n uɛessi inek d ilem.',
 'watchlistanontext'    => 'G leɛnaya-k $1 iwakken ad twalaḍ neɣ tbeddleḍ iferdas deg wumuɣ n uɛessi inek.',
 'watchnologin'         => 'Ur tekcimeḍ ara',
-'watchnologintext'     => 'Yessefk ad [[Special:Userlogin|tkecmeḍ]] iwakken ad tbeddleḍ umuɣ n uɛessi inek.',
+'watchnologintext'     => 'Yessefk ad [[Special:UserLogin|tkecmeḍ]] iwakken ad tbeddleḍ umuɣ n uɛessi inek.',
 'addedwatch'           => 'Yerna ɣer wumuɣ n uɛessi',
 'addedwatchtext'       => "Asebter \"[[:\$1]]\" yettwarnu deg [[Special:Watchlist|wumuɣ n uɛessi]] inek.
 Ma llan ibeddlen deg usebter-nni neɣ deg usbtar umyennan ines, ad banen dagi,
-Deg [[Special:Recentchanges|wumuɣ n yibeddlen imaynuten]] ad banen s '''yisekkilen ibberbuzen''' (akken ad teẓriḍ).
+Deg [[Special:RecentChanges|wumuɣ n yibeddlen imaynuten]] ad banen s '''yisekkilen ibberbuzen''' (akken ad teẓriḍ).
 
 Ma tebɣiḍ ad tekkseḍ asebter seg wumuɣ n uɛessi inek, wekki ɣef \"Fakk aɛessi\".",
 'removedwatch'         => 'Yettwakkes seg wumuɣ n uɛessi',
@@ -1227,9 +1220,6 @@
 
 Lukan akka, yessefk a t-tedmeḍ weḥdek.",
 'movearticle'             => 'Smimeḍ asebter',
-'movenologin'             => 'Ur tekcimeḍ ara',
-'movenologintext'         => 'Yessefk ad tesɛuḍ isem n wemseqdac u [[Special:Userlogin|tkecmeḍ]]
-iwakken ad tesmimḍeḍ asebter.',
 'newtitle'                => 'Ar azwel amaynut',
 'move-watch'              => 'Ɛass asebter-agi',
 'movepagebtn'             => 'Smimeḍ asebter',
@@ -1249,7 +1239,7 @@
 'delete_and_move'         => 'Mḥu u smimeḍ',
 'delete_and_move_text'    => '==Amḥay i tebɣiḍ==
 
-Anda tebɣiḍ tesmimeḍ "[[$1]]" yella yagi. tebɣiḍ ad temḥuḍ iwakken yeqqim-d wemkan i usmimeḍ?',
+Anda tebɣiḍ tesmimeḍ "[[:$1]]" yella yagi. tebɣiḍ ad temḥuḍ iwakken yeqqim-d wemkan i usmimeḍ?',
 'delete_and_move_confirm' => 'Ih, mḥu asebter',
 'delete_and_move_reason'  => 'Mḥu iwakken yeqqim-d wemkan i usmimeḍ',
 'selfmove'                => 'Izwal amezwaru d uneggaru kif-kif; ur yezmir ara ad yesmimeḍ asebter ɣur iman-is.',
@@ -1427,7 +1417,7 @@
 'show-big-image'       => 'Resolution tameqqrant',
 'show-big-image-thumb' => '<small>Tiddi n pre-timeẓriwt-agi: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Umuɣ n ifayluwen imaynuten',
 'imagelisttext'         => "Deg ukessar yella wumuɣ n '''$1''' {{PLURAL:$1|ufaylu|yifayluwen}} $2.",
 'noimages'              => 'Tugna ulac-itt.',
@@ -1445,7 +1435,7 @@
 
 # External editor support
 'edit-externally'      => 'Beddel afaylu-yagi s usnas aberrani.',
-'edit-externally-help' => 'Ẓer [http://meta.wikimedia.org/wiki/Help:External_editors taknut] iwakken ad tessneḍ kter.',
+'edit-externally-help' => 'Ẓer [http://www.mediawiki.org/wiki/Manual:External_editors taknut] iwakken ad tessneḍ kter.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'akk',
@@ -1511,7 +1501,7 @@
 'recreate'            => 'Ɛiwed xleq',
 
 # HTML dump
-'redirectingto' => 'Asemmimeḍ ar [[$1]]...',
+'redirectingto' => 'Asemmimeḍ ar [[:$1]]...',
 
 # action=purge
 'confirm_purge' => 'Mḥu lkac n usebter-agi?
Index: languages/messages/MessagesNa.php
===================================================================
--- languages/messages/MessagesNa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -91,7 +91,7 @@
 # Miscellaneous special pages
 'move' => 'Memori',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'nuwa ko',
 
 # E-mail user
@@ -111,7 +111,7 @@
 # Contributions
 'contributions' => 'Mana engame totow inne',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Anani ko',
 
 );
Index: languages/messages/MessagesNe.php
===================================================================
--- languages/messages/MessagesNe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
  * @author ne.wikipedia.org sysops
  */
 
@@ -221,8 +219,6 @@
 'blockedoriginalsource'  => "'''$1''' को स्रोत तल देखाइएको छ:",
 'whitelistedittitle'     => 'सम्पादन गर्नको लागि प्रवेश (लग इन) आवश्यक छ',
 'whitelistedittext'      => 'पाना सम्पादन गर्न तपाँईले $1 गर्नु पर्दछ।',
-'whitelistreadtitle'     => 'यो सामाग्री पढ्नको लागि तपाइले प्रवेश गरेको हुनुपर्दछ।',
-'whitelistacctitle'      => 'तपाईंले खाता खोल्न पाउनु हुन्न',
 'confirmedittitle'       => 'सम्पादन गर्न इमेल पुष्टि गर्नु आवस्यक छ',
 'loginreqlink'           => 'प्रवेश (लग ईन)',
 'accmailtitle'           => 'पासवर्ड पठाइयो',
@@ -308,7 +304,7 @@
 
 'nolicense' => 'केहिपनि छानिएन',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_date'        => 'मिति',
 'imagelist_name'        => 'नाम',
 'imagelist_user'        => 'प्रयोगकर्ता',
@@ -360,7 +356,7 @@
 'specialloguserlabel'  => 'प्रयोगकर्ता:',
 'speciallogtitlelabel' => 'शिर्षक:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'सबै पृष्ठहरु',
 'alphaindexline' => '$1 लाई $2 मा',
 'nextpage'       => 'अर्को पृष्ठ ($1)',
@@ -373,12 +369,12 @@
 # Special:Categories
 'categories' => 'श्रेणीहरू',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'देखाउनुहोस्',
 
 # E-mail user
 'mailnologin'     => 'ईमेल पठाउने ठेगाना नै भएन ।',
-'mailnologintext' => 'तपाईले अरु प्रयोगकर्ताहरुलाई ईमेल पठाउनको लागी आफु पहिले [[Special:Userlogin|प्रवेश(लगइन)गरेको]] हुनुपर्छ र [[Special:Preferences|आफ्नो रोजाइहरुमा]] यौटा वैध ईमेल ठेगाना भएको हुनुपर्छ।',
+'mailnologintext' => 'तपाईले अरु प्रयोगकर्ताहरुलाई ईमेल पठाउनको लागी आफु पहिले [[Special:UserLogin|प्रवेश(लगइन)गरेको]] हुनुपर्छ र [[Special:Preferences|आफ्नो रोजाइहरुमा]] यौटा वैध ईमेल ठेगाना भएको हुनुपर्छ।',
 'emailuser'       => 'यो प्रयोगकर्तालाई ई-मेल पठाउनुहोस्',
 'emailpage'       => 'प्रयोगकर्तालाई इमेल गर्नुहोस्',
 'noemailtitle'    => 'ईमेल ठेगाना नभएको',
@@ -392,7 +388,7 @@
 'mywatchlist'          => 'मेरो अवलोकनसूची',
 'nowatchlist'          => 'तपाईको अवलोकन(वाचलिस्ट)मा कुनैपनि चिज छैन।',
 'watchnologin'         => 'प्रवेश (लग ईन) नगरिएको',
-'watchnologintext'     => 'आफ्नो अवलोकनलाइ परिवर्तन गर्नको लागि त तपाइ यसमा [[Special:Userlogin|प्रवेश(लगइन)]] गर्नुपर्छ।',
+'watchnologintext'     => 'आफ्नो अवलोकनलाइ परिवर्तन गर्नको लागि त तपाइ यसमा [[Special:UserLogin|प्रवेश(लगइन)]] गर्नुपर्छ।',
 'addedwatch'           => 'अवलोकनसूची मा थपियो',
 'watch'                => 'अवलोकन',
 'watchthispage'        => 'यो पृष्ठ अवलोकन गर्नुहोस्',
@@ -460,7 +456,6 @@
 # Move page
 'move-page-legend'        => 'पृष्ठ सार्नुहोस्',
 'movearticle'             => 'पृष्ठ सार्नुहोस्',
-'movenologin'             => 'प्रवेश (लग ईन) नगरिएको',
 'movepagebtn'             => 'पृष्ठ सार्नुहोस्',
 'pagemovedsub'            => 'सार्ने काम सफल भयो',
 'movedto'                 => 'मा सारियो',
@@ -521,7 +516,7 @@
 'previousdiff' => '← अधिल्लो भिन्नता',
 'nextdiff'     => 'पछिल्लो भिन्नता →',
 
-# Special:Newimages
+# Special:NewImages
 'noimages' => 'हेर्नको लागि केही छैन.',
 'ilsubmit' => 'खोज्नुहोस्',
 'bydate'   => 'मिति अनुसार',
@@ -618,7 +613,7 @@
 # Live preview
 'livepreview-loading' => 'लोड गरिंदै छ…',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'फाइल',
 
 # Special:SpecialPages
Index: languages/messages/MessagesFo.php
===================================================================
--- languages/messages/MessagesFo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,11 @@
  * @ingroup Language
  * @file
  *
- * @author Spacebirdy
- * @author לערי ריינהארט
- * @author M.M.S.
  * @author Krun
- * @author S.Örvarr.S
- * @author Siebrand
  * @author Quackor
- * @author SPQRobin
- * @author Jon Harald Søby
+ * @author S.Örvarr.S
+ * @author Spacebirdy
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -345,7 +341,7 @@
 'nosuchspecialpage' => 'Ongin slík serlig síða',
 'nospecialpagetext' => "<big>'''Tú hevur biðið um eina serliga síðu, sum wiki ikki kennir aftur.'''</big>
 
-<!-- A list of valid special pages can be found at [[Special:Specialpages]]. -->",
+<!-- A list of valid special pages can be found at [[Special:SpecialPages]]. -->",
 
 # General errors
 'error'             => 'Villa',
@@ -470,7 +466,7 @@
 Ert tú komin higar av einum mistaki, kanst tú trýsta á '''aftur'''-knøttin á kagaranum.",
 'anontalkpagetext'         => "----''Hetta er ein kjaksíða hjá einum dulnevndum brúkara, sum ikki hevur stovnað eina kontu enn, ella ikki brúkar hana. Tí noyðast vit at brúka nummerisku IP-adressuna hjá honum ella henni.
 Ein slík IP-adressa kann verða brúkt av fleiri brúkarum.
-Ert tú ein dulnevndur brúkari, og kennir, at óvikomandi viðmerkingar eru vendar til tín, so vinarliga [[Special:Userlogin|stovna eina kontu]] fyri at sleppa undan samanblanding við aðrar dulnevndar brúkarar í framtíðini.''",
+Ert tú ein dulnevndur brúkari, og kennir, at óvikomandi viðmerkingar eru vendar til tín, so vinarliga [[Special:UserLogin|stovna eina kontu]] fyri at sleppa undan samanblanding við aðrar dulnevndar brúkarar í framtíðini.''",
 'clearyourcache'           => "'''Viðmerking:''' Eftir at hava goymt mást tú fara uttanum minnið á sneytara tínum fyri at síggja broytingarnar. '''Mozilla/Safari/Konqueror:''' halt knøttinum ''Shift'' niðri meðan tú trýstir á ''Reload'' (ella trýst ''Ctrl-Shift-R''), '''IE:''' trýst ''Ctrl-F5'', '''Opera:''' trýst F5.",
 'note'                     => '<strong>Viðmerking:</strong>',
 'previewnote'              => '<strong>Minst til at hetta bara er ein forskoðan, sum enn ikki er goymd!</strong>',
@@ -633,7 +629,7 @@
 'upload'            => 'Legg fílu upp',
 'uploadbtn'         => 'Legg fílu upp',
 'uploadnologin'     => 'Ikki ritað inn',
-'uploadnologintext' => 'Tú mást hava [[Special:Userlogin|ritað inn]]
+'uploadnologintext' => 'Tú mást hava [[Special:UserLogin|ritað inn]]
 fyri at leggja fílur upp.',
 'uploadlog'         => 'fílu logg',
 'uploadlogpage'     => 'Fílugerðabók',
@@ -657,7 +653,7 @@
 'license'   => 'Loyvi:',
 'nolicense' => 'Onki valt',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => 'Myndalisti',
 'imagelist_name' => 'Navn',
 'imagelist_user' => 'Brúkari',
@@ -711,7 +707,7 @@
 Tað gevur í miðal '''$5''' broytingar fyri hvørja síðu og '''$6''' skoðanir fyri hvørja broyting.
 
 <!--The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''$7'''.-->",
-'userstatstext' => "Tilsamans  {{PLURAL:$1|er '''1''' skrásettur [[Special:Listusers|brúkari]]|eru '''$1''' skrásettir [[Special:Listusers|brúkarar]]}}. '''$2''' (ella '''$4%''') av hesum {{PLURAL:$2|er umboðsstjóri|eru umboðsstjórar}} (sí $5).",
+'userstatstext' => "Tilsamans  {{PLURAL:$1|er '''1''' skrásettur [[Special:ListUsers|brúkari]]|eru '''$1''' skrásettir [[Special:ListUsers|brúkarar]]}}. '''$2''' (ella '''$4%''') av hesum {{PLURAL:$2|er umboðsstjóri|eru umboðsstjórar}} (sí $5).",
 
 'disambiguations'     => 'Síður við fleirfaldum týdningi',
 'disambiguationspage' => 'Template:fleiri týdningar',
@@ -772,7 +768,7 @@
 'alllogstext'          => 'Samansett sýning av upplegging, striking, friðing, forðing og sysop-gerðabókum.
 Tú kanst avmarka sýningina við at velja gerðabókaslag, brúkaranavn ella ávirkaðu síðuna.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Allar síður',
 'alphaindexline' => '$1 til $2',
 'nextpage'       => 'Næsta síða ($1)',
@@ -787,13 +783,13 @@
 'categories'         => 'Bólkar',
 'categoriespagetext' => 'Eftirfylgjandi bólkar eru í hesu wiki.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Vís brúkarar ið byrja við:',
 'listusers-submit'   => 'Sýna',
 'listusers-noresult' => 'Ongin brúkari var funnin.',
 
 # E-mail user
-'mailnologintext' => 'Tú mást hava [[Special:Userlogin|ritað inn]]
+'mailnologintext' => 'Tú mást hava [[Special:UserLogin|ritað inn]]
 og hava virkandi teldupostadressu í [[Special:Preferences|innstillingum]] tínum
 fyri at senda teldupost til aðrar brúkarar.',
 'emailuser'       => 'Send t-post til brúkara',
@@ -818,7 +814,7 @@
 'addedwatch'           => 'Lagt undir eftirlit',
 'addedwatchtext'       => "Síðan \"<nowiki>\$1</nowiki>\" er løgd undir [[Special:Watchlist|eftirlit]] hjá tær.
 Framtíðar broytingar á hesi síðu og tilknýttu kjaksíðuni verða at síggja her.
-Tá sæst síðan sum '''feit skrift''' í [[Special:Recentchanges|broytingaryvirlitinum]] fyri at gera hana lættari at síggja.
+Tá sæst síðan sum '''feit skrift''' í [[Special:RecentChanges|broytingaryvirlitinum]] fyri at gera hana lættari at síggja.
 
 Vilt tú flyta síðuna undan tínum eftirliti, kanst tú trýsta á \"Strika eftirlit\" á síðuni.",
 'removedwatch'         => 'Strikað úr eftirliti',
@@ -949,7 +945,7 @@
 at læsa dátugrunnin upp aftur tá ið viðgerðin er liðug.',
 'locknoconfirm'     => 'Tú krossaði ikki váttanarkassan.',
 'lockdbsuccesstext' => 'Dátugrunnurin er læstur.
-<br />Minst til at [[Special:Unlockdb|læsa upp]] aftur, tá ið viðgerðin er liðug.',
+<br />Minst til at [[Special:UnlockDB|læsa upp]] aftur, tá ið viðgerðin er liðug.',
 
 # Move page
 'move-page-legend'        => 'Flyt síðu',
@@ -967,7 +963,6 @@
 Hetta kann vera ein ógvuslig og óvæntað flyting av einari vældámdari síðu.
 Vinarliga tryggja tær, at tú skilur avleiðingarnar av hesum áðrenn tú heldur áfam.",
 'movearticle'             => 'Flyt síðu:',
-'movenologin'             => 'Hevur ikki ritað inn',
 'newtitle'                => 'Til nýtt heiti:',
 'move-watch'              => 'Hav eftirlit við hesi síðuni',
 'movepagebtn'             => 'Flyt síðu',
@@ -984,7 +979,7 @@
 'delete_and_move'         => 'Strika og flyt',
 'delete_and_move_text'    => '==Striking krevst==
 
-Grein við navninum "[[$1]]" finst longu. Ynskir tú at strika hana til tess at skapa pláss til flytingina?',
+Grein við navninum "[[:$1]]" finst longu. Ynskir tú at strika hana til tess at skapa pláss til flytingina?',
 'delete_and_move_confirm' => 'Ja, strika hesa síðuna',
 'delete_and_move_reason'  => 'Strika til at gera pláss til flyting',
 
@@ -1089,7 +1084,7 @@
 'file-info-size' => '($1 × $2 pixel, stødd fílu: $3, MIME-slag: $4)',
 'svg-long-desc'  => '(SVG fíle, nominelt $1 × $2 pixel, fíle stødd: $3)',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Nýggjar myndir',
 'noimages'  => 'Einki at síggja.',
 'ilsubmit'  => 'Leita',
@@ -1164,7 +1159,7 @@
 'version-version'          => 'Útgáva',
 'version-software-version' => 'Útgáva',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Fíla:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesPt_br.php
===================================================================
--- languages/messages/MessagesPt_br.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPt_br.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author 555
- * @author Siebrand
+ * @author LeonardoG
  * @author Lijealso
- * @author SPQRobin
- * @author לערי ריינהארט
- * @author Yves Marques Junqueira
  * @author Rodrigo Calanca Nishino
- * @author LeonardoG
+ * @author Yves Marques Junqueira
+ * @author לערי ריינהארט
+ * @author 555
  */
 
 $fallback = 'pt'; 
@@ -62,86 +60,89 @@
 #$linkTrail = '/^([a-z]+)(.*)$/sD';# ignore list
 
 $specialPageAliases = array(
-	'DoubleRedirects'           => array( 'Redirecionamentos_duplos', 'redirecionamentos_duplos' ),
-	'BrokenRedirects'           => array( 'Redirecionamentos_quebrados', 'redirecionamentos_quebrados' ),
-	'Disambiguations'           => array( 'Páginas_de_desambiguação', 'Desambiguar', 'Desambiguações' ),
-	'Userlogin'                 => array( 'Entrar', 'Login' ),
-	'Userlogout'                => array( 'Sair', 'Logout' ),
-	'CreateAccount'             => array( 'Criar_conta' ),
-	'Preferences'               => array( 'Preferências' ),
-	'Watchlist'                 => array( 'Páginas_vigiadas', 'Artigos_vigiados', 'Vigiados' ),
-	'Recentchanges'             => array( 'Mudanças_recentes' ),
-	'Upload'                    => array( 'Carregar_imagem', 'Carregar_arquivo', 'Carregar_arquivo', 'Enviar' ),
-	'Imagelist'                 => array( 'Lista_de_imagens', 'Lista_de_arquivos', 'Lista_de_arquivos' ),
-	'Newimages'                 => array( 'Imagens_novas', 'Arquivos_novos', 'Arquivos_novos' ),
-	'Listusers'                 => array( 'Lista_de_usuários', 'Lista_de_usuários' ),
-	'Listgrouprights'           => array( 'Listar_privilégios_de_grupos' ),
-	'Statistics'                => array( 'Estatísticas' ),
-	'Randompage'                => array( 'Aleatória', 'Aleatório', 'Página_aleatória', 'Artigo_aleatório' ),
-	'Lonelypages'               => array( 'Páginas_órfãs', 'Artigos_órfãos', 'Páginas_sem_afluentes', 'Artigos_sem_afluentes' ),
-	'Uncategorizedpages'        => array( 'Páginas_sem_categorias', 'Artigos_sem_categorias' ),
-	'Uncategorizedcategories'   => array( 'Categorias_sem_categorias' ),
-	'Uncategorizedimages'       => array( 'Imagens_sem_categorias', 'arquivos_sem_categorias', 'Arquivos_sem_categorias' ),
-	'Uncategorizedtemplates'    => array( 'Predefinições_não_categorizadas', 'Predefinições_sem_categorias' ),
-	'Unusedcategories'          => array( 'Categorias_não_utilizadas', 'Categorias_sem_uso' ),
-	'Unusedimages'              => array( 'Imagens_sem_uso', 'Imagens_não_utilizadas', 'Arquivos_sem_uso', 'Arquivos_não_utilizados', 'Arquivos_sem_uso', 'Arquivos_não_utilizados' ),
-	'Wantedpages'               => array( 'Páginas_em_falta', 'Artigos_em_falta', 'Páginas_pedidas', 'Artigos_pedidos' ),
-	'Wantedcategories'          => array( 'Categorias_em_falta', 'Categorias_inexistentes' ),
-	'Mostlinked'                => array( 'Páginas_com_mais_afluentes', 'Artigos_com_mais_afluentes' ),
-	'Mostlinkedcategories'      => array( 'Categorias_com_mais_afluentes' ),
-	'Mostlinkedtemplates'       => array( 'Predefinições_com_mais_afluentes' ),
-	'Mostcategories'            => array( 'Páginas_com_mais_categorias', 'Artigos_com_mais_categorias' ),
-	'Mostimages'                => array( 'Imagens_com_mais_afluentes', 'Arquivos_com_mais_afluentes', 'Arquivos_com_mais_afluentes' ),
-	'Mostrevisions'             => array( 'Páginas_com_mais_edições', 'Artigos_com_mais_edições' ),
-	'Fewestrevisions'           => array( 'Páginas_com_menos_edições', 'Artigos_com_menos_edições', 'Artigos_menos_editados' ),
-	'Shortpages'                => array( 'Páginas_curtas', 'Artigos_curtos' ),
-	'Longpages'                 => array( 'Páginas_longas', 'Artigos_extensos' ),
-	'Newpages'                  => array( 'Páginas_novas', 'Artigos_novos' ),
-	'Ancientpages'              => array( 'Páginas_inativas', 'Artigos_inativos' ),
-	'Deadendpages'              => array( 'Páginas_sem_saída', 'Artigos_sem_saída' ),
-	'Protectedpages'            => array( 'Páginas_protegidas', 'Artigos_protegidos' ),
-	'Protectedtitles'           => array( 'Títulos_protegidos' ),
-	'Allpages'                  => array( 'Todas_as_páginas', 'Todos_os_artigos', 'Todas_páginas', 'Todos_artigos' ),
-	'Prefixindex'               => array( 'Índice_de_prefixo', 'Índice_por_prefixo' ),
-	'Ipblocklist'               => array( 'Registro_de_bloqueios', 'Registro_de_bloqueios', 'IPs_bloqueados', 'Usuários_bloqueados', 'Usuários_bloqueados' ),
-	'Specialpages'              => array( 'Páginas_especiais' ),
-	'Contributions'             => array( 'Contribuições' ),
-	'Emailuser'                 => array( 'Contactar_usuário', 'Contactar_usuário', 'Contatar_usuário' ),
-	'Confirmemail'              => array( 'Confirmar_e-mail', 'Confirmar_email' ),
-	'Whatlinkshere'             => array( 'Páginas_afluentes', 'Artigos_afluentes' ),
-	'Recentchangeslinked'       => array( 'Novidades_relacionadas', 'Mudanças_relacionadas' ),
-	'Movepage'                  => array( 'Mover', 'Mover_página', 'Mover_artigo' ),
-	'Blockme'                   => array( 'Bloquear-me', 'Auto-bloqueio' ),
-	'Booksources'               => array( 'Fontes_de_livros' ),
-	'Categories'                => array( 'Categorias' ),
-	'Export'                    => array( 'Exportar' ),
-	'Version'                   => array( 'Versão', 'Sobre' ),
-	'Allmessages'               => array( 'Todas_as_mensagens', 'Todas_mensagens' ),
-	'Log'                       => array( 'Registro', 'Registro', 'Registros', 'Registros' ),
-	'Blockip'                   => array( 'Bloquear', 'Bloquear_IP', 'Bloquear_usuário', 'Bloquear_usuário' ),
-	'Undelete'                  => array( 'Restaurar', 'Restaurar_páginas_eliminadas', 'Restaurar_artigos_eliminados' ),
-	'Import'                    => array( 'Importar' ),
-	'Lockdb'                    => array( 'Bloquear_a_base_de_dados', 'Bloquear_banco_de_dados' ),
-	'Unlockdb'                  => array( 'Desbloquear_a_base_de_dados', 'Desbloquear_banco_de_dados' ),
-	'Userrights'                => array( 'Privilégios', 'Direitos', 'Estatutos' ),
-	'MIMEsearch'                => array( 'Busca_MIME' ),
-	'FileDuplicateSearch'       => array( 'Busca_de_arquivos_duplicados', 'Busca_de_arquivos_duplicados' ),
-	'Unwatchedpages'            => array( 'Páginas_não-vigiadas', 'Páginas_não_vigiadas', 'Artigos_não-vigiados', 'Artigos_não_vigiados' ),
-	'Listredirects'             => array( 'Redirecionamentos', 'Redirecionamentos', 'Lista_de_redirecionamentos', 'Lista_de_redirecionamentos' ),
-	'Revisiondelete'            => array( 'Eliminar_edição', 'Eliminar_revisão', 'Apagar_edição', 'Apagar_revisão' ),
-	'Unusedtemplates'           => array( 'Predefinições_sem_uso', 'Predefinições_não_utilizadas' ),
-	'Randomredirect'            => array( 'Redirecionamento_aleatório', 'Redirecionamento_aleatório' ),
-	'Mypage'                    => array( 'Minha_página' ),
-	'Mytalk'                    => array( 'Minha_discussão' ),
-	'Mycontributions'           => array( 'Minhas_contribuições', 'Minhas_edições', 'Minhas_constribuições' ),
-	'Listadmins'                => array( 'Administradores', 'Admins', 'Lista_de_administradores', 'Lista_de_admins' ),
-	'Listbots'                  => array( 'Bots', 'Lista_de_bots' ),
-	'Popularpages'              => array( 'Páginas_populares', 'Artigos_populares' ),
-	'Search'                    => array( 'Busca', 'Buscar', 'Procurar', 'Pesquisar', 'Pesquisa' ),
-	'Resetpass'                 => array( 'Repor_senha', 'Zerar_senha' ),
-	'Withoutinterwiki'          => array( 'Páginas_sem_interwikis', 'Artigos_sem_interwikis' ),
-	'MergeHistory'              => array( 'Fundir_históricos', 'Fundir_edições' ),
-	'Filepath'                  => array( 'Diretório_de_arquivo', 'Diretório_de_arquivo' ),
+	'DoubleRedirects'         => array( 'Redirecionamentos duplos', 'Redireccionamentos duplos' ),
+	'BrokenRedirects'         => array( 'Redirecionamentos quebrados', 'Redireccionamentos quebrados' ),
+	'Disambiguations'         => array( 'Páginas de desambiguação', 'Desambiguar', 'Desambiguações' ),
+	'Userlogin'               => array( 'Entrar', 'Login' ),
+	'Userlogout'              => array( 'Sair', 'Logout' ),
+	'CreateAccount'           => array( 'Criar conta' ),
+	'Preferences'             => array( 'Preferências' ),
+	'Watchlist'               => array( 'Páginas vigiadas', 'Artigos vigiados', 'Vigiados' ),
+	'Recentchanges'           => array( 'Mudanças recentes' ),
+	'Upload'                  => array( 'Carregar imagem', 'Carregar ficheiro', 'Carregar arquivo', 'Enviar' ),
+	'Imagelist'               => array( 'Lista de imagens', 'Lista de ficheiros', 'Lista de arquivos' ),
+	'Newimages'               => array( 'Imagens novas', 'Ficheiros novos', 'Arquivos novos' ),
+	'Listusers'               => array( 'Lista de usuários', 'Lista de utilizadores' ),
+	'Listgrouprights'         => array( 'Listar privilégios de grupos' ),
+	'Statistics'              => array( 'Estatísticas' ),
+	'Randompage'              => array( 'Aleatória', 'Aleatório', 'Página aleatória', 'Artigo aleatório' ),
+	'Lonelypages'             => array( 'Páginas órfãs', 'Artigos órfãos', 'Páginas sem afluentes', 'Artigos sem afluentes' ),
+	'Uncategorizedpages'      => array( 'Páginas sem categorias', 'Artigos sem categorias' ),
+	'Uncategorizedcategories' => array( 'Categorias sem categorias' ),
+	'Uncategorizedimages'     => array( 'Imagens sem categorias', 'Ficheiros sem categorias', 'Arquivos sem categorias' ),
+	'Uncategorizedtemplates'  => array( 'Predefinições não categorizadas', 'Predefinições sem categorias' ),
+	'Unusedcategories'        => array( 'Categorias não utilizadas', 'Categorias sem uso' ),
+	'Unusedimages'            => array( 'Imagens sem uso', 'Imagens não utilizadas', 'Ficheiros sem uso', 'Ficheiros não utilizados', 'Arquivos sem uso', 'Arquivos não utilizados' ),
+	'Wantedpages'             => array( 'Páginas em falta', 'Artigos em falta', 'Páginas pedidas', 'Artigos pedidos' ),
+	'Wantedcategories'        => array( 'Categorias em falta', 'Categorias inexistentes' ),
+	'Missingfiles'            => array( 'Arquivos em falta', 'Imagens em falta', 'Ficheiros em falta' ),
+	'Mostlinked'              => array( 'Páginas com mais afluentes', 'Artigos com mais afluentes' ),
+	'Mostlinkedcategories'    => array( 'Categorias com mais afluentes' ),
+	'Mostlinkedtemplates'     => array( 'Predefinições com mais afluentes' ),
+	'Mostcategories'          => array( 'Páginas com mais categorias', 'Artigos com mais categorias' ),
+	'Mostimages'              => array( 'Imagens com mais afluentes', 'Ficheiros com mais afluentes', 'Arquivos com mais afluentes' ),
+	'Mostrevisions'           => array( 'Páginas com mais edições', 'Artigos com mais edições' ),
+	'Fewestrevisions'         => array( 'Páginas com menos edições', 'Artigos com menos edições', 'Artigos menos editados' ),
+	'Shortpages'              => array( 'Páginas curtas', 'Artigos curtos' ),
+	'Longpages'               => array( 'Páginas longas', 'Artigos extensos' ),
+	'Newpages'                => array( 'Páginas novas', 'Artigos novos' ),
+	'Ancientpages'            => array( 'Páginas inativas', 'Artigos inativos' ),
+	'Deadendpages'            => array( 'Páginas sem saída', 'Artigos sem saída' ),
+	'Protectedpages'          => array( 'Páginas protegidas', 'Artigos protegidos' ),
+	'Protectedtitles'         => array( 'Títulos protegidos' ),
+	'Allpages'                => array( 'Todas as páginas', 'Todos os artigos', 'Todas páginas', 'Todos artigos' ),
+	'Prefixindex'             => array( 'Índice de prefixo', 'Índice por prefixo' ),
+	'Ipblocklist'             => array( 'Registro de bloqueios', 'IPs bloqueados', 'Utilizadores bloqueados', 'Usuários bloqueados', 'Registo de bloqueios' ),
+	'Specialpages'            => array( 'Páginas especiais' ),
+	'Contributions'           => array( 'Contribuições' ),
+	'Emailuser'               => array( 'Contactar usuário', 'Contactar utilizador', 'Contatar usuário' ),
+	'Confirmemail'            => array( 'Confirmar e-mail', 'Confirmar email' ),
+	'Whatlinkshere'           => array( 'Páginas afluentes', 'Artigos afluentes' ),
+	'Recentchangeslinked'     => array( 'Novidades relacionadas', 'Mudanças relacionadas' ),
+	'Movepage'                => array( 'Mover', 'Mover página', 'Mover artigo' ),
+	'Blockme'                 => array( 'Bloquear-me', 'Auto-bloqueio' ),
+	'Booksources'             => array( 'Fontes de livros' ),
+	'Categories'              => array( 'Categorias' ),
+	'Export'                  => array( 'Exportar' ),
+	'Version'                 => array( 'Versão', 'Sobre' ),
+	'Allmessages'             => array( 'Todas as mensagens', 'Todas mensagens' ),
+	'Log'                     => array( 'Registro', 'Registos', 'Registros', 'Registo' ),
+	'Blockip'                 => array( 'Bloquear', 'Bloquear IP', 'Bloquear utilizador', 'Bloquear usuário' ),
+	'Undelete'                => array( 'Restaurar', 'Restaurar páginas eliminadas', 'Restaurar artigos eliminados' ),
+	'Import'                  => array( 'Importar' ),
+	'Lockdb'                  => array( 'Bloquear banco de dados', 'Bloquear a base de dados' ),
+	'Unlockdb'                => array( 'Desbloquear banco de dados', 'Desbloquear a base de dados' ),
+	'Userrights'              => array( 'Privilégios', 'Direitos', 'Estatutos' ),
+	'MIMEsearch'              => array( 'Busca MIME' ),
+	'FileDuplicateSearch'     => array( 'Busca de arquivos duplicados', 'Busca de ficheiros duplicados' ),
+	'Unwatchedpages'          => array( 'Páginas não-vigiadas', 'Páginas não vigiadas', 'Artigos não-vigiados', 'Artigos não vigiados' ),
+	'Listredirects'           => array( 'Redirecionamentos', 'Lista de redireccionamentos', 'Lista de redirecionamentos', 'Redireccionamentos' ),
+	'Revisiondelete'          => array( 'Eliminar edição', 'Eliminar revisão', 'Apagar edição', 'Apagar revisão' ),
+	'Unusedtemplates'         => array( 'Predefinições sem uso', 'Predefinições não utilizadas' ),
+	'Randomredirect'          => array( 'Redirecionamento aleatório', 'Redireccionamento aleatório' ),
+	'Mypage'                  => array( 'Minha página' ),
+	'Mytalk'                  => array( 'Minha discussão' ),
+	'Mycontributions'         => array( 'Minhas contribuições', 'Minhas edições' ),
+	'Listadmins'              => array( 'Administradores', 'Admins', 'Lista de administradores', 'Lista de admins' ),
+	'Listbots'                => array( 'Bots', 'Lista de bots' ),
+	'Popularpages'            => array( 'Páginas populares', 'Artigos populares' ),
+	'Search'                  => array( 'Busca', 'Buscar', 'Procurar', 'Pesquisar', 'Pesquisa' ),
+	'Resetpass'               => array( 'Zerar senha', 'Repor senha' ),
+	'Withoutinterwiki'        => array( 'Páginas sem interwikis', 'Artigos sem interwikis' ),
+	'MergeHistory'            => array( 'Fundir históricos', 'Fundir edições' ),
+	'Filepath'                => array( 'Diretório de arquivo', 'Diretório de ficheiro' ),
+	'Invalidateemail'         => array( 'Invalidar e-mail' ),
+	'Blankpage'               => array( 'Página em branco' ),
 );
 
 $messages = array(
@@ -423,7 +424,7 @@
 'nosuchspecialpage' => 'Esta página especial não existe',
 'nospecialpagetext' => "<big>'''Você requisitou uma página especial inválida.'''</big>
 
-Uma lista de páginas especiais válidas poderá ser encontrada em [[Special:Specialpages|{{int:specialpages}}]].",
+Uma lista de páginas especiais válidas poderá ser encontrada em [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erro',
@@ -670,10 +671,6 @@
 'blockededitsource'         => "O texto das '''suas edições''' em '''$1''' é mostrado abaixo:",
 'whitelistedittitle'        => 'É necessário autenticar-se para editar páginas',
 'whitelistedittext'         => 'Você precisa $1 para poder editar páginas.',
-'whitelistreadtitle'        => 'É necessária a autentificação para poder visualizar',
-'whitelistreadtext'         => 'Você precisa se [[Special:Userlogin|logar]] para ler artigos.',
-'whitelistacctitle'         => 'Não lhe é permitido criar uma conta',
-'whitelistacctext'          => 'Para poder criar contas de usuário neste Wiki, você precisará estar [[Special:Userlogin|autenticado]] e possuir as devidas permissões.',
 'confirmedittitle'          => 'Confirmação de e-mail requerida para editar',
 'confirmedittext'           => 'Você precisa confirmar o seu endereço de e-mail antes de começar a editar páginas.
 Por favor, introduza um e valide-o através das suas [[Special:Preferences|preferências de usuário]].',
@@ -689,7 +686,7 @@
 Para criá-la, começe escrevendo na caixa abaixo
 (veja [[{{MediaWiki:Helppage}}|a página de ajuda]] para mais informações).
 Se você chegou aqui por engano, apenas clique no botão '''voltar''' do seu navegador.",
-'anontalkpagetext'          => "---- ''Esta é a página de discussão para um usuário anônimo que ainda não criou uma conta ou que não a usa, de forma que temos de utilizar o endereço de IP para identificá-lo(a). Um endereço de IP pode ser compartilhado por vários usuários. Se você é um usuário anônimo e acha irrelevantes os comentários direcionados a você, por gentileza, [[Special:Userlogin|crie uma conta ou autentique-se]], a fim de evitar futuras confusões com outros usuários anônimos.''",
+'anontalkpagetext'          => "---- ''Esta é a página de discussão para um usuário anônimo que ainda não criou uma conta ou que não a usa, de forma que temos de utilizar o endereço de IP para identificá-lo(a). Um endereço de IP pode ser compartilhado por vários usuários. Se você é um usuário anônimo e acha irrelevantes os comentários direcionados a você, por gentileza, [[Special:UserLogin|crie uma conta ou autentique-se]], a fim de evitar futuras confusões com outros usuários anônimos.''",
 'noarticletext'             => 'Não existe atualmente texto nesta página; você pode [[Special:Search/{{PAGENAME}}|pesquisar pelo título desta página em outras páginas]] ou [{{fullurl:{{FULLPAGENAME}}|action=edit}} editar esta página].',
 'userpage-userdoesnotexist' => 'A conta "$1" não se encontra registrada. Por gentileza, verifique se deseja mesmo criar/editar esta página.',
 'clearyourcache'            => "'''Nota:''' Após salvar, terá de limpar a cache do seu navegador para ver as alterações.'''
@@ -751,7 +748,7 @@
 'edittools'                 => '<!-- O texto aqui disponibilizado será exibido abaixo dos formulários de edição e de envio de arquivos. -->',
 'nocreatetitle'             => 'A criação de páginas se encontra limitada',
 'nocreatetext'              => '{{SITENAME}} tem restringida a habilidade de criar novas páginas.
-Volte à tela anterior e edite uma página já existente, ou [[Special:Userlogin|autentique-se ou crie uma conta]].',
+Volte à tela anterior e edite uma página já existente, ou [[Special:UserLogin|autentique-se ou crie uma conta]].',
 'nocreate-loggedin'         => 'Você não possui permissões de criar novas páginas neste wiki.',
 'permissionserrors'         => 'Erros de permissões',
 'permissionserrorstext'     => 'Você não possui permissão de fazer isso, {{PLURAL:$1|pelo seguinte motivo|pelos seguintes motivos}}:',
@@ -870,7 +867,7 @@
 # Suppression log
 'suppressionlog'     => 'Registro de supressões',
 'suppressionlogtext' => 'Abaixo está uma lista das remoções e bloqueios envolvendo conteúdo ocultado por administradores.
-Veja a [[Special:Ipblocklist|lista de bloqueios]] para uma lista de banimentos e bloqueios em efeito neste momento.',
+Veja a [[Special:IPBlockList|lista de bloqueios]] para uma lista de banimentos e bloqueios em efeito neste momento.',
 
 # History merging
 'mergehistory'                     => 'Fundir histórico de páginas',
@@ -954,7 +951,7 @@
 'mypreferences'            => 'Minhas preferências',
 'prefs-edits'              => 'Número de edições:',
 'prefsnologin'             => 'Não autenticado',
-'prefsnologintext'         => 'Precisa estar [[Special:Userlogin|autenticado]] para definir suas preferências.',
+'prefsnologintext'         => 'Precisa estar [[Special:UserLogin|autenticado]] para definir suas preferências.',
 'prefsreset'               => 'As preferências foram restauradas tal como se encontravam no banco de dados.',
 'qbsettings'               => 'Configurações da Barra Rápida',
 'qbsettings-none'          => 'Nenhuma',
@@ -1028,7 +1025,7 @@
 'userrights-reason'           => 'Motivo de alterações:',
 'userrights-no-interwiki'     => 'Você não tem permissão de alterar privilégios de usuários em outras wikis.',
 'userrights-nodatabase'       => 'O banco de dados $1 não existe ou não é um banco de dados local.',
-'userrights-nologin'          => 'Você precisa [[Special:Userlogin|autenticar-se]] como um administrador para especificar os privilégios de usuário.',
+'userrights-nologin'          => 'Você precisa [[Special:UserLogin|autenticar-se]] como um administrador para especificar os privilégios de usuário.',
 'userrights-notallowed'       => 'Sua conta não possui permissão para conceder privilégios a usuários.',
 'userrights-changeable-col'   => 'Grupos que pode alterar',
 'userrights-unchangeable-col' => 'Grupos que não pode alterar',
@@ -1158,12 +1155,12 @@
 'reupload'                    => 'Re-enviar',
 'reuploaddesc'                => 'Cancelar o envio e retornar ao formulário de upload',
 'uploadnologin'               => 'Não autenticado',
-'uploadnologintext'           => 'Você necessita estar [[Special:Userlogin|autenticado]] para enviar arquivos.',
+'uploadnologintext'           => 'Você necessita estar [[Special:UserLogin|autenticado]] para enviar arquivos.',
 'upload_directory_missing'    => 'O diretório de upload ($1) está em falta e não pôde ser criada pelo webserver.',
 'upload_directory_read_only'  => 'O diretório de download de arquivos ($1) não tem permissões de escrita para o servidor Web.',
 'uploaderror'                 => 'Erro ao carregar',
 'uploadtext'                  => "Utilize o formulário abaixo para carregar novos arquivos.
-Para ver ou pesquisar imagens anteriormente carregadas consulte a [[Special:Imagelist|lista de arquivos carregados]].
+Para ver ou pesquisar imagens anteriormente carregadas consulte a [[Special:ImageList|lista de arquivos carregados]].
 Uploads e eliminações são também registadros no [[Special:Log|registro do projeto]].
 
 Para incluír a imagem em uma página, utilize o link na forma de
@@ -1264,7 +1261,7 @@
 'upload_source_url'  => ' (um URL válido, publicamente acessível)',
 'upload_source_file' => ' (um arquivo no seu computador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Esta página especial mostra todos os arquivos carregados.
 Por padrão, os últimos arquivos carregados são mostrados no topo da lista.
 Um clique sobre um cabeçalho de coluna altera a ordenação.',
@@ -1292,7 +1289,7 @@
 'imagelinks'                     => 'Ligações',
 'linkstoimage'                   => '{{PLURAL:$1|A seguinte página aponta|As seguintes $1 páginas apontam}} para este arquivo:',
 'nolinkstoimage'                 => 'Nenhuma página aponta para este arquivo.',
-'morelinkstoimage'               => 'Ver [[Special:Whatlinkshere/$1|mais ligações]] para este arquivo.',
+'morelinkstoimage'               => 'Ver [[Special:WhatLinksHere/$1|mais ligações]] para este arquivo.',
 'redirectstofile'                => '{{PLURAL:$1|O seguinte arquivo redireciona|Os seguintes arquivos redirecionam}} para este arquivo:',
 'duplicatesoffile'               => '{{PLURAL:$1|O seguinte arquivo é duplicado|Os seguintes arquivos são duplicados}} deste arquivo:',
 'sharedupload'                   => 'Este arquivo encontra-se partilhado e pode ser utilizado por outros projetos.',
@@ -1468,7 +1465,7 @@
 'logempty'             => 'Nenhum item idêntico no registro.',
 'log-title-wildcard'   => 'Procurar por títulos que sejam iniciados com o seguinte texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Todas as páginas',
 'alphaindexline'    => '$1 até $2',
 'nextpage'          => 'Próxima página ($1)',
@@ -1491,12 +1488,12 @@
 'special-categories-sort-count' => 'ordenar por contagem',
 'special-categories-sort-abc'   => 'ordenar alfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostrar usuários começando em:',
 'listusers-submit'   => 'Exibir',
 'listusers-noresult' => 'Não foram encontrados usuários para a forma pesquisada.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Privilégios de grupo de usuários',
 'listgrouprights-summary'  => 'A seguinte lista contém os grupos de usuários definidos neste wiki, com os seus privilégios de acessos associados.
 Informação adicional sobre direitos individuais pode ser encontrada [[{{MediaWiki:Listgrouprights-helppage}}|aqui]].',
@@ -1507,7 +1504,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nenhum endereço de envio',
-'mailnologintext' => 'Necessita de estar [[Special:Userlogin|autenticado]] e de possuir um endereço de e-mail válido nas suas [[Special:Preferences|preferências]] para poder enviar um e-mail a outros usuários.',
+'mailnologintext' => 'Necessita de estar [[Special:UserLogin|autenticado]] e de possuir um endereço de e-mail válido nas suas [[Special:Preferences|preferências]] para poder enviar um e-mail a outros usuários.',
 'emailuser'       => 'Contactar este usuário',
 'emailpage'       => 'Contactar usuário',
 'emailpagetext'   => 'Se este usuário disponibilizou um endereço válido de e-mail em suas preferências, o formulário a seguir enviará uma mensagem única.
@@ -1534,10 +1531,10 @@
 'nowatchlist'          => 'A sua lista de vigiados não possui títulos.',
 'watchlistanontext'    => 'Por favor $1 para ver ou editar os itens na sua lista de páginas vigiados.',
 'watchnologin'         => 'Não está autenticado',
-'watchnologintext'     => 'Você precisa estar [[Special:Userlogin|autenticado]] para modificar a sua lista de artigos vigiados.',
+'watchnologintext'     => 'Você precisa estar [[Special:UserLogin|autenticado]] para modificar a sua lista de artigos vigiados.',
 'addedwatch'           => 'Adicionado à lista',
 'addedwatchtext'       => "A página \"[[:\$1]]\" foi adicionada à sua [[Special:Watchlist|lista de vigiados]].
-Modificações futuras em tal página e páginas de discussão a ela associadas serão listadas lá, com a página aparecendo a '''negrito''' na [[Special:Recentchanges|lista de mudanças recentes]], para que possa encontrá-la com maior facilidade.",
+Modificações futuras em tal página e páginas de discussão a ela associadas serão listadas lá, com a página aparecendo a '''negrito''' na [[Special:RecentChanges|lista de mudanças recentes]], para que possa encontrá-la com maior facilidade.",
 'removedwatch'         => 'Removida da lista de páginas vigiados',
 'removedwatchtext'     => 'A página "<nowiki>$1</nowiki>" foi removida de sua lista de páginas vigiadas.',
 'watch'                => 'Vigiar',
@@ -1652,7 +1649,7 @@
 Experimente usar o botão "Voltar" e atualizar a página de onde veio e tente novamente.',
 'protectlogpage'              => 'Registro de proteção',
 'protectlogtext'              => 'Abaixo encontra-se o registro de proteção e desproteção de páginas.
-Veja a [[Special:Protectedpages|lista de páginas protegidas]] para uma listagem das páginas que se encontram protegidas no momento.',
+Veja a [[Special:ProtectedPages|lista de páginas protegidas]] para uma listagem das páginas que se encontram protegidas no momento.',
 'protectedarticle'            => 'protegeu "[[$1]]"',
 'modifiedarticleprotection'   => 'foi alterado o nível de proteção para "[[$1]]"',
 'unprotectedarticle'          => 'desprotegeu "[[$1]]"',
@@ -1794,7 +1791,7 @@
 'ipbreason-dropdown'              => '*Razões comuns para um bloqueio
 ** Inserindo informações falsas
 ** Removendo o conteúdo de páginas
-** Fazendo "spam" de sites externos
+** Fazendo "spam" de sítios externos
 ** Inserindo conteúdo sem sentido/incompreensível nas páginas
 ** Comportamento intimidador/inoportuno
 ** Uso abusivo de contas múltiplas
@@ -1813,7 +1810,7 @@
 'badipaddress'                    => 'Endereço de IP inválido',
 'blockipsuccesssub'               => 'Bloqueio bem sucedido',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] foi bloqueado.<br />
-Consulte a [[Special:Ipblocklist|lista de IPs bloqueados]] para rever os bloqueios.',
+Consulte a [[Special:IPBlockList|lista de IPs bloqueados]] para rever os bloqueios.',
 'ipb-edit-dropdown'               => 'Editar motivos de bloqueio',
 'ipb-unblock-addr'                => 'Desbloquear $1',
 'ipb-unblock'                     => 'Desbloquear um usuário ou endereço de IP',
@@ -1845,7 +1842,7 @@
 'blocklogentry'                   => '"[[$1]]" foi bloqueado com um tempo de expiração de $2 $3',
 'blocklogtext'                    => 'Este é um registro de ações de bloqueio e desbloqueio.
 Endereços IP sujeitos a bloqueio automático não são listados.
-Consulte a [[Special:Ipblocklist|lista de IPs bloqueados]] para obter a lista de bloqueios e banimentos atualmente válidos.',
+Consulte a [[Special:IPBlockList|lista de IPs bloqueados]] para obter a lista de bloqueios e banimentos atualmente válidos.',
 'unblocklogentry'                 => 'desbloqueou $1',
 'block-log-flags-anononly'        => 'apenas usuários anônimos',
 'block-log-flags-nocreate'        => 'criação de contas desabilitada',
@@ -1903,8 +1900,6 @@
 
 Nestes casos, você terá que mover ou mesclar a página manualmente, se assim desejar.",
 'movearticle'             => 'Mover página',
-'movenologin'             => 'Não autenticado',
-'movenologintext'         => 'Você precisa ser um usuário registrado e [[Special:Userlogin|autenticado]] para poder mover uma página.',
 'movenotallowed'          => 'Você não possui permissão de mover páginas neste wiki.',
 'newtitle'                => 'Para novo título',
 'move-watch'              => 'Vigiar esta página',
@@ -1931,7 +1926,7 @@
 'revertmove'              => 'reverter',
 'delete_and_move'         => 'Eliminar e mover',
 'delete_and_move_text'    => '==Eliminação necessária==
-A página de destino ("[[$1]]") já existe. Deseja eliminá-la de modo a poder mover?',
+A página de destino ("[[:$1]]") já existe. Deseja eliminá-la de modo a poder mover?',
 'delete_and_move_confirm' => 'Sim, eliminar a página',
 'delete_and_move_reason'  => 'Eliminada para poder mover outra página para este título',
 'selfmove'                => 'O título fonte e o título destinatário são os mesmos; não é possível mover uma página para ela mesma.',
@@ -2166,7 +2161,7 @@
 'show-big-image'       => 'Resolução completa',
 'show-big-image-thumb' => '<small>Tamanho desta previsão: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria de novos arquivos',
 'imagelisttext'         => "É exibida a seguir uma listagem {{PLURAL:$1|de '''um''' arquivo organizado|de '''$1''' arquivos organizados}} por $2.",
 'newimages-summary'     => 'Esta página especial mostra os arquivos mais recentemente enviados',
@@ -2449,7 +2444,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar este arquivo utilizando uma aplicação externa',
-'edit-externally-help' => 'Consulte as [http://meta.wikimedia.org/wiki/Help:External_editors instruções de instalação] para mais informação.',
+'edit-externally-help' => 'Consulte as [http://www.mediawiki.org/wiki/Manual:External_editors instruções de instalação] para mais informação.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'todas',
@@ -2518,7 +2513,7 @@
 'recreate'            => 'Recriar',
 
 # HTML dump
-'redirectingto' => 'Redirecionando para [[$1]]...',
+'redirectingto' => 'Redirecionando para [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Limpar a memória cache desta página?
@@ -2617,7 +2612,7 @@
 'version-software-product'         => 'Produto',
 'version-software-version'         => 'Versão',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Diretório do arquivo',
 'filepath-page'    => 'arquivo:',
 'filepath-submit'  => 'Diretório',
@@ -2655,7 +2650,7 @@
 'specialpages-group-redirects'   => 'Páginas especias redirecionadas',
 'specialpages-group-spam'        => 'Ferramentas anti-spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Página em branco',
 'intentionallyblankpage' => 'Esta página foi intencionalmente deixada em branco e é usada para medições de performance, etc.',
 
Index: languages/messages/MessagesRoa_rup.php
===================================================================
--- languages/messages/MessagesRoa_rup.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRoa_rup.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,7 +3,8 @@
  *
  * @ingroup Language
  * @file
- * @author Niklas Laxström
+ *
+ * @author Hakka
  * @author Hakka (with the help of a native speaker Dumitrachi T. Fundu)
  */
 
@@ -153,7 +154,7 @@
 # Special:Log
 'log-search-submit' => 'Du-vã',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Du-vã',
 
 # Watchlist
@@ -201,7 +202,7 @@
 'tooltip-pt-logout'      => 'Disligats-vã',
 'tooltip-p-logo'         => 'Prota frãndzã',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Caftã',
 
 # Multipage image navigation
Index: languages/messages/MessagesDsb.php
===================================================================
--- languages/messages/MessagesDsb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDsb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,17 +4,14 @@
  * @ingroup Language
  * @file
  *
- * @author Nepl1
+ * @author Dunak
+ * @author Dundak
  * @author Michawiki
+ * @author Murjarik
+ * @author Nepl1
  * @author Pe7er
  * @author Qualia
- * @author Dundak
- * @author Siebrand
- * @author Murjarik
  * @author Tlustulimu
- * @author SPQRobin
- * @author Jon Harald Søby
- * @author Dunak
  * @author Tlustulimu Nepl1
  */
 
@@ -422,7 +419,7 @@
 'nosuchspecialpage' => 'Toś ten specialny bok njeeksistěrujo',
 'nospecialpagetext' => "<big>'''Toś ten specialny bok w toś tom wikiju njeeksistěrujo'''</big>
 
-Lisćina płaśecych specialnych bokow namakajo se pód [[Special:Specialpages|{{int:specialpages}}]].",
+Lisćina płaśecych specialnych bokow namakajo se pód [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Zmólka',
@@ -659,10 +656,6 @@
 'blockededitsource'                => "Žrědłowy tekst '''Twójich pśinoskow''' do '''$1''' jo:",
 'whitelistedittitle'               => 'Za wobźěłanje dejš se pśizjawiś',
 'whitelistedittext'                => 'Musyš se $1, aby mógał boki wobźěłowaś.',
-'whitelistreadtitle'               => 'Za cytanje dejš se pśizjawiś',
-'whitelistreadtext'                => 'Za cytanje bokow dejš se [[Special:Userlogin|how pśizjawiś]].',
-'whitelistacctitle'                => 'Njamaš pšawo, wužywarske konto załožyś.',
-'whitelistacctext'                 => 'Aby mógał pód {{SITENAME}} wužywarske konta załožyś, musyš [[Special:Userlogin|how se pśizjawiś]] a wótpowědujuce pšawa měś.',
 'confirmedittitle'                 => 'Za wobźěłanje jo wobkšuśenje e-mailki notne.',
 'confirmedittext'                  => 'Nježli až móžoš źěłaš, musyš swóju e-mailowu adresu wobkšuśiś. Pšosym dodaj a wobkšuś swóju e-mailowu adresu w [[Special:Preferences|nastajenjach]].',
 'nosuchsectiontitle'               => 'Wótrězk njeeksistěrujo.',
@@ -676,7 +669,7 @@
 'newarticletext'                   => 'Sy slědował wótkaz na bok, kótaryž hyšći njeeksistěrujo.
 Aby bok wutwórił, ga napiš do kašćika spózy.
 (Dokradnjejše informacije pód: [[{{MediaWiki:Helppage}}|help page]]).',
-'anontalkpagetext'                 => "---- ''Toś ten bok słužy za diskusiju z anonymnym wužywarjom, kótaryž njejo dotychměst žedno wužywarske konto załožył, abo swójo konto njewužywa. Togodla dejmy jogo numerisku ip-adresu wužywaś, aby jogo identificěrowali. Taka ip-adresa móžo wót wšakich wužywarjow se wužywaś. Jolic sy anonymny wužywaŕ a se mysliš, až su se njerelewantne komentary na tebje měrili, pšosym [[Special:Userlogin|załož konto abo pśizjaw se]], až njeby wěcej k takim zamólenjam došło.",
+'anontalkpagetext'                 => "---- ''Toś ten bok słužy za diskusiju z anonymnym wužywarjom, kótaryž njejo dotychměst žedno wužywarske konto załožył, abo swójo konto njewužywa. Togodla dejmy jogo numerisku ip-adresu wužywaś, aby jogo identificěrowali. Taka ip-adresa móžo wót wšakich wužywarjow se wužywaś. Jolic sy anonymny wužywaŕ a se mysliš, až su se njerelewantne komentary na tebje měrili, pšosym [[Special:UserLogin|załož konto abo pśizjaw se]], až njeby wěcej k takim zamólenjam došło.",
 'noarticletext'                    => 'Dotychměst njewopśimjejo toś ten bok hyšći žeden tekst. Móžoš w drugich bokach [[Special:Search/{{PAGENAME}}|za napismom togo boka pytaś]] abo [{{fullurl:{{FULLPAGENAME}}|action=edit}} toś ten bok wobźěłaś].',
 'userpage-userdoesnotexist'        => 'Wužywarske konto "$1" njejo zregistrěrowane. Pšosym pśeglědaj, lěc coš toś ten bok wopšawdu napóraś/wobźěłaś.',
 'clearyourcache'                   => "'''Pokazka: Jo móžno, až dejš wuprozniś cache wobglědowaka, aby změny wiźeł.'''
@@ -734,7 +727,7 @@
 'hiddencategories'                 => 'Toś ten bok jo jadna z {{PLURAL:$1|1 schowaneje kategorije|$1 schowaneju kategorijow|$1 schowanych kategorijow|$1 schowanych kategorijow}}:',
 'edittools'                        => '<!-- Tekst how buźo wiźeś pód wobźěłowańskimi a upload-formularami. -->',
 'nocreatetitle'                    => 'Załožowanje nowych bokow jo se wobgranicowało.',
-'nocreatetext'                     => 'Na {{GRAMMAR:lokatiw|{{SITENAME}}}} jo se załoženje nowych bokow wót serwera wobgranicowało. Móžoš hyś slědk a eksistěrujucy bok wobźěłaś, abo se [[Special:Userlogin|pśizjawiś]].',
+'nocreatetext'                     => 'Na {{GRAMMAR:lokatiw|{{SITENAME}}}} jo se załoženje nowych bokow wót serwera wobgranicowało. Móžoš hyś slědk a eksistěrujucy bok wobźěłaś, abo se [[Special:UserLogin|pśizjawiś]].',
 'nocreate-loggedin'                => 'Njamaš pšawo, w {{GRAMMAR:lokatiw|{{SITENAME}}}} nowy bok załožyś.',
 'permissionserrors'                => 'Problem z pšawami',
 'permissionserrorstext'            => 'Njamaš pšawo to cyniś. {{PLURAL:$1|Pśicyna|Pśicynje|Pśicyny}}:',
@@ -846,7 +839,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Protokol pódłocowanjow',
-'suppressionlogtext' => 'To jo lisćina wulašowanjow a blokěrowanjow, kótaraž ma wopśimjeśe, kótarež jo za administratorow schowane. Glědaj  [[Special:Ipblocklist|lisćinu blokěrowanjow IP]] za lisćinu aktualnych wugnanjow a blokěrowanjow.',
+'suppressionlogtext' => 'To jo lisćina wulašowanjow a blokěrowanjow, kótaraž ma wopśimjeśe, kótarež jo za administratorow schowane. Glědaj  [[Special:IPBlockList|lisćinu blokěrowanjow IP]] za lisćinu aktualnych wugnanjow a blokěrowanjow.',
 
 # History merging
 'mergehistory'                     => 'Zwězaś stawizny bokow',
@@ -930,7 +923,7 @@
 'mypreferences'            => 'móje nastajenja',
 'prefs-edits'              => 'Licba wobźěłanjow:',
 'prefsnologin'             => 'Njejsy pśizjawjony',
-'prefsnologintext'         => 'Musyš se [[Special:Userlogin|pśizjawiś]], aby mógał swóje nastajenja změniś.',
+'prefsnologintext'         => 'Musyš se [[Special:UserLogin|pśizjawiś]], aby mógał swóje nastajenja změniś.',
 'prefsreset'               => 'Nastajenja su ze składa se wótnowili. Twóje změny njejsu se składowali.',
 'qbsettings'               => 'Bocna lejstwa',
 'qbsettings-none'          => 'Žedne',
@@ -1004,7 +997,7 @@
 'userrights-reason'           => 'Pśicyna změny:',
 'userrights-no-interwiki'     => 'Njamaš pšawo wužywarske pšawa w drugich wikijach změniś.',
 'userrights-nodatabase'       => 'Datowa banka $1 njeeksistěrujo abo njejo lokalna.',
-'userrights-nologin'          => 'Musyš se z administratorowym kontom [[Special:Userlogin|pśizjawiś]], aby wužywarske pšawa změnił.',
+'userrights-nologin'          => 'Musyš se z administratorowym kontom [[Special:UserLogin|pśizjawiś]], aby wužywarske pšawa změnił.',
 'userrights-notallowed'       => 'Twóje konto njama pšawa, aby wužywarske pšawa změniło.',
 'userrights-changeable-col'   => 'Kupki, kótarež móžoš změniś',
 'userrights-unchangeable-col' => 'Kupki, kótarež njamóžoš změniś',
@@ -1134,13 +1127,13 @@
 'reupload'                    => 'Dataju hyšći raz pósłaś.',
 'reuploaddesc'                => 'Upload pśetergnuś a slědk k uploadowemu formularoju',
 'uploadnologin'               => 'Njepśizjawjony(a)',
-'uploadnologintext'           => 'Dejš se [[Special:Userlogin|pśizjawiś]], aby mógał dataje uploadowaś.',
+'uploadnologintext'           => 'Dejš se [[Special:UserLogin|pśizjawiś]], aby mógał dataje uploadowaś.',
 'upload_directory_missing'    => 'Nagrawański zapis ($1) felujo a njejo se pśez webserwer napóraś dał.',
 'upload_directory_read_only'  => 'Seśowy serwer njamóžo do uploadowego zapisa ($1) pisaś.',
 'uploaderror'                 => 'Zmólka pśi uploadowanju',
 'uploadtext'                  => "Wužyj toś ten formular za uploadowanje nowych datajow.
 
-Źi na [[Special:Imagelist|lisćinu uploadowanych datajow]], aby mógł juž uploadowane dataje pytaś a pokazaś, uploadowanja a lašowanja se teke w [[Special:Log/upload|protokol uploadowanjow]] protokoluju.
+Źi na [[Special:ImageList|lisćinu uploadowanych datajow]], aby mógł juž uploadowane dataje pytaś a pokazaś, uploadowanja a lašowanja se teke w [[Special:Log/upload|protokol uploadowanjow]] protokoluju.
 
 Aby dataju do boka zapśimjeł, wužyj wótkaz we formje
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Dataja.jpg]]</nowiki>''',
@@ -1240,7 +1233,7 @@
 'upload_source_url'  => ' (płaśeca, zjawnje pśistupna URL)',
 'upload_source_file' => ' (dataja na twójom kompjuterje)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Toś ten specialny bok nalicyjo wšykne uploadowane dataje. Normalnje pokazuje se te dataje, ako su slědne se uploadowali, ako prědne w lisćinje. Tłocenje na napise špaltow změnijo sortěrowanje.',
 'imagelist_search_for'  => 'Za medijowym mjenim pytaś:',
 'imgfile'               => 'dataja',
@@ -1266,7 +1259,7 @@
 'imagelinks'                     => 'Wótkaze',
 'linkstoimage'                   => '{{PLURAL:$1|Slědujucy bok wótkazujo|Slědujucej $1 boka wótkazujotej|Slědujuce $1 boki wótkazuju|Slědujucych $1 bokow wótkazujo}} na toś tu dataju:',
 'nolinkstoimage'                 => 'Žedne boki njewótkazuju na toś tu dataju.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Dalšne wótkazy]] k toś tej dataji wobglědaś.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Dalšne wótkazy]] k toś tej dataji wobglědaś.',
 'redirectstofile'                => '{{PLURAL:$1|Slědujuca dataja dalej pósrědnja|Slědujucej $1 dataji dalej pósrědnjatej|slědujuce $1 dataje dalej póšrědnjaju|Slědujucych $1 datajow dalej pósrědnja}} k toś tej dataji:',
 'duplicatesoffile'               => '{{PLURAL:$1|Slědujuca dataja jo duplikat|Slědujucej $1 dataji stej duplikata|Slědujuce dataje $1 su duplikaty|Slědujucych $1 datajow jo duplikaty}} toś teje dataje:',
 'sharedupload'                   => 'Toś ta dataja se gromaźe wužywa - snaź teke w drugich projektach.',
@@ -1285,18 +1278,18 @@
 # File reversion
 'filerevert'                => 'Slědk wześ $1',
 'filerevert-legend'         => 'Dataju nawrośiś',
-'filerevert-intro'          => '<span class="plainlinks">Nawrośijoš dataju \'\'\'[[Media:$1|$1]]\'\'\' na [$4 wersiju wót $2, $3 góź.].</span>',
+'filerevert-intro'          => "Nawrośijoš dataju '''[[Media:$1|$1]]''' na [$4 wersiju wót $2, $3 góź.].",
 'filerevert-comment'        => 'Komentar:',
 'filerevert-defaultcomment' => 'Nawrośona na wersiju wót $1, $2 góź.',
 'filerevert-submit'         => 'Slědk wześ',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' jo se nawrośiło na [$4 wersiju wót $2, $3 góź.].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' jo se nawrośiło na [$4 wersiju wót $2, $3 góź.].",
 'filerevert-badversion'     => 'Za pódany cas njeeksistěrujo žedna wersija dataje.',
 
 # File deletion
 'filedelete'                  => 'Wulašowaś $1',
 'filedelete-legend'           => 'Wulašowaś dataje',
 'filedelete-intro'            => "Ty wulašujoš '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Wulašujoš [$4 wersiju wót $2, $3 góź.] dataje \'\'\'„[[Media:$1|$1]]“\'\'\'.</span>',
+'filedelete-intro-old'        => "Wulašujoš [$4 wersiju wót $2, $3 góź.] dataje '''„[[Media:$1|$1]]“'''.",
 'filedelete-comment'          => 'Komentar:',
 'filedelete-submit'           => 'Wulašowaś',
 'filedelete-success'          => "'''$1''' wulašowane.",
@@ -1351,7 +1344,7 @@
 To wucynjujo '''$5''' {{PLURAL:$5|wobźěłanje|wobźěłani|wobźěłanja}} na bok a '''$6''' {{PLURAL:$6|wótwołanje|wótwołani|wótwołanja}} na wobźěłanje.
 
 Dłujkosć [http://www.mediawiki.org/wiki/Manual:Job_queue „Job queue“]: '''$7'''",
-'userstatstext'          => "Dajo '''$1''' {{PLURAL:$1|registrěrowanego|registrěrowaneju|registrěrowanych}} [[Special:Listusers|{{PLURAL:$1|wužywarja|wužywarjowu|wužywarjow}}]].
+'userstatstext'          => "Dajo '''$1''' {{PLURAL:$1|registrěrowanego|registrěrowaneju|registrěrowanych}} [[Special:ListUsers|{{PLURAL:$1|wužywarja|wužywarjowu|wužywarjow}}]].
 Wót togo {{PLURAL:$2|jo|stej|su}} '''$2''' (=$4 %) $5.",
 'statistics-mostpopular' => 'Nejwěcej woglědane boki',
 
@@ -1447,7 +1440,7 @@
 'logempty'             => 'Žedne se góźece zapise njeeksistěruju.',
 'log-title-wildcard'   => 'Pytaś nadpismo, kótarež zachopijo z ...',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Wšykne boki',
 'alphaindexline'    => '$1 do $2',
 'nextpage'          => 'Slědujucy bok ($1)',
@@ -1470,12 +1463,12 @@
 'special-categories-sort-count' => 'pśewuběrowaś pó licbje',
 'special-categories-sort-abc'   => 'pśewuběrowaś pó alfabeśe',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Pokaž wužywarjow wót:',
 'listusers-submit'   => 'Pokazaś',
 'listusers-noresult' => 'Žeden wužywaŕ njejo se namakał.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Pšawa wužywarskeje kupki',
 'listgrouprights-summary'  => 'To jo lisćina wužywarskich kupkow definěrowanych w toś tom wikiju z jich zwězanymi pśistupnymi pšawami. Pśidatne informacije wó jadnotliwych pšawach daje so na [[{{MediaWiki:Listgrouprights-helppage}}]] namakaś.',
 'listgrouprights-group'    => 'Kupka',
@@ -1485,7 +1478,7 @@
 
 # E-mail user
 'mailnologin'     => 'Njejo móžno e-mailku pósłaś.',
-'mailnologintext' => 'Dejš [[Special:Userlogin|pśizjawjony]] byś a płaśiwu e-mailowu adresu w swójich [[Special:Preferences|nastajenjach]] měś, aby drugim wužywarjam e-mail pósłał.',
+'mailnologintext' => 'Dejš [[Special:UserLogin|pśizjawjony]] byś a płaśiwu e-mailowu adresu w swójich [[Special:Preferences|nastajenjach]] měś, aby drugim wužywarjam e-mail pósłał.',
 'emailuser'       => 'Toś tomu wužywarjeju e-mail pósłaś',
 'emailpage'       => 'E-mail wužywarjeju',
 'emailpagetext'   => 'Jo-lic toś ten wužywaŕ płaśecu e-mailowu adresu zapódał, móžoš jomu z pomocu dołojcnego formulara e-mail pósłaś. Ako wótpósłaŕ pódajo se e-mailowa adresa z twójich nastajenjow, aby mógał wužywaŕ wótegroniś.',
@@ -1511,11 +1504,11 @@
 'nowatchlist'          => 'Žedne zapise w Twójich wobglědowańkach.',
 'watchlistanontext'    => 'Dejš se $1, aby mógał swóje wobglědowańka wiźeś abo zapise w nich wobźěłaś.',
 'watchnologin'         => 'Njepśizjawjony(a)',
-'watchnologintext'     => 'Musyš byś [[Special:Userlogin|pśizjawjony]], aby mógał swóje wobglědowańka wobźěłaś.',
+'watchnologintext'     => 'Musyš byś [[Special:UserLogin|pśizjawjony]], aby mógał swóje wobglědowańka wobźěłaś.',
 'addedwatch'           => 'Jo k wobglědowańkam se dodało',
 'addedwatchtext'       => 'Bok „<nowiki>$1</nowiki>“ jo k twójim [[Special:Watchlist|wobglědowańkam]] se dodał.
 
-Pózdźejšne změny na toś tom boku a w pśisłušecej diskusiji se tam nalicuju a w pśeglěźe [[Special:Recentchanges|slědnych změnow]] tucnje wóznamjeniju.
+Pózdźejšne změny na toś tom boku a w pśisłušecej diskusiji se tam nalicuju a w pśeglěźe [[Special:RecentChanges|slědnych změnow]] tucnje wóznamjeniju.
 
 Coš-lic bok zasej z twójich wobglědowańkow wulašowaś, kliknij na wótpowědujucem boce na "dalej njewobglědowaś".',
 'removedwatch'         => 'Jo z wobglědowańkow se wulašowało',
@@ -1622,7 +1615,7 @@
 Wěstoty dla jo akcija se pśetergnuła, aby se zadorało wopacnemu pśirědowanjoju twójeje změny drugemu wužywarjeju.
 Pšosym nawroś se na bok, wót kótaregož sy pśišeł a wopytaj hyšći raz.',
 'protectlogpage'              => 'Log-lisćina šćitanych bokow.',
-'protectlogtext'              => 'To jo log-lisćina šćitanych bokow. Glědaj do [[Special:Protectedpages|lisćiny šćitanych bokow]], aby wiźeł wšykne aktualnje šćitane boki.',
+'protectlogtext'              => 'To jo log-lisćina šćitanych bokow. Glědaj do [[Special:ProtectedPages|lisćiny šćitanych bokow]], aby wiźeł wšykne aktualnje šćitane boki.',
 'protectedarticle'            => 'Bok „[[$1]]“ jo se šćitał.',
 'modifiedarticleprotection'   => 'Šćitanska rownina za „[[$1]]“ jo se změniła.',
 'unprotectedarticle'          => 'Šćit za „[[$1]]“ jo se wótpórał.',
@@ -1781,7 +1774,7 @@
 'badipaddress'                    => 'IP-adresa jo njekorektna',
 'blockipsuccesssub'               => 'Wuspěšnje blokěrowane',
 'blockipsuccesstext'              => 'Wužywaŕ/IP-adresa [[Special:Contributions/$1|$1]] jo se blokěrował(a).<br />
-Glědaj do [[Special:Ipblocklist|lisćiny aktiwnych blokěrowanjow]].',
+Glědaj do [[Special:IPBlockList|lisćiny aktiwnych blokěrowanjow]].',
 'ipb-edit-dropdown'               => 'Pśicyny blokěrowanja wobźěłaś',
 'ipb-unblock-addr'                => '$1 dopušćiś',
 'ipb-unblock'                     => 'Wužywarske mě abo IP-adresu dopušćiś',
@@ -1813,7 +1806,7 @@
 'blocklogentry'                   => '[[$1]] blokěrujo se na $2 $3',
 'blocklogtext'                    => 'To jo log-lisćina blokěrowanjow a dopušćenjow.
 IP-adresy, ako su awtomatiski se blokěrowali, se njepokažu.
-Na boce [[Special:Ipblocklist|Lisćina blokěrowanych IP-adresow a wužywarskich mjenjow]] jo móžno, akualne blokěrowanja pśeglědowaś.',
+Na boce [[Special:IPBlockList|Lisćina blokěrowanych IP-adresow a wužywarskich mjenjow]] jo móžno, akualne blokěrowanja pśeglědowaś.',
 'unblocklogentry'                 => 'jo $1 zasej dopušćił',
 'block-log-flags-anononly'        => 'jano anonymne',
 'block-log-flags-nocreate'        => 'stwórjenje konta jo se znjemóžniło',
@@ -1848,7 +1841,7 @@
 'lockdbsuccesssub'    => 'Datowa banka jo zamknjona.',
 'unlockdbsuccesssub'  => 'Datowa banka jo zasej se spśistupniła.',
 'lockdbsuccesstext'   => 'Datowa banka jo zamknjona.
-<br />Njezabydń ju [[Special:Unlockdb|zasej spśistupniś]], gaž swójo zeźěłajoš.',
+<br />Njezabydń ju [[Special:UnlockDB|zasej spśistupniś]], gaž swójo zeźěłajoš.',
 'unlockdbsuccesstext' => 'Datowa banka jo zasej pśistupna.',
 'lockfilenotwritable' => 'Njejo móžno, blokěrowansku dataju datoweje banki změniś. Coš-lic datowu banku zamknuś abo zasej spśistupniś, dej webowy serwer měś pšawo, do njeje pisaś.',
 'databasenotlocked'   => 'Datowa banka njejo zamknjona.',
@@ -1873,8 +1866,6 @@
 
 W toś tyma padoma dej wopśimjeśe boka manualnje se pśesunuś resp. gromadu wjasć, jolic až to coš.",
 'movearticle'             => 'Bok pśesunuś',
-'movenologin'             => 'Njepśizjawjony(a)',
-'movenologintext'         => 'Aby mógał bok pśesunuś, dejš byś [[Special:Userlogin|pśizjawjony wužywaŕ]].',
 'movenotallowed'          => 'Njamaš pšawo pśesuwaś boki we {{GRAMMAR:lokatiw|{{SITENAME}}}}.',
 'newtitle'                => 'nowy nadpis:',
 'move-watch'              => 'Toś ten bok wobglědowaś',
@@ -1901,7 +1892,7 @@
 'delete_and_move'         => 'Wulašowaś a pśesunuś',
 'delete_and_move_text'    => '==Celowy bok eksistěrujo - wulašowaś??==
 
-Bok „[[$1]]“ južo eksistěrujo. Coš jen wulašowaś, aby mógał toś ten bok pśesunuś?',
+Bok „[[:$1]]“ južo eksistěrujo. Coš jen wulašowaś, aby mógał toś ten bok pśesunuś?',
 'delete_and_move_confirm' => 'Jo, toś ten bok wulašowaś',
 'delete_and_move_reason'  => 'wulašowane, aby było městno za pśesunjenje',
 'selfmove'                => 'Wuchadne a celowe mě stej identiskej; njejo móžno, bok na sam se pśesunuś.',
@@ -2136,7 +2127,7 @@
 'show-big-image'       => 'Połne optiske wótgranicowanje.',
 'show-big-image-thumb' => '<small>wjelikosć pśeglěda: $1 × $2 pikselow</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Nowe dataje',
 'imagelisttext'         => "How jo lisćina '''$1''' {{PLURAL:$1|dataje|datajowu|datajow}}, sortěrowane $2.",
 'newimages-summary'     => 'Toś ten specialny bok pokazujo wobraze a dataje, kótarež ako slědne su se uploadowali.',
@@ -2421,7 +2412,7 @@
 
 # External editor support
 'edit-externally'      => 'Dataje z eksternym programom wobźěłaś',
-'edit-externally-help' => 'Za dalšne informacije glědaj [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions].',
+'edit-externally-help' => 'Za dalšne informacije glědaj [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'wšykne',
@@ -2483,7 +2474,7 @@
 'recreate'            => 'Wótnowótki wutwóriś',
 
 # HTML dump
-'redirectingto' => 'Pśeadresěrowanje do [[$1]]...',
+'redirectingto' => 'Pśeadresěrowanje do [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Wulašowaś cache togo boka? $1',
@@ -2591,7 +2582,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Wersija',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Datajowa droga',
 'filepath-page'    => 'Dataja:',
 'filepath-submit'  => 'Droga',
@@ -2629,7 +2620,7 @@
 'specialpages-group-redirects'   => 'Dalej pósrědnjajuce boki',
 'specialpages-group-spam'        => 'Spamowe rědy',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Prozny bok',
 'intentionallyblankpage' => 'Toś ten bok jo z wótglědom prozny.',
 
Index: languages/messages/MessagesEml.php
===================================================================
--- languages/messages/MessagesEml.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEml.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Timichal
  * @author Ottaviano II
+ * @author Timichal
  * @author Tèstaquêdra
- * @author SPQRobin
  */
 
 $fallback = 'it';
@@ -82,7 +81,7 @@
 'showpreview'      => 'Anteprémma',
 'showdiff'         => 'Guèrda al differèinzi',
 'anoneditwarning'  => "'''Attenziòun:''' An sîv ménga vgnû dèinter. Al vòster indirézz IP al vrà signê in d'la stòria d'i cambiamèint ed sta pagina chè..",
-'anontalkpagetext' => "----''Sta chè l'éla pàgina ed discussiòun d'un utèint anònim c'al n'à brisa criê un sô account o c'an l'usa ménga. Bsògna quindi usêr al sô indirézz IP par identifichèrel. L'istèss indirézz IP al pôl èsser usê da di mòndi utèint. Se sèt un utèint anònim e pèinset c'a-t in sun stèdi fâti di cummèint irrilevànt, per piasér [[Special:Userlogin|criêt un account o fê al log-in]] par evitèr confusiòuni futuri cun di èter utèint anònim.''",
+'anontalkpagetext' => "----''Sta chè l'éla pàgina ed discussiòun d'un utèint anònim c'al n'à brisa criê un sô account o c'an l'usa ménga. Bsògna quindi usêr al sô indirézz IP par identifichèrel. L'istèss indirézz IP al pôl èsser usê da di mòndi utèint. Se sèt un utèint anònim e pèinset c'a-t in sun stèdi fâti di cummèint irrilevànt, per piasér [[Special:UserLogin|criêt un account o fê al log-in]] par evitèr confusiòuni futuri cun di èter utèint anònim.''",
 'editing'          => 'Cambiamèint ed $1',
 'yourdiff'         => 'Differèinzi',
 'templatesused'    => 'Modêl usèdi in sta pàgina:',
@@ -103,7 +102,7 @@
 'filedesc'          => "Ugêt d'al cambiamèint",
 'fileuploadsummary' => "Ugêt d'al cambiamèint:",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_size' => 'Dimensiòun (bytes)',
 
 # Random page
@@ -115,7 +114,7 @@
 # Special:Log
 'specialloguserlabel' => 'Utèint:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Tôt al pàgin',
 
 # Watchlist
@@ -148,7 +147,7 @@
 '1movedto2'   => "[[$1]] l'è stê mòs a [[$2]]",
 'movelogpage' => 'Regestér di muvimèint',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Zerca',
 
 # Special:SpecialPages
Index: languages/messages/MessagesJv.php
===================================================================
--- languages/messages/MessagesJv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesJv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Helix84
  * @author Meursault2004
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Helix84
  */
 
 $fallback = 'id';
@@ -316,7 +315,7 @@
 'nosuchaction'      => 'Ora ana pratingkah kaya ngono',
 'nosuchactiontext'  => 'Pratingkah sing dirinci déning URL kaya ngono ora ditepangi déning wiki.',
 'nosuchspecialpage' => 'Ora ana kaca astaméwa kaya ngono',
-'nospecialpagetext' => 'Panjenengan nyuwun kaca astaméwa sing ora sah. Daftar kaca astaméwa sing sah bisa dipirsani ing [[Special:Specialpages|daftar kaca astaméwa]].',
+'nospecialpagetext' => 'Panjenengan nyuwun kaca astaméwa sing ora sah. Daftar kaca astaméwa sing sah bisa dipirsani ing [[Special:SpecialPages|daftar kaca astaméwa]].',
 
 # General errors
 'error'                => 'Kasalahan',
@@ -529,10 +528,6 @@
 'blockededitsource'         => "Tèks '''suntingan panjenengan''' tumrap ing '''$1''' dituduhaké ing ngisor iki:",
 'whitelistedittitle'        => 'Prelu log mlebu kanggo nyunting',
 'whitelistedittext'         => 'Panjenengan kudu $1 supaya bisa nyunting artikel.',
-'whitelistreadtitle'        => 'Prelu log mlebu kanggo maca',
-'whitelistreadtext'         => 'Panjenengan kudu [[Special:Userlogin|log mlebu]] supaya bisa maca artikel.',
-'whitelistacctitle'         => 'Panjenengan ora pareng nggawé akun',
-'whitelistacctext'          => 'Supaya bisa mlebu dadi anggota wiki iki, panjenengan kudu [[Special:Userlogin|log mlebu]] lan kagungan idin sing cocog.',
 'confirmedittitle'          => 'Konfirmasi layang e-mail diprelokaké supaya panjenengan pareng nglakoni panyuntingan',
 'confirmedittext'           => 'Panjenengan kudu ndhedhes alamat e-mail dhisik sadurungé pareng nyunting sawijining kaca. Mangga nglebokaké lan validasi alamat e-mail panjenengan sadurungé nglakoni panyuntingan. Alamat e-mail sawisé bisa diowahi liwat [[Special:Preferences|kaca préférènsi]]',
 'nosuchsectiontitle'        => 'Subbagian iku ora bisa ditemokaké',
@@ -546,7 +541,7 @@
 'newarticletext'            => "Katonané panjenengan ngetutaké pranala artikel sing durung ana.
 Manawa kersa manulis artikel iki, manggaa. (Mangga mirsani [[{{MediaWiki:Helppage}}|Pitulung]] kanggo informasi sabanjuré).
 Yèn ora sengaja tekan kéné, bisa ngeklik pencètan '''back''' waé ing panjlajah wèb panjenengan.",
-'anontalkpagetext'          => "---- ''Iki yaiku kaca dhiskusi sawijining panganggo anonim sing durung kagungan akun utawa ora nganggo akuné, dadi kita keeksa kudu nganggo alamat IP-né kanggo nepangi. Alamat IP kaya mengkéné iki bisa dienggo déning panganggo sing séjé-séjé. Yèn panjenengan pancèn panganggo anonim lan olèh komentar-komentar miring, mangga [[Special:Userlogin|nggawé akun utawa log mlebu]] supaya ora rancu karo panganggo anonim liyané ing mangsa ngarep.''",
+'anontalkpagetext'          => "---- ''Iki yaiku kaca dhiskusi sawijining panganggo anonim sing durung kagungan akun utawa ora nganggo akuné, dadi kita keeksa kudu nganggo alamat IP-né kanggo nepangi. Alamat IP kaya mengkéné iki bisa dienggo déning panganggo sing séjé-séjé. Yèn panjenengan pancèn panganggo anonim lan olèh komentar-komentar miring, mangga [[Special:UserLogin|nggawé akun utawa log mlebu]] supaya ora rancu karo panganggo anonim liyané ing mangsa ngarep.''",
 'noarticletext'             => 'Saiki ora ana tèks ing kaca iki. Panjenengan bisa [[Special:Search/{{PAGENAME}}|nglakoni panggolèkan kanggo judhul iki kaca iki]] ing kaca-kaca liyané utawa [{{fullurl:{{FULLPAGENAME}}|action=edit}} nyunting kaca iki].',
 'userpage-userdoesnotexist' => 'Akun utawa rékening panganggo "$1" ora kadaftar.',
 'clearyourcache'            => "'''Cathetan:''' Sawisé nyimpen préférènsi, panjenengan prelu ngresiki <em>cache</em> panjlajah wèb panjenengan kanggo mirsani pangowahan. '''Mozilla / Firefox / Safari:''' pencèt ''Ctrl-Shift-R'' (''Cmd-Shift-R'' pada Apple Mac); '''IE:''' tekan ''Ctrl-F5''; '''Konqueror:''': pencèt ''F5''; '''Opera''' resikana <em>cache</em> miturut menu ''Tools→Preferences''.",
@@ -597,7 +592,7 @@
 'hiddencategories'          => 'Kaca iki sawijining anggota saka {{PLURAL:$1|1 kategori ndelik|$1 kategori-kategori ndelik}}:',
 'edittools'                 => '<!-- Tèks ing ngisor iki bakal ditudhuhaké ing ngisoring isènan suntingan lan pangemotan.-->',
 'nocreatetitle'             => 'Panggawéan kaca anyar diwatesi',
-'nocreatetext'              => 'Situs iki ngwatesi kemampuan kanggo nggawé kaca anyar. Panjenengan bisa bali lan nyunting kaca sing wis ana, utawa mangga [[Special:Userlogin|mlebua log utawa ndaftar]]',
+'nocreatetext'              => 'Situs iki ngwatesi kemampuan kanggo nggawé kaca anyar. Panjenengan bisa bali lan nyunting kaca sing wis ana, utawa mangga [[Special:UserLogin|mlebua log utawa ndaftar]]',
 'nocreate-loggedin'         => 'Panjenengan ora kagungan idin kanggo nggawé kaca anyar ing wiki iki.',
 'permissionserrors'         => 'Kaluputan Idin Aksès',
 'permissionserrorstext'     => 'Panjengan ora kagungan idin kanggo nglakoni sing panjenengan gayuh amerga {{PLURAL:$1|alesan|alesan-alesan}} iki:',
@@ -700,7 +695,7 @@
 
 # Suppression log
 'suppressionlog'     => "Log barang-barang sing didelikaké (''oversight'')",
-'suppressionlogtext' => "Ing ngisor iki kapacak daftar pambusakan lan pamblokiran pungkasan sing uga nyangkut isi sing didelikaké saka para opsis. Mangga mirsani [[Special:Ipblocklist|daftar pamblokiran IP]] kanggo daftar pambuwangan (''ban'') lan pamblokiran sing saiki lagi operasional.",
+'suppressionlogtext' => "Ing ngisor iki kapacak daftar pambusakan lan pamblokiran pungkasan sing uga nyangkut isi sing didelikaké saka para opsis. Mangga mirsani [[Special:IPBlockList|daftar pamblokiran IP]] kanggo daftar pambuwangan (''ban'') lan pamblokiran sing saiki lagi operasional.",
 
 # History merging
 'mergehistory'                     => 'Gabung sejarah kaca',
@@ -781,7 +776,7 @@
 'mypreferences'            => 'Préferènsiku',
 'prefs-edits'              => 'Gunggungé suntingan:',
 'prefsnologin'             => 'Durung mlebu log',
-'prefsnologintext'         => 'Panjenengan kudu [[Special:Userlogin|mlebu log]] kanggo nyimpen préferènsi njenengan.',
+'prefsnologintext'         => 'Panjenengan kudu [[Special:UserLogin|mlebu log]] kanggo nyimpen préferènsi njenengan.',
 'prefsreset'               => 'Préferènsi wis dibalèkaké menyang konfigurasi baku.',
 'qbsettings'               => 'Pengaturan bar sidhatan',
 'qbsettings-none'          => 'Ora ana',
@@ -854,7 +849,7 @@
 'userrights-reason'           => 'Alesané ngowahi:',
 'userrights-no-interwiki'     => 'Panjenengan ora ana hak kanggo ngowahi hak panganggo ing wiki liyané.',
 'userrights-nodatabase'       => 'Basis data $1 ora ana utawa ora lokal.',
-'userrights-nologin'          => 'Panjenengan kudu [[Special:Userlogin|mlebu log]] mawa nganggo akun utawa rékening pangurus supaya bisa ngowahi hak panganggo.',
+'userrights-nologin'          => 'Panjenengan kudu [[Special:UserLogin|mlebu log]] mawa nganggo akun utawa rékening pangurus supaya bisa ngowahi hak panganggo.',
 'userrights-notallowed'       => 'Panjenengan ora ndarbèni hak kanggo ngowahi hak panganggo.',
 'userrights-changeable-col'   => 'Grup sing bisa panjenengan owahi',
 'userrights-unchangeable-col' => 'Grup sing ora bisa diowahi panjenengan',
@@ -980,10 +975,10 @@
 'reupload'                    => 'Unggah ulang',
 'reuploaddesc'                => 'Bali ing formulir pamotan',
 'uploadnologin'               => 'Durung mlebu log',
-'uploadnologintext'           => 'Panjenengan kudu [[Special:Userlogin|mlebu log]] supaya olèh ngunggahaké gambar utawa berkas liyané.',
+'uploadnologintext'           => 'Panjenengan kudu [[Special:UserLogin|mlebu log]] supaya olèh ngunggahaké gambar utawa berkas liyané.',
 'upload_directory_read_only'  => 'Dirèktori pangunggahan ($1) ora bisa ditulis déning server wèb.',
 'uploaderror'                 => 'Kaluputan pangunggahan berkas',
-'uploadtext'                  => "Enggonen formulir ing ngisor iki kanggo ngunggahaké berkas. Gunakna [[Special:Imagelist|daftar berkas]] utawa [[Special:Log/upload|log pangunggahan]] kanggo nuduhaké utawa nggolèk berkas utawa gambar sing wis diunggahaké sadurungé.
+'uploadtext'                  => "Enggonen formulir ing ngisor iki kanggo ngunggahaké berkas. Gunakna [[Special:ImageList|daftar berkas]] utawa [[Special:Log/upload|log pangunggahan]] kanggo nuduhaké utawa nggolèk berkas utawa gambar sing wis diunggahaké sadurungé.
 
 Kanggo nuduhaké utawa nyertakaké berkas utawa gambar ing sawijining kaca, gunakna pranala mawa format
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Berkas.jpg]]</nowiki>''',
@@ -1073,7 +1068,7 @@
 'upload_source_url'  => ' (sawijining URL absah sing bisa diaksès publik)',
 'upload_source_file' => ' (sawijining berkas ing komputeré panjenengan)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Kaca astaméwa utawa kusus iki nuduhaké kabèh berkas sing wis diunggahaké.
 Sacara baku, berkas pungkasan sing diunggahaké dituduhaké ing urutan dhuwur dhéwé.
 Klik sirahé kolom kanggo ngowahi urutan.',
@@ -1101,7 +1096,7 @@
 'imagelinks'                     => 'Pranala',
 'linkstoimage'                   => 'Kaca-kaca sing kapacak iki duwé pranala menyang berkas iki:',
 'nolinkstoimage'                 => 'Ora ana kaca sing nyambung menyang berkas iki.',
-'morelinkstoimage'               => 'Ndeleng [[Special:Whatlinkshere/$1|luwih akèh pranala]] menyang berkas iki.',
+'morelinkstoimage'               => 'Ndeleng [[Special:WhatLinksHere/$1|luwih akèh pranala]] menyang berkas iki.',
 'redirectstofile'                => 'Berkas-berkas iki duwé pangalihan menyang berkas iki:',
 'sharedupload'                   => 'Berkas iki sawijining pangunggahan bebarengan sing uga bisa dienggo déning proyèk-proyèk liyané.',
 'shareduploadwiki'               => 'Mangga mirsani $1 kanggo informasi sabanjuré.',
@@ -1119,18 +1114,18 @@
 # File reversion
 'filerevert'                => 'Balèkna $1',
 'filerevert-legend'         => 'Balèkna berkas',
-'filerevert-intro'          => '<span class="plainlinks">Panjenengan mbalèkaké \'\'\'[[Media:$1|$1]]\'\'\' menyang [vèrsi $4 ing $3, $2].</span>',
+'filerevert-intro'          => "Panjenengan mbalèkaké '''[[Media:$1|$1]]''' menyang [vèrsi $4 ing $3, $2].",
 'filerevert-comment'        => 'Komentar:',
 'filerevert-defaultcomment' => 'Dibalèkaké menyang vèrsi ing $2, $1',
 'filerevert-submit'         => 'Balèkna',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' wis dibalèkaké menyang [vèrsi $4 ing $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' wis dibalèkaké menyang [vèrsi $4 ing $3, $2].",
 'filerevert-badversion'     => 'Ora ana vèrsi lokal sadurungé saka berkas iki mawa stèmpel wektu sing dikarepaké.',
 
 # File deletion
 'filedelete'                  => 'Mbusak $1',
 'filedelete-legend'           => 'Mbusak berkas',
 'filedelete-intro'            => "Panjenengan mbusak '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Panjenengan mbusak vèrsi \'\'\'[[Media:$1|$1]]\'\'\' per [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Panjenengan mbusak vèrsi '''[[Media:$1|$1]]''' per [$4 $3, $2].",
 'filedelete-comment'          => 'Alesan mbusak:',
 'filedelete-submit'           => 'Busak',
 'filedelete-success'          => "'''$1''' wis dibusak.",
@@ -1186,7 +1181,7 @@
 Dadi tegesé rata-rata ana '''\$5''' suntingan per kaca karo '''\$6''' tayangan per suntingan.
 
 Dawané [http://www.mediawiki.org/wiki/Manual:Job_queue antrian tugas] ana '''\$7'''.",
-'userstatstext'          => "Ana '''$1''' [[Special:Listusers|{{PLURAL:$1|panganggo|panganggo}}]] sing wis ndaftar. '''$2''' (utawa '''$4%''') antarané iku {{PLURAL:$2|duwé|duwé}} hak aksès $5.",
+'userstatstext'          => "Ana '''$1''' [[Special:ListUsers|{{PLURAL:$1|panganggo|panganggo}}]] sing wis ndaftar. '''$2''' (utawa '''$4%''') antarané iku {{PLURAL:$2|duwé|duwé}} hak aksès $5.",
 'statistics-mostpopular' => 'Kaca sing paling akèh dituduhaké',
 
 'disambiguations'      => 'Kaca disambiguasi',
@@ -1279,7 +1274,7 @@
 'logempty'             => 'Ora ditemokaké èntri log sing pas.',
 'log-title-wildcard'   => 'Golèk irah-irahan utawa judhul sing diawali mawa tèks kasebut',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Kabèh kaca',
 'alphaindexline'    => '$1 tumuju $2',
 'nextpage'          => 'Kaca sabanjuré ($1)',
@@ -1301,12 +1296,12 @@
 'special-categories-sort-count' => 'urutna miturut angka',
 'special-categories-sort-abc'   => 'urutna miturut abjad',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Tuduhna panganggo sing diawali karo:',
 'listusers-submit'   => 'Tuduhna',
 'listusers-noresult' => 'Panganggo ora ditemokaké.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Hak-hak grup panganggo',
 'listgrouprights-summary'  => 'Ing ngisor iki kapacak daftar grup panganggo sing didéfinisi ing wiki iki, karo hak-hak aksès gandhèngané.
 Informasi tambahan perkara hak-hak individual bisa ditemokaké ing [[{{MediaWiki:Listgrouprights-helppage}}|kéné]].',
@@ -1317,7 +1312,7 @@
 
 # E-mail user
 'mailnologin'     => 'Ora ana alamat layang e-mail',
-'mailnologintext' => 'Panjenengan kudu [[Special:Userlogin|mlebu log]] lan kagungan alamat e-mail sing sah ing [[Special:Preferences|preféèrensi]] yèn kersa ngirim layang e-mail kanggo panganggo liya.',
+'mailnologintext' => 'Panjenengan kudu [[Special:UserLogin|mlebu log]] lan kagungan alamat e-mail sing sah ing [[Special:Preferences|preféèrensi]] yèn kersa ngirim layang e-mail kanggo panganggo liya.',
 'emailuser'       => 'Kirim e-mail panganggo iki',
 'emailpage'       => 'Kirimi panganggo iki layang e-mail',
 'emailpagetext'   => 'Yèn panganggo iki nglebokaké alamat layang e-mailé sing absah sajroning préferènsiné, formulir ing ngisor iki bakal ngirimaké sawijining layang e-mail. Alamat e-mail sing ana ing préferènsi panjenengan bakal metu minangka alamat "Saka" ing layang e-mail iku, dadi sing nampa bisa mbales layang e-mail panjenengan.',
@@ -1342,10 +1337,10 @@
 'nowatchlist'          => 'Daftar pangawasan panjenengan kosong.',
 'watchlistanontext'    => 'Mangga $1 kanggo mirsani utawa nyunting daftar pangawasan panjenengan.',
 'watchnologin'         => 'Durung mlebu log',
-'watchnologintext'     => 'Panjenengan kudu [[Special:Userlogin|mlebu log]] kanggo ngowahi daftar artikel pilihan.',
+'watchnologintext'     => 'Panjenengan kudu [[Special:UserLogin|mlebu log]] kanggo ngowahi daftar artikel pilihan.',
 'addedwatch'           => 'Sampun katambahaken wonten ing daftar artikel pilihan.',
 'addedwatchtext'       => "Kaca \"[[:\$1]]\" wis ditambahaké menyang [[Special:Watchlist|daftar pangawasan]].
-Owah-owahan sing dumadi ing tembé ing kaca iku lan kaca dhiskusi sing kagandhèng, bakal dipacak ing kéné, lan kaca iku bakal dituduhaké '''kandel''' ing [[Special:Recentchanges|daftar owah-owahan iku]] supados luwih gampang katon.",
+Owah-owahan sing dumadi ing tembé ing kaca iku lan kaca dhiskusi sing kagandhèng, bakal dipacak ing kéné, lan kaca iku bakal dituduhaké '''kandel''' ing [[Special:RecentChanges|daftar owah-owahan iku]] supados luwih gampang katon.",
 'removedwatch'         => 'Wis dibusak saka daftar pangawasan',
 'removedwatchtext'     => 'Kaca "<nowiki>$1</nowiki>" wis dibusak saka daftar pangawasan.',
 'watch'                => 'tutana',
@@ -1455,7 +1450,7 @@
 'sessionfailure'              => 'Katoné ana masalah karo sèsi log panjenengan; log panjenengan wis dibatalaké kanggo nyegah pambajakan. Mangga mencèt tombol "back" lan unggahaké manèh kaca sadurungé mlebu log, lan coba manèh.',
 'protectlogpage'              => 'Log pangreksan',
 'protectlogtext'              => 'Ing ngisor iki kapacak log pangreksan lan panjabelan reksa kaca.
-Mangga mirsani [[Special:Protectedpages|daftar kaca sing direksa]] kanggo daftar pangreksan kaca pungkasan.',
+Mangga mirsani [[Special:ProtectedPages|daftar kaca sing direksa]] kanggo daftar pangreksan kaca pungkasan.',
 'protectedarticle'            => 'ngreksa "[[$1]]"',
 'modifiedarticleprotection'   => 'ngowahi tingkat pangreksan "[[$1]]"',
 'unprotectedarticle'          => 'ngilangi pangreksan "[[$1]]"',
@@ -1618,7 +1613,7 @@
 'ipbwatchuser'                => 'Ngawasi kaca panganggo lan kaca-kaca dhiskusi panganggo iki',
 'badipaddress'                => 'Alamat IP klèntu',
 'blockipsuccesssub'           => 'Pemblokiran suksès',
-'blockipsuccesstext'          => 'Alamat IP utawa panganggo "$1" wis diblokir. <br />Delengen [[Special:Ipblocklist|Daftar IP lan panganggo diblokir]] kanggo ndeleng manèh pemblokiran.',
+'blockipsuccesstext'          => 'Alamat IP utawa panganggo "$1" wis diblokir. <br />Delengen [[Special:IPBlockList|Daftar IP lan panganggo diblokir]] kanggo ndeleng manèh pemblokiran.',
 'ipb-edit-dropdown'           => 'Sunting alesan pamblokiran',
 'ipb-unblock-addr'            => 'Ilangna blokir $1',
 'ipb-unblock'                 => 'Ilangna blokir sawijining panganggo utawa alamat IP',
@@ -1650,7 +1645,7 @@
 'blocklogentry'               => 'mblokir "[[$1]]" dipun watesi wedalipun $2 $3',
 'blocklogtext'                => 'Ing ngisor iki kapacak log pamblokiran lan panjabelan blokir panganggo. 
 Alamat IP sing diblokir sacara otomatis ora ana ing daftar iki. 
-Mangga mirsani [[Special:Ipblocklist|daftar alamat IP sing diblokir]] kanggo daftar blokir pungkasan.',
+Mangga mirsani [[Special:IPBlockList|daftar alamat IP sing diblokir]] kanggo daftar blokir pungkasan.',
 'unblocklogentry'             => 'njabel blokir "$1"',
 'block-log-flags-anononly'    => 'namung panganggo anonim waé',
 'block-log-flags-nocreate'    => 'opsi nggawé akun utawa rékening dipatèni',
@@ -1685,7 +1680,7 @@
 'lockdbsuccesssub'    => 'Bisa kasil ngunci basis data',
 'unlockdbsuccesssub'  => 'Bisa kasil buka kunci basis data',
 'lockdbsuccesstext'   => 'Basis data wis dikunci.
-<br />Pastèkna panjenengan [[Special:Unlockdb|mbuka kunciné]] sawisé pangopènan bubar.',
+<br />Pastèkna panjenengan [[Special:UnlockDB|mbuka kunciné]] sawisé pangopènan bubar.',
 'unlockdbsuccesstext' => 'Kunci basis data wis dibuka.',
 'lockfilenotwritable' => 'Berkas kunci basis data ora bisa ditulis. Kanggo ngunci utawa mbuka basis data, berkas iki kudu ditulis déning server wèb.',
 'databasenotlocked'   => 'Basis data ora dikunci.',
@@ -1705,8 +1700,6 @@
 
 Ing kasus-kasus iku, yèn panjenengan gayuh, panjenengan bisa mindhahaké utawa nggabung kaca iku sacara manual.",
 'movearticle'             => 'Pindhah kaca',
-'movenologin'             => 'Durung mlebu log',
-'movenologintext'         => 'Panjenengan kudu dadi panganggo sing wis ndaftar lan wis [[Special:Userlogin|mlebu log]] kanggo mindhah kaca.',
 'movenotallowed'          => 'Panjenengan ora pareng ngalihaké kaca ing {{SITENAME}}.',
 'newtitle'                => 'Menyang irah-irahan utawa judhul anyar:',
 'move-watch'              => 'Awasna kaca iki',
@@ -1727,7 +1720,7 @@
 'delete_and_move'         => 'busak lan kapindahaken',
 'delete_and_move_text'    => '== Perlu mbusak ==
 
-Artikel sing dituju, "[[$1]]", wis ana isiné. 
+Artikel sing dituju, "[[:$1]]", wis ana isiné. 
 Apa panjenengan kersa mbusak iku supaya kacané bisa dialihaké?',
 'delete_and_move_confirm' => 'Ya, busak kaca iku.',
 'delete_and_move_reason'  => 'Dibusak kanggo antisipasi pangalihan kaca',
@@ -1952,10 +1945,10 @@
 'show-big-image'       => 'Résolusi kebak',
 'show-big-image-thumb' => '<small>Ukuran pratayang iki: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeri berkas anyar',
 'imagelisttext'         => "Ing ngisor iki kapacak daftar '''$1''' {{PLURAL:$1|berkas|berkas}} sing diurutaké $2.",
-'newimages-summary'     => 'Kaca astaméwa utawa kusus iki nuduhaké daftar berkas anyar dhéwé sing diunggahaké',
+'newimages-summary'     => 'Kaca astaméwa utawa kusus iki nuduhaké daftar berkas anyar dhéwé sing diunggahaké.',
 'showhidebots'          => '($1 bot)',
 'noimages'              => 'Ora ana sing dideleng.',
 'ilsubmit'              => 'Golek',
@@ -2233,7 +2226,7 @@
 
 # External editor support
 'edit-externally'      => 'Sunting berkas iki mawa aplikasi jaba',
-'edit-externally-help' => 'Deleng [http://meta.wikimedia.org/wiki/Help:External_editors instruksi pangaturan] kanggo informasi sabanjuré.',
+'edit-externally-help' => 'Deleng [http://www.mediawiki.org/wiki/Manual:External_editors instruksi pangaturan] kanggo informasi sabanjuré.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kabèh',
@@ -2299,7 +2292,7 @@
 'recreate'            => 'Gawé ulang',
 
 # HTML dump
-'redirectingto' => 'Dipun-alihaken tumuju [[$1]]...',
+'redirectingto' => 'Dipun-alihaken tumuju [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Busak ''cache'' kaca iki?$1",
@@ -2396,7 +2389,7 @@
 'version-software-product'         => 'Prodhuk',
 'version-software-version'         => 'Vèrsi',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Lokasi berkas',
 'filepath-page'    => 'Berkas:',
 'filepath-submit'  => 'Lokasi',
Index: languages/messages/MessagesSei.php
===================================================================
--- languages/messages/MessagesSei.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSei.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author SeriCtam
  * @author Ccaxjoj Iteja Z Iti Poop
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
+ * @author SeriCtam
  * @author Teak
  */
 
@@ -270,7 +267,7 @@
 'nosuchspecialpage' => "Ne'dáár páhina extrava",
 'nospecialpagetext' => "<big>'''Meccan páhina extrava invalida.'''</big>
 
-Meccan páhina extrava valide pac [[Special:Specialpages]] iti.",
+Meccan páhina extrava valide pac [[Special:SpecialPages]] iti.",
 
 # General errors
 'error'                => 'Römj',
@@ -489,10 +486,6 @@
 'blockededitsource'         => "Textua zode '''meticpatlöxde''' '''$1''' coccebj cohuatlöx:",
 'whitelistedittitle'        => 'Caápo Neces ticpatlöx',
 'whitelistedittext'         => 'Mecoccebj $1 ticpatlöx páhinám.',
-'whitelistreadtitle'        => 'Caápo Neces caitom',
-'whitelistreadtext'         => 'Mecoccebj [[Special:Userlogin|caápo]] caitom páhinám.',
-'whitelistacctitle'         => 'Me necoccebj permiccion de creacionde IDde caitom',
-'whitelistacctext'          => 'Coccebj permiccionde creacionde accountám coccebj [[Special:Userlogin|caápo]] ö coccebj permicción appropriatenón.',
 'confirmedittitle'          => 'Confirmacionde e-iitom coccebj Neces ticpatlöx',
 'confirmedittext'           => "Me confirmöx menadressade de e-iitom ticpatlöx 'depre. Set' ö validatenan menadressade IP [[Special:Preferences|hequáatlaác]] mii.",
 'nosuchsectiontitle'        => "Ne'dáár partam",
@@ -507,7 +500,7 @@
 Huants createnom jan páhina, startom type mii box !-cmaa iti
 ([[{{MediaWiki:Helppage}}|páhinade helpom]] zo viside plus informacion).
 Me coccebj römjasi poop, clickom meback-buttonde browser coccebj perfectua.',
-'anontalkpagetext'          => "----''Jan coccebj czaxö zode caitomde IDde adressade IP. Isój necoccebj caápo. Jan coccebj rae'de usadadde adressade IP numerical identificacion 'prenisój. Plusöxde caitom pos-coccebj jan adressade IP. Me pos-coccebj anonimo ö commentua irrevelantua coccebj directomde me poop, [[Special:Userlogin|caápo-jande]] exitom confucion diijömde IP-caitóm mii.''",
+'anontalkpagetext'          => "----''Jan coccebj czaxö zode caitomde IDde adressade IP. Isój necoccebj caápo. Jan coccebj rae'de usadadde adressade IP numerical identificacion 'prenisój. Plusöxde caitom pos-coccebj jan adressade IP. Me pos-coccebj anonimo ö commentua irrevelantua coccebj directomde me poop, [[Special:UserLogin|caápo-jande]] exitom confucion diijömde IP-caitóm mii.''",
 'noarticletext'             => 'Jan páhina necoccebj textua zo, me pos-coccebj [[Special:Search/{{PAGENAME}}|yahöx jan páhina]] diijömde páhinám iti jöx [{{fullurl:{{FULLPAGENAME}}|action=edit}} ticpatlöx jan páhina].',
 'clearyourcache'            => "'''Notificacion:''' Xuniim 'depre, me pos-coccebj bypassöx mecachede browser caitomi quiíx. '''Mozilla / Firefox / Safari:''' quan ti caitomde ''Shift'' zoxepe clickom ''Reload'', jöx cuápook zo ti ''Ctrl-Shift-R'' (''Cmd-Shift-R'' Apple Mac iti); '''IE:''' quan ti ''Ctrl'' zoxepe clickom ''Refresh'', jöx cuápook zo ti ''Ctrl-F5''; '''Konqueror:''': clickom buttonde ''Reload'' zo, jöx cuápook zo iti ''F5''; '''Opera''' caitóm pos-coccebj clairomde cache completementua ''Tools→Preferences'' iti.",
 'usercssjsyoucanpreview'    => "<strong>Tip:</strong> Usadad 'Cohuatlöx cuáxiit' testom me hun CSS/JS xuniim 'depre.",
@@ -550,7 +543,7 @@
 'template-semiprotected'    => '(semi-protectöx)',
 'nocreatetitle'             => 'Limiitde creacionde páhinám',
 'nocreatetext'              => 'Jan site coccebj avlutuatl altede creatöx hun páhinám.
-Me pos-coccebj revertöx ö ticpatlöx janpáhinám jöx [[Special:Userlogin|caápo]].',
+Me pos-coccebj revertöx ö ticpatlöx janpáhinám jöx [[Special:UserLogin|caápo]].',
 'nocreate-loggedin'         => 'Me necoccebj permiccionde creatöx hunpáhinám jan wiki iti.',
 'permissionserrors'         => 'Römjde permicción',
 'permissionserrorstext'     => "Me necoccebj permiccionde zo, pre'zo {{PLURAL:$1|rae|rae'}}:",
@@ -637,7 +630,7 @@
 'mypreferences'         => 'Hequáatlaác',
 'prefs-edits'           => 'Ticpatlöx jöxualtec ID-cort:',
 'prefsnologin'          => 'Necaápo',
-'prefsnologintext'      => 'Zo coccebj Neces [[Special:Userlogin|caápo]] quiixom hequáatlaác.',
+'prefsnologintext'      => 'Zo coccebj Neces [[Special:UserLogin|caápo]] quiixom hequáatlaác.',
 'qbsettings'            => 'Zuónaát',
 'qbsettings-none'       => 'Nepartám',
 'changepassword'        => "Reset'quimx canj",
@@ -742,7 +735,7 @@
 'uploadbtn'         => 'Ciúchan uploadan',
 'reupload'          => 'Re-uploadan',
 'uploadnologin'     => 'Necaápo',
-'uploadnologintext' => 'Zo coccebj Neces [[Special:Userlogin|caápo]] (re-)uploadande ciúchán.',
+'uploadnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] (re-)uploadande ciúchán.',
 'uploaderror'       => 'Römjde uploadan',
 'uploadlog'         => 'logde uploadan',
 'uploadlogpage'     => 'Logde uploadan',
@@ -772,7 +765,7 @@
 'nolicense'         => 'Seleccion coccebj hun',
 'license-nopreview' => '(Necuáxiit)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Yahöxde IDde ciúchan:',
 'imgfile'               => 'ciúchan',
 'imagelist'             => 'Listade ciúchán',
@@ -876,7 +869,7 @@
 'log-search-legend'    => 'Yahöxde logám',
 'log-search-submit'    => 'Caátemöx',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Jöxde páhinám',
 'nextpage'          => 'Hunpáhina ($1)',
 'prevpage'          => 'Janpáhina ($1)',
@@ -893,14 +886,14 @@
 # Special:Categories
 'categories' => 'Cayliibám',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Xuniim caitóm startomde:',
 'listusers-submit'   => 'Cohuatlöx',
 'listusers-noresult' => 'Necoccebj caitóm.',
 
 # E-mail user
 'mailnologin'     => 'Nenadressade iitom',
-'mailnologintext' => 'Zo coccebj Neces [[Special:Userlogin|caápo]]
+'mailnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]]
 ö coccebjöx adressade e-iitom validom [[Special:Preferences|mequáatlaác]]
 iitom e-iitomde diijömde caitóm.',
 'emailuser'       => 'E-iitom  jan caitom',
@@ -921,7 +914,7 @@
 'watchlistfor'         => "('''$1''' mii)",
 'nowatchlist'          => 'Hecoccebj 0 itémii helistade cáminot iti.',
 'watchnologin'         => 'Necaápo',
-'watchnologintext'     => 'Zo coccebj Neces [[Special:Userlogin|caápo]] ticpatlöx helistade cáminot.',
+'watchnologintext'     => 'Zo coccebj Neces [[Special:UserLogin|caápo]] ticpatlöx helistade cáminot.',
 'addedwatch'           => 'Plusöxaj listade cáminot',
 'removedwatch'         => 'Delatajde he listade cáminot',
 'removedwatchtext'     => 'Páhina zo "[[:$1]]" coccebj delataj me listade cáminot.',
@@ -1017,7 +1010,6 @@
 # Move page
 'move-page-legend' => 'Yacom páhina',
 'movearticle'      => 'Yacom páhina:',
-'movenologin'      => 'Necaápo',
 'move-watch'       => 'Cáminot jan páhina',
 'movepagebtn'      => 'Yacom páhina',
 'movedto'          => 'yacomöxde',
@@ -1080,7 +1072,7 @@
 # Media information
 'widthheightpage' => '$1×$2, $3 páhinám',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 botám)',
 'ilsubmit'     => 'Yahöx',
 'bydate'       => 'de datum',
Index: languages/messages/MessagesVo.php
===================================================================
--- languages/messages/MessagesVo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesVo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Smeira
  * @author Malafaya
- * @author Siebrand
- * @author SPQRobin
+ * @author Smeira
  * @author לערי ריינהארט
  */
 
@@ -376,7 +374,7 @@
 'nosuchaction'      => 'Atos no mögon',
 'nosuchactiontext'  => 'Dun peflagöl fa el URL no sevädon vüke',
 'nosuchspecialpage' => 'Pad patik at no dabinon',
-'nospecialpagetext' => 'Esukol padi patik no dabinöli. Lised padas patik dabinöl binon su pad: [[Special:Specialpages]].',
+'nospecialpagetext' => 'Esukol padi patik no dabinöli. Lised padas patik dabinöl binon su pad: [[Special:SpecialPages]].',
 
 # General errors
 'error'                => 'Pöl',
@@ -605,10 +603,6 @@
 'blockededitsource'         => "Vödem '''redakamas olik''' pada: '''$1''' pajonon dono:",
 'whitelistedittitle'        => 'Mutol nunädön oli ad redakön',
 'whitelistedittext'         => 'Mutol $1 ad redakön padis.',
-'whitelistreadtitle'        => 'Mutol nunädön oli ad reidön',
-'whitelistreadtext'         => 'Nedol [[Special:Userlogin|nunädön oli]] ad reidön padis.',
-'whitelistacctitle'         => 'No dalol jafön kali',
-'whitelistacctext'          => 'Ad dalön jafön kalis in {{SITENAME}}, mutol [[Special:Userlogin|nunädön oli]] e mutol labön dälis zesüdik.',
 'confirmedittitle'          => 'Fümedam me pot leäktronik zesüdon ad redakön',
 'confirmedittext'           => 'Mutol fümedön ladeti leäktronik ola büä okanol redakön padis. Pladölos e lonöfükölos ladeti olik in [[Special:Preferences|buükams olik]].',
 'nosuchsectiontitle'        => 'Diläd at no dabinon',
@@ -622,7 +616,7 @@
 'newarticletext'            => "Esökol yümi lü pad, kel no nog dabinon.
 Ad jafön padi at, primolös ad klavön vödemi olik in penaspad dono (logolöd [[{{MediaWiki:Helppage}}|yufapadi]] tefü nüns tefik votik).
 If binol is pölo, välolös knopi: '''geikön''' bevüresodatävöma olik.",
-'anontalkpagetext'          => "----''Bespikapad at duton lü geban nennemik, kel no nog ejafon kali, u no vilon labön u gebön oni. Sekü atos pemütobs ad gebön ladeti-IP ad dientifükön gebani at. Ladets-IP kanons pagebön fa gebans difik. If binol geban nennemik e cedol, das küpets netefik pelüodükons ole, [[Special:Userlogin|jafolös, begö! kali u nunädolös oli]] ad vitön kofudi ko gebans nennemik votik.''",
+'anontalkpagetext'          => "----''Bespikapad at duton lü geban nennemik, kel no nog ejafon kali, u no vilon labön u gebön oni. Sekü atos pemütobs ad gebön ladeti-IP ad dientifükön gebani at. Ladets-IP kanons pagebön fa gebans difik. If binol geban nennemik e cedol, das küpets netefik pelüodükons ole, [[Special:UserLogin|jafolös, begö! kali u nunädolös oli]] ad vitön kofudi ko gebans nennemik votik.''",
 'noarticletext'             => 'Atimo no dabinon vödem su pad at. Kanol [[Special:Search/{{PAGENAME}}|sukön padatiädi at]] su pads votik u [{{fullurl:{{FULLPAGENAME}}|action=edit}} redakön padi at].',
 'userpage-userdoesnotexist' => 'Gebanakal: "$1" no peregistaron. Fümükolös, va vilol jäfön/redakön padi at.',
 'clearyourcache'            => "'''Prudö!''' Pos dakip buükamas, mögos, das ozesüdos ad nedemön memi nelaidüpik bevüresodatävöma ad logön votükamis. '''Mozilla / Firefox / Safari:''' kipolöd klavi ''Shift'' dono e välolöd eli ''Reload'' (= dönulodön) me mugaparat, u dränolöd klävis ''Ctrl-Shift-R'' (''Cmd-Shift-R'' pö el Apple Mac); pro el '''IE:''' (Internet Explorer) kipolöd klavi ''Ctrl'' dono e välolöd eli ''Refresh'' (= flifädükön) me mugaparat, u dränolöd klavis ''Ctrl-F5''; '''Konqueror:''' välolöd eli ''Reload'' (= dönulodön) me mugaparat, u dränolöd klavi ''F5''; gebans ela '''Opera''' ba nedons vagükön lölöfiko memi nelaidüpik me ''Tools→Preferences'' (Stumem->Buükams).",
@@ -674,7 +668,7 @@
 'hiddencategories'          => 'Pad at duton lü {{PLURAL:$1|klad peklänedöl 1|klads peklänedöl $1}}:',
 'nocreatetitle'             => 'Padijafam pemiedükon',
 'nocreatetext'              => '{{SITENAME}} emiedükon mögi ad jafön padis nulik.
-Kanol redakön padi dabinöl, u [[Special:Userlogin|nunädön oli u jafön kali]].',
+Kanol redakön padi dabinöl, u [[Special:UserLogin|nunädön oli u jafön kali]].',
 'nocreate-loggedin'         => 'No dalol jafön padis nulik in {{SITENAME}}.',
 'permissionserrors'         => 'Dälapöls',
 'permissionserrorstext'     => 'No dalol dunön atosi sekü {{PLURAL:$1|kod|kods}} sököl:',
@@ -782,7 +776,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Lovelogam-jenotalised',
-'suppressionlogtext' => 'Is palisedons moükams e blokams lätik, kels ätefons ninädi de guvans peklänedöli. Logolös [[Special:Ipblocklist|lisedi ladetas-IP pebloköl]], kö pajonons blokams anu lonöföls.',
+'suppressionlogtext' => 'Is palisedons moükams e blokams lätik, kels ätefons ninädi de guvans peklänedöli. Logolös [[Special:IPBlockList|lisedi ladetas-IP pebloköl]], kö pajonons blokams anu lonöföls.',
 
 # History merging
 'mergehistory'                     => 'Balön padajenotemis',
@@ -862,7 +856,7 @@
 'mypreferences'            => 'Buükams obik',
 'prefs-edits'              => 'Num redakamas:',
 'prefsnologin'             => 'No enunädon oki',
-'prefsnologintext'         => 'Nedol [[Special:Userlogin|nunädön oli]] büä kanol votükön gebanabuükamis.',
+'prefsnologintext'         => 'Nedol [[Special:UserLogin|nunädön oli]] büä kanol votükön gebanabuükamis.',
 'prefsreset'               => 'Buükams egekömons ad stad büik peregistaröl.',
 'qbsettings'               => 'Stumem',
 'qbsettings-none'          => 'Nonik',
@@ -934,7 +928,7 @@
 'userrights-reason'           => 'Kod votükama:',
 'userrights-no-interwiki'     => 'No labol däli ad votükön gebanagitätis in vüks votik.',
 'userrights-nodatabase'       => 'Nünodem: $1 no dabinon, u no binon topik.',
-'userrights-nologin'          => 'Mutol [[Special:Userlogin|nunädön oli]] me guvanakal ad dalön gevön gitätis gebanes.',
+'userrights-nologin'          => 'Mutol [[Special:UserLogin|nunädön oli]] me guvanakal ad dalön gevön gitätis gebanes.',
 'userrights-notallowed'       => 'Kal olik no labon däli ad votükön gebanagitätis.',
 'userrights-changeable-col'   => 'Grups fa ol votükoviks',
 'userrights-unchangeable-col' => 'Grups fa ol nevotükoviks',
@@ -1040,10 +1034,10 @@
 'reupload'                    => 'Löpükön dönu',
 'reuploaddesc'                => 'Nosükon lopükami e geikön lü löpükamafomet.',
 'uploadnologin'               => 'No enunädon oki',
-'uploadnologintext'           => 'Mutol [[Special:Userlogin|nunädön oli]] ad löpükön ragivis.',
+'uploadnologintext'           => 'Mutol [[Special:UserLogin|nunädön oli]] ad löpükön ragivis.',
 'upload_directory_read_only'  => 'Ragiviär lopükama ($1) no kanon papenön fa dünanünöm bevüresodik.',
 'uploaderror'                 => 'Pök pö löpükam',
-'uploadtext'                  => "Gebolös fometi dono ad löpükön ragivis. Ad logön u sukön ragivis ya pelöpükölis, gololös lü [[Special:Imagelist|lised ragivas pelöpüköl]].
+'uploadtext'                  => "Gebolös fometi dono ad löpükön ragivis. Ad logön u sukön ragivis ya pelöpükölis, gololös lü [[Special:ImageList|lised ragivas pelöpüköl]].
 Löpükams e moükams padakipons id in  [[Special:Log/upload|jenotalised löpükamas]].
 
 Ad pladön magodi at ini pad semik, gebolös yümi fomätü:
@@ -1130,7 +1124,7 @@
 'upload_source_url'  => ' (el URL lonöföl ä fa valans gebovik)',
 'upload_source_file' => ' (ragiv pö nünöm olik)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Su pad patik at ragivs pelöpüköl valik pelisedons.
 Nomiko ragivs pelöpüköl lätikün palisedons primü lised.
 Klikolös tiädi padüla ad votükön sökaleodi at.',
@@ -1170,18 +1164,18 @@
 # File reversion
 'filerevert'                => 'Geükön padi: $1',
 'filerevert-legend'         => 'Geükön ragivi',
-'filerevert-intro'          => '<span class="plainlinks">Anu geükol padi: \'\'\'[[Media:$1|$1]]\'\'\' ad [fomam $4: $3, $2].</span>',
+'filerevert-intro'          => "Anu geükol padi: '''[[Media:$1|$1]]''' ad [fomam $4: $3, $2].",
 'filerevert-comment'        => 'Küpet:',
 'filerevert-defaultcomment' => 'Pegeükon ad fomam: $2, $1',
 'filerevert-submit'         => 'Geükön',
-'filerevert-success'        => '<span class="plainlinks">Pad: \'\'\'[[Media:$1|$1]]\'\'\' pegeükon ad [fomam $4: $3, $2].</span>',
+'filerevert-success'        => "Pad: '''[[Media:$1|$1]]''' pegeükon ad [fomam $4: $3, $2].",
 'filerevert-badversion'     => 'No dabinon fomam topik büik ragiva at labü timamäk pegevöl',
 
 # File deletion
 'filedelete'                  => 'Moükön padi: $1',
 'filedelete-legend'           => 'Moükön ragivi',
 'filedelete-intro'            => "Moükol padi: '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Anu moükol fomami pada: \'\'\'[[Media:$1|$1]]\'\'\' [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Anu moükol fomami pada: '''[[Media:$1|$1]]''' [$4 $3, $2].",
 'filedelete-comment'          => 'Küpet:',
 'filedelete-submit'           => 'Moükön',
 'filedelete-success'          => "'''$1''' pemoükon.",
@@ -1234,7 +1228,7 @@
 Kludo, zänedo ebinons redakams '''\$5'''  a pad, e logams '''\$6''' a redakam.
 
 Lunot [http://www.mediawiki.org/wiki/Manual:Job_queue vobodapoodkeda] binon '''\$7'''.",
-'userstatstext'          => "Dabinon{{PLURAL:$1| [[Special:Listusers|geban]] peregistaröl '''1'''|s [[Special:Listusers|gebans]] peregistaröl '''$1'''}}; '''$2''' (ü '''$4%''') {{PLURAL:$2|binon|binons}} $5.",
+'userstatstext'          => "Dabinon{{PLURAL:$1| [[Special:ListUsers|geban]] peregistaröl '''1'''|s [[Special:ListUsers|gebans]] peregistaröl '''$1'''}}; '''$2''' (ü '''$4%''') {{PLURAL:$2|binon|binons}} $5.",
 'statistics-mostpopular' => 'Pads suvüno palogöls:',
 
 'disambiguations'      => 'Telplänovapads',
@@ -1326,7 +1320,7 @@
 'logempty'             => 'No dabinons notets in jenotalised at.',
 'log-title-wildcard'   => 'Sukön tiäds primöl me:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Pads valik',
 'alphaindexline'    => '$1 jü $2',
 'nextpage'          => 'Pad sököl ($1)',
@@ -1348,12 +1342,12 @@
 'special-categories-sort-count' => 'leodükön ma num',
 'special-categories-sort-abc'   => 'leodükön ma lafab',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Jonolöd gebanis primölo me:',
 'listusers-submit'   => 'Jonolöd',
 'listusers-noresult' => 'Geban nonik petuvon.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Gitäts gebanagrupa',
 'listgrouprights-summary'  => 'Is palisedons gebanagrups in vük at dabinöls, sa gitäts tefik onsik.
 Nüns pluik tefü gebanagitäts patuvons [[{{MediaWiki:Listgrouprights-helppage}}|is]].',
@@ -1364,7 +1358,7 @@
 
 # E-mail user
 'mailnologin'     => 'Ladet nonik ad sedön',
-'mailnologintext' => 'Mutol [[Special:Userlogin|nunädön oli]] e labön ladeti leäktronik lonöföl pö [[Special:Preferences|buükams olik]] ad dalön sedön poti leäktronik gebanes votik.',
+'mailnologintext' => 'Mutol [[Special:UserLogin|nunädön oli]] e labön ladeti leäktronik lonöföl pö [[Special:Preferences|buükams olik]] ad dalön sedön poti leäktronik gebanes votik.',
 'emailuser'       => 'Penön gebane at',
 'emailpage'       => 'Penön gebane',
 'emailpagetext'   => 'If gebane at egivon ladeti leäktronik lonöföl in gebanabuükams onik,
@@ -1390,10 +1384,10 @@
 'nowatchlist'          => 'Labol nosi in galädalised olik.',
 'watchlistanontext'    => '$1 ad logön u redakön lienis galädaliseda olik',
 'watchnologin'         => 'No enunädon oki',
-'watchnologintext'     => 'Mutol [[Special:Userlogin|nunädön oli]] büä kanol votükön galädalisedi olik.',
+'watchnologintext'     => 'Mutol [[Special:UserLogin|nunädön oli]] büä kanol votükön galädalisedi olik.',
 'addedwatch'           => 'Peläüköl lä galädalised',
 'addedwatchtext'       => "Pad: \"[[:\$1]]\" peläükon lä [[Special:Watchlist|galädalised]] olik.
-Votükams fütürik pada at, äsi bespikapada onik, polisedons us, e pad popenon '''me tonats dagik'''  in [[Special:Recentchanges|lised votükamas nulik]] ad fasilükön tuvi ona.
+Votükams fütürik pada at, äsi bespikapada onik, polisedons us, e pad popenon '''me tonats dagik'''  in [[Special:RecentChanges|lised votükamas nulik]] ad fasilükön tuvi ona.
 
 If vilol poso moükön padi de galädalised olik, välolös lä on knopi: „negalädön“.",
 'removedwatch'         => 'Pemoükon de galädalised',
@@ -1503,7 +1497,7 @@
 'rollback-success'            => 'Redakams gebana: $1 pesädunons; pad pevotükon ad fomam lätik fa geban: $2.',
 'protectlogpage'              => 'Jenotalised jelodamas',
 'protectlogtext'              => 'Is palisedons pads pelökofärmüköl e pemaifüköls.
-Logolös [[Special:Protectedpages|lisedi padas pejelöl]], kö pajonons padijelams anu lonöföls.',
+Logolös [[Special:ProtectedPages|lisedi padas pejelöl]], kö pajonons padijelams anu lonöföls.',
 'protectedarticle'            => 'ejelon padi: "[[$1]]"',
 'modifiedarticleprotection'   => 'evotükon jelanivodi pada: "[[$1]]"',
 'unprotectedarticle'          => 'Pad: "[[$1]]" pesäjelon.',
@@ -1646,7 +1640,7 @@
 'badipaddress'                => 'Ladet-IP no lonöfon',
 'blockipsuccesssub'           => 'Blokam eplöpon',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] peblokon.
-<br />Logolös [[Special:Ipblocklist|lisedi ladetas-IP pebloköl]] ad vestigön blokamis.',
+<br />Logolös [[Special:IPBlockList|lisedi ladetas-IP pebloköl]] ad vestigön blokamis.',
 'ipb-edit-dropdown'           => 'Redakön kodis blokama',
 'ipb-unblock-addr'            => 'Säblokön eli $1',
 'ipb-unblock'                 => 'Säblokön gebananemi u ladeti-IP',
@@ -1675,7 +1669,7 @@
 'autoblocker'                 => 'Peblokon bi ladet-IP olik pegebon brefabüo fa geban: „[[User:$1|$1]]“. Kod blokama ela $1 binon: „$2“',
 'blocklogpage'                => 'Jenotalised blokamas',
 'blocklogentry'               => '"[[$1]]" peblokon dü: $2 $3',
-'blocklogtext'                => 'Is binon lised gebanablokamas e gebanasäblokamas. Ladets-IP itjäfidiko pebloköls no pajonons. Logolös blokamis e xilis anu lonöfölis in [[Special:Ipblocklist|lised IP-blokamas]].',
+'blocklogtext'                => 'Is binon lised gebanablokamas e gebanasäblokamas. Ladets-IP itjäfidiko pebloköls no pajonons. Logolös blokamis e xilis anu lonöfölis in [[Special:IPBlockList|lised IP-blokamas]].',
 'unblocklogentry'             => '$1 pesäblokon',
 'block-log-flags-anononly'    => 'te gebans nennemik',
 'block-log-flags-nocreate'    => 'kalijaf penemögükon',
@@ -1707,7 +1701,7 @@
 'lockdbsuccesssub'    => 'Lökofärmükam nünodema eplöpon',
 'unlockdbsuccesssub'  => 'Maifükam nünodema eplöpon',
 'lockdbsuccesstext'   => 'Nünodem pelökofärmükon.<br />
-No glömolös ad [[Special:Unlockdb|maifükön oni]] ven ufinükol vobi olik.',
+No glömolös ad [[Special:UnlockDB|maifükön oni]] ven ufinükol vobi olik.',
 'unlockdbsuccesstext' => 'Nünodem pemaifükon.',
 'lockfilenotwritable' => 'Ragiv lökofärmükamas no votükovon. Ad lökofärmükön u maifükön nünodemi, ragiv at muton binön votükovik (dub dünanünöm).',
 'databasenotlocked'   => 'Vük at no pefärmükon.',
@@ -1727,8 +1721,6 @@
 
 Ön jenets at, if vilol topätükön bespikapadi u balön oni e padi ya dabinöl, ol it omutol dunön osi.",
 'movearticle'             => 'Topätükolöd padi',
-'movenologin'             => 'No enunädon oki',
-'movenologintext'         => 'Mutol binön geban peregistaröl e [[Special:Userlogin|nunädön oli]] ad topätükön padi.',
 'movenotallowed'          => 'No dalol topätükön padis in {{SITENAME}}.',
 'newtitle'                => 'Lü tiäd nulik',
 'move-watch'              => 'Pladolöd padi at ini galädalised',
@@ -1750,7 +1742,7 @@
 'delete_and_move'         => 'Moükolöd e topätükolöd',
 'delete_and_move_text'    => '==Moükam peflagon==
 
-Yeged nulik "[[$1]]" ya dabinon. Vilol-li moükön oni ad jafön spadi pro topätükam?',
+Yeged nulik "[[:$1]]" ya dabinon. Vilol-li moükön oni ad jafön spadi pro topätükam?',
 'delete_and_move_confirm' => 'Si! moükolöd padi',
 'delete_and_move_reason'  => 'Pemoükon ad jafön spadi pro topätükam',
 'selfmove'                => 'Tiäds nulik e bäldik binons ots; pad no kanon patopätükön sui ok it.',
@@ -1966,7 +1958,7 @@
 'show-big-image'       => 'Gretot gudikün',
 'show-big-image-thumb' => '<small>Gretot büologeda at: magodaziöbs $1 × $2</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Pänotem ragivas nulik',
 'imagelisttext'         => "Dono binon lised '''$1''' {{PLURAL:$1|ragiva|ragivas}} $2 pedilädölas.",
 'newimages-summary'     => 'Pad patik at lisedon ragivis pelöpüköl lätik.',
@@ -2106,7 +2098,7 @@
 
 # External editor support
 'edit-externally'      => 'Votükön ragivi at me nünömaprogram plödik',
-'edit-externally-help' => 'Reidolös eli [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] (in Linglänapük) ad tuvön nünis pluik.',
+'edit-externally-help' => 'Reidolös eli [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] (in Linglänapük) ad tuvön nünis pluik.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'valik',
@@ -2162,7 +2154,7 @@
 'recreate'            => 'Dönujafön',
 
 # HTML dump
-'redirectingto' => 'Lüodükölo lü: [[$1]]...',
+'redirectingto' => 'Lüodükölo lü: [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Vagükön eli caché pada at?
@@ -2240,7 +2232,7 @@
 'version-software-product' => 'Prodäd',
 'version-software-version' => 'Fomam',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Ragivaluveg',
 'filepath-page'    => 'Ragiv:',
 'filepath-submit'  => 'Luveg',
Index: languages/messages/MessagesDe_formal.php
===================================================================
--- languages/messages/MessagesDe_formal.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDe_formal.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,15 +5,18 @@
  * @file
  *
  * @author Jimmy Collins <jimmy.collins@web.de>
+ * @author Leithian
+ * @author Pill
  * @author Raimond Spekking (Raymond) <raimond.spekking@gmail.com> since January 2007
  * @author Tim Bartel (avatar) <wikipedia@computerkultur.org> formal addressing
- * @author Siebrand
  */
 
 $fallback = 'de';
 
 $messages = array(
 # User preference toggles
+'tog-underline'        => 'Links unterstreichen:',
+'tog-nocache'          => 'Seitencache deaktivieren',
 'tog-enotifrevealaddr' => 'Ihre E-Mail-Adresse wird in Benachrichtigungs-E-Mails angezeigt.',
 
 'mainpagedocfooter' => 'Hilfe zur Benutzung und Konfiguration der Wiki-Software finden Sie im [http://meta.wikimedia.org/wiki/Help:Contents Benutzerhandbuch].
@@ -38,14 +41,15 @@
 
 Die Seite ist möglicherweise gelöscht oder verschoben worden.
 
-Falls dies nicht der Fall ist, haben Sie eventuell einen Fehler in der Software gefunden. Bitte melden Sie dies einem [[{{MediaWiki:Grouppage-sysop}}|Administrator]] unter Nennung der URL.',
+Falls dies nicht der Fall ist, haben Sie eventuell einen Fehler in der Software gefunden. Bitte melden Sie dies einem [[Special:ListUsers/sysop|Administrator]] unter Nennung der URL.',
 'actionthrottledtext'  => 'Diese Aktion kann in einem kurzen Zeitabstand nur begrenzt oft ausgeführt werden. Sie haben diese Grenze soeben erreicht. Bitte versuchen Sie es in einigen Minuten erneut.',
 'namespaceprotected'   => "Sie haben keine Berechtigung, die Seite im '''$1'''-Namensraum zu bearbeiten.",
 'customcssjsprotected' => 'Sie sind nicht berechtigt, diese Seite zu bearbeiten, da sie zu den persönlichen Einstellungen eines anderen Benutzers gehört.',
 
 # Login and logout pages
-'logouttext'                 => 'Sie sind nun abgemeldet.
-Sie können {{SITENAME}} jetzt anonym weiterbenutzen, oder sich erneut unter dem selben oder einem anderen Benutzernamen anmelden.',
+'logouttext'                 => '<strong>Sie sind nun abgemeldet.</strong>
+
+Sie können {{SITENAME}} jetzt anonym weiter benutzen, oder sich erneut unter dem selben oder einem anderen Benutzernamen [[Special:UserLogin|anmelden]].',
 'welcomecreation'            => '== Willkommen, $1! ==
 
 Ihr Benutzerkonto wurde eingerichtet. Vergessen Sie nicht, Ihre Einstellungen anzupassen.',
@@ -100,7 +104,7 @@
 'missingcommentheader'             => "'''ACHTUNG:''' Sie haben keine Überschrift im Feld „Betreff:“ eingegeben. Wenn Sie erneut auf „Seite speichern“ klicken, wird Ihre Bearbeitung ohne Überschrift gespeichert.",
 'blockedtext'                      => 'Ihr Benutzername oder Ihre IP-Adresse wurde von $1 gesperrt. Als Grund wurde angegeben:
 
-:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
+:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
 
 <p style="border-style: solid; border-color: red; border-width: 1px; padding:5px;"><b>Ein Lesezugriff ist weiterhin möglich,</b>
 nur die Bearbeitung und Erstellung von Seiten in {{SITENAME}} wurde gesperrt.
@@ -121,7 +125,7 @@
 'autoblockedtext'                  => 'Ihre IP-Adresse wurde automatisch gesperrt, da sie von einem anderen Benutzer genutzt wurde, der durch $1 gesperrt wurde.
 Als Grund wurde angegeben:
 
-:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
+:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
 
 <p style="border-style: solid; border-color: red; border-width: 1px; padding:5px;"><b>Ein Lesezugriff ist weiterhin möglich,</b>
 nur die Bearbeitung und Erstellung von Seiten in {{SITENAME}} wurde gesperrt.
@@ -136,19 +140,17 @@
 *Beginn der Sperre: $8
 *Sperr-Ende: $6
 *IP-Adresse: $3
+*Sperre betrifft: $7
 *Sperr-ID: #$5
 </div>',
 'blockededitsource'                => "Der Quelltext '''Ihrer Änderungen''' an '''$1''':",
 'whitelistedittext'                => 'Sie müssen sich $1, um Seiten bearbeiten zu können.',
-'whitelistreadtext'                => 'Sie müssen sich [[Special:Userlogin|hier anmelden]], um Seiten lesen zu können.',
-'whitelistacctitle'                => 'Sie sind nicht berechtigt, ein Benutzerkonto anzulegen.',
-'whitelistacctext'                 => 'Um in {{SITENAME}} Benutzer anlegen zu dürfen, müssen Sie sich [[Special:Userlogin|hier anmelden]] und die nötigen Berechtigungen haben.',
 'confirmedittext'                  => 'Sie müssen Ihre E-Mail-Adresse erst bestätigen, bevor Sie Bearbeitungen vornehmen können. Bitte ergänzen und bestätigen Sie Ihre E-Mail in den [[Special:Preferences|Einstellungen]].',
 'nosuchsectiontext'                => 'Sie versuchen den nicht vorhandenen Abschnitt $1 zu bearbeiten. Es können jedoch nur bereits vorhandene Abschnitte bearbeitet werden.',
 'loginreqpagetext'                 => 'Sie müssen sich $1, um Seiten lesen zu können.',
-'anontalkpagetext'                 => "---- ''Diese Seite dient dazu, einem nicht angemeldeten Benutzer Nachrichten zu hinterlassen. Wenn Sie mit den Kommentaren auf dieser Seite nichts anfangen können, richten sie sich vermutlich an einen früheren Inhaber Ihrer IP-Adresse und Sie können sie ignorieren.''",
+'anontalkpagetext'                 => "---- ''Diese Seite dient dazu, einem nicht angemeldeten Benutzer Nachrichten zu hinterlassen. Es wird seine IP-Adresse zur Identifizierung verwendet. IP-Adressen können von mehreren Benutzerm gemeinsam verwendet werden. Wenn Sie mit den Kommentaren auf dieser Seite nichts anfangen können, richten sie sich vermutlich an einen früheren Inhaber Ihrer IP-Adresse und Sie können  sie ignorieren. Sie können sich auch ein [[Special:UserLogin/signup|Benutzerkonto erstellen]] oder sich [[Special:UserLogin|anmelden]], um künftig Verwechslungen mit anderen anonymen Benutzer zu vermeiden.''",
 'userpage-userdoesnotexist'        => 'Das Benutzerkonto „$1“ ist nicht vorhanden. Bitte prüfen Sie, ob Sie diese Seite wirklich erstellen/bearbeiten möchten.',
-'clearyourcache'                   => "'''Hinweis:''' Leeren Sie nach dem Speichern den Browser-Cache, um die Änderungen zu sehen: '''Mozilla/Firefox:''' ''Shift-Strg-R'', '''Internet Explorer:''' ''Strg-F5'', '''Opera:''' ''F5'', '''Safari:''' ''⌘-R'', '''Konqueror:''' ''Strg-R''.",
+'clearyourcache'                   => "'''Hinweis - Leeren Sie nach dem Speichern den Browser-Cache, um die Änderungen sehen zu können:''' '''Mozilla/Firefox/Safari:''' ''Shift'' gedrückt halten und auf ''Aktualisieren'' klicken oder alternativ entweder ''Strg-F5'' oder ''Strg-R'' (''Befehlstaste-R'' bei Macintosh) drücken; '''Konqueror: '''Auf ''Aktualisieren'' klicken oder ''F5'' drücken; '''Opera:''' Cache unter ''Extras → Einstellungen'' leeren; '''Internet Explorer:''' ''Strg-F5'' drücken oder ''Strg'' gedrückt halten und dabei auf ''Aktualisieren'' klicken.",
 'usercssjsyoucanpreview'           => '<strong>Tipp:</strong> Benutzen Sie den Vorschau-Button, um Ihr neues CSS/JS vor dem Speichern zu testen.',
 'usercsspreview'                   => "== Vorschau Ihres Benutzer-CSS ==
 '''Hinweis:''' Nach dem Speichern müssen Sie Ihren Browser anweisen, die neue Version zu laden: '''Mozilla/Firefox:''' ''Strg-Shift-R'', '''Internet Explorer:''' ''Strg-F5'', '''Opera:''' ''F5'', '''Safari:''' ''Cmd-Shift-R'', '''Konqueror:''' ''F5''.",
@@ -163,7 +165,7 @@
 
 ''Da in {{SITENAME}} das Speichern von reinem HTML aktiviert ist, wurde die Vorschau ausgeblendet, um JavaScript-Attacken vorzubeugen.''
 
-<strong>Bitte versuchen Sie es erneut, indem Sie unter der folgenden Textvorschau nochmals auf „Seite speichern“ klicken. Sollte das Problem bestehen bleiben, melden Sie sich ab und danach wieder an.</strong>",
+<strong>Bitte versuchen Sie es erneut, indem Sie unter der folgenden Textvorschau nochmals auf „Seite speichern“ klicken. Sollte das Problem bestehen bleiben, [[Special:UserLogout|melden Sie sich ab]] und danach wieder an.</strong>",
 'token_suffix_mismatch'            => '<strong>Ihre Bearbeitung wurde zurückgewiesen, da Ihr Browser Zeichen im Bearbeiten-Token verstümmelt hat.
 Eine Speicherung kann den Seiteninhalt zerstören. Dies geschieht bisweilen durch die Benutzung eines anonymen Proxy-Dienstes, der fehlerhaft arbeitet.</strong>',
 'explainconflict'                  => "Jemand anders hat diese Seite geändert, nachdem Sie angefangen haben diese zu bearbeiten.
@@ -186,7 +188,7 @@
 Überlegen Sie bitte, ob eine Aufteilung der Seite in kleinere Abschnitte möglich ist.</strong>',
 'readonlywarning'                  => '<strong>WARNUNG: Die Datenbank wurde während der Seitenbearbeitung für Wartungsarbeiten gesperrt, so dass Sie die Seite im Moment nicht
 speichern können. Sichern Sie den Text und versuchen Sie die Änderungen später einzuspielen.</strong>',
-'nocreatetext'                     => 'Auf {{SITENAME}} wurde das Erstellen neuer Seiten eingeschränkt. Sie können bestehende Seiten ändern oder sich [[Special:Userlogin|anmelden]].',
+'nocreatetext'                     => 'Auf {{SITENAME}} wurde das Erstellen neuer Seiten eingeschränkt. Sie können bestehende Seiten ändern oder sich [[Special:UserLogin|anmelden]].',
 'nocreate-loggedin'                => 'Sie haben keine Berechtigung, neue Seiten in {{SITENAME}} anzulegen.',
 'permissionserrorstext'            => 'Sie sind nicht berechtigt, die Aktion auszuführen. {{PLURAL:$1|Grund|Gründe}}:',
 'permissionserrorstext-withaction' => 'Sie sind nicht berechtigt, die Aktion „$2“ auszuführen, {{PLURAL:$1|Grund|Gründe}}:',
@@ -211,7 +213,7 @@
 'mergehistory-fail'   => 'Versionsvereinigung nicht möglich, bitte prüfen Sie die Seite und die Zeitangaben.',
 
 # Search results
-'searchsubtitle'        => 'Ihre Suchanfrage: „[[:$1|$1]]“.',
+'searchsubtitle'        => 'Ihre Suchanfrage: „[[:$1|$1]]“ ([[Special:Prefixindex/$1|alle mit „$1“ beginnenden Seiten]] | [[Special:WhatLinksHere/$1|alle Seiten, die nach „$1“ verlinken]])',
 'searchsubtitleinvalid' => 'Ihre Suchanfrage: „$1“.',
 'noexactmatch'          => "'''Es existiert keine Seite mit dem Titel „$1“.'''
 
@@ -224,17 +226,16 @@
 'searchdisabled'        => 'Die {{SITENAME}} Suche wurde deaktiviert. Sie können unterdessen mit Google suchen. Bitte bedenken Sie, dass der Suchindex für {{SITENAME}} veraltet sein kann.',
 
 # Preferences page
-'preferences-summary' => 'Auf dieser Spezialseite können Sie Ihre Zugangsdaten ändern und bestimmte Teile der Oberfläche individuell anpassen.',
-'prefsnologintext'    => 'Sie müssen [[Special:Userlogin|angemeldet]] sein, um Ihre Einstellungen ändern zu können.',
-'savedprefs'          => 'Ihre Einstellungen wurden gespeichert.',
-'timezonetext'        => 'Geben Sie die Anzahl der Stunden ein, die zwischen Ihrer Zeitzone und UTC liegen.',
+'prefsnologintext' => 'Sie müssen [[Special:UserLogin|angemeldet]] sein, um Ihre Einstellungen ändern zu können.',
+'savedprefs'       => 'Ihre Einstellungen wurden gespeichert.',
+'timezonetext'     => 'Geben Sie die Anzahl der Stunden ein, die zwischen Ihrer Zeitzone und UTC liegen.',
 
 # User rights
 'userrights-groups-help'      => 'Sie können die Gruppenzugehörigkeit für diesen Benutzer ändern.
 * Ein markiertes Kästchen bedeutet, dass der Benutzer Mitglied dieser Gruppe ist.
 * Ein * bedeutet, dass Sie das Benutzerrecht nach Erteilung nicht wieder zurücknehmen können (oder umgekehrt).',
 'userrights-no-interwiki'     => 'Sie haben keine Berechtigung, Benutzerrechte in anderen Wikis zu ändern.',
-'userrights-nologin'          => 'Sie müssen sich mit einem Administrator-Benutzerkonto [[{{#special:Userlogin}}|anmelden]], um Benutzerrechte zu ändern.',
+'userrights-nologin'          => 'Sie müssen sich mit einem Administrator-Benutzerkonto [[Special:UserLogin|anmelden]], um Benutzerrechte zu ändern.',
 'userrights-notallowed'       => 'Sie besitzen nicht die erforderlichen Berechtigungen, um Benutzerrechte zu vergeben.',
 'userrights-changeable-col'   => 'Gruppenzugehörigkeit, die Sie ändern dürfen',
 'userrights-unchangeable-col' => 'Gruppenzugehörigkeit, die Sie nicht ändern dürfen',
@@ -244,10 +245,12 @@
 'recentchanges-feed-description' => 'Verfolgen Sie mit diesem Feed die letzten Änderungen in {{SITENAME}}.',
 
 # Upload
-'uploadnologintext'           => 'Sie müssen [[Special:Userlogin|angemeldet sein]], um Dateien hochladen zu können.',
-'uploadtext'                  => "In der [[{{#special:Imagelist}}|Liste hochgeladener Dateien]] können Sie vorhandene Dateien suchen und sich anzeigen lassen.
+'uploadnologintext'           => 'Sie müssen [[Special:UserLogin|angemeldet sein]], um Dateien hochladen zu können.',
+'uploadtext'                  => "Benutzen Sie dieses Formular, um neue Dateien hochzuladen. 
 
-Benutzen Sie dieses Formular, um neue Dateien hochzuladen. Klicken Sie auf '''„Durchsuchen …“''', um einen Dateiauswahl-Dialog zu öffnen.
+Gehen Sie zu der [[Special:ImageList|Liste hochgeladener Dateien]], um vorhandene Dateien zu suchen und anzuzeigen. Siehe auch das [[Special:Log/upload|Datei-]]- und [[Special:Log/upload|Lösch-Logbuch]].
+
+Klicken Sie auf '''„Durchsuchen …“''', um einen Dateiauswahl-Dialog zu öffnen.
 Nach der Auswahl einer Datei wird der Dateiname im Textfeld '''„Quelldatei“''' angezeigt.
 Bestätigen Sie dann die Lizenz-Vereinbarung und klicken Sie anschließend auf '''„Datei hochladen“'''.
 Dies kann eine Weile dauern, besonders bei einer langsamen Internet-Verbindung.
@@ -285,8 +288,11 @@
 'filename-bad-prefix'         => 'Der Dateiname beginnt mit <strong>„$1“</strong>. Dies ist im allgemeinen der von einer Digitalkamera vorgegebene Dateiname und daher nicht sehr aussagekräftig.
 Bitte geben Sie der Datei einen Namen, der den Inhalt besser beschreibt.',
 
-'upload-file-error-text' => 'Bei der Erstellung einer temporären Datei auf dem Server ist ein interner Fehler aufgetreten. Bitte informieren Sie einen System-Administrator.',
-'upload-misc-error-text' => 'Beim Hochladen ist ein unbekannter Fehler aufgetreten. Prüfen Sie die URL auf Fehler, den Online-Status der Seite und versuchen Sie es erneut. Wenn das Problem weiter besteht, informieren Sie einen System-Administrator.',
+'upload-file-error-text' => 'Bei der Erstellung einer temporären Datei auf dem Server ist ein interner Fehler aufgetreten.
+Bitte informieren Sie einen [[Special:ListUsers/sysop|System-Administrator]].',
+'upload-misc-error-text' => 'Beim Hochladen ist ein unbekannter Fehler aufgetreten.
+Prüfen Sie die URL auf Fehler, den Online-Status der Seite und versuchem Sie erneut.
+Wenn das Problem weiter besteht, informieren Sie einen [[Special:ListUsers/sysop|System-Administrator]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6-text'  => 'Die angegebene URL ist nicht erreichbar. Prüfen Sie sowohl die URL auf Fehler als auch den Online-Status der Seite.',
@@ -297,26 +303,23 @@
 'noimage'       => 'Eine Datei mit diesem Namen existiert nicht, Sie können sie jedoch $1.',
 
 # File reversion
-'filerevert-intro' => '<span class="plainlinks">Sie setzen die Datei \'\'\'[[Media:$1|$1]]\'\'\' auf die [$4 Version vom $2, $3 Uhr] zurück.</span>',
+'filerevert-intro' => "Sie setzen die Datei '''[[Media:$1|$1]]''' auf die [$4 Version vom $2, $3 Uhr] zurück.",
 
 # File deletion
 'filedelete-intro'     => "Sie löschen die Datei '''„[[Media:$1|$1]]“'''.",
-'filedelete-intro-old' => '<span class="plainlinks">Sie löschen von der Datei \'\'\'„[[Media:$1|$1]]“\'\'\' die [$4 Version vom $2, $3 Uhr].</span>',
+'filedelete-intro-old' => "Sie löschen von der Datei '''„[[Media:$1|$1]]“''' die [$4 Version vom $2, $3 Uhr].",
 'filedelete-iscurrent' => 'Sie versuchen die aktuelle Version dieser Datei zu löschen. Bitte setzen Sie diese vorher auf eine ältere Version zurück.',
 
 # Unused templates
-'unusedtemplates-summary' => 'Diese Seite listet alle Vorlagen auf, die nicht in anderen Seiten eingebunden sind. Überprüfen Sie andere Links zu den Vorlagen, bevor Sie diese löschen.',
+'unusedtemplatestext' => 'Diese Seite listet alle Vorlagen auf, die nicht in anderen Seiten eingebunden sind. Überprüfen Sie andere Links zu den Vorlagen, bevor Sie diese löschen.',
 
 # Miscellaneous special pages
 'unusedimagestext' => 'Bitte beachten Sie, dass andere Webseiten diese Datei mit einer direkten URL verlinken können. Diese wird nicht als Verwendung erkannt, so dass die Datei hier aufgeführt wird.',
 'notargettext'     => 'Sie haben nicht angegeben, auf welche Seite diese Funktion angewendet werden soll.',
 
-# Book sources
-'booksources-summary' => 'Auf dieser Spezialseite können Sie eine ISBN eingeben und erhalten dann eine Liste mit Onlinekatalogen und Bezugsmöglichkeiten zur gesuchten ISBN. Bindestriche oder Leerzeichen zwischen den Ziffern spielen für die Suche keine Rolle.',
-
 # E-mail user
-'mailnologintext' => 'Sie müssen [[Special:Userlogin|angemeldet sein]] und eine [[Special:Confirmemail|bestätigte]] E-Mail-Adresse haben, um anderen Benutzern E-Mails schicken zu können.',
-'emailpagetext'   => 'Wenn dieser Benutzer eine gültige E-Mail-Adresse angegeben hat, können Sie ihm mit dem untenstehenden Formular eine E-Mail senden. Als Absender wird die E-Mail-Adresse aus Ihren Einstellungen eingetragen, damit der Benutzer Ihnen antworten kann.',
+'mailnologintext' => 'Sie müssen [[Special:UserLogin|angemeldet sein]] und eine bestätigte E-Mail-Adresse in Ihren [[Special:Preferences|Einstellungen]] eingetragen haben, um anderen Benutzern E-Mails schicken zu können.',
+'emailpagetext'   => 'Wenn dieser Benutzer eine gültige E-Mail-Adresse angegeben hat, können Sie ihm mit dem untenstehenden Formular eine E-Mail senden. Als Absender wird die E-Mail-Adresse aus Ihren [[Special:Preferences|Einstellungen]] eingetragen, damit der Benutzer Ihnen antworten kann.',
 'emailccsubject'  => 'Kopie Ihrer Nachricht an $1: $2',
 'emailsenttext'   => 'Ihre E-Mail wurde verschickt.',
 
@@ -324,14 +327,14 @@
 'nowatchlist'       => 'Sie haben keine Einträge auf Ihrer Beobachtungsliste.',
 'watchlistanontext' => 'Sie müssen sich $1, um Ihre Beobachtungsliste zu sehen oder Einträge auf ihr zu bearbeiten.',
 'watchnologin'      => 'Sie sind nicht angemeldet',
-'watchnologintext'  => 'Sie müssen [[Special:Userlogin|angemeldet]] sein, um Ihre Beobachtungsliste zu bearbeiten.',
+'watchnologintext'  => 'Sie müssen [[Special:UserLogin|angemeldet]] sein, um Ihre Beobachtungsliste zu bearbeiten.',
 'addedwatchtext'    => 'Die Seite „<nowiki>$1</nowiki>“ wurde zu Ihrer [[Special:Watchlist|Beobachtungsliste]] hinzugefügt.
 
 Spätere Änderungen an dieser Seite und der dazugehörigen Diskussionsseite werden dort gelistet und
-in der Übersicht der [[Special:Recentchanges|letzten Änderungen]] in Fettschrift dargestellt.
+in der Übersicht der [[Special:RecentChanges|letzten Änderungen]] in Fettschrift dargestellt.
 
 Wenn Sie die Seite wieder von Ihrer Beobachtungsliste entfernen möchten, klicken Sie auf der jeweiligen Seite auf „nicht mehr beobachten“.',
-'removedwatchtext'  => 'Die Seite „<nowiki>$1</nowiki>“ wurde von Ihrer Beobachtungsliste entfernt.',
+'removedwatchtext'  => 'Die Seite „[[:$1]]“ wurde von Ihrer [[Special:Watchlist|Beobachtungsliste]] entfernt.',
 'watchnochange'     => 'Keine der von Ihnen beobachteten Seiten wurde während des angezeigten Zeitraums bearbeitet.',
 'watchlist-details' => 'Sie beobachten {{PLURAL:$1|1 Seite|$1 Seiten}}.',
 'watchlistcontains' => 'Ihre Beobachtungsliste enthält $1 {{PLURAL:$1|Seite|Seiten}}.',
@@ -361,8 +364,8 @@
 'historywarning'         => 'Achtung, die Seite, die Sie löschen möchten, hat eine Versionsgeschichte:',
 'confirmdeletetext'      => 'Sie sind dabei, eine Seite mit allen zugehörigen älteren Versionen zu löschen. Bitte bestätigen Sie, dass Sie sich der Konsequenzen bewusst sind, und dass Sie in Übereinstimmung mit den [[{{MediaWiki:Policy-url}}|Richtlinien]] handeln.',
 'deletedtext'            => '„<nowiki>$1</nowiki>“ wurde gelöscht. Im $2 finden Sie eine Liste der letzten Löschungen.',
-'sessionfailure'         => 'Es gab ein Problem mit Ihrer Benutzersitzung.
-Diese Aktion wurde aus Sicherheitsgründen abgebrochen, um eine falsche Zuordnung Ihrer Änderungen zu einem anderen Benutzer zu verhindern.
+'sessionfailure'         => 'Es gab ein Problem mit der Übertragung Ihrer Benutzerdaten.
+Diese Aktion wurde daher sicherheitshalber abgebrochen, um eine falsche Zuordnung Ihrer Änderungen zu einem anderen Benutzer zu verhindern.
 Bitte gehen Sie zurück und versuchen Sie den Vorgang erneut auszuführen.',
 'protect-text'           => "Hier können Sie den Schutzstatus für die Seite '''<nowiki>$1</nowiki>''' einsehen und ändern.",
 'protect-locked-blocked' => 'Sie können den Seitenschutz nicht ändern, da Ihr Benutzerkonto gesperrt ist. Hier sind die aktuellen Seitenschutz-Einstellungen für die Seite <strong>„$1“:</strong>',
@@ -389,15 +392,25 @@
 Dies sollte nur erfolgen, um Vandalismus zu verhindern und in Übereinstimmung mit den [[{{MediaWiki:Policy-url}}|Richtlinien]].
 Bitte geben Sie den Grund für die Sperre an.',
 'unblockiptext'    => 'Mit diesem Formular können Sie eine IP-Adresse oder einen Benutzer freigeben.',
-'autoblocker'      => 'Automatische Sperre, da Sie eine gemeinsame IP-Adresse mit [[Benutzer:$1]] benutzen. Grund: „$2“.',
+'autoblocker'      => 'Automatische Sperre, da Sie eine gemeinsame IP-Adresse mit [[User:$1|Benutzer:$1]] benutzen. Grund: „$2“.',
 'proxyblockreason' => 'Ihre IP-Adresse wurde gesperrt, da sie ein offener Proxy ist. Bitte kontaktieren Sie Ihren Internet-Provider oder Ihre Systemadministratoren und informieren Sie sie über dieses mögliche Sicherheitsproblem.',
 
 # Developer tools
 'locknoconfirm'     => 'Sie haben das Bestätigungsfeld nicht markiert.',
-'lockdbsuccesstext' => 'Die {{SITENAME}}-Datenbank wurde gesperrt.<br />Bitte geben Sie die Datenbank [[Special:Unlockdb|wieder frei]], sobald die Wartung abgeschlossen ist.',
+'lockdbsuccesstext' => 'Die {{SITENAME}}-Datenbank wurde gesperrt.<br />Bitte geben Sie die Datenbank [[Special:UnlockDB|wieder frei]], sobald die Wartung abgeschlossen ist.',
 
 # Move page
-'movepagetext'         => 'Mit diesem Formular können Sie eine Seite umbenennen (mitsamt allen Versionen). Der alte Titel wird zum neuen weiterleiten. Links auf den alten Titel werden nicht geändert.',
+'movepagetext'         => "Mit diesem Formular können Sie eine Seite umbenennen (mitsamt allen Versionen).
+Der alte Titel wird zum neuen weiterleiten.
+Sie können Weiterleitungen, die auf den Originaltitel verlinken, automatisch korrigieren lassen.
+Falls Sie dies nicht tun, prüfen Sie auf [[Special:DoubleRedirects|doppelte]] oder [[Special:BrokenRedirects|defekte Weiterleitungen]].
+Sie sind dafür verantwortlich, dass Links weiterhin auf das korrekte Ziel zeigen.
+
+Die Seite wird '''nicht''' verschoben, wenn es bereits eine Seite mit demselben Namen gibt, sofern diese nicht leer oder eine Weiterleitung ohne Versionsgeschichte ist. Dies bedeutet, dass Sie die Seite zurück verschieben können, wenn Sie einen Fehler gemacht haben. Sie können hingegen keine Seite überschreiben.
+
+'''Warnung'''
+Die Verschiebung kann weitreichende und unerwartete Folgen für beliebte Seiten haben.
+Sie sollten daher die Konsequenzen verstanden haben, bevor Sie fortfahren.",
 'movepagetalktext'     => "Die dazugehörige Diskussionsseite wird, sofern vorhanden, mitverschoben, '''es sei denn:'''
 *Es existiert bereits eine Diskussionsseite mit diesem Namen, oder
 *Sie wählen die unten stehende Option ab.
@@ -405,13 +418,12 @@
 In diesen Fällen müssen Sie, falls gewünscht, den Inhalt der Seite von Hand verschieben oder zusammenführen.
 
 Bitte den '''neuen''' Titel unter '''Ziel''' eintragen, darunter die Umbenennung bitte '''begründen.'''",
-'movenologintext'      => 'Sie müssen ein registrierter Benutzer und [[Special:Userlogin|angemeldet]] sein, um eine Seite zu verschieben.',
 'movenotallowed'       => 'Sie haben in diesem Wiki keine Berechtigung, Seiten zu verschieben.',
 'articleexists'        => 'Unter diesem Namen existiert bereits eine Seite. Bitte wählen Sie einen anderen Namen.',
 'talkexists'           => 'Die Seite selbst wurde erfolgreich verschoben, aber die zugehörige Diskussions-Seite nicht, da bereits eine mit dem neuen Titel existiert. Bitte gleichen Sie die Inhalte von Hand ab.',
 'delete_and_move_text' => '==Zielseite vorhanden, löschen?==
 
-Die Seite „[[$1]]“ existiert bereits. Möchten Sie diese löschen, um die Seite verschieben zu können?',
+Die Seite „[[:$1]]“ existiert bereits. Möchten Sie diese löschen, um die Seite verschieben zu können?',
 
 # Export
 'exporttext' => 'Mit dieser Spezialseite können Sie den Text (und die Bearbeitungs-/Versionsgeschichte) einzelner Seiten in eine XML-Datei exportieren.
@@ -469,8 +481,8 @@
 'deletedwhileediting' => '<span class="error">Achtung: Diese Seite wurde gelöscht, nachdem Sie angefangen haben, sie zu bearbeiten!
 Sehen Sie im [{{fullurl:Special:Log|type=delete&page=}}{{FULLPAGENAMEE}} Lösch-Logbuch] nach,
 warum die Seite gelöscht wurde. Wenn Sie die Seite speichern, wird sie neu angelegt.</span>',
-'confirmrecreate'     => "Benutzer [[User:$1|$1]] ([[User_talk:$1|Diskussion]]) hat diese Seite gelöscht, nachdem Sie angefangen haben, sie zu bearbeiten. Die Begründung lautete:
-''$2''
+'confirmrecreate'     => "Benutzer [[User:$1|$1]] ([[User talk:$1|Diskussion]]) hat diese Seite gelöscht, nachdem Sie angefangen haben, sie zu bearbeiten. Die Begründung lautete:
+: ''$2''
 Bitte bestätigen Sie, dass Sie diese Seite wirklich neu erstellen möchten.",
 
 # Watchlist editor
Index: languages/messages/MessagesKa.php
===================================================================
--- languages/messages/MessagesKa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,12 +5,10 @@
  * @file
  *
  * @author Alsandro
+ * @author Malafaya
  * @author Sopho
- * @author Malafaya
+ * @author ka.wikipedia.org sysops
  * @author לערי ריינהארט
- * @author Siebrand
- * @author ka.wikipedia.org sysops
- * @author SPQRobin
  */
 
 $namespaceNames = array(
@@ -315,7 +313,7 @@
 'nosuchspecialpage' => 'სპეციალური გვერდი არ არსებობს',
 'nospecialpagetext' => "<big>'''თქვენ არასწორი სპეციალური გვერდი მოითხოვეთ.'''</big>
 
-სწორი სპეციალური გვერდების სია შეგიძლიათ იხილოთ აქ: [[Special:Specialpages|{{int:specialpages}}]].",
+სწორი სპეციალური გვერდების სია შეგიძლიათ იხილოთ აქ: [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'შეცდომა',
@@ -541,10 +539,6 @@
 'blockededitsource'         => "ქვემოთ მოყვანილია '''$1'''-ში თქვენი რედაქტირების ტექსტი:",
 'whitelistedittitle'        => 'რედაქტირება საჭიროებს სისტემაში შესვლას',
 'whitelistedittext'         => 'გვერდების რედაქტირებისათვის თქვენ გესაჭიროებათ $1.',
-'whitelistreadtitle'        => 'წასაკითხად საჭიროა რეგისტრაცია',
-'whitelistreadtext'         => 'გვერდების წასაკითხად უნდა [[Special:Userlogin|დარეგისტრირდეთ]].',
-'whitelistacctitle'         => 'ანგარიშის შექმნის ნებართვა არ გაქვთ',
-'whitelistacctext'          => 'იმისათვის, რათა გქონდეთ ვიკიპედიაში ანგარიშების გახსნის უფლება, უნდა გაიაროთ [[Special:Userlogin|რეგისტრაცია]] და მოიპოვოთ სათანადო ნებართვები.',
 'confirmedittitle'          => 'რედაქტირებისთვის საჭიროა ელფოსტის დამოწმება',
 'confirmedittext'           => 'გვერდების დარედაქტირებამდე უნდა დაადასტუროთ თქვენი ელფოსტის მისამართი. გთხოვთ [[Special:Preferences|მომხმარებლის პარამეტრებში]] მიუთითოთ და დაამოწმოთ ელფოსტის მისამართი.',
 'nosuchsectiontitle'        => 'სექცია არ არსებობს',
@@ -555,11 +549,11 @@
 'accmailtitle'              => 'პაროლი გაგზავნილია.',
 'accmailtext'               => "'$1'-ის პაროლი გადაგზავნილია $2-ზე.",
 'newarticle'                => '(ახალი)',
-'newarticletext'            => 'ბმულის მეშვებით თქვენ მოხვდით გვერდზე, რომელიც ჯერ არ არსებობს.
+'newarticletext'            => 'ბმულის მეშვეობით თქვენ მოხვდით გვერდზე, რომელიც ჯერ არ არსებობს.
 გვერდის შესაქმნელად შეიყვანეთ ინფორმაცია ქვემო ფანჯარაში
 (იხ. [[{{MediaWiki:Helppage}}|დახმარების გვერდი]] დამატებითი ინფორმაციისთვის).
 თუ ამ გვერდზე შეცდომით მოხვდით, დაბრუნდით უკან თქვენი ბრაუზერის მეშვეობით.',
-'anontalkpagetext'          => "----''ეს არის ანონიმური მომხმარებლის განხილვის გვერდი, რომელსაც ანგარიში ჯერ არ შეუქმნია ან არ იყენებს მას. შესაბამისად, ჩვენ მისი ციფრული IP მისამართი უნდა გამოვიყენოთ მისი იდენტიფიცირებისთვის. ამგვარი მისამართი შეიძლება რამდენიმე მომხმარებელმა გამოიყენოს. თუ თქვენ ანონიმური მომხმარებელი ხართ და თვლით, რომ სხვისთვის გამიზნული მითითება მიიღეთ, გთხოვთ [[Special:Userlogin|შექმენით ანგარიში ან დარეგისტრირდით]] მომავალში გაუგებრობის თავიდან ასაცილებლად.''",
+'anontalkpagetext'          => "----''ეს არის ანონიმური მომხმარებლის განხილვის გვერდი, რომელსაც ანგარიში ჯერ არ შეუქმნია ან არ იყენებს მას. შესაბამისად, ჩვენ მისი ციფრული IP მისამართი უნდა გამოვიყენოთ მისი იდენტიფიცირებისთვის. ამგვარი მისამართი შეიძლება რამდენიმე მომხმარებელმა გამოიყენოს. თუ თქვენ ანონიმური მომხმარებელი ხართ და თვლით, რომ სხვისთვის გამიზნული მითითება მიიღეთ, გთხოვთ [[Special:UserLogin|შექმენით ანგარიში ან დარეგისტრირდით]] მომავალში გაუგებრობის თავიდან ასაცილებლად.''",
 'noarticletext'             => 'ამჟამად ამ გვერდზე ტექსტი არ არსებობს, თქვენ შგიძლიათ [[Special:Search/{{PAGENAME}}|მოძებნოთ ამ გვერდის სათაური]] სხვა გვერდებზე ან [{{fullurl:{{FULLPAGENAME}}|action=edit}} დაიწყოთ ამ გვერდის რედაქტირება].',
 'clearyourcache'            => "'''შენიშვნა:''' შენახვის შემდეგ შესაძლოა დაგჭირდეთ ბრაუზერის ქეშის გაწმენდა ცვლილებების სანახავად. '''Mozilla / Firefox / Safari:''' დააჭირეთ ''Shift'' ''Reload''-ზე დაწკაპებისას, ან დააჭირეთ ''Ctrl-Shift-R'' (''Cmd-Shift-R'' Apple Mac-ზე); '''IE:''' დააჭირეთ ''Ctrl'' ''Refresh''-ზე დაწკაპებისას, ან დააჭირეთ ''Ctrl-F5''; '''Konqueror:''': მხოლოდ დააწკაპეთ ''Reload'' ღილაკს, ან დააჭირეთ ''F5''; '''Opera''' შესაძლოა საჭირო გახდეს ქეშის სრულიად გაწმენდა ''Tools→Preferences''-დან.",
 'usercssjsyoucanpreview'    => "<strong>რჩევა:</strong> შენახვამდე გამოიყენეთ 'წინასწარი გადახედვის' ღილაკი თქვენი ახალი CSS/JS ტესტირებისთვის.",
@@ -676,6 +670,7 @@
 'mergehistory-submit'         => 'ცვლილებების შერწყმა',
 'mergehistory-empty'          => 'რაიმე ცვლილების შერწყმა შეუძლებელია.',
 'mergehistory-no-destination' => 'დანიშნულების გვერდი $1 არ არსებობს.',
+'mergehistory-autocomment'    => '[[:$1]] შეერთდა [[:$2]]-სთან',
 
 # Diffs
 'history-title'           => '"$1" ცვლილებათა ისტორია',
@@ -712,7 +707,7 @@
 'mypreferences'            => 'ჩემი კონფიგურაცია',
 'prefs-edits'              => 'რედაქციების რაოდენობა:',
 'prefsnologin'             => 'შესული არ ხართ',
-'prefsnologintext'         => 'თქვენ [[Special:Userlogin|რეგისტრირებული უნდა იყოთ]] მომხმარებლის კონფიგურაციის შესაცვლელად.',
+'prefsnologintext'         => 'თქვენ [[Special:UserLogin|რეგისტრირებული უნდა იყოთ]] მომხმარებლის კონფიგურაციის შესაცვლელად.',
 'qbsettings'               => 'სწრაფი ზოლი',
 'qbsettings-none'          => 'არაფერი',
 'qbsettings-fixedleft'     => 'ფიქსირებული მარცხნივ',
@@ -848,7 +843,7 @@
 'reupload'                    => 'ხელმეორედ ატვირთვა',
 'reuploaddesc'                => 'გააუქმეთ ატვირთვა და დაუბრუნდით ატვირთვის ფორმას.',
 'uploadnologin'               => 'რეგისტრაცია არ გაქვთ გავლილი',
-'uploadnologintext'           => 'ფაილის ატვირთვისთვის თქვენ უნდა [[Special:Userlogin|შეხვიდეთ]].',
+'uploadnologintext'           => 'ფაილის ატვირთვისთვის თქვენ უნდა [[Special:UserLogin|შეხვიდეთ]].',
 'upload_directory_read_only'  => 'ვებსერვერი ვერ იწერს ატვირთვის დირექტორიაში ($1).',
 'uploaderror'                 => 'ატვირთვის შეცდომა',
 'uploadtext'                  => "<div style=\"border: 1px solid grey; background: #ddf; padding: 10px 30px; margin: 0 auto;\">
@@ -921,7 +916,7 @@
 'nolicense'          => 'არაფერი არის მონიშნული',
 'upload_source_file' => ' (ფაილი შენს კომპიუტერზე)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'ძიება სურათის სახელის მიხედვით:',
 'imgfile'               => 'ფაილი',
 'imagelist'             => 'სურათების სია',
@@ -1092,7 +1087,7 @@
 'alllogstext'          => 'ატვირთვის, წაშლის, დაცვის, ბლოკირების და ადმინისტრატორის ჟურნალის კომბინირებული ასახვა. შეგიძლიათ გაფილტროთ ჟურნალის ტიპით, მომხმარებლის სახელით ან სტატიის მიხედვით.',
 'logempty'             => 'რეზულტატები არ არის სიაში.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'ყველა გვერდი',
 'alphaindexline'    => '$1-დან $2-მდე',
 'nextpage'          => 'შემდეგი გვერდი ($1)',
@@ -1113,11 +1108,11 @@
 'categoriespagetext'          => 'ვიკიპედიაში შემდეგი კატეგორიებია.',
 'special-categories-sort-abc' => 'ანბანზე დალაგება',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'ჩვენება',
 'listusers-noresult' => 'მომხმარებელი ვერ ვიპოვეთ.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'    => 'ჯგუფი',
 'listgrouprights-rights'   => 'უფლებები',
 'listgrouprights-helppage' => 'Help:ჯგუფების უფლებები',
@@ -1150,9 +1145,9 @@
 
 იხილეთ ან რედაქტირება გაუკეთეთ თქვენი კონტროლის სიაში შეტანილ ერთეულებს.',
 'watchnologin'         => 'რეგისტრაცია ვერ შესრულდა',
-'watchnologintext'     => 'თქვენ უნდა მოახდინოთ [[Special:Userlogin|რეგისტრაცია]] თქვენი კონტროლის სიის მოდიფიცირებისათვის.',
+'watchnologintext'     => 'თქვენ უნდა მოახდინოთ [[Special:UserLogin|რეგისტრაცია]] თქვენი კონტროლის სიის მოდიფიცირებისათვის.',
 'addedwatch'           => 'შეტანილია კონტროლის სიაში',
-'addedwatchtext'       => "გვერდი \"[[:\$1]]\" დაემატა თქვენი [[Special:Watchlist|კონტროლის სიას]]. მომავალი ცვლილებები ამ გვერდსა და მის განხილვაზე მითითებული იქნება ამ სიაში, ხოლო ბმული ამ გვერდზე [[Special:Recentchanges|უკანასკნელი ცვლილებების სიაში]] გამოჩნდება '''სქლად''' თქვენთვის მათი შემჩნევის გასაადვილებლად.",
+'addedwatchtext'       => "გვერდი \"[[:\$1]]\" დაემატა თქვენი [[Special:Watchlist|კონტროლის სიას]]. მომავალი ცვლილებები ამ გვერდსა და მის განხილვაზე მითითებული იქნება ამ სიაში, ხოლო ბმული ამ გვერდზე [[Special:RecentChanges|უკანასკნელი ცვლილებების სიაში]] გამოჩნდება '''სქლად''' თქვენთვის მათი შემჩნევის გასაადვილებლად.",
 'removedwatch'         => 'ამოღებულია კონტროლის სიიდან',
 'removedwatchtext'     => 'გვერდი "[[:$1]]" ამოღებულია თქვენი კონტროლის სიიდან.',
 'watch'                => 'კონტროლი',
@@ -1262,6 +1257,8 @@
 'protect-text'                => 'თქვენ შეგიძლიათ აქ იხილოთ და შეცვალოთ დაცვის დონე გვერდისთვის <strong><nowiki>$1</nowiki></strong>.',
 'protect-locked-access'       => 'თქვენს ანგარიშს არ აქვს გვერდის დაცვის დონეების შეცვლის ნებართვა.
 იხილეთ ქვემოთ ამჟამინდელი პარამეტრები გვერდისთვის <strong>$1</strong>:',
+'protect-cascadeon'           => 'ეს გვერდი ამჟამად დაცულია, ვინაიდან იგი ნაწილია ამ {{PLURAL:$1|გვერდის, რომელსაც|გვერდების, რომელთაც}} კასკადური დაცვა აქვს ჩართული.
+თქვენ შეგიძლიათ ამ გვერდის დაცვის დონე შეცვალოთ, თუმცა ეს კასკადურ დაცვაზე გავლენას არ იქონიებს.',
 'protect-default'             => '(სტანდარტული)',
 'protect-fallback'            => 'საჭიროა "$1"-ის უფლება',
 'protect-level-autoconfirmed' => 'არარეგისტრირებული მომხმარებლების დაბლოკვა',
@@ -1374,7 +1371,7 @@
 'badipaddress'             => 'არასწორი IP მისამართი',
 'blockipsuccesssub'        => 'ბლოკირება შესრულებულია',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|$1]] ბლოკირებულ იქნა.<br />
-იხილეთ [[Special:Ipblocklist|ბლოკირებული IP მისამართების სია]].',
+იხილეთ [[Special:IPBlockList|ბლოკირებული IP მისამართების სია]].',
 'ipb-edit-dropdown'        => 'დაბლოკვის მიზეზების რედაქტირება',
 'ipb-unblock-addr'         => 'ბლოკის მოხსნა $1',
 'ipb-unblock'              => 'მომხმარებლის სახელზე ან IP მისამართზე ბლოკის მოხსნა',
@@ -1400,7 +1397,7 @@
 'autoblocker'              => 'თქვენ ავტომატურად ბლოკირებული ხართ, ვინაიდან თქვენი IP მისამართი ახლახან იქნა გამოყენებული "[[User:$1|$1]]"–ის მიერ. $1-ის ბლოკირების მიზეზი: "\'\'\'$2\'\'\'"',
 'blocklogpage'             => 'დაბლოკილთა აღრიცხვა',
 'blocklogentry'            => '"[[$1]]" ბლოკირების ვადის გასვლის თარიღი $2 $3.',
-'blocklogtext'             => 'ეს არის მომხმარებლების დაბლოკვის და განბლოკვის ჟურნალი. ავტომატურად დაბლოკილი IP მისამართები არაა ჩამოთვლილი. იხილეთ [[Special:Ipblocklist|IP ბლოკირების სია]] მიმდინარე დაბლოკვებისთვის.',
+'blocklogtext'             => 'ეს არის მომხმარებლების დაბლოკვის და განბლოკვის ჟურნალი. ავტომატურად დაბლოკილი IP მისამართები არაა ჩამოთვლილი. იხილეთ [[Special:IPBlockList|IP ბლოკირების სია]] მიმდინარე დაბლოკვებისთვის.',
 'unblocklogentry'          => 'ბლოკი მოხსნილია $1',
 'block-log-flags-anononly' => 'მხოლოდ ანონიმური მომხმარებლები',
 'block-log-flags-nocreate' => 'ანგარიშის შექმნა გამორთულია',
@@ -1432,13 +1429,18 @@
 გაითვალისწინეთ, რომ გვერდი არ გადავა, თუ ახალი სათაურით სტატია უკვე არსებობს, გარდა იმ შემთხვევისა, თუ ის ცარიელია ან გადამისამართებაა და არ აქვს გვერდის რედაქტირების ისტორია. ეს ნიშნავს, რომ თქვენ შეგიძლიათ დაუბრუნოთ ძველი სახელი გვერდს, თუ შეცდომა დაუშვით, მაგრამ არ შეგიძლიათ ზემოთ გადააწეროთ არსებულ გვერდს.
 
 <b>გაფრთხილებთ!</b> ამ მოქმედებამ შეიძლება მნიშვნელოვანი და მოულოდნელი ცვლილება გამოიწვის პოპულარულ გვერდზე; სანამ გააგრძელებდეთ, გთხოვთ დარწმუნდეთ, რომ თქვენ გესმით თქვენი ქმედების შედეგები.',
+'movepagetalktext'        => "დაკავშირებული განხილვის გვერდი ავტომატურად გადავა მასთან ერთად, '''გარდა იმ შემთხვევისა, თუ''':
+*განხილვის გვერდი ახალი სათაურით და გარკვეული შინაარსით უკვე არსებობს, ან
+*თქვენ მოხსნით ნიშნულს ქვევით დაფაზე.
+
+ამ შემთხვევებში, თქვენ თავად მოგიწევთ ამ გვერდის გადატანა, სურვილისამებრ.",
 'movearticle'             => 'გვერდის გადატანა',
-'movenologin'             => 'რეგისტრაცია ვერ გაიარა',
 'movenotallowed'          => 'თქვენ არ გაქვთ {{SITENAME}}-ში გვერდების გადატანის უფლება.',
 'newtitle'                => 'ახალი სათაური',
 'move-watch'              => 'ამ გვერდის კონტროლი',
 'movepagebtn'             => 'გვერდის გადატანა',
 'pagemovedsub'            => 'გადატანა შესრულებულია',
+'movepage-moved'          => '<big>\'\'\'"$1" გადატანილ იქნა "$2"-ზე\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'ამ დასახელების გვერდი უკვე არსებობს, ან თქვენს მიერ მითითებული დასახელება არასწორია. თუ შეიძლება, მიუთითეთ სხვა სახელი.',
 'talkexists'              => "'''თვით გვერდი წარმატებით გადავიდა, ხოლო განხილვის გვერდი ვერ გადავიდა, ვინაიდან ის უკვე არსებობს ახალი სათაურით. გთხოვთ მანუალურად განაცალკევოთ ისინი.'''",
 'movedto'                 => 'გადატანილია',
@@ -1451,7 +1453,7 @@
 'delete_and_move'         => 'წაშლა და გადატანა',
 'delete_and_move_text'    => '==საჭიროა წაშლა==
 
-სტატია დასახელებით "[[$1]]" უკვე არსებობს. გსურთ მისი წაშლა გადატანისთვის ადგილის დასათმობად?',
+სტატია დასახელებით "[[:$1]]" უკვე არსებობს. გსურთ მისი წაშლა გადატანისთვის ადგილის დასათმობად?',
 'delete_and_move_confirm' => 'დიახ, წაშალეთ ეს გვერდი',
 'delete_and_move_reason'  => 'წაშლილია გადატანისთვის ადგილის დასათმობად',
 'selfmove'                => 'წყარო და დანიშნულების სათაურები მსგავსია; შეუძლებელია გვერდის საკუთარ თავზე გადატანა.',
@@ -1612,7 +1614,7 @@
 'show-big-image'       => 'სრული გარჩევადობა',
 'show-big-image-thumb' => '<small>ზომა წინასწარი გადახედვისას: $1 × $2 პიქსელი</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'ახალი სურათები',
 'imagelisttext'         => "ქვემოთ მოცემულია '''$1''' ფაილის სია დახარისხებული მომხმარებლის $2 მიერ.",
 'showhidebots'          => '(რობოტების $1)',
@@ -1749,7 +1751,7 @@
 
 # External editor support
 'edit-externally'      => 'ამ ფაილის რედაქტირებისას გამოიყენეთ გარე პროგრამა',
-'edit-externally-help' => 'დაწვრილებითი ინფორმაციისთვის იხილეთ [http://meta.wikimedia.org/wiki/Help:External_editors ჩადგმის ინსტრუქციები].',
+'edit-externally-help' => 'დაწვრილებითი ინფორმაციისთვის იხილეთ [http://www.mediawiki.org/wiki/Manual:External_editors ჩადგმის ინსტრუქციები].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ყველა',
@@ -1811,7 +1813,7 @@
 'recreate'            => 'აღადგინე',
 
 # HTML dump
-'redirectingto' => 'გადამისამართდება [[$1]]-ზე...',
+'redirectingto' => 'გადამისამართდება [[:$1]]-ზე...',
 
 # action=purge
 'confirm_purge'        => 'გსურთ ამ გვერდის ქეშის წაშლა?
@@ -1879,7 +1881,7 @@
 'version-software-product' => 'პროდუქტი',
 'version-software-version' => 'ვერსია',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'ფაილი:',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesNso.php
===================================================================
--- languages/messages/MessagesNso.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNso.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author Mohau
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -377,10 +375,6 @@
 'blockedoriginalsource'  => "Mothopo wa '''$1''' oa botšhwa tlase:",
 'whitelistedittitle'     => 'O swanela ke go tsena go fetola',
 'whitelistedittext'      => 'O swanela ke go $1 go fetola matlakala.',
-'whitelistreadtitle'     => 'O swanela ke go tsena bo bala',
-'whitelistreadtext'      => 'O swanela ke go  [[Special:Userlogin|tsena]] go bala matlakala.',
-'whitelistacctitle'      => 'Ga wa dumelwa go tlhola tšhupaleloko',
-'whitelistacctext'       => 'Go dumelwa go tlhola tšhupaleloko go {{SITENAME}} o swanela ke go  [[Special:Userlogin|tsena]]  gape obe le ditshwanelo tša maleba.',
 'confirmedittitle'       => 'E-mail e swanetše ke go tiišetšwa pele ge o ka fetola',
 'confirmedittext'        => 'E-mail e swanetše ke go tiišetšwa pele ge o ka fetola matlakala. Ka kgopelo, tiišetša e-mail atrese ya gago go [[Special:Preferences|dikgatlhego tša mošomiši]].',
 'nosuchsectiontitle'     => 'Gago sekgao seo',
@@ -417,7 +411,7 @@
 'template-protected'     => '(e lotilwe)',
 'template-semiprotected' => '(lota-ka-seripa)',
 'nocreatetext'           => '{{SITENAME}} e nale dithibelo tše itšego go tlholeng ga matlakala a maphsa.
-O ka boela morago wa felola matlakala a lego gona, goba o [[Special:Userlogin|tsene]].',
+O ka boela morago wa felola matlakala a lego gona, goba o [[Special:UserLogin|tsene]].',
 'nocreate-loggedin'      => 'Ga ona tumello ya go tlhola matlakala a mampsha go {{SITENAME}}.',
 'permissionserrors'      => 'Phošo ya ditumello',
 'permissionserrorstext'  => 'Gawa dumelwa go pheta seo,ka {{PLURAL:$1|lebaka|mabaka}} a latelago:',
@@ -565,7 +559,7 @@
 'license-nopreview'  => '(Ponopele ga e gona)',
 'upload_source_file' => '(faele go khomphuthara ya gago)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'faele',
 'imagelist'      => 'Lenano la difaele',
 'imagelist_date' => 'Letšatšikgwedi',
@@ -684,7 +678,7 @@
 'all-logs-page'        => "Di-''log'' kamoka",
 'log-search-submit'    => 'Sepela',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Matlakala ka moka',
 'alphaindexline' => '$1 goya go $2',
 'nextpage'       => 'Letlakala lago latela ($1)',
@@ -697,7 +691,7 @@
 # Special:Categories
 'categories' => 'Dihlopha',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Botšha',
 
 # E-mail user
@@ -719,7 +713,7 @@
 'watchlistfor'         => "(ya '''$1''')",
 'addedwatch'           => 'Loketšwe go lenano la ditlhapetšo',
 'addedwatchtext'       => "Letlakala \"[[:\$1]]\" le tsene go [[Special:Watchlist|watchlist]] ya gago.
-Go tloga bjale, diphetogo letlakaleng le, le letlakaleng la dipoledišano la gona, di tla bontšhwa ka mongalo wa '''bold''' gare ga [[Special:Recentchanges|list of recent changes]] gore go be bonolo gore oa bone.
+Go tloga bjale, diphetogo letlakaleng le, le letlakaleng la dipoledišano la gona, di tla bontšhwa ka mongalo wa '''bold''' gare ga [[Special:RecentChanges|list of recent changes]] gore go be bonolo gore oa bone.
 
 Ga eba o nyaka go hloša letlaka le go lenano la ditlhapetšo tša gago, šomiša \"Tloša tlhapetšo\" go sidebar.",
 'removedwatch'         => 'Tlošitšwe go lenano la ditlhapetšo',
@@ -980,7 +974,7 @@
 'show-big-image'       => "''resolution'' ya gofella",
 'show-big-image-thumb' => '<small>Bogolo ba pono: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => "''Gallery'' ya difaele tše mpsha",
 'ilsubmit'  => 'Fetleka',
 'bydate'    => 'ka letšatšikgwedi',
@@ -1018,7 +1012,7 @@
 
 # External editor support
 'edit-externally'      => 'Fetola faele ye o šumiša thulusi ya ka ntle',
-'edit-externally-help' => 'Lebelela [http://meta.wikimedia.org/wiki/Help:External_editors Taelo ya go thoma] go humana sedi.',
+'edit-externally-help' => 'Lebelela [http://www.mediawiki.org/wiki/Manual:External_editors Taelo ya go thoma] go humana sedi.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ka moka',
Index: languages/messages/MessagesCo.php
===================================================================
--- languages/messages/MessagesCo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
- * @author SPQRobin
  */
 
 $messages = array(
@@ -267,7 +265,7 @@
 
 'upload-file-error' => 'Errore internu',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'schedariu',
 'imagelist_date' => 'Data',
 'imagelist_name' => 'Nome',
@@ -304,7 +302,7 @@
 'speciallogtitlelabel' => 'Titulu:',
 'all-logs-page'        => "Tutte l'azzioni",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tutte e pagine',
 'alphaindexline'    => 'da $1 à $2',
 'allpagesfrom'      => 'Mustrà e pagine à parte da:',
@@ -320,7 +318,7 @@
 # Special:Categories
 'categories' => 'Categurie',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Mustrà',
 
 # E-mail user
@@ -444,7 +442,7 @@
 # Media information
 'show-big-image' => 'Imagine in alta resoluzione',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 boti)',
 'noimages'     => 'Nulla da vede.',
 'ilsubmit'     => 'Ricerca',
@@ -495,7 +493,7 @@
 # Special:Version
 'version' => 'Versione', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Schedariu:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesSr_el.php
===================================================================
--- languages/messages/MessagesSr_el.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSr_el.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
- * @author לערי ריינהארט
  * @author Red Baron
- * @author Jon Harald Søby
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -458,7 +456,7 @@
 'nosuchspecialpage' => 'Nema takve posebne stranice',
 'nospecialpagetext' => "<big>'''Tražili ste nepostojeću posebnu stranicu.'''</big>
 
-Spisak svih posebnih stranica se može naći na [[Special:Specialpages|{{int:specialpages}}]].",
+Spisak svih posebnih stranica se može naći na [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Greška',
@@ -636,10 +634,6 @@
 'blockededitsource'         => "Tekst '''vaših izmena''' za '''$1''' je prikazan ispod:",
 'whitelistedittitle'        => 'Obavezno je prijavljivanje za uređivanje',
 'whitelistedittext'         => 'Morate da se [[{{ns:special}}:Userlogin|prijavite]] da biste menjali članke.',
-'whitelistreadtitle'        => 'Obavezno je prijavljivanje za čitanje',
-'whitelistreadtext'         => 'Morate da se [[Special:Userlogin|prijavite]] da biste čitali članke.',
-'whitelistacctitle'         => 'Nije vam dozvoljeno da napravite nalog',
-'whitelistacctext'          => 'Da bi vam bilo dozvoljeno da pravite naloge na ovom vikiju morate da se [[Special:Userlogin|prijavite]] i imate odgovarajuća ovlašćenja.',
 'confirmedittitle'          => 'Potrebna je potvrda adrese e-pošte za uređivanje',
 'confirmedittext'           => 'Morate potvrditi vašu adresu e-pošte pre uređivanja strana.
 Molimo postavite i potvrdite adresu vaše e-pošte preko vaših [[Special:Preferences|korisničkih podešavanja]].',
@@ -656,7 +650,7 @@
 'anontalkpagetext'          => "----''Ovo je stranica za razgovor za anonimnog korisnika koji još nije napravio nalog ili ga ne koristi.
 Zbog toga moramo da koristimo brojčanu IP adresu kako bismo identifikovali njega ili nju.
 Takvu adresu može deliti više korisnika.
-Ako ste anonimni korisnik i mislite da su vam upućene nebitne primedbe, molimo vas da [[Special:Userlogin|napravite nalog ili se prijavite]] da biste izbegli buduću zabunu sa ostalim anonimnim korisnicima.''",
+Ako ste anonimni korisnik i mislite da su vam upućene nebitne primedbe, molimo vas da [[Special:UserLogin|napravite nalog ili se prijavite]] da biste izbegli buduću zabunu sa ostalim anonimnim korisnicima.''",
 'noarticletext'             => 'Trenutno nema teksta na ovoj stranici. Možete [[Special:Search/{{PAGENAME}}|pretražiti ovaj naziv]] u ostalim stranicama ili [{{fullurl:{{FULLPAGENAME}}|action=edit}} urediti ovu stranicu].',
 'clearyourcache'            => "'''Zapamtite:''' Nakon snimanja, možda morate očistiti keš vašeg brauzera da biste videli promene. '''Mozilla / Firefox / Safari:''' držite ''Shift'' dok klikćete ''Reload'' ili pritisnite  ''Shift+Ctrl+R'' (''Cmd-Shift-R'' na ''Apple Mac'' mašini); '''IE:''' držite ''Ctrl'' dok klikćete ''Refresh'' ili pritisnite ''Ctrl-F5''; '''Konqueror:''': samo kliknite ''Reload'' dugme ili pritisnite ''F5''; korisnici '''Opera''' brauzera možda moraju da u potpunosti očiste svoj keš preko ''Tools→Preferences''.",
 'usercssjsyoucanpreview'    => "<strong>Savet:</strong> Korisitite 'Prikaži pretpregled' dugme da testirate svoj novi CSS/JS pre snimanja.",
@@ -708,7 +702,7 @@
 'edittools'                 => '<!-- Tekst odavde će biti pokazan ispod formulara za uređivanje i slanje slika. -->',
 'nocreatetitle'             => 'Pravljenje stranice ograničeno',
 'nocreatetext'              => 'Na ovom sajtu je ograničeno pravljenje novih stranica.
-Možete se vratiti i urediti već postojeću stranu ili [[Special:Userlogin|se prijaviti ili napraviti nalog]].',
+Možete se vratiti i urediti već postojeću stranu ili [[Special:UserLogin|se prijaviti ili napraviti nalog]].',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Ne može da se napravi nalog',
@@ -804,7 +798,7 @@
 'preferences'              => 'Podešavanja',
 'mypreferences'            => 'Moja podešavanja',
 'prefsnologin'             => 'Niste prijavljeni',
-'prefsnologintext'         => 'Morate biti [[Special:Userlogin|prijavljeni]] da biste podešavali korisnička podešavanja.',
+'prefsnologintext'         => 'Morate biti [[Special:UserLogin|prijavljeni]] da biste podešavali korisnička podešavanja.',
 'prefsreset'               => 'Vraćena su uskladištena podešavanja.',
 'qbsettings'               => 'Brza paleta',
 'qbsettings-none'          => 'Nikakva',
@@ -919,11 +913,11 @@
 'reupload'                    => 'Ponovo pošalji',
 'reuploaddesc'                => 'Vrati se na upitnik za slanje.',
 'uploadnologin'               => 'Niste prijavljeni',
-'uploadnologintext'           => 'Morate biti [[Special:Userlogin|prijavljeni]] da biste slali fajlove.',
+'uploadnologintext'           => 'Morate biti [[Special:UserLogin|prijavljeni]] da biste slali fajlove.',
 'upload_directory_read_only'  => 'Na direktorijum za slanje ($1) server ne može da piše.',
 'uploaderror'                 => 'Greška pri slanju',
 'uploadtext'                  => "Koristite donji obrazac da pošaljete fajlove.
-Za gledanje ili pretraživanje već poslatih slika, idite na [[Special:Imagelist|spisak poslatih fajlova]].
+Za gledanje ili pretraživanje već poslatih slika, idite na [[Special:ImageList|spisak poslatih fajlova]].
 Slanja i brisanja se beleže u [[Special:Log/upload|istoriji slanja]]
 
 Da biste ubacili sliku na stranu, koristite vezu u obliku
@@ -982,7 +976,7 @@
 'upload_source_url'  => ' (validan, javno dostupan URL)',
 'upload_source_file' => ' (fajl na vašem računaru)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Traži ime slike:',
 'imgfile'               => 'fajl',
 'imagelist'             => 'Spisak slika',
@@ -1100,7 +1094,7 @@
 Možete suziti pregled odabirom tipa istorije, korisničkog imena ili tražene stranice.',
 'logempty'             => 'Protokol je prazan.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Sve stranice',
 'alphaindexline'    => '$1 u $2',
 'nextpage'          => 'Sledeća stranica ($1)',
@@ -1118,12 +1112,12 @@
 'categories'         => 'Kategorije stranica',
 'categoriespagetext' => 'Sledeće kategorije već postoje na vikiju',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom' => 'Prikaži korisnike počevši od:',
 
 # E-mail user
 'mailnologin'     => 'Nema adrese za slanje',
-'mailnologintext' => 'Morate biti [[Special:Userlogin|prijavljeni]] i imati ispravnu adresu e-pošte u vašim [[Special:Preferences|podešavanjima]]
+'mailnologintext' => 'Morate biti [[Special:UserLogin|prijavljeni]] i imati ispravnu adresu e-pošte u vašim [[Special:Preferences|podešavanjima]]
 da biste slali e-poštu drugim korisnicima.',
 'emailuser'       => 'Pošalji e-poštu ovom korisniku',
 'emailpage'       => 'Pošalji e-pismo korisniku',
@@ -1153,7 +1147,7 @@
 'nowatchlist'          => 'Nemate ništa na svom spisku nadgledanja.',
 'watchlistanontext'    => 'Molimo $1 da biste gledali ili menjali stavke na vašem spisku nadgledanja.',
 'watchnologin'         => 'Niste prijavljeni',
-'watchnologintext'     => 'Morate biti [[Special:Userlogin|prijavljeni]] da biste menjali spisak nadgledanja.',
+'watchnologintext'     => 'Morate biti [[Special:UserLogin|prijavljeni]] da biste menjali spisak nadgledanja.',
 'addedwatch'           => 'Dodato spisku nadgledanja',
 'addedwatchtext'       => "Stranica \"[[:\$1]]\" je dodata vašem [[{{ns:special}}:Watchlist|spisku nadgledanja]] .
 Buduće promene na ovoj stranici i njoj pridruženoj stranici za razgovor biće navedene ovde, i stranica će biti '''podebljana''' u [[{{ns:special}}:Recentchanges|spisku skorašnjih izmena]] da bi se lakše uočila.
@@ -1415,9 +1409,6 @@
 
 U tim slučajevima, moraćete ručno da premestite ili spojite stranicu ukoliko to želite.",
 'movearticle'             => 'Premesti stranicu',
-'movenologin'             => 'Niste prijavljeni',
-'movenologintext'         => 'Morate biti registrovani korisnik i [[Special:Userlogin|prijavljeni]]
-da biste premestili stranicu.',
 'newtitle'                => 'Novi naslov',
 'movepagebtn'             => 'premesti stranicu',
 'pagemovedsub'            => 'Premeštanje uspelo',
@@ -1437,7 +1428,7 @@
 'delete_and_move'         => 'Obriši i premesti',
 'delete_and_move_text'    => '==Potrebno brisanje==
 
-Ciljani članak "[[$1]]" već postoji. Da li želite da ga obrišete da biste napravili mesto za premeštanje?',
+Ciljani članak "[[:$1]]" već postoji. Da li želite da ga obrišete da biste napravili mesto za premeštanje?',
 'delete_and_move_confirm' => 'Da, obriši stranicu',
 'delete_and_move_reason'  => 'Obrisano kako bi se napravilo mesto za premeštanje',
 'selfmove'                => 'Izvorni i ciljani naziv su isti; strana ne može da se premesti preko same sebe.',
@@ -1623,7 +1614,7 @@
 'imagemaxsize' => 'Ograniči slike na stranama za razgovor o slikama na:',
 'thumbsize'    => 'Veličina umanjenog prikaza :',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerija novih slika',
 'imagelisttext'         => "Ispod je spisak od '''$1''' {{PLURAL:$1|fajla|fajla|fajlova}} poređanih $2.",
 'showhidebots'          => '($1 botove)',
@@ -1903,7 +1894,7 @@
 
 # External editor support
 'edit-externally'      => 'Izmenite ovaj fajl koristeći spoljašnju aplikaciju',
-'edit-externally-help' => 'Pogledajte [http://meta.wikimedia.org/wiki/Help:External_editors uputstvo za podešavanje] za više informacija.',
+'edit-externally-help' => 'Pogledajte [http://www.mediawiki.org/wiki/Manual:External_editors uputstvo za podešavanje] za više informacija.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'sve',
@@ -1954,7 +1945,7 @@
 'recreate'            => 'Ponovo napravi',
 
 # HTML dump
-'redirectingto' => 'Preusmeravam na [[$1]]...',
+'redirectingto' => 'Preusmeravam na [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Da li želite očistiti keš ove stranice?
@@ -1990,7 +1981,7 @@
 # Special:Version
 'version' => 'Verzija', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Putanja fajla',
 'filepath-page'   => 'Fajl:',
 'filepath-submit' => 'Putanja',
Index: languages/messages/MessagesKu_arab.php
===================================================================
--- languages/messages/MessagesKu_arab.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKu_arab.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author Aras Noori
  */
 
@@ -258,7 +257,7 @@
 'nosuchspecialpage' => 'په‌ڕه‌ی تایبه‌تی له‌و شێوه‌یه‌ نییه‌',
 'nospecialpagetext' => "<big>''په‌ڕه‌یكی تایبه‌ت ده‌خوازیت كه‌ بوونی نییه‌'''</big>
 
-لیستی په‌ڕه‌ تایبه‌تییه‌كان له‌ [[Special:Specialpages|لیسته‌ی په‌ڕه‌ تایبه‌ته‌كان]] ده‌توانرێت ببینرێت.",
+لیستی په‌ڕه‌ تایبه‌تییه‌كان له‌ [[Special:SpecialPages|لیسته‌ی په‌ڕه‌ تایبه‌ته‌كان]] ده‌توانرێت ببینرێت.",
 
 # General errors
 'error'              => 'هه‌ڵه‌',
@@ -341,7 +340,7 @@
 
 # Separators for various lists, etc.
 'semicolon-separator' => '؛',
-'comma-separator'     => '،',
+'comma-separator'     => '،&#32;',
 
 # Live preview
 'livepreview-loading' => 'له‌باركردنایه‌ ...',
Index: languages/messages/MessagesGn.php
===================================================================
--- languages/messages/MessagesGn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author Hugo.arg
  */
 
@@ -261,7 +260,7 @@
 '''<nowiki>[[</nowiki>Media<nowiki>:Archivo.ogg]]</nowiki>''' ojoaju hag̃ua hekopete pe jehai'atýre.",
 'filename'   => "Téra jehai'aty",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => "Ta'ãnga rysýi",
 'imagelist_user' => 'Puruhára',
 
@@ -347,7 +346,7 @@
 # Special:Log
 'log' => 'Ñemboguapypyre',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Opaite kuatiarogue',
 'allnotinnamespace' => 'Opaite kuatiarogue (fuera del espacio $1)',
 'allpagesnext'      => 'Upeigua',
@@ -356,7 +355,7 @@
 # Special:Categories
 'categories' => 'Ñemohendakuéra',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Hechauka',
 
 # E-mail user
@@ -410,7 +409,7 @@
 'ipblocklist-submit' => 'Heka',
 'blocklink'          => 'ejoko',
 'contribslink'       => "mba'emoĩmbyre",
-'blocklogtext'       => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:Ipblocklist|IP mbohape rysýi imbotypyréva]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
+'blocklogtext'       => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:IPBlockList|IP mbohape rysýi imbotypyréva]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
 
 # Move page
 'movearticle'     => 'Guerova kuatiarogue',
@@ -450,7 +449,7 @@
 # Media information
 'file-info' => "(tamaño de jehai'aty: $1; tipo MIME: $2)",
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => "Ta'ãnga pyahu renda",
 'ilsubmit'  => 'Jeheka',
 
@@ -472,7 +471,7 @@
 # Special:Version
 'version' => "Mba'ereko", # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Ruta de archivo',
 'filepath-page'   => 'Archivo:',
 'filepath-submit' => 'Ruta',
Index: languages/messages/MessagesSc.php
===================================================================
--- languages/messages/MessagesSc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -268,7 +267,7 @@
 # Preferences page
 'preferences'              => 'Preferenze',
 'prefsnologin'             => 'Non hai eseguito il login',
-'prefsnologintext'         => 'Devi avere eseguito il [[Special:Userlogin|login]]
+'prefsnologintext'         => 'Devi avere eseguito il [[Special:UserLogin|login]]
 per poter personalizzare le tue preferenze.',
 'prefsreset'               => 'Le tue Preferenze sono state ripescate dalla memoria di sistema del potente server di {{SITENAME}}.',
 'qbsettings'               => 'Settaggio della barra menu',
@@ -318,13 +317,13 @@
 'reupload'          => 'Ri-upload',
 'reuploaddesc'      => 'Torna al modulo per lo upload.',
 'uploadnologin'     => 'Devi fare il login per eseguire questa operazione.',
-'uploadnologintext' => 'Devi eseguire [[Special:Userlogin|il login]]
+'uploadnologintext' => 'Devi eseguire [[Special:UserLogin|il login]]
 per fare lo upload di files.',
 'uploaderror'       => 'Errore di Upload',
 'uploadtext'        => "'''FERMA!''' Prima di effettuare un upload su {{SITENAME}}, accertati di avere ben letto e soprattutto compreso
 le regole di {{SITENAME}} sull'uso delle immagini.
 
-Per visualizzare o cercare immagini precedentemente caricate su {{SITENAME}}, vai alla [[Special:Imagelist|lista delle immagini già caricate]].
+Per visualizzare o cercare immagini precedentemente caricate su {{SITENAME}}, vai alla [[Special:ImageList|lista delle immagini già caricate]].
 Uploads e cancellazioni delle immagini sono registrati nello
 upload log.
 
@@ -356,7 +355,7 @@
 'savefile'          => 'Salva file',
 'uploadedimage'     => 'caricato "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Lista delle immagini',
 
 # Image description page
@@ -405,11 +404,11 @@
 'notargettitle'    => 'Dati mancanti',
 'notargettext'     => "Non hai specificato una pagina o un Utente in relazione al quale eseguire l'operazione richiesta.",
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Tutte le pagine',
 
 # E-mail user
-'mailnologintext' => 'Devi fare il [[Special:Userlogin|login]]
+'mailnologintext' => 'Devi fare il [[Special:UserLogin|login]]
 ed aver registrato una valida casella e-mail nelle tue [[Special:Preferences|preferenze]] per mandare posta elettronica ad altri Utenti.',
 'emailuser'       => 'Manda una E-mail a questo Utente',
 'emailpagetext'   => 'Se questo Utente ha registrato una valida casella e-mail, il modulo qui sotto ti consentirà di scrivergli un solo messaggio.
@@ -425,11 +424,11 @@
 'mywatchlist'      => 'Osservati Speciali',
 'nowatchlist'      => "Non hai indicato articoli da tenere d'occhio.",
 'watchnologin'     => 'Manca il login',
-'watchnologintext' => 'Devi prima fare il [[Special:Userlogin|login]]
+'watchnologintext' => 'Devi prima fare il [[Special:UserLogin|login]]
 per modificare la tua lista di osservati speciali.',
 'addedwatch'       => 'Aggiunto agli Osservati Speciali',
 'addedwatchtext'   => ' La pagina  "<nowiki>$1</nowiki>" è stata aggiunta alla tua [[Special:Watchlist|lista di osservati speciali]].
-Le future modifiche a questa pagina ed alla relativa pagina di discussione saranno elencate qui, e la pagina apparirà in <b>grassetto</b> nella pagina delle [[Special:Recentchanges|modifiche recenti]] per essere più facile da tener d\'occhio.
+Le future modifiche a questa pagina ed alla relativa pagina di discussione saranno elencate qui, e la pagina apparirà in <b>grassetto</b> nella pagina delle [[Special:RecentChanges|modifiche recenti]] per essere più facile da tener d\'occhio.
 
 Se in seguito vorrai togliere questo articolo dalla tua lista di osservati speciali, clicca " Smetti di seguire " nella barra dei menu.',
 'removedwatch'     => 'Rimosso dalla lista degli Osservati Speciali',
@@ -490,7 +489,7 @@
 'badipaddress'       => "L'indirizzo IP indicato non è corretto.",
 'blockipsuccesssub'  => 'Blocco eseguito',
 'blockipsuccesstext' => ' L\'indirizzo IP "$1" è stato bloccato.
-<br />Vedi [[Special:Ipblocklist|lista IP bloccati]].',
+<br />Vedi [[Special:IPBlockList|lista IP bloccati]].',
 'unblockip'          => ' Sblocca indirizzo IP',
 'unblockiptext'      => 'Usa il modulo sottostante per restituire il diritto di scrittura ad un indirizzo IP precedentemente bloccato.',
 'ipusubmit'          => 'Sblocca questo indirizzo IP',
@@ -538,9 +537,6 @@
 
 In questi casi, se lo ritieni opportuno, dovrai spostare o aggiungere manualmente la pagina di discussione.",
 'movearticle'      => 'Rinomina articolo',
-'movenologin'      => 'Non hai effettuato il login',
-'movenologintext'  => 'Devi essere un Utente registrato ed aver effettuato il [[Special:Userlogin|login]]
-per poter spostare una pagina.',
 'newtitle'         => 'Al nuovo titolo di',
 'movepagebtn'      => 'Sposta questa pagina',
 'pagemovedsub'     => 'Spostamento effettuato con successo',
@@ -550,7 +546,7 @@
 'movedto'          => 'spostata a',
 'movetalk'         => 'Sposta anche la corrispondente pagina "discussione", se possibile.',
 
-# Special:Newimages
+# Special:NewImages
 'imagelisttext' => 'Qui di seguito una lista di $1 immagini, ordinate per $2.',
 'ilsubmit'      => 'Cerca',
 'bydate'        => 'data',
Index: languages/messages/MessagesCs.php
===================================================================
--- languages/messages/MessagesCs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,16 +4,15 @@
  * @ingroup Language
  * @file
  *
- * @author Li-sung
  * @author Danny B.
+ * @author Helix84
+ * @author Li-sung
+ * @author Martin Kozák
  * @author Matěj Grabovský
- * @author לערי ריינהארט
- * @author Siebrand
+ * @author Michawiki
  * @author Mormegil
  * @author Reaperman
- * @author Helix84
- * @author Michawiki
- * @author Martin Kozák
+ * @author לערי ריינהארט
  */
 
 $fallback8bitEncoding = 'cp1250';
@@ -594,7 +593,7 @@
 'nosuchspecialpage' => 'Neexistující speciální stránka',
 'nospecialpagetext' => "<big>'''Zadali jste neplatnou speciální stránku.'''</big>
 
-Zkuste se podívat na [[Special:Specialpages|seznam všech existujících speciálních stránek]].",
+Zkuste se podívat na [[Special:SpecialPages|seznam všech existujících speciálních stránek]].",
 
 # General errors
 'error'                => 'Chyba',
@@ -620,12 +619,11 @@
 'readonlytext'         => 'Databáze je nyní uzamčena, takže nelze ukládat nové doplňky a změny. Důvodem je pravděpodobně pravidelná údržba, po které se vše vrátí do normálního stavu.
 
 Správce, který databázi zamkl, zanechal následující zprávu: $1',
-'missing-article'      => 'V databázi nebyl nalezen text stránky „$1“ $2.
+'missing-article'      => 'V databázi nebyl nalezen požadovaný text stránky „$1“ $2.
 
-Toto je obvykle způsobeno tím, že jste následovali zastaralý odkaz na rozdíl verzí nebo historii stránky, jež byla smazána.
+Toto je obvykle způsobeno tím, že jste následovali zastaralý odkaz na rozdíl verzí nebo historickou verzi stránky, jež byla smazána.
 
-Pokud toto není váš případ, možná jste nalezli chybu v software.
-Prosíme, ohlaste to správcům spolu s URL této stránky.',
+Pokud toto není váš případ, možná jste nalezli chybu v software. Prosíme, ohlaste to [[Special:ListUsers/sysop|správcům]] spolu s URL této stránky.',
 'missingarticle-rev'   => '(číslo revize: $1)',
 'missingarticle-diff'  => '(Rozdíl: $1, $2)',
 'readonly_lag'         => 'Databáze byla automaticky dočasně uzamčena kvůli zpoždění ostatních databázových servery proti hlavnímu',
@@ -677,7 +675,7 @@
 Tento počítač může být používán k prohlížení a editaci {{grammar:2sg|{{SITENAME}}}} bez uživatelského jména, nebo pro přihlášení jiného uživatele. Upozorňujeme, že některé stránky se mohou i nadále zobrazovat, jako byste byli dosud přihlášeni. Tento jev potrvá do smazání cache vašeho prohlížeče.',
 'welcomecreation'            => '== Vítejte, $1! ==
 Váš účet byl vytvořen.
-Nezapomeňte si upravit své nastavení!',
+Nezapomeňte si upravit [[Special:Preferences|nastavení {{grammar:2sg|{{SITENAME}}}}]].',
 'loginpagetitle'             => 'Přihlaste se',
 'yourname'                   => 'Uživatelské jméno:',
 'yourpassword'               => 'Vaše heslo',
@@ -812,44 +810,38 @@
 'summary-preview'                  => 'Náhled shrnutí',
 'subject-preview'                  => 'Náhled předmětu/nadpisu',
 'blockedtitle'                     => 'Uživatel zablokován',
-'blockedtext'                      => "<big> Vaší IP adrese či uživatelskému jménu byla zablokována možnost editace.</big>
+'blockedtext'                      => "<big>'''Vaší IP adrese či uživatelskému jménu byla zablokována možnost editace.'''</big>
 
-Vaše uživatelské jméno nebo IP adresa byly zablokovány správcem s&nbsp;uživatelským jménem „$1“. Jako důvod blokování bylo uvedeno:
+Zablokování provedl $1.
+Udaným důvodem bylo „$2“.
 
-'''$2'''
-
-----
-
-* Začátek zablokování: $8
+* Začátek blokování: $8
 * Zablokování vyprší: $6
-* Určeno k blokování: $7
+* Blokovaný uživatel: $7
 
 Pokud chcete zablokování prodiskutovat, můžete kontaktovat uživatele $1 či jiného [[{{MediaWiki:Grouppage-sysop}}|správce]].
-Uvědomte si, že nemůžete použít nabídku „Poslat e-mail“, jestliže nemáte na {{grammar:6sg|{{SITENAME}}}} účet a&nbsp;ve svém [[Special:Preferences|nastavení]] uvedenu platnou e-mailovou adresu a&nbsp;pokud Vám byla tato možnost zakázána.
-Vaše IP adresa je '''$3''' a&nbsp;identifikační číslo bloku je '''$5'''; tyto údaje budete muset uvést ve všech žádostech o&nbsp;odblokování.",
+Uvědomte si, že nemůžete použít nabídku „Poslat e-mail“, jestliže nemáte na {{grammar:6sg|{{SITENAME}}}} účet a&nbsp;ve svém [[Special:Preferences|nastavení]] uvedenu platnou e-mailovou adresu nebo pokud Vám byla tato možnost zakázána.
+Vaše IP adresa je $3 a&nbsp;identifikační číslo bloku je #$5; tyto údaje uvádějte ve všech dotazech na správce.",
 'autoblockedtext'                  => "Vaše IP adresa byla automaticky zablokována, protože ji používal jiný uživatel, kterého zablokoval $1.
-
 Udaný důvod blokování:
 
 :''$2''
 
 * Začátek blokování: $8
 * Konec blokování: $6
+* Původně blokovaný uživatel: $7
 
 Zablokování můžete prodiskutovat se správcem $1 nebo některým z dalších [[{{MediaWiki:Grouppage-sysop}}|správců]].
 
 Uvědomte si však, že funkci „Poslat e-mail tomuto uživateli“ nemůžete použít, pokud nemáte ve svém [[Special:Preferences|nastavení]] zadaný platný e-mail a nebylo vám zablokováno jeho užívání.
 
-Číslo vašeho zablokování je $5. Prosíme, uveďte ho při komunikaci se správci.",
+Vaše současná IP adresa je $3, číslo vašeho zablokování je #$5.
+Prosíme, uveďte tyto údaje při komunikaci se správci.",
 'blockednoreason'                  => 'důvod nebyl zadán',
 'blockedoriginalsource'            => "Zdrojový text stránky '''$1''' následuje:",
 'blockededitsource'                => "Text '''vašich editací''' stránky '''$1''' následuje:",
 'whitelistedittitle'               => 'Pro editaci je vyžadováno přihlášení',
 'whitelistedittext'                => 'Pro editaci se musíte $1.',
-'whitelistreadtitle'               => 'Vyžadováno přihlášení',
-'whitelistreadtext'                => 'Musíte se [[Special:Userlogin|přihlásit]], abyste mohli číst stránky.',
-'whitelistacctitle'                => 'Není vám dovoleno vytvářet uživatelské účty',
-'whitelistacctext'                 => 'Abyste na {{grammar:6sg|{{SITENAME}}}} mohl(a) vytvářet uživatelské účty, musíte se [[Special:Userlogin|přihlásit]] a mít příslušná oprávnění.',
 'confirmedittitle'                 => 'Vyžadováno e-mailové potvrzení',
 'confirmedittext'                  => 'Pro editaci stránek je vyžadováno potvrzení vaší e-mailové adresy. Na stránce [[Special:Preferences|nastavení]] zadejte a nechte potvrdit svou e-mailovou adresu.',
 'nosuchsectiontitle'               => 'Neexistující sekce',
@@ -863,7 +855,7 @@
 'newarticletext'                   => "Následovali jste odkaz na stránku, která dosud neexistuje.
 Pokud ji chcete vytvořit, napište text do rámečku níže a stiskněte tlačítko ''Uložit změny''. Další rady najdete v [[{{MediaWiki:Helppage}}|nápovědě]].
 Pokud jste zde omylem, stiskněte ve svém prohlížeči tlačítko ''Zpět''.",
-'anontalkpagetext'                 => "---- ''Toto je diskusní stránka anonymního uživatele, který si dosud nevytvořil účet nebo ho nepoužívá. Musíme proto použít číselnou IP adresu k&nbsp;jeho identifikaci. Taková IP adresa může být sdílena několika uživateli. Pokud jste anonymní uživatel a&nbsp;máte za to, že jsou vám adresovány irelevantní komentáře, prosíme, [[Special:Userlogin|vytvořte si účet nebo se přihlaste]], abyste se tím vyhnul(a) budoucí záměně s&nbsp;jinými anonymními uživateli.''",
+'anontalkpagetext'                 => "----''Toto je diskusní stránka anonymního uživatele, který si dosud nevytvořil účet nebo ho nepoužívá. K&nbsp;jeho identifikaci proto musíme používat číselnou IP adresu. Takovou IP adresu může sdílet několik uživatelů. Pokud jste anonymní uživatel a&nbsp;máte za to, že jsou vám adresovány irelevantní komentáře, prosíme, [[Special:UserLogin/signup|vytvořte si účet]] nebo [[Special:UserLogin|se přihlaste]], vyhnete se tím budoucí záměně s&nbsp;jinými anonymními uživateli.''",
 'noarticletext'                    => 'Tato stránka zatím neobsahuje žádný text, můžete [[Special:Search/{{PAGENAME}}|zkusit tento název vyhledat]] na jiných stránkách, nebo [{{fullurl:{{FULLPAGENAME}}|action=edit}} tuto stránku založit].',
 'userpage-userdoesnotexist'        => 'Uživatelský účet „$1“ není zaregistrován. Zkontrolujte zda skutečně chcete vytvořit či editovat tuto stránku.',
 'clearyourcache'                   => "'''Poznámka:''' Po uložení musíte smazat cache vašeho prohlížeče, jinak změny neuvidíte: '''Mozilla / Firefox:''' ''Ctrl-Shift-R'', '''IE:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-Shift-R'', '''Konqueror''': ''F5''.",
@@ -878,9 +870,9 @@
 'session_fail_preview'             => '<strong>Omlouváme se, ale váš požadavek se nepodařilo zpracovat. Zkuste to prosím znovu. Pokud se tento problém bude opakovat, zkuste se odhlásit a znovu přihlásit.</strong>',
 'session_fail_preview_html'        => "<strong>Omlouváme se, ale váš požadavek se nepodařilo zpracovat.</strong>
 
-''Jelikož {{SITENAME}} má povoleno libovolné HTML, není zobrazen náhled jako prevence proti útokům JavaScriptem.''
+''Jelikož má {{SITENAME}} zapnuto používání neomezeného HTML, náhled se kvůli prevenci proti útokům JavaScriptem nezobrazuje.''
 
-<strong>Pokud jde o zamýšlenou editaci, zkuste to prosím znovu. Pokud se tento problém bude opakovat, zkuste se odhlásit a znovu přihlásit.</strong>",
+<strong>Pokud jde o zamýšlenou editaci, zkuste to prosím znovu. Pokud se tento problém bude opakovat, zkuste se [[Special:UserLogout|odhlásit]] a znovu přihlásit.</strong>",
 'token_suffix_mismatch'            => '<strong>Vaše editace byla odmítnuta, protože Váš prohlížeč komolí některé znaky v editovaném textu.
 Editace byla odmítnuta, aby se zabránilo poškození textu stránky.
 Toto se může někdy stát pokud používáte chybující webový anonymizér.</strong>',
@@ -918,7 +910,7 @@
 'edittools'                        => '<!-- Tento text bude zobrazen pod formuláři pro editaci stránek a načítání souborů. -->',
 'nocreatetitle'                    => 'Vytváření nových stránek je omezeno',
 'nocreatetext'                     => 'Na {{grammar:6sg|{{SITENAME}}}} je možnost vytváření nových stránek omezena.
-Můžete se vrátit a editovat již existující stránku, nebo [[Special:Userlogin|se přihlásit či se registrovat]].',
+Můžete se vrátit a editovat již existující stránku, nebo [[Special:UserLogin|se přihlásit či se registrovat]].',
 'nocreate-loggedin'                => 'Nemáte povoleno zakládat nové stránky na {{grammar:6sg|{{SITENAME}}}}.',
 'permissionserrors'                => 'Chyba povolení',
 'permissionserrorstext'            => 'Nemáte povoleno toto provést z {{PLURAL:$1|následujícího důvodu|následujících důvodů|následujících důvodů}}:',
@@ -1036,7 +1028,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Záznam potlačení',
-'suppressionlogtext' => 'Toto je záznam činností dohlížitelů – mazání a blokování zahrnující skrytí obsahu i před správci. Vizte též [[Special:Ipblocklist|seznam všech probíhajících bloků]].',
+'suppressionlogtext' => 'Toto je záznam činností dohlížitelů – mazání a blokování zahrnující skrytí obsahu i před správci. Vizte též [[Special:IPBlockList|seznam všech probíhajících bloků]].',
 
 # History merging
 'mergehistory'                     => 'Slučování historií stránek',
@@ -1119,7 +1111,7 @@
 'mypreferences'            => 'Nastavení',
 'prefs-edits'              => 'Počet editací:',
 'prefsnologin'             => 'Nejste přihlášen(a)!',
-'prefsnologintext'         => 'Pro nastavení se musíte [[Special:Userlogin|přihlásit]].',
+'prefsnologintext'         => 'Pro nastavení se musíte [[Special:UserLogin|přihlásit]].',
 'prefsreset'               => 'Nastavení vráceno.',
 'qbsettings'               => 'Nastavení lišty nástrojů',
 'qbsettings-none'          => 'Žádný',
@@ -1193,7 +1185,7 @@
 'userrights-reason'           => 'Zdůvodnění:',
 'userrights-no-interwiki'     => 'Nemáte povoleno měnit uživatelská práva na jiných wiki.',
 'userrights-nodatabase'       => 'Databáze $1 neexistuje nebo není místní.',
-'userrights-nologin'          => 'Musíte se [[Special:Userlogin|přihlásit]] k účtu správce, abyste mohli měnit uživatelská práva.',
+'userrights-nologin'          => 'Musíte se [[Special:UserLogin|přihlásit]] k účtu správce, abyste mohli měnit uživatelská práva.',
 'userrights-notallowed'       => 'Tento účet nemá povoleno měnit uživatelská práva.',
 'userrights-changeable-col'   => 'Skupiny, které můžete měnit',
 'userrights-unchangeable-col' => 'Skupiny, které nemůžete měnit',
@@ -1323,27 +1315,16 @@
 'reupload'                    => 'Načíst znovu',
 'reuploaddesc'                => 'Vrátit se k načtení.',
 'uploadnologin'               => 'Nejste přihlášen(a)',
-'uploadnologintext'           => 'Pro načtení souboru se musíte [[Special:Userlogin|přihlásit]].',
+'uploadnologintext'           => 'Pro načtení souboru se musíte [[Special:UserLogin|přihlásit]].',
 'upload_directory_missing'    => 'Adresář pro nahrávání souborů ($1) chybí a webový server ho nedokáže vytvořit.',
 'upload_directory_read_only'  => 'Do adresáře pro načítané soubory ($1) nemá webserver právo zápisu.',
 'uploaderror'                 => 'Při načítání došlo k chybě',
-'uploadtext'                  => 'Pro prohlížení a hledání již dříve nahraných souborů se podívejte na [[Special:Imagelist|seznam načtených souborů]].
-Všechna načtení a smazání jsou zaznamenány v [[Special:Log|protokolovacích záznamech]].
+'uploadtext'                  => "Níže uvedený formulář slouží k načtení souborů. Již načtené soubory si můžete prohlížet a hledat pomocí [[Special:ImageList|seznamu načtených souborů]], každé načtení se také zaznamenává do [[Special:Log/upload|knihy načtení]], smazání jsou v [[Special:Log/delete|knize smazaných stránek]].
 
-Pomocí níže uvedeného formuláře můžete na wiki nahrát obrázky a jiné soubory, které poté budete moci použít v článcích.
-Ve většině prohlížečů je zobrazeno tlačítko „Procházet…“, pomocí kterého budete moci vybrat soubor k načtení, jehož jméno se poté objeví v políčku vedle tlačítka.
-Poté stiskněte tlačítko „Načíst soubor“ k dokončení načtení. Buďte trpěliví, nahrávání může chvíli trvat.
-
-Preferované formáty jsou JPEG pro fotografie, PNG pro schémata a OGG pro zvuky. Používejte laskavě smysluplná jména souborů, soubor po načtení nelze přejmenovat.
-
-Pro vložení obrázku do stránky použijte syntaxi
-<code><nowiki>[[</nowiki>{{ns:image}}<nowiki>:soubor.jpg]]</nowiki></code> nebo
-<code><nowiki>[[</nowiki>{{ns:image}}<nowiki>:soubor.png|popisek]]</nowiki></code>, popř.
-<code><nowiki>[[</nowiki>{{ns:media}}<nowiki>:soubor.ogg]]</nowiki></code> pro zvuky.
-
-Uvědomte si laskavě, že stejně jako u ostatních wikistránek mohou ostatní uživatelé vámi nahraný soubor smazat či upravit, pokud to
-uznají za vhodné;
-pokud budete tuto funkci zneužívat, může být váš uživatelský účet zablokován.',
+Pro vložení obrázku do stránky použijte jeden z následujících způsobů zápisu:
+* '''<code><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Soubor.jpg]]</nowiki></code>''' do stránky vloží celý obrázek,
+* '''<code><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Soubor.png|thumb|left|Popisek]]</nowiki></code>''' vloží náhled v rámečku zarovnaném na levý okraj, s popiskem „Popisek“,
+* '''<code><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Soubor.ogg]]</nowiki></code>''' vloží přímý odkaz na soubor, aniž by se zobrazoval ve stránce.",
 'upload-permitted'            => 'Povolené formáty souborů: $1.',
 'upload-preferred'            => 'Upřednostňované formáty souborů: $1.',
 'upload-prohibited'           => 'Zakázané formáty souborů: $1.',
@@ -1423,7 +1404,7 @@
 'upload_source_url'  => ' (platné, veřejně přístupné URL)',
 'upload_source_file' => ' (soubor na vašem počítači)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Tato speciální stránka zobrazuje všechny načtené soubory.
 Ve výchozím stavu je poslední načtený soubor nahoře.
 Kliknutím na hlavičku sloupce můžete změnit řazení.',
@@ -1451,13 +1432,13 @@
 'imagelinks'                     => 'Odkazy k souboru',
 'linkstoimage'                   => 'Na soubor {{plural:$1|odkazuje tato stránka|odkazují tyto stránky}}:',
 'nolinkstoimage'                 => 'Na tento soubor neodkazuje žádná stránka.',
-'morelinkstoimage'               => 'Zobrazit [[Special:Whatlinkshere/$1|další odkazy]] na tento soubor.',
+'morelinkstoimage'               => 'Zobrazit [[Special:WhatLinksHere/$1|další odkazy]] na tento soubor.',
 'redirectstofile'                => '{{plural:$1|Následující soubor přesměrovává|Následující $1 soubory přesměrovávají|Následujících $1 souborů přesměrovává}} na tento soubor:',
 'duplicatesoffile'               => '{{plural:$1|Následující soubor je duplikát|Následující $1 soubory jsou duplikáty|Následujících $1 souborů jsou duplikáty}} tohoto souboru:',
 'sharedupload'                   => 'Tento soubor je sdílený a může být používán ostatními projekty.',
-'shareduploadwiki'               => 'Více informací najdete na $1.',
-'shareduploadwiki-desc'          => 'Níže je zobrazený popis, který obsahuje jeho $1 na sdíleném úložišti.',
-'shareduploadwiki-linktext'      => 'stránce s popisem',
+'shareduploadwiki'               => 'Více informací obsahuje $1.',
+'shareduploadwiki-desc'          => 'Níže je zobrazen popis, který obsahuje jeho $1 na sdíleném úložišti.',
+'shareduploadwiki-linktext'      => 'stránka s popisem souboru',
 'shareduploadduplicate'          => 'Tento soubor je duplikát souboru $1 ze sdíleného úložiště.',
 'shareduploadduplicate-linktext' => 'další soubor',
 'shareduploadconflict'           => 'Tento soubor má stejné jméno jako má $1 ze sdíleného úložiště.',
@@ -1470,18 +1451,18 @@
 # File reversion
 'filerevert'                => 'Vrátit zpět $1',
 'filerevert-legend'         => 'Vrátit zpět soubor',
-'filerevert-intro'          => '<span class="plainlinks">Vracíte zpět \'\'\'[[Media:$1|$1]]\'\'\' na [$4 verzi z $3 $2].</span>',
+'filerevert-intro'          => "Vracíte zpět '''[[Media:$1|$1]]''' na [$4 verzi z $3 $2].",
 'filerevert-comment'        => 'Zdůvodnění:',
 'filerevert-defaultcomment' => 'Navrácena verze nahraná v $2 dne $1.',
 'filerevert-submit'         => 'Vrátit zpět',
-'filerevert-success'        => '<span class="plainlinks">Soubor \'\'\'[[Media:$1|$1]]\'\'\' byl vrácen zpět na [$4 verzi z $3 $2].</span>',
+'filerevert-success'        => "Soubor '''[[Media:$1|$1]]''' byl vrácen zpět na [$4 verzi z $3 $2].",
 'filerevert-badversion'     => 'Není dostupná předchozí verze tohoto souboru s odpovídající časovou značkou.',
 
 # File deletion
 'filedelete'                  => 'Smazání souboru $1',
 'filedelete-legend'           => 'Smazat soubor',
 'filedelete-intro'            => "Chystáte se smazat '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Chystáte se smazat verzi souboru \'\'\'[[Media:$1|$1]]\'\'\' z [$4 $3 $2].</span>',
+'filedelete-intro-old'        => "Chystáte se smazat verzi souboru '''[[Media:$1|$1]]''' z [$4 $3 $2].",
 'filedelete-comment'          => 'Důvod smazání:',
 'filedelete-submit'           => 'Smazat',
 'filedelete-success'          => "Soubor '''$1''' byl smazán.",
@@ -1533,15 +1514,17 @@
 Od založení wiki bylo navštíveno celkem '''$3''' stránek a editováno '''$4'''krát. To činí v průměru '''$5''' editací na stránku a '''$6''' návštěv na editaci.
 
 Aktuální délka fronty údržby je '''$7'''.",
-'userstatstext'          => "{{PLURAL:$1|Je|Jsou|Je}} zde '''$1''' {{PLURAL:$1|registrovaný [[Special:Listusers|uživatel]]|registrovaní [[Special:Listusers|uživatelé]]|registrovaných [[Special:Listusers|uživatelů]]}}, z&nbsp;toho '''$2''' (což je '''$4&nbsp;%''') {{PLURAL:$2|má|mají|má}} práva $5.",
+'userstatstext'          => "{{PLURAL:$1|Je|Jsou|Je}} zde '''$1''' {{PLURAL:$1|registrovaný [[Special:ListUsers|uživatel]]|registrovaní [[Special:ListUsers|uživatelé]]|registrovaných [[Special:ListUsers|uživatelů]]}}, z&nbsp;toho '''$2''' (což je '''$4&nbsp;%''') {{PLURAL:$2|má|mají|má}} práva $5.",
 'statistics-mostpopular' => 'Nejčtenější stránky',
 
 'disambiguations'      => 'Stránky odkazující na rozcestníky',
 'disambiguationspage'  => 'Template:Rozcestník',
 'disambiguations-text' => 'Odkazy na následujících stránkách vedou na rozcestníky (stránky obsahující některou ze šablon uvedených na [[MediaWiki:Disambiguationspage|seznamu rozcestníkových šablon]]) místo na příslušný článek.',
 
-'doubleredirects'     => 'Dvojitá přesměrování',
-'doubleredirectstext' => 'Na této stránce je seznam přesměrování vedoucí na další přesměrování. Každý řádek obsahuje odkaz na první a druhé přesměrování, a k tomu cíl druhého přesměrování, který obvykle ukazuje jméno „skutečné“ cílové stránky, na kterou by mělo první přesměrování odkazovat.',
+'doubleredirects'            => 'Dvojitá přesměrování',
+'doubleredirectstext'        => 'Na této stránce je seznam přesměrování vedoucí na další přesměrování. Každý řádek obsahuje odkaz na první a druhé přesměrování, a k tomu cíl druhého přesměrování, který obvykle ukazuje jméno „skutečné“ cílové stránky, na kterou by mělo první přesměrování odkazovat.',
+'double-redirect-fixed-move' => 'Stránka [[$1]] byla přesunuta, nyní přesměrovává na [[$2]]',
+'double-redirect-fixer'      => 'Opravář přesměrování',
 
 'brokenredirects'        => 'Přerušená přesměrování',
 'brokenredirectstext'    => 'Tato přesměrování vedou na neexistující stránky.',
@@ -1627,7 +1610,7 @@
 'logempty'             => 'Protokol neobsahuje žádný odpovídající záznam.',
 'log-title-wildcard'   => 'Hledat názvy začínající na tento text',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Všechny stránky',
 'alphaindexline'    => 'od $1 do $2',
 'nextpage'          => 'Další stránka ($1)',
@@ -1650,14 +1633,14 @@
 'special-categories-sort-count' => 'seřadit podle počtu',
 'special-categories-sort-abc'   => 'seřadit abecedně',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Zobrazit uživatele počínaje od:',
 'listusers-submit'   => 'Ukázat',
 'listusers-noresult' => 'Nenalezen žádný uživatel.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Práva skupin uživatelů',
-'listgrouprights-summary'  => 'Toto je seznam skupin uživatelů definovaných na této wiki a&nbsp;jejich přístupových práv.
+'listgrouprights-summary'  => 'Toto je seznam uživatelských skupin definovaných na této wiki a&nbsp;jejich přístupových práv.
 
 [[{{MediaWiki:Listgrouprights-helppage}}|Podrobné informace o&nbsp;jednotlivých právech]]',
 'listgrouprights-group'    => 'Skupina',
@@ -1667,7 +1650,7 @@
 
 # E-mail user
 'mailnologin'     => 'Bez odesílací adresy',
-'mailnologintext' => 'Pokud chcete posílat e-maily jiným uživatelům, musíte se [[Special:Userlogin|přihlásit]] a mít platnou e-mailovou adresu ve svém [[Special:Preferences|nastavení]].',
+'mailnologintext' => 'Pokud chcete posílat e-maily jiným uživatelům, musíte se [[Special:UserLogin|přihlásit]] a mít platnou e-mailovou adresu ve svém [[Special:Preferences|nastavení]].',
 'emailuser'       => 'Poslat e-mail',
 'emailpage'       => 'Poslat e-mail',
 'emailpagetext'   => 'Pokud tento uživatel uvedl platnou e-mailovou adresu ve svém nastavení, tímto formulářem mu lze poslat zprávu. E-mailová adresa, kterou máte uvedenu v nastavení, se objeví jako adresa odesílatele pošty, aby adresát mohl odpovědět.',
@@ -1684,6 +1667,7 @@
 'emailccsubject'  => 'Kopie Vaší zprávy pro uživatele $1: $2',
 'emailsent'       => 'Zpráva odeslána',
 'emailsenttext'   => 'Váš e-mail byl odeslán.',
+'emailuserfooter' => 'Tento e-mail byl odeslán z {{grammar:2sg|{{SITENAME}}}} pomocí funkce „Poslat e-mail“; odeslal ho uživatel $1 uživateli $2',
 
 # Watchlist
 'watchlist'            => 'Sledované stránky',
@@ -1692,9 +1676,9 @@
 'nowatchlist'          => 'Na svém seznamu sledovaných stránek nemáte žádné položky.',
 'watchlistanontext'    => 'Pro prohlížení či úpravu seznamu sledovaných stránek se musíte $1.',
 'watchnologin'         => 'Nejste přihlášen(a)',
-'watchnologintext'     => 'Pro sledování stránek se musíte [[Special:Userlogin|přihlásit]].',
+'watchnologintext'     => 'Pro sledování stránek se musíte [[Special:UserLogin|přihlásit]].',
 'addedwatch'           => 'Přidáno k sledovaným',
-'addedwatchtext'       => 'Stránka „[[:$1]]“ byla přidána mezi stránky, které [[Special:Watchlist|sledujete]]. Budoucí změny této stránky se objeví <b>tučně</b> v [[Special:Recentchanges|seznamu posledních změn]], aby bylo snadnější si jí povšimnout. Pokud budete později chtít stránku ze seznamu sledovaných smazat, klikněte na „Nesledovat tuto stránku“ v liště nástrojů.',
+'addedwatchtext'       => 'Stránka „[[:$1]]“ byla přidána mezi stránky, které [[Special:Watchlist|sledujete]]. Budoucí změny této stránky se objeví <b>tučně</b> v [[Special:RecentChanges|seznamu posledních změn]], aby bylo snadnější si jí povšimnout. Pokud budete později chtít stránku ze seznamu sledovaných smazat, klikněte na „Nesledovat tuto stránku“ v liště nástrojů.',
 'removedwatch'         => 'Vyřazeno ze seznamu sledovaných stránek',
 'removedwatchtext'     => 'Stránka „<nowiki>$1</nowiki>“ byla vyřazena z vašeho seznamu sledovaných stránek.',
 'watch'                => 'Sledovat',
@@ -1791,7 +1775,9 @@
 'rollbacklink'                => 'vrácení zpět',
 'rollbackfailed'              => 'Nešlo vrátit zpět',
 'cantrollback'                => 'Nelze vrátit zpět poslední editaci, neboť poslední přispěvatel je jediným autorem této stránky.',
-'alreadyrolled'               => 'Nelze vrátit zpět poslední editaci [[:$1]] od [[User:$2|$2]] ([[User talk:$2|Diskuse]]), protože někdo jiný již stránku editoval nebo vrátil tuto změnu zpět. Poslední editace byla od [[User:$3|$3]] ([[User talk:$3|Diskuse]]).',
+'alreadyrolled'               => 'Nelze vrátit zpět poslední editaci [[:$1]] od uživatele [[User:$2|$2]] ([[User talk:$2|diskuse]] | [[Special:Contributions/$2|{{int:contribslink}}]]), protože někdo jiný již stránku editoval nebo vrátil tuto změnu zpět.
+
+Poslední editaci této stránky provedl(a) [[User:$3|$3]] ([[User talk:$3|diskuse]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Shrnutí editace bylo: <i>„$1“</i>.', # only shown if there is an edit comment
 'revertpage'                  => 'Editace uživatele „$2“ vrácena do předchozího stavu, jehož autorem je „$1“.', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Editace uživatele $1 byla vrácena na poslední verzi od uživatele $2.',
@@ -1906,7 +1892,7 @@
 
 # What links here
 'whatlinkshere'            => 'Odkazuje sem',
-'whatlinkshere-title'      => 'Stránky odkazující na $1',
+'whatlinkshere-title'      => 'Stránky odkazující na „$1“',
 'whatlinkshere-page'       => 'Strana:',
 'linklistsub'              => '(Seznam odkazů)',
 'linkshere'                => "Na '''[[:$1]]''' odkazují tyto stránky:",
@@ -1957,7 +1943,7 @@
 'badipaddress'                    => 'Neplatná IP adresa',
 'blockipsuccesssub'               => 'Zablokování uspělo',
 'blockipsuccesstext'              => 'Uživatel „[[Special:Contributions/$1|$1]]“ je zablokován.<br />
-Můžete si prohlédnout [[Special:Ipblocklist|seznam zablokovaných uživatelů]].',
+Můžete si prohlédnout [[Special:IPBlockList|seznam zablokovaných uživatelů]].',
 'ipb-edit-dropdown'               => 'Editace seznamu důvodů zablokování',
 'ipb-unblock-addr'                => 'Odblokovat uživatele nebo IP $1',
 'ipb-unblock'                     => 'Odblokovat uživatele nebo IP adresu',
@@ -1987,7 +1973,7 @@
 'autoblocker'                     => 'Automaticky zablokováno, protože sdílíte IP adresu s „$1“. Důvod zablokování tohoto uživatele: „$2“.',
 'blocklogpage'                    => 'Kniha zablokování',
 'blocklogentry'                   => 'blokuje „[[$1]]“ s časem vypršení $2 $3',
-'blocklogtext'                    => 'Toto je kniha úkonů blokování a odblokování uživatelů. Automaticky blokované IP adresy nejsou vypsány. Podívejte se na [[Special:Ipblocklist|seznam blokování IP]] s výčtem aktuálních zákazů a blokování.',
+'blocklogtext'                    => 'Toto je kniha úkonů blokování a odblokování uživatelů. Automaticky blokované IP adresy nejsou vypsány. Podívejte se na [[Special:IPBlockList|seznam blokování IP]] s výčtem aktuálních zákazů a blokování.',
 'unblocklogentry'                 => 'odblokovává „$1“',
 'block-log-flags-anononly'        => 'jen nepřihl.',
 'block-log-flags-nocreate'        => 'vytváření účtů zablokováno',
@@ -2022,7 +2008,7 @@
 'lockdbsuccesssub'    => 'Databáze uzamčena',
 'unlockdbsuccesssub'  => 'Databáze odemčena',
 'lockdbsuccesstext'   => 'Databáze {{grammar:2sg|{{SITENAME}}}} byla úspěšně uzamčena.
-<br />Nezapomeňte ji po dokončení údržby [[Special:Unlockdb|odemknout]].',
+<br />Nezapomeňte ji po dokončení údržby [[Special:UnlockDB|odemknout]].',
 'unlockdbsuccesstext' => 'Databáze {{grammar:2sg|{{SITENAME}}}} je odemčena.',
 'lockfilenotwritable' => 'Do souboru zámku databáze nelze zapisovat. Pro zamčení či odemčení databáze musí mít webový server právo zápisu do tohoto souboru.',
 'databasenotlocked'   => 'Databáze není uzamčena.',
@@ -2037,14 +2023,12 @@
 
 V těchto případech musíte přesunout nebo sloučit stránky manuálně, jestliže si to přejete.",
 'movearticle'             => 'Přesunout stránku:',
-'movenologin'             => 'Nejste přihlášen(a)!',
-'movenologintext'         => 'Pro přesouvání stránek se musíte [[Special:Userlogin|přihlásit]].',
 'movenotallowed'          => 'Nemáte oprávnění k přesunu stránek na {{grammar:6sg|{{SITENAME}}}}.',
 'newtitle'                => 'Na nový název:',
 'move-watch'              => 'Sledovat tuto stránku',
 'movepagebtn'             => 'Přesunout stránku',
 'pagemovedsub'            => 'Úspěšně přesunuto',
-'movepage-moved'          => "<big>'''„$1“ bylo přesunuto na „$2“'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => "<big>'''Stránka „$1“ byla přesunuta na „$2“'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Takto nazvaná stránka již existuje, nebo Vámi zvolený název je neplatný. Zvolte jiný název.',
 'cantmove-titleprotected' => 'Stránku nelze přesunout na zadané místo, protože název je uzamčen proti vytváření',
 'talkexists'              => 'Stránka byla přesunuta úspěšně, ale diskusní stránka přesunuta být nemohla, neboť pod novým názvem již nějaká stránka existuje. Proveďte prosím ruční sloučení.',
@@ -2065,7 +2049,7 @@
 'delete_and_move'         => 'Smazat a přesunout',
 'delete_and_move_text'    => '==Je potřeba smazání==
 
-Cílová stránka „[[$1]]“ již existuje. Přejete si ji smazat pro uvolnění místa pro přesun?',
+Cílová stránka „[[:$1]]“ již existuje. Přejete si ji smazat pro uvolnění místa pro přesun?',
 'delete_and_move_confirm' => 'Ano, smazat cílovou stránku',
 'delete_and_move_reason'  => 'Smazáno pro umožnění přesunu',
 'selfmove'                => 'Původní a nový název jsou stejné; nelze stránku přesunout na sebe samu.',
@@ -2073,12 +2057,15 @@
 'imagenocrossnamespace'   => 'Nelze přesunout mimo jmenný prostor Soubor:',
 'imagetypemismatch'       => 'Nová přípona souboru neodpovídá jeho typu',
 'imageinvalidfilename'    => 'Název cílového souboru není platný',
+'fix-double-redirects'    => 'Opravit všechna přesměrování směřující na původní název',
 
 # Export
 'export'            => 'Exportovat stránky',
-'exporttext'        => 'Můžete exportovat text a historii editací některé stránky nebo sady stránek zabalené v XML. Výsledný soubor lze naimportovat do jiné wiki, která běží na software MediaWiki, pomocí stránky [[Special:Import]].
+'exporttext'        => 'Můžete exportovat text a historii editací některé stránky nebo sady stránek zabalené v XML. Výsledný soubor lze naimportovat do jiné wiki, která běží na software MediaWiki, pomocí stránky [[{{ns:Special}}:Import]].
 
-Do níže uvedeného editačního pole zadejte názvy stránek, které chcete exportovat; každý řádek jeden název. Zvolte také, zda se mají exportovat i starší verze stránky včetně informací v historii editací, nebo jen aktuální verze s informací o poslední editaci.',
+Do níže uvedeného editačního pole zadejte názvy stránek, které chcete exportovat; každý řádek jeden název. Zvolte také, zda se mají exportovat i starší verze stránky včetně informací v historii editací, nebo jen aktuální verze s informací o poslední editaci.
+
+V druhém případě můžete také používat přímý odkaz, např. pomocí [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] se vyexportuje „[[{{MediaWiki:Mainpage}}]]“.',
 'exportcuronly'     => 'Zahrnout jen současnou verzi, ne plnou historii',
 'exportnohistory'   => "----
 '''Poznámka:''' export plných historií prostřednictvím tohoto formuláře byl z výkonnostních důvodů zakázán.",
@@ -2295,10 +2282,10 @@
 'show-big-image'       => 'Obrázek ve vyšším rozlišení',
 'show-big-image-thumb' => '<small>Velikost tohoto náhledu je: $1 × $2 pixelů</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerie nových obrázků',
 'imagelisttext'         => "Níže je {{PLURAL:$1|jeden obrázek|seznam '''$1'''&nbsp;obrázků seřazených $2|seznam '''$1'''&nbsp;obrázků seřazených $2}}.",
-'newimages-summary'     => 'Na této speciální stránce se zobrazují poslední načtené soubory',
+'newimages-summary'     => 'Na této speciální stránce se zobrazují poslední načtené soubory.',
 'showhidebots'          => '($1 roboty)',
 'noimages'              => 'Není co zobrazit.',
 'ilsubmit'              => 'Hledat',
@@ -2578,7 +2565,7 @@
 
 # External editor support
 'edit-externally'      => 'Editovat tento soubor v externím programu',
-'edit-externally-help' => 'Více informací najdete v [http://meta.wikimedia.org/wiki/Help:External_editors nápovědě pro nastavení].',
+'edit-externally-help' => 'Více informací najdete v [http://www.mediawiki.org/wiki/Manual:External_editors nápovědě pro nastavení].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'všechny',
@@ -2648,7 +2635,7 @@
 'recreate'            => 'Znovu založit',
 
 # HTML dump
-'redirectingto' => 'Přesměrovává se na [[$1]]…',
+'redirectingto' => 'Přesměrovává se na [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Aktualizovat cachovanou verzi této stránky?
@@ -2696,8 +2683,8 @@
 'livepreview-error'   => 'Neúspěšné spojení: $1 "$2". Použijte normální náhled.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Změny za posledních $1 sekund nemusí být v tomto seznamu zobrazeny.',
-'lag-warn-high'   => 'Protože je databázový server právě mimořádně vytížen, nemusí být změny za posledních $1 sekund v tomto seznamu zobrazeny.',
+'lag-warn-normal' => 'Změny za {{PLURAL:$1|poslední sekundu|poslední $1 sekundy|posledních $1 sekund}} nemusí být v tomto seznamu zobrazeny.',
+'lag-warn-high'   => 'Protože je databázový server právě mimořádně vytížen, nemusí být změny za {{PLURAL:$1|poslední sekundu|poslední $1 sekundy|posledních $1 sekund}} v tomto seznamu zobrazeny.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Váš seznam sledovaných stránek obsahuje (mimo diskusních stránek) {{PLURAL:$1|1 položku|$1 položky|$1 položek}}.',
@@ -2786,7 +2773,7 @@
 'version-software-product'         => 'Název',
 'version-software-version'         => 'Verze',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Cesta k souboru',
 'filepath-page'    => 'Soubor:',
 'filepath-submit'  => 'Cesta',
@@ -2824,7 +2811,7 @@
 'specialpages-group-redirects'   => 'Přesměrovávací speciální stránky',
 'specialpages-group-spam'        => 'Protispamové nástroje',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Prázdná stránka',
 'intentionallyblankpage' => 'Tato stránka je úmyslně prázdná. Používá se na měření výkonnosti atd.',
 
Index: languages/messages/MessagesPdc.php
===================================================================
--- languages/messages/MessagesPdc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPdc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -96,7 +96,7 @@
 # Tooltip help for the actions
 'tooltip-p-logo' => 'Haaptblatt',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Guuck uff',
 
 );
Index: languages/messages/MessagesKm.php
===================================================================
--- languages/messages/MessagesKm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,16 +4,14 @@
  * @ingroup Language
  * @file
  *
- * @author Lovekhmer
- * @author គីមស៊្រុន
+ * @author Bunly
  * @author Chhorran
+ * @author Kiensvay
+ * @author Lovekhmer
  * @author T-Rithy
- * @author Bunly
- * @author តឹក ប៊ុនលី
- * @author Siebrand
- * @author Jon Harald Søby
- * @author SPQRobin
  * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+ * @author គីមស៊្រុន
+ * @author តឹក ប៊ុនលី
  */
 
 $digitTransformTable = array(
@@ -565,7 +563,7 @@
 'nosuchspecialpage' => 'មិនមានទំព័រពិសេសបែបនេះទេ',
 'nospecialpagetext' => "<big>'''អ្នកបានស្នើរក​ទំព័រពិសេសមួយ ដែលមិនត្រូវបាន​ទទួលស្គាល់​ដោយ វិគី។'''</big>
 
-បញ្ជី​នៃ​ទំព័រពិសេស​អាចត្រូវបាន​រកឃើញ​នៅ [[Special:Specialpages|{{int:specialpages}}]]។",
+បញ្ជី​នៃ​ទំព័រពិសេស​អាចត្រូវបាន​រកឃើញ​នៅ [[Special:SpecialPages|{{int:specialpages}}]]។",
 
 # General errors
 'error'                => 'កំហុស',
@@ -746,25 +744,25 @@
 'hr_tip'          => 'បន្ទាត់ដេក (មិនសូវប្រើទេ)',
 
 # Edit pages
-'summary'                   => 'សេចក្តីសង្ខេប',
-'subject'                   => 'ប្រធានបទ/ចំនងជើងរង',
-'minoredit'                 => 'នេះជា​កំនែប្រែតិចតួចប៉ុណ្ណោះ',
-'watchthis'                 => 'តាមដាន​ទំព័រនេះ',
-'savearticle'               => 'រក្សាទំព័រទុក',
-'preview'                   => 'មើលជាមុន',
-'showpreview'               => 'បង្ហាញ​ការមើលជាមុន',
-'showlivepreview'           => 'មើលជាមុនដោយផ្ទាល់',
-'showdiff'                  => 'បង្ហាញ​បំលាស់ប្តូរ',
-'anoneditwarning'           => "'''ប្រយ័ត្ន ៖''' អ្នកមិនទាន់បានឡុកអ៊ីន​ទេ។ អាសយដ្ឋាន IP របស់អ្នក​នឹងត្រូវបាន​កត់ត្រាទុក​ក្នុងប្រវត្តិកែប្រែ​នៃទំព័រ​នេះ។",
-'missingsummary'            => "'''រំលឹក៖''' អ្នកមិនទាន់បានផ្ដល់អោយនូវសេចក្ដីសង្ខេបអំពីកំនែប្រែទេ។
+'summary'                          => 'សេចក្តីសង្ខេប',
+'subject'                          => 'ប្រធានបទ/ចំនងជើងរង',
+'minoredit'                        => 'នេះជា​កំនែប្រែតិចតួចប៉ុណ្ណោះ',
+'watchthis'                        => 'តាមដាន​ទំព័រនេះ',
+'savearticle'                      => 'រក្សាទំព័រទុក',
+'preview'                          => 'មើលជាមុន',
+'showpreview'                      => 'បង្ហាញ​ការមើលជាមុន',
+'showlivepreview'                  => 'មើលជាមុនដោយផ្ទាល់',
+'showdiff'                         => 'បង្ហាញ​បំលាស់ប្តូរ',
+'anoneditwarning'                  => "'''ប្រយ័ត្ន ៖''' អ្នកមិនទាន់បានឡុកអ៊ីន​ទេ។ អាសយដ្ឋាន IP របស់អ្នក​នឹងត្រូវបាន​កត់ត្រាទុក​ក្នុងប្រវត្តិកែប្រែ​នៃទំព័រ​នេះ។",
+'missingsummary'                   => "'''រំលឹក៖''' អ្នកមិនទាន់បានផ្ដល់អោយនូវសេចក្ដីសង្ខេបអំពីកំនែប្រែទេ។
 បើសិនជាអ្នកចុច '''រក្សាទុក''' ម្ដងទៀតនោះកំនែប្រែរបស់អ្នកនឹងត្រូវរក្សាទុកដោយគ្មានវា។",
-'missingcommenttext'        => 'សូមបញ្ចូលមួយវិចារនៅខាងក្រោម។',
-'missingcommentheader'      => "'''រំលឹក៖''' អ្នកមិនទាន់បានផ្ដល់អោយនូវ ប្រធានបទ/ចំនងជើង របស់វិចារនេះទេ។
+'missingcommenttext'               => 'សូមបញ្ចូលមួយវិចារនៅខាងក្រោម។',
+'missingcommentheader'             => "'''រំលឹក៖''' អ្នកមិនទាន់បានផ្ដល់អោយនូវ ប្រធានបទ/ចំនងជើង របស់វិចារនេះទេ។
 បើសិនជាអ្នកចុច '''រក្សាទុក''' ម្ដងទៀតនោះកំនែប្រែរបស់អ្នកនឹងត្រូវរក្សាទុកដោយគ្មានវា។",
-'summary-preview'           => 'ការមើលជាមុននូវសេចក្តីសង្ខេប',
-'subject-preview'           => 'ការមើលជាមុននូវប្រធានបទ/ចំនងជើង',
-'blockedtitle'              => 'អ្នកប្រើប្រាស់ត្រូវបានហាមឃាត់',
-'blockedtext'               => '<big>\'\'\'ឈ្មោះគណនី (ឬ អាសយដ្ឋាន IP)របស់អ្នកបានត្រូវរាំងខ្ទប់ហើយ។\'\'\'</big>
+'summary-preview'                  => 'ការមើលជាមុននូវសេចក្តីសង្ខេប',
+'subject-preview'                  => 'ការមើលជាមុននូវប្រធានបទ/ចំនងជើង',
+'blockedtitle'                     => 'អ្នកប្រើប្រាស់ត្រូវបានហាមឃាត់',
+'blockedtext'                      => '<big>\'\'\'ឈ្មោះគណនី (ឬ អាសយដ្ឋាន IP)របស់អ្នកបានត្រូវរាំងខ្ទប់ហើយ។\'\'\'</big>
 
 
 ការរាំងខ្ទប់ត្រូវបានធ្វើដោយ $1 ដោយសំអាងលើហេតុផល \'\'$2\'\'។
@@ -778,7 +776,7 @@
 អ្នកមិនអាចប្រើប្រាស់មុខងារ "អ៊ីមែលទៅអ្នកប្រើប្រាស់នេះ" បានទេ លើកលែងអាសយដ្ឋានអ៊ីមែលមានសុពលភាពមួយ​ត្រូវបានបញ្ជាក់​ក្នុង[[Special:Preferences|ចំនូលចិត្តនានានៃគណនី]]របស់លោកអ្នកហើយលោកអ្នកមិនត្រូវបានគេរាំងខ្ទប់មិនអោយប្រើប្រាស់មុខងារនោះ។
 
 អាសយដ្ឋាន IP បច្ចុប្បន្នរបស់លោកអ្នកគឺ $3, និង អត្តសញ្ញាណរាំងខ្ទប់គឺ  #$5 ។ សូមបញ្ចូលអាសយដ្ឋានទាំងនេះសំរាប់គ្រប់សំនួរអង្កេត។',
-'autoblockedtext'           => 'អាសយដ្ឋានIPរបស់អ្នកបានត្រូវហាមឃាត់ដោយស្វ័យប្រវត្តិ ព្រោះវាត្រូវបានប្រើប្រាស់ដោយអ្នកប្រើប្រាស់ផ្សេងទៀត​ ដែលត្រូវបានហាមឃាត់ដោយ $1 ។ 
+'autoblockedtext'                  => 'អាសយដ្ឋានIPរបស់អ្នកបានត្រូវហាមឃាត់ដោយស្វ័យប្រវត្តិ ព្រោះវាត្រូវបានប្រើប្រាស់ដោយអ្នកប្រើប្រាស់ផ្សេងទៀត​ ដែលត្រូវបានហាមឃាត់ដោយ $1 ។ 
 មូលហេតុលើកឡើង៖
 
 :\'\'$2\'\'
@@ -793,94 +791,91 @@
 
 អត្តសញ្ញាណហាមឃាត់របស់អ្នក៖ $5 ។ 
 សូមបញ្ចូលអត្តសញ្ញាណនេះ ក្នុងគ្រប់សំនួរអង្កេតដែលអ្នកបានបង្កើត។',
-'blockednoreason'           => 'គ្មានហេតុផល​ត្រូវបានលើកឡើង',
-'blockedoriginalsource'     => "កូដនៃទំព័រ '''$1''' ត្រូវបានបង្ហាញដូចខាងក្រោម៖",
-'blockededitsource'         => "ខ្លឹមសារ​នៃ '''កំនែប្រែ​របស់អ្នក''' ចំពោះ '''$1''' ត្រូវបាន​បង្ហាញ​ខាងក្រោម ៖",
-'whitelistedittitle'        => 'តំរូវអោយឡុកអ៊ីនដើម្បីកែប្រែ',
-'whitelistedittext'         => 'អ្នកត្រូវតែជា $1 ដើម្បី​កែប្រែ​ខ្លឹមសារទំព័រ។',
-'whitelistreadtitle'        => 'តំរូវអោយឡុកអ៊ីន​ដើម្បីអាន',
-'whitelistreadtext'         => 'អ្នកត្រូវតែ [[Special:Userlogin|ឡុកអ៊ីន]] ដើម្បីអានទំព័រ។',
-'whitelistacctitle'         => 'អ្នកមិនត្រូវបានអនុញ្ញាតអោយបង្កើតគណនីទេ',
-'whitelistacctext'          => 'ដើម្បីអាច​បង្កើត​គណនីមួយ​លើ {{SITENAME}} អ្នកត្រូវតែ  [[Special:Userlogin|ឡុកអ៊ីន]] និង​មាន​ការអនុញ្ញាត​សមស្រប ។',
-'confirmedittitle'          => 'តំរូវអោយ​បញ្ជាក់ទទួលស្គាល់​អ៊ីមែល ដើម្បីកែប្រែ',
-'confirmedittext'           => 'អ្នកត្រូវតែបញ្ជាក់ទទួលស្គាល់អាសយដ្ឋានអ៊ីមែលរបស់អ្នកមុននឹងកែប្រែខ្លឹមសារអត្ថបទ។ ចូរកំនត់និងផ្តល់សុពលភាពអោយអាសយដ្ឋានអ៊ីមែល របស់អ្នកតាម [[Special:Preferences|ចំនូលចិត្តនានារបស់អ្នកប្រើប្រាស់]] ។',
-'nosuchsectiontitle'        => 'មិនមានផ្នែក​បែបនេះ',
-'nosuchsectiontext'         => 'អ្នកបាន​ព្យាយាម​កែប្រែផ្នែក​មួយ​ដែលមិនទាន់មាន​នៅឡើយ ។  ដោយហេតុថា​មិនមាន​ផ្នែក $1 ម៉្លោះហើយ​គ្មានកន្លែង​សំរាប់​រក្សាទុក​កំនែប្រែ​របស់អ្នកទេ ។',
-'loginreqtitle'             => 'តំរូវអោយឡុកអ៊ីន',
-'loginreqlink'              => 'ឡុកអ៊ីន',
-'loginreqpagetext'          => 'អ្នកត្រូវតែ$1ដើម្បីមើលទំព័រដទៃផ្សេងទៀត។',
-'accmailtitle'              => 'ពាក្យសំងាត់ត្រូវបានផ្ញើរួចហើយ។',
-'accmailtext'               => 'ពាក្យសំងាត់​របស់ "$1" ត្រូវបានផ្ញើទៅ $2 ហើយ។',
-'newarticle'                => '(ថ្មី)',
-'newarticletext'            => "អ្នកបានតាម​តំនភ្ជាប់​ទៅ​ទំព័រដែលមិនទាន់មាននៅឡើយ។
+'blockednoreason'                  => 'គ្មានហេតុផល​ត្រូវបានលើកឡើង',
+'blockedoriginalsource'            => "កូដនៃទំព័រ '''$1''' ត្រូវបានបង្ហាញដូចខាងក្រោម៖",
+'blockededitsource'                => "ខ្លឹមសារ​នៃ '''កំនែប្រែ​របស់អ្នក''' ចំពោះ '''$1''' ត្រូវបាន​បង្ហាញ​ខាងក្រោម ៖",
+'whitelistedittitle'               => 'តំរូវអោយឡុកអ៊ីនដើម្បីកែប្រែ',
+'whitelistedittext'                => 'អ្នកត្រូវតែជា $1 ដើម្បី​កែប្រែ​ខ្លឹមសារទំព័រ។',
+'confirmedittitle'                 => 'តំរូវអោយ​បញ្ជាក់ទទួលស្គាល់​អ៊ីមែល ដើម្បីកែប្រែ',
+'confirmedittext'                  => 'អ្នកត្រូវតែបញ្ជាក់ទទួលស្គាល់អាសយដ្ឋានអ៊ីមែលរបស់អ្នកមុននឹងកែប្រែខ្លឹមសារអត្ថបទ។ ចូរកំនត់និងផ្តល់សុពលភាពអោយអាសយដ្ឋានអ៊ីមែល របស់អ្នកតាម [[Special:Preferences|ចំនូលចិត្តនានារបស់អ្នកប្រើប្រាស់]] ។',
+'nosuchsectiontitle'               => 'មិនមានផ្នែក​បែបនេះ',
+'nosuchsectiontext'                => 'អ្នកបាន​ព្យាយាម​កែប្រែផ្នែក​មួយ​ដែលមិនទាន់មាន​នៅឡើយ ។  ដោយហេតុថា​មិនមាន​ផ្នែក $1 ម៉្លោះហើយ​គ្មានកន្លែង​សំរាប់​រក្សាទុក​កំនែប្រែ​របស់អ្នកទេ ។',
+'loginreqtitle'                    => 'តំរូវអោយឡុកអ៊ីន',
+'loginreqlink'                     => 'ឡុកអ៊ីន',
+'loginreqpagetext'                 => 'អ្នកត្រូវតែ$1ដើម្បីមើលទំព័រដទៃផ្សេងទៀត។',
+'accmailtitle'                     => 'ពាក្យសំងាត់ត្រូវបានផ្ញើរួចហើយ។',
+'accmailtext'                      => 'ពាក្យសំងាត់​របស់ "$1" ត្រូវបានផ្ញើទៅ $2 ហើយ។',
+'newarticle'                       => '(ថ្មី)',
+'newarticletext'                   => "អ្នកបានតាម​តំនភ្ជាប់​ទៅ​ទំព័រដែលមិនទាន់មាននៅឡើយ។
 ដើម្បីបង្កើតទំព័រនេះ សូមចាប់ផ្តើមវាយ​ក្នុងប្រអប់ខាងក្រោម (សូមមើល [[{{MediaWiki:Helppage}}|ទំព័រ​ជំនួយ]] សំរាប់​ពត៌មានបន្ថែម)។
 បើ​អ្នកមក​ទីនេះ​ដោយច្រឡំ​ សូមចុចប៊ូតុង '''ត្រលប់ក្រោយ''' របស់ឧបករណ៍រាវរក(browser)​របស់អ្នក។",
-'anontalkpagetext'          => "----''ទំព័រពិភាក្សានេះគឺសំរាប់តែអ្នកប្រើប្រាស់អនាមិកដែលមិនទាន់បានបង្កើតគណនីតែប៉ុណ្ណោះ។ ដូច្នេះអាសយដ្ឋានលេខIPរបស់កុំព្យូទ័ររបស់លោកអ្នក​នឹងត្រូវបានបង្ហាញ ដើមី្បសំគាល់លោកអ្នក។ 
+'anontalkpagetext'                 => "----''ទំព័រពិភាក្សានេះគឺសំរាប់តែអ្នកប្រើប្រាស់អនាមិកដែលមិនទាន់បានបង្កើតគណនីតែប៉ុណ្ណោះ។ ដូច្នេះអាសយដ្ឋានលេខIPរបស់កុំព្យូទ័ររបស់លោកអ្នក​នឹងត្រូវបានបង្ហាញ ដើមី្បសំគាល់លោកអ្នក។ 
 
-អាសយដ្ឋានIPទាំងនោះអាចនឹងត្រូវប្រើដោយមនុស្សជាច្រើន។ ប្រសិនបើអ្នកជាអ្នកប្រើប្រាស់អនាមិក​ហើយ​ប្រសិនបើអ្នកឃើញមានការបញ្ចេញយោបល់​ដែល​មិន​ទាក់ទងទៅនឹងអ្វីដែល​អ្នកបាន​ធ្វើ​ សូម[[Special:Userlogin|ចូលឬបង្កើតគណនី]]ដើម្បីចៀសវាង​ការភ័នច្រឡំ​ណាមួយជាយថាហេតុជាមួយនិងអ្នកប្រើប្រាស់អនាមិកដទៃទៀត។''",
-'noarticletext'             => 'បច្ចុប្បន្ន គ្មានអត្ថបទណាមួយក្នុងទំព័រនេះទេ។ អ្នកអាច [[Special:Search/{{PAGENAME}}|ស្វែងរក​ចំនងជើង​នៃទំព័រនេះ]] ក្នុងទំព័រ​ផ្សេង​ ឬ [{{fullurl:{{FULLPAGENAME}}|action=edit}} កែប្រែ​ទំព័រនេះ]។',
-'userpage-userdoesnotexist' => 'គណនីអ្នកប្រើប្រាស់ "$1" មិនបានត្រូវ ចុះបញ្ជី ។ ចូរឆែកមើល តើ អ្នកចង់ បង្កើត / កែប្រែ ទំព័រ នេះ ។',
-'clearyourcache'            => "'''សំគាល់:''' បន្ទាប់ពីបានរក្សាទុករួចហើយ លោកអ្នកគួរតែសំអាត browser's cache របស់លោកអ្នក។ ខាងក្រោមនេះជាវិធីសំអាត browser's cache ចំពោះកម្មវិធីរុករក(Browser)មួយចំនួន។
+អាសយដ្ឋានIPទាំងនោះអាចនឹងត្រូវប្រើដោយមនុស្សជាច្រើន។ ប្រសិនបើអ្នកជាអ្នកប្រើប្រាស់អនាមិក​ហើយ​ប្រសិនបើអ្នកឃើញមានការបញ្ចេញយោបល់​ដែល​មិន​ទាក់ទងទៅនឹងអ្វីដែល​អ្នកបាន​ធ្វើ​ សូម[[Special:UserLogin|ចូលឬបង្កើតគណនី]]ដើម្បីចៀសវាង​ការភ័នច្រឡំ​ណាមួយជាយថាហេតុជាមួយនិងអ្នកប្រើប្រាស់អនាមិកដទៃទៀត។''",
+'noarticletext'                    => 'បច្ចុប្បន្ន គ្មានអត្ថបទណាមួយក្នុងទំព័រនេះទេ។ អ្នកអាច [[Special:Search/{{PAGENAME}}|ស្វែងរក​ចំនងជើង​នៃទំព័រនេះ]] ក្នុងទំព័រ​ផ្សេង​ ឬ [{{fullurl:{{FULLPAGENAME}}|action=edit}} កែប្រែ​ទំព័រនេះ]។',
+'userpage-userdoesnotexist'        => 'គណនីអ្នកប្រើប្រាស់ "$1" មិនបានត្រូវ ចុះបញ្ជី ។ ចូរឆែកមើល តើ អ្នកចង់ បង្កើត / កែប្រែ ទំព័រ នេះ ។',
+'clearyourcache'                   => "'''សំគាល់:''' បន្ទាប់ពីបានរក្សាទុករួចហើយ លោកអ្នកគួរតែសំអាត browser's cache របស់លោកអ្នក។ ខាងក្រោមនេះជាវិធីសំអាត browser's cache ចំពោះកម្មវិធីរុករក(Browser)មួយចំនួន។
 * '''Mozilla / Firefox / Safari:''' សង្កត់ [Shift] អោយជាប់រួចចុច ''Reload''  ប៊ូតុង ឬក៏ចុច  [Shift]-[Ctrl]-[R]  (ចំពោះApple Mac វិញ​ចុច [Cmd]-[Shift]-[R]) ។
 * '''IE(Internet Explorer):''' សង្កត់ [Ctrl] អោយជាប់ រួចចុច ''Refresh''ប៊ូតុង ឬក៏ចុច ''Ctrl-F5'' ។ 
 * '''Konqueror:''' ចុច ''Refresh'' ប៊ូតុង ឬក៏ចុច ''Ctrl-F5'' 
 * '''Opera:'''  ចំពោះអ្នកប្រើប្រាស់ Opera សូមចុច  ''[Tools]→[Preferences]'' ។",
-'usercssjsyoucanpreview'    => "<strong>គន្លឹះ ៖ </strong> សូមប្រើប្រាស់​ប្រអប់ 'បង្ហាញការមើលមុន' ដើម្បី​ធ្វើតេស្ត​សន្លឹក CSS/JS ថ្មីរបស់អ្នក​មុននឹង​រក្សាទុកវា ។",
-'usercsspreview'            => "'''កុំភ្លេចថា​អ្នកគ្រាន់តែ​កំពុងមើលមុន សន្លឹក CSS របស់អ្នក។ វាមិនទាន់​ត្រូវបានរក្សាទុកទេ!'''",
-'userjspreview'             => "'កុំភ្លេចថាអ្នកគ្រាន់តែកំពុង ធ្វើតេស្ត/មើលមុន ទំព័រអ្នកប្រើប្រាស់  JavaScript របស់អ្នក។ វាមិនទាន់ត្រូវបានរក្សាទុកទេ!'''",
-'userinvalidcssjstitle'     => "'''ប្រយ័ត្ន៖''' គ្មានសំបក \"\$1\"។ ចងចាំថា ទំព័រផ្ទាល់ខ្លួន .css និង .js ប្រើប្រាស់ ចំណងជើង ជាអក្សរតូច, ឧទាហរ  {{ns:user}}:Foo/monobook.css ត្រឹមត្រូវ, រីឯ {{ns:user}}:Foo/Monobook.css មិនត្រឹមត្រូវ។",
-'updated'                   => '(បានបន្ទាន់សម័យ)',
-'note'                      => '<strong>ចំនាំ៖</strong>',
-'previewnote'               => '<strong>នេះគ្រាន់តែជា​ការបង្ហាញការមើលជាមុនប៉ុណ្ណោះ។ បំលាស់ប្តូរ​មិនទាន់បាន​រក្សាទុកទេ!</strong>',
-'session_fail_preview'      => '<strong>សូមអភ័យទោស! យើងមិនអាចរក្សាទុកការកែប្រែរបស់អ្នក ដោយសារបាត់ទិន្នន័យវេនការងារ។
+'usercssjsyoucanpreview'           => "<strong>គន្លឹះ ៖ </strong> សូមប្រើប្រាស់​ប្រអប់ 'បង្ហាញការមើលមុន' ដើម្បី​ធ្វើតេស្ត​សន្លឹក CSS/JS ថ្មីរបស់អ្នក​មុននឹង​រក្សាទុកវា ។",
+'usercsspreview'                   => "'''កុំភ្លេចថា​អ្នកគ្រាន់តែ​កំពុងមើលមុន សន្លឹក CSS របស់អ្នក។ វាមិនទាន់​ត្រូវបានរក្សាទុកទេ!'''",
+'userjspreview'                    => "'កុំភ្លេចថាអ្នកគ្រាន់តែកំពុង ធ្វើតេស្ត/មើលមុន ទំព័រអ្នកប្រើប្រាស់  JavaScript របស់អ្នក។ វាមិនទាន់ត្រូវបានរក្សាទុកទេ!'''",
+'userinvalidcssjstitle'            => "'''ប្រយ័ត្ន៖''' គ្មានសំបក \"\$1\"។ ចងចាំថា ទំព័រផ្ទាល់ខ្លួន .css និង .js ប្រើប្រាស់ ចំណងជើង ជាអក្សរតូច, ឧទាហរ  {{ns:user}}:Foo/monobook.css ត្រឹមត្រូវ, រីឯ {{ns:user}}:Foo/Monobook.css មិនត្រឹមត្រូវ។",
+'updated'                          => '(បានបន្ទាន់សម័យ)',
+'note'                             => '<strong>ចំនាំ៖</strong>',
+'previewnote'                      => '<strong>នេះគ្រាន់តែជា​ការបង្ហាញការមើលជាមុនប៉ុណ្ណោះ។ បំលាស់ប្តូរ​មិនទាន់បាន​រក្សាទុកទេ!</strong>',
+'session_fail_preview'             => '<strong>សូមអភ័យទោស! យើងមិនអាចរក្សាទុកការកែប្រែរបស់អ្នក ដោយសារបាត់ទិន្នន័យវេនការងារ។
 
 សូមព្យាយាមម្តងទៀត។ បើនៅតែមិនធ្វើការ, សូមព្យាយាមពិនិត្យចេញ និង ពិនិត្យចូល ឡើងវិញ។</strong>',
-'session_fail_preview_html' => "<strong>សូមអភ័យទោស! យើងមិនអាចរក្សាទុកកំនែប្រែរបស់លោកអ្នកបានទេ មកពីបាត់ទិន្នន័យណាមួយ ។</strong>
+'session_fail_preview_html'        => "<strong>សូមអភ័យទោស! យើងមិនអាចរក្សាទុកកំនែប្រែរបស់លោកអ្នកបានទេ មកពីបាត់ទិន្នន័យណាមួយ ។</strong>
 
 ''ដោយ {{SITENAME}} មានអក្សរកូដ HTML ឆៅ ងាយប្រើប្រាស់។
 
 ទំព័រមើលមុនត្រូវបានបិទបាំង ដើម្បីចៀសវាងការវាយលុក ដោយ JavaScript ។''
 
 <strong>បើនេះជាការប៉ុនប៉ងកែប្រែសមស្រប,សូមព្យាយាមម្តងទៀត។បើនៅតែមិនដំនើរការ, ព្យាយាមពិនិត្យចេញនិងពិនិត្យចូល ឡើងវិញ។</strong>",
-'editing'                   => 'កំពុងកែប្រែ​ $1',
-'editingsection'            => "កំពុងកែប្រែ'''$1'''(ផ្នែក)",
-'editingcomment'            => 'កែប្រែ $1 (យោបល់)',
-'editconflict'              => 'ភាពឆ្គងនៃកំនែប្រែ៖ $1',
-'explainconflict'           => 'ចាប់តាំងពីអ្នកបានបង្កើតទំព័រនេះមក មានអ្នកដទៃបានកែប្រែវាហើយ។ ផ្នែកខាងលើនៃទំព័រអត្ថបទ គឺជាកំនែប្រែថ្មី។ កំនែប្រែរបស់អ្នក គឺនៅផ្នែកខាងក្រោម។ ចូរដាក់កំនែប្រែរបស់អ្នកបញ្ចូលគ្នាជាមួយអត្ថបទដែលមាននៅផ្នែកខាងលើ។​ <strong>អត្ថបទនៅផ្នែកខខាងលើ</strong> នឹងត្រូវរក្សាទុក នៅពេលអ្នក ចុច"រក្សាទំព័រ"។',
-'yourtext'                  => 'អត្ថបទរបស់អ្នក',
-'storedversion'             => 'កំណែ ដែលបានតំកល់ទុក',
-'editingold'                => '<strong>បំរាម:អ្នកកំពុងតែកែកំនែប្រែដែលហួសសម័យរបស់ទំព័រនេះ។
+'editing'                          => 'កំពុងកែប្រែ​ $1',
+'editingsection'                   => "កំពុងកែប្រែ'''$1'''(ផ្នែក)",
+'editingcomment'                   => 'កែប្រែ $1 (យោបល់)',
+'editconflict'                     => 'ភាពឆ្គងនៃកំនែប្រែ៖ $1',
+'explainconflict'                  => 'ចាប់តាំងពីអ្នកបានបង្កើតទំព័រនេះមក មានអ្នកដទៃបានកែប្រែវាហើយ។ ផ្នែកខាងលើនៃទំព័រអត្ថបទ គឺជាកំនែប្រែថ្មី។ កំនែប្រែរបស់អ្នក គឺនៅផ្នែកខាងក្រោម។ ចូរដាក់កំនែប្រែរបស់អ្នកបញ្ចូលគ្នាជាមួយអត្ថបទដែលមាននៅផ្នែកខាងលើ។​ <strong>អត្ថបទនៅផ្នែកខខាងលើ</strong> នឹងត្រូវរក្សាទុក នៅពេលអ្នក ចុច"រក្សាទំព័រ"។',
+'yourtext'                         => 'អត្ថបទរបស់អ្នក',
+'storedversion'                    => 'កំណែ ដែលបានតំកល់ទុក',
+'editingold'                       => '<strong>បំរាម:អ្នកកំពុងតែកែកំនែប្រែដែលហួសសម័យរបស់ទំព័រនេះ។
 
 ប្រសិនបើអ្នករក្សាវាទុក កំនែប្រែពីមុនទាំងប៉ុន្មាននឹងត្រូវបាត់បង់។</strong>',
-'yourdiff'                  => 'ភាពខុសគ្នា',
-'copyrightwarning'          => 'សូមធ្វើការកត់សំគាល់​ថា គ្រប់ការរួមចំនែក​របស់អ្នក​នៅលើ {{SITENAME}} ត្រូវបាន​ពិចារណា​ដើម្បី​ផ្សព្វផ្សាយ​តាម​លិខិតអនុញ្ញាត $2 (សូម​មើល $1 សំរាប់​ពត៌មាន​លំអិត) ។ បើអ្នកមិនចង់អោយ​សំនេរ​របស់អ្នក​ត្រូវបានគេលុប កែប្រែ ឬក៏អ្នកមិនមានបំនងផ្សព្វផ្សាយវា សូមកុំដាក់​ស្នើវា​នៅទីនេះអី។<br />
+'yourdiff'                         => 'ភាពខុសគ្នា',
+'copyrightwarning'                 => 'សូមធ្វើការកត់សំគាល់​ថា គ្រប់ការរួមចំនែក​របស់អ្នក​នៅលើ {{SITENAME}} ត្រូវបាន​ពិចារណា​ដើម្បី​ផ្សព្វផ្សាយ​តាម​លិខិតអនុញ្ញាត $2 (សូម​មើល $1 សំរាប់​ពត៌មាន​លំអិត) ។ បើអ្នកមិនចង់អោយ​សំនេរ​របស់អ្នក​ត្រូវបានគេលុប កែប្រែ ឬក៏អ្នកមិនមានបំនងផ្សព្វផ្សាយវា សូមកុំដាក់​ស្នើវា​នៅទីនេះអី។<br />
 អ្នកត្រូវសន្យាថា ​អ្នកសរសេរវា​ដោយខ្លួនអ្នក ឬបានចំលងវា​ពី​កម្មសិទ្ធិសាធារណៈឬពីប្រភពសេរី ។
 <strong>មិនត្រូវ​ដាក់ស្នើ​ការងារមានរក្សាសិទ្ធិកម្មសិទ្ឋិបញ្ញាដោយគ្មានការអនុញ្ញាតទេ!</strong>',
-'copyrightwarning2'         => 'សូមធ្វើការកត់សំគាល់​ថា គ្រប់ការរួមចំនែក​ទៅ {{SITENAME}} អាច​ត្រូវបាន​កែប្រែ​ ផ្លាស់ប្តូរ រឺលុបចោល ដោយអ្នករួមចំនែកដទៃទៀត។ បើអ្នកមិនចង់អោយ​សំនេររបស់អ្នក​ត្រូវបានគេកែប្រែដោយ​គ្មានអាសូរទេនោះ សូមកុំដាក់​ស្នើវា​នៅទីនេះអី។<br />
+'copyrightwarning2'                => 'សូមធ្វើការកត់សំគាល់​ថា គ្រប់ការរួមចំនែក​ទៅ {{SITENAME}} អាច​ត្រូវបាន​កែប្រែ​ ផ្លាស់ប្តូរ រឺលុបចោល ដោយអ្នករួមចំនែកដទៃទៀត។ បើអ្នកមិនចង់អោយ​សំនេររបស់អ្នក​ត្រូវបានគេកែប្រែដោយ​គ្មានអាសូរទេនោះ សូមកុំដាក់​ស្នើវា​នៅទីនេះអី។<br />
 អ្នកត្រូវសន្យាជាមួយ​យើង​ខ្ញុំផងដែរថា ​អ្នកសរសេរវា​ដោយខ្លួនអ្នក ឬ បានចំលងវា​ពី​កម្មសិទ្ធិសាធារណៈឬពីប្រភពសេរី (សូមមើល $1 សំរាប់ពត៌មាន​លំអិត)។
 
 <strong>មិនត្រូវ​ដាក់ស្នើ​ការងារមានរក្សាសិទ្ធិកម្មសិទ្ឋិបញ្ញាដោយគ្មានការអនុញ្ញាតទេ!</strong>',
-'longpagewarning'           => '<strong>ប្រយ័ត្ន ៖ ទំព័រនេះមានទំហំ $1 គីឡូបៃ។ ឧបករណ៍រាវរក(browser)ខ្លះអាចមានបញ្ហាក្នុងការកែប្រែទំព័រក្បែរឬធំជាង៣២គីឡូបៃ​។
+'longpagewarning'                  => '<strong>ប្រយ័ត្ន ៖ ទំព័រនេះមានទំហំ $1 គីឡូបៃ។ ឧបករណ៍រាវរក(browser)ខ្លះអាចមានបញ្ហាក្នុងការកែប្រែទំព័រក្បែរឬធំជាង៣២គីឡូបៃ​។
 
 សូមពិចារណាអំពីលទ្ឋភាពបំបែកទំព័រជាផ្នែកតូចៗ ។ </strong>',
-'longpageerror'             => '<strong>កំហុស៖ អត្ថបទ​ដែល​អ្នក​បានដាក់​ស្នើ​មានទំហំ $1 គីឡូបៃ ដែលធំជាង​ទំហំអតិបរមា $2 គីឡូបៃ។ អត្ថបទនេះ​មិនអាច​រក្សាទុកបានទេ។</strong>',
-'readonlywarning'           => '<strong>បំរាម:មូលដ្ឋានទិន្នន័យត្រូវបានចាក់សោសំរាប់ការរក្សាទុក ដូច្នេះអ្នកនឹងមិនអាចរក្សាទុករាល់កំនែប្រែរបស់អ្នកបានទេឥឡូវនេះ។ សូមអ្នកចំលងអត្ថបទ រួចដាក់ទៅក្នុងឯកសារដែលជាអត្ថបទ ហើយបន្ទាប់មករក្សាវាទុក។</strong>',
-'protectedpagewarning'      => '<strong>ប្រយ័ត្ន៖ ទំព័រនេះ​ត្រូវបានចាក់សោ។ ដូច្នេះ​មានតែ​អ្នកប្រើប្រាស់​ដែល​មាន​អភ័យឯកសិទ្ឋិ​ជាអ្នកថែទាំប្រព័ន្ឋ​ (sysop) ទេទើបអាច​កែប្រែ​វាបាន។</strong>',
-'semiprotectedpagewarning'  => "'''សំគាល់៖''' ទំព័រនេះ​បានត្រូវ​ចាក់សោ។ ដូច្នេះ​មានតែអ្នកប្រើប្រាស់​ដែលបានចុះឈ្មោះ​ទើបអាចកែប្រែ​វា​បាន។",
-'titleprotectedwarning'     => '<strong>ប្រយ័ត្ន៖ ទំព័រនេះត្រូវបានចាក់សោ ដូច្នេះមានតែអ្នកប្រើប្រាស់មួយចំនួនប៉ុណ្ណោះអាចបង្កើតវា។</strong>',
-'templatesused'             => 'ទំព័រគំរូប្រើនៅក្នុងទំព័រនេះគឺ៖',
-'templatesusedpreview'      => 'ទំព័រគំរូ​នានាដែល​បានប្រើប្រាស់​ក្នុងការមើលមុននេះ៖',
-'templatesusedsection'      => 'ទំព័រគំរូដែលត្រូវបានប្រើប្រាស់ក្នុងផ្នែកនេះ៖',
-'template-protected'        => '(ត្រូវបានការពារ)',
-'template-semiprotected'    => '(ត្រូវបានការពារពាក់កណ្តាល)',
-'hiddencategories'          => 'ទំព័រនេះស្ថិតនៅក្នុង {{PLURAL:$1|ចំនាត់ថ្នាក់ក្រុមដែលត្រូវបានបិទបាំង១|ចំនាត់ថ្នាក់ក្រុមដែលត្រូវបានបិទបាំង $1}}:',
-'nocreatetitle'             => 'ការបង្កើតទំព័រ​ត្រូវបានកំរិត',
-'nocreatetext'              => '{{SITENAME}} បានដាក់កំហិតលទ្ធភាពបង្កើតទំព័រថ្មី ។
-អ្នកអាចត្រលប់ក្រោយ និង កែប្រែទំព័រមានស្រាប់ ឬ  [[Special:Userlogin|ចូលឬបង្កើតគណនី]]។',
-'nocreate-loggedin'         => 'អ្នកគ្មានការអនុញ្ញាត​បង្កើតទំព័រថ្មី​លើ {{SITENAME}} ទេ។',
-'permissionserrors'         => 'កំហុសនៃការអនុញ្ញាតនានា',
-'permissionserrorstext'     => 'អ្នកគ្មានការអនុញ្ញាតឱ្យធ្វើអ្វីទាំងនោះទេ សំរាប់{{PLURAL:$1|ហេតុផល|ហេតុផល}}ដូចតទៅ៖',
-'recreate-deleted-warn'     => "'''ប្រយ័ត្ន ៖ អ្នកកំពុង​បង្កើតឡើងវិញ​ទំព័រដែលទើបតែ​ត្រូវបានលុបចេញ ។'''
+'longpageerror'                    => '<strong>កំហុស៖ អត្ថបទ​ដែល​អ្នក​បានដាក់​ស្នើ​មានទំហំ $1 គីឡូបៃ ដែលធំជាង​ទំហំអតិបរមា $2 គីឡូបៃ។ អត្ថបទនេះ​មិនអាច​រក្សាទុកបានទេ។</strong>',
+'readonlywarning'                  => '<strong>បំរាម:មូលដ្ឋានទិន្នន័យត្រូវបានចាក់សោសំរាប់ការរក្សាទុក ដូច្នេះអ្នកនឹងមិនអាចរក្សាទុករាល់កំនែប្រែរបស់អ្នកបានទេឥឡូវនេះ។ សូមអ្នកចំលងអត្ថបទ រួចដាក់ទៅក្នុងឯកសារដែលជាអត្ថបទ ហើយបន្ទាប់មករក្សាវាទុក។</strong>',
+'protectedpagewarning'             => '<strong>ប្រយ័ត្ន៖ ទំព័រនេះ​ត្រូវបានចាក់សោ។ ដូច្នេះ​មានតែ​អ្នកប្រើប្រាស់​ដែល​មាន​អភ័យឯកសិទ្ឋិ​ជាអ្នកថែទាំប្រព័ន្ឋ​ (sysop) ទេទើបអាច​កែប្រែ​វាបាន។</strong>',
+'semiprotectedpagewarning'         => "'''សំគាល់៖''' ទំព័រនេះ​បានត្រូវ​ចាក់សោ។ ដូច្នេះ​មានតែអ្នកប្រើប្រាស់​ដែលបានចុះឈ្មោះ​ទើបអាចកែប្រែ​វា​បាន។",
+'titleprotectedwarning'            => '<strong>ប្រយ័ត្ន៖ ទំព័រនេះត្រូវបានចាក់សោ ដូច្នេះមានតែអ្នកប្រើប្រាស់មួយចំនួនប៉ុណ្ណោះអាចបង្កើតវា។</strong>',
+'templatesused'                    => 'ទំព័រគំរូប្រើនៅក្នុងទំព័រនេះគឺ៖',
+'templatesusedpreview'             => 'ទំព័រគំរូ​នានាដែល​បានប្រើប្រាស់​ក្នុងការមើលមុននេះ៖',
+'templatesusedsection'             => 'ទំព័រគំរូដែលត្រូវបានប្រើប្រាស់ក្នុងផ្នែកនេះ៖',
+'template-protected'               => '(ត្រូវបានការពារ)',
+'template-semiprotected'           => '(ត្រូវបានការពារពាក់កណ្តាល)',
+'hiddencategories'                 => 'ទំព័រនេះស្ថិតនៅក្នុង {{PLURAL:$1|ចំនាត់ថ្នាក់ក្រុមដែលត្រូវបានបិទបាំង១|ចំនាត់ថ្នាក់ក្រុមដែលត្រូវបានបិទបាំង $1}}:',
+'nocreatetitle'                    => 'ការបង្កើតទំព័រ​ត្រូវបានកំរិត',
+'nocreatetext'                     => '{{SITENAME}} បានដាក់កំហិតលទ្ធភាពបង្កើតទំព័រថ្មី ។
+អ្នកអាចត្រលប់ក្រោយ និង កែប្រែទំព័រមានស្រាប់ ឬ  [[Special:UserLogin|ចូលឬបង្កើតគណនី]]។',
+'nocreate-loggedin'                => 'អ្នកគ្មានការអនុញ្ញាត​បង្កើតទំព័រថ្មី​លើ {{SITENAME}} ទេ។',
+'permissionserrors'                => 'កំហុសនៃការអនុញ្ញាតនានា',
+'permissionserrorstext'            => 'អ្នកគ្មានការអនុញ្ញាតឱ្យធ្វើអ្វីទាំងនោះទេ សំរាប់{{PLURAL:$1|ហេតុផល|ហេតុផល}}ដូចតទៅ៖',
+'permissionserrorstext-withaction' => 'អ្នកមិនត្រូវបានអនុញ្ញាតអោយ$2ទេ ដោយសារ{{PLURAL:$1|មូលហេតុ|មូលហេតុ}}ដូចខាងក្រោម:',
+'recreate-deleted-warn'            => "'''ប្រយ័ត្ន ៖ អ្នកកំពុង​បង្កើតឡើងវិញ​ទំព័រដែលទើបតែ​ត្រូវបានលុបចេញ ។'''
 
 អ្នក​គួរពិចារណាមើល​តើជាការសមស្របទេ ដែលបន្តកែប្រែ​ទំព័រនេះ ។
 
@@ -937,8 +932,8 @@
 'revdelete-legend'          => 'ដាក់កំហិត នានា',
 'revdelete-hide-text'       => 'បិទបាំងឃ្លានៃកំនែប្រែ',
 'revdelete-hide-name'       => 'បិទបាំងសកម្មភាពនិងគោលដៅ',
-'revdelete-hide-comment'    => 'បិទបាំង កំណែប្រែ វិចារ',
-'revdelete-hide-user'       => 'បិទបាំង ឈ្មោះអ្នកប្រើប្រាស់​ ឬ អាស័យដ្ឋាន IP នៃ អ្នករួមចំណែក',
+'revdelete-hide-comment'    => 'បិទបាំងកំនែប្រែវិចារ',
+'revdelete-hide-user'       => 'បិទបាំងឈ្មោះអ្នកប្រើប្រាស់​ឬអាសយដ្ឋានIPនៃអ្នករួមចំណែក',
 'revdelete-hide-restricted' => 'អនុវត្ត ការដាក់កំហិត នានា ចំពោះ អ្នកថែទាំប្រព័ន្ធ(sysops) ក៏ដូចជា អ្នកប្រើប្រាស់ ដ៏ទៃទៀត',
 'revdelete-suppress'        => 'លាក់ទិន្នន័យពីអ្នកថែទាំប្រព័ន្ធ ព្រមទាំងពីសមាជិកដទៃទៀតផងដែរ',
 'revdelete-hide-image'      => 'បិទបាំងខ្លឹមសារនៃឯកសារ',
@@ -954,8 +949,8 @@
 'revdelete-content'         => 'ខ្លឹមសារ',
 'revdelete-summary'         => 'កែប្រែសេចក្ដីសង្ខេប',
 'revdelete-uname'           => 'អ្នកប្រើប្រាស់',
-'revdelete-hid'             => 'លាក់ $1',
-'revdelete-unhid'           => 'បង្ហាញ $1',
+'revdelete-hid'             => 'បានលាក់$1',
+'revdelete-unhid'           => 'ឈប់លាក់$1',
 
 # History merging
 'mergehistory'                     => 'បញ្ចូលរួមគ្នាប្រវត្តិទាំងឡាយនៃទំព័រ',
@@ -1001,7 +996,7 @@
 'prevn'                     => 'មុន $1',
 'nextn'                     => 'បន្ទាប់ $1',
 'viewprevnext'              => 'មើល ($1) ($2) ($3)',
-'search-result-size'        => '$1 ({{PLURAL:$2|1 ពាក្យ|$2 ពាក្យ}})',
+'search-result-size'        => '$1({{PLURAL:$2|១ពាក្យ|$2ពាក្យ}})',
 'search-result-score'       => 'កំរិតនៃភាពទាក់ទិន៖ $1%',
 'search-redirect'           => '(បញ្ជូនបន្ត $1)',
 'search-section'            => '(ផ្នែក $1)',
@@ -1015,7 +1010,7 @@
 'searchrelated'             => 'ទាក់ទិន',
 'searchall'                 => 'ទាំងអស់',
 'showingresults'            => "ខាងក្រោមកំពុងបង្ហាញរហូតដល់ {{PLURAL:$1|'''១''' លទ្ឋផល|'''$1''' លទ្ឋផល}} ចាប់ផ្ដើមពីលេខ #'''$2'''។",
-'showingresultsnum'         => "ខាងក្រោមកំពុងបង្ហាញ {{PLURAL:$3|'''១''' លទ្ឋផល|'''$3''' លទ្ឋផល}} ចាប់ផ្ដើមពីលេខ #'''$2'''។",
+'showingresultsnum'         => 'កំពុងបង្ហាញ<b>$3</b>លទ្ឋផលខាងក្រោម ចាប់ផ្ដើមដោយ #<b>$2</b>។',
 'showingresultstotal'       => "ខាងក្រោមកំពុងបង្ហាញលទ្ឋផលពីលេខ '''$1 - $2''' ក្នុងចំនោមលទ្ឋផលសរុប '''$3'''",
 'powersearch'               => 'ស្វែងរកថ្នាក់ខ្ពស់',
 'powersearch-legend'        => 'ស្វែងរកថ្នាក់ខ្ពស់',
@@ -1029,7 +1024,7 @@
 'mypreferences'            => 'ចំនូលចិត្ត​របស់ខ្ញុំ',
 'prefs-edits'              => 'ចំនួនកំនែប្រែ៖',
 'prefsnologin'             => 'មិនបានឡុកអ៊ីន',
-'prefsnologintext'         => 'អ្នកត្រូវតែ [[Special:Userlogin|ឡុកអ៊ីន]] ដើម្បីកំនត់ចំនូលចិត្តរបស់អ្នកប្រើប្រាស់។',
+'prefsnologintext'         => 'អ្នកត្រូវតែ [[Special:UserLogin|ឡុកអ៊ីន]] ដើម្បីកំនត់ចំនូលចិត្តរបស់អ្នកប្រើប្រាស់។',
 'prefsreset'               => 'ចំនូលចិត្ត​ផ្ទាល់ខ្លួនត្រូវបានធ្វើអោយដូចដើមវិញពីកំនែមុននេះហើយ។',
 'qbsettings'               => 'របារទាន់ចិត្ត',
 'qbsettings-none'          => 'ទទេ',
@@ -1098,7 +1093,7 @@
 'userrights-reason'           => 'មូលហេតុនៃការផ្លាស់ប្តូរ៖',
 'userrights-no-interwiki'     => 'អ្នកមិនមានការអនុញ្ញាតិ កែប្រែសិទ្ធិ នៃអ្នកប្រើប្រាស់ លើ វិគី ផ្សេង ទេ។',
 'userrights-nodatabase'       => 'មូលដ្ឋានទិន្នន័យ $1 មិនមាន ឬ ថិតនៅខាងក្រៅ។',
-'userrights-nologin'          => 'អ្នកត្រូវតែ [[Special:Userlogin|ឡុកអ៊ីន]] ជាគណនីអ្នកអភិបាលដើម្បីផ្តល់សិទ្ធិអោយអ្នកប្រើប្រាស់ ។',
+'userrights-nologin'          => 'អ្នកត្រូវតែ [[Special:UserLogin|ឡុកអ៊ីន]] ជាគណនីអ្នកអភិបាលដើម្បីផ្តល់សិទ្ធិអោយអ្នកប្រើប្រាស់ ។',
 'userrights-notallowed'       => 'គណនីរបស់អ្នកមិនមានការអនុញ្ញាតិដើម្បីកំនត់សិទ្ធិរបស់អ្នកប្រើប្រាស់ដទៃ។',
 'userrights-changeable-col'   => 'ក្រុមនានាដែលអ្នកអាចផ្លាស់ប្ដូរបាន',
 'userrights-unchangeable-col' => 'ក្រុមនានាដែលអ្នកមិនអាចផ្លាស់ប្ដូរបាន',
@@ -1204,10 +1199,10 @@
 'reupload'                    => 'ផ្ទុកឡើងម្តងទៀត',
 'reuploaddesc'                => 'ឈប់ផ្ទុកឡើងរួចត្រឡប់ទៅបែបបទផ្ទុកឡើងវិញ។',
 'uploadnologin'               => 'មិនបានឡុកអ៊ីនទេ',
-'uploadnologintext'           => 'អ្នកត្រូវតែ [[Special:Userlogin|ឡុកអ៊ីន]] ដើម្បីផ្ទុកឡើងឯកសារទាំងឡាយ។',
+'uploadnologintext'           => 'អ្នកត្រូវតែ [[Special:UserLogin|ឡុកអ៊ីន]] ដើម្បីផ្ទុកឡើងឯកសារទាំងឡាយ។',
 'uploaderror'                 => 'កំហុសផ្ទុកឡើង',
 'uploadtext'                  => "ប្រើប្រាស់ បែបបទ ខាងក្រោម ដើម្បី ផ្ទុកឡើង ឯកសារ​។
-ចង់មើល ឬ ស្វែងរក ឯកសារ ដែលបានផ្ទុកឡើង មុននេះ, ត្រូវចូលទៅ [[Special:Imagelist|បញ្ជី នៃ ឯកសារ ដែលបានផ្ទុកឡើង]]។ ការផ្ទុកឡើង និង ការលុបចេញ ត្រូវបានរក្សាទុក ផងដែរ ក្នុង [[Special:Log/upload|កំណត់ហេតុ នៃ បន្ទុកឡើង]]។
+ចង់មើល ឬ ស្វែងរក ឯកសារ ដែលបានផ្ទុកឡើង មុននេះ, ត្រូវចូលទៅ [[Special:ImageList|បញ្ជី នៃ ឯកសារ ដែលបានផ្ទុកឡើង]]។ ការផ្ទុកឡើង និង ការលុបចេញ ត្រូវបានរក្សាទុក ផងដែរ ក្នុង [[Special:Log/upload|កំណត់ហេតុ នៃ បន្ទុកឡើង]]។
 
 ដើម្បី ដាក់ រូបភាព ទៅក្នុងទំព័រ, អ្នកត្រូវ ប្រើប្រាស់ តំណភ្ជាប់ តាមទំរង់
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1283,7 +1278,7 @@
 'upload_source_url'  => ' (URL ត្រឹមត្រូវនិងបើកចំហជាសាធារណៈ)',
 'upload_source_file' => ' (ឯកសារក្នុងកុំព្យូទ័ររបស់អ្នក)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'ស្វែងរកឈ្មោះមេឌា៖',
 'imgfile'               => 'ឯកសារ',
 'imagelist'             => 'បញ្ជីរូបភាព',
@@ -1308,7 +1303,7 @@
 'imagelinks'                     => 'តំនភ្ជាប់​នានា',
 'linkstoimage'                   => '{{PLURAL:$1|ទំព័រ​|$1 ទំព័រ}} ខាងក្រោម​មានតំនភ្ជាប់មក​ឯកសារនេះ ៖',
 'nolinkstoimage'                 => 'គ្មានទំព័រណាមួយដែលតភ្ជាប់មកឯកសារនេះទេ។',
-'morelinkstoimage'               => 'មើល [[Special:Whatlinkshere/$1|តំនភ្ជាប់បន្ថែមទៀត]] ដែលតភ្ជាប់មកកាន់ឯកសារនេះ។',
+'morelinkstoimage'               => 'មើល [[Special:WhatLinksHere/$1|តំនភ្ជាប់បន្ថែមទៀត]] ដែលតភ្ជាប់មកកាន់ឯកសារនេះ។',
 'redirectstofile'                => 'ឯកសារដូចតទៅនេះបញ្ជូនបន្ដមកឯកសារនេះ៖',
 'sharedupload'                   => 'ឯកសារនេះ​ត្រូវបានផ្ទុកឡើង​ដើម្បីចែករំលែក និង អាចត្រូវបានប្រើប្រាស់​នៅគំរោង​ដទៃ ។',
 'shareduploadwiki'               => 'សូម​មើល $1 សំរាប់ពត៌មានបន្ថែម ។',
@@ -1379,7 +1374,7 @@
 *គិតជាមធ្យមមាន '''\$5''' កំនែប្រែក្នុងមួយទំព័រ និង '''\$6'''ដងនៃការចូលមើលក្នុងមួយកំនែប្រែ។
 
 *<span class=\"plainlinks\">[http://www.mediawiki.org/wiki/Manual:Job_queue ជួរការងារ]</span>(job queue)ឥឡូវនេះមានប្រវែង '''\$7''' ។",
-'userstatstext'          => "នៅពេលនេះមាន[[Special:Listusers|អ្នកប្រើប្រាស់]]​ដែលបានចុះឈ្មោះចំនួន '''$1'''នាក់ ដែលក្នុងនោះមាន'''$2'''នាក់(ស្មើនឹង'''$4%''') {{PLURAL:$2|មានសិទ្ធិជា|មានសិទ្ធិជា}}$5 ។",
+'userstatstext'          => "នៅពេលនេះមាន[[Special:ListUsers|អ្នកប្រើប្រាស់]]​ដែលបានចុះឈ្មោះចំនួន '''$1'''នាក់ ដែលក្នុងនោះមាន'''$2'''នាក់(ស្មើនឹង'''$4%''') {{PLURAL:$2|មានសិទ្ធិជា|មានសិទ្ធិជា}}$5 ។",
 'statistics-mostpopular' => 'ទំព័រដែលត្រូវបានមើលច្រើនបំផុត',
 
 'disambiguations' => 'ទំព័រមានន័យច្បាស់លាស់',
@@ -1461,7 +1456,7 @@
 'logempty'             => 'គ្មានអ្វីក្នុងកំណត់ហេតុត្រូវនឹងទំព័រនេះទេ។',
 'log-title-wildcard'   => 'ស្វែងរកចំនងជើងចាប់ផ្តើមដោយឃ្លានេះ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'ទំព័រទាំងអស់',
 'alphaindexline'    => 'ពីទំព័រ $1 ដល់ទំព័រ $2',
 'nextpage'          => 'ទំព័របន្ទាប់ ($1)',
@@ -1484,12 +1479,12 @@
 'special-categories-sort-count' => 'តំរៀបតាមចំនួន',
 'special-categories-sort-abc'   => 'តំរៀបតាមអក្ខរក្រម',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'បង្ហាញអ្នកប្រើប្រាស់ចាប់ផ្តើមដោយ៖',
 'listusers-submit'   => 'បង្ហាញ',
 'listusers-noresult' => 'មិនមានអ្នកប្រើប្រាស់នៅក្នុងក្រុមនេះទេ។',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'សិទ្ធិនិងក្រុមអ្នកប្រើប្រាស់',
 'listgrouprights-summary'  => 'ខាងក្រោមនេះជាបញ្ជីរាយឈ្មោះក្រុមអ្នកប្រើប្រាស់ដែលបានកំនត់ជាមួយនឹងសិទ្ធិរបស់គេនៅលើវិគីនេះ។ ចំពោះពត៌មានបន្ថែមអំពីសិទ្ធិផ្ទាល់ខ្លួន សូមមើល [[{{MediaWiki:Listgrouprights-helppage}}]] ។',
 'listgrouprights-group'    => 'ក្រុម',
@@ -1499,7 +1494,7 @@
 
 # E-mail user
 'mailnologin'     => 'មិនមានអាសយដ្ឋានផ្ញើទេ',
-'mailnologintext' => 'អ្នកត្រូវតែ [[Special:Userlogin|ឡុកអ៊ីន]] និង មានអាសយដ្ឋានអ៊ីមែលមានសុពលភាពមួយ ក្នុង[[Special:Preferences|ចំនូលចិត្តនានារបស់អ្នក]] ដើម្បីផ្ញើអ៊ីមែលទៅ អ្នកប្រើប្រាស់ដទៃទៀត។',
+'mailnologintext' => 'អ្នកត្រូវតែ [[Special:UserLogin|ឡុកអ៊ីន]] និង មានអាសយដ្ឋានអ៊ីមែលមានសុពលភាពមួយ ក្នុង[[Special:Preferences|ចំនូលចិត្តនានារបស់អ្នក]] ដើម្បីផ្ញើអ៊ីមែលទៅ អ្នកប្រើប្រាស់ដទៃទៀត។',
 'emailuser'       => 'អ៊ីមែលទៅកាន់អ្នកប្រើប្រាស់នេះ',
 'emailpage'       => 'ទំព័រផ្ញើអ៊ីមែល',
 'defemailsubject' => 'អ៊ីមែល{{SITENAME}}',
@@ -1510,8 +1505,8 @@
 'emailsubject'    => 'ប្រធានបទ',
 'emailmessage'    => 'សារ',
 'emailsend'       => 'ផ្ញើ',
-'emailccme'       => 'អ៊ីមែលមកខ្ញុំ នូវច្បាប់ចំលងមួយនៃសាររបស់ខ្ញុំ។',
-'emailccsubject'  => 'ច្បាប់ចំលង នៃ សាររបស់អ្នក ចំពោះ $1 ៖  $2',
+'emailccme'       => 'អ៊ីមែលមកខ្ញុំនូវច្បាប់ចំលងមួយនៃសាររបស់ខ្ញុំ។',
+'emailccsubject'  => 'ច្បាប់ចំលងនៃសាររបស់អ្នកចំពោះ $1 ៖ $2',
 'emailsent'       => 'អ៊ីមែលត្រូវបានផ្ញើទៅហើយ',
 'emailsenttext'   => 'សារអ៊ីមែលរបស់អ្នកត្រូវបានផ្ញើរួចហើយ។',
 'emailuserfooter' => 'អ៊ីមែលនេះត្រូវបានផ្ញើដោយ$1ទៅកាន់$2ដោយប្រើមុខងារ"អ៊ីមែលអ្នកប្រើប្រាស់"របស់{{SITENAME}}។',
@@ -1523,9 +1518,9 @@
 'nowatchlist'          => 'អ្នកគ្មានរបស់អ្វី លើបញ្ជីតាមដាន របស់អ្នក',
 'watchlistanontext'    => 'សូម $1 ដើម្បី​មើល​ឬ​កែប្រែ​របស់​ក្នុង​បញ្ជីតាមដាន​របស់អ្នក។',
 'watchnologin'         => 'មិនបានឡុកអ៊ីន',
-'watchnologintext'     => 'អ្នកចាំបាច់ត្រូវតែ[[Special:Userlogin|ឡុកអ៊ីន]]ដើម្បីកែប្រែបញ្ជីតាមដានរបស់អ្នក។',
+'watchnologintext'     => 'អ្នកចាំបាច់ត្រូវតែ[[Special:UserLogin|ឡុកអ៊ីន]]ដើម្បីកែប្រែបញ្ជីតាមដានរបស់អ្នក។',
 'addedwatch'           => 'បានបន្ថែមទៅបញ្ជីតាមដាន',
-'addedwatchtext'       => "ទំព័រ \"[[:\$1]]\" ត្រូវបានដាក់បញ្ចូលទៅក្នុង​[[Special:Watchlist|បញ្ជីតាមដាន]]របស់លោកអ្នកហើយ ។ រាល់ការផ្លាស់ប្តូរនៃទំព័រនេះ រួមទាំងទំព័រពិភាក្សារបស់វាផងដែរ នឹងត្រូវបានដាក់បញ្ចូលក្នុងបញ្ជីនៅទីនោះ។  ទំព័រនេះនឹងបង្ហាញជា'''អក្សរដិត''' នៅក្នុង [[Special:Recentchanges|បញ្ជីបំលាស់ប្តូរថ្មីៗ]] ងាយស្រួលក្នុងការស្វែងរក។ ប្រសិនបើលោកអ្នកចង់យកវាចេញពី [[Special:Watchlist|បញ្ជីតាមដាន]]របស់លោកអ្នក សូមចុច '''ឈប់តាមដាន''' នៅលើរបារចំហៀងផ្នែកខាងលើ។",
+'addedwatchtext'       => "ទំព័រ \"[[:\$1]]\" ត្រូវបានដាក់បញ្ចូលទៅក្នុង​[[Special:Watchlist|បញ្ជីតាមដាន]]របស់លោកអ្នកហើយ ។ រាល់ការផ្លាស់ប្តូរនៃទំព័រនេះ រួមទាំងទំព័រពិភាក្សារបស់វាផងដែរ នឹងត្រូវបានដាក់បញ្ចូលក្នុងបញ្ជីនៅទីនោះ។  ទំព័រនេះនឹងបង្ហាញជា'''អក្សរដិត''' នៅក្នុង [[Special:RecentChanges|បញ្ជីបំលាស់ប្តូរថ្មីៗ]] ងាយស្រួលក្នុងការស្វែងរក។ ប្រសិនបើលោកអ្នកចង់យកវាចេញពី [[Special:Watchlist|បញ្ជីតាមដាន]]របស់លោកអ្នក សូមចុច '''ឈប់តាមដាន''' នៅលើរបារចំហៀងផ្នែកខាងលើ។",
 'removedwatch'         => 'ត្រូវបានដកចេញពីបញ្ជីតាមដាន',
 'removedwatchtext'     => 'ទំព័រ "[[:$1]]" ត្រូវបានដកចេញពីបញ្ជីតាមដានរបស់លោកអ្នកហើយ ។',
 'watch'                => 'តាមដាន',
@@ -1561,7 +1556,7 @@
 'created'                      => 'បានបង្កើត',
 'enotif_subject'               => 'ទំព័រ $PAGETITLE នៃ {{SITENAME}} ត្រូវបាន $CHANGEDORCREATED ដោយ $PAGEEDITOR',
 'enotif_lastvisited'           => 'ពិនិត្យ $1 ចំពោះគ្រប់បំលាស់ប្តូរ តាំងពីពេលចូលមើល ចុងក្រោយ។',
-'enotif_lastdiff'              => 'ពិនិត្យ $1 ដើម្បីមើលបំលាស់ប្តូរ នេះ។',
+'enotif_lastdiff'              => 'សូមពិនិត្យ$1ដើម្បីមើលបំលាស់ប្តូរនេះ។',
 'enotif_anon_editor'           => 'អ្នកប្រើប្រាស់អនាមិក $1',
 'enotif_body'                  => 'ជូនចំពោះ $WATCHINGUSERNAME ជាទីរាប់អាន,
 
@@ -1787,7 +1782,7 @@
 'autoblocker'                 => 'អ្នកបានត្រូវបានហាមឃាត់ដោយស្វ័យប្រវត្តិ ពីព្រោះអាសយដ្ឋានIPរបស់អ្នកត្រូវបានប្រើប្រាស់ដោយ"[[User:$1|$1]]"។ មូលហេតុលើកឡើងចំពោះការហាមឃាត់$1គឺ៖ "$2"',
 'blocklogpage'                => 'កំនត់ហេតុនៃការហាមឃាត់',
 'blocklogentry'               => 'បានហាមឃាត់[[$1]]​ដោយរយៈពេលផុតកំនត់$2 $3',
-'blocklogtext'                => 'នេះជាកំណត់ហេតុនៃការហាមឃាត់និងឈប់ហាមឃាត់អ្នកប្រើប្រាស់។ អាសយដ្ឋានIPដែលត្រូវបានហាមឃាត់ដោយស្វ័យប្រវត្តិមិនត្រូវបានដាក់ក្នុងបញ្ជីនេះទេ។ សូមមើល[[Special:Ipblocklist|បញ្ជីនៃការហាមឃាត់IP]]ចំពោះបញ្ជីនៃហាមឃាត់នាថ្មីៗ។',
+'blocklogtext'                => 'នេះជាកំណត់ហេតុនៃការហាមឃាត់និងឈប់ហាមឃាត់អ្នកប្រើប្រាស់។ អាសយដ្ឋានIPដែលត្រូវបានហាមឃាត់ដោយស្វ័យប្រវត្តិមិនត្រូវបានដាក់ក្នុងបញ្ជីនេះទេ។ សូមមើល[[Special:IPBlockList|បញ្ជីនៃការហាមឃាត់IP]]ចំពោះបញ្ជីនៃហាមឃាត់នាថ្មីៗ។',
 'unblocklogentry'             => 'បានឈប់ហាមឃាត់ $1',
 'block-log-flags-anononly'    => 'សំរាប់តែ អ្នកប្រើប្រាស់អនាមិក',
 'block-log-flags-nocreate'    => 'ការបង្កើតគណនីត្រូវបានហាមឃាត់',
@@ -1803,15 +1798,15 @@
 # Developer tools
 'lockdb'              => 'ចាក់សោមូលដ្ឋានទិន្នន័យ',
 'unlockdb'            => 'ដោះសោមូលដ្ឋានទិន្នន័យ',
-'lockconfirm'         => 'បាទ/ចាស, ខ្ញុំពិតជាចង់ ចាក់សោ មូលដ្ឋានទិន្នន័យ។',
-'unlockconfirm'       => 'បាទ/ចាស, ខ្ញុំពិតជាចង់ ដោះសោ មូលដ្ឋានទិន្នន័យ។',
+'lockconfirm'         => 'បាទ/ចាស, ខ្ញុំពិតជាចង់ចាក់សោមូលដ្ឋានទិន្នន័យមែន។',
+'unlockconfirm'       => 'បាទ/ចាស, ខ្ញុំពិតជាចង់ដោះសោមូលដ្ឋានទិន្នន័យមែន។',
 'lockbtn'             => 'ចាក់សោមូលដ្ឋានទិន្នន័យ',
 'unlockbtn'           => 'ដោះសោមូលដ្ឋានទិន្នន័យ',
-'locknoconfirm'       => 'អ្នកមិនបាន ឆែកមើល ប្រអប់បញ្ជាក់ទទួលស្គាល់។',
+'locknoconfirm'       => 'អ្នកមិនបានឆែកមើលប្រអប់បញ្ជាក់ទទួលស្គាល់ទេ។',
 'lockdbsuccesssub'    => 'មូលដ្ឋានទិន្នន័យត្រូវបានចាក់សោរដោយជោគជ័យ',
 'unlockdbsuccesssub'  => 'សោ មូលដ្ឋានទិន្នន័យ ត្រូវបានដកចេញ',
 'lockdbsuccesstext'   => 'មូលដ្ឋានទិន្នន័យត្រូវបានចាក់សោ។<br />
-កុំភ្លេច [[Special:Unlockdb|ដោះសោ]] បន្ទាប់ពីបញ្ជប់ការថែទាំរបស់អ្នក។',
+កុំភ្លេច [[Special:UnlockDB|ដោះសោ]] បន្ទាប់ពីបញ្ជប់ការថែទាំរបស់អ្នក។',
 'unlockdbsuccesstext' => 'មូលដ្ឋានទិន្នន័យត្រូវបានដោះសោរួចហើយ។',
 'databasenotlocked'   => 'មូលដ្ឋានទិន្នន័យ មិនត្រូវបានចាក់សោ។',
 
@@ -1834,8 +1829,6 @@
 
 ក្នុងករណី ទាំងនោះ, អ្នកត្រូវតែ ប្តូរឈ្មោះទំព័រ ឬ បញ្ចូលរួមគ្នា ដោយដៃ បើចង់ ។",
 'movearticle'             => 'ប្តូរទីតាំងទំព័រ៖',
-'movenologin'             => 'មិនបានឡុកអ៊ីន',
-'movenologintext'         => 'អ្នកត្រូវតែជាអ្នកប្រើប្រាស់ដែលបានចុះឈ្មោះរួច  ហើយបាន[[Special:Userlogin|ឡុកអ៊ីន]]ដើម្បីប្ដូរទីតាំងទំព័រមួយ។',
 'movenotallowed'          => 'អ្នកគ្មានការអនុញ្ញាតក្នុងការប្តូរទីតាំងទំព័រលើ {{SITENAME}} ទេ។',
 'newtitle'                => 'ទៅចំនងជើងថ្មី៖',
 'move-watch'              => 'តាមដានទំព័រនេះ',
@@ -1860,7 +1853,7 @@
 'revertmove'              => 'ត្រឡប់',
 'delete_and_move'         => 'លុបនិងប្តូរទីតាំង',
 'delete_and_move_text'    => '==ការលុបជាចាំបាច់==
-"[[$1]]"ដែលជាទីតាំងទំព័រត្រូវបញ្ជូនទៅ មានរួចជាស្រេចហើយ។
+"[[:$1]]"ដែលជាទីតាំងទំព័រត្រូវបញ្ជូនទៅ មានរួចជាស្រេចហើយ។
 តើអ្នកចង់លុបវាដើម្បីជាវិធីសំរាប់ប្តូរទីតាំងទេ?',
 'delete_and_move_confirm' => 'បាទ/ចាស, លុបចេញទំព័រ',
 'delete_and_move_reason'  => 'បានលុបដើម្បីផ្លាស់ប្តូរទីតាំង',
@@ -1920,18 +1913,18 @@
 'importlogpage'                    => 'កំនត់ហេតុនៃការនាំចូល',
 'import-logentry-upload'           => 'បាននាំចូល [[$1]] ដោយការផ្ទុកឡើង ឯកសារ',
 'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|កំណែ}}',
-'import-logentry-interwiki'        => 'បាននាំចូល $1 ពីវិគី ផ្សេង',
+'import-logentry-interwiki'        => 'បាននាំចូល$1ពីវិគីផ្សេងទៀត',
 'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|កំណែ}} ពី $2',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'ទំព័រអ្នកប្រើប្រាស់​របស់ខ្ញុំ',
 'tooltip-pt-mytalk'               => 'ទំព័រពិភាក្សា​របស់ខ្ញុំ',
-'tooltip-pt-anontalk'             => 'ការពិភាក្សា អំពីកំណែប្រែ ពី អាស័យដ្ឋាន IP នេះ',
+'tooltip-pt-anontalk'             => 'ការពិភាក្សាអំពីកំណែប្រែពីអាសយដ្ឋានIPនេះ',
 'tooltip-pt-preferences'          => 'ចំនង់ចំនូលចិត្ត',
 'tooltip-pt-watchlist'            => 'បញ្ជី​នៃ​ទំព័រ​ដែលអ្នកកំពុង​ត្រួតពិនិត្យ​រក​បំលាស់ប្តូរ',
 'tooltip-pt-mycontris'            => 'បញ្ជីរួមចំនែក​របស់ខ្ញុំ',
 'tooltip-pt-login'                => 'អ្នកត្រូវបានលើកទឹកចិត្តអោយឡុកអ៊ីន។ ប៉ុន្តែនេះមិនមែនជាការបង្ខំទេ។',
-'tooltip-pt-anonlogin'            => 'អ្នកត្រូវបាន លើកទឹកចិត្ត អោយពិនិត្យចូល, មិនមែនជាការបង្ខំទេ។',
+'tooltip-pt-anonlogin'            => 'អ្នកត្រូវបានលើកទឹកចិត្តអោយឡុកអ៊ីន មិនមែនជាការបង្ខំទេ។',
 'tooltip-pt-logout'               => 'ចាកចេញ',
 'tooltip-ca-talk'                 => 'ការពិភាក្សា​អំពីទំព័រខ្លឹមសារ​នេះ',
 'tooltip-ca-edit'                 => "អ្នកអាច​កែប្រែ​ទំព័រ​នេះ ។ សូមប្រើប្រាស់​ប៊ូតុង 'បង្ហាញការមើលមុន' មុននឹង​រក្សាទុក​វា  ។",
@@ -2048,7 +2041,7 @@
 'show-big-image'       => 'រូបភាពពេញ',
 'show-big-image-thumb' => '<small>ទំហំ​នៃការមើលជាមុននេះ៖ $1 × $2 ភីកសែល</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'វិចិត្រសាលរូបភាពថ្មីៗ',
 'imagelisttext'         => "ខាងក្រោមនេះជាបញ្ជី'''$1'''{{PLURAL:$1|ឯកសារ|ឯកសារ}}បានរៀបតាមលំដាប់$2។",
 'newimages-summary'     => 'ទំព័រពិសេសនេះបង្ហាញឯកសារដែលទើបផ្ទុកឡើង',
@@ -2181,8 +2174,8 @@
 'exif-gpsdirection-m' => 'ខាងជើងម៉ាញេទិក',
 
 # External editor support
-'edit-externally'      => 'កែប្រែ​ឯកសារ​នេះ ដោយប្រើប្រាស់​កម្មវិធី​ខាងក្រៅ',
-'edit-externally-help' => 'សូមមើល [http://meta.wikimedia.org/wiki/Help:External_editors ណែនាំ​ប្រើប្រាស់] សំរាប់​ពត៌មានបន្ថែម ។',
+'edit-externally'      => 'កែប្រែ​ឯកសារ​នេះដោយប្រើប្រាស់​កម្មវិធី​ខាងក្រៅ',
+'edit-externally-help' => 'សូមមើល[http://www.mediawiki.org/wiki/Manual:External_editors ណែនាំ​ប្រើប្រាស់]សំរាប់​ពត៌មានបន្ថែម ។',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ទាំងអស់',
@@ -2231,7 +2224,7 @@
 'recreate'            => 'បង្កើតឡើងវិញ',
 
 # HTML dump
-'redirectingto' => 'កំពុងប្តូរទិស ទៅ [[$1]]...',
+'redirectingto' => 'កំពុងប្តូរទិស ទៅ [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'សំអាតឃ្លាំងសំងាត់(cache)នៃទំព័រនេះ?
@@ -2322,7 +2315,7 @@
 'version-software-product'  => 'ផលិតផល',
 'version-software-version'  => 'កំណែ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'ផ្លូវនៃឯកសារ',
 'filepath-page'    => 'ឯកសារ៖',
 'filepath-submit'  => 'ផ្លូវ',
@@ -2356,8 +2349,9 @@
 'specialpages-group-pagetools'   => 'ឧបករណ៍ទំព័រ',
 'specialpages-group-wiki'        => 'ទិន្នន័យនិងឧបករណ៍វិគី',
 'specialpages-group-redirects'   => 'ទំព័របញ្ជូនបន្តពិសេសៗ',
+'specialpages-group-spam'        => 'ឧបករណ៍ស្ព៊ែម',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage' => 'ទំព័រទទេ',
 
 );
Index: languages/messages/MessagesGrc.php
===================================================================
--- languages/messages/MessagesGrc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGrc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,15 @@
  * @ingroup Language
  * @file
  *
+ * @author AndreasJS
+ * @author Lefcant
  * @author LeighvsOptimvsMaximvs
+ * @author Neachili
+ * @author Nychus
  * @author Omnipaedista
- * @author Lefcant
- * @author AndreasJS
- * @author Nychus
- * @author Neachili
  * @author SPQRobin
- * @author Siebrand
  * @author Yannos
+ * @author ZaDiak
  */
 
 $dateFormats = array(
@@ -36,7 +36,7 @@
 'tog-justify'                 => 'Στοιχίζειν παραγράφους',
 'tog-hideminor'               => 'Κρύπτειν μικρὰς ἐγγραφὰς ἐν προσφάταις ἀλλαγαῖς',
 'tog-extendwatchlist'         => 'Ἐφορώμενα ἐκτείνειν ἵνα ἅπασαι φανῶσιν αἱ ἁρμόδιοι ἀλλαγαὶ',
-'tog-usenewrc'                => 'Προσκεκοσμημέναι πρόσφαται ἀλλαγαί (JavaScript)',
+'tog-usenewrc'                => 'Προσκεκοσμημέναι πρόσφατοι ἀλλαγαί (JavaScript)',
 'tog-numberheadings'          => 'Ἐξαριθμεῖν τίτλους αὐτομάτως',
 'tog-showtoolbar'             => 'Δεικνύναι τὴν τῶν ἐργαλείων ἐπιμελείας μετώπην (JavaScript)',
 'tog-editondblclick'          => 'Δέλτους δὶς θλιβείσας ἐπιμελεῖσθαι (JavaScript)',
@@ -53,17 +53,22 @@
 'tog-previewontop'            => 'Δεικνύναι τὸ προεπισκοπεῖν πρὸ τοῦ κυτίου μεταγραφῆς',
 'tog-previewonfirst'          => 'Τῆς πρώτης μεταγραφῆς, δεικνύναι τὸ προεπισκοπεῖν',
 'tog-nocache'                 => 'Ἀπενεργοποιεῖν τὸ κρύπτειν τὰς δέλτους',
-'tog-enotifwatchlistpages'    => 'Ἄγγειλον μοι ὅταν μία δέλτος ἐν τῇ ἐφορειοδιαλογή μου μεταβάλληται',
+'tog-enotifwatchlistpages'    => 'Ἄγγειλον μοι ὅτε μία δέλτος ἐν τῇ ἐφοροδιαλογή μου μεταβάλλεται',
 'tog-enotifusertalkpages'     => 'Ἄγγειλον μοι ὅταν ἡ δέλτος ὁμιλίας χρήστου μου μεταβάλληται',
 'tog-enotifminoredits'        => 'Ἄγγειλον μοι ἐπἴσης τὰς ἥττονες ἀλλαγὰς δέλτων',
 'tog-enotifrevealaddr'        => 'Ἀποκαλύπτειν τὴν ταχυδρομικὴν μου διεύθυνσιν ἐν τῇ εἰδοποιητηρίᾳ ἀλληλογραφίᾳ',
 'tog-shownumberswatching'     => 'Δεικνύναι ἀριθμὸν παρακολουθούντων χρηστῶν',
 'tog-fancysig'                => 'Ἀκατέργασται ὑπογραφαὶ (ἄνευ αὐτομάτου συνδέσμου)',
+'tog-externaleditor'          => 'Χρῆσθαι ἐξώτερον πρόγραμμα επεξεργασίας κειμένων κατὰ προεπιλογήν (διὰ εἰδικοῦς μόνον· ἀπαραίτητοι εἰδικαὶ ῥυθμίσεις τινες ἐν τῇ υπολογιστικῇ μηχανῇ σου)',
+'tog-externaldiff'            => 'Χρῆσθαι ἐξώτερον λογισμικὸν αντιπαραβολῆς κατὰ προεπιλογήν (διὰ εἰδικοῦς μόνον· ἀπαραίτητοι εἰδικαὶ ῥυθμίσεις τινες ἐν τῇ υπολογιστικῇ μηχανῇ σου)',
 'tog-showjumplinks'           => 'Ἐνεργοποιεῖν τοὺς "ἅλμα πρὸς" συνδέσμους προσβασιμότητος',
-'tog-forceeditsummary'        => 'Προειδοποίησόν με εἰ εἰσάγω κενὴ περίληψιν μεταγραφῆς',
+'tog-uselivepreview'          => 'Χρῆσθαι ἄμεσον προθεώρησιν (JavaScript) (Πειραστικόν)',
+'tog-forceeditsummary'        => 'Προμήνυσόν με εἰ εἰσάγω κενὴ περίληψιν μεταγραφῆς',
 'tog-watchlisthideown'        => 'Οὐ δηλοῦν τὰς ἐμὰς μεταβολὴς ἐν τὰ ἐφορώμενά μου',
-'tog-watchlisthidebots'       => 'Ἀποκρύπτειν τὰς αὐτοματας μεταγραφ ὰς ἐκ τῆς ἐφορειοδιαλογῆς',
+'tog-watchlisthidebots'       => 'Ἀποκρύπτειν τὰς αὐτόματας μεταγραφὰς ἐκ τῆς ἐφοροδιαλογῆς',
 'tog-watchlisthideminor'      => 'Οὐ δηλοῦν τὰς μικρὰς μεταβολὰς ἐν τὰ ἐφορώμενά μου',
+'tog-ccmeonemails'            => "Στεῖλον μοι ἀντίγραφα τῶν ἠλ.-ἐπιστολῶν τῶν ἀπεσταλμένων ὑπ'ἐμοῦ πρὸς ἑτέρους χρήστας",
+'tog-diffonly'                => 'Οὐκ ἐμφανίζειν τὸ τῆς δέλτου περιεχόμενον ὑπὸ τῶν διαφορῶν',
 'tog-showhiddencats'          => 'Κεκρυμμένας κατηγορίας δηλοῦν',
 
 'underline-always'  => 'Ἀεὶ',
@@ -125,14 +130,16 @@
 'dec'           => 'Δεκ',
 
 # Categories related messages
-'pagecategories'           => '{{PLURAL:$1|Γένος|Γένη}}',
+'pagecategories'           => '{{PLURAL:$1|Κατηγορία|Κατηγορίαι}}',
 'category_header'          => 'Χρήματα ἐν γένει "$1"',
-'subcategories'            => 'Ὑπογένη',
+'subcategories'            => 'Ὑποκατηγορίαι',
 'category-media-header'    => 'Μέσα ἐν κατηγορίᾳ "$1"',
+'category-empty'           => "''Ταύτη ἡ κατηγορία οὐ περιλαμβάνει δέλτους τῷ παρόντι.''",
 'hidden-categories'        => '{{PLURAL:$1|Κεκρυμμένη Κατηγορία|Κεκρυμμέναι Κατηγορίαι}}',
 'hidden-category-category' => 'Κεκρυμμέναι κατηγορίαι', # Name of the category where hidden categories will be listed
-'listingcontinuesabbrev'   => 'συμβ.',
+'listingcontinuesabbrev'   => 'συνεχίζεται',
 
+'mainpagetext'      => "<big>'''Ἡ ἐγκατάστασις τῆς MediaWiki ἦν ἐπιτυχής'''</big>",
 'mainpagedocfooter' => "Συμβουλευθήσεσθε τὸ [http://meta.wikimedia.org/wiki/Help:Contents User's Guide] ἵνα πληροφορηθῇτε ἐπὶ τοῦ οὐίκι λογισμικοῦ.
 
 == Ἄρξασθε ==
@@ -141,7 +148,7 @@
 * [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]",
 
 'about'          => 'Περὶ',
-'article'        => 'τὸ χρῆμα',
+'article'        => 'Ἡ ἐγγραφή',
 'newwindow'      => '(ἀνοίξεται ἐν νέᾳ θυρίδι)',
 'cancel'         => 'Ἀκυροῦν',
 'qbfind'         => 'Εὑρίσκειν',
@@ -153,7 +160,7 @@
 'qbspecialpages' => 'Εἰδικαὶ δέλτοι',
 'moredotdotdot'  => 'πλέον...',
 'mypage'         => 'Δέλτος μου',
-'mytalk'         => 'Διάλεκτός μου',
+'mytalk'         => 'Ἡ διάλεξίς μου',
 'anontalk'       => 'Διάλεκτος πρὸ τοῦδε τοῦ IP',
 'navigation'     => 'Πλοήγησις',
 'and'            => 'καί',
@@ -169,10 +176,10 @@
 'searchbutton'      => 'Ζητεῖν',
 'go'                => 'Ἰέναι',
 'searcharticle'     => 'Ἰέναι',
-'history'           => 'Τὰ τῆς δέλτου πρότερα',
-'history_short'     => 'Τὰ πρότερα',
+'history'           => 'Αἱ τῆς δέλτου προτέραι',
+'history_short'     => 'Αἱ προτέραι',
 'info_short'        => 'Μάθησις',
-'printableversion'  => 'Ἐκτυπωτέα μορφὴ',
+'printableversion'  => 'Ἐκτυπωτέα μορφή',
 'permalink'         => 'Σύνδεσμος βέβαιος',
 'print'             => 'Τυποῦν',
 'edit'              => 'Μεταγράφειν',
@@ -183,6 +190,7 @@
 'deletethispage'    => 'Διαγράφειν τήνδε τὴν δέλτον',
 'undelete_short'    => 'Ἐπανορθοῦν {{PLURAL:$1|ἕνα μεταγραφέν|$1 μεταγραφέντα}}',
 'protect'           => 'Φυλλάττειν',
+'protect_change'    => 'ἀλλάττειν προστασίαν',
 'protectthispage'   => 'Tήνδε τὴν δέλτον φυλάττειν',
 'unprotect'         => 'μὴ φυλάττειν',
 'unprotectthispage' => 'Tήνδε τὴν δέλτον  μὴ φυλάττειν',
@@ -195,7 +203,7 @@
 'articlepage'       => 'Χρήματος δέλτον ὁρᾶν',
 'talk'              => 'Διάλεξις',
 'views'             => 'Ποσάκις ἔσκεπται',
-'toolbox'           => 'Σιδηριοκάδος',
+'toolbox'           => 'Ἐργαλειοκάδος',
 'userpage'          => 'Ὁρᾶν δέλτον χρωμένου',
 'projectpage'       => 'Ἰδὲ δέλτον σχεδίου',
 'imagepage'         => 'Ὁρᾶν μέσων δέλτον',
@@ -204,7 +212,7 @@
 'viewhelppage'      => 'Ὁρᾶν βοηθείας δέλτον',
 'categorypage'      => 'Ὁρᾶν γένους δέλτον',
 'viewtalkpage'      => 'Ὁρᾶν διάλεκτον',
-'otherlanguages'    => 'Βαρβαριστὶ',
+'otherlanguages'    => 'Ἀλλογλωσσιστί',
 'redirectedfrom'    => '(Ἀποστελτὸν παρὰ $1)',
 'redirectpagesub'   => 'Ἐπανάγειν δέλτον',
 'lastmodifiedat'    => 'Ἥδε ἡ δέλτος ὕστατον μετεβλήθη $2, $1.', # $1 date, $2 time
@@ -218,6 +226,8 @@
 'aboutpage'            => 'Project:Περί',
 'bugreports'           => 'Ἀναφορὰ πλανῶν',
 'bugreportspage'       => 'Project:Ἀναφορὰ πλανῶν',
+'copyright'            => 'Ἡ διάθεσις τοῦδε περιεχομένου ἐστιν ὑπὸ $1.',
+'copyrightpagename'    => '{{SITENAME}} πνευματικὰ δικαιώματα',
 'copyrightpage'        => '{{ns:project}}:Πνευματικὰ Δικαιώματα',
 'currentevents'        => 'Τὰ γιγνόμενα',
 'currentevents-url'    => 'Project:Τὰ γιγνόμενα',
@@ -230,33 +240,41 @@
 'helppage'             => 'Help:Περιεχόμενα',
 'mainpage'             => 'Κυρία Δέλτος',
 'mainpage-description' => 'Κυρία Δέλτος',
-'policy-url'           => 'Project:Πολιτική',
+'policy-url'           => 'Project:Προαίρεσις',
 'portal'               => 'Πύλη πολιτείας',
-'portal-url'           => 'Project:Πύλη Κοινότητος',
-'privacy'              => 'Ἡ περὶ τῶν ἰδίων προαίρεσις',
+'portal-url'           => 'Project:Πύλη Πολιτείας',
+'privacy'              => 'Ἡ περὶ τῶν ἰδιωτικῶν προαίρεσις',
 'privacypage'          => 'Project:Περὶ τῶν ἰδιωτικῶν',
 
 'badaccess'        => 'Σφάλμα ἀδείας',
 'badaccess-group0' => 'Οὐκ ἔξεστί σοι ταῦτα διαπράττειν.',
 
-'ok'                  => 'εἶεν',
-'retrievedfrom'       => 'ᾑρεθὲν ἀπὸ "$1"',
-'youhavenewmessages'  => 'Ἔχεις $1 ($2).',
-'newmessageslink'     => 'νέαι ἀγγελίαι',
-'newmessagesdifflink' => 'ἐσχάτη μεταβολή',
-'editsection'         => 'μεταγράφειν',
-'editold'             => 'μεταγράφειν',
-'viewsourceold'       => 'ὁρᾶν πηγήν',
-'editsectionhint'     => 'Μεταγράφειν τὸ μέρος: $1',
-'toc'                 => 'Περιεχόμενα',
-'showtoc'             => 'δεικνύναι',
-'hidetoc'             => 'κρύπτειν',
-'viewdeleted'         => 'Ὁρᾶν $1;',
-'feedlinks'           => 'Βοτήρ:',
-'site-rss-feed'       => 'Ἡ τοῦ $1 Ρ.Σ.Σ.-παρασκευή',
-'site-atom-feed'      => 'Ἡ τοῦ $1 Ἀτομο-παρασκευή',
-'page-rss-feed'       => 'Βοτὴρ RSS "$1"',
+'versionrequired' => 'Ἔκδοσις $1 τῆς MediaWiki ἀπαιτεῖται',
 
+'ok'                      => 'εἶεν',
+'retrievedfrom'           => 'ᾑρεθὲν ἀπὸ "$1"',
+'youhavenewmessages'      => 'Ἔχεις $1 ($2).',
+'newmessageslink'         => 'νέαι ἀγγελίαι',
+'newmessagesdifflink'     => 'ἐσχάτη μεταβολή',
+'youhavenewmessagesmulti' => 'Νέας εἰσί σοι ἀγγελίας ἐν $1',
+'editsection'             => 'μεταγράφειν',
+'editold'                 => 'μεταγράφειν',
+'viewsourceold'           => 'ὁρᾶν πηγήν',
+'editsectionhint'         => 'Μεταγράφειν τὸ μέρος: $1',
+'toc'                     => 'Περιεχόμενα',
+'showtoc'                 => 'δεικνύναι',
+'hidetoc'                 => 'κρύπτειν',
+'thisisdeleted'           => 'Ὁρᾶν ἢ ἀποκαθίστασθαι $1;',
+'viewdeleted'             => 'Ὁρᾶν $1;',
+'feedlinks'               => 'Βοτήρ:',
+'feed-invalid'            => 'Ἄκυρος τύπος συνδρομῆς εἰς ῥοὴν δεδομένων.',
+'feed-unavailable'        => 'Αἱ ῥοαὶ οὔκ εἰσι διαθέσιμοι ἐν τῷ {{SITENAME}}',
+'site-rss-feed'           => 'Ἡ τοῦ $1 RSS-παρασκευή',
+'site-atom-feed'          => 'Ἡ τοῦ $1 Ἀτομο-παρασκευή',
+'page-rss-feed'           => 'Βοτὴρ RSS "$1"',
+'page-atom-feed'          => '"$1" Atom Ῥοή',
+'red-link-title'          => '$1 (οὔπω γέγραπται)',
+
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Χρῆμα',
 'nstab-user'      => 'Δέλτος χρωμένου',
@@ -269,73 +287,121 @@
 'nstab-help'      => 'Βοήθεια',
 'nstab-category'  => 'Γένος',
 
+# Main script and global functions
+'nosuchaction'      => 'Οὐδεμία τοιούτη λειτουργία',
+'nosuchspecialpage' => 'Οὐδεμία τοιούτη δέλτος',
+
 # General errors
-'error'           => 'Σφάλμα',
-'databaseerror'   => 'Σφάλμα βάσεως δεδομένων',
-'dberrortext'     => 'Ἓν σφάλμα συντάξεως τῆς πεύσεως βάσεως δεδομένων ἀπήντησεν,
+'error'                => 'Σφάλμα',
+'databaseerror'        => 'Σφάλμα βάσεως δεδομένων',
+'dberrortext'          => 'Ἓν σφάλμα συντάξεως τῆς πεύσεως βάσεως δεδομένων ἀπήντησεν,
 ὅπερ ὑποδηλοῖ τὴν ὕπαρξιν μίας πλάνης ἐν τῷ λογισμικῷ.
 Ἡ ἔσχατη ἀποπειραθεῖσα πεῦσις βάσεως δεδομένων ἦν:
 <blockquote><tt>$1</tt></blockquote>
 ἐξ ἐντὸς τῆς τελέσεως "<tt>$2</tt>".
 Ἡ MySQL ἐπέστρεψεν σφάλμα "<tt>$3: $4</tt>".',
-'readonly'        => 'Βάσις δεδομένων ἀποκεκλεισμένη',
-'filenotfound'    => 'Γραφὴ "$1" οὐχ ηὑρέθη',
-'formerror'       => 'Σφάλμα: οὐ δυναμένη ἡ ὑποβολὴ τοῦ τύπου ἐστίν',
-'badtitle'        => 'Κακὸν τὸ ἐπώνυμον',
-'viewsource'      => 'Πηγήν διασκοπεῖν',
-'viewsourcefor'   => 'Ὑπὲρ τοῦ $1',
-'actionthrottled' => 'Δρᾶσις ἠγχθεῖσα',
-'viewsourcetext'  => 'Ἔξεστί σοὶ ὁρᾶν τε ἀντιγράφειν τὴν τῆς δέλτου πηγὴν:',
-'sqlhidden'       => '(πεῦσις SQL keκρυμμένη)',
+'noconnect'            => 'Συγγνώμην! Τὸ οὐίκι ἔχει τεχνικὰς δυσχέρειας καὶ οὐ δύναται ἐπιμείγνυναι πρὸς τὸ ἐξυπηρετικὸν δεδομένων.<br />
+$1',
+'nodb'                 => 'Ἀδύνατον τὸ ἐπιλέγειν βάσιν δεδομένων $1',
+'readonly'             => 'Βάσις δεδομένων ἀποκεκλεισμένη',
+'missingarticle-rev'   => '(ἀναθεώρησις#: $1)',
+'missingarticle-diff'  => '(Διαφ: $1, $2)',
+'internalerror'        => 'Ἐσώτερον σφάλμα',
+'internalerror_info'   => 'Ἐσώτερον σφάλμα: $1',
+'filecopyerror'        => 'Οὐκ ἦν δυνατὴ ἡ ἀντιγραφὴ τοῦ ἀρχείου "$1" εἰς τὸ "$2".',
+'filerenameerror'      => 'Οὐκ ἦν δυνατὴ ἡ μετωνόμασις τοῦ ἀρχείου "$1" ὡς "$2".',
+'filedeleteerror'      => 'Οὐκ ἦν δυνατὴ ἡ διαγραφὴ τοῦ ἀρχείου "$1".',
+'directorycreateerror' => 'Οὐκ ἦν δυνατὴ ἡ δημιουργία τοῦ ἀρχειοκαταλόγου "$1".',
+'filenotfound'         => 'Γραφὴ "$1" οὐχ ηὑρέθη',
+'fileexistserror'      => 'Οὐκ ἦν δυνατὴ ἡ ἐγγραφὴ εἰς τὸ ἀρχεῖον "$1": τὸ ἀρχεῖον ὑπάρχει',
+'unexpected'           => 'Ἀπροσδόκητος τιμή: "$1"="$2".',
+'formerror'            => 'Σφάλμα: οὐ δυναμένη ἡ ὑποβολὴ τοῦ τύπου ἐστίν',
+'badarticleerror'      => 'Ἡ πρᾶξις οὐκ ἐκτελέσιμος ἦν ἐν τῇδε δέλτῳ.',
+'badtitle'             => 'Κακὸν τὸ ἐπώνυμον',
+'badtitletext'         => 'Ἡ ἐπιγραφὴ τῆς ᾐτουμένης δέλτου ἐστιν ἄκυρος, κενή, ἢ πρόκειται περὶ ἐσφαλμένως συνδεδεμένης ἐπιγραφῆς μεταξὺ διαφόρων οὐίκι· δύναται περιέχειν χαρακτῆρες μὴ χρηστέους ἐν ἐπιγραφαῖς.',
+'wrong_wfQuery_params' => 'Ἐσφαλμέναι παράμετροι εἰς τὸ wfQuery()<br />
+Λειτουργία: $1<br />
+Πεῦσις: $2',
+'viewsource'           => 'Πηγήν διασκοπεῖν',
+'viewsourcefor'        => 'Ὑπὲρ τοῦ $1',
+'actionthrottled'      => 'Δρᾶσις ἠγχθεῖσα',
+'viewsourcetext'       => 'Ἔξεστί σοὶ ὁρᾶν τε ἀντιγράφειν τὴν τῆς δέλτου πηγὴν:',
+'sqlhidden'            => '(πεῦσις SQL κεκρυμμένη)',
 
 # Virus scanner
-'virus-scanfailed' => 'Σάρωσις πταιστή (κῶδιξ $1)',
+'virus-badscanner'     => 'Κακὸς σχηματισμός: ἄγνωτος σαρωτὴς ἰῶν: <i>$1</i>',
+'virus-scanfailed'     => 'Σάρωσις πταιστή (κῶδιξ $1)',
+'virus-unknownscanner' => 'ἄγνωτος ἀντιιός:',
 
 # Login and logout pages
-'logouttitle'             => 'Ἀποσυνδεῖσθαι χρήστου',
-'welcomecreation'         => '== Χαῖρε, $1! ==
+'logouttitle'                => 'Ἀποσυνδεῖσθαι χρήστου',
+'welcomecreation'            => '== Ὡς εὖ παρέστης, $1! ==
 
-Λογισμὸν σὸν πεποίηται. Ἔχε μνήμην μεταβάλλειν τὰς τοῦ {{SITENAME}} αἱρέσεις σου.',
-'loginpagetitle'          => 'Συνδεῖσθαι χρήστου',
-'yourname'                => 'Ὄνομα χρωμένου:',
-'yourpassword'            => 'Σῆμα:',
-'remembermypassword'      => 'Μίμνῃσκε ἐνθάδε τὸ συνδεῖσθαι',
-'yourdomainname'          => 'Ὁ τομεύς σου:',
-'login'                   => 'Συνδεῖσθαι',
-'nav-login-createaccount' => 'Συνδεῖσθαι/λογισμὸν ποιεῖν',
-'userlogin'               => 'Συνδεῖσθαι/λογισμὸν ποιεῖν',
-'logout'                  => 'Ἐξέρχεσθαι',
-'userlogout'              => 'Ἐξέρχεσθαι',
-'notloggedin'             => 'Οὐ συνδεδεμένος',
-'nologin'                 => 'Ἆρα λογισμὸν οὐκ ἔχεις? $1.',
-'nologinlink'             => 'Λογισμὸν ποιεῖν',
-'createaccount'           => 'Λογισμὸν ποιεῖν',
-'gotaccount'              => 'Ἆρα λογισμὸν ἤδη τινὰ ἔχεις; $1.',
-'gotaccountlink'          => 'Συνδεῖσθαι',
-'createaccountmail'       => 'ἠλεκτρονικῇ ἐπιστολῇ',
-'youremail'               => 'Ἠλεκτρονικαὶ ἐπιστολαὶ:',
-'username'                => 'Ὄνομα χρωμένου:',
-'uid'                     => 'Ταυτότης χρήστου:',
-'prefs-memberingroups'    => 'Μέλος {{PLURAL:$1|ομάδoς|ομάδων}}:',
-'yourrealname'            => 'Τὸ ἀληθὲς ὄνομα:',
-'yourlanguage'            => 'Γλῶττά σου:',
-'yournick'                => 'Προσωνυμία:',
-'email'                   => 'ἠλεκτρονική ἐπιστολή',
-'loginerror'              => 'Ἡμάρτηκας περὶ τοῦ συνδεδεκαῖναι',
-'loginsuccesstitle'       => 'Καλῶς συνδέδεσαι',
-'loginsuccess'            => "'''συνδέδεσαι ἤδη τῷ {{SITENAME}} ὡς \"\$1\".'''",
-'nouserspecified'         => 'Ὄνομα χρωμένου καθοριστέον ὑποχρεωτικώς.',
-'wrongpassword'           => 'Εἰσηγμένον σύνθημα ἐσφαλμένον. Πείρασον πάλιν.',
-'wrongpasswordempty'      => 'Σύνθημα οὐκ ἐγράψας.
-Αὖθις πειρῶ.',
-'mailmypassword'          => 'Τὸ σύνθημα ἠλεκτρονικῇ ἐπιστολῇ πέμπειν',
-'passwordremindertitle'   => 'Νέον ἐφήμερον σύνθημα διὰ {{SITENAME}}',
-'loginlanguagelabel'      => 'Γλῶττα: $1',
+Λογισμός σὸς πεποίηται. Ἔχε μνήμην μεταβάλλειν τὰς τοῦ [[Special:Preferences|{{SITENAME}} αἱρέσεις σου]].',
+'loginpagetitle'             => 'Συνδεῖσθαι χρήστου',
+'yourname'                   => 'Ὄνομα χρωμένου:',
+'yourpassword'               => 'Σῆμα:',
+'yourpasswordagain'          => 'Ἀνατυπῶσαι σύνθημα:',
+'remembermypassword'         => 'Μίμνῃσκε ἐνθάδε τὸ συνδεῖσθαι',
+'yourdomainname'             => 'Ὁ τομεύς σου:',
+'login'                      => 'Συνδεῖσθαι',
+'nav-login-createaccount'    => 'Συνδεῖσθαι/λογισμὸν ποιεῖν',
+'loginprompt'                => 'Δεῖ ἐνεργὰ τὰ HTTP-πύσματα εἶναι πρὸ τοῦ συνδεῖσθαι τῷ {{SITENAME}}.',
+'userlogin'                  => 'Συνδεῖσθαι/λογισμὸν ποιεῖν',
+'logout'                     => 'Ἐξέρχεσθαι',
+'userlogout'                 => 'Ἐξέρχεσθαι',
+'notloggedin'                => 'Οὐ συνδεδεμένος',
+'nologin'                    => 'Ἆρα λογισμὸν οὐκ ἔχεις; $1.',
+'nologinlink'                => 'Λογισμὸν ποιεῖν',
+'createaccount'              => 'Λογισμὸν ποιεῖν',
+'gotaccount'                 => 'Ἆρα λογισμὸν ἤδη τινὰ ἔχεις; $1.',
+'gotaccountlink'             => 'Συνδεῖσθαι',
+'createaccountmail'          => 'ἠλεκτρονικῇ ἐπιστολῇ',
+'youremail'                  => 'Ἠλεκτρονικαὶ ἐπιστολαί:',
+'username'                   => 'Ὄνομα χρωμένου:',
+'uid'                        => 'Ταυτότης χρήστου:',
+'prefs-memberingroups'       => 'Μέλος {{PLURAL:$1|ομάδoς|ομάδων}}:',
+'yourrealname'               => 'Τὸ ἀληθὲς ὄνομα:',
+'yourlanguage'               => 'Γλῶττά σου:',
+'yournick'                   => 'Προσωνυμία:',
+'email'                      => 'ἠλεκτρονική ἐπιστολή',
+'prefs-help-realname'        => 'Ἀληθὲς ὄνομα προαιρετικὸν ἐστίν.
+Εἰ εἰσάγεις τὸ ὄνομά σου, ἀναγνωριστέον ἔσται τὸ ἔργον σου.',
+'loginerror'                 => 'Ἡμάρτηκας περὶ τοῦ συνδεδεκαῖναι',
+'prefs-help-email-required'  => 'Διεύθυνσις ἠλ-ταχυδρομείου προαπαιτεῖται.',
+'loginsuccesstitle'          => 'Καλῶς συνδέδεσαι',
+'loginsuccess'               => "'''συνδέδεσαι ἤδη τῷ {{SITENAME}} ὡς \"\$1\".'''",
+'nosuchuser'                 => 'Οὐκ ἐστὶ χρώμενος "$1" ὀνομαστί.
+Σκόπει τὴν τῶν γραμμάτων ἀκρίβειαν ἢ λογισμὸν νέον ποίει.',
+'nosuchusershort'            => 'Οὔκ ἐστι χρήστης ἔχων τὸ ὄνομα "<nowiki>$1</nowiki>".
+Ἔλεγξον τὴν ὀρθογραφίαν σου.',
+'nouserspecified'            => 'Ὄνομα χρωμένου καθοριστέον ὑποχρεωτικώς.',
+'wrongpassword'              => 'Εἰσηγμένον σύνθημα ἐσφαλμένον. Πείρασον πάλιν.',
+'wrongpasswordempty'         => 'Σύνθημα οὐκ ἔγραψας.
+Αὖθις πείρασον.',
+'passwordtooshort'           => 'Τὸ σύνθημά σου ἄκυρον ἢ λίαν βραχὺ ἐστίν.
+Δεῖ αὐτὸ ἔχειν τοὐλάχιστον {{PLURAL:$1|1 χαρακτὴρ|$1 χαρακτῆρες}} καὶ εἶναι διάφορον τοῦ ὀνόματος χρήστου σου.',
+'mailmypassword'             => 'Τὸ σύνθημα ἠλεκτρονικῇ ἐπιστολῇ πέμπειν',
+'passwordremindertitle'      => 'Νέον ἐφήμερον σύνθημα διὰ {{SITENAME}}',
+'passwordremindertext'       => "Τίς (πιθανὼς σύ, μετὰ τῆς IP-διευθύνσεως \$1) ἐζήτησεν τὴν πρὸς σέ ἀποστολὴν νέου συνθήματος διὰ τὸν ἱστότοπον {{SITENAME}} (\$4). Τὸ σύνθημα διὰ τὸν χρήστην \"\$2\" ἐν τῷ παρόντι \"\$3\" ἐστίν. Δεῖ ''νῦν'' συνδεῖσθαι τε καὶ ἀλλάττειν τὸ σύνθημά σου.
 
+Εἰ τὶς ''ἕτερος'' τὴν αἴτησιν ταύτην ὑπέβαλεν ἢ εἰ οὐκ ἀμνηστεῖς τοῦ συνθήματός σου καὶ ''οὐκ'' επιθυμεῖς τὴν ἀλλαγὴν οὗ, δύνασαι ἀγνοῆσαι ταῦτο τὸ μήνυμα καὶ διατηρῆσαι τὸ παλαιὸν σύνθημά σου.",
+'noemail'                    => 'Οὐδεμία ἠλεκτρονικὴ διεύθυνσις ἐγγεγραμένη διὰ τὸν χρώμενον "$1".',
+'passwordsent'               => 'Νέον τι σύνθημα πρὸς τὴν τοῦ χρωμένου "$1" ὀνομαστὶ ἠλεκτρονικὴ διεύθυνσιν προσπέπεπται.
+Τοῦτο δεχόμενος αὖθις συνδεῖσθαι.',
+'eauthentsent'               => 'Μήνυμα τι ἐπαληθεύσεως ἐστάλη τῇ δεδηλωμένῃ ἠλεκτρονικῇ διευθύνσει σου. Πρὸ τῆς περαιτέρω ἀποστολῆς μηνυμάτων τῷ συγκεκριμένῳ λογισμῷ, δεῖ σὺ ἀκολουθῆσαι τὰς ὀδηγίας ἐν τῷ ἀπεσταλμένῳ μηνύματι πρὸς ἐπαλήθευσιν τῆς κυριότητός σου τοῦ συγκεκριμένου λογισμοῦ.',
+'mailerror'                  => 'Σφάλμα κατὰ τὴν ἀποστολὴν τῆσδε ἐπιστολῆς: $1',
+'acct_creation_throttle_hit' => 'Λυπούμεθα· πεποίηκας ἤδη $1 λογισμοῦς.
+Οὐ δύνασαι ἔχειν πλείω τοῦ ἑνός.',
+'emailconfirmlink'           => 'Ἐπιβεβαίωσον τὴν διεύθυνσιν ἠλ-ταχυδρομείου σου',
+'accountcreated'             => 'Λογισμὸς δημιουργηθείς',
+'loginlanguagelabel'         => 'Γλῶσσα: $1',
+
 # Password reset dialog
-'resetpass'        => 'Ἀναδιορισμὸς συνθήματος λογισμοῦ',
-'resetpass_header' => 'Ἀναδιορισμὸς συνθήματος',
-'resetpass_submit' => 'Ἀναδιορισμὸς συνθήματος καὶ σύνδεσις',
+'resetpass'         => 'Ἀναδιορισμὸς συνθήματος λογισμοῦ',
+'resetpass_header'  => 'Ἀναδιορισμὸς συνθήματος',
+'resetpass_submit'  => 'Ἀναδιορισμὸς συνθήματος καὶ σύνδεσις',
+'resetpass_missing' => 'Οὐδὲν δεδομένον τύπου.',
 
 # Edit page toolbar
 'bold_sample'     => 'Γράμματα παχέα',
@@ -365,30 +431,91 @@
 'savearticle'            => 'Γράφειν τὴν δέλτον',
 'preview'                => 'Τὸ προεπισκοπεῖν',
 'showpreview'            => 'Προεπισκοπεῖν',
+'showlivepreview'        => 'Ἄμεσος προθεώρησις',
 'showdiff'               => 'Δεικνύναι τὰς μεταβολάς',
+'anoneditwarning'        => "'''Προσοχή:''' Οὐ συνδεδεμένος εἶ.
+Ἡ IP-διεύθυνσίς σου καταγεγραμμένη ἔσται ἐν τῇδε δέλτου ἱστορίᾳ.",
 'summary-preview'        => 'Πρόβλεψις περιλήψεως',
+'subject-preview'        => 'Ἀντικειμένου/ἐπικεφαλίδος προθεώρησις',
 'blockedtitle'           => 'Ἀποκεκλεισμένος ὁ χρώμενος',
+'blockedtext'            => "<big>'''Τὸ ὄνομα χρήστου σου ἢ ἡ IP-διεύθυνσις σου πεφραγμένα ἐστίν.'''</big>
+
+Ἡ φραγὴ γέγονε ὑπὸ τὸν/τὴν $1.
+Ἡ δεδομένη αἰτιολογία ἐστίν: ''$2''.
+
+* Ἔναρξις φραγῆς: $8
+* Λῆξις φραγῆς: $6
+* Ἡ φραγὴ προορίζεται διὰ τὸν χρήστην: $7
+
+Ἀποτάθητι εἰς τὸν/τὴν $1 ἢ ὅντινα ἕτερον [[{{MediaWiki:Grouppage-sysop}}|γέροντα]] διὰ τὸ διαλέγεσθαι περὶ τῆς φραγῆς. 
+Οὐ δύνασαι χρῆσθαι τὴν δυνατότηταν «αποστολῆς ἠλεκτρονικῆς ἐπιστολῆς τῷδε χρήστη» εἰ οὐ ὁρίσεις μίαν ἔγκυρον ἠλεκτρονικὴν διεύθυνσιν ἐν ταῖς [[Special:Preferences|προκρίσεσί]] σου. 
+Ἡ τρέχουσα IP-διεύθυνσις σου $3 ἐστίν, καὶ ἡ ἀναγνώρισις τῆς φραγῆς #$5 ἐστίν. 
+Παρακαλοῦμεν σε περιλαμβάνειν οἱανδήποτε ἐξ αὐτῶν ἢ καὶ ἀμφοτέρας ἐν ταῖς ἐρωτήσεσί σου.",
+'autoblockedtext'        => "Ἡ IP-διεύθυνσις σου ἐφράγη αὐτομάτως ἐπεὶ κεχρησμένη ἦν ὑπὸ ἑτέρου τινὸς χρήστου, ὅπερ ἀποκεκλεισμένος ἐστὶν ἐκ τοῦ/τῆς $1.
+Ἡ δεδομένη αἰτία ἐστὶν ὡς ἑξῆς:
+
+:''$2''
+
+*Ἔναρξις φραγῆς: $8
+*Λῆξις φραγῆς: $6
+*Προκαθωρισμένος πεφραχθείς: $7
+
+Ἀποτάθητι εἰς τὸν/τὴν $1 ἢ εἰς ἑτέρους τινὲς 
+[[{{MediaWiki:Grouppage-sysop}}|γέροντας]] διὰ τὸ διαλέγεσθαι περὶ τῆς φραγῆς.
+
+Σημείωσον: οὐ δύνασαι χρῆσθαι τὸ γνώρισμα «αποστολῆς ἠλεκτρονικῆς ἐπιστολῆς τῷδε χρήστη» εἰ μὴ ἔχης ἔγκυρον τινὰ διεύθυνσιν ἠλεκτρονικοῦ ταχυδρομείου κατακεχωρημένην ἐν ταῖς [[Special:Preferences|προτιμήσεσι χρήστου]] σου.
+
+Ἡ τρέχουσα IP-διεύθυνσις σου $3 ἐστίν, καὶ ἡ ἀναγνώρισις τῆς φραγῆς #$5 ἐστίν. 
+Παρακαλοῦμεν σε περιλαμβάνειν οἱανδήποτε ἐξ αὐτῶν ἢ καὶ ἀμφοτέρας ἐν ταῖς ἐρωτήσεσί σου.",
+'blockednoreason'        => 'οὐδεμία αἰτία ἐδόθη',
+'nosuchsectiontitle'     => 'Οὐδὲν τοιοῦτον τμῆμα',
 'loginreqtitle'          => 'Δεῖ συνδεῖσθαι',
 'loginreqlink'           => 'συνδεῖσθαι',
+'accmailtitle'           => 'Σύνθημα ἀπεστάλη.',
 'newarticle'             => '(νέα)',
-'userinvalidcssjstitle'  => "'''Προσοχή:''' Οὐκ ὑφίσταται skin \"\$1\". Μέμνησο: οἱ προσηρμοσμέναι δέλτοι .css και .js χρησιμοποιούν ένα ἐπώνυμον ἔχον μικρά γράμματα, π.χ. {{ns:user}}:Foo/monobook.css ἐν ἀντίθεσει πρὸς τὸ {{ns:user}}:Foo/Monobook.css.",
+'newarticletext'         => "Ἀκολούθησας σύνδεμόν τινα πρὸς δέλτον εἰσέτι μὴ ὑπαρκτήν.
+Δύνασαι δημιουργῆσαι τὴν δέλτον, τυπῶν ἐν τῷ κυτίῳ κατωτέρω (ἰδὲ [[{{MediaWiki:Helppage}}|δέλτος βοηθείας]] διά πλείονας πληροφορίας).
+Εἰ ὧδε εἶ κατὰ λάθος, πίεσον τὸ κομβίον τοῦ πλοηγοῦ σου ὀνόματι '''ὀπίσω (back)'''.",
+'noarticletext'          => 'Οὐδὲν ἐν τῇδε τῇ δέλτῳ γεγραμμένον, ἔξεστι σοὶ [[Special:Search/{{PAGENAME}}|δέλτον τινὰ ὧδε ὀνομαστὶ ζῆτειν]] ἢ [{{fullurl:{{FULLPAGENAME}}|action=edit}} τήνδε τὴν δέλτον μεταγράφειν].',
+'userinvalidcssjstitle'  => "'''Προσοχή:''' Οὐκ ὑφίσταται ''skin'' \"\$1\". Μέμνησο: αἱ προσηρμοσμέναι δέλτοι .css καὶ .js χρῶνται ἐπώνυμον τι ἔχον πεζὰ γράμματα, π.χ. {{ns:user}}:Foo/monobook.css ἐν ἀντίθεσει πρὸς τὸν {{ns:user}}:Foo/Monobook.css.",
+'updated'                => '(Ἐνημερωθέν)',
 'note'                   => '<strong>Ἐπισήμανσις:</strong>',
-'editing'                => 'Μεταγράφων $1',
-'editingsection'         => 'Μεταγράφων $1 (μέρος)',
-'yourtext'               => 'Τὰ ὑπό σου γραφόμενα',
+'previewnote'            => '<strong>Ἥδε ἐστὶ προθεώρησις, οὐχὶ καταγραφὴ τῶν μεταβολῶν!</strong>',
+'editing'                => 'Μεταγράφειν $1',
+'editingsection'         => 'Μεταγράφειν $1 (τμῆμα)',
+'editingcomment'         => 'Μεταγράφειν $1 (σχόλιον)',
+'editconflict'           => 'Ἀντιμαχία μεταγραφῶν: $1',
+'yourtext'               => 'Τὰ ὑπὸ ἐσοῦ γραφόμενα',
+'storedversion'          => 'Τεταμιευμένη ἔκδοσις',
 'yourdiff'               => 'Τὰ διαφέροντα',
-'copyrightwarning'       => 'Ὅλαι αἱ συμβολαὶ εἰς τὸ {{SITENAME}} θεωροῦνται ὡς σύμφωναι πρὸς τὴν $2 (βλ. $1 διὰ τὰς ἀκριβεῖας).
-Εἰ οὐκ ἐπιθυμεῖτε τὰ ὑμέτερα κείμενα μεταγράψιμα καὶ διαδόσιμα εἰσὶν ὑπὸ ἄλλων χρωμένων, κατὰ τὴν βούλησίν των, παρακαλοῦμε σας ἵνα μὴ αὐτὰ ἀναρτητε ἐν τούτῳ χώρῳ. Ὅ,τι συνεισφέρετε ἐνθάδε (κείμενα, διαγράμματα, στοιχεῖα ἢ εἰκόνες) δεῖ εἶναι ὑμέτερον ἔργον, ἢ ἀνῆκον τῷ δημοσίῳ τομεῖ, ἢ προερχόμενον ἐξ ἐλευθέρων ἢ ανοικτῶν πηγῶν μετὰ ῥητῆς ἀδείας ἀναδημοσιεύσεως. <br />
+'copyrightwarning'       => 'Ὅλαι αἱ συμβολαὶ εἰς τὸν {{SITENAME}} θεωροῦνται ὡς σύμφωναι πρὸς τὴν $2 (βλ. $1 διὰ τὰς ἀκριβεῖας).
+Εἰ οὐκ ἐπιθυμεῖτε τὰ ὑμέτερα κείμενα μεταγράψιμα καὶ διαδόσιμα εἰσὶν ὑπὸ ἄλλων χρωμένων, κατὰ τὴν βούλησίν των, παρακαλοῦμεν ὑμᾶς ἵνα μὴ αὐτὰ ἀναρτῆτε ἐν τούτῳ χώρῳ. Ὅ,τι συνεισφέρετε ἐνθάδε (κείμενα, διαγράμματα, στοιχεῖα ἢ εἰκόνας) δεῖ εἶναι ὑμέτερον ἔργον, ἢ ἀνῆκον τῷ δημοσίῳ τομεῖ, ἢ προερχόμενον ἐξ ἐλευθέρων ἢ ἀνοικτῶν πηγῶν μετὰ ῥητῆς ἀδείας ἀναδημοσιεύσεως. <br />
 
-Βεβαιοῦτε ἡμᾶς περὶ τῆς πρωτοτυπίας ὅτου ἔργου γραφομένου ὑφ’ ὑμᾶς ἐνθάδε. Βεβαιοῦτε ἡμᾶς ἐπἴσης περὶ τῆς μὴ ἐκχωρήσεως αὐτου εἰς αλλοτρίους πρὸς ὑμᾶς τοῦ δικαιώματος δημοσιεύσεως καὶ ὀνήσεως του, ἥντινα ἔκτασιν αὐτὸν ἔχει.
+Βεβαιοῦτε ἡμᾶς περὶ τῆς πρωτοτυπίας ὅτου ἔργου γραφομένου ὑφ’ ὑμᾶς ἐνθάδε. Βεβαιοῦτε ἡμᾶς ἐπἴσης περὶ τῆς μὴ ἐκχωρήσεως αὐτοῦ εἰς ἀλλοτρίους πρὸς ὑμᾶς τοῦ δικαιώματος δημοσιεύσεως καὶ ὀνήσεως του, ἥντινα ἔκτασιν αὐτὸν ἔχει.
 <br />
-<strong>ΠΑΡΑΚΑΛΟΥΜΕ ΙΝΑ ΜΗ ΑΝΑΡΤΗΤΕ ΚΕΙΜΕΝΑ ΑΛΛΟΤΡΙΩΝ ΕΙ ΜΗ ΕΧΕΤΕ ΤΗΝ ΑΔΕΙΑ ΤΟΥ ΙΔΙΟΚΤΗΤΟΥ ΤΩΝ ΠΝΕΥΜΑΤΙΚΩΝ ΔΙΚΑΙΩΜΑΤΩΝ!</strong>',
+<strong>ΠΑΡΑΚΑΛΟΥΜΕΝ ΙΝΑ ΜΗ ΑΝΑΡΤΗΤΕ ΚΕΙΜΕΝΑ ΑΛΛΟΤΡΙΩΝ ΕΙ ΜΗ ΕΧΕΤΕ ΤΗΝ ΑΔΕΙΑ ΤΟΥ ΙΔΙΟΚΤΗΤΟΥ ΤΩΝ ΠΝΕΥΜΑΤΙΚΩΝ ΔΙΚΑΙΩΜΑΤΩΝ!</strong>',
+'longpagewarning'        => '<strong>ΠΡΟΣΟΧΗ: Ἡδε δέλτος μῆκος $1 χιλιοδυφίων (δυαδικῶν ψηφίων) ἔχει.
+Ἐνδέχεται πλοηγοί τινες προβληματικὼς μεταγράφειν δέλτους προσεγγίζοντας τὰ ἢ μακροτέρας τῶν 32ΧΔ.
+Θεωρήσατε τὸ διασπάσειν τὴν δέλτον εἰς μικρότερα τεμάχια.</strong>',
 'templatesused'          => 'Πρότυπα κεχρησμένα ἐν τοιαύτῃ δελτῳ:',
-'templatesusedpreview'   => 'Πρότυπα κεχρησμένα ἐν ταύτῃ πρόβλεψει:',
+'templatesusedpreview'   => 'Πρότυπα κεχρησμένα ἐν ταύτῃ προθεωρήσει:',
 'template-protected'     => '(φυλλάττεται)',
 'template-semiprotected' => '(ἡμιπεφυλαγμένη)',
+'nocreatetitle'          => 'Δημιουργία δέλτων περιωρισμένη',
+'nocreatetext'           => "{{SITENAME}} οὐκ σ'ἐᾷ νέας δέλτους ποιεῖν.
+Ἐᾷ σε δέλτον ἢδη οὖσαν μεταβάλλειν ἢ [[Special:UserLogin|συνδεῖσθαι ἢ λογισμὸν ποιεῖν]].",
+'permissionserrors'      => 'Σφάλματα ἀδειῶν',
+'recreate-deleted-warn'  => "'''Προσοχή: Ἀναδημιουργεῖς δέλτον πάλαι ποτὲ διαγραφεῖσα.'''
 
+Δεῖ θεωρήσειν εἰ ἁρμοστόν ἐστι τὸ συνεχίζειν μεταγράφειν τήνδε δέλτον.
+Ὁ κατάλογος διαγραφῆς τῆσδε δέλτου διατίθεται ἐνθάδε πρὸς ἐπικουρίαν σου:",
+
+# Account creation failure
+'cantcreateaccounttitle' => 'Μὴ δυνατὴ ἡ ποίησις λογισμοῦ',
+
 # History pages
+'viewpagelogs'        => 'Ὁρᾶν καταλόγους διὰ ταύτην τὴν δέλτον',
+'revnotfound'         => 'Ἀναθεώρησις μὴ εὑρεθεῖσα',
 'currentrev'          => 'Τὸ νῦν',
 'revisionasof'        => 'Τὰ ἐπὶ $1',
 'revision-info'       => 'Τὸ ἐπὶ $1 ὑπὸ $2',
@@ -400,147 +527,294 @@
 'last'                => 'ἡ ὑστάτη',
 'page_first'          => 'πρώτη',
 'page_last'           => 'ἐσχάτη',
+'histlegend'          => 'Σύγκρισις διαφορῶν: Ἐπιλέξατε τὰς συγκριτέας ἐκδοχὰς καὶ πατήσατε enter ἢ τὸ κομβίον  "Σύγκρισις...". <br />
+Ὑπόμνημα: (τρέχον) = διαφοραὶ ὡς πρὸς τὴν τρέχουσαν ἐκδοχήν,
+(ὕστατον) = διαφοραὶ ὡς πρὸς τὴν προηγουμένη ἐκδοχήν, μ = ἀλλαγαὶ μικρῆς κλίμακος.',
+'deletedrev'          => '[διεγράφη]',
 'histfirst'           => 'πρώτη',
 'histlast'            => 'ἐσχάτη',
 'historyempty'        => '(κενόν)',
 
 # Revision feed
+'history-feed-title'          => 'Ἱστορία ἀναθεωρήσεων',
+'history-feed-description'    => 'Ἱστορία ἀναθεωρήσεων τῆσδε δέλτου ἐν τῷ οὐίκι',
 'history-feed-item-nocomment' => '$1 ἐπὶ $2', # user at time
 
 # Revision deletion
-'rev-delundel'      => 'δεικνύναι/κρύπτειν',
-'pagehist'          => 'Ἱστορία δέλτου',
-'revdelete-content' => 'περιεχόμενον',
-'revdelete-uname'   => 'ὄνομα χρήστου',
-'revdelete-hid'     => 'κρύπ $1',
-'revdelete-unhid'   => 'oὐ κρύπ $1',
+'rev-deleted-comment'     => '(σχόλιον ἀφελόμενον)',
+'rev-deleted-user'        => '(ὄνομα χρωμένου ἀφελόμενον)',
+'rev-deleted-event'       => '(δρᾶσις καταλόγου ἀφελομένη)',
+'rev-delundel'            => 'δεικνύναι/κρύπτειν',
+'revisiondelete'          => 'Διαγράφειν/ἐκδιαγράφειν ἀναθεωρήσεις',
+'revdelete-nooldid-title' => 'Ἄκυρος ἀναθεώρησις-στόχος',
+'revdelete-legend'        => 'Θέτειν περιορισμοῦς ὀρατότητος',
+'revdelete-hide-text'     => 'Κρύπτειν κείμενον ἀναθεωρήσεως',
+'revdelete-hide-name'     => 'Κρύπτειν δρᾶσιν τε καὶ στόχον',
+'revdelete-hide-comment'  => 'Κρύπτειν σχόλιον μεταγραφῆς',
+'revdelete-hide-user'     => 'Κρύπτειν μεταγραφέως ὄνομα/IP-διεύθυνσιν',
+'revdelete-hide-image'    => 'Κρύπτειν περιεχόμενον ἀρχείου',
+'revdelete-log'           => 'Σχόλιον καταλόγου:',
+'revdel-restore'          => 'Ἀλλάττειν ὀρατότητα',
+'pagehist'                => 'Ἱστορία δέλτου',
+'deletedhist'             => 'Ἱστορία διεγραμμένη',
+'revdelete-content'       => 'περιεχόμενον',
+'revdelete-summary'       => 'σύνοψις μεταγραφῶν',
+'revdelete-uname'         => 'ὄνομα χρήστου',
+'revdelete-hid'           => 'κρύπ $1',
+'revdelete-unhid'         => 'oὐ κρύπ $1',
 
+# Suppression log
+'suppressionlog' => 'Κατάλογος διαγραφῶν',
+
 # History merging
-'mergehistory' => 'Συγχωνεύειν ἱστορίας δέλτων',
+'mergehistory'        => 'Συγχωνεύειν ἱστορίας δέλτων',
+'mergehistory-box'    => 'Συγχωνεύειν τὰς ἀναθεωρήσεις τῶν δύο δέλτων:',
+'mergehistory-from'   => 'Δέλτος πηγῶν:',
+'mergehistory-into'   => 'Δέλτος προορισμοῦ:',
+'mergehistory-list'   => 'Συγχωνεύσιμος ἱστορία μεταγραφῶν',
+'mergehistory-go'     => 'Δεικνύειν συγχωνεύσιμας μεταγραφάς',
+'mergehistory-submit' => 'Συγχωνεύειν ἀναθεωρήσεις',
 
 # Merge log
 'mergelog'    => 'Τῶν συγχωνεύσεων καταλόγος',
 'revertmerge' => 'Ἀποσυγχωνεύειν',
 
 # Diffs
-'history-title' => 'Τὰ πρότερα περὶ "$1" κατὰ τὸ μεταγράφειν',
-'difference'    => '(Τὰ μεταβεβλημένα)',
-'lineno'        => 'Γραμμή $1·',
-'editundo'      => 'ἀγέννητον τιθέναι',
+'history-title'           => 'Αἱ προτέραι ἐκδόσεις τῆς δέλτου "$1"',
+'difference'              => '(Τὰ μεταβεβλημένα)',
+'lineno'                  => 'Γραμμή $1·',
+'compareselectedversions' => 'Συγκρίνειν τὰς ἐπιλεγμένας δέλτους',
+'editundo'                => 'ἀγέννητον τιθέναι',
+'diff-multi'              => '({{PLURAL:$1|Μία ἐνδιάμεσος ἀναθεώρησις|$1 ἐνδιάμεσοι ἀναθεωρήσεις}} οὐ φαίνονται.)',
 
 # Search results
-'searchresults'            => 'Ἀποτελέσματα ἀναζητήσεως',
-'noexactmatch'             => "'''Οὐκ ἐστὶ δέλτος \"\$1\" ὀνομαστί.'''
+'searchresults'             => 'Ἀποτελέσματα ἀναζητήσεως',
+'noexactmatch'              => "'''Οὐκ ἐστὶ δέλτος \"\$1\" ὀνομαστί.'''
 Ἔξεστι σοὶ [[:\$1|ταύτην ποιεῖν]].",
-'prevn'                    => 'πρότερον $1',
-'nextn'                    => 'τὸ $1 τὸ ἐχόμενον',
-'viewprevnext'             => 'Ἐπισκοπεῖν ($1) ($2) ($3)',
-'search-interwiki-caption' => 'Sister projects
+'prevn'                     => 'πρότερον $1',
+'nextn'                     => 'τὸ $1 τὸ ἐχόμενον',
+'viewprevnext'              => 'Ἐπισκοπεῖν ($1) ($2) ($3)',
+'search-result-size'        => '$1 ({{PLURAL:$2|1 λέξις|$2 λέξεις}})',
+'search-result-score'       => 'Σχετικότης: $1%',
+'search-redirect'           => '(ἀναδιευθύνειν $1)',
+'search-section'            => '(τμῆμα $1)',
+'search-suggest'            => 'Συνίης: $1',
+'search-interwiki-caption'  => 'Sister projects
 Ἀδελφὰ σχέδια',
-'search-interwiki-more'    => '(πλείω)',
-'search-relatedarticle'    => 'Σχετικά',
-'searchrelated'            => 'σχετικά',
-'searchall'                => 'ἅπαντα',
-'powersearch'              => 'Ζητεῖν ἀναλυτικῶς',
-'search-external'          => 'Ἐξωτέρα ἀναζήτησις',
+'search-interwiki-default'  => '$1 ἀποτελέσματα:',
+'search-interwiki-more'     => '(πλείω)',
+'search-mwsuggest-enabled'  => "μεθ'ὑποδείξεων",
+'search-mwsuggest-disabled' => 'οὐκ αἵτινες ὑποδείξεις',
+'search-relatedarticle'     => 'Σχετικά',
+'searchrelated'             => 'σχετικά',
+'searchall'                 => 'ἅπαντα',
+'nonefound'                 => "'''Ἐπισημείωμα''': Μόνον οἵτινες ὀνοματικοὶ χώροι ἀναζητοῦνται κατὰ προεπιλογήν.
+Πείρασον τὸ προθεματίζειν τὴν πεῦσιν σου μετὰ τοῦ ''ὅλα:'' διὰ τὸ ἀναζητεῖν εἰς παντὶ περιεχομένῳ (δέλτων διαλόγου, προτύπων, κ.λ., περιλαμβανομένων), ἢ χρῆσον τὸν ἐπιθυμητὸν ὀνοματικὸν χώρον ὡς πρόθεμα.",
+'powersearch'               => 'Ζητεῖν ἀναλυτικῶς',
+'powersearch-legend'        => 'Ἀνωτέρα ἀναζήτησις',
+'powersearch-ns'            => 'Ζήτησις ἐν τοῖς ὀνοματεἰοις:',
+'powersearch-redir'         => 'Ἀναδιευθύνειν καταλόγου',
+'powersearch-field'         => 'Ἀναζήτησις διά',
+'search-external'           => 'Ἐξωτέρα ἀναζήτησις',
 
 # Preferences page
-'preferences'           => 'Αἱρέσεις',
-'mypreferences'         => 'Αἱρέσεις μου',
-'prefs-edits'           => 'Τοσοῦται αἱ μεταβολαί:',
-'prefsnologin'          => 'Οὐ συνδεδεμένος',
-'qbsettings-none'       => 'Οὐδέν',
-'skin'                  => 'Ἐμφάνισις',
-'math'                  => 'Τὰ μαθηματικά',
-'dateformat'            => 'Μορφοποιία χρονολογίας',
-'datedefault'           => 'Οὐδεμία προτίμησις',
-'datetime'              => 'Χρονολογία καὶ ὥρα',
-'math_unknown_error'    => 'ἄγνωστον σφάλμα',
-'math_unknown_function' => 'ἄγνωστος λειτουργία',
-'math_lexing_error'     => 'σφάλμα λεξικῆς ἀναλύσεως',
-'math_syntax_error'     => 'σφάλμα συντάξεως',
-'prefs-rc'              => 'Αἱ νέαι μεταβολαί',
-'prefs-watchlist'       => 'Τὰ ἐφορώμενα',
-'saveprefs'             => 'Γράφειν',
-'retypenew'             => 'Ἀνατύπωσις νέου συνθήματος:',
-'textboxsize'           => 'Τὸ μεταγράφειν',
-'searchresultshead'     => 'Ζητεῖν',
-'timezonelegend'        => 'Χρονικὴ ζώνη',
-'localtime'             => 'Τοπικὴ ὥρα',
-'timezoneoffset'        => 'Ἐκτόπισμα¹',
-'default'               => 'προκαθωρισμένον',
+'preferences'              => 'Αἱρέσεις',
+'mypreferences'            => 'Αἱ αἱρέσεις μου',
+'prefs-edits'              => 'Τοσοῦται αἱ μεταβολαί:',
+'prefsnologin'             => 'Οὐ συνδεδεμένος',
+'qbsettings'               => 'Ταχεῖα πρόσβασις',
+'qbsettings-none'          => 'Οὐδέν',
+'qbsettings-fixedleft'     => 'Σταθερὰ ἀριστερώς',
+'qbsettings-fixedright'    => 'Σταθερὰ δεξιώς',
+'qbsettings-floatingleft'  => 'Πλανώμενα αριστερώς',
+'qbsettings-floatingright' => 'Πλανώμενα δεξιώς',
+'changepassword'           => 'Ἀλλάττειν σύνθημα',
+'skin'                     => 'Ἐμφάνισις',
+'math'                     => 'Τὰ μαθηματικά',
+'dateformat'               => 'Μορφοποιία χρονολογίας',
+'datedefault'              => 'Οὐδεμία προτίμησις',
+'datetime'                 => 'Χρονολογία καὶ ὥρα',
+'math_failure'             => 'Λεξιανάλυσις ἀποτετυχηκυῖα',
+'math_unknown_error'       => 'ἄγνωστον σφάλμα',
+'math_unknown_function'    => 'ἄγνωστος λειτουργία',
+'math_lexing_error'        => 'σφάλμα λεξικῆς ἀναλύσεως',
+'math_syntax_error'        => 'σφάλμα συντάξεως',
+'prefs-personal'           => 'Στοιχεῖα χρωμένου',
+'prefs-rc'                 => 'Αἱ νέαι μεταβολαί',
+'prefs-watchlist'          => 'Τὰ ἐφορώμενα',
+'prefs-misc'               => 'Διάφορα',
+'saveprefs'                => 'Γράφειν',
+'oldpassword'              => 'Πρότερον σύνθημα:',
+'newpassword'              => 'Νέον σύνθημα:',
+'retypenew'                => 'Ἀνατύπωσις νέου συνθήματος:',
+'textboxsize'              => 'Τὸ μεταγράφειν',
+'rows'                     => 'Σειραί:',
+'columns'                  => 'Στῆλαι:',
+'searchresultshead'        => 'Ζητεῖν',
+'resultsperpage'           => 'Ἀποτελέσματα ἄνα δέλτον:',
+'contextlines'             => 'Σειραὶ ἄνα ἀποτέλεσμα:',
+'timezonelegend'           => 'Χρονικὴ ζώνη',
+'localtime'                => 'Τοπικὴ ὥρα',
+'timezoneoffset'           => 'Ἐκτόπισμα¹',
+'servertime'               => 'Ὥρα ἐξυπηρετικῆς ὑπολογιστικῆς μηχανῆς',
+'prefs-namespaces'         => 'Ὄνοματικὸς χῶρος',
+'defaultns'                => 'Ἀναζήτησις ἐν τοῖσδε ὀνοματικοῖς χώροις κατὰ προεπιλογήν:',
+'default'                  => 'προκαθωρισμένον',
+'files'                    => 'Ἀρχεῖα',
 
+# User rights
+'userrights-lookup-user'   => 'Χειρίζεσθαι ὁμάδας χρωμένου',
+'userrights-user-editname' => 'Εἰσάγειν ἓν ὄνομα χρήστου:',
+'editusergroup'            => 'Μεταγράφειν ὁμάδας χρωμένου',
+'userrights-editusergroup' => 'Μεταγράφειν ὁμάδας χρωμένου',
+'saveusergroups'           => 'Σῴζειν ὁμάδας χρωμένου',
+'userrights-groupsmember'  => 'Μέλος τοῦ:',
+
 # Groups
+'group'            => 'Ὁμάς:',
+'group-user'       => 'Χρώμενοι',
+'group-bot'        => 'Αὐτόματα',
 'group-sysop'      => 'Γέρoντες',
 'group-bureaucrat' => 'Ἔφοροι',
 'group-suppress'   => 'Παροράματα',
+'group-all'        => '(ὅλοι)',
 
 'group-user-member'       => 'Χρήστης',
-'group-bot-member'        => 'Μεταβάλλων μηχανικὸς',
+'group-bot-member'        => 'Μεταβάλλων μηχανικός',
 'group-sysop-member'      => 'Γέρων',
 'group-bureaucrat-member' => 'Ἔφορος',
+'group-suppress-member'   => 'Παρόραμα',
 
 'grouppage-sysop'      => '{{ns:project}}:Γέροντες',
 'grouppage-bureaucrat' => '{{ns:project}}:Ἔφοροι',
 
+# Rights
+'right-read'      => 'Ἀναγιγνώσκειν δέλτους',
+'right-edit'      => 'Μεταγράφειν δέλτους',
+'right-move'      => 'Μετακινεῖν δέλτους',
+'right-upload'    => 'Ἐπιφορτίζειν ἀρχεῖα',
+'right-delete'    => 'Δέλτους σβεννύναι',
+'right-undelete'  => 'Δέλτον ἐπαναφέρειν',
+'right-patrol'    => 'Σημαίνειν τὰς μεταγραφὰς ἑτέρων ὡς φρουρουμένας',
+'right-trackback' => 'Ὀνασύνδεσμον ὑποβάλλειν',
+
 # User rights log
 'rightslog'  => 'Κατάλογος δικαιωμάτων χρωμένων',
 'rightsnone' => '(Οὐδέν)',
 
 # Recent changes
-'nchanges'        => '$1 {{PLURAL:$1|μεταβολή|μεταβολαί}}',
-'recentchanges'   => 'Αἱ νέαι μεταβολαί',
-'rcnote'          => "Κατωτέρω εἰσὶ {{PLURAL:$1|'''1''' ἀλλαγὴ|αἱ τελευταίαι '''$1''' ἀλλαγαὶ}} ἐν {{PLURAL:$2|τῇ τελευταίᾳ ἡμέρᾳ|ταῖς τελευταίαις '''$2''' ἡμέραις}}, ὡς καὶ $5, $4.",
-'rcshowhideminor' => '$1 μικραὶ μεταβολαὶ',
-'rcshowhidebots'  => '$1 αὐτόματα',
-'rcshowhideliu'   => '$1 χρωμένους συνδεδεμένους',
-'rcshowhideanons' => '$1 χρώμενοι ἀνώνυμοι',
-'rcshowhidepatr'  => '$1 Τὰς φυλασσόμενας μεταβολάς',
-'rcshowhidemine'  => '$1 μεταβολὰς μου',
-'diff'            => 'διαφ.',
-'hist'            => 'Προτ.',
-'hide'            => 'Κρύπτειν',
-'show'            => 'Δεικνύναι',
-'minoreditletter' => 'μ',
-'newpageletter'   => 'Ν',
-'boteditletter'   => 'α',
+'nchanges'                       => '$1 {{PLURAL:$1|μεταβολή|μεταβολαί}}',
+'recentchanges'                  => 'Αἱ νέαι μεταβολαί',
+'recentchanges-feed-description' => 'Παρακολουθεῖν τὰς πλείω πρόσφατας ἀλλαγὰς τοῦ οὐίκι ἐν ταύτῃ περιλήψει.',
+'rcnote'                         => "Κατωτέρω εἰσὶ {{PLURAL:$1|'''1''' ἀλλαγὴ|αἱ τελευταίαι '''$1''' ἀλλαγαὶ}} ἐν {{PLURAL:$2|τῇ τελευταίᾳ ἡμέρᾳ|ταῖς τελευταίαις '''$2''' ἡμέραις}}, ὡς καὶ $5, $4.",
+'rcnotefrom'                     => "Ἰδοῦ αἱ ἀλλαγαὶ ἐκ τοῦ '''$2''' (ἕως τὸ '''$1''').",
+'rclistfrom'                     => 'Δεικνύειν νέας ἀλλαγάς. Ἐκκίνησις ἐκ τοῦ $1',
+'rcshowhideminor'                => '$1 μικραὶ μεταβολαὶ',
+'rcshowhidebots'                 => '$1 αὐτόματα',
+'rcshowhideliu'                  => '$1 χρωμένους συνδεδεμένους',
+'rcshowhideanons'                => '$1 χρώμενοι ἀνώνυμοι',
+'rcshowhidepatr'                 => '$1 Τὰς φυλασσόμενας μεταβολάς',
+'rcshowhidemine'                 => '$1 μεταβολὰς μου',
+'rclinks'                        => 'Ἐμφάνισις τῶν τελευταίων $1 ἀλλαγῷν τῷ χρονικῷ διαστήματι τῶν τελευταίων $2 ἡμερῷν <br />$3',
+'diff'                           => 'διαφ.',
+'hist'                           => 'Προτ.',
+'hide'                           => 'Κρύπτειν',
+'show'                           => 'Δεικνύναι',
+'minoreditletter'                => 'μ',
+'newpageletter'                  => 'Ν',
+'boteditletter'                  => 'α',
+'rc_categories_any'              => 'Οἵα δήποτε',
+'newsectionsummary'              => '/* $1 */ νέον τμῆμα',
 
 # Recent changes linked
-'recentchangeslinked'       => 'Οἰκεῖαι μεταβολαί',
-'recentchangeslinked-title' => 'Μεταβολαὶ οἰκεῖαι "$1"',
+'recentchangeslinked'          => 'Οἰκεῖαι μεταβολαί',
+'recentchangeslinked-title'    => 'Μεταβολαὶ οἰκεῖαι "$1"',
+'recentchangeslinked-noresult' => 'Οὐδεμία ἀλλαγὴ τῶν συνδεδεμένων δέλτων ἐν τῇ δεδομένῃ χρονικῇ περιόδῳ.',
+'recentchangeslinked-summary'  => "Ὅδε ἐστὶ κατάλογος τῶν νέων μεταβόλων κατὰ δέλτους συνδεδεμένας σὺν δέλτῳ τινί (ἢ κατὰ τὰς κατηγορίας τινός).
+Δέλτοι ἐν τῷ [[Special:Watchlist|καταλόγῳ ἐφορωμένων]] σου '''ἔντονοι''' εἰσίν.",
+'recentchangeslinked-page'     => 'Ὄνομα δέλτου:',
 
 # Upload
-'upload'            => 'Ἀνάγειν γραφήν',
-'uploadbtn'         => 'Φορτίον ἐντιθέναι',
-'uploadnologin'     => 'Οὐ συνδεδεμένος',
-'uploadlogpage'     => 'Ἐπιφόρτωσις καταλόγου',
-'filedesc'          => 'Τὸ κεφάλαιον',
-'fileuploadsummary' => 'Τὸ κεφάλαιον:',
-'uploadedimage'     => 'ἐπιφορτισμένον "[[$1]]"',
-'watchthisupload'   => 'Ἐφορᾶν τήνδε τὴν δέλτον',
+'upload'             => 'Ἐπιφορτίζειν ἀρχεῖον',
+'uploadbtn'          => 'Φορτίον ἐντιθέναι',
+'reupload'           => 'Ἀναεπιφορτίζειν',
+'uploadnologin'      => 'Οὐ συνδεδεμένος',
+'uploaderror'        => 'Σφάλμα ἐπιφορτίσεως',
+'upload-permitted'   => 'Ἐπιτρεπόμενοι τύποι ἀρχείων: $1.',
+'upload-preferred'   => 'Προκρινόμενοι τύποι ἀρχείων: $1.',
+'upload-prohibited'  => 'Ἀπηγορευμένοι τύποι ἀρχείων: $1.',
+'uploadlog'          => 'ἐπιφορτίζειν κατάλογον',
+'uploadlogpage'      => 'Ἐπιφόρτωσις καταλόγου',
+'filename'           => 'Ὄνομα ἀρχείου',
+'filedesc'           => 'Τὸ κεφάλαιον',
+'fileuploadsummary'  => 'Τὸ κεφάλαιον:',
+'filestatus'         => 'Κατάστασις πνευματικῶν δικαιωμάτων:',
+'filesource'         => 'Πηγή:',
+'uploadedfiles'      => 'Ἀρχεῖα ἐπιπεφορτισμένα',
+'successfulupload'   => 'Ἐπιφόρτισις ἐπιτυχής',
+'uploadwarning'      => 'Προμήνυσις ἐπιφορτώσεως',
+'savefile'           => 'Σῴζειν ἀρχεῖον',
+'uploadedimage'      => 'ἐπιφορτισμένον "[[$1]]"',
+'upload-maxfilesize' => 'Μέγιστον μέγεθος ἀρχείου: $1',
+'watchthisupload'    => 'Ἐφορᾶν τήνδε τὴν δέλτον',
 
-# Special:Imagelist
+'upload-proto-error' => 'Ἐσφαλμένον πρωθυπόμνημα',
+'upload-file-error'  => 'Ἐσώτερον σφάλμα',
+
+'license'   => 'Ἀδειηδότησις:',
+'nolicense' => 'Οὐδὲν ἐπιλεγμένον',
+
+# Special:ImageList
+'imagelist-summary'     => 'Ἡδε εἰδικὴ δέλτος δεικνύει ὅλα τὰ ἐπιφορτισμένα αρχεῖα.
+Κατὰ προεπιλογὴν τὰ υστάτως ἐπιφορισμένα ἀρχεῖα δεινύονται ἐν τῇ κορυφῇ τοῦ καταλόγου.
+Πιέσατε ἐπικεφαλίδα στήλης τινὰ ἵνα ἡ καταλογὴ ἀλλάξηται.',
+'imagelist_search_for'  => 'Ἀναζήτησις τοῦ τῶν μέσων ὀνόματος:',
+'imgfile'               => 'ἀρχεῖον',
 'imagelist'             => 'Κατάλογος πάντων τῶν φορτίων',
+'imagelist_date'        => 'Χρονολογία',
 'imagelist_name'        => 'Ὄνομα',
 'imagelist_user'        => 'Χρώμενος',
 'imagelist_size'        => 'Ὁπόσος',
 'imagelist_description' => 'Διέξοδος',
 
 # Image description page
-'filehist'            => 'Τοῦ ἀρχείου συγγραφή',
-'filehist-current'    => 'Τὸ νῦν',
-'filehist-datetime'   => 'Ἡμέρα/Ὥρα',
-'filehist-user'       => 'Χρώμενος',
-'filehist-dimensions' => 'Τὸ μέγαθος',
-'filehist-filesize'   => 'Μέγεθος',
-'filehist-comment'    => 'Σχόλιον',
-'imagelinks'          => 'Σύνδεσμοι',
-'nolinkstoimage'      => 'Οὐδένα ἐστὶ προσάγον τόδε τὸ φορτίον.',
-'noimage'             => 'Οὐδένα ἐστὶ οὕτως ὀνομαστί, ἔξεστι σοὶ $1.',
-'noimage-linktext'    => 'Ἐντιθέναι',
+'filehist'                       => 'Τοῦ ἀρχείου συγγραφή',
+'filehist-help'                  => 'Πατήσατε ἐπὶ μίας χρονολογίας/ὥρας ἵνα ἴδητε τὸ ἀρχεῖον ὡς ἐμφανισθὲν ἐν ᾗπερ ὥρᾳ ᾗ.',
+'filehist-deleteall'             => 'διαγράφειν ὅλα',
+'filehist-deleteone'             => 'διαγράφειν',
+'filehist-revert'                => 'ἀναστρέφειν',
+'filehist-current'               => 'Τὸ νῦν',
+'filehist-datetime'              => 'Ἡμέρα/Ὥρα',
+'filehist-user'                  => 'Χρώμενος',
+'filehist-dimensions'            => 'Τὸ μέγαθος',
+'filehist-filesize'              => 'Μέγεθος',
+'filehist-comment'               => 'Σχόλιον',
+'imagelinks'                     => 'Σύνδεσμοι',
+'linkstoimage'                   => 'Αἱ ἀκόλουθοι/Ἡ ἀκόλουθος {{PLURAL:$1|δέλτοι σύνδεσμοι|$1 δέλτος σύνδεσμος}} πρὸς ταύτην εἰκόναν {{PLURAL:$1|εἰσίν|$1 ἐστίν}}.',
+'nolinkstoimage'                 => 'Οὐδένα ἐστὶ προσάγον τόδε τὸ φορτίον.',
+'sharedupload'                   => 'Τὸ ἀρχεῖον ταῦτο ἐπιφορτίσθη πρὸς κοινὴν χρῆσιν καὶ δύνασθε χρῆσθαι αὐτὸ εἰς ἕτερα σχέδια καὶ δέλτους ἐξἴσου.',
+'shareduploadduplicate-linktext' => 'ἕτερον ἀρχεῖον',
+'shareduploadconflict-linktext'  => 'ἕτερον ἀρχεῖον',
+'noimage'                        => 'Οὐδένα ἐστὶ οὕτως ὀνομαστί, ἔξεστι σοὶ $1.',
+'noimage-linktext'               => 'Ἐντιθέναι',
+'uploadnewversion-linktext'      => 'Ἐπιφορτίζειν μίαν νέαν ἐκδοχὴν ταύτου τοῦ ἀρχείου',
 
+# File reversion
+'filerevert'         => 'Ἐπαναφέρειν  $1',
+'filerevert-legend'  => 'Ἐπαναφέρειν ἀρχεῖον',
+'filerevert-comment' => 'Σχόλιον:',
+'filerevert-submit'  => 'Ἀναστρέφειν',
+
+# File deletion
+'filedelete'                  => 'Διαγράφειν $1',
+'filedelete-legend'           => 'Διαγράφειν ἀρχεῖον',
+'filedelete-submit'           => 'Διαγράφειν',
+'filedelete-reason-otherlist' => 'Ἑτέρα αἰτία',
+
 # MIME search
 'mimesearch' => 'MIME Ζητεῖν',
+'mimetype'   => 'τύπος MIME:',
+'download'   => 'καταφορτίζειν',
 
 # List redirects
 'listredirects' => 'Κατάλογος ἀναδιευθύνσεων',
@@ -557,8 +831,10 @@
 
 # Statistics
 'statistics' => 'Τὰ περὶ τῶν δεδομένων',
+'userstats'  => 'Χρωμένου στατιστικά',
 
-'disambiguations' => 'Αἱ τινὰ ἱστᾶσαι εἰς τὸ ἀναμφισβήτητον δέλτοι',
+'disambiguations'     => 'Αἱ τινὰ ἱστάναι εἰς τὸ ἀναμφισβήτητον δέλτοι',
+'disambiguationspage' => 'Template:ἐκσαφήνισις',
 
 'doubleredirects' => 'Ἀναδιευθύνσεις διπλασιοζόμεναι',
 
@@ -566,12 +842,14 @@
 'brokenredirects-edit'   => '(μεταγράφειν)',
 'brokenredirects-delete' => '(διαγράφειν)',
 
-'withoutinterwiki' => 'Δέλτοι ἄνευ γλωττικῶν συνδέσμων',
+'withoutinterwiki'        => 'Δέλτοι ἄνευ γλωσσικῶν συνδέσμων',
+'withoutinterwiki-legend' => 'Πρόθεμα',
+'withoutinterwiki-submit' => 'Ἐμφανίζειν',
 
 'fewestrevisions' => 'Δέλτοι ἔχουσαι τὰς ὀλιγωτέρας ἀναθεωρήσεις',
 
 # Miscellaneous special pages
-'nbytes'                  => '$1 {{PLURAL:$1|ψηφιολέξις|ψηφιολέξεις}}',
+'nbytes'                  => '$1 {{PLURAL:$1|δυφιολέξις|δυφιολέξεις}}',
 'ncategories'             => '$1 {{PLURAL:$1|κατηγορία|κατηγορίαι}}',
 'nlinks'                  => '$1 {{PLURAL:$1|σύνδεσμος|σύνδεσμοι}}',
 'nmembers'                => '$1 {{PLURAL:$1|μέλος|μέλη}}',
@@ -579,13 +857,15 @@
 'nviews'                  => '$1 {{PLURAL:$1|βλέψις|βλέψεις}}',
 'lonelypages'             => 'Δέλτοι ὀρφαναί',
 'uncategorizedpages'      => 'Αἱ δέλτοι αἱ οὐκ ἐνοῦσαι γένεσι',
-'uncategorizedcategories' => 'Τὰ γένη τὰ οὐκ ἐνοῦντα γένεσι',
+'uncategorizedcategories' => 'Αἱ κατηγορίαι αἱ μὴ προσήκουσαι κατηγορέσι',
 'uncategorizedimages'     => 'Ἀκατηγοριοποίητα ἀρχεῖα',
 'uncategorizedtemplates'  => 'Ἀκατηγοριοποίητα πρότυπα',
 'unusedcategories'        => 'Ἄχρησται κατηγορίαι',
 'unusedimages'            => 'Ἄχρηστα ἀρχεῖα',
+'popularpages'            => 'Δημοφιλεῖς δέλτοι',
 'wantedcategories'        => 'Αἰτούμεναι κατηγορίαι',
 'wantedpages'             => 'Αἱ δέλτοι οἷας ἱμείρομεν',
+'missingfiles'            => 'Ἀπωλολότα ἀρχεῖα',
 'mostlinked'              => 'Αἱ πλέον προσσυνδεδεμέναι δέλτοι',
 'mostlinkedcategories'    => 'Αἱ πλέον προσσυνδεδεμέναι κατηγορίαι',
 'mostlinkedtemplates'     => 'Τὰ πλέον προσσυνδεδεμένα πρότυπα',
@@ -596,12 +876,15 @@
 'shortpages'              => 'Δέλτοι μικραί',
 'longpages'               => 'Δέλτοι μακραί',
 'deadendpages'            => 'Ἀδιέξοδαι δέλτοι',
-'protectedpages'          => 'Αἱ δέλτοι αἱ φυλαττόμενοι',
+'protectedpages'          => 'Αἱ δέλτοι αἱ φυλαττομέναι',
+'protectedtitles'         => 'Πεφυλαγμέναι ἐπιγραφαί',
 'listusers'               => 'Κατάλογος πάντων τῶν χρωμένων',
 'newpages'                => 'Δέλτοι νέαι',
+'newpages-username'       => 'Ὄνομα χρωμένου:',
 'ancientpages'            => 'Αἱ παλαιόταται δέλτοι',
 'move'                    => 'κινεῖν',
 'movethispage'            => 'Κινεῖν τήνδε τὴν δέλτον',
+'suppress'                => 'Παρόραμα',
 
 # Book sources
 'booksources'    => 'Αἱ ἐν βίβλοις πηγαί',
@@ -612,36 +895,60 @@
 'speciallogtitlelabel' => 'Ὄνομα:',
 'log'                  => 'Κατάλογοι',
 'all-logs-page'        => 'Κατάλογοι ἅπαντες',
+'log-search-legend'    => 'Ἀναζητεῖν καταλόγους',
 'log-search-submit'    => 'Ἰέναι',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Πᾶσαι αἱ δέλτοι',
 'alphaindexline' => '$1 ἕως $2',
 'nextpage'       => 'Ἡ δέλτος ἡ ἐχομένη ($1)',
 'prevpage'       => 'Ἡ δέλτος ἡ προτέρη ($1)',
+'allpagesfrom'   => 'Ἐπιδεικνύειν τὰς δέλτους ἐκ:',
 'allarticles'    => 'Πάντες γραφαί',
+'allpagesprev'   => 'Προηγούμενον',
+'allpagesnext'   => 'Ἐπόμενον',
 'allpagessubmit' => 'Ἰέναι',
+'allpagesprefix' => 'Ἐπιδεικνύειν δέλτους ἔχουσας πρόθεμα:',
 
 # Special:Categories
-'categories' => 'Γένη',
+'categories' => 'Κατηγορίαι',
 
+# Special:ListUsers
+'listusers-submit' => 'Ἐμφανίζειν',
+
+# Special:ListGroupRights
+'listgrouprights'        => 'Δικαιώματα ὁμάδος χρωμένου',
+'listgrouprights-group'  => 'Ὁμάς',
+'listgrouprights-rights' => 'Δικαιώματα',
+
 # E-mail user
-'emailuser'    => 'Ἠλεκτρονικὴν ἐπιστολὴν τῷδε τῷ χρήστῃ πέμπειν',
-'emailmessage' => 'Ἀγγελία',
-'emailsend'    => 'Πέμπειν',
+'emailuser'       => 'Ἠλεκτρονικὴν ἐπιστολὴν τῷδε τῷ χρήστῃ πέμπειν',
+'emailpage'       => 'Χρώμενος ἠλ.-ταχυδρομείου',
+'defemailsubject' => '{{SITENAME}} ἠλ.-ταχυδρομεῖον',
+'emailfrom'       => 'Ἐκ',
+'emailto'         => 'Πρός',
+'emailsubject'    => 'Θέμα',
+'emailmessage'    => 'Ἀγγελία',
+'emailsend'       => 'Πέμπειν',
+'emailsent'       => 'Ἠλ.-ἐπιστολὴ ἀπεστάλη',
 
 # Watchlist
 'watchlist'            => 'Τὰ ἐφορώμενά μου',
 'mywatchlist'          => 'Τὰ ἐφορώμενά μου',
 'watchlistfor'         => "(πρό '''$1''')",
 'watchnologin'         => 'Οὐ συνδεδεμένος',
-'addedwatch'           => 'Δέλτος ἐπῶπται',
+'addedwatch'           => 'Δέλτος προστεθειμένη εἰς τὸν ἐποπτευομένων κατάλογον ἐστίν',
+'addedwatchtext'       => "Ἡ δέλτος \"[[:\$1]]\" προσετέθη εἰς τῷ [[Special:Watchlist|καταλόγῳ ἐφορωμένων]].
+Μελλοντικαὶ ἀλλαγαὶ τῆσδε δέλτου καὶ τῆς σχετικῆς δέλτου διαλόγου καταλεχθήσονται ὧδε, καὶ ἡ δέλτος ἐμφανίσεται '''ἔντονος''' ἐν τῷ [[Special:RecentChanges|καταλόγῳ προσφάτων ἀλλαγων]] οὕτωσι εὐχερέστερός ἐστιν ἡ διάκρισις αὐτῆς.",
 'removedwatch'         => 'Ἀνεώραται ἥδε ἡ δέλτος',
-'removedwatchtext'     => 'Ἀνεώραται ἡ δέλτος "[[:$1]]"',
+'removedwatchtext'     => 'Ἡ δέλτος "[[:$1]]" ἀφῃρέθη ἐκ τοῦ [[Special:Watchlist|καταλόγου ἐφορωμένων σου]].',
 'watch'                => 'Ἐφορᾶν',
 'watchthispage'        => 'Ἐφορᾶν τήνδε τὴν δέλτον',
 'unwatch'              => 'Ἀνεφορᾶν',
+'unwatchthispage'      => 'Παῦσαι τὸ ἐφορᾶν',
 'notanarticle'         => 'οὐ χρῆμα δέλτος',
+'watchlist-details'    => '{{PLURAL:$1|$1 δέλτος|$1 δέλτοι}} ἐφορωμέναι, ἄνευ τῶν δέλτων διαλέξεως περιλαμβανομένων.',
+'wlshowlast'           => 'Ἐμφάνισις τῶν τελευταίων $1 ὡρῶν $2 ἡμερῶν $3',
 'watchlist-hide-bots'  => 'Κρύπτειν τὰς ὑπ᾿ αὐτομάτων μεταβολάς',
 'watchlist-show-own'   => 'Δεικνύναι τοὺς ἐράνους μου',
 'watchlist-hide-own'   => 'Κρύπτειν τὰς ὑπ᾿ ἐμοῦ μεταβολάς',
@@ -649,27 +956,47 @@
 'watchlist-hide-minor' => 'Κρύπτειν τὰς μικρὰς μεταβολάς',
 
 # Displayed when you click the "watch" button and it is in the process of watching
-'watching'   => 'Ἐφορών...',
+'watching'   => 'Ἐφορῶν...',
 'unwatching' => 'Ἀνεφορῶν...',
 
+'enotif_impersonal_salutation' => 'Χρώμενος τοῦ {{SITENAME}}',
+'changed'                      => 'ἀλλαχθέν',
+'created'                      => 'δημιουργηθέν',
+'enotif_anon_editor'           => 'ἀνώνυμος χρώμενος $1',
+
 # Delete/protect/revert
 'deletepage'                  => 'Διαγράφειν τὴν δέλτον',
 'confirm'                     => 'Κυροῦν',
+'excontent'                   => "ἡ ὕλη ἦτο: '$1'",
+'excontentauthor'             => "ἡ ὕλη ἦτο: '$1' (καὶ ὁ μόνος ἐρανίζων ἦτο ὁ '[[Special:Contributions/$2|$2]]')",
 'exblank'                     => 'δέλτος κενὴ ἦν',
+'delete-confirm'              => 'Διαγράφειν "$1"',
+'delete-legend'               => 'Διαγράφειν',
 'historywarning'              => 'Προσοχή: Ἡ δέλτος ἥντινα βούλεσαι διαγράψειν ἔχει ἱστορίαν:',
+'confirmdeletetext'           => 'Πρόκεισαι διαγράψειν ὁριστικὼς ἐκ τῆς βάσεως δεδομένων δέλτον τίνα (ἢ εἰκόνα τινα) μετὰ τῆς ἐῆς ἱστορίας. Παρακαλοῦμεν ἵνα ἐπιβεβαιώσητε τὴν θέλησιν ὑμῶν περὶ τοῦ αὐτὸ πράττειν καὶ περὶ τῆς ἀντιλήψεως τῶν συνεπειῶν, και περὶ τοῦ πράττειν ὑμῶν συμφώνως τῶν [[{{MediaWiki:Policy-url}}|κανόνων]].',
 'actioncomplete'              => 'Τέλειον τὸ ποιούμενον',
+'deletedtext'                 => '"<nowiki>$1</nowiki>" διεγράφηκεν.
+Ἰδὲ $2 διὰ τὸ μητρῷον τῶν προσφάτων διαγραφῶν.',
 'deletedarticle'              => 'Ἐσβέσθη τὴν δέλτον "[[$1]]"',
 'dellogpage'                  => 'Τὰ ἐσβεσένα',
+'deletionlog'                 => 'κατάλογος διαγραφῶν',
 'deletecomment'               => 'Αἰτία τοῦ σβεννύναι:',
 'deleteotherreason'           => 'Αἰτία ἄλλα:',
 'deletereasonotherlist'       => 'Αἰτία ἄλλα',
+'rollback'                    => 'Ἀναστρέφειν μεταγραφάς',
+'rollback_short'              => 'Ἀναστροφή',
 'rollbacklink'                => 'ἀναστροφή',
+'rollbackfailed'              => 'Ἀναστροφὴ μὴ ἐπιτυχής',
 'protectlogpage'              => 'Κατάλογος προφυλάξεων',
 'protectcomment'              => 'Σχόλιον:',
 'protectexpiry'               => 'Ἐξήξει:',
 'protect_expiry_invalid'      => 'Ἄκυρος χρόνος λήξεως.',
 'protect_expiry_old'          => 'Χρόνος λήξεως ἐν τῷ παρελθόντι ἐστίν.',
 'protect-unchain'             => 'Δικαιώματα μετακινήσεως ἐκκλειδοῦν',
+'protect-text'                => 'Ὁρᾶν τε καὶ ἀλλάττειν δύνασθε τὴν κλίμακα προστασίας ἐνθάδε διὰ τὴν δέλτον <strong><nowiki>$1</nowiki></strong>.',
+'protect-locked-access'       => 'Ὁ λογισμός σου οὐκ ἔχει ἄδειαν ἀλλαγῆς τῆς κλίμακος προστασίας δέλτων.
+Ἐνθάδε εἰσὶν αἱ τρέχουσαι ῥυθμίσεις διὰ τὴν δέλτον <strong>$1</strong>:',
+'protect-cascadeon'           => 'Ἡδε δέλτος τῷ παρόντι προστατευμένη ἐστὶν ἐπεὶ περιλαμβάνεται {{PLURAL:$1|τῇ ἀκολούθῳ δέλτῳ, ἥπερ ἔχει|ταῖς ἀκολούθοις δέλτοις, αἵπερ ἔχουσι}} τὴν διαδοχικὴν προστασίαν ἐνεργόν. Δύνασαι ἀλλάττειν τὴν κλίμακα προστασίας  τῆσδε δέλτου, ἄνευ ἐπηρεασμοῦ τῆς διαδοχικὴς προστασίας.',
 'protect-default'             => '(κριτήριον)',
 'protect-fallback'            => 'Δεῖ ἐχεῖν τὴν "$1" οὐσίαν',
 'protect-level-autoconfirmed' => 'Ἀποκλῄειν τοὺς ἀγράφους',
@@ -677,30 +1004,41 @@
 'protect-summary-cascade'     => 'Διαδεχόμενον',
 'protect-expiring'            => 'Ἐξήξει $1 (UTC)',
 'protect-cascade'             => 'Προφυλάττειν δέλτους περικεκλεισμένας ἐν τοιαύτῃ δελτῳ (διαδοχικὴ προφύλαξις)',
+'protect-cantedit'            => 'Οὐ δύνασθε ἀλλάττειν τὴν κλίμακα προστασίας ταύτης τῆς δέλτου, διότι οὐκ ἔχετε τὴν ἀδείαν τοῦ μεταγράφειν αὐτήν.',
 'restriction-type'            => 'Ἐξουσία:',
 'restriction-level'           => 'Κλῖμαξ περιορισμοῦ:',
+'minimum-size'                => 'Ἐλάχιστον μέγεθος',
+'maximum-size'                => 'Μέγιστον μέγεθος:',
+'pagesize'                    => '(δυφία)',
 
 # Restrictions (nouns)
-'restriction-edit' => 'Μεταγράφειν',
-'restriction-move' => 'Kινεῖν',
+'restriction-edit'   => 'Μεταγράφειν',
+'restriction-move'   => 'Kινεῖν',
+'restriction-create' => 'Δημιουργεῖν',
+'restriction-upload' => 'Ἐπιφορτίζειν',
 
 # Restriction levels
 'restriction-level-sysop'         => 'πλήρως διαφυλαττομένη',
 'restriction-level-autoconfirmed' => 'ἡμιδιαφυλαττομένη',
+'restriction-level-all'           => 'οἵα δήποτε κλῖμαξ περιορισμοῦ',
 
 # Undelete
 'viewdeletedpage'        => 'Δεικνύναι διαγραφείσας δέλτους',
 'undeletebtn'            => 'Ἀνορθοῦν',
+'undeletelink'           => 'ἐπανίσταναι',
+'undeletereset'          => 'Ἐπαναθέτειν',
+'undeletecomment'        => 'Σχόλιον:',
+'undeletedarticle'       => 'ἐπανιστάν "[[$1]]"',
 'undelete-search-submit' => 'Ζητεῖν',
 
 # Namespace form on various pages
-'namespace'      => 'Ὀνομεῖον:',
+'namespace'      => 'Ὀνοματεῖον:',
 'invert'         => 'Ἀντιστρέφειν ἐπιλογήν',
 'blanknamespace' => '(Κυρία γραφή)',
 
 # Contributions
 'contributions' => 'Ἔρανοι χρωμένου',
-'mycontris'     => 'Ἔρανοί μου',
+'mycontris'     => 'Οἱ ἔρανοί μου',
 'contribsub2'   => 'Πρὸς $1 ($2)',
 'uctop'         => '(ἄκρον)',
 'month'         => 'Μήν:',
@@ -708,118 +1046,179 @@
 
 'sp-contributions-newbies-sub' => 'Ἔρανοι νέων χρωμένων',
 'sp-contributions-blocklog'    => 'Τὰ ἀποκλῄειν',
+'sp-contributions-username'    => 'IP-διεύθυνσις ἢ ὄνομα χρωμένου:',
 'sp-contributions-submit'      => 'Ζητεῖν',
 
 # What links here
-'whatlinkshere'       => 'Τὰ ἐνθάδε ἄγοντα',
-'whatlinkshere-title' => 'Δέλτοι ἐζεύγμεναι ὑπο $1',
-'linklistsub'         => '(Κατάλογος τῶν συνδέσμων)',
-'linkshere'           => "Τάδε ἄγουσι πρὸς '''[[:$1]]''':",
-'nolinkshere'         => "Οὐδένα ἄγουσι πρὸς '''[[:$1]]'''.",
-'isredirect'          => 'ἀναδιευθύνειν δέλτον',
-'istemplate'          => 'περίκλεισις',
-'whatlinkshere-prev'  => '{{PLURAL:$1|πρότερον|Τὰ $1 πρότερα}}',
-'whatlinkshere-next'  => '{{PLURAL:$1|ἑξῆς|οἱ $1 ἑξαῖ}}',
-'whatlinkshere-links' => '← σύνδεσμοι',
+'whatlinkshere'            => 'Τὰ ἐνθάδε ἄγοντα',
+'whatlinkshere-title'      => 'Δέλτοι ἐζεύγμεναι ὑπὸ "$1"',
+'whatlinkshere-page'       => 'Δέλτος:',
+'linklistsub'              => '(Κατάλογος τῶν συνδέσμων)',
+'linkshere'                => "Τάδε ἄγουσι πρὸς '''[[:$1]]''':",
+'nolinkshere'              => "Οὐδένα ἄγουσι πρὸς '''[[:$1]]'''.",
+'isredirect'               => 'ἀναδιευθύνειν δέλτον',
+'istemplate'               => 'περίκλεισις',
+'isimage'                  => 'σύνδεσμος εἰκόνος',
+'whatlinkshere-prev'       => '{{PLURAL:$1|προτἐρα|Αἱ $1 προτέραι}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|ἑξῆς|οἱ $1 ἑξῆς}}',
+'whatlinkshere-links'      => '← σύνδεσμοι',
+'whatlinkshere-hideredirs' => '$1 ἀναδιευθύνσεις',
+'whatlinkshere-hidelinks'  => '$1 συνδέσμους',
+'whatlinkshere-hideimages' => '$1 συνδέσμους εἰκόνων',
+'whatlinkshere-filters'    => 'Ἠθητήρια',
 
 # Block/unblock
 'blockip'            => 'Ἀποκλῄειν τόνδε τὸν χρώμενον',
+'ipaddress'          => 'IP-Διεύθυνσις:',
+'ipadressorusername' => 'IP-Διεύθυνσις ἢ ὄνομα χρωμένου :',
+'ipbexpiry'          => 'Λῆξις:',
+'ipbreason'          => 'Αἰτία:',
+'ipbreasonotherlist' => 'Ἑτέρα αἰτία',
 'ipboptions'         => 'βʹ ὥραι:2 hours,αʹ ἡμέρα day:1 day,γʹ ἡμέραι:3 days,ζʹ ἡμέραι:1 week,ιδʹ ἡμέραι:2 weeks,αʹ μήν:1 month,γʹ μήνες:3 months,ϝʹ μήνες:6 months,αʹ ἔτος:1 year,ἄπειρον:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'     => 'ἄλλη',
+'ipbotherreason'     => 'Πρόσθετος/ἄλλη αἰτία:',
+'ipblocklist'        => 'Πεφραγμέναι IP-διευθύνσεις καὶ ὀνόματα τῶν χρωμένων',
 'ipblocklist-submit' => 'Ζητεῖν',
 'infiniteblock'      => 'ἄπειρον',
+'anononlyblock'      => 'ἀνωνύμους μόνον',
+'emailblock'         => 'ἠλεκτρονικὸν ταχυδρομεῖον πεφραγμένον',
 'blocklink'          => 'ἀποκλῄειν',
-'unblocklink'        => 'χαλᾶν',
+'unblocklink'        => 'χαλᾶν φραγήν',
 'contribslink'       => 'Ἔρανοι',
 'blocklogpage'       => 'Τὰ ἀποκλῄειν',
 'blocklogentry'      => 'Κεκλῃμένος [[$1]] μέχρι οὗ $2 $3',
 
 # Move page
-'move-page-legend' => 'Κινεῖν τὴν δέλτον',
-'movearticle'      => 'Κινεῖν τὴν δέλτον:',
-'movenologin'      => 'Οὐ συνδεδεμένος',
-'newtitle'         => 'Πρὸς τὸ νέον ὄνομα:',
-'move-watch'       => 'Ἑφορᾶν τήνδε τὴν δέλτον',
-'movepagebtn'      => 'Κινεῖν τὴν δέλτον',
-'pagemovedsub'     => 'Κεκίνηται ἡ δέλτος',
-'movepage-moved'   => '<big>\'\'\'"$1" κεκίνηται πρὸς "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'movedto'          => 'Κεκίνηται πρὸς',
-'movetalk'         => 'Κινεῖν τὸν διάλεκτον',
-'1movedto2'        => '[[$1]] ἐκινήθη πρὸς [[$2]]',
-'movelogpage'      => 'Τὰ κινεῖν',
-'movereason'       => 'Ἀπολογία:',
-'revertmove'       => 'Ἐπανέρχεσθαι',
+'move-page-legend'     => 'Κινεῖν τὴν δέλτον',
+'movepagetext'         => "Χρῆτε τὸν ἀκόλουθον τύπον διὰ τὴν μετωνόμασιν τῆς δέλτου καὶ διὰ τὴν μεταφορὰν ὅλου τοῦ ἑοῦ ἱστορικοῦ ὑπὸ τὸ νέον ὄνομα. 
+Ἡ προηγουμένη ἐπιγραφὴ τῆς δέλτου ἔσται δέλτος τις ἀνακατευθύνσεως. Οἱ τυχόντες σύνδεσμοι πρὸς τὴν προηγουμένην δέλτον ἀναλλοίωτοι ἔσονται. 
+Βεβαιοῦσθε περὶ τῆς μὴ ὑπάρξεως [[Special:DoubleRedirects|διπλῶν]] ἢ [[Special:BrokenRedirects|διεφθαρμένων συνδέσμων]]. 
+Ἀναλαμβάνετε τὴν εὐθύνην τοῦ ἐπιβεβαιῶσαι τὴν ὀρθὴν καὶ ὑποτιθεμένην κατεύθυνσιν τῶν συνδέσμων.
 
+Ἐπισημείωμα: ἡ δέλτος '''οὐ''' κινήσεται εἰ ὑπάρχει ἤδη ἑτέρα δέλτος ὑπὸ τὴν νέαν ἐπιγραφήν, εἰ μὴ ἡ δελτος ταύτη κενή ἐστι '''καὶ οὐκ''' ἔχει ἱστορίαν. Δῆλα δή, ἐν περιπτώσει λάθους ὑμῶν, δύνασθε μετωνομάσειν δέλτον τινά, δίδοντες αὐτῇ τὴν ἑὴν πρότερην ὀνομασίαν, ἀλλὰ οὐ δύνασθε ὑποκαταστήσειν προϋπάρχουσαν δέλτον τινά.
+
+'''ΠΡΟΣΟΧΗ!'''
+Ἡ μετωνόμασις δέλτου τινὸς αἰφνιδία καὶ δραστικὴ ἀλλαγή ἐστιν ὁπηνίκα πρόκειται περὶ δημοφιλοῦς δέλτου· παρακαλοῦμεν ἵνα ἐξετάζητε τὰς πιθανὰς ἐπιπτώσεις ταύτης τῆς ἐνεργείας, πρὸ τῆς ἀποφάσεως ὑμῶν.",
+'movepagetalktext'     => "Ἡ σχετικὴ δέλτος διαλέξεως μετακινήσεται αὐτομάτως μετὰ τῆς δέλτου ἐγγραφῆς '''ἐκτός εἰ οὐ(κ):'''
+*Μετακινήσεις τὴν δέλτον εἰς διάφορον ὀνοματικὸν χῶρον (namespace), ἢ
+*Ὑπάρχει ὑπὸ τὸ νέον ὄνομα μὴ κενὴ δέλτος τις διαλέξεως, ἢ
+*Ἀφῄρηκας τὴν κατασήμανσιν (check) ἐκ του κυτίου κατωτέρω.
+
+Ἐν ταύταις ταῖς περιπτώσεσιν, δεῖ μετακινῆσαι ἢ συγχωνεῦσαι τὴν δέλτον μέσῳ ἀντιγραφῆς-καὶ-ἐπικολήσεως.",
+'movearticle'          => 'Κινεῖν τὴν δέλτον:',
+'newtitle'             => 'Πρὸς τὸ νέον ὄνομα:',
+'move-watch'           => 'Ἑφορᾶν τήνδε τὴν δέλτον',
+'movepagebtn'          => 'Κινεῖν τὴν δέλτον',
+'pagemovedsub'         => 'Κεκίνηται ἡ δέλτος',
+'movepage-moved'       => '<big>\'\'\'"$1" κεκίνηται πρὸς "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'articleexists'        => 'Ἢ ἐστὶ δέλτος τις οὔτως ὀνομαστὶ ἢ ἀπόρρητον τὸ ὄνομα.
+Ἄλλως τὴν δέλτον ὀνόμασον.',
+'talkexists'           => "'''Κεκίνηται μὲν ἡ δέλτος αὐτὴ, ἡ δὲ διαλόγου δέλτος οὐ κεκίνηται ὅτι ἤδη ἐστὶ ἐνθάδε διαλόγου δέλτος.
+Δεῖ σοι καθ'ἕκαστον συγκεραννύναι.'''",
+'movedto'              => 'Κεκίνηται πρὸς',
+'movetalk'             => 'Κινεῖν τὴν διαλόγου δέλτον',
+'1movedto2'            => '[[$1]] ἐκινήθη πρὸς [[$2]]',
+'movelogpage'          => 'Τὰ κινεῖν',
+'movereason'           => 'Ἀπολογία:',
+'revertmove'           => 'Ἐπανέρχεσθαι',
+'delete_and_move_text' => '==Διαγραφὴ ἀπαραίτητος==
+Ἡ ἐγγραφὴ [[:$1]] ὑπάρχει ἤδη. Βούλῃ διαγράψειν τήνδε ἵνα ἐκτελέσηται ἡ μετακίνησις;',
+
 # Export
-'export' => 'Δέλτους ἐξάγειν',
+'export'            => 'Δέλτους ἐξάγειν',
+'export-submit'     => 'Ἐξάγειν',
+'export-addcattext' => 'Προστιθέναι δέλτους ἐκ τῆς κατηγορίας:',
+'export-addcat'     => 'Προστιθέναι',
+'export-download'   => 'Σῴζειν ὡς ἀρχεῖον',
 
 # Namespace 8 related
-'allmessages'     => 'Μυνήματα συστήματος',
-'allmessagesname' => 'Ὄνομα',
+'allmessages'        => 'Μυνήματα συστήματος',
+'allmessagesname'    => 'Ὄνομα',
+'allmessagesdefault' => 'Προεπειλεγμένον κείμενον',
+'allmessagescurrent' => 'Τρέχον κείμενον',
 
 # Thumbnails
 'thumbnail-more'  => 'Αὐξάνειν',
+'filemissing'     => 'Ἀρχεῖον ἐκλιπόν',
 'thumbnail_error' => 'Σφάλμα τοῦ δημιουργεῖν σύνοψιν: $1',
 
 # Special:Import
-'import-upload' => 'Ἐπιφόρτωσις δεδομένων XML',
+'import-interwiki-submit' => 'Εἰσάγειν',
+'import-upload'           => 'Ἐπιφόρτωσις δεδομένων XML',
 
 # Import log
 'importlogpage'             => 'Εἰσάγειν κατάλογον',
 'import-logentry-interwiki' => 'οὐικιπεποιημένη $1',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'       => 'Τὴν δέλτον χρωμένου ἐμήν',
-'tooltip-pt-mytalk'         => 'Διάλεκτός μου',
-'tooltip-pt-preferences'    => 'Αἱρέσεις μου',
-'tooltip-pt-watchlist'      => 'Κατάλογος τῶν ἐφορωμένων μου',
-'tooltip-pt-mycontris'      => 'Κατάλογος τῶν ἔρανων μου',
-'tooltip-pt-login'          => 'Ἐνθαρρυντέον τὸ συνδεῖσθαι, οὐκ υποχρεωτικόν.',
-'tooltip-pt-logout'         => 'Ἐξέρχεσθαι',
-'tooltip-ca-talk'           => 'Διάλεκτος περὶ τῆς δέλτου',
-'tooltip-ca-edit'           => 'Ἔξεστι σοι μεταγράφειν τήνδε τὴν δέλτον. Προεπισκοπεῖν πρὶν ἂν γράφῃς τὴν δέλτον.',
-'tooltip-ca-viewsource'     => 'Σῴζεται ἥδε ἡ δέλτος.
+'tooltip-pt-userpage'             => 'Τὴν δέλτον χρωμένου ἐμήν',
+'tooltip-pt-mytalk'               => 'Ἡ διάλεξίς μου',
+'tooltip-pt-preferences'          => 'Αἱ αἱρέσεις μου',
+'tooltip-pt-watchlist'            => 'Κατάλογος τῶν ἐφορωμένων μου',
+'tooltip-pt-mycontris'            => 'Κατάλογος τῶν ἐράνων μου',
+'tooltip-pt-login'                => 'Ἐνθαρρυντέον τὸ συνδεῖσθαι, οὐκ υποχρεωτικόν.',
+'tooltip-pt-anonlogin'            => 'Ἐνθαρρυντέον τὸ συνδεῖσθαι, οὐκ υποχρεωτικόν.',
+'tooltip-pt-logout'               => 'Ἐξέρχεσθαι',
+'tooltip-ca-talk'                 => 'Διάλεκτος περὶ τῆς δέλτου',
+'tooltip-ca-edit'                 => 'Ἔξεστι σοι μεταγράφειν τήνδε τὴν δέλτον. Προεπισκοπεῖν πρὶν ἂν γράφῃς τὴν δέλτον.',
+'tooltip-ca-addsection'           => 'Προστιθέναι σχόλιόν τι τῇδε τῇ διαλέξει.',
+'tooltip-ca-viewsource'           => 'Σῴζεται ἥδε ἡ δέλτος.
 Ἔξεστι σοὶ τὴν πηγήν ἐπισκοπεῖν.',
-'tooltip-ca-protect'        => 'Ἀμύνειν τῇδε τῇ δέλτῳ',
-'tooltip-ca-delete'         => 'Διαγράφειν τήνδε τὴν δέλτον',
-'tooltip-ca-move'           => 'Κινεῖν τήνδε τὴν δέλτον',
-'tooltip-ca-watch'          => 'Ἐφορᾶν τήνδε τὴν δέλτον',
-'tooltip-ca-unwatch'        => 'Ἀνεφορᾶν τήνδε τὴν δέλτον',
-'tooltip-search'            => 'Ζητεῖν {{SITENAME}}',
-'tooltip-p-logo'            => 'Δέλτος Μεγίστη',
-'tooltip-n-mainpage'        => 'Πορεύεσθαι τὴν κυρίαν Δέλτον',
-'tooltip-n-portal'          => 'Τὰ περὶ ταῦτης τε τὴς ἐνκυκλοπαιδείας, τῶν τε οἷων ἔξεστι σοὶ πράττεις, οὗ παρεστὶ τινά',
-'tooltip-n-currentevents'   => 'Πληροφορίαι διὰ ἐπίκαιρα γεγονότα',
-'tooltip-n-recentchanges'   => 'Κατάλογος κατὰ πᾶσας τὰς νέας μεταβολάς.',
-'tooltip-n-randompage'      => 'Τινὰ γραφὴν χύδην δηλοῦν.',
-'tooltip-n-help'            => 'Μάθησις περὶ τῆσδε Οὐίκεως',
-'tooltip-t-whatlinkshere'   => 'Κατάλογος τῶν ἐνθάδε ἀγόντων',
-'tooltip-t-contributions'   => 'Ὁρᾶν τοὺς τοῦδε τοῦ χρωνένου ἐράνους',
-'tooltip-t-emailuser'       => 'Ἠλεκτρονικὴν ἐπιστολὴν τῷδε τῷ χρήστῃ πέμπειν',
-'tooltip-t-upload'          => 'Φορτία ἐντιθέναι',
-'tooltip-t-specialpages'    => 'Κατάλογος κατὰ πᾶσας τὰς εἰδικὰς δέλτους',
-'tooltip-ca-nstab-main'     => 'χρῆμα δέλτον ὁρᾶν',
-'tooltip-ca-nstab-user'     => 'Δέλτος χρωμένου ὁρᾶν',
-'tooltip-ca-nstab-image'    => 'Ὁρᾶν τὴν τοῦ φορτίου δέλτον',
-'tooltip-ca-nstab-template' => 'Ὁρᾶν πρότυπον',
-'tooltip-ca-nstab-help'     => 'Ὁρᾶν δέλτον βοηθείας',
-'tooltip-ca-nstab-category' => 'Ἐπισκοπεῖν τὴν τῆς κατηγορίας δέλτον',
-'tooltip-minoredit'         => 'Δεικνύναι ἥδε ἡ μεταβολή μικρά εἴναι',
-'tooltip-save'              => 'Γράφειν τὰς μεταβολάς σου',
-'tooltip-diff'              => 'Δείξαι σὰ κατὰ τὰ γεγράμμενα μεταβολά.',
-'tooltip-watch'             => 'Ἐφορᾶν τήνδε τὴν δέλτον',
-'tooltip-upload'            => 'Ἐκκινεῖν ἀναφόρτωσιν',
+'tooltip-ca-protect'              => 'Ἀμύνειν τῇδε τῇ δέλτῳ',
+'tooltip-ca-delete'               => 'Διαγράφειν τήνδε τὴν δέλτον',
+'tooltip-ca-move'                 => 'Κινεῖν τήνδε τὴν δέλτον',
+'tooltip-ca-watch'                => 'Ἐφορᾶν τήνδε τὴν δέλτον',
+'tooltip-ca-unwatch'              => 'Ἀνεφορᾶν τήνδε τὴν δέλτον',
+'tooltip-search'                  => 'Ζητεῖν {{SITENAME}}',
+'tooltip-p-logo'                  => 'Δέλτος Μεγίστη',
+'tooltip-n-mainpage'              => 'Πορεύεσθαι τὴν κυρίαν Δέλτον',
+'tooltip-n-portal'                => 'Τὰ περὶ ταῦτης τε τὴς ἐνκυκλοπαιδείας, τῶν τε οἷων ἔξεστι σοὶ πράττεις, οὗ παρεστὶ τινά',
+'tooltip-n-currentevents'         => 'Πληροφορίαι διὰ ἐπίκαιρα γεγονότα',
+'tooltip-n-recentchanges'         => 'Κατάλογος κατὰ πᾶσας τὰς νέας μεταβολάς.',
+'tooltip-n-randompage'            => 'Τινὰ γραφὴν χύδην δηλοῦν.',
+'tooltip-n-help'                  => 'Μάθησις περὶ τῆσδε Οὐίκεως',
+'tooltip-t-whatlinkshere'         => 'Κατάλογος τῶν ἐνθάδε ἀγόντων',
+'tooltip-feed-rss'                => 'RSS Ῥοὴ διὰ τήνδε δέλτον',
+'tooltip-feed-atom'               => 'Atom Ῥοὴ διὰ τήνδε δέλτον',
+'tooltip-t-contributions'         => 'Ὁρᾶν τοὺς τοῦδε τοῦ χρωμένου ἐράνους',
+'tooltip-t-emailuser'             => 'Ἠλεκτρονικὴν ἐπιστολὴν τῷδε τῷ χρήστῃ πέμπειν',
+'tooltip-t-upload'                => 'Φορτία ἐντιθέναι',
+'tooltip-t-specialpages'          => 'Κατάλογος κατὰ πᾶσας τὰς εἰδικὰς δέλτους',
+'tooltip-ca-nstab-main'           => 'χρῆμα δέλτον ὁρᾶν',
+'tooltip-ca-nstab-user'           => 'Δέλτος χρωμένου ὁρᾶν',
+'tooltip-ca-nstab-project'        => 'Ὁρᾶν τὴν δέλτον τοῦ σχεδίου',
+'tooltip-ca-nstab-image'          => 'Ὁρᾶν τὴν τοῦ φορτίου δέλτον',
+'tooltip-ca-nstab-template'       => 'Ὁρᾶν πρότυπον',
+'tooltip-ca-nstab-help'           => 'Ὁρᾶν δέλτον βοηθείας',
+'tooltip-ca-nstab-category'       => 'Ἐπισκοπεῖν τὴν τῆς κατηγορίας δέλτον',
+'tooltip-minoredit'               => 'Δεικνύναι ἥδε ἡ μεταβολή μικρά εἴναι',
+'tooltip-save'                    => 'Γράφειν τὰς μεταβολάς σου',
+'tooltip-preview'                 => 'Προεπισκοπεῖν τὰς ἀλλαγὰς ὑμῶν. Παρακαλοῦμεν ὑμᾶς ἵνα χρῆτε ταύτην τὴν ἐπιλογὴν πρὸ τοῦ αποθηκεύειν!',
+'tooltip-diff'                    => 'Δεῖξαι τὰς γεγράμμενας μεταβολάς.',
+'tooltip-compareselectedversions' => 'Ὁρᾶν τὰς διαφορὰς μεταξὺ τῶν δύω ἐπιλεγμένων ἐκδοχῶν ταύτης τῆς δέλτου.',
+'tooltip-watch'                   => 'Ἐφορᾶν τήνδε τὴν δέλτον',
+'tooltip-upload'                  => 'Ἐκκινεῖν ἐπιφόρτωσιν',
 
 # Attribution
-'others'      => 'ἄλλοι',
-'creditspage' => 'Διαπιστεύσεις δέλτου',
+'anonymous'        => 'Ἀνώνυμ-ος,-οι χρώμεν-οσ,-οι τοῦ {{SITENAME}}',
+'lastmodifiedatby' => 'Τῆδε δἐλτος ἠλλάχθη ὑστάτως $2, $1 ἐκ τοῦ $3.', # $1 date, $2 time, $3 user
+'others'           => 'ἄλλοι',
+'creditspage'      => 'Διαπιστεύσεις δέλτου',
 
 # Info page
-'numtalkedits' => 'Ἀριθμὸς μεταγραφῶν (δέλτος συζητήσεως): $1',
+'infosubtitle' => 'Πληροφορίαι περὶ τῆς δἐλτου',
+'numtalkedits' => 'Ἀριθμὸς μεταγραφῶν (δέλτος διαλέξεως): $1',
 
+# Math options
+'mw_math_png'    => 'Ἀπόδοσις PNG πάντοτε',
+'mw_math_mathml' => 'MathML εἰ δυνατόν (πειραστικόν)',
+
 # Patrolling
-'markaspatrolleddiff' => 'Σεσημασμένη ὡς ἐπιτηρουμένη',
+'markaspatrolleddiff' => 'Σεσημασμένη ὡς φρουρουμένη',
+'markaspatrolledtext' => 'Σημαίνειν τῆδε δέλτον ὡς φρουρούμενη',
 
 # Patrol log
+'patrol-log-page' => 'Κατάλογος περιπόλων',
 'patrol-log-auto' => '(αὐτόματον)',
 
 # Browsing diffs
@@ -828,14 +1227,16 @@
 
 # Media information
 'file-info-size'       => '($1 × $2 εἰκονοστοιχεῖα, μέγεθος ἀρχείου: $3, τύπος MIME: $4)',
+'file-nohires'         => '<small>Οὐ διατίθεται ὑψηλοτέρα ἀνάλυσις.</small>',
 'svg-long-desc'        => '(αρχεῖον SVG, ὀνομαστικὼς $1 × $2 εἰκονοστοιχεῖα, μέγεθος ἀρχείου: $3)',
 'show-big-image'       => 'Πλήρης ἀνάλυσις',
 'show-big-image-thumb' => '<small>Τοῦδε προεπισκοπεῖν μέγεθος: $1 × $2 εἰκονοστοιχεία</small>',
 
-# Special:Newimages
-'newimages' => 'Τὰ νέα φορτία δεῦρο ἀθροίζει',
-'ilsubmit'  => 'Ζητεῖν',
-'bydate'    => 'κατὰ χρονολογίαν',
+# Special:NewImages
+'newimages'    => 'Τὰ νέα φορτία δεῦρο ἀθροίζειν',
+'showhidebots' => '($1 αὐτόματα)',
+'ilsubmit'     => 'Ζητεῖν',
+'bydate'       => 'κατὰ χρονολογίαν',
 
 # Bad image list
 'bad_image_list' => 'Ἡ μορφοποιία ὡς ἑξῆς ἐστίν:
@@ -846,8 +1247,16 @@
 
 # Metadata
 'metadata'          => 'Μεταδεδομένα',
+'metadata-help'     => 'Τόδε ἀρχεῖον περιέχει προσθέτους πληροφορίας, πιθανὼς προστεθειμένας ἐκ τῆς ψηφιακῆς φωτογραφικῆς μηχανῆς ἢ τοῦ σαρωτοῦ χρησθέντος τῇ δημιουργίᾳ ἢ τῇ ἑῇ ψηφιοποιήσει. Εἰ τὸ ἀρχεῖον ἤλλακται ἐκ τῆς ἑῆς ἀρχικῆς καταστάσεως, ἀκρίβειαί τινες πιθανὼς μὴ πλήρως τὸ ἠλλαγμενον ἀρχεῖον ἀνακλοῦσιν.',
 'metadata-expand'   => 'Δηλοῦν τὰς ἀκριβείας',
 'metadata-collapse' => 'Κρύπτειν τὰς ἀκριβείας',
+'metadata-fields'   => 'Τὰ πεδία μεταδεδομένων EXIF ταύτου τοῦ μηνύματος περιλήψονται ἐν τῇ δέλτῳ ἐμφανίσεως εἰκόνος ὁπηνίκα ὁ πίναξ μεταδεδομένων ἀποκρύψηται. Τὰ ἕτερα πεδία ἔσονται κεκρυμμένα κατὰ προεπιλογήν.
+* make
+* model
+* datetimeoriginal
+* exposuretime
+* fnumber
+* focallength', # Do not translate list items
 
 # EXIF tags
 'exif-imagewidth'          => 'Πλάτος',
@@ -856,44 +1265,169 @@
 'exif-planarconfiguration' => 'Παράταξις δεδομένων',
 'exif-xresolution'         => 'Ὁριζόντιος ἀνάλυσις',
 'exif-yresolution'         => 'Κάθετος ἀνάλυσις',
+'exif-imagedescription'    => 'Ἐπιγραφὴ εἰκόνος',
+'exif-make'                => 'Ἐξεργαστὴς τῆς εἰκονοληπτικῆς μηχανῆς',
+'exif-model'               => 'Πρότυπον τῆς εἰκονοληπτικῆς μηχανῆς',
+'exif-artist'              => 'Πρωτουργός',
+'exif-colorspace'          => 'Χρωματικὸς χῶρος',
+'exif-pixelydimension'     => 'Ἔγκυρον πλάτος εἰκόνος',
+'exif-pixelxdimension'     => 'Ἔγκυρον ὕψος εἰκόνος',
+'exif-makernote'           => 'Ἐπισημειώσεις ἐξεργαστοῦ',
+'exif-relatedsoundfile'    => 'Σχετιζόμενον ἀρχεῖον ἤχου',
 'exif-exposuretime'        => 'Χρόνος ἐκθέσεως',
 'exif-exposuretime-format' => '$1 δευτ. ($2)',
+'exif-fnumber'             => 'F Ἀριθμός',
 'exif-oecf'                => 'Παράγων ὀπτοηλεκτονικῆς μετατροπῆς',
+'exif-aperturevalue'       => 'Ἄνοιξις διαφράγματος',
+'exif-brightnessvalue'     => 'Φωτεινότης',
+'exif-lightsource'         => 'Πηγὴ φωτός',
+'exif-flash'               => 'Ἀστραποβόλον',
+'exif-subjectarea'         => 'Θεματικὸν πεδίον',
 'exif-filesource'          => 'Πηγὴ ἀρχείου',
+'exif-contrast'            => 'Ἀντίθεσις',
+'exif-saturation'          => 'Κορεσμός',
+'exif-sharpness'           => 'Ὀξύτης',
+'exif-gpslatituderef'      => 'Βόρειον ἢ Νότιον γεωγραφικὸν πλάτος',
 'exif-gpslatitude'         => 'Πλάτος γεωγραφικόν',
+'exif-gpslongituderef'     => 'Ἀνατολικὸν ἢ Δυτικὸν γεωγραφικὸν μῆκος',
+'exif-gpslongitude'        => 'Γεωγραφικὸν μῆκος',
 'exif-gpsaltituderef'      => 'Ἀναφορὰ ὕψους γεωγραφικοῦ',
+'exif-gpsaltitude'         => 'Γεωγραφικὸν ὕψος',
+'exif-gpsspeedref'         => 'Μονὰς ταχύτητος',
 'exif-gpsdatestamp'        => 'Χρονολογία GPS',
 
+'exif-unknowndate' => 'Ἄγνωτος χρονολογία',
+
+'exif-orientation-1' => 'Κανονικόν', # 0th row: top; 0th column: left
+'exif-orientation-3' => 'Περιεστραμμένον κατὰ 180°', # 0th row: bottom; 0th column: right
+
 'exif-componentsconfiguration-0' => 'Οὐκ ἔστι',
 
+'exif-exposureprogram-1' => 'Χειροκίνητον',
+'exif-exposureprogram-3' => 'Προτεραιότης ἀνοἰξεως διαφράγματος',
+
 'exif-subjectdistance-value' => '$1 μέτρα',
 
-'exif-meteringmode-5' => 'Ὑπόδειγμα',
-'exif-meteringmode-6' => 'Μερικόν',
+'exif-meteringmode-0'   => 'Ἄγνωτον',
+'exif-meteringmode-1'   => 'Μέσον',
+'exif-meteringmode-5'   => 'Ὑπόδειγμα',
+'exif-meteringmode-6'   => 'Μερικόν',
+'exif-meteringmode-255' => 'Ἄλλη',
 
+'exif-lightsource-0'   => 'Ἄγνωτη',
+'exif-lightsource-2'   => 'Φθορίζον',
+'exif-lightsource-3'   => 'Βαρυλίθιον (πυρακτωσικὸν φῶς)',
+'exif-lightsource-4'   => 'Ἀστραποβόλος συσκευή',
+'exif-lightsource-11'  => 'Σκίασις',
+'exif-lightsource-12'  => 'Ἡμερινοφωτικὴ φθοριοφάνεια (D 5700 – 7100K)',
+'exif-lightsource-13'  => 'Ἡμερινὴ λευκὴ φθοριοφάνεια (N 4600 – 5400K)',
+'exif-lightsource-14'  => 'Ψυχρὴ λευκὴ φθοριοφάνεια (W 3900 – 4500K)',
+'exif-lightsource-15'  => 'Λευκὴ φθοριοφάνεια (WW 3200 – 3700K)',
+'exif-lightsource-17'  => 'Τυπικὸν φῶς A',
+'exif-lightsource-18'  => 'Τυπικὸν φῶς B',
+'exif-lightsource-19'  => 'Τυπικὸν φῶς C',
+'exif-lightsource-24'  => 'Βαρυλίθιον τοῦ ἐργαστηρίου ISO',
+'exif-lightsource-255' => 'Ἑτέραι φωτοπηγαί',
+
+'exif-focalplaneresolutionunit-2' => 'οὐγκιαί',
+
+'exif-sensingmethod-1' => 'Ἀόριστος',
+'exif-sensingmethod-7' => 'Τριγραμμικὸν αἰσθητήριον',
+
+'exif-customrendered-0' => 'Κανονικὴ διαδικασία',
+'exif-customrendered-1' => 'Συνήθης διαδικασία',
+
+'exif-exposuremode-0' => 'Αὐτοέκθεσις',
+'exif-exposuremode-1' => 'Χειροκίνητος ἔκθεσις',
+
+'exif-scenecapturetype-0' => 'Συνήθης',
+'exif-scenecapturetype-1' => 'Τοπίον',
+'exif-scenecapturetype-2' => 'Παράστασις',
+'exif-scenecapturetype-3' => 'Νυκτερινὴ σκηνή',
+
+'exif-gaincontrol-0' => 'Οὐδεμία',
+'exif-gaincontrol-1' => 'Χθαμηλὸν κέρδος ἄνω',
+'exif-gaincontrol-2' => 'Ὑψηλὸν κέρδος ἄνω',
+'exif-gaincontrol-3' => 'Χθαμηλὸν κέρδος κάτω',
+'exif-gaincontrol-4' => 'Ὑψηλὸν κέρδος κάτω',
+
+'exif-contrast-0' => 'Κανονική',
+'exif-contrast-1' => 'Ἁπαλή',
+'exif-contrast-2' => 'Σκληρή',
+
+'exif-saturation-0' => 'Κανονικόν',
+'exif-saturation-1' => 'Χθαμηλὸς κορεσμός',
+'exif-saturation-2' => 'Ὑψηλὸς κορεσμός',
+
+'exif-sharpness-0' => 'Κανονική',
+'exif-sharpness-1' => 'Ἁπαλή',
+'exif-sharpness-2' => 'Σκληρή',
+
+'exif-subjectdistancerange-0' => 'Ἄγνωτη',
+'exif-subjectdistancerange-1' => 'Μακρο.',
+'exif-subjectdistancerange-2' => 'Ἐγγεῖα θέα',
+'exif-subjectdistancerange-3' => 'Ἀφεστηκυῖα θέα',
+
+# Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
+'exif-gpslatitude-n' => 'Βόρειον γεωγραφικὸν πλάτος',
+'exif-gpslatitude-s' => 'Νότιον γεωγραφικὸν πλάτος',
+
+# Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
+'exif-gpslongitude-e' => 'Ἀνατολικὸν γεωγραφικὸν μῆκος',
+'exif-gpslongitude-w' => 'Δυτικὸν γεωγραφικὸν μῆκος',
+
 # Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+'exif-gpsspeed-k' => 'Χιλιόμετρα ἀνὰ ὥρα',
+'exif-gpsspeed-m' => 'Μίλια ἀνὰ ὥρα',
 'exif-gpsspeed-n' => 'Κόμβοι',
 
+# Pseudotags used for GPSTrackRef, GPSImgDirectionRef and GPSDestBearingRef
+'exif-gpsdirection-t' => 'Ἀληθὴς κατεύθυνσις',
+
 # External editor support
-'edit-externally-help' => 'Εἰ πλείοντα βούλει μαθεῖν, [http://meta.wikimedia.org/wiki/Help:External_editors τὰς περὶ τοῦ σχῆματος διδασκαλίας] λέξε.',
+'edit-externally'      => 'Μεταγράφειν ταῦτο τὸ ἀρχεῖον χρωμένοι μίαν ἐξώτερην ἐφαρμογήν.',
+'edit-externally-help' => 'Εἰ πλείοντα βούλει μαθεῖν, [http://www.mediawiki.org/wiki/Manual:External_editors τὰς περὶ τοῦ σχῆματος διδασκαλίας] λέξε.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'Πᾶσαι',
 'imagelistall'     => 'Πᾶσαι',
-'watchlistall2'    => 'Πάντα',
-'namespacesall'    => 'πάντα',
+'watchlistall2'    => 'ἅπαντα',
+'namespacesall'    => 'ἅπαντα',
 'monthsall'        => 'ἅπαντες',
 
+# E-mail address confirmation
+'confirmemail_subject' => '{{SITENAME}} ἐπιβεβαίωσις διευθύνσεως ἠλ.-ταχυδρομείου',
+
+# Scary transclusion
+'scarytranscludefailed'  => '[Τὸ προσκομίζειν τὸ πρότυπον διὰ τὸ $1 ἀπετεύχθη· συγγνώμην]',
+'scarytranscludetoolong' => '[Ὁ URL ὑπὲρ τὸ δέον μακρύς ἐστιν· συγγνώμην]',
+
 # Trackbacks
-'trackbackremove' => ' ([$1 Διαγράφειν])',
+'trackbackbox'      => '<div id="mw_trackbacks">Ὀνασύνδεσμοι διὰ τήνδε ἐγγραφήν:<br />
+$1
+</div>',
+'trackbackremove'   => ' ([$1 Διαγράφειν])',
+'trackbacklink'     => 'Ὀνασύνδεσμος',
+'trackbackdeleteok' => 'Ὀνασύνδεσμος ἐπιτυχὼς διαγραφείς.',
 
+# Delete conflict
+'recreate' => 'Ἀναδημιουργεῖν',
+
 # action=purge
+'confirm_purge'        => 'Καθαίρειν τὴν λανθάνουσαν μνήμην τῆσδε δέλτου;
+
+$1',
 'confirm_purge_button' => 'εἶεν',
 
+# AJAX search
+'hideresults'   => 'Ἀποκρύπτειν ἀποτελέσματα',
+'useajaxsearch' => 'Χρῆσθαι ἀναζήτησιν AJAX',
+
 # Multipage image navigation
 'imgmultipageprev' => '← Δέλτος προτέρα',
 'imgmultipagenext' => 'Δέλτος ἡ ἐχομένη →',
 'imgmultigo'       => 'Ἰέναι!',
+'imgmultigoto'     => 'Μεταβαίνειν εἰς δέλτον $1',
 
 # Table pager
 'ascending_abbrev'         => 'ἀναβ',
@@ -903,6 +1437,7 @@
 'table_pager_first'        => 'Δέλτος πρώτη',
 'table_pager_last'         => 'Δέλτος ἐσχάτη',
 'table_pager_limit_submit' => 'Ἰέναι',
+'table_pager_empty'        => 'Οὐδὲν ἀποτέλεσμα',
 
 # Auto-summaries
 'autosumm-new' => 'Δέλτος νέα: $1',
@@ -914,30 +1449,64 @@
 'size-gigabytes' => '$1 ΓΔ',
 
 # Live preview
-'livepreview-loading' => 'Φορτεῖν…',
+'livepreview-loading' => 'Φορτίζειν…',
+'livepreview-ready'   => 'Φορτίζειν… Ἕτοιμον!',
 
 # Watchlist editor
-'watchlistedit-raw-titles' => 'Ἐπιγραφαί:',
+'watchlistedit-normal-title'  => 'Μεταγράφειν κατάλογον ἐφορωμένων',
+'watchlistedit-normal-submit' => 'Ἀφαιρεῖν ἐπιγραφάς',
+'watchlistedit-raw-title'     => 'Μεταγράφειν πρωταρχικὸν κατάλογον ἐφορωμένων',
+'watchlistedit-raw-legend'    => 'Μεταγράφειν πρωταρχικὸν κατάλογον ἐφορωμένων',
+'watchlistedit-raw-titles'    => 'Ἐπιγραφαί:',
+'watchlistedit-raw-submit'    => 'Ἐκσυγχρονίζειν τὸν κατάλογον ἐφορωμένων',
 
 # Watchlist editing tools
 'watchlisttools-view' => 'Ὁρᾶν τὰς πρὸς ταῦτα μεταβολὰς',
-'watchlisttools-edit' => 'Ὁρᾶν τε μεταγράφειν τὰ ἐφορωμένα',
+'watchlisttools-edit' => 'Ὁρᾶν τε καὶ μεταγράφειν τὰ ἐφορωμένα',
+'watchlisttools-raw'  => 'Μεταγράφειν τὸν πρωτογενῆ κατάλογον ἐφορωμένων',
 
 # Special:Version
-'version'              => 'Ἐπανόρθωμα', # Not used as normal message but as header for the special page itself
-'version-specialpages' => 'Εἰδικαὶ δέλτοι',
-'version-other'        => 'Ἄλλα',
+'version'                   => 'Ἐπανόρθωμα', # Not used as normal message but as header for the special page itself
+'version-extensions'        => 'Ἐγκατεστημέναι ἐπεκτάσεις',
+'version-specialpages'      => 'Εἰδικαὶ δέλτοι',
+'version-parserhooks'       => 'Ἐπεκτάσεις λεξιαναλυτικοῦ προγράμματος',
+'version-variables'         => 'Μεταβληταί',
+'version-other'             => 'Ἄλλα',
+'version-mediahandlers'     => 'Χειρισταὶ μέσων',
+'version-hooks'             => 'Ἀγγύλαι',
+'version-hook-name'         => 'Ὄνομα ἀγκύλης',
+'version-hook-subscribedby' => 'Προγεγραφὼς ἀπὸ',
+'version-version'           => 'Ἐκδοχή',
+'version-license'           => 'Ἄδεια',
+'version-software'          => 'Ἐγκατεστημένον λογισμικόν',
+'version-software-product'  => 'Προϊόν',
+'version-software-version'  => 'Ἐκδοχή',
 
-# Special:Filepath
-'filepath-page' => 'Ἀρχεῖον:',
+# Special:FilePath
+'filepath'        => 'Διαδρομὴ ἀρχείου',
+'filepath-page'   => 'Ἀρχεῖον:',
+'filepath-submit' => 'Διαδρομή',
 
+# Special:FileDuplicateSearch
+'fileduplicatesearch-filename' => 'Ὄνομα ἀρχείου:',
+'fileduplicatesearch-submit'   => 'Ἀναζήτησις',
+
 # Special:SpecialPages
-'specialpages'               => 'Εἰδικαὶ δέλτοι',
-'specialpages-group-highuse' => 'Ὑψηλῆς χρήσεως δέλτοι',
-'specialpages-group-pages'   => 'Κατάλογος δέλτων',
-'specialpages-group-wiki'    => 'Οὐκιδεδομένα καὶ στοιχεῖα',
+'specialpages'                   => 'Εἰδικαὶ δέλτοι',
+'specialpages-group-maintenance' => 'Ἀναφοραὶ συντηρήσεως',
+'specialpages-group-other'       => 'Ἕτεραι εἰδικαὶ δέλτοι',
+'specialpages-group-login'       => 'Συνδεῖσθαι / ἐγγράφεσθαι',
+'specialpages-group-changes'     => 'Πρόσφατοι ἀλλαγαὶ καὶ κατάλογοι',
+'specialpages-group-media'       => 'Ἀναφοραὶ μέσων καὶ ἐπιφορτίσεις',
+'specialpages-group-users'       => 'Χρώμενοι καὶ δικαιώματα',
+'specialpages-group-highuse'     => 'Ὑψηλῆς χρήσεως δέλτοι',
+'specialpages-group-pages'       => 'Κατάλογος δέλτων',
+'specialpages-group-pagetools'   => 'Ἐργαλεῖα δέλτου',
+'specialpages-group-wiki'        => 'Οὐικιδεδομένα καὶ στοιχεῖα',
+'specialpages-group-redirects'   => 'Ἀναδιευθύνειν εἰδικὰς δέλτους',
+'specialpages-group-spam'        => 'Ἐργαλεῖα κατὰ τῶν ἀνεπιθυμήτων διαγγελιῶν',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Κενὴ δέλτος',
 'intentionallyblankpage' => 'Ταῦτη ἡ δέλτος ἀφίεται ἐσκεμμένως κενὴ καὶ ἐστὶ χρήσιμη ὡς σημεῖον ἀναφορᾶς, κτλ.',
 
Index: languages/messages/MessagesGv.php
===================================================================
--- languages/messages/MessagesGv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Alison
  * @author MacTire02
- * @author Siebrand
  * @author Shimmin Beg
- * @author Alison
  */
 
 $messages = array(
@@ -220,23 +219,23 @@
 'viewsourcetext'     => 'Foddee oo jeeagh er as jean aascreeuyn bun y ghuillag shoh:',
 
 # Login and logout pages
-'logouttitle'                => 'Claare magh yn ymmydeyr',
-'loginpagetitle'             => 'Claare stiagh yn ymmydeyr',
+'logouttitle'                => 'Log magh yn ymmydeyr',
+'loginpagetitle'             => 'Log stiagh yn ymmydeyr',
 'yourname'                   => "Dt'ennym ymmydeyr",
 'yourpassword'               => 'Fockle yn arrey:',
 'yourpasswordagain'          => "Aascreeu d'ockle arrey:",
 'remembermypassword'         => "Cooinnee m'ockle arrey",
-'login'                      => 'Claare stiagh',
-'nav-login-createaccount'    => 'Claare stiagh / croo coontys',
-'userlogin'                  => 'Claare stiagh / croo coontys',
-'logout'                     => 'Claare magh',
-'userlogout'                 => 'Claare magh',
-'notloggedin'                => 'Cha nel ou claarit stiagh',
-'nologin'                    => 'Nagh vel claare stiagh ayd? $1.',
+'login'                      => 'Log stiagh',
+'nav-login-createaccount'    => 'Log stiagh / croo coontys',
+'userlogin'                  => 'Log stiagh / croo coontys',
+'logout'                     => 'Log magh',
+'userlogout'                 => 'Log magh',
+'notloggedin'                => 'Cha nel ou loggit stiagh',
+'nologin'                    => 'Nagh vel log stiagh ayd? $1.',
 'nologinlink'                => 'Croo coontys',
 'createaccount'              => 'Croo coontys',
 'gotaccount'                 => 'Vel coontys ayd hannah? $1.',
-'gotaccountlink'             => 'Claare stiagh',
+'gotaccountlink'             => 'Log stiagh',
 'createaccountmail'          => 'er post-L',
 'youremail'                  => 'Post-L:',
 'username'                   => "Dt'ennym ymmydeyr:",
@@ -244,16 +243,17 @@
 'yourlanguage'               => 'Çhengey:',
 'yournick'                   => 'Far-ennym:',
 'email'                      => 'Post-L',
-'loginerror'                 => 'Marranys claare stiagh',
-'loginsuccesstitle'          => "T'ou claarit stiagh",
-'loginsuccess'               => "'''T'ou claarit stiagh ayns {{SITENAME}} myr \"\$1\".'''",
+'loginerror'                 => 'Marranys log stiagh',
+'loginsuccesstitle'          => "T'ou loggalt stiagh",
+'loginsuccess'               => "'''T'ou loggit stiagh ayns {{SITENAME}} myr \"\$1\".'''",
 'nosuchuser'                 => 'Cha nel ymmydeyr lesh yn ennym "$1".
 Cur streean er dty lettraghey, ny croo coontys noa.',
 'nosuchusershort'            => 'Cha nel ymmydeyr lesh yn ennym "<nowiki>$1</nowiki>".
 Cur streean er dty lettraghey.',
 'nouserspecified'            => 'Shegin dhyt ennym ymmydeyr y honraghey.',
 'wrongpassword'              => 'Va fockle arrey neuchiart screeuit. Screeu eh reesht eh.',
-'wrongpasswordempty'         => "Va'n fockle arrey screeuit bane. Aascreeu, my sailliu.",
+'wrongpasswordempty'         => "Va'n fockle arrey screeuit bane.
+Aascreeu, my sailliu.",
 'mailmypassword'             => "Cur dou m'ockle arrey er post-L",
 'passwordremindertitle'      => 'Fockle arrey noa shallidagh gys {{SITENAME}}',
 'acct_creation_throttle_hit' => 'Gow my leshtal, ta $1 coontysyn crooit ayd.
@@ -296,7 +296,7 @@
 'showpreview'            => 'Roie-haishbynys y haishbyney',
 'showlivepreview'        => 'Roie-haishbynys bio',
 'showdiff'               => 'Caghlaaghyn y haishbyney',
-'anoneditwarning'        => "'''Raaue:''' Cha nel ou claarit stiagh.
+'anoneditwarning'        => "'''Raaue:''' Cha nel ou loggit stiagh.
 Bee dt'enmys IP recortyssit ayns shennaghys reaghey yn duillag shoh.",
 'missingcommenttext'     => 'Taggloo er heese, my sailt.',
 'summary-preview'        => 'Roie-haishbynys y ghiare-choontey',
@@ -314,8 +314,7 @@
 Cha nod oo jannoo ymmyd jeh'n cummey 'cur post-L da'n ymmydeyr shoh' mannagh vel eh sonrit ayns dty [[Special:Preferences|choontys tosheeaghtyn]] as mannagh vel ou glasst magh.<br />
 She $3 dt'enmys IP troa, as she dt'enney ghlass ny #$5. Cur ad lesh dagh ooilley eysht.",
 'blockednoreason'        => 'cha nel fa currit',
-'whitelistacctitle'      => 'Cha nel kied ayd coontys y chroo',
-'loginreqlink'           => 'Claare stiagh',
+'loginreqlink'           => 'Log stiagh',
 'loginreqpagetext'       => 'Shegin dhyt $1 dys jeeagh er duillagyn elley.',
 'accmailtitle'           => 'Fockle yn arrey currit.',
 'accmailtext'            => 'Ta fockle yn arrey da "$1" currit dy $2.',
@@ -411,7 +410,7 @@
 # Preferences page
 'preferences'          => 'Tosheeaghtyn',
 'mypreferences'        => 'My hosheeaghtyn',
-'prefsnologin'         => 'Cha nel ou claarit stiagh',
+'prefsnologin'         => 'Cha nel oo loggit stiagh',
 'qbsettings-none'      => 'Veg',
 'changepassword'       => 'Fockle yn arrey y cheaghley',
 'skin'                 => 'Crackan',
@@ -477,7 +476,7 @@
 'rclistfrom'      => "Taishbyney caghlaaghyn s'noa veih $1",
 'rcshowhideminor' => '$1 myn-arraghyn',
 'rcshowhidebots'  => '$1 robotyn',
-'rcshowhideliu'   => '$1 ymmydeyryn ta claarit stiagh',
+'rcshowhideliu'   => '$1 ymmydeyryn ta loggit stiagh',
 'rcshowhideanons' => '$1 ymmydeyryn neuenmyssit',
 'rcshowhidepatr'  => '$1 arraghyn patrolaghit',
 'rcshowhidemine'  => "$1 m'arraghyn",
@@ -496,20 +495,20 @@
 'recentchangeslinked-page'  => 'Ennym y duillag:',
 
 # Upload
-'upload'            => 'Cur neese coadan',
-'uploadbtn'         => 'Cur neese coadan',
-'reupload'          => 'Aachur neese',
-'uploadnologin'     => 'Cha nel ou claarit stiagh',
+'upload'            => 'Laadey neese coadan',
+'uploadbtn'         => 'Laadey neese coadan',
+'reupload'          => 'Aalaadey neese',
+'uploadnologin'     => 'Cha nel oo loggit stiagh',
 'filename'          => 'Ennym y choadan',
 'filedesc'          => 'Giare-choontey',
 'fileuploadsummary' => 'Giare-choontey:',
 'filestatus'        => 'Stayd choip-chiart:',
 'filesource'        => 'Bun:',
-'uploadedfiles'     => 'Coadanyn ta currit neese',
+'uploadedfiles'     => 'Coadanyn ta laadit neese',
 'badfilename'       => 'T\'ennym y choadan aa-enmyssit myr "$1".',
 'fileexists-thumb'  => "<center>'''Coadan immeeaght'''</center>",
 'savefile'          => 'Sauail y coadan',
-'uploadedimage'     => '"[[$1]]" currit neese',
+'uploadedimage'     => '"[[$1]]" laadit neese',
 'uploadvirus'       => "Ta veerys 'sy coadan! Mynphoyntyn: $1",
 'watchthisupload'   => 'Freill arrey er y duillag shoh',
 
@@ -519,7 +518,7 @@
 'license-nopreview'  => '(Cha nel roie-haishbynys ry-gheddyn)',
 'upload_source_file' => ' (coadan er dty cho-earrooder)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'coadan',
 'imagelist'             => 'Rolley coadanyn',
 'imagelist_date'        => 'Date',
@@ -544,8 +543,8 @@
 'shareduploadwiki-linktext'      => 'duillag huarastyl y choadan',
 'shareduploadduplicate-linktext' => 'coadyn elley',
 'shareduploadconflict-linktext'  => 'coadan elley',
-'noimage-linktext'               => 'cur neese eh',
-'uploadnewversion-linktext'      => "Cur neese lhieggan noa jeh'n coadan shoh",
+'noimage-linktext'               => 'laad neese eh',
+'uploadnewversion-linktext'      => "Laad neese lhieggan noa jeh'n choadan shoh",
 
 # File reversion
 'filerevert-comment' => 'Cohaggloo:',
@@ -582,7 +581,7 @@
 
 # Statistics
 'statistics' => 'Staydraa',
-'sitestats'  => 'Staydraa dy {{SITENAME}}',
+'sitestats'  => 'Staydraa {{SITENAME}}',
 'userstats'  => 'Staydraa yn ymmydeyr',
 
 'disambiguations' => 'Duillagyn reddaghyn',
@@ -637,11 +636,11 @@
 'speciallogtitlelabel' => 'Ennym:',
 'log-search-submit'    => 'Gow',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Dagh ooilley ghuillag',
 'alphaindexline' => '$1 gys $2',
 'nextpage'       => 'Yn chied duillag elley ($1)',
-'prevpage'       => 'Yn duillag roish shen ($1)',
+'prevpage'       => 'Yn duillag roish ($1)',
 'allarticles'    => 'Dagh ooilley ghuillag',
 'allpagessubmit' => 'Gow',
 'allpagesprefix' => 'Taishbyney duillagyn lesh roie-ockle:',
@@ -651,10 +650,10 @@
 'special-categories-sort-count' => 'sorçhaghey rere coontey',
 'special-categories-sort-abc'   => 'sorçhaghey rere lettyr',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Taishbyney',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'    => 'Possan',
 'listgrouprights-rights'   => 'Kiartyn',
 'listgrouprights-helppage' => 'Help:Kiartyn y phossan',
@@ -665,7 +664,7 @@
 'emailto'        => 'Da',
 'emailsubject'   => 'Cooish',
 'emailmessage'   => 'Çhaghteraght',
-'emailsend'      => 'Dy chur',
+'emailsend'      => 'Cur',
 'emailccsubject' => 'Aascreeuyn dty haghteraght dys $1: $2',
 'emailsent'      => 'Post-L currit',
 'emailsenttext'  => 'Ta dty phost-L currit.',
@@ -674,10 +673,10 @@
 'watchlist'            => 'My rolley arrey',
 'mywatchlist'          => 'My rolley arrey',
 'watchlistfor'         => "(son '''$1''')",
-'watchnologin'         => 'Cha nel ou claarit stiagh',
+'watchnologin'         => 'Cha nel oo loggit stiagh',
 'addedwatch'           => 'Currit rish y rolley arrey',
 'addedwatchtext'       => "Va'n duillag \"[[:\$1]]\" currit lesh dty [[Special:Watchlist|rolley arrey]].<br />
-Bee caghlaaghyn jeant er y duillag shoh as e ghuillag resoonaght ry-akin ayns y rolley shoh, as bee '''clou trome''' er ayns rolley ny [[Special:Recentchanges|caghlaaghyn s'noa]].",
+Bee caghlaaghyn jeant er y duillag shoh as e ghuillag resoonaght ry-akin ayns y rolley shoh, as bee '''clou trome''' er ayns rolley ny [[Special:RecentChanges|caghlaaghyn s'noa]].",
 'removedwatch'         => 'Gowit ass y rolley arrey',
 'removedwatchtext'     => 'Ta\'n duillag "[[:$1]]" gowit ass dty rolley arrey.',
 'watch'                => 'Freill arrey',
@@ -706,7 +705,7 @@
 # Delete/protect/revert
 'deletepage'                  => 'Scryss y duillag',
 'confirm'                     => 'Feeraghey',
-'excontent'                   => "v'eh ny chummal ny: '$1'",
+'excontent'                   => "v'eh ny chummal na: '$1'",
 'exblank'                     => "va'n duillag follym",
 'delete-confirm'              => 'Scryss "$1"',
 'delete-legend'               => 'Scryss',
@@ -826,7 +825,6 @@
 'move-page'               => '$1 y scughey',
 'move-page-legend'        => 'Duillag y scughey',
 'movearticle'             => 'Duillag y scughey:',
-'movenologin'             => 'Cha nel ou claarit stiagh',
 'newtitle'                => 'Gys ard-ennym noa:',
 'move-watch'              => 'Freill arrey er y duillag shoh',
 'movepagebtn'             => 'Yn duillag y scughey',
@@ -835,7 +833,7 @@
 'movedto'                 => 'aa-enmyssit myr',
 'movetalk'                => 'Scughey yn duillag resoonaght ta cochianglt lesh',
 '1movedto2'               => '[[$1]] aa-enmyssit myr [[$2]]',
-'movelogpage'             => 'Lioar y scughey',
+'movelogpage'             => 'Lioar chooishyn y scughey',
 'movereason'              => 'Fa',
 'revertmove'              => 'goll er ash',
 'delete_and_move'         => 'Scryss as scughey',
@@ -866,8 +864,8 @@
 'tooltip-pt-preferences'          => 'My hosheeaghtyn',
 'tooltip-pt-watchlist'            => 'Rolley duillagyn ta er dty rolley arrey',
 'tooltip-pt-mycontris'            => 'Rolley my chohortysyn',
-'tooltip-pt-login'                => 'Ta greinnaghey shiu gys claare stiagh, cha nel eh anneydagh, ansherbee.',
-'tooltip-pt-logout'               => 'Claare magh',
+'tooltip-pt-login'                => 'Ta greinnaghey shiu loggal stiagh, cha nel eh anneydagh, ansherbee.',
+'tooltip-pt-logout'               => 'Log magh',
 'tooltip-ca-talk'                 => 'Resoonaght mychione y ghuillag cummal',
 'tooltip-ca-edit'                 => 'Foddee oo reaghey yn duillah shoh. Click er y cramman roie-haishbynys roish eh y sauail.',
 'tooltip-ca-addsection'           => 'Cur baght er y resoonaght shoh.',
@@ -883,12 +881,12 @@
 'tooltip-n-portal'                => "Mychione y çhalee, jean dty chooid share, c'raad reddyn dy feddyn",
 'tooltip-n-currentevents'         => 'Fow oayllys shaghadys fo chooishyn yn laa',
 'tooltip-n-recentchanges'         => "Rolley caghlaaghyn s'noa ayns y wiki.",
-'tooltip-n-randompage'            => 'Duillag gyn tort y lughtaghey',
+'tooltip-n-randompage'            => 'Duillag gyn tort y laadey',
 'tooltip-n-help'                  => 'Boayl gys feddyn magh.',
 'tooltip-t-whatlinkshere'         => 'Rolley dagh ooilley ghuillag wiki ta kianglt lesh shoh',
 'tooltip-t-contributions'         => 'Jeeagh er cohortysyn yn ymmydeyr shoh',
 'tooltip-t-emailuser'             => "Cur post-L da'n ymmydeyr shoh",
-'tooltip-t-upload'                => 'Cur neese coadanyn',
+'tooltip-t-upload'                => 'Laadey neese coadanyn',
 'tooltip-t-specialpages'          => 'Rolley dagh ooilley ghuillag er lheh',
 'tooltip-ca-nstab-main'           => 'Jeeagh er duillag y chummal',
 'tooltip-ca-nstab-user'           => 'Jeeagh er duillag yn ymmydeyr',
@@ -915,7 +913,7 @@
 'infosubtitle' => 'Oayllys da duillag',
 
 # Math options
-'mw_math_png' => 'Jannoo PNG dagh ooilley hraa',
+'mw_math_png' => 'Jean PNG dagh ooilley hraa',
 
 # Patrol log
 'patrol-log-auto' => '(seyr-obbragh)',
@@ -932,7 +930,7 @@
 'show-big-image'       => 'Jeeskeaylley ymlane',
 'show-big-image-thumb' => '<small>Mooadys y roie-haishbynys shoh: $1 × $2 pixelyn</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'    => 'Laaragh coadanyn noa',
 'showhidebots' => '($1 botyn)',
 'ilsubmit'     => 'Ronsaghey',
@@ -999,7 +997,7 @@
 
 # External editor support
 'edit-externally'      => 'Reaghey yn coadan shoh lesh sheeyntagh mooie',
-'edit-externally-help' => 'Jeeagh er [http://meta.wikimedia.org/wiki/Help:External_editors saraghyn soiaghey seose] son tooilley oayllys.',
+'edit-externally-help' => 'Jeeagh er [http://www.mediawiki.org/wiki/Manual:External_editors saraghyn soiaghey seose] son tooilley oayllys.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'yn clane',
@@ -1047,7 +1045,7 @@
 'version-license'          => 'Kiedoonys',
 'version-software-version' => 'Lhieggan',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Coadan:',
 
 # Special:FileDuplicateSearch
@@ -1058,7 +1056,7 @@
 'specialpages'                   => 'Duillagyn er lheh',
 'specialpages-group-maintenance' => 'Coontaghyn meansal',
 'specialpages-group-other'       => 'Duillagyn elley er lheh',
-'specialpages-group-login'       => 'Claare stiagh / croo coontys',
+'specialpages-group-login'       => 'Log stiagh / croo coontys',
 'specialpages-group-users'       => 'Ymmydeyryn as kiartyn',
 
 );
Index: languages/messages/MessagesSk.php
===================================================================
--- languages/messages/MessagesSk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,17 +5,13 @@
  * @file
  *
  * @author Helix84
- * @author Andre Engels
- * @author Siebrand
- * @author לערי ריינהארט
+ * @author Liso
+ * @author Maros
  * @author Michawiki
- * @author Jon Harald Søby
+ * @author Palica
  * @author Sp5uhe
  * @author Valasek
- * @author Palica
- * @author Liso
- * @author Maros
- * @author SPQRobin
+ * @author לערי ריינהארט
  */
 
 $datePreferences = array(
@@ -432,7 +428,7 @@
 'nosuchspecialpage' => 'Takáto špeciálna stránka neexistuje',
 'nospecialpagetext' => "<big>'''Vyžiadali ste si neplatnú špeciálnu stránku.'''</big>
 
-Zoznam platných špeciálnych stránok nájdete na [[Special:Specialpages|{{int:specialpages}}]].",
+Zoznam platných špeciálnych stránok nájdete na [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Chyba',
@@ -462,7 +458,7 @@
 To sa zvyčajne stane, keď kliknete na zastaralý odkaz na rozdiel alebo do histórie stránky, ktorá bola zmazaná.
 
 Ak to tak nie je, je možné, že ste našli chybu v softvéri.
-Oznámte to prosím správcovi a uveďte URL.',
+Oznámte to prosím [[Special:ListUsers/sysop|správcovi]] a uveďte URL.',
 'missingarticle-rev'   => '(č. revízie: $1)',
 'missingarticle-diff'  => '(rozdiel: $1, $2)',
 'readonly_lag'         => 'Databáza bola automaticky zamknutá pokým záložné databázové servery nedoženú hlavný server',
@@ -513,14 +509,16 @@
 
 # Login and logout pages
 'logouttitle'                => 'Odhlásiť používateľa',
-'logouttext'                 => 'Práve ste sa odhlásili.
+'logouttext'                 => '<strong>Práve ste sa odhlásili.</strong>
+
 Odteraz môžete používať {{GRAMMAR:akuzatív|{{SITENAME}}}} ako anonymný používateľ alebo sa môžete
-opäť prihlásiť pod rovnakým alebo odlišným používateľským menom. Uvedomte si, že niektoré stránky sa môžu
-naďalej zobrazovať ako keby ste boli prihlásený, až kým nevymažete
+opäť [[Special:UserLogin|prihlásiť]] pod rovnakým alebo odlišným používateľským menom.
+Uvedomte si, že niektoré stránky sa môžu naďalej zobrazovať ako keby ste boli prihlásený, až kým nevymažete
 vyrovnávaciu pamäť vášho prehliadača.',
 'welcomecreation'            => '== Vitaj, $1! ==
 
-Vaše konto je vytvorené. Nezabudnite si nastaviť svoje používateľské nastavenia.',
+Vaše konto je vytvorené.
+Nezabudnite si nastaviť svoje [[Special:Preferences|používateľské nastavenia]].',
 'loginpagetitle'             => 'Prihlásenie používateľa',
 'yourname'                   => 'Používateľské meno:',
 'yourpassword'               => 'Heslo:',
@@ -667,9 +665,10 @@
 * Kto mal byť zablokovaný: $7
 
 Môžete kontaktovať $1 alebo s jedného z ďalších [[{{MediaWiki:Grouppage-sysop}}|správcov]] a prediskutovať blokovanie.
-Uvedomte si, že nemôžete použiť funkciu „{{MediaWiki:Emailuser}}“, pokiaľ nemáte registrovanú platnú e-mailovú adresu vo vašich [[Special:Preferences|nastaveniach]].
-Vaša IP adresa je $3 a ID blokovania je #$5. Prosíme, zahrňte oba tieto údaje do každej správy, ktorú posielate.",
-'autoblockedtext'                  => "Vaša IP adresa bola automaticky zablokovaná, pretože je používaná iným používateľom, ktorého zablokoval $1.
+Uvedomte si, že nemôžete použiť funkciu „{{MediaWiki:Emailuser}}“, pokiaľ nemáte registrovanú platnú e-mailovú adresu vo svojich [[Special:Preferences|nastaveniach]].
+Vaša IP adresa je $3 a ID blokovania je #$5.
+Prosím, uveďte oba tieto údaje do každej správy, ktorú posielate.",
+'autoblockedtext'                  => "Vaša IP adresa bola automaticky zablokovaná, pretože ju používa iný používateľ, ktorého zablokoval $1.
 Udaný dôvod zablokovania:
 
 :''$2''
@@ -677,7 +676,7 @@
 * Blokovanie začalo: $8
 * Blokovanie vyprší: $6
 
-Ak sa potrebujete informovať o blokovaní, môžete kontaktovať $1 alebo niektorého iného
+Ak potrebujete informácie o blokovaní, môžete kontaktovať $1 alebo niektorého iného
 [[{{MediaWiki:Grouppage-sysop}}|správcu]].
 
 Pozn.: Nemôžete použiť funkciu „{{MediaWiki:emailuser}}“, ak ste si vo svojich
@@ -689,10 +688,6 @@
 'blockededitsource'                => "Text '''vašich úprav''' stránky '''$1''' je zobrazený nižšie:",
 'whitelistedittitle'               => 'Aby ste mohli upravovať stránky, musíte sa prihlásiť',
 'whitelistedittext'                => 'Aby ste mohli upravovať stránky, musíte sa $1',
-'whitelistreadtitle'               => 'Aby ste mohli čítať stránky, musíte sa prihlásiť',
-'whitelistreadtext'                => 'Aby ste mohli čítať stránky, musíte sa [[Special:Userlogin|prihlásiť]].',
-'whitelistacctitle'                => 'Nemáte dovolené vytvoriť si účet',
-'whitelistacctext'                 => 'Ak chcete na {{GRAMMAR:lokál|{{SITENAME}}}} vytvárať účty, musíte sa [[Special:Userlogin|prihlásiť]] a mať príslušné oprávnenia.',
 'confirmedittitle'                 => 'Aby ste mohli upravovať je potrebné potvrdenie e-mailu',
 'confirmedittext'                  => 'Pred úpravami stránok musíte potvrdiť vašu emailovú adresu. Prosím, nastavte a overte svoju emailovú adresu v [[Special:Preferences|používateľských nastaveniach]].',
 'nosuchsectiontitle'               => 'Sekcia neexistuje',
@@ -707,7 +702,9 @@
 Stránku vytvoríte tak, že začnete písať do dolného poľa a potom stlačíte tlačidlo „Uložiť stránku“.
 (Viac informácií nájdete na stránkach [[{{MediaWiki:Helppage}}|Pomocníka]]).
 Ak ste sa sem dostali nechtiac, iba kliknite na tlačidlo '''späť''' vo svojom prehliadači.",
-'anontalkpagetext'                 => "----''Toto je diskusná stránka anonymného používateľa, ktorý nemá vytvorené svoje konto alebo ho nepoužíva. Preto musíme na jeho identifikáciu použiť numerickú IP adresu. Je možné, že takúto IP adresu používajú viacerí používatelia. Ak ste anonymný používateľ a máte pocit, že vám boli adresované irelevantné diskusné príspevky, vytvorte si konto alebo sa prihláste ([[Special:Userlogin|Vytvorenie konta alebo prihlásenie]]), aby sa zamedzilo budúcim zámenám s inými anonymnými používateľmi''",
+'anontalkpagetext'                 => "----''Toto je diskusná stránka anonymného používateľa, ktorý nemá vytvorené svoje konto alebo ho nepoužíva. 
+Preto musíme na jeho identifikáciu použiť numerickú IP adresu. Je možné, že takúto IP adresu používajú viacerí používatelia.
+Ak ste anonymný používateľ a máte pocit, že vám boli adresované irelevantné diskusné príspevky, [[Special:UserLogin/signup|vytvorte si konto]] alebo sa [[Special:UserLogin|prihláste]], aby sa zamedzilo budúcim zámenám s inými anonymnými používateľmi.''",
 'noarticletext'                    => 'Na tejto stránke sa momentálne nenachádza žiadny text. Môžete [[Special:Search/{{PAGENAME}}|vyhľadávať názov tejto stránky]] v obsahu iných stránok alebo [{{fullurl:{{FULLPAGENAME}}|action=edit}} upravovať túto stránku].',
 'userpage-userdoesnotexist'        => 'Používateľský účet „$1“ nie je registrovaný. Prosím, zaškrtnite ak chcete vytvoriť/upravovať túto stránku.',
 'clearyourcache'                   => "'''Poznámka: Aby sa zmeny prejavili, po uložení musíte vymazať vyrovnávaciu pamäť vášho prehliadača.'''
@@ -721,12 +718,14 @@
 'previewnote'                      => '<strong>Nezabudnite, toto je iba náhľad stránky, ktorú upravujete.
 Zmeny ešte nie sú uložené!</strong>',
 'previewconflict'                  => 'Tento náhľad upravenej stránky zobrazuje text z horného poľa s textom tak, ako sa zobrazí potom, keď ju uložíte.',
-'session_fail_preview'             => '<strong>Prepáčte, nemohli sme spracovať váš príspevok kvôli strate údajov relácie. Skúste to prosím ešte raz. Ak to nebude fungovať, skúste sa odhlásiť a znovu prihlásiť.</strong>',
+'session_fail_preview'             => '<strong>Prepáčte, nemohli sme spracovať váš príspevok kvôli strate údajov relácie.
+Skúste to prosím ešte raz.
+Ak to nebude fungovať, skúste sa [[Special:UserLogout|odhlásiť]] a znovu prihlásiť.</strong>',
 'session_fail_preview_html'        => "<strong>Prepáčte! Nemohli sme spracovať vašu úpravu kvôli strate údajov relácie.</strong>
 
 ''Pretože {{SITENAME}} má použitie HTML umožnené, náhľad sa nezobrazí (prevencia pred JavaScript útokmi).''
 
-<strong>Ak je toto legitímny pokus o úpravu, skúste to prosím znova. Ak to stále nefunguje, skúste sa odhlásiť a znovu prihlásiť.</strong>",
+<strong>Ak je toto legitímny pokus o úpravu, skúste to prosím znova. Ak to stále nefunguje, skúste sa [[Special:UserLogout|odhlásiť]] a znovu prihlásiť.</strong>",
 'token_suffix_mismatch'            => '<strong>Vaša úprava bola zamietnutá, pretože váš klient pokazil znaky s diakritikou v editačnom symbole (token). Úprava bola zamietnutá, aby sa zabránilo poškodeniu textu stránky. Toto sa občas stáva, keď používate chybnú anonymnú proxy službu cez webové rozhranie.</strong>',
 'editing'                          => 'Úprava stránky $1',
 'editingsection'                   => 'Úprava stránky $1 (sekcia)',
@@ -773,7 +772,7 @@
 'edittools'                        => '<!-- Tento text sa zobrazí pod upravovacím a nahrávacím formulárom. -->',
 'nocreatetitle'                    => 'Tvorba nových stránok bola obmedzená',
 'nocreatetext'                     => 'Na {{GRAMMAR:lokál|{{SITENAME}}}} je tvorba nových stránok obmedzená.
-Teraz sa môžete vrátiť späť a upravovať existujúcu stránku alebo [[Special:Userlogin|sa prihlásiť alebo vytvoriť účet]].',
+Teraz sa môžete vrátiť späť a upravovať existujúcu stránku alebo [[Special:UserLogin|sa prihlásiť alebo vytvoriť účet]].',
 'nocreate-loggedin'                => 'Na {{GRAMMAR:lokál|{{SITENAME}}}} nemáte povolenie vytvárať nové stránky.',
 'permissionserrors'                => 'Chyba povolení',
 'permissionserrorstext'            => 'Na to nemáte povolenie z {{PLURAL:$1|nasledujúceho dôvodu|nasledujúcich dôvodov}}:',
@@ -896,7 +895,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Záznam potlačení',
-'suppressionlogtext' => 'Toto je zoznam zmazaní a blokovaní vrátane obsahu, ktorý je skrytý pred správcami. Zoznam momentálne účinných blokovaní nájdete na [[Special:Ipblocklist|Zoznam blokovaní IP]].',
+'suppressionlogtext' => 'Toto je zoznam zmazaní a blokovaní vrátane obsahu, ktorý je skrytý pred správcami. Zoznam momentálne účinných blokovaní nájdete na [[Special:IPBlockList|Zoznam blokovaní IP]].',
 
 # History merging
 'mergehistory'                     => 'Zlúčiť histórie stránok',
@@ -936,7 +935,7 @@
 # Search results
 'searchresults'             => 'Výsledky vyhľadávania',
 'searchresulttext'          => 'Viac informácií o vyhľadávaní vo {{GRAMMAR:lokál|{{SITENAME}}}} nájdete na stránke [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => 'Na vyhľadávaciu požiadavku „[[:$1]]“',
+'searchsubtitle'            => "Hľadali ste „'''[[:$1]]'''“ ([[Special:Prefixindex/$1|všetky stránky začínajúce na „$1”]] | [[Special:WhatLinksHere/$1|všetky stránky odkazujúce na „$1”]])",
 'searchsubtitleinvalid'     => 'Na vyhľadávaciu požiadavku „$1“',
 'noexactmatch'              => "'''Neexistuje stránka nazvaná „$1“'''. Chcete '''[[:$1|vytvoriť novú stránku]]''' s týmto názvom?",
 'noexactmatch-nocreate'     => "'''Stránka s názvom „$1“ neexistuje.'''",
@@ -979,7 +978,7 @@
 'mypreferences'            => 'nastavenia',
 'prefs-edits'              => 'Počet úprav:',
 'prefsnologin'             => 'Nie ste prihlásený/á',
-'prefsnologintext'         => 'Musíte byť [[Special:Userlogin|prihlásený/á]], aby ste mohli zmeniť vaše nastavenia.',
+'prefsnologintext'         => 'Musíte byť [[Special:UserLogin|prihlásený/á]], aby ste mohli zmeniť vaše nastavenia.',
 'prefsreset'               => 'Boli obnovené pôvodné nastavenia.',
 'qbsettings'               => 'Navigačný panel',
 'qbsettings-none'          => 'Žiadne',
@@ -999,8 +998,8 @@
 'math_lexing_error'        => 'lexikálna chyba',
 'math_syntax_error'        => 'syntaktická chyba',
 'math_image_error'         => 'PNG konverzia neúspešná; skontrolujte správnosť inštalácie programov: latex, dvips, gs a convert',
-'math_bad_tmpdir'          => 'Nemôžem zapisovať alebo vytvoriť dočasný matematický adresár',
-'math_bad_output'          => 'Nemôžem zapisovať alebo vytvoriť výstupný matematický adresár',
+'math_bad_tmpdir'          => 'Nemožno zapisovať alebo vytvoriť dočasný matematický adresár',
+'math_bad_output'          => 'Nemožno zapisovať alebo vytvoriť výstupný matematický adresár',
 'math_notexvc'             => 'Chýbajúci program texvc; konfigurácia je popísaná v math/README.',
 'prefs-personal'           => 'Profil',
 'prefs-rc'                 => 'Posledné úpravy',
@@ -1053,7 +1052,7 @@
 'userrights-reason'           => 'Dôvod zmeny:',
 'userrights-no-interwiki'     => 'Nemáte oprávnenie upravovať práva používateľov na iných wiki.',
 'userrights-nodatabase'       => 'Databáza $1 neexistuje alebo nie je lokálna.',
-'userrights-nologin'          => 'Aby ste mohli prideľovať používateľom oprávnenia, musíte sa [[Special:Userlogin|prihlásiť]] s účtom správcu.',
+'userrights-nologin'          => 'Aby ste mohli prideľovať používateľom oprávnenia, musíte sa [[Special:UserLogin|prihlásiť]] s účtom správcu.',
 'userrights-notallowed'       => 'Váš účet nemá oprávnenia prideľovať používateľom oprávnenia.',
 'userrights-changeable-col'   => 'Skupiny, ktoré môžete zmeniť',
 'userrights-unchangeable-col' => 'Skupiny, ktoré nemôžete zmeniť',
@@ -1183,25 +1182,25 @@
 'reupload'                    => 'Zopakovať nahranie',
 'reuploaddesc'                => 'Zrušiť nahrávanie a vrátiť sa späť na nahrávací formulár.',
 'uploadnologin'               => 'Nie ste prihlásený',
-'uploadnologintext'           => 'Musíte byť [[Special:Userlogin|prihlásený/á]], aby ste mohli nahrávať súbory.',
+'uploadnologintext'           => 'Musíte byť [[Special:UserLogin|prihlásený/á]], aby ste mohli nahrávať súbory.',
 'upload_directory_missing'    => 'Adresár pre nahrávanie ($1) chýba a webový server ho nedokáže vytvoriť.',
 'upload_directory_read_only'  => 'Webový server nemôže zapisovať do adresára pre nahrávanie ($1).',
 'uploaderror'                 => 'Chyba pri nahrávaní',
 'uploadtext'                  => "Tento formulár použite na nahrávanie súborov.
-Na zobrazenie alebo hľadanie už nahraných súborov choďte na [[Special:Imagelist|zoznam nahraných súborov]]. Nahrávania a mazania sa tiež zaznamenávajú v [[Special:Log/upload|zázname nahrávaní]].
+Už nahrané súbory môžete zobraziť alebo hľadať v [[Special:ImageList|zozname nahraných súborov]]. Nahrávania a mazania sa tiež zaznamenávajú v [[Special:Log/upload|zázname nahrávaní]].
 
 Na začlenenie obrázka do stránky použite odkaz v tvare
 
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Súbor.jpg]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Súbor.png|alternatívny text]]</nowiki>'''
-alebo pre priamy odkaz na súbor
-* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Súbor.ogg]]</nowiki>'''",
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Súbor.jpg]]</nowiki>''' - použije sa plná verzia obrázka
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Súbor.png|alternatívny text]]</nowiki>''' - vykreslí sa v šírke 200 pixelov s okrajom, na ľavom okraji, s popisom v „alt” texte.
+* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Súbor.ogg]]</nowiki>''' - priamy odkaz na súbor (nezobrazí obrázok na stránke)",
 'upload-permitted'            => 'Povolené typy súborov: $1.',
 'upload-preferred'            => 'Uprednostňované typy súborov: $1.',
 'upload-prohibited'           => 'Zakázané typy súborov: $1.',
 'uploadlog'                   => 'Záznam nahrávaní',
 'uploadlogpage'               => 'Záznam nahrávaní',
-'uploadlogpagetext'           => 'Nižšie je zoznam nedávno nahraných súborov.',
+'uploadlogpagetext'           => 'Nižšie je zoznam nedávno nahraných súborov.
+Vizuálny prehľad nájdete v [[Special:NewImages|galérii novo nahraných súborov]].',
 'filename'                    => 'Názov súboru',
 'filedesc'                    => 'Opis súboru',
 'fileuploadsummary'           => 'Zhrnutie:',
@@ -1273,9 +1272,12 @@
 'upload-proto-error'      => 'Nesprávny protokol',
 'upload-proto-error-text' => 'Vzdialené nahrávanie vyžaduje, aby URL začínali <code>http://</code> alebo <code>ftp://</code>.',
 'upload-file-error'       => 'Vnútorná chyba',
-'upload-file-error-text'  => 'Vyskytla sa vnútorná chyba pri pokuse vytvoriť dočasný súbor na serveri. Prosím, kontaktujte správcu systému.',
+'upload-file-error-text'  => 'Vyskytla sa vnútorná chyba pri pokuse vytvoriť dočasný súbor na serveri.
+Prosím, kontaktujte [[Special:ListUsers/sysop|správcu systému]].',
 'upload-misc-error'       => 'Neznáma chyba pri nahrávaní',
-'upload-misc-error-text'  => 'Počas nahrávania sa vyskytla neznáma chyba. Prosím, overte, že URL je platný a dostupný a skúste znova. Ak problém pretrváva, kontaktujte správcu systému.',
+'upload-misc-error-text'  => 'Počas nahrávania sa vyskytla neznáma chyba.
+Prosím, overte, že URL je platný a dostupný a skúste znova.
+Ak problém pretrváva, kontaktujte [[Special:ListUsers/sysop|správcu systému]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Nedostupný URL',
@@ -1289,7 +1291,7 @@
 'upload_source_url'  => ' (platný, verejne prístupný URL)',
 'upload_source_file' => ' (súbor na vašom počítači)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Táto špeciálna stránka zobrazuje všetky nahrané súbory.
 Posledné nahrané súbory sa štandardne zobrazujú na vrchu.
 Kliknutím na hlavičku stĺpca zmeníte poradie triedenia.',
@@ -1317,7 +1319,7 @@
 'imagelinks'                     => 'Odkazy na obrázok',
 'linkstoimage'                   => 'Na tento obrázok {{PLURAL:$1|odkazuje nasledujúca stránka|odkazujú nasledujúce $1 stránky|odkazuje nasledujúcich $1 stránok}}:',
 'nolinkstoimage'                 => 'Žiadne stránky neobsahujú odkazy na tento obrázok.',
-'morelinkstoimage'               => 'Zobraziť [[Special:Whatlinkshere/$1|ďalšie odkazy]] na tento súbor.',
+'morelinkstoimage'               => 'Zobraziť [[Special:WhatLinksHere/$1|ďalšie odkazy]] na tento súbor.',
 'redirectstofile'                => '{{PLURAL:$1|Nasledujúci súbor presmerúva|Nasledujúce $1 súbory presmerúvajú|Nasledujúcich $1 súborov presmerúva}} na tento súbor:',
 'duplicatesoffile'               => '{{PLURAL:$1|Nasledujúci súbor je duplikát|Nasledujúce $1 súbory sú duplikáty||Nasledujúcich $1 súborov sú duplikáty}} tohto súboru:',
 'sharedupload'                   => 'Toto je zdieľaný súbor a je možné ho používať na iných projektoch.',
@@ -1336,18 +1338,18 @@
 # File reversion
 'filerevert'                => 'Obnoviť $1',
 'filerevert-legend'         => 'Obnoviť súbor',
-'filerevert-intro'          => '<span class="plainlinks">Obnovujete \'\'\'[[Media:$1|$1]]\'\'\' na [$4 verziu z $2, $3].</span>',
+'filerevert-intro'          => "Obnovujete '''[[Media:$1|$1]]''' na [$4 verziu z $2, $3].",
 'filerevert-comment'        => 'komentár:',
 'filerevert-defaultcomment' => 'Obnovená verzia z $1, $2',
 'filerevert-submit'         => 'Obnoviť',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' bol obnovený na [$4 verziu z $2, $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' bol obnovený na [$4 verziu z $2, $3].",
 'filerevert-badversion'     => 'Neexistuje predchádzajúca lokálna verzia tohto súboru s požadovanopu časovou známkou.',
 
 # File deletion
 'filedelete'                  => 'Zmazať $1',
 'filedelete-legend'           => 'Zmazať súbor',
 'filedelete-intro'            => "Mažete '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Mažete verziu súboru \'\'\'[[Media:$1|$1]]\'\'\' z [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Mažete verziu súboru '''[[Media:$1|$1]]''' z [$4 $3, $2].",
 'filedelete-comment'          => 'Komentár:',
 'filedelete-submit'           => 'Zmazať',
 'filedelete-success'          => "'''$1''' bol zmazaný.",
@@ -1410,8 +1412,10 @@
 Mali by však odkazovať priamo na príslušnú tému.<br />
 Stránka sa považuje za rozlišovaciu, keď používa šablónu, na ktorú odkazuje [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Dvojité presmerovania',
-'doubleredirectstext' => 'Každý riadok obsahuje odkaz na prvé a druhé presmerovanie a tiež prvý riadok z textu na ktorý odkazuje druhé presmerovanie, ktoré zvyčajne odkazuje na „skutočný“ cieľ, na ktorý má odkazovať prvé presmerovanie.',
+'doubleredirects'            => 'Dvojité presmerovania',
+'doubleredirectstext'        => 'Každý riadok obsahuje odkaz na prvé a druhé presmerovanie a tiež prvý riadok z textu na ktorý odkazuje druhé presmerovanie, ktoré zvyčajne odkazuje na „skutočný“ cieľ, na ktorý má odkazovať prvé presmerovanie.',
+'double-redirect-fixed-move' => 'Stránka [[$1]] bola presunutá, teraz je presmerovaním na [[$2]]',
+'double-redirect-fixer'      => 'Korektor presmerovaní',
 
 'brokenredirects'        => 'Pokazené presmerovania',
 'brokenredirectstext'    => 'Tieto presmerovania odkazujú na neexistujúcu stránku.',
@@ -1498,7 +1502,7 @@
 'logempty'             => 'V zázname neboli nájdené zodpovedajúce položky.',
 'log-title-wildcard'   => 'Hľadať názvy začínajúce týmto textom',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Všetky stránky',
 'alphaindexline'    => '$1 do $2',
 'nextpage'          => 'Ďalšia stránka ($1)',
@@ -1521,15 +1525,15 @@
 'special-categories-sort-count' => 'zoradiť podľa počtu',
 'special-categories-sort-abc'   => 'zoradiť podľa abecedy',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Zobraziť používateľov počnúc:',
 'listusers-submit'   => 'Zobraziť',
 'listusers-noresult' => 'Neboli nájdení používatelia. Prosím, skontrolujte aj varianty s veľkými/malými písmenami.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Práva skupiny používateľov',
 'listgrouprights-summary'  => 'Toto je zoznam skupín používateľov definovaných na tejto wiki a ich prístupových práv.
-Ďalšie informácie o jednotlivých právach nájdete na [[{{MediaWiki:Listgrouprights-helppage}}|tejto stránke]].',
+Môžete si prečítať [[{{MediaWiki:Listgrouprights-helppage}}|ďalšie informácie]] o jednotlivých právach.',
 'listgrouprights-group'    => 'Skupina',
 'listgrouprights-rights'   => 'Práva',
 'listgrouprights-helppage' => 'Help:Práva skupiny',
@@ -1537,14 +1541,12 @@
 
 # E-mail user
 'mailnologin'     => 'Žiadna adresa na zaslanie',
-'mailnologintext' => 'Musíte byť [[Special:Userlogin|prihlásený]] a mať platnú e-mailovú adresu vo vašich [[Special:Preferences|nastaveniach]], aby ste mohli iným používateľom posielať e-maily.',
+'mailnologintext' => 'Musíte byť [[Special:UserLogin|prihlásený]] a mať platnú e-mailovú adresu vo vašich [[Special:Preferences|nastaveniach]], aby ste mohli iným používateľom posielať e-maily.',
 'emailuser'       => 'E-mail tomuto používateľovi',
 'emailpage'       => 'E-mail používateľovi',
 'emailpagetext'   => 'Ak tento používateľ zadal platnú e-mailovú adresu vo svojich nastaveniach,
-môžete mu pomocou dole zobrazeného formulára poslať e-mail.
-E-mailová adresa, ktorú ste zadali vo vašich nastaveniach sa zobrazí
-ako adresa odosielateľa e-mailu, aby vám bol príjemca schopný
-odpovedať.',
+môžete mu pomocou nasledovného formulára poslať email.
+Emailová adresa, ktorú ste zadali vo svojich [[Special:Preferences|nastaveniach]] sa zobrazí ako adresa odosielateľa emailu, aby vám bol príjemca schopný odpovedať.',
 'usermailererror' => 'Emailový program vrátil chybu:',
 'defemailsubject' => 'email {{GRAMMAR:genitív|{{SITENAME}}}}',
 'noemailtitle'    => 'Chýba e-mailová adresa',
@@ -1568,9 +1570,9 @@
 'nowatchlist'          => 'V zozname sledovaných stránok nemáte žiadne položky.',
 'watchlistanontext'    => 'Prosím $1 pre prezeranie alebo úpravu vášho zoznamu sledovaných stránok.',
 'watchnologin'         => 'Nie ste prihlásený/á',
-'watchnologintext'     => 'Musíte byť [[Special:Userlogin|prihlásený/á]], aby ste mohli modifikovať vaše sledované stránky.',
+'watchnologintext'     => 'Musíte byť [[Special:UserLogin|prihlásený/á]], aby ste mohli modifikovať vaše sledované stránky.',
 'addedwatch'           => 'Pridaná do zoznamu sledovaných stránok',
-'addedwatchtext'       => "Stránka [[$1]] bola pridaná do [[Special:Watchlist|sledovaných stránok]]. Budú tam uvedené ďalšie úpravy tejto stránky a jej diskusie a stránka bude zobrazená '''tučne''' v [[Special:Recentchanges|zozname posledných úprav]], aby ste ju ľahšie našli.
+'addedwatchtext'       => "Stránka [[$1]] bola pridaná do [[Special:Watchlist|sledovaných stránok]]. Budú tam uvedené ďalšie úpravy tejto stránky a jej diskusie a stránka bude zobrazená '''tučne''' v [[Special:RecentChanges|zozname posledných úprav]], aby ste ju ľahšie našli.
 
 Ak budete chcieť neskôr stránku odstrániť zo sledovaných stránok, kliknite na „{{MediaWiki:unwatch}}“ v záložkách na vrchu.",
 'removedwatch'         => 'Odstránená zo zoznamu sledovaných stránok',
@@ -1668,10 +1670,10 @@
 'rollback_short'              => 'Rollback',
 'rollbacklink'                => 'rollback',
 'rollbackfailed'              => 'Rollback neúspešný',
-'cantrollback'                => 'Nemôžem úpravu vrátiť späť, posledný autor je jediný autor tejto stránky.',
-'alreadyrolled'               => 'Nemôžem vrátiť späť poslednú úpravu [[$1]] od [[User:$2|$2]] ([[User talk:$2|Diskusia]]); niekto iný buď upravoval stránku, alebo už vrátil späť.
+'cantrollback'                => 'Nie je možné úpravu vrátiť späť, posledný autor je jediný autor tejto stránky.',
+'alreadyrolled'               => 'Nemožno vrátiť späť poslednú úpravu [[:$1]] od [[User:$2|$2]] ([[User talk:$2|Diskusia]] | [[Special:Contributions/$2|{{int:contribslink}}]]); niekto iný buď upravoval stránku alebo už vrátil úpravy späť.
 
-Autorom poslednej úpravy je [[User:$3|$3]] ([[User talk:$3|Diskusia]]).',
+Autorom poslednej úpravy je [[User:$3|$3]] ([[User talk:$3|Diskusia]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Komentár k úprave bol: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Posledné úpravy používateľa [[Special:Contributions/$2|$2]] ([[User talk:$2|diskusia]]) vrátené; bola obnovená posledná úprava $1', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Úpravy $1 vrátené; obnovená posledná verzia od $2.',
@@ -1680,7 +1682,7 @@
 Prosím, stlačte "naspäť", obnovte stránku, z ktorej ste sa sem dostali, a skúste to znova.',
 'protectlogpage'              => 'Záznam zamknutí',
 'protectlogtext'              => 'Nižšie je zoznam zamknutí/odomknutí stránok.
-Môžete si pozrieť aj [[Special:Protectedpages|zoznam momentálne platných zamknutí]].',
+Môžete si pozrieť aj [[Special:ProtectedPages|zoznam momentálne platných zamknutí]].',
 'protectedarticle'            => 'zamyká „[[$1]]“',
 'modifiedarticleprotection'   => 'zmenená úroveň ochrany „[[$1]]“',
 'unprotectedarticle'          => 'odomyká „[[$1]]“',
@@ -1795,7 +1797,7 @@
 
 # What links here
 'whatlinkshere'            => 'Odkazy na túto stránku',
-'whatlinkshere-title'      => 'Stránky odkazujúce na $1',
+'whatlinkshere-title'      => 'Stránky odkazujúce na „$1”',
 'whatlinkshere-page'       => 'Page:',
 'linklistsub'              => '(Zoznam odkazov)',
 'linkshere'                => "Nasledujúce stránky odkazujú na '''[[:$1]]''':",
@@ -1846,7 +1848,7 @@
 'badipaddress'                    => 'IP adresa má nesprávny formát.',
 'blockipsuccesssub'               => 'Zablokovanie bolo úspešné',
 'blockipsuccesstext'              => '„$1“ bol/a zablokovaný/á.<br />
-[[Special:Ipblocklist|IP block list]] obsahuje zoznam blokovaní.',
+[[Special:IPBlockList|IP block list]] obsahuje zoznam blokovaní.',
 'ipb-edit-dropdown'               => 'Upraviť dôvody pre blokovanie',
 'ipb-unblock-addr'                => 'Odblokovať $1',
 'ipb-unblock'                     => 'Odblokovať používateľa alebo IP adresu',
@@ -1858,7 +1860,7 @@
 'ipusubmit'                       => 'Odblokovať túto adresu',
 'unblocked'                       => '[[User:$1|$1]] bol odblokovaný',
 'unblocked-id'                    => 'Blokovanie $1 bolo odstránené',
-'ipblocklist'                     => 'Zoznam zablokovaných používateľov/IP adries',
+'ipblocklist'                     => 'Zablokovaní používatelia/IP adresy',
 'ipblocklist-legend'              => 'Nájsť zablokovaného používateľa',
 'ipblocklist-username'            => 'Používateľské meno alebo IP adresa:',
 'ipblocklist-submit'              => 'Hľadať',
@@ -1879,7 +1881,7 @@
 'blocklogentry'                   => 'zablokoval/a "[[$1]]" s časom ukončenia $2 $3',
 'blocklogtext'                    => 'Toto je zoznam blokovaní a odblokovaní používateľov. Automaticky
 blokované IP adresy nie sú zahrnuté. Pozri zoznam
-[[Special:Ipblocklist|aktuálnych blokovaní]].',
+[[Special:IPBlockList|aktuálnych blokovaní]].',
 'unblocklogentry'                 => 'odblokoval/a $1',
 'block-log-flags-anononly'        => 'iba anonymní používatelia',
 'block-log-flags-nocreate'        => 'možnosť vytvoriť si účet bola vypnutá',
@@ -1921,7 +1923,7 @@
 'lockdbsuccesssub'    => 'Zamknutie databázy úspešné',
 'unlockdbsuccesssub'  => 'Databáza bola úspešne odomknutá',
 'lockdbsuccesstext'   => 'Databáza bola zamknutá.<br />
-Nezabudnite po dokončení údržby [[Special:Unlockdb|odstrániť zámok]].',
+Nezabudnite po dokončení údržby [[Special:UnlockDB|odstrániť zámok]].',
 'unlockdbsuccesstext' => 'Databáza {{GRAMMAR:genitív|{{SITENAME}}}} bola odomknutá.',
 'lockfilenotwritable' => 'Súbor, ktorý zamyká databázu nie je zapisovateľný. Aby bolo možné zamknúť či odomknúť databázu, je potrebné, aby doňho mohol web server zapisovať.',
 'databasenotlocked'   => 'Databáza nie je zamknutá.',
@@ -1929,10 +1931,11 @@
 # Move page
 'move-page'               => 'Presunúť $1',
 'move-page-legend'        => 'Presunúť stránku',
-'movepagetext'            => "Pomocou tohto formulára premenujete stránku a premiestnite všetky jej predchádzajúce verzie pod zadané nové meno.
+'movepagetext'            => "Pomocou tohto formulára premenujete stránku a premiestnite všetky jej predchádzajúce verzie pod zadaný nový názov.
 Starý názov sa stane presmerovacou stránkou na nový názov.
-Odkazy na starú stránku sa však nezmenia, ubezpečte sa, že ste skontrolovali
-výskyt dvojitých alebo pokazených presmerovaní.
+Môžete automaticky aktualizovať odkazy odkazujúce na pôvodný názov.
+Ak sa rozhodnete túto možnosť nevyužiť, ubezpečte sa, že ste skontrolovali
+výskyt [[Special:DoubleRedirects|dvojitých]] a [[Special:BrokenRedirects|pokazených]] presmerovaní.
 Vy ste zodpovedný za to, aby odkazy naďalej ukazovali tam, kam majú.
 
 Uvedomte si, že stránka sa '''nepremiestni''', ak pod novým názvom už stránka existuje.
@@ -1949,8 +1952,6 @@
 
 V takých prípadoch budete musieť, ak si to želáte, premiestniť alebo zlúčiť stránku ručne.",
 'movearticle'             => 'Presunúť stránku',
-'movenologin'             => 'Nie ste prihlásený',
-'movenologintext'         => 'Musíte byť registrovaný používateľ a [[Special:Userlogin|prihlásený]], aby ste mohli presunúť stránku.',
 'movenotallowed'          => 'Na {{GRAMMAR:lokál|{{SITENAME}}}} nemáte povolenie presúvať stránky.',
 'newtitle'                => 'Na nový názov:',
 'move-watch'              => 'Sledovať túto stránku',
@@ -1982,14 +1983,15 @@
 'delete_and_move'         => 'Vymazať a presunúť',
 'delete_and_move_text'    => '==Je potrebné zmazať stránku==
 
-Cieľová stránka „[[$1]]“ už existuje. Chcete ho vymazať a vytvoriť tak priestor pre presun?',
+Cieľová stránka „[[:$1]]“ už existuje. Chcete ho vymazať a vytvoriť tak priestor pre presun?',
 'delete_and_move_confirm' => 'Áno, zmaž stránku',
 'delete_and_move_reason'  => 'Vymazať, aby sa umožnil presun',
-'selfmove'                => 'Zdrojový a cieľový názov sú rovnaké; nemôžem presunúť stránku na seba samú.',
+'selfmove'                => 'Zdrojový a cieľový názov sú rovnaké; nemožno presunúť stránku na seba samú.',
 'immobile_namespace'      => 'Cieľový názov je špeciálneho typu; nemôžem presunúť stránku do tohto menného priestoru.',
 'imagenocrossnamespace'   => 'Obrázok nemožno presunúť mimo menného priestoru obrázkov',
 'imagetypemismatch'       => 'Nová prípona súboru nezodpovedá jeho typu',
 'imageinvalidfilename'    => 'Cieľový názov obrázka nie je platný',
+'fix-double-redirects'    => 'Aktualizovať všetky presmerovania odkazujúce na pôvodný názov',
 
 # Export
 'export'            => 'Export stránok',
@@ -2037,7 +2039,7 @@
 'import-interwiki-history'   => 'Skopírovať všetky historické revízie tejto stránky',
 'import-interwiki-submit'    => 'Importovať',
 'import-interwiki-namespace' => 'Presunúť stránky do menného priestoru:',
-'importtext'                 => 'Prosím exportujte súbor zo zdrojov wiki použitím nástroja Special:Export, uložte na váš disk a nahrajte tu.',
+'importtext'                 => 'Prosím exportujte súbor zo zdrojovej wiki použitím [[Special:Export|nástroja na export]], uložte ho na svoj disk a nahrajte sem.',
 'importstart'                => 'Importujú sa stránky...',
 'import-revision-count'      => '$1 {{PLURAL:$1|revízia|revízie|revízií}}',
 'importnopages'              => 'Žiadne stránky pre import.',
@@ -2187,9 +2189,10 @@
 'markedaspatrollederror-noautopatrol' => 'Nie je vám umožnené označiť vlastné zmeny za strážené.',
 
 # Patrol log
-'patrol-log-page' => 'Záznam strážení',
-'patrol-log-line' => '$1 z $2 označených ako sledované $3',
-'patrol-log-auto' => '(automaticky)',
+'patrol-log-page'   => 'Záznam strážení',
+'patrol-log-header' => 'Toto je záznam strážených revízií.',
+'patrol-log-line'   => '$1 z $2 označených ako sledované $3',
+'patrol-log-auto'   => '(automaticky)',
 
 # Image deletion
 'deletedrevision'                 => 'Zmazať staré verzie $1',
@@ -2219,10 +2222,10 @@
 'show-big-image'       => 'Obrázok vo vyššom rozlíšení',
 'show-big-image-thumb' => '<small>Veľkosť tohto náhľadu: $1 × $2 pixelov</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galéria nových obrázkov',
 'imagelisttext'         => "Tu je zoznam {{PLURAL:$1|jedného súboru|'''$1''' súborov|'''$1''' súborov}} zoradený $2.",
-'newimages-summary'     => 'Táto špeciálna stránka zobrazuje posledné nahrané súbory',
+'newimages-summary'     => 'Táto špeciálna stránka zobrazuje posledné nahrané súbory.',
 'showhidebots'          => '($1 botov)',
 'noimages'              => 'Niet čo zobraziť.',
 'ilsubmit'              => 'Hľadať',
@@ -2501,7 +2504,7 @@
 
 # External editor support
 'edit-externally'      => 'Upraviť tento súbor pomocou externého programu',
-'edit-externally-help' => 'Viac informácií poskytnú inštrukcie pre nastavenie [http://meta.wikimedia.org/wiki/Help:External_editors externého editora].',
+'edit-externally-help' => 'Viac informácií poskytnú inštrukcie pre nastavenie [http://www.mediawiki.org/wiki/Manual:External_editors externého editora].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'všetky',
@@ -2575,7 +2578,7 @@
 'recreate'            => 'Znova vytvoriť',
 
 # HTML dump
-'redirectingto' => 'Presmerovanie na [[$1]]...',
+'redirectingto' => 'Presmerovanie na [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Vyčistiť vyrovnávaciu pamäť (cache) tejto stránky?
@@ -2622,8 +2625,8 @@
 Skúste obyčajný náhľad.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Zmeny novšie ako $1 sekúnd sa nemôžu v tomto zozname zobraziť.',
-'lag-warn-high'   => 'Z dôvodu dlhej odozvy databázového servera sa zmeny novšie ako $1 sekúnd nemôžu v tomto zozname zobraziť.',
+'lag-warn-normal' => 'Zmeny novšie ako $1 {{PLURAL:$1|sekunda|sekundy|sekúnd}} nemožno v tomto zozname zobraziť.',
+'lag-warn-high'   => 'Z dôvodu dlhej odozvy databázového servera zmeny novšie ako $1 {{PLURAL:$1|sekunda|sekundy|sekúnd}} nemožno v tomto zozname zobraziť.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Váš zoznam sledovaných stránok obsahuje {{PLURAL:$1|jednu stránku|$1 stránky|$1 stránok}} nepočítajúc diskusné stránky.',
@@ -2674,7 +2677,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Verzia',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Cesta k súboru',
 'filepath-page'    => 'Súbor:',
 'filepath-submit'  => 'Cesta',
@@ -2713,7 +2716,7 @@
 'specialpages-group-redirects'   => 'Špeciálne stránky, ktoré sú presmerovania',
 'specialpages-group-spam'        => 'Nástroje proti spamu',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Prázdna stránka',
 'intentionallyblankpage' => 'Táto stránka je zámerne prázdna. Používa sa na meranie výkonnosti atď.',
 
Index: languages/messages/MessagesSo.php
===================================================================
--- languages/messages/MessagesSo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Mimursal
  * @author Yariiska
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -214,7 +212,7 @@
 # Main script and global functions
 'nosuchaction'      => 'Codsi aanan jirin',
 'nosuchspecialpage' => "Boggan khaaska ah ma'jiro",
-'nospecialpagetext' => 'Waxaad codsatay bogga khaas ah oo aanan jirin, liis boggaga khaaska ah ee jira waxaad laga helikartaa [[Special:Specialpages|liiska boggaga khaaska ah]].',
+'nospecialpagetext' => 'Waxaad codsatay bogga khaas ah oo aanan jirin, liis boggaga khaaska ah ee jira waxaad laga helikartaa [[Special:SpecialPages|liiska boggaga khaaska ah]].',
 
 # General errors
 'error'             => 'Qalad',
@@ -294,12 +292,11 @@
 'blockededitsource'         => "Qoraalkii '''aad waxkaga bedashay''' '''$1''' waxaad ku arkikartaa hoos:",
 'whitelistedittitle'        => 'Waxaa loo baahanyahay gudagal si aad wax uga bedeshid',
 'whitelistedittext'         => 'Waa in aad $1 si aad wax uga bedeshid boggaga.',
-'whitelistacctitle'         => 'Laguuma ogola in aad sameysid gudagale',
 'loginreqtitle'             => 'Waxaa loo baahanyahay gudagalid',
 'loginreqpagetext'          => 'Waa in aad $1 si aad u fiirisid boggaga kale.',
 'accmailtitle'              => "Ereysirka waa la'diray.",
 'accmailtext'               => 'Ereysirka "$1" waxaa loo diray $2.',
-'anontalkpagetext'          => "----''Meeshaan waa bogga wadahadalka isticmaalayaasha aanan la aqoonsanin oo aanan weli sameysanin akoon ama aanan weli isticmaali. Si loo kala sooco isticmaalayaasha, waa in aan isticmaalnaa lambar cinwaaneedka IP:ga. Cinwaanka IP:ga waxaa suurto gal ah in ay wada isticmaalaan dad badan. Hadii aad tahay isticmaale aanan la'aqoonsanin oo aad dareemaysid in laguu gafay, fadlan ka sameyso akoon meeshaan  [[Special:Userlogin|sameyso akoon ama gudaha gal]] si aad uga dhowrsatid in laguugu qaldo isticmaalayaasha kale oo aann la'aqoonsanin.''",
+'anontalkpagetext'          => "----''Meeshaan waa bogga wadahadalka isticmaalayaasha aanan la aqoonsanin oo aanan weli sameysanin akoon ama aanan weli isticmaali. Si loo kala sooco isticmaalayaasha, waa in aan isticmaalnaa lambar cinwaaneedka IP:ga. Cinwaanka IP:ga waxaa suurto gal ah in ay wada isticmaalaan dad badan. Hadii aad tahay isticmaale aanan la'aqoonsanin oo aad dareemaysid in laguu gafay, fadlan ka sameyso akoon meeshaan  [[Special:UserLogin|sameyso akoon ama gudaha gal]] si aad uga dhowrsatid in laguugu qaldo isticmaalayaasha kale oo aann la'aqoonsanin.''",
 'previewnote'               => '<strong>Waxa aad aragtid waa horfiirin; wixii aad bedeshay lama keydinin!</strong>',
 'session_fail_preview'      => "<strong>Waan ka xunahay! Wixii aad bedeshay ma'suurto galin in la'keydiyo cilad dhacday awgeed.
 Fadlan markale isku day. Hadii aysan weli shaqaynin, ka bax ee markale soo gudagal.</strong>",
@@ -351,7 +348,7 @@
 'preferences'          => 'Dooqyada',
 'mypreferences'        => 'Dooqyadeyda',
 'prefsnologin'         => 'Gudaha kuma jirtid',
-'prefsnologintext'     => 'Waa in aad [[Special:Userlogin|Gudaha ku jirtaa]] si aad dooqyadaada u dalbatid.',
+'prefsnologintext'     => 'Waa in aad [[Special:UserLogin|Gudaha ku jirtaa]] si aad dooqyadaada u dalbatid.',
 'prefsreset'           => 'Dooqyada waxaa laga keenay keydka.',
 'math'                 => 'Xisaab',
 'datedefault'          => "Ma'jiro dooq",
@@ -431,7 +428,7 @@
 # Special:Log
 'log-search-submit' => 'Soco',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Dhamaan boggaga',
 'alphaindexline'    => '$1 ilaa $2',
 'nextpage'          => 'Bogga ku xiga ($1)',
@@ -449,14 +446,14 @@
 # Special:Categories
 'categories' => 'Qeybaha',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "I'tus isticmaalayaasha laga bilaabo:",
 'listusers-submit'   => "I'tus",
 'listusers-noresult' => 'Lama helin isticmaale.',
 
 # E-mail user
 'mailnologin'     => "Ma'jiro cinwaan wax lagu diro",
-'mailnologintext' => 'Waa in aad [[Special:Userlogin|gudaha ku jirtaa]]
+'mailnologintext' => 'Waa in aad [[Special:UserLogin|gudaha ku jirtaa]]
 kuna haysatid E-boosto sax ah [[Special:Preferences|dooqyadaada]],
 si aad ugu dirto E-boosto isticmaalayaasha kale.',
 'emailuser'       => 'U dir E-boosto isticmaalahaan',
@@ -477,11 +474,11 @@
 'nowatchlist'       => 'Waxba kuma jiraan liiskaaga waardiyeynta.',
 'watchlistanontext' => 'Fadlan $1 si aad u fiirisid ama wax uga bedeshid qoraalada ku jira liiska waardiyeyska.',
 'watchnologin'      => 'Gudaha kuma jirtid',
-'watchnologintext'  => 'Waa ina aad [[Special:Userlogin|gudaha ku jirtaa]] si aad wax uga bedeshid liiskaaga waardiyeynta.',
+'watchnologintext'  => 'Waa ina aad [[Special:UserLogin|gudaha ku jirtaa]] si aad wax uga bedeshid liiskaaga waardiyeynta.',
 'addedwatch'        => 'Kudar liiska-waardiyaha',
 'addedwatchtext'    => "Bogga \"[[:\$1]]\" waxaa lagudaray [[Special:Watchlist|liiska-waardiyahaaga]].
 Isbedelka mustaqbalka ku dhaca boggan iyo bogga wadahadalka la'xiriira waxaa lagu soo qoridoonaa inta,
-boggana wuxuu noqonaayaa mid la' '''nuuriyey''' dhinaca [[Special:Recentchanges|Liiska isbedelada show]] si
+boggana wuxuu noqonaayaa mid la' '''nuuriyey''' dhinaca [[Special:RecentChanges|Liiska isbedelada show]] si
 ay u fududdayso sidii loo dalbanlahaa.
 
 Hadii aad rabootid in aad boggan ka saartid wardiyeynta, dhagsii \"Ha' wardiyeynin\" oo ku yaala dhinaca.",
@@ -543,7 +540,6 @@
 'block-log-flags-nocreate' => 'sameynta gudagalah lamaogola',
 
 # Move page
-'movenologin'     => 'Gudaha kuma jirtid',
 'movedto'         => 'loo wareejiyey',
 'movetalk'        => "Wareejiyey bogga wadahadalka la'xiriira",
 '1movedto2'       => '[[$1]] waxaa loo wareejiyey [[$2]]',
@@ -593,7 +589,7 @@
 # Info page
 'numwatchers' => 'Tirada waardiyeyaasha: $1',
 
-# Special:Newimages
+# Special:NewImages
 'imagelisttext' => "Hoos waxaa yaala liiska '''$1''' {{PLURAL:$1|file|faylalka}} oo u kala soocan $2.",
 'bydate'        => 'hab taariikheed',
 
Index: languages/messages/MessagesAvk.php
===================================================================
--- languages/messages/MessagesAvk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAvk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Nkosi ya Cabinda
+ * @author Sab
  * @author Wikimistusik
- * @author Sab
- * @author Siebrand
- * @author Nkosi ya Cabinda
- * @author SPQRobin
  */
 
 $messages = array(
@@ -342,6 +340,10 @@
 'titleprotected'       => "Bat vergumvelt gan [[User:$1|$1]] zo reduranendar.
 Batdume : ''$2''.",
 
+# Virus scanner
+'virus-scanfailed'     => 'rodjeyena drunara ($1 beksa)',
+'virus-unknownscanner' => 'megrupena kevkioxeka :',
+
 # Login and logout pages
 'logouttitle'                => 'Solgluyara',
 'logouttext'                 => 'Rin daletoe til solgluyanaf.
@@ -487,10 +489,6 @@
 'blockededitsource'         => "Krent ke '''rinaf betakseem''' va '''$1''' vleveon zo betar :",
 'whitelistedittitle'        => 'Kucilan login ta sutelara',
 'whitelistedittext'         => 'Ta bubetara rin gonaskil ta $1',
-'whitelistreadtitle'        => 'Kucilan login ta rupera',
-'whitelistreadtext'         => 'Ta rupera va teliz gotil [[Special:Userlogin|dogluyarakiraf]]',
-'whitelistacctitle'         => 'Ta pataredura rin me zo rictal',
-'whitelistacctext'          => 'Ta da mo bati wiki ropataredul va int [[Special:Userlogin|godogluyal]] ise gotil drutckanhayan',
 'confirmedittitle'          => 'Gruyera va e-mail eruyuna ta robetara',
 'confirmedittext'           => 'Abdi bubetara va rinafe e-mail mane gogruyel. Kan rinaf [[Special:Preferences|favesiklodamaceem]] va rinafe e-mail mane vay plekul ise tuenal !',
 'nosuchsectiontitle'        => 'Me man gabot',
@@ -502,7 +500,7 @@
 'accmailtext'               => 'Remravlem ke « $1 » al zo stakser pu $2.',
 'newarticle'                => '(Warzaf)',
 'newarticletext'            => 'Va rinaf teliz batliz geltsutel !',
-'anontalkpagetext'          => "---- ''Vous êtes sur la page de discussion d'un utilisateur anonyme qui n'a pas encore créé un compte ou qui ne l'utilise pas. Pour cette raison, nous devons utiliser l'adresse IP numérique pour l'identifier. Une adresse de ce type peut être partagée entre plusieurs utilisateurs. Si vous êtes un utilisateur anonyme et si vous constatez que des commentaires qui ne vous concernent pas vous ont été adressés, vous pouvez [[Special:Userlogin|créer un compte ou vous connecter]] afin d'éviter toute future confusion.''",
+'anontalkpagetext'          => "---- ''Vous êtes sur la page de discussion d'un utilisateur anonyme qui n'a pas encore créé un compte ou qui ne l'utilise pas. Pour cette raison, nous devons utiliser l'adresse IP numérique pour l'identifier. Une adresse de ce type peut être partagée entre plusieurs utilisateurs. Si vous êtes un utilisateur anonyme et si vous constatez que des commentaires qui ne vous concernent pas vous ont été adressés, vous pouvez [[Special:UserLogin|créer un compte ou vous connecter]] afin d'éviter toute future confusion.''",
 'noarticletext'             => 'Moe batu bu mek krent dure tir, vanmiae yonaru bu [[Special:Search/{{PAGENAME}}|va man buvergumvelt rotaneyal]] oke [{{fullurl:{{FULLPAGENAME}}|action=edit}} va batu bu robetal].',
 'userpage-userdoesnotexist' => '"$1" favesikpata me tir vuesteyena. Vay stujel ede va batu bu roredul ike robetal.',
 'clearyourcache'            => "'''Note :''' Après avoir sauvegardé, vous devez forcer le rechargement de la page pour voir les changements : '''Mozilla / Konqueror / Firefox''' : ''ctrl-shift-r'', '''IE''' : ''ctrl-f5'', '''Safari''' : ''cmd-shift-r''; '''Konqueror''' : ''f5''.",
@@ -545,7 +543,7 @@
 'hiddencategories'          => 'Batu bu tir bewafu gu {{PLURAL:$1|1 palsena loma|$1 palsena loma}}:',
 'nocreatetitle'             => 'Irutana buredura',
 'nocreatetext'              => '{{SITENAME}} va roredura va warzafu bu irutar.
-Rodimal aze va tisu bu robetal oke [[Special:Userlogin|va int rodogluyal oke ropataredul]].',
+Rodimal aze va tisu bu robetal oke [[Special:UserLogin|va int rodogluyal oke ropataredul]].',
 'nocreate-loggedin'         => 'Ko {{SITENAME}} ta redura va warzafu bu rin me zo rictal.',
 'permissionserrors'         => 'Rictajaks',
 'permissionserrorstext'     => 'Ta mana askira me zo rictal, golde {{PLURAL:$1|lazava|lazava se}}:',
@@ -723,7 +721,7 @@
 'mypreferences'            => 'Jinaf lodamaceem',
 'prefs-edits'              => 'Ota va betaks :',
 'prefsnologin'             => 'Dogluyariskaf',
-'prefsnologintext'         => 'Ta da va favesiklodamaceem robetal gotil [[Special:Userlogin|dogluyarakiraf]].',
+'prefsnologintext'         => 'Ta da va favesiklodamaceem robetal gotil [[Special:UserLogin|dogluyarakiraf]].',
 'prefsreset'               => 'Les préférences ont été rétablies à partir de la version enregistrée.',
 'qbsettings'               => 'Tuweltara va xekobla',
 'qbsettings-none'          => 'Mek',
@@ -792,7 +790,7 @@
 'userrights-reason'           => 'Betaralazava :',
 'userrights-no-interwiki'     => 'Va favesikroka koe ari wiki me robetal.',
 'userrights-nodatabase'       => '$1 origak me krulder oke me tir lizukaf.',
-'userrights-nologin'          => 'Ta tentura va favesikroka gotil [[Special:Userlogin|dogluyan]] kan ristusikpata.',
+'userrights-nologin'          => 'Ta tentura va favesikroka gotil [[Special:UserLogin|dogluyan]] kan ristusikpata.',
 'userrights-notallowed'       => 'Rinafa pata va tentura va favesikroka me rictar.',
 'userrights-changeable-col'   => 'Yona rinon robetana lospa',
 'userrights-unchangeable-col' => 'Yona rinon merobetana lospa',
@@ -913,11 +911,11 @@
 'reupload'                    => 'Tolon kalvajá',
 'reuploaddesc'                => 'Empara va kalvajara nume dimpira',
 'uploadnologin'               => 'Dogluyariskaf',
-'uploadnologintext'           => 'Gotil [[Special:Userlogin|dogluyarakiraf]] ta kalvajara va iyeltak mo zanisiko.',
+'uploadnologintext'           => 'Gotil [[Special:UserLogin|dogluyarakiraf]] ta kalvajara va iyeltak mo zanisiko.',
 'upload_directory_read_only'  => 'Sutera ko kalvajarabonja ($1) gan web zanisiko zo pour.',
 'uploaderror'                 => 'Rokla',
 'uploadtext'                  => "Ta iyeltakkalvajara, va vlevefi tazukasiki favel.
-Ta wira va kalvajayan iyeltak oku aneyara, ko [[Special:Imagelist|vexala dem kalvajayan iyeltak]] grablel, kalvajaks is sulaks \"log\" tid koe [[Special:Log/upload|kalvajara \"log\"]].
+Ta wira va kalvajayan iyeltak oku aneyara, ko [[Special:ImageList|vexala dem kalvajayan iyeltak]] grablel, kalvajaks is sulaks \"log\" tid koe [[Special:Log/upload|kalvajara \"log\"]].
 
 Ta kobura va iyeltak, koe tazukasiki va gluyasiki favel
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -995,7 +993,7 @@
 'upload_source_url'  => ' (enafe sanegon rovansane URL mane)',
 'upload_source_file' => ' (iyeltak koe rinafo vusiko)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Aneyara va ewavayolt :',
 'imgfile'               => 'iyeltak',
 'imagelist'             => 'Ewavavexala',
@@ -1018,9 +1016,9 @@
 'filehist-filesize'              => 'Iyeltakaldo',
 'filehist-comment'               => 'Sebuks',
 'imagelinks'                     => 'Gluyasiki se',
-'linkstoimage'                   => 'Vlevef bueem va bata ewava ruldar :',
+'linkstoimage'                   => 'Vlevefi {{PLURAL:$1|bugluyasiki|$1 bugluyasiki}} va bat iyeltak :',
 'nolinkstoimage'                 => 'Meku bu va bata ewava ruldar.',
-'morelinkstoimage'               => 'Rupera va [[Special:Whatlinkshere/$1|lofi skedasiki]] va bat iyeltak.',
+'morelinkstoimage'               => 'Rupera va [[Special:WhatLinksHere/$1|lofi skedasiki]] va bat iyeltak.',
 'redirectstofile'                => 'Vlevef {{PLURAL:$1|graskan iyeltak|$1 graskan iyeltak}} va bat iyeltak :',
 'duplicatesoffile'               => 'Bat {{PLURAL:$1|iyeltak tir|$1 iyeltak tid}} jontolaca ke bat iyeltak:',
 'sharedupload'                   => 'Bat iyeltak tir dof nume gan ar abdumimaks zo rofaver.',
@@ -1047,7 +1045,7 @@
 'filedelete'                  => 'Sulara va $1',
 'filedelete-legend'           => 'Sulara va iyeltak',
 'filedelete-intro'            => "Rin va '''[[Media:$1|$1]]''' sulal.",
-'filedelete-intro-old'        => '<span class="plainlinks">Rin va siatos ke \'\'\'[[Media:$1|$1]]\'\'\' wetce [$4 $3, $2] sulal.</span>',
+'filedelete-intro-old'        => "Rin va siatos ke '''[[Media:$1|$1]]''' wetce [$4 $3, $2] sulal.",
 'filedelete-comment'          => 'Sebuks :',
 'filedelete-submit'           => 'Sulara',
 'filedelete-success'          => "'''$1''' al zo sular.",
@@ -1098,14 +1096,15 @@
 '''\$3''' bu zo rupeyed ise '''\$4''' zo betayad. Va mialuk va '''\$5''' betara fuxe bu is '''\$6''' rupera fuxe betara batcoba tadler.
 
 Abrotcuca ke [http://www.mediawiki.org/wiki/Manual:Job_queue \"job queue\"] tir '''\$7'''.",
-'userstatstext'          => "{{PLURAL:$1|Tir '''1''' vertokayan [[Special:Listusers|favesik]]|Tid '''$1''' vertokayan [[Special:Listusers|favesik]]}}. Vanmiaeon '''$2''' (ok '''$4%''') va $5 roka {{PLURAL:$2|digir|digid}}.",
+'userstatstext'          => "{{PLURAL:$1|Tir '''1''' vertokayan [[Special:ListUsers|favesik]]|Tid '''$1''' vertokayan [[Special:ListUsers|favesik]]}}. Vanmiaeon '''$2''' (ok '''$4%''') va $5 roka {{PLURAL:$2|digir|digid}}.",
 'statistics-mostpopular' => 'Tel lorupen bueem',
 
 'disambiguations'     => 'Bu dem milyoltaca yo',
 'disambiguationspage' => '{{ns:template}}:Milyoltaca',
 
-'doubleredirects'     => 'Jontolafa graskara',
-'doubleredirectstext' => "<b>Attention:</b> cette liste peut contenir des « faux positifs ». Dans ce cas, c'est probablement la page du premier #REDIRECT contient aussi du texte.<br />Chaque ligne contient les liens à la 1re et 2e page de redirection, ainsi que la première ligne de cette dernière, qui donne normalement la « vraie » destination. Le premier #REDIRECT devrait lier vers cette destination.",
+'doubleredirects'            => 'Jontolafa graskara',
+'doubleredirectstext'        => "<b>Attention:</b> cette liste peut contenir des « faux positifs ». Dans ce cas, c'est probablement la page du premier #REDIRECT contient aussi du texte.<br />Chaque ligne contient les liens à la 1re et 2e page de redirection, ainsi que la première ligne de cette dernière, qui donne normalement la « vraie » destination. Le premier #REDIRECT devrait lier vers cette destination.",
+'double-redirect-fixed-move' => 'arrundayan [[$1]], dure graskan kal [[$2]]',
 
 'brokenredirects'        => 'Arlizafa graskaraja yo',
 'brokenredirectstext'    => 'Kal metisu bu bata graskara yo stad.',
@@ -1187,7 +1186,7 @@
 'logempty'             => 'Mek trasiks koe "log" iyeltak.',
 'log-title-wildcard'   => 'Aneyara va vergumvelt dem mana toza',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Kotaf bueem',
 'alphaindexline'    => 'male $1 kale $2',
 'nextpage'          => 'Radimebu ($1)',
@@ -1205,15 +1204,16 @@
 # Special:Categories
 'categories'                    => 'Bulomeem',
 'categoriespagetext'            => 'Radimiasa loma se moe wiki krulded :',
+'categoriesfrom'                => 'Nedira va loma tozakirafa gu :',
 'special-categories-sort-count' => 'Otafa mubera',
 'special-categories-sort-abc'   => 'Abavafa mubera',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Fintara va favesikeem male :',
 'listusers-submit'   => 'Nedira',
 'listusers-noresult' => 'Mek trasiyin favesik.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rokeem ke favesiklospa',
 'listgrouprights-group'    => 'Lospa',
 'listgrouprights-rights'   => 'Rokeem',
@@ -1222,7 +1222,7 @@
 
 # E-mail user
 'mailnologin'     => 'Meke mane',
-'mailnologintext' => 'Rin gotil [[Special:Userlogin|dogluyarakiraf]]
+'mailnologintext' => 'Rin gotil [[Special:UserLogin|dogluyarakiraf]]
 is bazeyes va wadafe internetmane ko rinaf [[Special:Preferences|lodamaceem]]
 ta da pu ar favesik rostaksal.',
 'emailuser'       => 'Staksara va bat favesik',
@@ -1250,10 +1250,10 @@
 'nowatchlist'          => 'Rinafi suzdasiki va nedoy teliz ruldar.',
 'watchlistanontext'    => 'Ta wira ik betara va ra ke rinafi suzdasiki vay $1.',
 'watchnologin'         => 'Dogluyariskaf',
-'watchnologintext'     => 'Ta betara va suzdasiki gotil [[Special:Userlogin|dogluyarakiraf]].',
+'watchnologintext'     => 'Ta betara va suzdasiki gotil [[Special:UserLogin|dogluyarakiraf]].',
 'addedwatch'           => 'Loplekuyun ko suzdasiki',
 'addedwatchtext'       => "« $1 » bu ko rinafi [[Special:Watchlist|Suzdasiki]] fu zo loplekur.
-Va moniyaf betareem va batu bu is dofu prilarabu batlize zo bonjatad, ise ta lokaliafa tcalutera telu '''ton bold''' koe bu dem [[Special:Recentchanges|noeltaf betakseem]] turowinaweter.
+Va moniyaf betareem va batu bu is dofu prilarabu batlize zo bonjatad, ise ta lokaliafa tcalutera telu '''ton bold''' koe bu dem [[Special:RecentChanges|noeltaf betakseem]] turowinaweter.
 
 Ta sulara va batu bu div rinafi suzdasiki, koe grablexo va « Mea suzdá » vulegal.",
 'removedwatch'         => 'Sulayanu div suzdasiki',
@@ -1364,7 +1364,7 @@
 'revertpage'                  => 'Dimplekuyun betakseem ke [[Special:Contributions/$2|$2]] ([[User talk:$2|Prilara]]); dim ironokaf siatos ke [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Dimplekun betaks yo gan $1; dimpira ko ironokaf siatos ke $2.',
 'protectlogpage'              => 'Izvot va nendareem',
-'protectlogtext'              => 'Vleveon tir elekan is dimelekayan bueem. Ta vexala dem noelaf skus nendareem, va [[Special:Protectedpages|nendan bueem]] wil.',
+'protectlogtext'              => 'Vleveon tir elekan is dimelekayan bueem. Ta vexala dem noelaf skus nendareem, va [[Special:ProtectedPages|nendan bueem]] wil.',
 'protectedarticle'            => 'va « $1 » al nendar',
 'modifiedarticleprotection'   => 'betayana nendareka va "[[$1]]"',
 'unprotectedarticle'          => 'va « $1 » al dimnendar',
@@ -1497,7 +1497,7 @@
 'ipbotherreason'           => 'Ardume/lodume :',
 'badipaddress'             => 'IP mane tir mewadafe.',
 'blockipsuccesssub'        => 'Elekanhara',
-'blockipsuccesstext'       => "L'adresse IP « $1 » a été bloquée.<br />Vous pouvez consulter sur cette [[Special:Ipblocklist|page]] la liste des adresses IP bloquées.",
+'blockipsuccesstext'       => "L'adresse IP « $1 » a été bloquée.<br />Vous pouvez consulter sur cette [[Special:IPBlockList|page]] la liste des adresses IP bloquées.",
 'ipb-edit-dropdown'        => 'Betara va elekaralazava',
 'ipb-unblock-addr'         => 'Va $1 dimelekara',
 'ipb-unblock'              => 'Dimelekara va favesikyolt ok IP mane',
@@ -1528,7 +1528,7 @@
 'autoblocker'              => 'Bloqué automatiquement parce que vous partagez une adresse IP avec « $1 ». Raison : « $2 ».',
 'blocklogpage'             => 'Elekara log',
 'blocklogentry'            => 'Elekan [[$1]] kali $2 ke $3 evledja',
-'blocklogtext'             => 'Ceci est la trace des blocages et déblocages des utilisateurs. Les adresses IP automatiquement bloquées ne sont pas listées. Consultez la [[Special:Ipblocklist|liste des utilisateurs bloqués]] pour voir qui est actuellement effectivement bloqué.',
+'blocklogtext'             => 'Ceci est la trace des blocages et déblocages des utilisateurs. Les adresses IP automatiquement bloquées ne sont pas listées. Consultez la [[Special:IPBlockList|liste des utilisateurs bloqués]] pour voir qui est actuellement effectivement bloqué.',
 'unblocklogentry'          => 'grielekara va « $1 »',
 'block-log-flags-anononly' => 'anton yoltiskaf favesik',
 'block-log-flags-nocreate' => 'Pataredura gritegirana',
@@ -1580,8 +1580,6 @@
 
 Dans ce cas, vous devrez renommer ou fusionner la page manuellement si vous le désirez.",
 'movearticle'             => 'Tolyoltara va teliz',
-'movenologin'             => 'Dogluyariskaf',
-'movenologintext'         => 'Ede rin va teliz co-djutolyoltal, wetce koverteyen favesik gotil [[Special:Userlogin|dogluyarakiraf]].',
 'movenotallowed'          => 'Rin me zo rictal da ko {{SITENAME}} va bu rotarrundal.',
 'newtitle'                => 'Warzaf vergumvelt',
 'move-watch'              => 'Busuzdara',
@@ -1593,6 +1591,8 @@
 'talkexists'              => "La page elle-même a été déplacée avec succès, mais la page de discussion n'a pas pu être déplacée car il en existait déjà une sous le nouveau nom. S'il vous plait, fusionnez les manuellement.",
 'movedto'                 => 'Tolyoltayan ton',
 'movetalk'                => "Renommer aussi la page « discussion », s'il y a lieu.",
+'move-subpages'           => 'Arrundara va volveybueem, ede rotisa',
+'move-talk-subpages'      => 'Arrundara va volveybueem ke prilarabu, ede rotisa',
 'movepage-page-exists'    => '$1 bu ixam tir nume me balkon zo rotolsuter.',
 'movepage-page-moved'     => '$1 bu ko $2 su zo arrundar.',
 'movepage-page-unmoved'   => '$1 bu ko $2 me al zo rotarrundar.',
@@ -1604,12 +1604,13 @@
 'revertmove'              => 'dimplekura',
 'delete_and_move'         => 'Sulara is arplekura',
 'delete_and_move_text'    => '==Sulara eruna==
-"[[$1]]" kalefu bu ixam krulder.
+"[[:$1]]" kalefu bu ixam krulder.
 Kas ta askira va darka ta arrundara va in djusulal ?',
 'delete_and_move_confirm' => 'En, va bu sulal !',
 'delete_and_move_reason'  => 'Sulayan ta dark ta arrundara',
 'selfmove'                => 'Malef vergumvelt isu kalef tid mil;
 bu ika int me zo rotarrundar.',
+'imageinvalidfilename'    => 'Jalaf iyeltakyolt tir meenaf',
 
 # Export
 'export'            => 'Budivburera',
@@ -1808,10 +1809,10 @@
 'show-big-image'       => 'Geltraf lum',
 'show-big-image-thumb' => '<small>Lum ke bata abdinedira : $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Warzaf ewaviyeltak yo',
 'imagelisttext'         => "Tir vexala dem '''$1''' {{PLURAL:$1|iyeltak|iyeltak}} $2 pulana.",
-'newimages-summary'     => 'Batu aptafu bu va ironokaf kalvajayan iyeltakeem nedir',
+'newimages-summary'     => 'Batu aptafu bu va ironokaf kalvajayan iyeltakeem nedir.',
 'showhidebots'          => '($1 stiernik)',
 'noimages'              => 'Mecoba rowina',
 'ilsubmit'              => 'Aneyara',
@@ -2017,7 +2018,7 @@
 
 # External editor support
 'edit-externally'      => 'Betara va bat iyeltak faveson va divef talpey',
-'edit-externally-help' => 'Ta lo giva va [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] disukel !',
+'edit-externally-help' => 'Ta lo giva va [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] disukel !',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kot',
@@ -2073,7 +2074,7 @@
 'recreate'            => 'Tolredura',
 
 # HTML dump
-'redirectingto' => 'Graskas kal [[$1]]...',
+'redirectingto' => 'Graskas kal [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Palsexo ke batu bu zo gokarler ?
@@ -2163,7 +2164,7 @@
 'version-software-product'         => 'Warzeks',
 'version-software-version'         => 'Siatos',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Iyeltakkelda',
 'filepath-page'   => 'Iyeltak :',
 'filepath-submit' => 'Kelda',
@@ -2186,5 +2187,9 @@
 'specialpages-group-pagetools' => 'Buxekeem',
 'specialpages-group-wiki'      => 'Wiki origeem isu xekeem',
 'specialpages-group-redirects' => 'Graskara va aptabu',
+'specialpages-group-spam'      => 'Spam xekeem',
 
+# Special:BlankPage
+'blankpage' => 'Butuvlardara',
+
 );
Index: languages/messages/MessagesKy.php
===================================================================
--- languages/messages/MessagesKy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -204,7 +204,7 @@
 
 'license' => 'Лицензиялоо:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Файлдар тизмеси',
 
 # Image description page
@@ -234,7 +234,7 @@
 'specialloguserlabel'  => 'Колдонуучу:',
 'speciallogtitlelabel' => 'Аталышы:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Бардык барактар',
 'nextpage'       => 'Кийинки барак ($1)',
 'allpagesfrom'   => '-дан башталган барактарды көрсөт:',
@@ -303,7 +303,7 @@
 # Browsing diffs
 'nextdiff' => 'Кийинки айырма →',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Жаңы файлдардын галлереясы',
 'ilsubmit'  => 'Издөө',
 'bydate'    => 'Күнү боюнча',
Index: languages/messages/MessagesSs.php
===================================================================
--- languages/messages/MessagesSs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author MF-Warburg
  * @author Jatrobat
- * @author Siebrand
+ * @author MF-Warburg
  */
 
 $messages = array(
@@ -86,7 +85,7 @@
 # Preferences page
 'searchresultshead' => 'Kucálata',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_date' => 'Lusuku',
 'imagelist_name' => 'Ligama',
 'imagelist_user' => 'Umuntfu',
@@ -109,10 +108,10 @@
 'specialloguserlabel' => 'Umuntfu:',
 'log-search-submit'   => 'Kúhámba',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Kúhámba',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Kúfúna',
 
 # Watchlist
@@ -143,7 +142,7 @@
 'tooltip-search' => 'Kucálata {{SITENAME}}',
 'tooltip-p-logo' => 'Likhasi Lelikhulu',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Kucálata',
 
 # Multipage image navigation
Index: languages/messages/MessagesSw.php
===================================================================
--- languages/messages/MessagesSw.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSw.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,11 +5,9 @@
  * @file
  *
  * @author Malangali
- * @author לערי ריינהארט
- * @author Siebrand
- * @author SPQRobin
  * @author Marcos
  * @author Robert Ullmann
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -291,7 +289,7 @@
 'templatesusedpreview'   => 'Vigezo vinavyotumiwa katika mandhari haya:',
 'template-protected'     => '(kulindwa)',
 'template-semiprotected' => '(ulindaji kwa kiasi)',
-'nocreatetext'           => '{{SITENAME}} imebana uwezekano kutengeneza kurasa mpya. Unaweza kurudia na kuhariri kurasa zilizomo, au [[Special:Userlogin|ingia au anza akaunti]].',
+'nocreatetext'           => '{{SITENAME}} imebana uwezekano kutengeneza kurasa mpya. Unaweza kurudia na kuhariri kurasa zilizomo, au [[Special:UserLogin|ingia au anza akaunti]].',
 'recreate-deleted-warn'  => "'''Ilani: Unatengeneza tena ukurasa uliofutwa tayari.'''
 
 Fikiria kama inafaa kuendelea kuhariri ukurasa huu.
@@ -382,7 +380,7 @@
 'ignorewarning' => 'Hifadhi bila kujali maonyo yoyote.',
 'uploadedimage' => ' "[[$1]]" imepakiwa',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Orodha ya mafaili',
 
 # Image description page
@@ -471,7 +469,7 @@
 'log'                  => 'Kumbukumbu',
 'all-logs-page'        => 'Kumbukumbu zote',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Kurasa zote',
 'alphaindexline' => '$1 hadi $2',
 'nextpage'       => 'Ukurasa ujao ($1)',
@@ -494,7 +492,7 @@
 'addedwatch'           => 'Imeongezwa kwenye maangalizi yako',
 'addedwatchtext'       => "Ukurasa \"[[:\$1]]\" umewekwa kwenye [[Special:Watchlist|maangalizi]] yako.
 Mabadiliko katika ukurasa huo na ukurasa wake wa majadiliano utaonekana hapo,
-na ukurasa utaonyeshwa wenye '''koze''' kwenye [[Special:Recentchanges|orodha ya mabadiliko ya karibuni]]
+na ukurasa utaonyeshwa wenye '''koze''' kwenye [[Special:RecentChanges|orodha ya mabadiliko ya karibuni]]
 ili kukusaidia kutambua.
 
 Ukitaka kufuta ukurasa huo kutoka maangalizi yako baadaye, bonyeza \"Acha kufuatilia\" katika mwamba pembeni.",
@@ -698,7 +696,7 @@
 'show-big-image'       => 'Ukubwa wa awali',
 'show-big-image-thumb' => '<small>Ukubwa wa hakikisho hili: piseli $1 x $2</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Mkusanyiko wa faili jipya',
 
 # Bad image list
@@ -724,7 +722,7 @@
 
 # External editor support
 'edit-externally'      => 'Tumia programu ya nje kuhariri faili hii',
-'edit-externally-help' => 'Ona [http://meta.wikimedia.org/wiki/Help:External_editors maelezo (kwa Kiingereza)] kwa maarifa mengine.',
+'edit-externally-help' => 'Ona [http://www.mediawiki.org/wiki/Manual:External_editors maelezo (kwa Kiingereza)] kwa maarifa mengine.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'zote',
Index: languages/messages/MessagesBpy.php
===================================================================
--- languages/messages/MessagesBpy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBpy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Usingha
  * @author Uttam Singha, Dec 2006
- * @author Usingha
- * @author Siebrand
  */
 
 $digitTransformTable = array(
@@ -84,6 +83,7 @@
 'tog-nolangconversion'        => 'সারুকর সিলপা থেপকর',
 'tog-ccmeonemails'            => 'আরতারে দিয়াপেঠাউরি ইমেইল মরাঙউ কপি আহান যাকগা',
 'tog-diffonly'                => 'ফারাকর তলে পাতাহানর বিষয়বস্তু নাদেখাদি',
+'tog-showhiddencats'          => 'আরুমে আসে থাকহানি ফংকর',
 
 'underline-always'  => 'হারি সময়',
 'underline-never'   => 'সুপৌনা',
@@ -144,11 +144,14 @@
 'dec'           => 'ডিসে',
 
 # Categories related messages
-'pagecategories'        => '{{PLURAL:$1|থাক|থাকহানি}}',
-'category_header'       => '"$1" বিষয়রথাকে আসে নিবন্ধহানি',
-'subcategories'         => 'উপথাক',
-'category-media-header' => '"$1" থাকর মিডিয়া',
-'category-empty'        => "''এরে থাক এহাত এবাকা কোন পাতা বা মিডিয়া নেই''",
+'pagecategories'           => '{{PLURAL:$1|থাক|থাকহানি}}',
+'category_header'          => '"$1" বিষয়রথাকে আসে নিবন্ধহানি',
+'subcategories'            => 'উপথাক',
+'category-media-header'    => '"$1" থাকর মিডিয়া',
+'category-empty'           => "''এরে থাক এহাত এবাকা কোন পাতা বা মিডিয়া নেই''",
+'hidden-categories'        => '{{PLURAL:$1|গুরিসি থাকহান|গুরিসি থাকহানি}}',
+'hidden-category-category' => 'আরুম করিসি থাকহানি', # Name of the category where hidden categories will be listed
+'listingcontinuesabbrev'   => 'চলতই',
 
 'mainpagetext'      => "<big>'''মিডিয়াউইকি হবাবালা ইয়া ইন্সটল ইল'''</big>",
 'mainpagedocfooter' => 'উইকি সফটৱ্যার এহান আতানির বারে দরকার ইলে [http://meta.wikimedia.org/wiki/Help:Contents আতাকুরার গাইড]হানর পাঙলাক নেগা।
@@ -196,7 +199,9 @@
 'permalink'         => 'আকুবালা মিলাপ',
 'print'             => 'ছাপা',
 'edit'              => 'পতানি',
+'create'            => 'হঙকর',
 'editthispage'      => 'পাতা এহান পতিক',
+'create-this-page'  => 'পাতা এহান হঙকর',
 'delete'            => 'পুসানি',
 'deletethispage'    => 'পাতা এহান পুসে বেলিক',
 'undelete_short'    => 'পুসানিহান আলকর {{PLURAL:$1|পতাহান|$1 পতাহানি}}',
@@ -264,28 +269,42 @@
 'badaccess-group2' => 'তি যে কামহানর হেইচা করিসত, অহান করানির য়্যাথাং হুদ্দা $1 গ্রুপর আতাকুরারতা আসে।',
 'badaccess-groups' => 'তি যে কামহানর হেইচা করিসত, অহান করানির য়্যাথাং হুদ্দা $1 গ্রুপরতা আসে।',
 
-'ok'              => 'চুমিসে',
-'retrievedfrom'   => "'$1' -ত্ত আনানি অসে",
-'newmessageslink' => 'নুৱা পৌ',
-'editsection'     => 'পতিক',
-'editold'         => 'পতিক',
-'toc'             => 'মেথেল',
-'showtoc'         => 'ফংকর',
-'hidetoc'         => 'মেথেল আরুম কর',
+'ok'                  => 'চুমিসে',
+'retrievedfrom'       => "'$1' -ত্ত আনানি অসে",
+'youhavenewmessages'  => 'তরতা $1 ($2) আসে।',
+'newmessageslink'     => 'নুৱা পৌ',
+'newmessagesdifflink' => 'গেলগা সিলপা',
+'editsection'         => 'পতিক',
+'editold'             => 'পতিক',
+'viewsourceold'       => 'উৎস চা',
+'editsectionhint'     => 'সেকসনহান পতা: $1',
+'toc'                 => 'মেথেল',
+'showtoc'             => 'ফংকর',
+'hidetoc'             => 'মেথেল আরুম কর',
+'site-rss-feed'       => '$1 আরএসএস ফিড',
+'site-atom-feed'      => '$1 এটম ফিড',
+'page-rss-feed'       => '"$1" আরএসএস ফিড',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'নিবন্ধ',
 'nstab-user'      => 'আতাকুরার পাতা',
 'nstab-special'   => 'বিশেষ',
 'nstab-project'   => 'প্রকল্প পাতা',
+'nstab-image'     => 'ফাইল',
 'nstab-mediawiki' => 'পৌ',
+'nstab-template'  => 'মডেল',
+'nstab-help'      => 'পাঙলাকর পাতা',
+'nstab-category'  => 'থাক',
 
 # General errors
 'error'              => 'লালুইসে',
 'cachederror'        => 'এরে পাতা এহান বা লাতলগ পুছানি নাকরল। (নিঙকরুরিতাঃ আগেদে কুঙগ আগই পুছে বেলাসিসাত)',
 'badarticleerror'    => 'এরে পাতা এহান কাম এহান করানি সম্ভব নেই।',
-'badtitle'           => 'শিরোনাঙহান গ্রহনযোগ্য নাইসে।',
+'badtitle'           => 'চিঙনাঙহান চুমনাইসে নাইসে।',
+'badtitletext'       => 'হেইচা করিসত পাতাহানর চিঙনাঙহান চুম নাইসে, খালি বা আর ঠার বা আন্তঃউইকি চিঙনাঙ মিলাপ অসিল। হয়ত এহানত আক বারো গজে কোন আখর মিহিসে, যেতা চিঙনাঙে বরানি লালুইসে।',
 'viewsource'         => 'উৎসহান চা',
+'viewsourcefor'      => '$1-র কা',
+'viewsourcetext'     => 'পাতা এহানর উত্স চা বারো কপি করে পারর:',
 'protectedinterface' => 'পাতা এহানর মেথেল উইকি সফটওয়্যারর ইন্টারফেসর পৌহান দের, অহানে এহানরে ইতু করিয়া থনা অসে এবিউসেত্ত ঙাক্করানির কাজে।',
 
 # Login and logout pages
@@ -300,14 +319,50 @@
 'remembermypassword'         => 'এরে কম্পিউটার এহাত্ত সাইট এহাত মর হমানিহান মনে থ',
 'yourdomainname'             => 'তর ডোমেইনগ',
 'login'                      => 'হমানি',
+'nav-login-createaccount'    => 'লগইন / একাউন্ট খুল',
+'loginprompt'                => 'তি যেসাদেউ [[Special:UserLogin|হমাসি {{SITENAME}}]] পাতা এহানর কুকিসর য়্যাথাঙ দে।',
 'userlogin'                  => 'হমানি / নৱা একাউন্ট খুলানি',
 'logout'                     => 'নিকুলানি',
 'userlogout'                 => 'নিকুলানি',
+'nologin'                    => 'লগইন নেই? $1.',
+'nologinlink'                => 'একাউন্ট আহান খুল',
+'createaccount'              => 'একাউন্ট খুল',
+'gotaccount'                 => 'মান্নাপা একাউন্ট আহান আগেত্তর আসে? $1।',
+'gotaccountlink'             => 'লগইন',
 'badretype'                  => 'খন্তাচাবি (password) দ্বিয়গি না মিলের।',
 'youremail'                  => 'ই-মেইল *:',
 'yourrealname'               => 'আৱৈপা নাংহান *:',
 'yourlanguage'               => 'ঠারহান:',
 'yournick'                   => 'দাহানির নাংহান:',
+'email'                      => 'ইমেইল',
+'prefs-help-realname'        => 'আয়ৌপা নাংহান নাদলেউ চলের।
+যদি তি দের অতাইলে তর কামর থাকাত দেনাত সুবিধা অইতই।',
+'loginerror'                 => 'লগইনে লালুইসে',
+'loginsuccesstitle'          => 'লগইনহান চুমিল',
+'loginsuccess'               => "'''এরে {{SITENAME}}ত তি \"\$1\" হিসাবে না হমাসত।'''",
+'nosuchuser'                 => 'এরে "$1" নাঙর কোন আতাকুরা নেই।
+তর বানানহান খিয়াল কর, নাইলে আরাক আহান হঙকর।',
+'nosuchusershort'            => 'এরে "<nowiki>$1</nowiki>" নাঙর কোন আতাকুরা নেই।
+তর বানানহান খিয়াল কর।',
+'nouserspecified'            => 'তি আতাকুরার নাঙ আহান থনা লাগতই।',
+'wrongpassword'              => 'খন্তাচাবি চুম নাইসে।
+আলথকে হতনা কর।',
+'wrongpasswordempty'         => 'খন্তা চাবি খালি ইসে।
+বারো হতনা কর।',
+'passwordtooshort'           => 'খন্তাচাবি লালুইসে নাইলে বাট্টি ইসে।
+খন্তাচাবি যেসারেউ {{PLURAL:$1|মেয়েক আকগর|$1 মেয়েকগির}} বারো আতাকুরার নাঙেত্ত তঙাল অনা লাগতই।',
+'mailmypassword'             => 'খন্তাচাবি ইমেইল করেদে',
+'passwordremindertitle'      => 'নুয়া খন্তাচাবি {{SITENAME}}র কাজে',
+'passwordremindertext'       => 'কুঙগ আগই (মনে অর তি, $1 আইপি ঠিকানা এহাত্ত) হেইচা করিসত যে আমি তরে {{SITENAME}}-র কা আরাক নুৱা খন্তাচাবি দিয়া পেঠাদেনা ($4)।
+"$2" নাঙর আতাকুরার এপাগার খন্তাচাবি "$3"।
+তি একাউন্টহান হমিয়াই খন্তাচাবি বদালানি থকিতই।
+
+তি নায়া আরাক আগই হেইচা করিয়া থাইতারা, নাইলে তরতা পুরানা খন্তাচাবিগ নিঙশিঙ ইয়া থার অতাইলে বারো অগ সিলকরানির খৌরাঙ না থার অতা ইলে এরে পৌ এহান বেলিয়া পুরানা খন্তাচাবিগই আতা পারতেই।',
+'noemail'                    => 'এহানাত আতাকুরা "$1"র কুন ইমেল ঠিকানা নেয়সে।',
+'passwordsent'               => 'নুৱা খন্তাচাবি দিয়াপেঠানি ইল আতাকুরা "$1"র ইমেইল ঠিকানাত।
+কৃপা করিয়া লগইন কর পানার লগে লগে।',
+'eauthentsent'               => 'লেপ্পা ইমেইল আহান তি দিয়াসিলে ইমেইল ঠিকানাহাত দিয়া পেঠানি ইল।
+আর কোন ইমেইল দিয়া এপঠানির আগেই তি পাসত ইমেইল অহানর নিদর্শনা ইলয়া যাগা, এহান করানি অরতা তর ইমেইল ঠিকানাহান চুমিসেতানা কিতা লেপকরানির কা।',
 'acct_creation_throttle_hit' => 'ঙাক্করেদিবাং, তি এবাকাপেয়া $1হান অ্যাকাউন্ট হংকরেবেলাসত৷ অতাত্ত বপ হঙকরানির য়্যাথাং নেই।৷',
 'accountcreated'             => 'একাউন্টহান হঙকরানি ইল',
 'accountcreatedtext'         => 'আতাকুরা $1 -র কা একাউন্টহান হঙকরানি ইল।',
@@ -315,90 +370,258 @@
 # Edit page toolbar
 'bold_sample'     => 'গাঢ়পা ৱাহি',
 'bold_tip'        => 'গাঢ়পা ৱাহি',
+'italic_sample'   => 'ইটালিক মেয়েক',
+'italic_tip'      => 'ইটালিক মেয়েক',
+'link_sample'     => 'চিঙনাঙ মিলাপ',
+'link_tip'        => 'ভিতরর মিলাপ',
+'extlink_sample'  => 'http://www.example.com চিঙনাঙ মিলাপ',
+'extlink_tip'     => 'বারেদের মিলাপ (মুঙে http:// বারনি না পাহুরিস)',
 'headline_sample' => 'চিঙনাঙর খন্তাহানি',
+'headline_tip'    => 'থাক ২র চিঙনাঙ',
+'math_sample'     => 'এহাত সুত্র বরা',
+'math_tip'        => 'অংকর সুত্র (LaTeX)',
+'nowiki_sample'   => 'ফরমেট নাকরিসি মেয়েক বরা',
 'nowiki_tip'      => 'উইকির পাজালানিহান লালুয়া যাগা',
+'image_tip'       => 'তিলকরিসি ফাইলগ',
+'media_tip'       => 'ফাইল মিলাপ',
+'sig_tip'         => 'তর স্বাক্ষরহান লগে খেন্তাম বরিয়া',
+'hr_tip'          => 'পাথারি খাস (খানি করা ইয়া আতা)',
 
 # Edit pages
-'minoredit'        => 'এহান হুরু-মুরু সম্পাদনাহানহে।',
-'watchthis'        => 'পাতাএহান খিয়ালে থ',
-'anoneditwarning'  => "'''সিঙুইসঃ''' তি লগইন নাকরিসত। পতানির ইতিহাসহাত তর IP addressহান সিজিল ইতই।",
-'blockedtitle'     => 'আতাকুরাগরে থেপ করানি অসে',
-'blockedtext'      => "তর আতাকুরা নাঙহান নাইলেউ আইপি ঠিকানাহানরে $1 থেপকরানি অসে। এহানর কারণহান অসেতাইঃ:<br />''$2''
+'summary'                => 'সারমর্ম',
+'subject'                => 'বিষয়/চিঙনাঙ',
+'minoredit'              => 'এহান হুরু-মুরু সম্পাদনাহানহে।',
+'watchthis'              => 'পাতাএহান খিয়ালে থ',
+'savearticle'            => 'পাতাহান ইতুকর',
+'preview'                => 'আগচা',
+'showpreview'            => 'আগচা',
+'showdiff'               => 'পতাসিতা দেহাদে',
+'anoneditwarning'        => "'''সিঙুইসঃ''' তি লগইন নাকরিসত। পতানির ইতিহাসহাত তর IP addressহান সিজিল ইতই।",
+'summary-preview'        => 'সারমর্মর আগচা',
+'blockedtitle'           => 'আতাকুরাগরে থেপ করানি অসে',
+'blockedtext'            => "<big>'''তর আতাকুরা নাঙহান নাইলেউ আইপি ঠিকানাহানরে থেপকরানি অসে।'''</big>
 
-তি $1 নাইলেউ [[{{MediaWiki:Grouppage-sysop}}|প্রশাসকর]] মা যে কোন আগর লগে বিষয় এহান্ন য়্যারি পরি দে পারর। বিশেষ মাতিলতাঃ তর ই-মেইল ঠিকানাহান যদি [[Special:Preferences|তর পছন তালিকাত]] বরিয়া নাথার, অতা ইলে তি উইকিপিডিয়াত হের আতাকুরারে ই-মেইল করানি নুৱারবে। তর আইপি ঠিকানাহান ইলতাই $3। কৃপা করিয়া যে কোন যোগাযোগর সময়ত এরে ঠিকানা এহান যেসাদেউ বরিস।",
-'confirmedittitle' => 'সম্পাদনা করানির কা ই-মেইল লেপকানি থকিতই',
-'confirmedittext'  => 'যেহানউ সম্পাদনা করানির আগে তর ই-মেইল ঠিকানাহন যেসাদেউ লেপকরানি লাগতই। কৃপাকরিয়া তর ই-মেইল ঠিকানাহান [[Special:Preferences|আতাকুরার পছনতালিকা]]ত চুমকরে বরা।',
-'loginreqtitle'    => 'লগইন দরকার ইসে',
-'accmailtitle'     => 'খন্তাচাবি(password) দিয়াপেঠৱা দিলাং।',
-'accmailtext'      => '"$1"-র খন্তাচাবি(password) $2-রাঙ দিয়াপেঠৱাদেনা ইল।',
-'anontalkpagetext' => "''এহান অচিনা অতার য়্যারির পাতাহান। এরে আইপি ঠিকানা (IP Address) এহানাত্ত লগ-ইন নাকরিয়া পতানিত মেইক্ষু অসিল। আক্কুস ক্ষেন্তামে আইপি ঠিকানা হামেসা বদল অর, বিশেষ করিয়া ডায়াল-আপ ইন্টারনেট, প্রক্সি সার্ভার মাহি ক্ষেত্র এতা সিলরতা, বারো আগত্ত বপ ব্যবহারকারেকুরার ক্ষেত্রত প্রযোজ্য ইতে পারে। অহানে তি নিশ্চকে এরে আইপি এহাত্ত উইকিপিডিয়াত হমিয়া কোন য়্যারী দেখর, অহান তরে নিঙকরিয়া নাউ ইতে পারে। অহানে হাবিত্ত হবা অর, তি যদি [[Special:Userlogin|লগ-ইন করর, বা নৱা একাউন্ট খুলর]] অহানবুলতেউ লগ-ইন করলে কুঙগউ তর আইপি ঠিকানাহান, বারো অহানর মাতুঙে তর অবস্থানহান সুপকরেউ হার না পেইবা।''",
-'clearyourcache'   => "'''খিয়াল থ:''' তর পছনহানি রক্ষা করানির থাঙনাত পতাহানি চানার কা তর ব্রাউজারর ক্যাশ লালুয়া যানা লাগতে পারে। '''মোজিলা/ফায়ারফক্স/সাফারি:''' শিফট কী চিপিয়া থয়া রিলোড-এ ক্লিক কর, নাইলে ''কন্ট্রোল-শিফট-R''(এপল ম্যাক-এ ''কমান্ড-শিফট-R'') আকপাকে চিপা; '''ইন্টারনেট এক্সপ্লোরার:''' ''কন্ট্রোল'' চিপিয়া থয়া রিফ্রেশ-এ ক্লিক কর, নাইলে ''কন্ট্রোল-F5'' চিপা; '''কংকারার:''' হুদ্দা রিলোড ক্লিক করলে বা F5 চিপিলে চলতই; '''অপেরা''' আতাকুরাই ''Tools→Preferences''-এ গিয়া কাশ সম্পূর্ণ ঙক্ষি করানি লাগতে পারে।",
-'yourtext'         => 'তর ইকরা বিষয়হানি',
-'yourdiff'         => 'ফারাকহানি',
+থেপকরিসেতাই: $1
+এহানর কারণহান অসেতাইঃ: ''$2''
 
+* থেপকরানি অকরিসিতা: $8
+* থেপকরানিহান লমিতইতা: $6
+* থেপকরানি মনাসিলাতা: $7
+
+তি $1 নাইলেউ [[{{MediaWiki:Grouppage-sysop}}|প্রশাসকর]] মা যে কোন আগর লগে বিষয় এহান্ন য়্যারি পরি দে পারর। বিশেষ মাতিলতাঃ তর ই-মেইল ঠিকানাহান যদি [[Special:Preferences|তর পছন তালিকাত]] বরিয়া নাথার, অতা ইলে তি উইকিপিডিয়াত হের আতাকুরারে ই-মেইল করানি নুৱারবে। তর আইপি ঠিকানাহান ইলতাই $3 বারো থেপকরিসি আইপিগ ইলতাই #$5। 
+কৃপা করিয়া যে কোন যোগাযোগর সময়ত এরে আইপি ঠিকানাহানি যেসাদেউ বরিস।",
+'confirmedittitle'       => 'সম্পাদনা করানির কা ই-মেইল লেপকানি থকিতই',
+'confirmedittext'        => 'যেহানউ সম্পাদনা করানির আগে তর ই-মেইল ঠিকানাহন যেসাদেউ লেপকরানি লাগতই। কৃপাকরিয়া তর ই-মেইল ঠিকানাহান [[Special:Preferences|আতাকুরার পছনতালিকা]]ত চুমকরে বরা।',
+'loginreqtitle'          => 'লগইন দরকার ইসে',
+'accmailtitle'           => 'খন্তাচাবি(password) দিয়াপেঠৱা দিলাং।',
+'accmailtext'            => '"$1"-র খন্তাচাবি(password) $2-রাঙ দিয়াপেঠৱাদেনা ইল।',
+'newarticle'             => '(নুৱা)',
+'newarticletext'         => 'এর নিবন্ধ এহান এপাগাউ {{SITENAME}}-ত না তিলসে। তি চেইলে তলর বক্সগত বিষয়হানর বারে খানি ইকরিয়া ইতুকরে পারর বারো নিবন্ধহান অকরে পারর। যদি হারনাপেয়া এহাত আহিয়া থার অতা ইলে ব্রাউজারর ব্যাক গুতমগত ক্লিক করিয়া আগর পাতাত আল পারর।',
+'anontalkpagetext'       => "''এহান অচিনা অতার য়্যারির পাতাহান। এরে আইপি ঠিকানা (IP Address) এহানাত্ত লগ-ইন নাকরিয়া পতানিত মেইক্ষু অসিল। আক্কুস ক্ষেন্তামে আইপি ঠিকানা হামেসা বদল অর, বিশেষ করিয়া ডায়াল-আপ ইন্টারনেট, প্রক্সি সার্ভার মাহি ক্ষেত্র এতা সিলরতা, বারো আগত্ত বপ ব্যবহারকারেকুরার ক্ষেত্রত প্রযোজ্য ইতে পারে। অহানে তি নিশ্চকে এরে আইপি এহাত্ত উইকিপিডিয়াত হমিয়া কোন য়্যারী দেখর, অহান তরে নিঙকরিয়া নাউ ইতে পারে। অহানে হাবিত্ত হবা অর, তি যদি [[Special:UserLogin|লগ-ইন করর, বা নৱা একাউন্ট খুলর]] অহানবুলতেউ লগ-ইন করলে কুঙগউ তর আইপি ঠিকানাহান, বারো অহানর মাতুঙে তর অবস্থানহান সুপকরেউ হার না পেইবা।''",
+'noarticletext'          => 'এপাগা এরে পাতাত কোন টেক্সট নেই। তি মনেইলে হের পাতাহান [[Special:Search/{{PAGENAME}}|এরে চিঙনাঙল বিসারা পারর]] নাইলে [{{fullurl:{{FULLPAGENAME}}|action=edit}} এরে পাতা এহান পতা পারর]।',
+'clearyourcache'         => "'''খিয়াল থ:''' তর পছনহানি রক্ষা করানির থাঙনাত পতাহানি চানার কা তর ব্রাউজারর ক্যাশ লালুয়া যানা লাগতে পারে। '''মোজিলা/ফায়ারফক্স/সাফারি:''' শিফট কী চিপিয়া থয়া রিলোড-এ ক্লিক কর, নাইলে ''কন্ট্রোল-শিফট-R''(এপল ম্যাক-এ ''কমান্ড-শিফট-R'') আকপাকে চিপা; '''ইন্টারনেট এক্সপ্লোরার:''' ''কন্ট্রোল'' চিপিয়া থয়া রিফ্রেশ-এ ক্লিক কর, নাইলে ''কন্ট্রোল-F5'' চিপা; '''কংকারার:''' হুদ্দা রিলোড ক্লিক করলে বা F5 চিপিলে চলতই; '''অপেরা''' আতাকুরাই ''Tools→Preferences''-এ গিয়া কাশ সম্পূর্ণ ঙক্ষি করানি লাগতে পারে।",
+'previewnote'            => '<strong>এহান হুদ্দা আগচাহান;
+ফারাকহান এপাগাউ ইতু করানি নাইসে!</strong>',
+'editing'                => 'পতানি চলের $1',
+'editingsection'         => '$1র পতানি চলের (ডেংগ)',
+'yourtext'               => 'তর ইকরা বিষয়হানি',
+'yourdiff'               => 'ফারাকহানি',
+'copyrightwarning'       => 'দয়া করিয়া খিয়াল কর {{SITENAME}}-ত হারি অবদান $2-র মাতুঙে পাসিতা (আরাকউ হবাকরে $1-ত চা)। তর জমা দিয়াসত লেখা যেগউ বে-রিদয় ইয়া পতিতে পারে বারো যেসারে খুশি অসারে বিলিতে পারে। তি যদি এহানর বারে একমত নার, অতা ইলে তর লেখা এহাত জমা নাদি।<br />
+তি আরাকউ ৱাশাক করর যে, এরে লেখা এহান তি নিজে ইকিসতহান, নাইলে  হাব্বির কা উন্মুক্ত কোন উৎস আহাত্ত পাসতহান।
+<strong>স্বত্ব সংরক্ষিত অসে অসাদে কোন লেখা স্বত্বাধিকারীর য়্যাথাঙ না লুইয়া এহাত জমা না দিস!</strong>',
+'longpagewarning'        => '<strong>সিঙুইস: এরে পাতা এহান $1 কিলোবাইট ডাঙর; ব্রাউজার আকেইগত ৩২ কিলোবাইটর গজে ডাঙর পাতানিত বেরা ইতে পারে।
+দয়া করিয়া পাতা এহানরে হুরকা হুরকা কত অংশত খেইকরানির হতনা কর।</strong>',
+'templatesused'          => 'পাতাহান মডেল বরাসিতা:',
+'templatesusedpreview'   => 'আগচা এহানাত মিহিসে মডেল:',
+'template-protected'     => '(লুকরিসি)',
+'template-semiprotected' => '(আধা-কাচা লুকরিসি)',
+'nocreatetext'           => '{{SITENAME}}-এরে নুৱা পাতা এহানর পতানিহানাত থিতপা আসে।
+তি আলথকে গিয়া আসে হের পাতা সিলকরানি পারর, নাইলে [[Special:UserLogin|অ্যাকাউন্টহানাত হমানি বারো অ্যাকাউন্ট খুলে পারর]]।',
+'recreate-deleted-warn'  => "'''সিঙুইস: তি যে পতাহান হঙকরলে অহান আগে আরাকমু হঙকরানি অসিল।
+
+পাতা এহান তি আরাতা হঙকরতেইতানা কিতা খালকরিয়া চা।
+তর সুবিধারকা পাতা এহানর পুসিসি লগ এহানাত দেনা ইল:",
+
 # History pages
+'viewpagelogs'        => 'পাতাহানর লগ চা',
 'currentrev'          => 'হাদিএহানর পতানি',
+'revisionasof'        => 'রিভিসনহান $1 পেয়া',
+'revision-info'       => '$1 পেয়া  $2-এ পতাসেতা',
+'previousrevision'    => '←পুরানা পতানিহান',
+'nextrevision'        => 'নুৱা ভার্সনহান→',
 'currentrevisionlink' => 'হাদি এহানর পতানি',
+'cur'                 => 'এপাগা',
+'last'                => 'লাতঙ',
+'page_first'          => 'পয়লাকা',
+'page_last'           => 'লমনিত',
 'histlegend'          => 'ফারাক (Diff) বাছানি: যে সংস্করণহানি তুলনা করানি চার, অহান লেপকরিয়া এন্টার বা তলর খুথামগত যাতা।<br />
 নির্দেশিকা: (এব) = এবাকার সংস্করণহানর লগে ফারাক,(আ) =  জানে আগে-আগে গেলগা সংস্করণহানর লগে ফারাক, হ = হুরু-মুরু (নামাতলেউ একরব অসারে) সম্পাদনাহান।',
 'histfirst'           => 'হাব্বিত্ত পুরানা',
 'histlast'            => 'হাব্বিত্ত নুৱা',
 
+# Revision feed
+'history-feed-item-nocomment' => '$1 খেন্তাম $2 ত', # user at time
+
 # Diffs
+'history-title'           => '"$1"-র রিভিসন ইতিহাসহান',
+'difference'              => '(রিভিসনহানির ফারাকহান)',
+'lineno'                  => 'লাইন $1:',
 'compareselectedversions' => 'বাসাইল সংস্করণহানি তুলনা কর',
+'editundo'                => 'আলকর',
+'diff-multi'              => '({{PLURAL:$1|হমবুকর রিভিসন আহান|$1 হমবুকর রিভিসন হানি}} দেহাদেনা এহাত না মিহিসে।)',
 
+# Search results
+'noexactmatch' => "'''\"\$1\" চিংনাঙর কোন পাতা নেই।'''
+তি [[:\$1|পাতা এহান হঙকরে পারর]]।",
+'prevn'        => 'পিসেদে $1',
+'nextn'        => 'থাংনাত $1',
+'viewprevnext' => 'চা ($1) ($2) ($3)',
+'powersearch'  => 'এডভান্স বিসারানি',
+
 # Preferences page
+'preferences'    => 'পছনহানি',
 'mypreferences'  => 'মর পছন',
 'changepassword' => 'খন্তাচাবি(password) পতা',
 'saveprefs'      => 'ইতু',
+'retypenew'      => 'নুৱা খন্তাচাবি বারো টাইপ কর:',
 'columns'        => 'দুরগিঃ',
 'allowemail'     => 'আরতা(ব্যবহার করেকুরা)ই ইমেইল করানির য়্যাথাং দে।',
 
+'grouppage-sysop' => '{{ns:project}}:প্রশাসকগি',
+
+# User rights log
+'rightslog' => 'আতাকুরার অধিকারর লগ',
+
 # Recent changes
-'recentchanges'   => 'হাদিএহান পতাসিতা',
-'diff'            => 'ফারাক',
-'hist'            => 'ইতিহাসহান',
-'hide'            => 'আরুম',
-'minoreditletter' => 'হ',
-'newpageletter'   => 'নু',
-'boteditletter'   => 'ব',
+'nchanges'                       => '$1 {{PLURAL:$1|সিলপা|সিলপাহানি}}',
+'recentchanges'                  => 'হাদিএহান পতাসিতা',
+'recentchanges-feed-description' => 'ফিড এহানর মা পাতা এহার পতানিহানর গজে মিল্লেং দে।',
+'rcnote'                         => 'গেলগা <strong>$2</strong> দিনে পতাসি <strong>$1</strong> হান পরিবর্তন তলে দেখাদেনা ইলতা $5, $4 পেয়া।',
+'rcnotefrom'                     => "তলে গেলগা '''$2''' ত্ত পতাসিতা দেনা অইল ('''$1''' পেয়া)।",
+'rclistfrom'                     => 'নুৱাতা পতাসিতা $1 পাতাহানাত্ত চিঙকরিয়া',
+'rcshowhideminor'                => '$1 হুরু পতানিহান',
+'rcshowhidebots'                 => '$1 বটগি',
+'rcshowhideliu'                  => '$1 হমাসি আতাকুরা',
+'rcshowhideanons'                => '$1 হারানাপাসি আতাকুরা',
+'rcshowhidepatr'                 => '$1 পাহারাত আসে পতানি',
+'rcshowhidemine'                 => '$1 মর পাতানিহানি',
+'rclinks'                        => 'গেলগা $1 হান পতানি দেখাদে $2 দিনরতা <br />$3',
+'diff'                           => 'ফারাক',
+'hist'                           => 'ইতিহাসহান',
+'hide'                           => 'আরুম',
+'show'                           => 'দেখাদে',
+'minoreditletter'                => 'হ',
+'newpageletter'                  => 'নু',
+'boteditletter'                  => 'ব',
 
 # Recent changes linked
-'recentchangeslinked' => 'সাকেই আসে পতা',
+'recentchangeslinked'          => 'সাকেই আসে পতা',
+'recentchangeslinked-title'    => 'পতানিহান "$1"র লগে সর্ম্পক আসে',
+'recentchangeslinked-noresult' => 'দেনা অসে খেন্তামর ভিতরে পতাসিতা নেই।',
+'recentchangeslinked-summary'  => "লেপকরা পাতা আহান (অথবা লেপকরা বিষয়শ্রেণী)ত্ত তিলসে এরে পাতা এহানর হাদি এহান পতাসি অহানর লাতঙ দেনা অইল। তর [[Special:Watchlist|তর চালাতঙ]]এ থসি পাতাহানি '''গাঢ়''' করিয়া দেহাদেনা অসে।",
 
 # Upload
 'upload'          => 'আপলোড ফাইল',
 'uploadbtn'       => 'আপলোড',
+'uploadlogpage'   => 'আপলোড করিসি লগ',
 'badfilename'     => 'ফাইলগর নাঙহান পতিয়া $1" করানি ইল।',
 'savefile'        => 'ফাইল ইতু',
+'uploadedimage'   => 'আপলোডকরানি অইল "[[$1]]"',
 'watchthisupload' => 'পাতাএহান খিয়ালে থ',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'ছবির তালিকা',
 
 # Image description page
-'imagelinks' => 'জুরিসিতা',
+'filehist'                  => 'ফাইলর ইতিহাস',
+'filehist-help'             => 'দিন/সময়-র গজে যাতিলে ঔ খেন্তাম পেয়া হঙিসে ফাইলগ চ পারতেই।',
+'filehist-current'          => 'এপাগা',
+'filehist-datetime'         => 'দিন/সময়',
+'filehist-user'             => 'আতাকুরা',
+'filehist-dimensions'       => 'চাঙহান',
+'filehist-filesize'         => 'ফাইলর সাইজহান',
+'filehist-comment'          => 'মতহান',
+'imagelinks'                => 'জুরিসিতা',
+'linkstoimage'              => 'এরে ফাইলর লগে {{PLURAL:$1|পাতার মিলাপ|$1 পাতাহানির মিলাপ}} আসে:',
+'nolinkstoimage'            => 'ফাইল এগর লগে মিলাপ অসে অসাদে কোন পাতা নেই।',
+'sharedupload'              => 'ফাইল এগ শেয়ার আপলোডে আসে, মনে অর আর আর প্রকল্পউ আতিতারা।',
+'noimage'                   => 'এরে নাঙর কোন ফাইল নেই, তি পারর $1।',
+'noimage-linktext'          => 'আপলোড কর',
+'uploadnewversion-linktext' => 'এরে ফাইল এগর নুৱা সংস্করনহান আপলোড কর',
 
+# MIME search
+'mimesearch' => 'MIME বিসারানি',
+
+# List redirects
+'listredirects' => 'আলথক করেদের পাতার লাতঙগি',
+
+# Unused templates
+'unusedtemplates' => 'বপ নাচলের মডেলহানি',
+
 # Random page
 'randompage' => 'খাংদা পাতা',
 
+# Random redirect
+'randomredirect' => 'চৌরাপ আলথকপা',
+
+# Statistics
+'statistics' => 'হিসাবহান',
+
+'disambiguations' => 'সন্দই চুমকরের পাতাহানি',
+
+'doubleredirects' => 'আলথকে যানা দ্বিমাউ মাতের',
+
 'brokenredirects' => 'বারো-নির্দেশ কামনাকরের',
 
+'withoutinterwiki' => 'ঠারর মিলাপ নেয়সে পাতাহানি',
+
+'fewestrevisions' => 'যে পাতাহানির কম রিভিসন অসে',
+
 # Miscellaneous special pages
-'nbytes'       => '$1 বাইট',
-'ncategories'  => '$1 {{PLURAL:$1|থাক|থাকহানি}}',
-'ancientpages' => 'পুরানা পাতাহানি',
-'move'         => 'থেইকরানি',
+'nbytes'                  => '$1 বাইট',
+'ncategories'             => '$1 {{PLURAL:$1|থাক|থাকহানি}}',
+'nlinks'                  => '$1 {{PLURAL:$1|মিলাপ|মিলাপহানি}}',
+'nmembers'                => '$1 {{PLURAL:$1|আতাকুরা|আতাকুরাগি}}',
+'lonelypages'             => 'এতিম পাতাহানি',
+'uncategorizedpages'      => 'বিষয়রথাকে নাবেলাসি পাতাহানি',
+'uncategorizedcategories' => 'বিষয়থাকে নাবেলাসি থাকহানি',
+'uncategorizedimages'     => 'বিষয়থাকে নাবেলাসি ফাইলগি',
+'uncategorizedtemplates'  => 'বিষয়থাকে নাবেলাসি থাকহানি',
+'unusedcategories'        => 'বিষয়থাক বপ নাচলের',
+'unusedimages'            => 'নাচলের ফাইলগি',
+'wantedcategories'        => 'চারাঙ বিষয়র থাকহানি',
+'wantedpages'             => 'খৌরাঙর পাতাহানি',
+'mostlinked'              => 'হাবিত্ত মিলাপ বপিসে পাতাহানি',
+'mostlinkedcategories'    => 'বিষয়থাকে য়্যামসে মিলাপ',
+'mostlinkedtemplates'     => 'মডেলহানিত য়্যামসে মিলাপ',
+'mostcategories'          => 'বপতা বিষয়থাকর পাতাহানি',
+'mostimages'              => 'ফাইলগিত য়্যামসে মিলাপ',
+'mostrevisions'           => 'রিভিসন বপসে পাতাহানি',
+'prefixindex'             => 'প্রিফিক্স সুচি',
+'shortpages'              => 'হুরু পাতাহানি',
+'longpages'               => 'ডাঙর পাতাহানি',
+'deadendpages'            => 'যে পাতাহানিত্ত কোন মিলাপ নেই',
+'protectedpages'          => 'লুকরিসি পাতাহানি',
+'listusers'               => 'আতাকুরার লাতংগ',
+'newpages'                => 'নুৱা পাতাহানি',
+'ancientpages'            => 'পুরানা পাতাহানি',
+'move'                    => 'থেইকরানি',
+'movethispage'            => 'পাতা এহান থেইকর',
 
 # Book sources
 'booksources' => 'লেরিকর উৎসহান',
 
 # Special:Log
-'specialloguserlabel' => 'আতাকুরাগ:',
+'specialloguserlabel'  => 'আতাকুরাগ:',
+'speciallogtitlelabel' => 'চিঙনাঙ:',
+'log'                  => 'লগ',
+'all-logs-page'        => 'হাব্বি লগ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'হাবি পাতাহানি',
 'alphaindexline' => '$1 ত $2',
+'nextpage'       => 'থাঙনার পাতা ($1)',
+'prevpage'       => 'আগেকার পাতা ($1)',
 'allpagesfrom'   => 'যেহাত্ত অকরিসি অহাত্ত পাতাহানি দেহাদেঃ',
 'allarticles'    => 'নিবন্ধহাবি',
 'allinnamespace' => 'পাতাহানি হাবি ($1 নাঙরজাগা)',
@@ -411,55 +634,157 @@
 'categories'         => 'বিষয়রথাকহানি',
 'categoriespagetext' => 'ইমারঠারর উইকিপিডিয়াত এবাকার বিষয়রথাক:',
 
+# E-mail user
+'emailuser' => 'আতাকুরাগরে ইমেইল কর',
+
 # Watchlist
-'watchlist'       => 'মর তালাবি',
-'mywatchlist'     => 'মর তালাবি',
-'addedwatch'      => 'তালাবির তালিকাহাত থনা ইল',
-'addedwatchtext'  => "\"<nowiki>\$1</nowiki>\" পাতা এহান তর [[Special:Watchlist|আহির-আরুম তালিকা]]-ত তিলকরানি ইল। পিসেদে এরে পাতা এহান বারো পাতা এহানর লগে সাকেই আসে য়্যারী পাতাত অইতই হারি জাতর পতানি এহানাত তিলকরানি অইতই। অতাবাদেউ [[Special:Recentchanges|হাদি এহানর পতানিহানি]]-ত পাতা এহানরে '''গাঢ়করা''' মেয়েকে দেহা দেনা অইতই যাতে তি নুঙিকরে পাতা এহান চিনে পারবেতা।
+'watchlist'            => 'মর তালাবি',
+'mywatchlist'          => 'মর তালাবি',
+'watchlistfor'         => "('''$1'''-র কা)",
+'addedwatch'           => 'তালাবির তালিকাহাত থনা ইল',
+'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" পাতা এহান তর [[Special:Watchlist|আহির-আরুম তালিকা]]-ত তিলকরানি ইল। পিসেদে এরে পাতা এহান বারো পাতা এহানর লগে সাকেই আসে য়্যারী পাতাত অইতই হারি জাতর পতানি এহানাত তিলকরানি অইতই। অতাবাদেউ [[Special:RecentChanges|হাদি এহানর পতানিহানি]]-ত পাতা এহানরে '''গাঢ়করা''' মেয়েকে দেহা দেনা অইতই যাতে তি নুঙিকরে পাতা এহান চিনে পারবেতা।
 
 পিসেদে তি পাতা এহানরে থেইকরানি মনেইলে \"আহির-আরুমেত্ত থেইকরেদে\" ট্যাবগত ক্লিক করিস৷",
-'watch'           => 'তালাবি',
-'watchthispage'   => 'পাতাএহান খিয়ালে থ',
-'unwatch'         => 'তালাবি নেই',
-'unwatchthispage' => 'তালাবি এরাদেনা',
+'removedwatch'         => 'তালাবির পাতাত্ত গুসাদে',
+'removedwatchtext'     => 'এরে পাতা "[[:$1]]" এহান গুসানি ইলতা [[Special:Watchlist|তর তালাবির]] পাতাত্ত।',
+'watch'                => 'তালাবি',
+'watchthispage'        => 'পাতাএহান খিয়ালে থ',
+'unwatch'              => 'তালাবি নেই',
+'unwatchthispage'      => 'তালাবি এরাদেনা',
+'watchlist-details'    => '{{PLURAL:$1|$1 পাতা|$1 পাতাহানি}} চানাঅসিল অতার কোন য়্যারির পাতা নেই।',
+'wlshowlast'           => 'গেলগা $1 ঘন্টা $2 দিনর $3 দেখাদে',
+'watchlist-hide-bots'  => 'বোটর পতানি থেইকর',
+'watchlist-hide-own'   => 'মি পতাসুতা গুর',
+'watchlist-hide-minor' => 'হুরকা পতানি থেইকর',
 
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'চা...',
+'unwatching' => 'নাউচা...',
+
 'changed' => 'পতেসে',
 
 # Delete/protect/revert
-'confirm'        => 'লেপকরানি',
-'actioncomplete' => 'কামহান লমিল।',
-'cantrollback'   => 'আগেকার সঙস্করনহাত আলথকে যানা নুৱারলু, লমিলগা সম্পদনাকরেকুরা অগ পাতা অহানর আকখুলা লেখকগ।',
+'deletepage'                  => 'পাতাহান পুস',
+'confirm'                     => 'লেপকরানি',
+'historywarning'              => 'সিঙুইস: তি যে পাতাহান পুসানিত লেপুইসত এহানর ইতিহাস আহান আসে:',
+'confirmdeletetext'           => 'তি যে পাতাহান পুসানি লেপুইসত অহানর লগে ইতিহাসহানউ পুসতই।
+তি লেপকর যে তি এহান করতেই বুলিয়া, বারো তি এহানর পিসহান হারপাসত লগে [[{{MediaWiki:Policy-url}}|পলিসিহান]] ইলয়া তি কামএহান করানিত লেপুইসত।',
+'actioncomplete'              => 'কামহান লমিল।',
+'deletedtext'                 => '"<nowiki>$1</nowiki>" পুসানি অইল।
+চা $2 এহার বারে আগে আসে পুসানির লাতংগ।',
+'deletedarticle'              => 'পুসানিইল "[[$1]]"',
+'dellogpage'                  => 'পুসিসিতার লাতংগ',
+'deletecomment'               => 'পুসানির কারনহান:',
+'deleteotherreason'           => 'আরাক/উপরি কারন:',
+'deletereasonotherlist'       => 'আর আর কারন',
+'rollbacklink'                => 'রোলবেক',
+'cantrollback'                => 'আগেকার সঙস্করনহাত আলথকে যানা নুৱারলু, লমিলগা সম্পদনাকরেকুরা অগ পাতা অহানর আকখুলা লেখকগ।',
+'protectlogpage'              => 'লুকরানির লগ',
+'protectcomment'              => 'মতহান:',
+'protectexpiry'               => 'মিয়াদহান লালর:',
+'protect_expiry_invalid'      => 'খেন্তাম লিতনাহান লালুইসে।',
+'protect_expiry_old'          => 'বাতিলর খেন্তামহান আগেকার তারিখে পরিসে।',
+'protect-unchain'             => 'গুসানি পারানির য়্যাথাঙ মুকা',
+'protect-text'                => 'তি চেইলে <strong><nowiki>$1</nowiki> পাতাহানর লুকরানির মাত্রাহান চানা বারো সিলকরানি পারর</strong>।',
+'protect-locked-access'       => 'তরতা পাতা লুকরে পারানির মত য়্যাথাঙ নেই।
+পাতাহান <strong>$1</strong>র এপাগার পাজালানিহান:',
+'protect-cascadeon'           => 'এরে পাতাহান এপাগা লুকরানি অসে, কারণ পাতাহানর তলে {{PLURAL:$1|পাতা আহানাত|পাতা হানিত}} অন্তর্ভুক্ত ইসে, যেহানাত আগপাতাকরেকুরাতাত লুকরানিহান আসে। তি চেইলে অহান সিলকরে পারর, তবে এরে আগপাতাকরেকুরাতাত কোন বদালা নাইব।',
+'protect-default'             => '(ডিফল্ট)',
+'protect-fallback'            => 'য়্যাথাং "$1" দরকার',
+'protect-level-autoconfirmed' => 'রেজিষ্টার নাকরিসি আতাকুরারের থেপকর',
+'protect-level-sysop'         => 'হুদ্দা ডান্ডিকরেকুরা',
+'protect-summary-cascade'     => 'আগপাতাকরেকুরা',
+'protect-expiring'            => '$1 (আমাস) খেন্তামে মিয়াদহান লালুইতই',
+'protect-cascade'             => 'এরে পাতাত মিহিসে পাতাহানি তালাবি করানি অক (আগপাতাকরেকুরা তালাবি)',
+'protect-cantedit'            => 'লুকরিসি পাতাহানরে তি সিলকরে নারবে, কিদিয়া বুল্লে তরতা পতানির য়্যাথাঙ নেই।',
+'restriction-type'            => 'য়্যাথাঙ:',
+'restriction-level'           => 'লুকরানির থাক:',
 
 # Restrictions (nouns)
 'restriction-edit' => 'পতানিহান_চিয়ৌকর',
 
+# Undelete
+'undeletebtn' => 'বারোইতুকর',
+
 # Namespace form on various pages
+'namespace'      => 'নাঙরথাক:',
+'invert'         => 'বাসিসি এহান আলকর',
 'blanknamespace' => '(গুরি)',
 
 # Contributions
-'mycontris' => 'মর অবদান',
+'contributions' => 'আতাকুরার অবদান',
+'mycontris'     => 'মর অবদান',
+'contribsub2'   => '$1 ($2)-র কা',
+'uctop'         => '(গজ)',
+'month'         => 'মাহাহানাত্ত (বারো অতার আগেত্ত):',
+'year'          => 'বসরেত্ত (বারো অতার আগেত্ত):',
 
+'sp-contributions-newbies-sub' => 'নুৱা একাউন্টর কা',
+'sp-contributions-blocklog'    => 'থেপকরিসি লগ',
+
 # What links here
-'whatlinkshere' => 'যে পাতাহানিত্ত এহানাত মিলাপ আসে',
+'whatlinkshere'       => 'যে পাতাহানিত্ত এহানাত মিলাপ আসে',
+'whatlinkshere-title' => 'পাতাহানি $1 -ত মিলাপ আসে',
+'linklistsub'         => '(মিলাপর লাতংগ)',
+'linkshere'           => "থাঙনার পাতাহানি '''[[:$1]]'''র লগে মিলাপ আসে:",
+'nolinkshere'         => "পাতা '''[[:$1]]'''হানাত কোন মিলাপ নেই।",
+'isredirect'          => 'বুলনদের পাতা',
+'istemplate'          => 'বরানি',
+'whatlinkshere-prev'  => '{{PLURAL:$1|পিসেদে|পিসেদে $1}}',
+'whatlinkshere-next'  => '{{PLURAL:$1|থাংনা|থাংনা $1}}',
+'whatlinkshere-links' => '← মিলাপহানি',
 
 # Block/unblock
 'blockip'            => 'আতাকুরাগরে থেপকর',
+'ipboptions'         => '২ ঘন্টা:2 hours,১ দিন:1 day,৩ দিন:3 days,হাপ্তা আহান:1 week,হাপ্তা দুহান:2 weeks,মাহা আহান:1 month,৩ মাহা:3 months,৬ মাহা:6 months,বসর আহান:1 year,লম নেই সময়:infinite', # display1:time1,display2:time2,...
 'badipaddress'       => 'আইপি ঠিকানাহান গ্রহনযোগ্যনাইসে',
 'blockipsuccesssub'  => 'থেপকরানিহান চুমিল',
-'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] রে থেপকরিয়া থসি <br />থেপকরানিহান খাল করানি থকিলে,[[Special:Ipblocklist| থেপকরিয়া থসি আইপি ঠিকানার তালিকাহান]] চা।',
+'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] রে থেপকরিয়া থসি <br />থেপকরানিহান খাল করানি থকিলে,[[Special:IPBlockList| থেপকরিয়া থসি আইপি ঠিকানার তালিকাহান]] চা।',
+'ipblocklist'        => 'থেপকরিয়া থসি আইপি ঠিকানা বারো আতাকুরার লাতঙগি',
 'blocklistline'      => '$1 তারিখে $2, $3 ($4) রে থেপকরানি অসে।',
 'blocklink'          => 'থেপ কর',
+'unblocklink'        => 'ব্লকনাকরি',
 'contribslink'       => 'অবদান',
 'blocklogpage'       => 'থেপকরানির log',
 'blocklogentry'      => '"[[$1]]"-রে $2 মেয়াদর কা থেপকরানি অসে। $3',
 
 # Move page
+'movepagetext'            => "তলর ফর্মহান ব্যবহার করিয়া পাতা আহানর চিঙনাঙ সিলকরানি একরতই, বারো লগে অহানর নুৱি চিঙনাঙ বারো ইতিহাসহান থেইকরানি একরতই।
+পুরনা চিঙনাঙ অহান নুৱা চিঙনাঙে যানার পথগ বাগেইতই।
+পুরনা চিঙনাঙর প্রতি মিলাপ অতাত কোন পতানি নাইব; অহান থকিয়া দ্বিমাউকার আলথকে যানার পাতা নাচলের আলথকে দিয়াপেঠার মিলাপ পরীক্ষা করানিত নাপাহুরিস।
+মিলাপ অহানি আয়ৌপা যাগাত থুঙকগা, অহান লেপকরানির দায়িত্বহান তরহান।
+
+খিয়াল কর যে যদি নুৱা চিঙনাঙ অহান্ন আগেত্তর পাতা আসেতানা কিতা, থা থাইলে  নুৱা পাতা এহান অহানাত '''না'''যিবগা, যদি না পাতা অহান খালি থার বা আলথকর নিদের্শনা আসে বারো আগেকার পতাসি ইতিহাস না থার। অর্থাৎ তি হারনাপেয়া নাঙ সিলকরিয়া থার সহজেই পুরানা নাঙহাত আলুইয়া যানা পারতেই, কিন্তু আগেত্তর আসে পাতার গজে ইকরানি নুৱারতেই।
+
+'''সিঙুইস!'''
+মানুর প্রিয় পাতার বারে এসাদে সিলনা খাঙদা ইতে পারে; মুঙেদে আগ বারানির আগে কামহার ফলহান কিহান ইতই, অহান লেপুইয়া করানি থক।",
+'movepagetalktext'        => "পাতাহান গুসানির লগে লগে অহানর য়্যারির পাতাহানউ আপ্পানে যিতইগা '''যদি না:'''
+*খালি নাইসে এসাদে য়্যারির পাতা নুৱা চিঙনাঙর তলে আগত্তর থা থাইলে, নাইলে
+*তি তলর বাক্সগত্ত টিক চিনৎহান থেইকরে পারর।
+
+এতার বারে তি চেইলে নিজর আতহানল পাতা অহান গুসানি বা পুলকরানি পারর।",
+'movearticle'             => 'পাতাহান থেইকর:',
+'newtitle'                => 'নুৱা চিঙনার কা:',
+'move-watch'              => 'পাতা এহান খিয়াল কর',
+'movepagebtn'             => 'পাতা থেইকর',
+'pagemovedsub'            => 'গুসানিহান হবা বালাই লমিল',
+'movepage-moved'          => '<big>\'\'\'"$1" থেইককরানি ইল "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'ইতে পারে এরে শিরোনাঙর নিবন্ধহান হঙপরসেগা, নাইলে তি দিয়াসত শিরোনাং এহান দেনার য়্যাথাং নেই। কৃপা করিয়া আরাক শিরোনাং আহান দেনার হৎনা কর।',
+'talkexists'              => "'''পাতাহান হবা বালাই গুসিল কিন্তু অরে নাঙর য়্যারির পাতা আহান আগেত্তর থানাই না গুসিল।
+দয়া করিয়া তি নিজর আতহান্ন তিলকরগা।'''",
+'movedto'                 => 'থেইকর',
+'movetalk'                => 'লগর য়্যারির পাতাহান গুসা',
 '1movedto2'               => '[[$1]]-রে [[$2]]-ত গুসানি ইল',
 '1movedto2_redir'         => '[[$1]]-রে [[$2]]-ত বারো-র্নির্দেশনার মা থেইকরানি ইল',
+'movelogpage'             => 'লগ গুসা',
+'movereason'              => 'কারন:',
+'revertmove'              => 'রিভার্ট',
 'delete_and_move'         => 'পুসানি বারো থেইকরানি',
 'delete_and_move_confirm' => 'হায়, পাতা এহান পুস',
 
+# Export
+'export' => 'পাতাহান দিয়াপেঠা',
+
 # Namespace 8 related
 'allmessages'         => 'সিস্টেমর পৌহানি',
 'allmessagesname'     => 'নাং',
@@ -467,16 +792,106 @@
 'allmessagestext'     => 'তলে মিডিয়াউইকি: নাঙরজাগাত পানা একরের সিস্টেম পৌহানির তালিকাহান দেনা ইল।',
 'allmessagesmodified' => 'পতাসি অতা হুদ্দা দেহাদে',
 
+# Thumbnails
+'thumbnail-more'  => 'ডাঙরকর',
+'thumbnail_error' => 'থাম্বনেইল হংকরানিত লেইলেক অসে: $1',
+
+# Import log
+'importlogpage' => 'লগ আন',
+
 # Tooltip help for the actions
-'tooltip-p-logo' => 'পয়লা পাতা',
+'tooltip-pt-userpage'             => 'মরকা পাতাহান',
+'tooltip-pt-mytalk'               => 'মর য়্যারির পাতা',
+'tooltip-pt-preferences'          => 'মর পছন',
+'tooltip-pt-watchlist'            => 'পতাসি পাতার হিসাব আসে লাতংগ',
+'tooltip-pt-mycontris'            => 'মর তালাবির লাতংগ',
+'tooltip-pt-login'                => 'লগ করানির হেইচা কররাঙ, যদিউ অহান বাধ্যতামুলকহান নাবে।',
+'tooltip-pt-logout'               => 'নিকুলানি',
+'tooltip-ca-talk'                 => 'পাতাহানর বারে য়্যারি দে',
+'tooltip-ca-edit'                 => 'তি পাতা এহান পতা পারতেই।
+পাতাহান ইতুকরানির আগে আলথকে মিল্লেং আহান দে।',
+'tooltip-ca-addsection'           => 'য়্যারী এহাত তর মতহান তিলকর।',
+'tooltip-ca-viewsource'           => 'পাতা এহান লুকরানি অসে।
+তি হুদ্দা উত্স চা পারতেই।',
+'tooltip-ca-protect'              => 'পাতাএহান লুকর',
+'tooltip-ca-delete'               => 'পাতা এহান পুস',
+'tooltip-ca-move'                 => 'পাতা এহান থেইকর',
+'tooltip-ca-watch'                => 'পাতা এহান চাফামে থ',
+'tooltip-ca-unwatch'              => 'তর মিল্লেঙর লাতঙেত্ত পাতা এহান গুসা',
+'tooltip-search'                  => 'বিসারা {{SITENAME}}',
+'tooltip-p-logo'                  => 'পয়লা পাতা',
+'tooltip-n-mainpage'              => 'মুল পাতাহান চেইক',
+'tooltip-n-portal'                => 'প্রকল্প এহানর বারে, তি কিহান পাংকরে পারতেই, বস্তু কুরাঙত বিসারিয়া পানা',
+'tooltip-n-currentevents'         => 'এপাগার ইভেন্টহানরকা পিসেদের ইতাহানহান বিসারা',
+'tooltip-n-recentchanges'         => 'উইকি এহাত হাদি এহান পতাসি পাতার লাতংগ।',
+'tooltip-n-randompage'            => 'খাঙদা পাতা আহান লোড কর',
+'tooltip-n-help'                  => 'বিসরিয়া পানার ফামহান।',
+'tooltip-t-whatlinkshere'         => 'উইকির যে পাতাহানি এহানাত মিলাপ অসে অতার লাতংগ',
+'tooltip-t-contributions'         => 'পাতাএহান অবদান থসি অতার লাতংগ চা',
+'tooltip-t-emailuser'             => 'আতাকুরা এগরে ইমেল আহান কর',
+'tooltip-t-upload'                => 'ফাইল আপলোড কর',
+'tooltip-t-specialpages'          => 'বিশেষ পাতাহানির লাতংগ',
+'tooltip-ca-nstab-user'           => 'আতাকুরার পাতাহান চা',
+'tooltip-ca-nstab-project'        => 'প্রকল্প পাতাহান চা',
+'tooltip-ca-nstab-image'          => 'ফাইলর পাতাহান চা',
+'tooltip-ca-nstab-template'       => 'মডেলহান চা',
+'tooltip-ca-nstab-help'           => 'পাঙলাকর পাতা চা',
+'tooltip-ca-nstab-category'       => 'থাকর পাতাহানি চা',
+'tooltip-minoredit'               => 'এহান হুরু পতানিহান বুলিয়া চিনতদে',
+'tooltip-save'                    => 'তর পতানিহান ইতু কর',
+'tooltip-preview'                 => 'তি ইতু করানির আগে যেসাদেউ আগচা (প্রিভিউ) দে!',
+'tooltip-diff'                    => 'তি কিসারেতা কিসারেতা পতাসত অতা চা।',
+'tooltip-compareselectedversions' => 'এরে পাতা এহানর দুহান ভার্সনর তুলনা কর।',
+'tooltip-watch'                   => 'পাতা এহান তর মিল্লেঙে থ',
 
 # Attribution
 'anonymous' => '{{SITENAME}}র বেনাঙর আতাকুরা(গি)',
 
-# Special:Newimages
-'ilsubmit' => 'বিসারা',
-'bydate'   => 'তারিখর সিজিলন',
+# Browsing diffs
+'previousdiff' => '← পিসেদের ফারাক',
+'nextdiff'     => 'থাংনার ফারাক →',
 
+# Media information
+'file-info-size'       => '($1 × $2 পিক্সেল, ফাইলর সাইজহান: $3, এমআইএমই-র অংতা: $4)',
+'file-nohires'         => '<small>এহাত্ত গজর রিজরিউশন নেই।</small>',
+'svg-long-desc'        => '(SVG ফাইল, সাধারনত $1 × $2 পিক্সেল, ফাইলর সাইজহান: $3)',
+'show-big-image'       => 'পুল্লাপ রিজলিউশন',
+'show-big-image-thumb' => '<small>আগচা হানর সাইজহান: $1 × $2 পিক্সেলস</small>',
+
+# Special:NewImages
+'newimages' => 'নুৱা ফাইলর গ্যালারিগ',
+'ilsubmit'  => 'বিসারা',
+'bydate'    => 'তারিখর সিজিলন',
+
+# Bad image list
+'bad_image_list' => 'ফরমেটহান তলর সাদে:
+
+লিস্টর বস্তু হুদ্দা (লাইনহান অকরতইতাই *) বিবেচিত অইতই।
+পইলাকার লাইনহান যেসাদেই হবানেই ফাইলর মিলাপ করতই।
+লাইন অহানর ভিতরে আর আর মিলাপ অতা ব্যতিক্রম বুলিয়া ধরানি অইতই, যেসাদে: যেহাত পাতাহানির ফইলগ লাইনহানর মা মাতানি অইতই।',
+
+# Metadata
+'metadata'          => 'মেটারপৌ',
+'metadata-help'     => 'ফাইল এগত আরাকউ হেলপা পৌ খানি তিলুইসে, মনে অরতা ডিজিটাল ক্যামেরাগত্ত নাইলে স্ক্যানারহাত্ত হমাসে। যদি ফাইল এগ মুল অংতাত্ত পতিয়া থার অতা ইলে খানি মানি পৌ না তিলুতে পারে।',
+'metadata-expand'   => 'আরাকউ সালকরিসি পৌ চা',
+'metadata-collapse' => 'সালকরিসি পৌ ঝিপা',
+'metadata-fields'   => 'এরে পৌ এহান তিলসে EXIF মেটাপৌ অতা ছবির পাতাত দেখাদেনা ইতই, যেপাগা হেলপা উপাত্ত সারণি অতা জিপানি ইতই। হের ক্ষেত্রহানি স্বাভাবিক অবস্থাত জিপিয়া থাইতই।
+* make
+* model
+* datetimeoriginal
+* exposuretime
+* fnumber
+* focallength', # Do not translate list items
+
+# External editor support
+'edit-externally'      => 'এর ফাইল এগ পতানির কা বারেদের এপ্লিকেশন আতা',
+'edit-externally-help' => 'আরাকউ হারপানির কা [http://www.mediawiki.org/wiki/Manual:External_editors সেটাপর বারে পৌ] হানি চা।',
+
+# 'all' in various places, this might be different for inflected languages
+'watchlistall2' => 'হাব্বি',
+'namespacesall' => 'হাব্বি',
+'monthsall'     => 'হাব্বি',
+
 # E-mail address confirmation
 'confirmemail'            => 'ই-মেইল ঠিকানাহান লেপকর',
 'confirmemail_send'       => 'লেপকরেকুরা কোডগ দিয়াপেঠাদে',
@@ -498,6 +913,14 @@
 # Auto-summaries
 'autoredircomment' => '[[$1]]-ত যানার বারো-র্নিদেশ করানি ইল',
 
+# Watchlist editing tools
+'watchlisttools-view' => 'মিল আসে পতা চা',
+'watchlisttools-edit' => 'তর তালাবির পাতা চা বারো পতা',
+'watchlisttools-raw'  => 'পেরকা তালাবির পাতা পতা',
+
+# Special:Version
+'version' => 'সংস্করন', # Not used as normal message but as header for the special page itself
+
 # Special:SpecialPages
 'specialpages' => 'বিশেষ পাতাহানি',
 
Index: languages/messages/MessagesHe.php
===================================================================
--- languages/messages/MessagesHe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -191,6 +191,7 @@
 	'hiddencat'             => array( 1,    '__קטגוריה_מוסתרת__',                  '__HIDDENCAT__'          ),
 	'pagesincategory'       => array( 1,    'דפים בקטגוריה',                       'PAGESINCATEGORY', 'PAGESINCAT' ),
 	'pagesize'              => array( 1,    'גודל דף',                            'PAGESIZE'               ),
+	'staticredirect'        => array( 1,    '__הפניה_קבועה__',                     '__STATICREDIRECT__'     ),
 );
 
 $specialPageAliases = array(
@@ -478,7 +479,7 @@
 'talkpagelinktext'  => 'שיחה',
 'specialpage'       => 'דף מיוחד',
 'personaltools'     => 'כלים אישיים',
-'postcomment'       => 'הוספת הערה לדף השיחה',
+'postcomment'       => 'הוספת פסקה לדף השיחה',
 'articlepage'       => 'צפייה בדף התוכן',
 'talk'              => 'שיחה',
 'views'             => 'צפיות',
@@ -579,7 +580,7 @@
 'nosuchspecialpage' => 'אין דף מיוחד בשם זה',
 'nospecialpagetext' => '<big>ביקשתם דף מיוחד שאינו קיים.</big>
 
-ראו גם את [[Special:Specialpages|רשימת הדפים המיוחדים התקינים]].',
+ראו גם את [[Special:SpecialPages|רשימת הדפים המיוחדים התקינים]].',
 
 # General errors
 'error'                => 'שגיאה',
@@ -663,7 +664,7 @@
 'viewsource'           => 'הצגת מקור',
 'viewsourcefor'        => 'לדף $1',
 'actionthrottled'      => 'הפעולה הוגבלה',
-'actionthrottledtext'  => 'כאמצעי נגד ספאם, אינכם מורשים לבצע פעולה זו פעמים רבות מדי בזמן קצר, ועברתם את ההגבלה הזו. אנא נסו שנית בעוד מספר דקות.',
+'actionthrottledtext'  => 'כאמצעי נגד ספאם, אינכם מורשים לבצע פעולה זו פעמים רבות מדי בזמן קצר. אנא נסו שנית בעוד מספר דקות.',
 'protectedpagetext'    => 'דף זה נעול לעריכה.',
 'viewsourcetext'       => 'באפשרותכם לצפות בטקסט המקור של הדף, ואף להעתיקו:',
 'protectedinterface'   => 'דף זה הוא אחד מסדרת דפים המספקים הודעות מערכת לתוכנה, ונעול לעריכה למפעילי מערכת בלבד כדי למנוע השחתות של ההודעות.',
@@ -683,9 +684,9 @@
 
 # Login and logout pages
 'logouttitle'                => 'יציאה מהחשבון',
-'logouttext'                 => 'יצאתם זה עתה מהחשבון. באפשרותכם להמשיך ולעשות שימוש ב{{grammar:תחילית|{{SITENAME}}}} באופן אנונימי, או לשוב ולהיכנס לאתר עם שם משתמש זהה או אחר.',
+'logouttext'                 => 'יצאתם זה עתה מהחשבון. באפשרותכם להמשיך ולעשות שימוש ב{{grammar:תחילית|{{SITENAME}}}} באופן אנונימי, או [[Special:UserLogin|לשוב ולהיכנס לאתר]] עם שם משתמש זהה או אחר.',
 'welcomecreation'            => '== ברוך הבא, $1! ==
-חשבונך נפתח. אל תשכח להתאים את הגדרות המשתמש שלך.',
+חשבונך נפתח. אל תשכח להתאים את [[Special:Preferences|העדפות המשתמש]] שלך.',
 'loginpagetitle'             => 'כניסת משתמש',
 'yourname'                   => 'שם משתמש:',
 'yourpassword'               => 'סיסמה:',
@@ -806,8 +807,8 @@
 'showdiff'                         => 'הצגת שינויים',
 'anoneditwarning'                  => "'''אזהרה:''' אינכם מחוברים לחשבון. כתובת ה־IP שלכם תירשם בהיסטוריית העריכות של הדף.",
 'missingsummary'                   => "'''תזכורת:''' לא הזנתם תקציר עריכה. אם תלחצו שוב על כפתור השמירה, עריכתכם תישמר בלעדיו.",
-'missingcommenttext'               => 'אנא הקלידו את ההערה למטה.',
-'missingcommentheader'             => "'''תזכורת:''' לא הזנתם נושא/כותרת להערה זו. אם תלחצו שוב על כפתור השמירה, עריכתכם תישמר בלעדיו.",
+'missingcommenttext'               => 'אנא הקלידו את ההודעה למטה.',
+'missingcommentheader'             => "'''תזכורת:''' לא הזנתם נושא/כותרת להודעה זו. אם תלחצו שוב על כפתור השמירה, עריכתכם תישמר בלעדיו.",
 'summary-preview'                  => 'תצוגה מקדימה של התקציר',
 'subject-preview'                  => 'תצוגה מקדימה של הנושא/הכותרת',
 'blockedtitle'                     => 'המשתמש חסום',
@@ -819,9 +820,10 @@
 * פקיעת החסימה: $6
 * החסימה שבוצעה: $7
 
-באפשרותכם ליצור קשר עם $1 או עם כל אחד מ[[Project:מפעיל מערכת|מפעילי המערכת]] האחרים כדי לדון על החסימה.
+באפשרותכם ליצור קשר עם $1 או עם כל אחד מ[[{{MediaWiki:Grouppage-sysop}}|מפעילי המערכת]] האחרים כדי לדון על החסימה.
 אינכם יכולים להשתמש בתכונת "שליחת דואר אלקטרוני למשתמש זה" אם לא ציינתם כתובת דוא"ל תקפה ב[[Special:Preferences|העדפות המשתמש שלכם]] או אם נחסמתם משליחת דוא"ל.
-כתובת ה־IP שלכם היא $3, ומספר החסימה שלכם הוא #$5. אנא ציינו אחת מעובדות אלה (או את שתיהן) בכל פנייה למפעילי המערכת.',
+כתובת ה־IP שלכם היא $3, ומספר החסימה שלכם הוא #$5.
+אנא ציינו את כל הפרטים הללו בכל פנייה למפעילי המערכת.',
 'autoblockedtext'                  => 'כתובת ה־IP שלכם נחסמה באופן אוטומטי כיוון שמשתמש אחר, שנחסם על ידי $1, עשה בה שימוש.
 הסיבה שניתנה לחסימה היא:
 
@@ -829,23 +831,21 @@
 
 * תחילת החסימה: $8
 * פקיעת החסימה: $6
+* החסימה שבוצעה: $7
 
-באפשרותכם ליצור קשר עם $1 או עם כל אחד מ[[Project:מפעיל מערכת|מפעילי המערכת]] האחרים כדי לדון על החסימה.
+באפשרותכם ליצור קשר עם $1 או עם כל אחד מ[[{{MediaWiki:Grouppage-sysop}}|מפעילי המערכת]] האחרים כדי לדון על החסימה.
 אינכם יכולים להשתמש בתכונת "שליחת דואר אלקטרוני למשתמש זה" אם לא ציינתם כתובת דוא"ל תקפה ב[[Special:Preferences|העדפות המשתמש שלכם]] או אם נחסמתם משליחת דוא"ל.
-מספר החסימה שלכם הוא #$5. אנא ציינו זאת בכל פנייה למפעילי המערכת.',
+כתובת ה־IP שלכם היא $3, ומספר החסימה שלכם הוא #$5.
+אנא ציינו את כל הפרטים הללו בכל פנייה למפעילי המערכת.',
 'blockednoreason'                  => 'לא ניתנה סיבה',
 'blockedoriginalsource'            => "טקסט המקור של '''$1''' מוצג למטה:",
 'blockededitsource'                => "הטקסט של '''העריכות שלך''' לדף '''$1''' מוצג למטה:",
 'whitelistedittitle'               => 'כניסה לחשבון נדרשת לעריכה',
 'whitelistedittext'                => 'עליכם $1 כדי לערוך דפים.',
-'whitelistreadtitle'               => 'כניסה לחשבון נדרשת לקריאה',
-'whitelistreadtext'                => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] כדי לקרוא דפים.',
-'whitelistacctitle'                => 'אינכם מורשים ליצור חשבון',
-'whitelistacctext'                 => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] שיש לו את ההרשאה ליצור חשבונות כדי ליצור חשבון.',
 'confirmedittitle'                 => 'הנכם חייבים לאמת את כתובת הדוא"ל שלכם כדי לערוך',
 'confirmedittext'                  => 'עליכם לאמת את כתובת הדוא"ל שלכם לפני שתוכלו לערוך דפים. אנא הגדירו ואמתו את כתובת הדוא"ל שלכם באמצעות [[Special:Preferences|העדפות המשתמש]] שלכם.',
 'nosuchsectiontitle'               => 'אין פסקה כזו',
-'nosuchsectiontext'                => 'ניסיתם לערוך פיסקה שאינה קיימת. כיוון שאין פיסקה בשם $1, אין מקום לשמור את עריכתכם.',
+'nosuchsectiontext'                => 'ניסיתם לערוך פסקה שאינה קיימת. כיוון שאין פסקה בשם $1, אין מקום לשמור את עריכתכם.',
 'loginreqtitle'                    => 'כניסה לחשבון נדרשת',
 'loginreqlink'                     => 'להיכנס לחשבון',
 'loginreqpagetext'                 => 'עליכם $1 כדי לצפות בדפים אחרים.',
@@ -856,7 +856,7 @@
 
 אם הגעתם לכאן בטעות, לחצו על מקש ה־'''Back''' בדפדפן שלכם.",
 'anontalkpagetext'                 => "----
-'''זהו דף שיחה של משתמש אנונימי שעדיין לא יצר חשבון במערכת, או שהוא לא משתמש בו. כיוון שכך, אנו צריכים להשתמש בכתובת ה־IP כדי לזהותו. ייתכן שכתובת IP זו תייצג מספר משתמשים. אם אתם משתמשים אנונימיים ומרגישים שקיבלתם הודעות בלתי רלוונטיות, אנא [[Special:Userlogin|צרו חשבון או הכנסו]] כדי להימנע מבלבול עתידי עם משתמשים אנונימיים נוספים.'''
+'''זהו דף שיחה של משתמש אנונימי שעדיין לא יצר חשבון במערכת, או שהוא לא משתמש בו. כיוון שכך, אנו צריכים להשתמש בכתובת ה־IP כדי לזהותו. ייתכן שכתובת IP זו תייצג מספר משתמשים. אם אתם משתמשים אנונימיים ומרגישים שקיבלתם הודעות בלתי רלוונטיות, אנא [[Special:UserLogin|היכנסו לחשבון]] או [[Special:UserLogin/signup|הירשמו לאתר]] כדי להימנע מבלבול עתידי עם משתמשים אנונימיים נוספים.'''
 ----",
 'noarticletext'                    => 'אין עדיין טקסט בדף זה. באפשרותכם [[Special:Search/{{PAGENAME}}|לחפש את {{PAGENAME}} באתר]], או [{{fullurl:{{FULLPAGENAME}}|action=edit}} ליצור דף זה].',
 'userpage-userdoesnotexist'        => 'חשבון המשתמש "$1" אינו רשום. אנא בדקו אם ברצונכם ליצור/לערוך דף זה.',
@@ -873,16 +873,16 @@
 'note'                             => '<strong>הערה:</strong>',
 'previewnote'                      => '<strong>זכרו שזו רק תצוגה מקדימה, והדף עדיין לא נשמר!</strong>',
 'previewconflict'                  => 'תצוגה מקדימה זו מציגה כיצד ייראה הטקסט בחלון העריכה העליון, אם תבחרו לשמור אותו.',
-'session_fail_preview'             => '<strong>מצטערים! לא ניתן לבצע את עריכתכם עקב אובדן קשר עם השרת. אנא נסו שנית. אם זה לא עוזר, אנא צאו מהחשבון ונסו שנית.</strong>',
+'session_fail_preview'             => '<strong>מצטערים! לא ניתן לבצע את עריכתכם עקב אובדן קשר עם השרת. אנא נסו שנית. אם זה לא עוזר, אנא [[Special:UserLogout|צאו מהחשבון]] ונסו שנית.</strong>',
 'session_fail_preview_html'        => '<strong>מצטערים! לא ניתן לבצע את עריכתם עקב אובדן קשר עם השרת.</strong>
 
 כיוון שבאתר זה אפשרות השימוש ב־HTML מאופשרת, התצוגה המקדימה מוסתרת כדי למנוע התקפות JavaScript.
 
-<strong>אם זהו ניסיון עריכה לגיטימי, אנא נסו שנית. אם זה לא עוזר, נסו לצאת מהחשבון ולהיכנס אליו שנית.</strong>',
+<strong>אם זהו ניסיון עריכה לגיטימי, אנא נסו שנית. אם זה לא עוזר, נסו [[Special:UserLogout|לצאת מהחשבון]] ולהיכנס אליו שנית.</strong>',
 'token_suffix_mismatch'            => '<strong>עריכתכם נדחתה כיוון שהדפדפן שלכם מחק את תווי הניקוד בסימון העריכה. העריכה נדחתה כדי למנוע בעיות כאלה בטקסט של הדף. ייתכן שזה קרה בגלל שירות פרוקסי אנונימי פגום.</strong>',
 'editing'                          => 'עריכת $1',
 'editingsection'                   => 'עריכת $1 (פסקה)',
-'editingcomment'                   => 'עריכת $1 (הערה)',
+'editingcomment'                   => 'עריכת $1 (הודעה)',
 'editconflict'                     => 'התנגשות עריכה: $1',
 'explainconflict'                  => "משתמש אחר שינה את הדף מאז שהתחלתם לערוך אותו. חלון העריכה העליון מכיל את הטקסט בדף כפי שהוא עתה. השינויים שלכם מוצגים בחלון העריכה התחתון. עליכם למזג את השינויים שלכם לתוך הטקסט הקיים. '''רק''' הטקסט בחלון העריכה העליון יישמר כשתשמרו את הדף.",
 'yourtext'                         => 'הטקסט שלך',
@@ -901,13 +901,13 @@
 'titleprotectedwarning'            => '<strong>אזהרה: דף זה ננעל כך שרק משתמשים מסוימים יכולים ליצור אותו.</strong>',
 'templatesused'                    => 'תבניות המופיעות בדף זה:',
 'templatesusedpreview'             => 'תבניות המופיעות בתצוגה המקדימה הזו:',
-'templatesusedsection'             => 'תבניות המופיעות בפיסקה זו:',
+'templatesusedsection'             => 'תבניות המופיעות בפסקה זו:',
 'template-protected'               => '(מוגנת)',
 'template-semiprotected'           => '(מוגנת חלקית)',
 'hiddencategories'                 => 'דף זה חבר ב{{PLURAL:$1|קטגוריה מוסתרת אחת|־$1 קטגוריות מוסתרות}}:',
 'edittools'                        => '<!-- הטקסט הנכתב כאן יוצג מתחת לטפסי עריכת דפים והעלאת קבצים, ולפיכך ניתן לכתוב להציג בו תווים קשים לכתיבה, קטעים מוכנים של טקסט ועוד. -->',
 'nocreatetitle'                    => 'יצירת הדפים הוגבלה',
-'nocreatetext'                     => 'אתר זה מגביל את האפשרות ליצור דפים חדשים. באפשרותכם לחזור אחורה ולערוך דף קיים, או [[Special:Userlogin|להיכנס לחשבון]].',
+'nocreatetext'                     => 'אתר זה מגביל את האפשרות ליצור דפים חדשים. באפשרותכם לחזור אחורה ולערוך דף קיים, או [[Special:UserLogin|להיכנס לחשבון]].',
 'nocreate-loggedin'                => 'אינכם מורשים ליצור דפים חדשים באתר זה.',
 'permissionserrors'                => 'שגיאות הרשאה',
 'permissionserrorstext'            => 'אינכם מורשים לבצע פעולה זו, {{PLURAL:$1|מהסיבה הבאה|מהסיבות הבאות}}:',
@@ -1020,7 +1020,7 @@
 
 # Suppression log
 'suppressionlog'     => 'יומן הסתרות',
-'suppressionlogtext' => 'להלן רשימת המחיקות והחסימות הכוללות תוכן המוסתר ממפעילי המערכת. ראו את  [[Special:Ipblocklist|רשימת המשתמשים החסומים]] לרשימת החסימות הפעילות כעת.',
+'suppressionlogtext' => 'להלן רשימת המחיקות והחסימות הכוללות תוכן המוסתר ממפעילי המערכת. ראו את  [[Special:IPBlockList|רשימת המשתמשים החסומים]] לרשימת החסימות הפעילות כעת.',
 
 # History merging
 'mergehistory'                     => 'מיזוג גרסאות של דפים',
@@ -1062,7 +1062,7 @@
 # Search results
 'searchresults'             => 'תוצאות החיפוש',
 'searchresulttext'          => 'למידע נוסף על חיפוש ב{{grammar:תחילית|{{SITENAME}}}}, עיינו ב[[Project:עזרה|דפי העזרה]].',
-'searchsubtitle'            => "לחיפוש המונח '''[[:$1]]'''",
+'searchsubtitle'            => 'לחיפוש המונח \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|לכל הדפים המתחילים ב"$1"]] | [[Special:WhatLinksHere/$1|לכל הדפים המקשרים ל"$1"]])',
 'searchsubtitleinvalid'     => "לחיפוש המונח '''$1'''",
 'noexactmatch'              => 'אין דף שכותרתו "$1". באפשרותכם [[:$1|ליצור את הדף]].',
 'noexactmatch-nocreate'     => 'אין דף שכותרתו "$1".',
@@ -1105,7 +1105,7 @@
 'mypreferences'            => 'ההעדפות שלי',
 'prefs-edits'              => 'מספר עריכות:',
 'prefsnologin'             => 'לא נרשמת באתר',
-'prefsnologintext'         => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] כדי לשנות העדפות משתמש.',
+'prefsnologintext'         => 'עליכם [[Special:UserLogin|להיכנס לחשבון]] כדי לשנות העדפות משתמש.',
 'prefsreset'               => 'ההעדפות שוחזרו למצבן הקודם.',
 'qbsettings'               => 'הגדרות סרגל כלים',
 'qbsettings-none'          => 'ללא',
@@ -1179,7 +1179,7 @@
 'userrights-reason'           => 'סיבה לשינוי:',
 'userrights-no-interwiki'     => 'אין לכם הרשאה לערוך הרשאות משתמש באתרים אחרים.',
 'userrights-nodatabase'       => 'בסיס הנתונים $1 אינו קיים או אינו מקומי.',
-'userrights-nologin'          => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] עם הרשאות מתאימות כדי לשנות הרשאות של משתמשים.',
+'userrights-nologin'          => 'עליכם [[Special:UserLogin|להיכנס לחשבון]] עם הרשאות מתאימות כדי לשנות הרשאות של משתמשים.',
 'userrights-notallowed'       => 'לחשבון המשתמש שלכם אין הרשאה לשנות הרשאות של משתמשים.',
 'userrights-changeable-col'   => 'קבוצות שבאפשרותכם לשנות',
 'userrights-unchangeable-col' => 'קבוצות שאין באפשרותכם לשנות',
@@ -1310,19 +1310,23 @@
 'reupload'                    => 'העלאה חוזרת',
 'reuploaddesc'                => 'ביטול ההעלאה וחזרה לטופס העלאת קבצים לשרת',
 'uploadnologin'               => 'לא נכנסתם לאתר',
-'uploadnologintext'           => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] כדי להעלות קבצים.',
+'uploadnologintext'           => 'עליכם [[Special:UserLogin|להיכנס לחשבון]] כדי להעלות קבצים.',
 'upload_directory_missing'    => 'שרת האינטרנט אינו יכול ליצור את תיקיית ההעלאות ($1) החסרה.',
 'upload_directory_read_only'  => 'שרת האינטרנט אינו יכול לכתוב בתיקיית ההעלאות ($1), ולפיכך הוא אינו יכול להעלות את התמונה.',
 'uploaderror'                 => 'שגיאה בהעלאת הקובץ',
-'uploadtext'                  => "השתמשו בטופס להלן כדי להעלות תמונות. כדי לראות או לחפש תמונות שהועלו בעבר אנא פנו ל[[Special:Imagelist|רשימת הקבצים המועלים]], וכמו כן, העלאות ומחיקות מוצגות ב[[Special:Log/upload|יומן ההעלאות]] וב[[Special:Log/delete|יומן המחיקות]].
+'uploadtext'                  => "השתמשו בטופס להלן כדי להעלות תמונות. כדי לראות או לחפש תמונות שהועלו בעבר אנא פנו ל[[Special:ImageList|רשימת הקבצים המועלים]], וכמו כן, העלאות (כולל העלאות של גרסה חדשה) מוצגות ב[[Special:Log/upload|יומן ההעלאות]], ומחיקות ב[[Special:Log/delete|יומן המחיקות]].
 
-כדי לכלול תמונה בדף, השתמשו בקישור בצורות '''<nowiki>[[</nowiki>{{ns:image}}:File.jpg<nowiki>]]</nowiki>''' לתמונות בפורמט JPG (המיועד לתצלומים), '''<nowiki>[[</nowiki>{{ns:image}}:File.png<nowiki>]]</nowiki>''' לתמונות בפורמט PNG (לאיורים, שרטוטים וסמלים). כדי לקשר ישירות לקובץ קול, השתמשו בקישור בצורה '''<nowiki>[[</nowiki>{{ns:media}}:File.jpg<nowiki>]]</nowiki>''' לקובצי קול בפורמט OGG.",
+כדי לכלול תמונה בדף, השתמשו בקישור באחת הצורות הבאות:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' לשימוש בגרסה המלאה של הקובץ
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|טקסט תיאור]]</nowiki></tt>''' לשימוש בגרסה מוקטנת ברוחב 200 פיקסלים בתיבה בצד שמאל של הדף, עם 'טקסט תיאור' כתיאור התמונה
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' לקישור ישיר לקובץ בלי להציגו",
 'upload-permitted'            => 'סוגי קבצים מותרים: $1.',
 'upload-preferred'            => 'סוגי קבצים מומלצים: $1.',
 'upload-prohibited'           => 'סוגי קבצים אסורים: $1.',
 'uploadlog'                   => 'יומן העלאות קבצים',
 'uploadlogpage'               => 'יומן העלאות',
-'uploadlogpagetext'           => 'להלן רשימה של העלאות הקבצים האחרונות שבוצעו.',
+'uploadlogpagetext'           => 'להלן רשימה של העלאות הקבצים האחרונות שבוצעו.
+ראו את [[Special:NewImages|גלריית התמונות החדשות]] להצגה ויזואלית שלהם.',
 'filename'                    => 'שם הקובץ',
 'filedesc'                    => 'תקציר',
 'fileuploadsummary'           => 'תיאור:',
@@ -1395,9 +1399,12 @@
 'upload-proto-error'      => 'פרוטוקול שגוי',
 'upload-proto-error-text' => 'בהעלאה מרוחקת, יש להשתמש בכתובות URL המתחילות עם <code>http://</code> או <code>ftp://</code>.',
 'upload-file-error'       => 'שגיאה פנימית',
-'upload-file-error-text'  => 'שגיאה פנימית התרחשה בעת הניסיון ליצור קובץ זמני על השרת. אנא צרו קשר עם מנהל מערכת.',
+'upload-file-error-text'  => 'שגיאה פנימית התרחשה בעת הניסיון ליצור קובץ זמני על השרת.
+אנא צרו קשר עם מנהל מערכת.',
 'upload-misc-error'       => 'שגיאת העלאה בלתי ידועה',
-'upload-misc-error-text'  => 'שגיאת העלאה בלתי ידועה התרחשה במהלך ההעלאה. אנא ודאו שכתובת ה־URL תקינה וזמינה ונסו שנית. אם הבעיה חוזרת על עצמה, אנא צרו קשר עם מנהל המערכת.',
+'upload-misc-error-text'  => 'שגיאת העלאה בלתי ידועה התרחשה במהלך ההעלאה.
+אנא ודאו שכתובת ה־URL תקינה וזמינה ונסו שנית.
+אם הבעיה חוזרת על עצמה, אנא צרו קשר עם מנהל המערכת.',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'לא ניתן להגיע ל־URL',
@@ -1411,7 +1418,7 @@
 'upload_source_url'  => ' (כתובת URL תקפה ונגישה)',
 'upload_source_file' => ' (קובץ במחשב שלך)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'דף זה מציג את כל הקבצים שהועלו. כברירת מחדל מוצגים הקבצים האחרונים שהועלו בראש הרשימה. לחיצה על כותרת של עמודה משנה את המיון.',
 'imagelist_search_for'  => 'חיפוש תמונה בשם:',
 'imgfile'               => 'קובץ',
@@ -1437,7 +1444,7 @@
 'imagelinks'                     => 'קישורי תמונות',
 'linkstoimage'                   => '{{PLURAL:$1|הדף הבא משתמש|הדפים הבאים משתמשים}} בתמונה זו:',
 'nolinkstoimage'                 => 'אין דפים המשתמשים בתמונה זו.',
-'morelinkstoimage'               => 'ראו [[Special:Whatlinkshere/$1|דפים נוספים]] המשתמשים בתמונה זו.',
+'morelinkstoimage'               => 'ראו [[Special:WhatLinksHere/$1|דפים נוספים]] המשתמשים בתמונה זו.',
 'redirectstofile'                => '{{PLURAL:$1|הדף הבא הוא דף הפניה|הדפים הבאים הם דפי הפניה}} לתמונה זו:',
 'duplicatesoffile'               => '{{PLURAL:$1|התמונה הבאה זהה|התמונות הבאות זהות}} לתמונה זו:',
 'sharedupload'                   => 'קובץ זה הוא קובץ משותף וניתן להשתמש בו גם באתרים אחרים.',
@@ -1523,7 +1530,7 @@
 אורך [http://www.mediawiki.org/wiki/Manual:Job_queue תור המשימות] הוא '''$7'''.
 
 {{PLURAL:$1|קובץ '''אחד'''|'''$8''' קבצים}} הועלו לאתר עד כה.",
-'userstatstext'          => "{{PLURAL:$1|ישנו [[Special:Listusers|משתמש רשום]] '''אחד'''|ישנם '''$1''' [[Special:Listusers|משתמשים רשומים]] באתר}}, {{PLURAL:$2|ול'''אחד'''|ול־'''$2'''}} (או $4%) מתוכם יש הרשאות $5.",
+'userstatstext'          => "{{PLURAL:$1|ישנו [[Special:ListUsers|משתמש רשום]] '''אחד'''|ישנם '''$1''' [[Special:ListUsers|משתמשים רשומים]] באתר}}, {{PLURAL:$2|ול'''אחד'''|ול־'''$2'''}} (או $4%) מתוכם יש הרשאות $5.",
 'statistics-mostpopular' => 'הדפים הנצפים ביותר',
 
 'disambiguations'      => 'דפי פירושונים',
@@ -1565,7 +1572,7 @@
 'uncategorizedtemplates'  => 'תבניות חסרות קטגוריה',
 'unusedcategories'        => 'קטגוריות שאינן בשימוש',
 'unusedimages'            => 'תמונות שאינן בשימוש',
-'popularpages'            => 'דפים פופולריים',
+'popularpages'            => 'הדפים הנצפים ביותר',
 'wantedcategories'        => 'קטגוריות מבוקשות',
 'wantedpages'             => 'דפים מבוקשים',
 'missingfiles'            => 'קבצים חסרים',
@@ -1621,7 +1628,7 @@
 'logempty'             => 'אין פריטים תואמים ביומן.',
 'log-title-wildcard'   => 'חיפוש כותרות המתחילות באותיות אלה',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'כל הדפים',
 'alphaindexline'    => '$1 עד $2',
 'nextpage'          => 'הדף הבא ($1)',
@@ -1644,12 +1651,12 @@
 'special-categories-sort-count' => 'סידור לפי מספר חברים',
 'special-categories-sort-abc'   => 'סידור לפי סדר האלף בית',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'הצגת משתמשים החל מ:',
 'listusers-submit'   => 'הצגה',
 'listusers-noresult' => 'לא נמצאו משתמשים.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'רשימת הרשאות לקבוצה',
 'listgrouprights-summary'  => 'זוהי רשימה של קבוצות המשתמש המוגדרות באתר זה, עם ההרשאות של כל אחת.
 מידע נוסף על ההרשאות ניתן למצוא [[{{MediaWiki:Listgrouprights-helppage}}|כאן]].',
@@ -1660,10 +1667,10 @@
 
 # E-mail user
 'mailnologin'     => 'אין כתובת לשליחה',
-'mailnologintext' => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] ולהגדיר לעצמכם כתובת דואר אלקטרוני תקינה ב[[Special:Preferences|העדפות המשתמש]] שלכם כדי לשלוח דואר למשתמש אחר.',
+'mailnologintext' => 'עליכם [[Special:UserLogin|להיכנס לחשבון]] ולהגדיר לעצמכם כתובת דואר אלקטרוני תקינה ב[[Special:Preferences|העדפות המשתמש]] שלכם כדי לשלוח דואר למשתמש אחר.',
 'emailuser'       => 'שליחת דואר אלקטרוני למשתמש זה',
 'emailpage'       => 'שליחת דואר למשתמש',
-'emailpagetext'   => 'ניתן לשלוח דואר אלקטרוני דרך טופס זה רק למשתמשים שהזינו כתובת דואר אלקטרוני בהעדפותיהם. כתובת הדואר האלקטרוני שהזנתם בהעדפותיכם האישיות תופיע ככתובת ממנה נשלחה ההודעה כדי לאפשר תגובה למכתב.',
+'emailpagetext'   => 'ניתן לשלוח דואר אלקטרוני דרך טופס זה רק למשתמשים שהזינו כתובת דואר אלקטרוני בהעדפותיהם. כתובת הדואר האלקטרוני שהזנתם ב[[Special:Preferences|העדפות המשתמש שלכם]] תופיע ככתובת ממנה נשלחה ההודעה כדי לאפשר תגובה למכתב.',
 'usermailererror' => 'אוביקט הדואר החזיר שגיאה:',
 'defemailsubject' => 'דוא"ל {{SITENAME}}',
 'noemailtitle'    => 'אין כתובת דואר אלקטרוני',
@@ -1686,13 +1693,13 @@
 'nowatchlist'          => 'אין דפים ברשימת המעקב.',
 'watchlistanontext'    => 'עליכם $1 כדי לצפות או לערוך פריטים ברשימת המעקב.',
 'watchnologin'         => 'לא נכנסתם לאתר',
-'watchnologintext'     => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] כדי לערוך את רשימת המעקב.',
+'watchnologintext'     => 'עליכם [[Special:UserLogin|להיכנס לחשבון]] כדי לערוך את רשימת המעקב.',
 'addedwatch'           => 'הדף נוסף לרשימת המעקב',
 'addedwatchtext'       => 'הדף [[:$1]] נוסף ל[[Special:Watchlist|רשימת המעקב]]. שינויים שייערכו בעתיד, בדף זה ובדף השיחה שלו, יוצגו ברשימת המעקב.
 
-בנוסף, הדף יופיע בכתב מודגש ב[[Special:Recentchanges|רשימת השינויים האחרונים]], כדי להקל עליכם את המעקב אחריו.',
+בנוסף, הדף יופיע בכתב מודגש ב[[Special:RecentChanges|רשימת השינויים האחרונים]], כדי להקל עליכם את המעקב אחריו.',
 'removedwatch'         => 'הדף הוסר מרשימת המעקב',
-'removedwatchtext'     => 'הדף [[:$1]] הוסר מרשימת המעקב.',
+'removedwatchtext'     => 'הדף [[:$1]] הוסר מ[[Special:Watchlist|רשימת המעקב]].',
 'watch'                => 'מעקב',
 'watchthispage'        => 'מעקב אחרי דף זה',
 'unwatch'              => 'הפסקת מעקב',
@@ -1791,15 +1798,15 @@
 'rollbacklink'                => 'שחזור',
 'rollbackfailed'              => 'השחזור נכשל',
 'cantrollback'                => 'לא ניתן לשחזר את העריכה – התורם האחרון הוא היחיד שכתב דף זה; עם זאת, ניתן למחוק את הדף.',
-'alreadyrolled'               => 'לא ניתן לשחזר את עריכת הדף [[:$1]] על ידי [[User:$2|$2]] ([[User talk:$2|שיחה]]); מישהו אחר כבר ערך או שחזר דף זה.
+'alreadyrolled'               => 'לא ניתן לשחזר את עריכת הדף [[:$1]] על ידי [[User:$2|$2]] ([[User talk:$2|שיחה]] | [[Special:Contributions/$2|{{int:contribslink}}]]); מישהו אחר כבר ערך או שחזר דף זה.
 
-העריכה האחרונה הייתה של [[User:$3|$3]] ([[User talk:$3|שיחה]]).',
+העריכה האחרונה הייתה של [[User:$3|$3]] ([[User talk:$3|שיחה]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => "תקציר העריכה היה: \"'''\$1'''\".", # only shown if there is an edit comment
 'revertpage'                  => 'שוחזר מעריכה של [[Special:Contributions/$2|$2]] ([[User talk:$2|שיחה]]) לעריכה האחרונה של [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'שוחזר מעריכה של $1 לעריכה האחרונה של $2',
 'sessionfailure'              => 'נראה שיש בעיה בחיבורכם לאתר. פעולתכם בוטלה כאמצעי זהירות כנגד התחזות לתקשורת ממחשבכם. אנא חיזרו לדף הקודם ונסו שנית.',
 'protectlogpage'              => 'יומן הגנות',
-'protectlogtext'              => 'להלן רשימה של הגנות וביטולי הגנות על דפים. ראו גם את [[Special:Protectedpages|רשימת הדפים המוגנים]] הנוכחית.',
+'protectlogtext'              => 'להלן רשימה של הגנות וביטולי הגנות על דפים. ראו גם את [[Special:ProtectedPages|רשימת הדפים המוגנים]] הנוכחית.',
 'protectedarticle'            => 'הגן על [[$1]]',
 'modifiedarticleprotection'   => 'שינה את רמת ההגנה של [[$1]]',
 'unprotectedarticle'          => 'ביטל את ההגנה על [[$1]]',
@@ -1963,7 +1970,7 @@
 'blockipsuccesssub'               => 'החסימה הושלמה בהצלחה',
 'blockipsuccesstext'              => 'המשתמש [[Special:Contributions/$1|$1]] נחסם.
 
-ראו את [[Special:Ipblocklist|רשימת המשתמשים החסומים]] כדי לצפות בחסימות.',
+ראו את [[Special:IPBlockList|רשימת המשתמשים החסומים]] כדי לצפות בחסימות.',
 'ipb-edit-dropdown'               => 'עריכת סיבות החסימה',
 'ipb-unblock-addr'                => 'הסרת חסימה של $1',
 'ipb-unblock'                     => 'הסרת חסימה של שם משתמש או כתובת IP',
@@ -1995,7 +2002,7 @@
 'blocklogentry'                   => 'חסם את [[$1]] למשך $2 $3',
 'blocklogtext'                    => 'זהו יומן פעולות החסימה והשחרור של משתמשים. כתובות IP הנחסמות באופן אוטומטי אינן מופיעות.
 
-ראו גם את [[Special:Ipblocklist|רשימת המשתמשים החסומים]] הנוכחית.',
+ראו גם את [[Special:IPBlockList|רשימת המשתמשים החסומים]] הנוכחית.',
 'unblocklogentry'                 => 'שחרר את [[$1]]',
 'block-log-flags-anononly'        => 'משתמשים אנונימיים בלבד',
 'block-log-flags-nocreate'        => 'יצירת חשבונות נחסמה',
@@ -2034,7 +2041,7 @@
 'unlockdbsuccesssub'  => 'שוחררה הנעילה מבסיס הנתונים',
 'lockdbsuccesstext'   => 'בסיס הנתונים ננעל.
 
-זכרו [[Special:Unlockdb|לשחרר את הנעילה]] לאחר שפעולת התחזוקה הסתיימה.',
+זכרו [[Special:UnlockDB|לשחרר את הנעילה]] לאחר שפעולת התחזוקה הסתיימה.',
 'unlockdbsuccesstext' => 'שוחררה הנעילה של בסיס הנתונים',
 'lockfilenotwritable' => 'קובץ נעילת בסיס הנתונים אינו ניתן לכתיבה. כדי שאפשר יהיה לנעול את בסיס הנתונים או לבטל את נעילתו, שרת האינטרנט צריך לקבל הרשאות לכתוב אליו.',
 'databasenotlocked'   => 'בסיס הנתונים אינו נעול.',
@@ -2047,7 +2054,8 @@
 
 השם הישן יהפוך לדף הפניה אל הדף עם השם החדש.
 
-קישורים לשם הישן לא ישתנו, ולכן אנא ודאו שאין [[Special:DoubleRedirects|הפניות כפולות]] או [[Special:BrokenRedirects|שבורות]].
+באפשרותכם לעדכן אוטומטית דפי הפניה לכותרת המקורית.
+אם תבחרו לא לעשות זאת, אנא ודאו שאין [[Special:DoubleRedirects|הפניות כפולות]] או [[Special:BrokenRedirects|שבורות]].
 
 אתם אחראים לוודא שכל הקישורים ממשיכים להצביע למקום שאליו הם אמורים להצביע.
 
@@ -2060,8 +2068,6 @@
 
 במקרים אלו, תצטרכו להעביר או לשלב את הדפים באופן ידני, אם תרצו.',
 'movearticle'             => 'העברת דף:',
-'movenologin'             => 'לא נכנסתם לאתר',
-'movenologintext'         => 'עליכם [[Special:Userlogin|להיכנס לחשבון]] כדי להעביר דפים.',
 'movenotallowed'          => 'אינכם מורשים להעביר דפים באתר זה.',
 'newtitle'                => 'לשם החדש:',
 'move-watch'              => 'מעקב אחרי דף זה',
@@ -2088,7 +2094,7 @@
 'revertmove'              => 'החזרה',
 'delete_and_move'         => 'מחיקה והעברה',
 'delete_and_move_text'    => '== בקשת מחיקה ==
-דף היעד, [[$1]], כבר קיים. האם ברצונכם למחוק אותו כדי לאפשר את ההעברה?',
+דף היעד, [[:$1]], כבר קיים. האם ברצונכם למחוק אותו כדי לאפשר את ההעברה?',
 'delete_and_move_confirm' => 'אישור מחיקת הדף',
 'delete_and_move_reason'  => 'מחיקה על מנת לאפשר העברה',
 'selfmove'                => 'כותרות המקור והיעד זהות; לא ניתן להעביר דף לעצמו.',
@@ -2105,7 +2111,7 @@
 
 כדי לייצא דפים, הקישו את שמותיהם בתיבת הטקסט שלהלן, כל שם בשורה נפרדת, ובחרו האם לייצא גם את הגרסה הנוכחית וגם את היסטוריית השינויים של הדפים, או רק את הגרסה הנוכחית עם מידע על העריכה האחרונה.
 
-בנוסף, ניתן להשתמש בקישור, כגון [[Special:Export/{{MediaWiki:mainpage}}]] לדף [[{{MediaWiki:mainpage}}]] ללא היסטוריית השינויים שלו.',
+בנוסף, ניתן להשתמש בקישור, כגון [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] לדף [[{{MediaWiki:Mainpage}}]] ללא היסטוריית השינויים שלו.',
 'exportcuronly'     => 'כלול רק את הגרסה הנוכחית, ללא כל ההיסטוריה',
 'exportnohistory'   => "----
 '''הערה:''' ייצוא ההיסטוריה המלאה של דפים דרך טופס זה הופסקה עקב בעיות ביצוע.",
@@ -2145,14 +2151,14 @@
 'import-interwiki-history'   => 'העתקת כל היסטוריית העריכות של דף זה',
 'import-interwiki-submit'    => 'ייבוא',
 'import-interwiki-namespace' => 'העבר את הדפים לתוך מרחב השם:',
-'importtext'                 => 'אנא ייצאו את הקובץ מאתר המקור תוך שימוש בעזר הייצוא, שמרו אותו לדיסק הקשיח שלכם והעלו אותו לכאן.',
+'importtext'                 => 'אנא ייצאו את הקובץ מאתר המקור תוך שימוש ב[[Special:Export|כלי הייצוא]], שמרו אותו לדיסק הקשיח שלכם והעלו אותו לכאן.',
 'importstart'                => 'מייבא דפים…',
 'import-revision-count'      => '{{PLURAL:$1|גרסה אחת|$1 גרסאות}}',
 'importnopages'              => 'אין דפים לייבוא.',
 'importfailed'               => 'הייבוא נכשל: <nowiki>$1</nowiki>',
 'importunknownsource'        => 'סוג ייבוא בלתי ידוע',
 'importcantopen'             => 'פתיחת קובץ הייבוא נכשלה',
-'importbadinterwiki'         => 'קישור אינטרוויקי שגוי',
+'importbadinterwiki'         => 'קישור בינוויקי שגוי',
 'importnotext'               => 'ריק או חסר טקסט',
 'importsuccess'              => 'הייבוא הושלם בהצלחה!',
 'importhistoryconflict'      => 'ישנה התנגשות עם ההיסטוריה הקיימת של הדף (ייתכן שהדף יובא בעבר)',
@@ -2170,7 +2176,7 @@
 # Import log
 'importlogpage'                    => 'יומן ייבוא',
 'importlogpagetext'                => 'ייבוא מנהלי של דפים (כולל היסטוריית העריכות שלהם) מאתרי ויקי אחרים.',
-'import-logentry-upload'           => 'ייבא את [[$1]] על ידי העלאת קובץ',
+'import-logentry-upload'           => 'ייבא את [[$1]] באמצעות העלאת קובץ',
 'import-logentry-upload-detail'    => '{{PLURAL:$1|גרסה אחת|$1 גרסאות}}',
 'import-logentry-interwiki'        => 'ייבא את $1 בייבוא בין־אתרי',
 'import-logentry-interwiki-detail' => '{{PLURAL:$1|גרסה אחת|$1 גרסאות}} של הדף $2',
@@ -2188,7 +2194,7 @@
 'tooltip-pt-logout'               => 'יציאה מהחשבון',
 'tooltip-ca-talk'                 => 'שיחה על דף זה',
 'tooltip-ca-edit'                 => 'באפשרותכם לערוך דף זה. אנא השתמשו בלחצן "תצוגה מקדימה" לפני השמירה',
-'tooltip-ca-addsection'           => 'הוספת הערה לשיחה זו',
+'tooltip-ca-addsection'           => 'הוספת פסקה לשיחה זו',
 'tooltip-ca-viewsource'           => 'זהו דף מוגן, אך באפשרותכם לצפות במקורו',
 'tooltip-ca-history'              => 'גרסאות קודמות של דף זה.',
 'tooltip-ca-protect'              => 'הגנה על דף זה',
@@ -2309,10 +2315,11 @@
 'markedaspatrollederror-noautopatrol' => 'אינכם מורשים לסמן את השינויים של עצמכם כבדוקים.',
 
 # Patrol log
-'patrol-log-page' => 'יומן שינויים בדוקים',
-'patrol-log-line' => 'סימן את  $1 בדף $2 כבדוקה $3',
-'patrol-log-auto' => '(אוטומטית)',
-'patrol-log-diff' => 'גרסה $1',
+'patrol-log-page'   => 'יומן שינויים בדוקים',
+'patrol-log-header' => 'יומן זה מציג גרסאות שנבדקו.',
+'patrol-log-line'   => 'סימן את  $1 בדף $2 כבדוקה $3',
+'patrol-log-auto'   => '(אוטומטית)',
+'patrol-log-diff'   => 'גרסה $1',
 
 # Image deletion
 'deletedrevision'                 => 'מחק גרסה ישנה $1',
@@ -2341,7 +2348,7 @@
 'show-big-image'       => 'תמונה ברזולוציה גבוהה יותר',
 'show-big-image-thumb' => '<small>גודל התצוגה הזו: $1 × $2 פיקסלים</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'גלריית תמונות חדשות',
 'imagelisttext'         => 'להלן רשימה של {{PLURAL:$1|תמונה אחת|$1 תמונות}}, ממוינות $2:',
 'newimages-summary'     => 'דף זה מציג את הקבצים האחרונים שהועלו',
@@ -2624,7 +2631,7 @@
 
 # External editor support
 'edit-externally'      => 'ערכו קובץ זה באמצעות יישום חיצוני',
-'edit-externally-help' => 'ראו את [http://meta.wikimedia.org/wiki/Help:External_editors הוראות ההתקנה] למידע נוסף.',
+'edit-externally-help' => 'ראו את [http://www.mediawiki.org/wiki/Manual:External_editors הוראות ההתקנה] למידע נוסף.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'הכול',
@@ -2646,7 +2653,8 @@
 תוכנת הדואר החזירה את ההודעה הבאה: $1',
 'confirmemail_invalid'     => 'קוד האישור שגוי. ייתכן שפג תוקפו.',
 'confirmemail_needlogin'   => 'עליכם לבצע $1 כדי לאמת את כתובת הדוא"ל שלכם.',
-'confirmemail_success'     => 'כתובת הדוא"ל שלכם אושרה. כעת באפשרותכם להיכנס לחשבון שלכם וליהנות מהאתר.',
+'confirmemail_success'     => 'כתובת הדוא"ל שלכם אושרה.
+כעת באפשרותכם [[Special:UserLogin|להיכנס לחשבון שלכם]] וליהנות מהאתר.',
 'confirmemail_loggedin'    => 'כתובת הדוא"ל שלכם אושרה כעת.',
 'confirmemail_error'       => 'שגיאה בשמירת קוד האישור.',
 'confirmemail_subject'     => 'קוד אישור דוא"ל מ{{grammar:תחילית|{{SITENAME}}}}',
@@ -2686,7 +2694,7 @@
 'recreate'            => 'יצירה מחדש',
 
 # HTML dump
-'redirectingto' => 'מפנה ל־[[$1]]…',
+'redirectingto' => 'מפנה ל־[[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'לנקות את המטמון של דף זה?
@@ -2737,8 +2745,8 @@
 'livepreview-error'   => 'ההתחברות נכשלה: $1 "$2". נסו להשתמש בתצוגה מקדימה רגילה.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'שינויים שבוצעו לפני פחות מ־$1 שניות אינם מוצגים ברשימה זו.',
-'lag-warn-high'   => 'בגלל עיכוב בעדכון בסיס הנתונים, שינויים שבוצעו לפני פחות מ־$1 שניות אינם מוצגים ברשימה זו.',
+'lag-warn-normal' => 'שינויים שבוצעו לפני פחות מ{{PLURAL:$1|שנייה אחת|־$1 שניות}} אינם מוצגים ברשימה זו.',
+'lag-warn-high'   => 'בגלל עיכוב בעדכון בסיס הנתונים, שינויים שבוצעו לפני פחות מ{{PLURAL:$1|שנייה אחת|־$1 שניות}} אינם מוצגים ברשימה זו.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'יש לכם {{PLURAL:$1|פריט אחד|$1 פריטים}} ברשימת המעקב, לא כולל דפי שיחה.',
@@ -2844,7 +2852,7 @@
 'version-software-product'         => 'תוכנה',
 'version-software-version'         => 'גרסה',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'נתיב לקובץ',
 'filepath-page'    => 'הקובץ:',
 'filepath-submit'  => 'מציאת הנתיב',
@@ -2882,7 +2890,7 @@
 'specialpages-group-redirects'   => 'הפניות מדפים מיוחדים',
 'specialpages-group-spam'        => 'כלי ספאם',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'דף ריק',
 'intentionallyblankpage' => 'דף זה נשאר ריק במכוון',
 
Index: languages/messages/MessagesHi.php
===================================================================
--- languages/messages/MessagesHi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Aksi great
  * @author Kaustubh
- * @author לערי ריינהארט
  * @author Shyam
- * @author Siebrand
  * @author Sunil Mohan
- * @author Jon Harald Søby
- * @author Aksi great
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -579,10 +577,6 @@
 'blockededitsource'                => "'''$1''' को '''आपके बदलाव''' का पाठ्य नीचे दर्शाया गया हैं:",
 'whitelistedittitle'               => 'संपादित करनें के लिये लॉग इन करना ज़रूरी हैं',
 'whitelistedittext'                => 'लेख संपादित करने के लियें $1 करें ।',
-'whitelistreadtitle'               => 'पढ़ने के लिये लॉग इन करना ज़रूरी हैं',
-'whitelistreadtext'                => 'लेख पढ़ने के लिये [[Special:Userlogin|लॉग इन]] करना ज़रूरी हैं ।',
-'whitelistacctitle'                => 'आप नया खाता नहीं बना सकतें',
-'whitelistacctext'                 => '{{SITENAME}} पर नया खाता बनाने से पहलें आपने [[Special:Userlogin|लॉग]] इन किया होना और साथ ही उचित अधिकार प्राप्त कर लेना ज़रूरी हैं ।',
 'confirmedittitle'                 => 'संपादित करने के लियें इ-मेल से पुष्टि करना आवश्यक हैं',
 'confirmedittext'                  => 'संपादन करने से पहले आपने अपना इ-मेल पता प्रमाणित कराना आवश्यक हैं ।
 कृपया अपनी [[Special:Preferences|सदस्य वरीयताएं]] में जाकर अपना इ-मेल पता दें और उसे प्रमाणित करें ।',
@@ -597,7 +591,7 @@
 'newarticletext'                   => 'आप जो लेख चाहते हैं वह अभीतक लिखा नहीं गया हैं । यह लेख लिखनेके लिये नीचे पाठ्य लिखियें । सहाय्यताके लिये [[{{MediaWiki:Helppage}}|यहां]] क्लीक किजीयें ।
 
 अगर आप यहांपर गलतीसे आये हैं तो अपने ब्राउज़रके बॅक (back) पर क्लीक किजीयें ।',
-'anontalkpagetext'                 => "---- ''यह वार्ता पन्ना उस अज्ञात सदस्य के लिये है जिसने या तो अकाउन्ट नहीं बनाया है या वह उसे प्रयोग नहीं कर रहा है । इसलिये उसकी पहचान के लिये हम उसका आ ई पी ऐड्रस प्रयोग कर रहे हैं । ऐसे आ ई पी ऐड्रस कई लोगों के बीच शेयर किये जा सके हैं । अगर आप एक अज्ञात सदस्य हैं और आपको लगता है कि आपके बारे में अप्रासंगिक टीका टिप्पणी की गयी है तो कृपया  [[Special:Userlogin|अकाउन्ट बनायें या लॉग इन करें]] जिससे भविष्य में अन्य अज्ञात सदस्यों के साथ  कोई गलतफहमी न हों .''",
+'anontalkpagetext'                 => "---- ''यह वार्ता पन्ना उस अज्ञात सदस्य के लिये है जिसने या तो अकाउन्ट नहीं बनाया है या वह उसे प्रयोग नहीं कर रहा है । इसलिये उसकी पहचान के लिये हम उसका आ ई पी ऐड्रस प्रयोग कर रहे हैं । ऐसे आ ई पी ऐड्रस कई लोगों के बीच शेयर किये जा सके हैं । अगर आप एक अज्ञात सदस्य हैं और आपको लगता है कि आपके बारे में अप्रासंगिक टीका टिप्पणी की गयी है तो कृपया  [[Special:UserLogin|अकाउन्ट बनायें या लॉग इन करें]] जिससे भविष्य में अन्य अज्ञात सदस्यों के साथ  कोई गलतफहमी न हों .''",
 'noarticletext'                    => 'इस लेखमें अभी कुछभी पाठ्य नहीं हैं । आप विकिपीडियापर होनेवाले दुसरे लेखोंमें इस [[Special:Search/{{PAGENAME}}|शीर्षक को खोज सकते हैं]] या फिर यह लेख [{{fullurl:{{FULLPAGENAME}}|action=edit}} तैयार कर सकते हैं] ।',
 'userpage-userdoesnotexist'        => 'सदस्य खाता "$1" पंजिकृत नहीं हैं । कृपया यह लेख आप संपादित अथवा निर्मित करना चाहते हैं इसकी जाँच करें ।',
 'clearyourcache'                   => "'''सुचना''': यह पृष्ठ सुरक्षित करने बाद, बदलावों देखने लिए आपका ब्राउज़र का कैश ख़ाली करने की ज़रूरत हो सकती है। 
@@ -668,7 +662,7 @@
 'edittools'                        => '<!-- यहां दिया हुआ पाठ संपादन और अपलोड फ़ार्म के नीचे दर्शाया जायेगा। -->',
 'nocreatetitle'                    => 'लेख निर्माणमें प्रतिबंध',
 'nocreatetext'                     => '{{SITENAME}} पर नये लेख लिखनेके लिये मनाई की गई हैं ।
-आप पीछे जाकर अस्तित्वमें होनेवाले लेखोंको संपादित कर सकते हैं, अथवा [[Special:Userlogin|नया ख़ाता खोलें / प्रवेश करें]] ।',
+आप पीछे जाकर अस्तित्वमें होनेवाले लेखोंको संपादित कर सकते हैं, अथवा [[Special:UserLogin|नया ख़ाता खोलें / प्रवेश करें]] ।',
 'nocreate-loggedin'                => '{{SITENAME}} पर नये पन्ने बनाने का आपको अधिकार नहीं हैं।',
 'permissionserrors'                => 'अधिकारोंमें गलती',
 'permissionserrorstext'            => 'निम्नलिखित {{PLURAL:$1|कारण|कारणोंसे}} आपको ऐसा करने की अनुमति नहीं हैं:',
@@ -785,7 +779,7 @@
 
 # Suppression log
 'suppressionlog'     => 'सप्रेशन सूची',
-'suppressionlogtext' => 'नीचे प्रबंधकोंसे छुपायें गयें ब्लॉक और हटाये गये पन्नों की सूची हैं। अभी अस्तित्वमें होने वाले ब्लॉक देखने के लिये [[Special:Ipblocklist|आइपी ब्लॉक सूची]] देखें।',
+'suppressionlogtext' => 'नीचे प्रबंधकोंसे छुपायें गयें ब्लॉक और हटाये गये पन्नों की सूची हैं। अभी अस्तित्वमें होने वाले ब्लॉक देखने के लिये [[Special:IPBlockList|आइपी ब्लॉक सूची]] देखें।',
 
 # History merging
 'mergehistory'                     => 'पन्ने के इतिहास एकत्रित करें',
@@ -871,7 +865,7 @@
 'mypreferences'            => 'मेरी वरीयताएँ',
 'prefs-edits'              => 'संपादनोंकी संख्या:',
 'prefsnologin'             => 'लॉग इन नहीं किया हैं',
-'prefsnologintext'         => 'सदस्य वरीयतायें बदलने के लियें आपने [[Special:Userlogin|लॉग इन]] किया होना जरूरी हैं।',
+'prefsnologintext'         => 'सदस्य वरीयतायें बदलने के लियें आपने [[Special:UserLogin|लॉग इन]] किया होना जरूरी हैं।',
 'prefsreset'               => 'पसंदे पूर्ववत कर दी गईं हैं।',
 'qbsettings'               => 'शीघ्रपट',
 'qbsettings-none'          => 'बिल्कुल नहीं',
@@ -947,7 +941,7 @@
 'userrights-reason'           => 'बदलाव के कारण:',
 'userrights-no-interwiki'     => 'अन्य विकियोंपर आपको सदस्य अधिकार बदलने की अनुमति नहीं हैं।',
 'userrights-nodatabase'       => 'डाटाबेस $1 या तो अस्तित्वमें नहीं हैं या फिर स्थानीय नहीं हैं।',
-'userrights-nologin'          => 'सदस्य अधिकार बदलने के लिये आपने प्रबंधक खाते से [[Special:Userlogin|लॉग इन]] किया हुआ होना आवश्यक हैं।',
+'userrights-nologin'          => 'सदस्य अधिकार बदलने के लिये आपने प्रबंधक खाते से [[Special:UserLogin|लॉग इन]] किया हुआ होना आवश्यक हैं।',
 'userrights-notallowed'       => 'आपके सदस्य खातेको सदस्य अधिकार बदलनेकी अनुमति नहीं हैं।',
 'userrights-changeable-col'   => 'ग्रुप जिन्हें आप बदल सकतें हैं',
 'userrights-unchangeable-col' => 'ग्रुप जिन्हें आप नहीं बदल सकते हैं',
@@ -1077,11 +1071,11 @@
 'reupload'                    => 'पुन: अपलोड करें',
 'reuploaddesc'                => 'अपलोड रद्द करें और पुन: अपलोड पन्ने पर जायें',
 'uploadnologin'               => 'आप लॉगड इन नहीं हैं ।',
-'uploadnologintext'           => 'फ़ाईलें अपलोड करने के लिये [[Special:Userlogin|लॉग इन]] किया होना ज़रूरी हैं।',
+'uploadnologintext'           => 'फ़ाईलें अपलोड करने के लिये [[Special:UserLogin|लॉग इन]] किया होना ज़रूरी हैं।',
 'upload_directory_read_only'  => 'अपलोड डाइरेक्टरी ($1) में सर्वर लिख नहीं पा रहा हैं।',
 'uploaderror'                 => 'अपलोड एरर',
 'uploadtext'                  => "नईं फ़ाईलें अपलोड करने के लिये इस पन्ने का इस्तेमाल करें।
-इसके पहले [[Special:Imagelist|अपलोड की गईं फ़ाईलों की सूची]] देखें। अपलोड की हुईं और हटाईं हुई फ़ाइलों के लिये [[Special:Log/upload|सूची]] देखें।
+इसके पहले [[Special:ImageList|अपलोड की गईं फ़ाईलों की सूची]] देखें। अपलोड की हुईं और हटाईं हुई फ़ाइलों के लिये [[Special:Log/upload|सूची]] देखें।
 
 अपने लेखोंमें यह फ़ाईल इस्तेमाल के लिये नीचे दिये गये उदाहरणोंके अनुसार कड़ियां बनाईयें।
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1196,7 +1190,7 @@
 'upload_source_url'  => ' (एक वैध, सभी जगहोंसे उपलब्ध URL)',
 'upload_source_file' => ' (आपके कम्प्यूटरपर होनेवाली फ़ाईल)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'यह विशेष पृष्ठ सभी अपलोड की हुई फ़ाईलें दर्शाता हैं।
 सामान्यत: सबसे बादमें अपलोड हुई फ़ाईलें सबसे उपर दिखती हैं।
 कालम कें शीर्षकमें क्लिक करने से अनुक्रम बदला जा सकता हैं।',
@@ -1224,7 +1218,7 @@
 'imagelinks'                     => 'कड़ियाँ',
 'linkstoimage'                   => 'निम्नलिखित पन्ने इस चित्र से जुडते हैं :',
 'nolinkstoimage'                 => 'इस चित्र से कोई पन्ने नहीं जुडते',
-'morelinkstoimage'               => 'इस फ़ाईलकी [[Special:Whatlinkshere/$1|और कडी़याँ]] देखें।',
+'morelinkstoimage'               => 'इस फ़ाईलकी [[Special:WhatLinksHere/$1|और कडी़याँ]] देखें।',
 'redirectstofile'                => 'नीचे दी हुई फ़ाइलें इस फ़ाईलको अनुप्रेषितें हैं:',
 'duplicatesoffile'               => 'निम्नलिखित फ़ाइलें इस फ़ाइलकी कापीयाँ हैं:',
 'sharedupload'                   => 'यह फ़ाईल दुसरेभी प्रोजेक्ट्समें इस्तेमाल की हुई होनेकी आशंका है ।',
@@ -1243,18 +1237,18 @@
 # File reversion
 'filerevert'                => '$1 पूर्ववत करें',
 'filerevert-legend'         => 'फ़ाईल पूर्ववत करें',
-'filerevert-intro'          => '<span class="plainlinks">आप \'\'\'[[Media:$1|$1]]\'\'\' के [$3, $2 तक के अवतरण, $4 की तरफ] वापिस भेज रहें हैं।</span>',
+'filerevert-intro'          => "आप '''[[Media:$1|$1]]''' के [$3, $2 तक के अवतरण, $4 की तरफ] वापिस भेज रहें हैं।",
 'filerevert-comment'        => 'टिप्पणी:',
 'filerevert-defaultcomment' => '$2, $1 के अवतरण पूर्ववत कियें',
 'filerevert-submit'         => 'पूर्ववत करें',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' के [$3, $2 तक के अवतरण, $4 की तरफ] वापिस भेज दिये गयें हैं।</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' के [$3, $2 तक के अवतरण, $4 की तरफ] वापिस भेज दिये गयें हैं।",
 'filerevert-badversion'     => 'दिये हुए समयसे मेल खाने वाला, इस फ़ाईलका पुराना अवतरण नहीं हैं।',
 
 # File deletion
 'filedelete'                  => '$1 हटायें',
 'filedelete-legend'           => 'फ़ाइल हटायें',
 'filedelete-intro'            => "आप '''[[Media:$1|$1]]''' हटा रहें हैं।",
-'filedelete-intro-old'        => '<span class="plainlinks">आप \'\'\'[[Media:$1|$1]]\'\'\' के [$4 $3, $2 के अवतरण] हटा रहें हैं।</span>',
+'filedelete-intro-old'        => "आप '''[[Media:$1|$1]]''' के [$4 $3, $2 के अवतरण] हटा रहें हैं।",
 'filedelete-comment'          => 'हटाने का कारण:',
 'filedelete-submit'           => 'हटायें',
 'filedelete-success'          => "'''$1''' को हटा दिया गया हैं।",
@@ -1311,7 +1305,7 @@
 इससे पता चलता है कि, औसतन प्रति पृष्ठ '''\$5''' संपादन होते हैं, एवं प्रति संपादन इन्हें '''\$6''' बार देखा जाता है।
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue कार्य पंक्ति] की लम्बाई '''\$7''' है।",
-'userstatstext'          => "इस विकिपीडिया में  {{PLURAL:$1|'''1''' रजिस्टर्ड [[Special:Listusers|सदस्य]]|'''$1''' रजिस्टर्ड  [[Special:Listusers|सदस्य]]}} हैं, जिसमें से  '''$2''' (या '''$4%''') {{PLURAL:$2|सदस्यको|सदस्योंको}} $5 अधिकार हैं।",
+'userstatstext'          => "इस विकिपीडिया में  {{PLURAL:$1|'''1''' रजिस्टर्ड [[Special:ListUsers|सदस्य]]|'''$1''' रजिस्टर्ड  [[Special:ListUsers|सदस्य]]}} हैं, जिसमें से  '''$2''' (या '''$4%''') {{PLURAL:$2|सदस्यको|सदस्योंको}} $5 अधिकार हैं।",
 'statistics-mostpopular' => 'सबसे ज्यादा देखें जाने वाले पन्ने',
 
 'disambiguations'      => 'डिसऍम्बिग्वीशन पन्ने',
@@ -1408,7 +1402,7 @@
 'logempty'             => 'सूची में ऐसा आइटम नहीं हैं।',
 'log-title-wildcard'   => 'इस पाठ से शुरू होनेवाले शीर्षक खोजें',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'सभी पन्ने',
 'alphaindexline'    => '$1 से $2',
 'nextpage'          => 'अगला पन्ना ($1)',
@@ -1431,12 +1425,12 @@
 'special-categories-sort-count' => 'संख्यानुसार वर्ग दर्शायें',
 'special-categories-sort-abc'   => 'वर्णानुक्रम के अनुसार दर्शायें',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'इस शब्द से शुरु होनेवाले सदस्य दर्शायें:',
 'listusers-submit'   => 'दर्शायें',
 'listusers-noresult' => 'सदस्य मिला नहीं।',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'सदस्य ग्रुप अधिकार',
 'listgrouprights-summary'  => 'नीचे विकिपर बनायें गये ग्रुपोंकी सूची उन ग्रुपोंके सदस्योंको प्राप्त अधिकारोंके साथ दर्शायी गई हैं। हर एक के अधिकार के बारे में अधिक जानकारी [[{{MediaWiki:Listgrouprights-helppage}}|यहां]] दी गई हैं।',
 'listgrouprights-group'    => 'ग्रुप',
@@ -1446,7 +1440,7 @@
 
 # E-mail user
 'mailnologin'     => 'पानेवाले का एड्रेस दिया नहीं',
-'mailnologintext' => 'अन्य सदस्यों को इ-मेल भेजने के लिये आपने [[Special:Userlogin|लॉग इन]] किया होना जरूरी हैं और आपकी [[Special:Preferences|वरीयताओंमें]] वैध इ-मेल एड्रेस होना आवश्यक हैं।',
+'mailnologintext' => 'अन्य सदस्यों को इ-मेल भेजने के लिये आपने [[Special:UserLogin|लॉग इन]] किया होना जरूरी हैं और आपकी [[Special:Preferences|वरीयताओंमें]] वैध इ-मेल एड्रेस होना आवश्यक हैं।',
 'emailuser'       => 'इस सदस्य को ई-मेल भेजें',
 'emailpage'       => 'सदस्य को इ-मेल करें',
 'emailpagetext'   => 'यदि इस सदस्य ने अपनी सदस्य वरीयताओं में एक उपयुक्त ई-मेल पता प्रवेश किया है, तब निम्न पत्र एक संदेश भेजेगा।
@@ -1472,10 +1466,10 @@
 'nowatchlist'          => 'आपकी ध्यानसूचीमें कोईभी लेख नहीं हैं।',
 'watchlistanontext'    => 'अपने ध्यानसूचीमें होने वाले लेख देखने या फिर संपादित करने के लिये कॄपया $1 करें।',
 'watchnologin'         => 'लॉग इन नहीं किया हैं',
-'watchnologintext'     => 'ध्यानसूचीमें बदलाव के लिये आपने [[Special:Userlogin|लॉग इन]] किया होना आवश्यक हैं।',
+'watchnologintext'     => 'ध्यानसूचीमें बदलाव के लिये आपने [[Special:UserLogin|लॉग इन]] किया होना आवश्यक हैं।',
 'addedwatch'           => 'ध्यानसूची में जोड़ दिया गया',
 'addedwatchtext'       => 'आपकी [[Special:Watchlist|ध्यानसूची]] में "<nowiki>$1</nowiki>" का समावेश कर दिया गया है ।
-भविष्य में इस पन्ने तथा इस पन्ने की वार्ता में होने  वाले बदलाव आपकी ध्यानसूची में दिखेंगे तथा [[Special:Recentchanges|हाल में हुए बदलावों की सूची]] में यह पन्ना बोल्ड दिखेगा ताकि  आप आसानी से इसका ध्यान रख सके ।
+भविष्य में इस पन्ने तथा इस पन्ने की वार्ता में होने  वाले बदलाव आपकी ध्यानसूची में दिखेंगे तथा [[Special:RecentChanges|हाल में हुए बदलावों की सूची]] में यह पन्ना बोल्ड दिखेगा ताकि  आप आसानी से इसका ध्यान रख सके ।
 
 <p>अगर आपको इस पन्ने को अपनी ध्यानसूची से निकालना हो तो "ध्यान हटायें" पर क्लिक करें ।',
 'removedwatch'         => 'ध्यानसूची से हटाया गया है',
@@ -1592,7 +1586,7 @@
 कृपया "back" पर वार करें और पृष्ठ को दुबारा से लोड करें, तब दुबारा कोशिश करें।',
 'protectlogpage'              => 'सुरक्षा सूची',
 'protectlogtext'              => 'नीचे उन पृष्ठों की सारणी है, जिनमें ताला लगा हुआ है और ताला खोल दिया गया है।
-वर्त्तमान में क्रियाशील सुरक्षित पृष्ठों की सूची के लिए [[Special:Protectedpages|सुरक्षित पृष्ठों की सूची]] देखें।',
+वर्त्तमान में क्रियाशील सुरक्षित पृष्ठों की सूची के लिए [[Special:ProtectedPages|सुरक्षित पृष्ठों की सूची]] देखें।',
 'protectedarticle'            => '"[[$1]]" सुरक्षित कर दिया',
 'modifiedarticleprotection'   => '"[[$1]]" के सुरक्षा-स्तर को बदला',
 'unprotectedarticle'          => '"[[$1]]" असुरक्षित कर दिया',
@@ -1761,7 +1755,7 @@
 'badipaddress'                => 'अमान्य आईपी पता।',
 'blockipsuccesssub'           => 'अवरोधन सफल ।(संपादन करने से रोक दिया गया है)',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] को बाध्य किया जा चुका है।<br />
-बाध्यों की समीक्षा के लिए [[Special:Ipblocklist|IP बाध्य सूची]] देखें।',
+बाध्यों की समीक्षा के लिए [[Special:IPBlockList|IP बाध्य सूची]] देखें।',
 'ipb-edit-dropdown'           => 'ब्लॉक कारण संपादित करें',
 'ipb-unblock-addr'            => '$1 को अनब्लॉक करें',
 'ipb-unblock'                 => 'सदस्य अथवा आईपी एड्रेस को अनब्लॉक करें',
@@ -1794,7 +1788,7 @@
 'blocklogentry'               => '"[[$1]]" को $2 $3 तक बदलाव करने से रोक दिया गया है।',
 'blocklogtext'                => 'यह सदस्यों को बाध्य एवं अबाध्य करने के क्रियाकलापों का अभिलेख है।
 स्वत: बाधित होने वाले IP पते इस सूची में उपलब्ध नहीं है।
-वर्त्तमान में क्रियाशील प्रतिबंधों और बाध्यों की सूची के लिए [[Special:Ipblocklist|IP बाधित सूची]] देखें।',
+वर्त्तमान में क्रियाशील प्रतिबंधों और बाध्यों की सूची के लिए [[Special:IPBlockList|IP बाधित सूची]] देखें।',
 'unblocklogentry'             => '$1 ब्लॉक निकाल दिया हैं',
 'block-log-flags-anononly'    => 'सिर्फ अनामक सदस्य',
 'block-log-flags-nocreate'    => 'खाता निर्माण पर रोक',
@@ -1832,7 +1826,7 @@
 'lockdbsuccesssub'    => 'डाटाबेस को ताला लगाया गया हैं',
 'unlockdbsuccesssub'  => 'डाटाबेस का ताला निकाला गया हैं',
 'lockdbsuccesstext'   => 'डाटाबेस को ताला लगाया गया हैं।<br />
-आपके द्वारा मेंटेनन्स पूरा होने के बाद [[Special:Unlockdb|ताला खोलना]] याद रखें।',
+आपके द्वारा मेंटेनन्स पूरा होने के बाद [[Special:UnlockDB|ताला खोलना]] याद रखें।',
 'unlockdbsuccesstext' => 'डाटाबेसका ताला खोल दिया गया हैं।',
 'lockfilenotwritable' => 'डाटाबेस के लॉक फ़ाईलमें लिख नहीं पा रहें हैं।
 डाटाबेस का ताला लगाने या खोलनेके लिये, इस फ़ाईलपर लिखा जाना जरूरी हैं।',
@@ -1859,8 +1853,6 @@
 
 इन मामलोंमे आपको स्वयं यह पन्ने जोडने पड़ सकते है ।",
 'movearticle'             => 'पृष्ठ का नाम बदलें',
-'movenologin'             => 'लॉग इन नहीं किया',
-'movenologintext'         => 'लेख स्थानांतरित करने के लिये आपने [[Special:Userlogin|लॉग इन]] किया होना जरूरी हैं।',
 'movenotallowed'          => '{{SITENAME}} पर पृष्ठ स्थानांतरणकी अनुमति आपको नहीं हैं।',
 'newtitle'                => 'नये शीर्षक की ओर:',
 'move-watch'              => 'ध्यान रखें',
@@ -1886,7 +1878,7 @@
 'revertmove'              => 'पुराने अवतरण पर ले जाएं',
 'delete_and_move'         => 'हटाया और नाम बदला',
 'delete_and_move_text'    => '==हटाने की जरूरत==
-लक्ष्य पृष्ठ "[[$1]]" पहले से अस्तित्वमें हैं।
+लक्ष्य पृष्ठ "[[:$1]]" पहले से अस्तित्वमें हैं।
 नाम बदलने के लिये क्या आप इसे हटाना चाहतें हैं?',
 'delete_and_move_confirm' => 'जी हां, पन्ना हटाईयें',
 'delete_and_move_reason'  => 'स्थानांतरण करने के लिये जगह बनाई',
@@ -2124,7 +2116,7 @@
 'show-big-image'       => 'सम्पूर्ण रिज़ोल्यूशन',
 'show-big-image-thumb' => '<small>इस झलक का आकार: $1 × $2 पीक्सेल्स</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'नई फ़ाईल्सकी गैलरी',
 'imagelisttext'         => "नीचे $2 के नुसार '''$1''' {{PLURAL:$1|फ़ाईल दी है।|फ़ाईलें दी हुईं हैं।}}",
 'newimages-summary'     => 'यह विशेष पन्ना हाल में अपलोड हुई फ़ाईलोंकी सूची दर्शाता हैं',
@@ -2409,7 +2401,7 @@
 
 # External editor support
 'edit-externally'      => 'बाहरी प्रणालीका इस्तेमाल करते हुए इस फ़ाईल को संपादित करें ।',
-'edit-externally-help' => 'अधिक जानकारीके लिये [http://meta.wikimedia.org/wiki/Help:External_editors सेट‍अप जानकारीयाँ] देखें ।',
+'edit-externally-help' => 'अधिक जानकारीके लिये [http://www.mediawiki.org/wiki/Manual:External_editors सेट‍अप जानकारीयाँ] देखें ।',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'सभी',
@@ -2479,7 +2471,7 @@
 'recreate'            => 'फिरसे बनायें',
 
 # HTML dump
-'redirectingto' => '[[$1]] की तरफ़ भेज रहें हैं...',
+'redirectingto' => '[[:$1]] की तरफ़ भेज रहें हैं...',
 
 # action=purge
 'confirm_purge'        => 'क्या आप यह पृष्ठ का कैश ख़ाली करने चाहिए?
@@ -2520,6 +2512,12 @@
 'autoredircomment' => '[[$1]] को अनुप्रेषित',
 'autosumm-new'     => 'नया पृष्ठ: $1',
 
+# Size units
+'size-bytes'     => '$1 B',
+'size-kilobytes' => '$1 KB',
+'size-megabytes' => '$1 MB',
+'size-gigabytes' => '$1 GB',
+
 # Live preview
 'livepreview-loading' => 'लोड हो रहा हैं...',
 'livepreview-ready'   => 'लोड हो रहा हैं... तैयार!',
@@ -2625,7 +2623,7 @@
 'version-software-product'         => 'प्रोडक्ट',
 'version-software-version'         => 'अवतरण',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'फ़ाइल पाथ',
 'filepath-page'    => 'फ़ाइल:',
 'filepath-submit'  => 'पाथ',
Index: languages/messages/MessagesHak.php
===================================================================
--- languages/messages/MessagesHak.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHak.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,6 @@
  * @file
  *
  * @author Hakka
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -436,10 +433,6 @@
 'blockededitsource'         => "Ngì tui '''$1''' chin-hàng '''phiên-siá''' ke vùn-sṳ yì-hâ:",
 'whitelistedittitle'        => 'Tên-ngi̍p heu chhòi hí-khó phiên-siá',
 'whitelistedittext'         => 'Ngì pit-sî siên $1 chhòi-nèn phiên-siá vùn-chông.',
-'whitelistreadtitle'        => 'Tên-ngi̍p heu chhòi hí-khó thu̍k vùn-chông',
-'whitelistreadtext'         => 'Ngì pit-sî siên [[Special:Userlogin|tên-ngi̍p]] chhòi hí-khó thu̍k vùn-chông.',
-'whitelistacctitle'         => 'Ngì pûn kim-chṳ́ kien-li̍p chong-ho',
-'whitelistacctext'          => 'Chhai pún Wiki chûng kien-li̍p chong-ho ngì pit-sî siên [[Special:Userlogin|tên-ngi̍p]] pin yúng-yû siong-kôan hí-khó-khièn.',
 'confirmedittitle'          => 'Email khok-ngin heu chhòi-nèn phiên-cho',
 'confirmedittext'           => 'Chhai phiên-cho chhṳ́-chông chṳ̂-chhièn pit-sî khok-ngin ngì-ke email thi-tiám. Chhiáng theu-ko [[Special:Preferences|chhâm-su sat-thin]] sat-thin pin ngiam-chṳn ngì-ke email thi-tiám.',
 'nosuchsectiontitle'        => 'Mò-yû liá-ke thon-lo̍k',
@@ -453,7 +446,7 @@
 'newarticletext'            => 'Ngì hien-chhai chin-ngi̍p yit-ke hàn-mò chhóng-kien ke vùn-chông.
 Yeu kien-chho ke vùn-chông, chhiáng chhai ha-mien ke phiên-cho-khiông chûng sû-ngi̍p nui-yùng (Chhâm-siòng [[{{MediaWiki:Helppage}}|Pông-chhu]]).
 Kó-yèn ngì-he put-séu-sîm to chhṳ́ hong-mien, chhṳ̍t-chiap tiám-kit ngì hi-khí chûng ke "fì-chón" on-néu fán-fì.',
-'anontalkpagetext'          => "---- ''Liá-he yit-ke hàn-mò kien-li̍p chong-ho ke ngia̍k-miàng yung-fu ke tui-fa-hong. Só-yî chṳ́-nèn yung IP thi-tiám lòi lâu kí lièn-lo̍k. Ke-IP thi-tiám khó-nèn yù-chhai kí-miàng yung-fu khiung-hióng. Kó-yèn ngì-he yit-miàng ngia̍k-miàng yung-fu ngin-vì pún-hong song ke phìn-lî kiên ngì mò-kôan, chhiáng [[Special:Userlogin|Chhóng-kien sîn chong-ho fe̍t-chá Tên-ngi̍p]] khó-yî phit-miên lòi-yì khì-thâ ngia̍k-miàng yung-fu ke fun-lon.''",
+'anontalkpagetext'          => "---- ''Liá-he yit-ke hàn-mò kien-li̍p chong-ho ke ngia̍k-miàng yung-fu ke tui-fa-hong. Só-yî chṳ́-nèn yung IP thi-tiám lòi lâu kí lièn-lo̍k. Ke-IP thi-tiám khó-nèn yù-chhai kí-miàng yung-fu khiung-hióng. Kó-yèn ngì-he yit-miàng ngia̍k-miàng yung-fu ngin-vì pún-hong song ke phìn-lî kiên ngì mò-kôan, chhiáng [[Special:UserLogin|Chhóng-kien sîn chong-ho fe̍t-chá Tên-ngi̍p]] khó-yî phit-miên lòi-yì khì-thâ ngia̍k-miàng yung-fu ke fun-lon.''",
 'noarticletext'             => 'Chhṳ́-chông muk-chhièn hàn-mò nui-yùng, ngì khó-yî chhai khì-thâ hong [[Special:Search/{{PAGENAME}}|sêu-chhà chhṳ́-chông phêu-thì]] fe̍t-chá [{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} phiên-chho chhṳ́-chông].',
 'clearyourcache'            => "'''Chu-yi:''' Chhai tú-chhùn yî-heu, ngì pit-sî khoai chhái-chhí chhîn-chhù hi-khí chhòi-nèn khon-tó chok-chhut ke kói-pien. '''Mozilla / Firefox / Safari:''' on-tén ''Shift'' chai tiám-kit '' Chhùng-sîn chṳ́n-lî ''(fe̍t-chá on-hâ ''Ctrl-Shift-R'', chhai Phìn-kó Mac song on-hâ ''Cmd-Shift-R''); '''IE:''' on-tén ''Ctrl'' chai tiám-kit ''Chhùng-sîn chṳ́n-lî'', fe̍t-he on-hâ ''Ctrl-F5''；'''Konqueror:''' chak  sî-yeu tiám-kit ''Chhùng-sîn chṳ́n-lî''; '''Opera:''' yung-fu sî-yeu chhai ''kûng-khí-sat-thin'' chûng vàn-cháng-thi chhîn-chhù ke khoai-chhí.",
 'usercssjsyoucanpreview'    => "<strong>Thì-sṳ:</strong> Chhai pó-chhùn chhièn chhiáng yung 'hién-sṳ yi-ko' on-néu lòi chhet-chhṳ ngì sîn-ke CSS/JS.",
@@ -500,7 +493,7 @@
 'template-semiprotected'    => '(pan-pó-fu)',
 'edittools'                 => '<!-- Chhṳ́-chhu ke vùn-sṳ chiông-voi pûn hién-sṳ chhai yî-ha phiên-cho lâu song-chhòn péu-tân chûng. -->',
 'nocreatetitle'             => 'Chhóng-kien vùn-chông su han-chṳ',
-'nocreatetext'              => 'Chhṳ́ mióng-chham han-chṳ chhóng-chho sîn hong-mien ke kûng-yung. ngì khó-yî fán-fì pin phiên-cho yí-kîn yû ke hong-mien, fe̍t-chá [[Special:Userlogin|tên-liu̍k fe̍t-he chhóng-kien sîn chong-fu]].',
+'nocreatetext'              => 'Chhṳ́ mióng-chham han-chṳ chhóng-chho sîn hong-mien ke kûng-yung. ngì khó-yî fán-fì pin phiên-cho yí-kîn yû ke hong-mien, fe̍t-chá [[Special:UserLogin|tên-liu̍k fe̍t-he chhóng-kien sîn chong-fu]].',
 
 # "Undo" feature
 'undo-success' => 'Ke phiên-cho khó-yî pûn chhat-sêu. Chhiáng kiám-chhà yî-ha tui-pí fu̍t-sṳ̍t liá chang-he ngì sióng-cho ke, yèn-heu tú-chhùn yî-ha kiên-kói vàn-sṳ̀n chhat-sêu phiên-siá.',
@@ -598,7 +591,7 @@
 'preferences'              => 'Chhâm-su sat-chṳ',
 'mypreferences'            => 'Ngô-ke chhâm-su sat-chṳ',
 'prefsnologin'             => 'Hàn-mò tên-ngi̍p',
-'prefsnologintext'         => 'Ngì pit-sî chhai-siên [[Special:Userlogin|tên-ngi̍p]] chhòi-nèn sat-chṳ ke-ngìn chhâm-su.',
+'prefsnologintext'         => 'Ngì pit-sî chhai-siên [[Special:UserLogin|tên-ngi̍p]] chhòi-nèn sat-chṳ ke-ngìn chhâm-su.',
 'prefsreset'               => 'Chhâm-su yí-kîn chhùng-sîn sat-chṳ.',
 'qbsettings'               => 'Khoai-suk thô-hòng-thiàu',
 'qbsettings-none'          => 'Mò',
@@ -722,10 +715,10 @@
 'reupload'                    => 'Chhùng-sîn song-chai',
 'reuploaddesc'                => 'Fán-fì song-chai péu-tân.',
 'uploadnologin'               => 'Hàn-mò tên-ngi̍p',
-'uploadnologintext'           => 'Ngì pit-sî chó-siên [[Special:Userlogin|tên-ngi̍p]] chhòi-nèn sông-chai vùn-khien.',
+'uploadnologintext'           => 'Ngì pit-sî chó-siên [[Special:UserLogin|tên-ngi̍p]] chhòi-nèn sông-chai vùn-khien.',
 'upload_directory_read_only'  => 'Song-chhòn muk-liu̍k ($1) put-chhùn-chhai fe̍t-chá mò siá khièn-han.',
 'uploaderror'                 => 'Song-chhòn chho-ngu',
-'uploadtext'                  => "Sṳ́-yung ha-mien ke péu-tân lòi song-chhòn yung-chhai vùn-chông nui sîn-ke thù-hìn tóng-on. Yeu kiám-sṳ fe̍t-chá sêu-chhà yî-chhièn song-chhòn ke thù-phién khó-yî chin-ngi̍p [[Special:Imagelist|Thù-hìn chhîn-tân]], song-chhòn lâu chhù-hi chiông-chhai [[Special:Log/upload|Song-chhòn ngit-ki]] chûng ki-liu̍k. Yeu-chhai vùn-chông chûng kâ-ngi̍p thù-hiong, sṳ́-yung yî-ha hìn-sṳt ke lièn-chiap: '''<nowiki>[[{{ns:image}}:file.jpg]]</nowiki>'''， '''<nowiki>[[{{ns:image}}:file.png|Thi-von vùn-sṳ]]</nowiki>''' fe̍t-he '''<nowiki>[[{{ns:media}}:file.ogg]]</nowiki>'''.",
+'uploadtext'                  => "Sṳ́-yung ha-mien ke péu-tân lòi song-chhòn yung-chhai vùn-chông nui sîn-ke thù-hìn tóng-on. Yeu kiám-sṳ fe̍t-chá sêu-chhà yî-chhièn song-chhòn ke thù-phién khó-yî chin-ngi̍p [[Special:ImageList|Thù-hìn chhîn-tân]], song-chhòn lâu chhù-hi chiông-chhai [[Special:Log/upload|Song-chhòn ngit-ki]] chûng ki-liu̍k. Yeu-chhai vùn-chông chûng kâ-ngi̍p thù-hiong, sṳ́-yung yî-ha hìn-sṳt ke lièn-chiap: '''<nowiki>[[{{ns:image}}:file.jpg]]</nowiki>'''， '''<nowiki>[[{{ns:image}}:file.png|Thi-von vùn-sṳ]]</nowiki>''' fe̍t-he '''<nowiki>[[{{ns:media}}:file.ogg]]</nowiki>'''.",
 'uploadlog'                   => 'Song-chhòn ki-liu̍k',
 'uploadlogpage'               => 'Song-chhòn ki-liu̍k',
 'uploadlogpagetext'           => 'Yî-ha he chui-khiûn song-chhòn vùn-khien ke chúng-péu.',
@@ -790,7 +783,7 @@
 'upload_source_url'  => '(Yit-ke yû-háu ke, hí-khó kûng-khôi fóng-mun ke URL)',
 'upload_source_file' => '(ngì thien-nó chûng ke tóng-on)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'On-cheu thù-chhiong miàng-chhṳ̂n sêu-chhà:',
 'imgfile'               => 'tóng-on',
 'imagelist'             => 'Tóng-on lie̍t-péu',
@@ -931,7 +924,7 @@
 'logempty'             => 'Mò-yû siông-thùng ki-liu̍k.',
 'log-title-wildcard'   => 'Chhà-chhìm liá-ke vùn-sṳ khôi-sṳ́ ke phêu-thì',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Só-yû ke hong-mian',
 'alphaindexline'    => '$1 to $2',
 'nextpage'          => 'Hâ yit-chông ($1)',
@@ -950,14 +943,14 @@
 'categories'         => 'Hong-mien fûn-lui',
 'categoriespagetext' => 'Yî-ha lie̍t-chhut só-yû ke hong-mien fûn-lui.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Hién-sṳ yung-fu lie̍t-péu chhiùng:',
 'listusers-submit'   => 'Hién-sṳ',
 'listusers-noresult' => 'Cháu put-to yung-fu.',
 
 # E-mail user
 'mailnologin'     => 'Mò email thi-tiám',
-'mailnologintext' => 'Ngì pit-sî siên [[Special:Userlogin|tên-ngi̍p]] pin-chhai [[Special:Preferences|chhâm-su sat-chṳ]] chûng yû yit-ke yû-háu ke e-mail thi-tiám chhòi-nèn email khì-thâ yung-fu.',
+'mailnologintext' => 'Ngì pit-sî siên [[Special:UserLogin|tên-ngi̍p]] pin-chhai [[Special:Preferences|chhâm-su sat-chṳ]] chûng yû yit-ke yû-háu ke e-mail thi-tiám chhòi-nèn email khì-thâ yung-fu.',
 'emailuser'       => 'Email ke-yung-fu',
 'emailpage'       => 'Email yung-fu',
 'emailpagetext'   => 'Kó-yèn ke-yung-fu yí-kîn chhai chhâm-su sat-chṳ chông chûng sû-ngi̍p yû-háu ke e-mail thi-tiám, yî-ha ke péu-kak chiông-ki yit-ke sêu-sit pûn ke-yung-fu. Ngì chhai chhâm-su sat-chṳ chûng só sû-ngi̍p ke e-mail thi-tiám chiông chhut-hien chhai email "fat-khien-ngìn" yit-làn-chûng, liá-yong ke-yung-fu chhiu khó-yî fì-fu̍k.',
@@ -982,9 +975,9 @@
 'nowatchlist'          => 'Ngì ke kam-sṳ lie̍t-péu he khûng-hî.',
 'watchlistanontext'    => 'Chhiáng $1 yî kiám-sṳ fe̍t-chá phiên-chho ngì-ke kam-sṳ lie̍t-péu.',
 'watchnologin'         => 'Hàn-mò tên-ngi̍p',
-'watchnologintext'     => 'Ngì pit-sî siên [[Special:Userlogin|tên-ngi̍p]] chhòi-nèn kiên-kói ngì-ke kam-sṳ lie̍t-péu.',
+'watchnologintext'     => 'Ngì pit-sî siên [[Special:UserLogin|tên-ngi̍p]] chhòi-nèn kiên-kói ngì-ke kam-sṳ lie̍t-péu.',
 'addedwatch'           => 'Kâ-ngi̍p to kam-sṳ lie̍t-péu',
-'addedwatchtext'       => "Hong-mien \"[[:\$1]]\" yí-kîn pûn kâ-ngi̍p to ngì-ke [[Special:Watchlist|Kam-sṳ chhîn-tân]] chûng. Chiông-lòi yû-kôan chhṳ́ hong-mien khi̍p khì-thâ thó-lun-hong ke ngim-hò siû-cháng chiông-voi chhai hong-mien lie̍t-chhut, song-chhiá hàn-voi chhai [[Special:Recentchanges|Chui-khiûn ke kiên-kói]] chûng ke '''chhû-thí''' hìn-sṳt lie̍t-chhut. Kó-yèn  ngì heu-lòi sióng chhiùng hong-mien kam-sṳ chhîn-tân chûng chhîn-chhù, hí-khó tiám-kit thô-hòng thiàu-chûng \"thìn-chṳ́ kam-sṳ\" ke lièn-kiet。",
+'addedwatchtext'       => "Hong-mien \"[[:\$1]]\" yí-kîn pûn kâ-ngi̍p to ngì-ke [[Special:Watchlist|Kam-sṳ chhîn-tân]] chûng. Chiông-lòi yû-kôan chhṳ́ hong-mien khi̍p khì-thâ thó-lun-hong ke ngim-hò siû-cháng chiông-voi chhai hong-mien lie̍t-chhut, song-chhiá hàn-voi chhai [[Special:RecentChanges|Chui-khiûn ke kiên-kói]] chûng ke '''chhû-thí''' hìn-sṳt lie̍t-chhut. Kó-yèn  ngì heu-lòi sióng chhiùng hong-mien kam-sṳ chhîn-tân chûng chhîn-chhù, hí-khó tiám-kit thô-hòng thiàu-chûng \"thìn-chṳ́ kam-sṳ\" ke lièn-kiet。",
 'removedwatch'         => 'Yí-kîn thìn-chṳ́ kam-sṳ',
 'removedwatchtext'     => 'Vùn-chông "[[:$1]]" yí-kîn chhiùng Ngì kekam-sṳ lie̍t-péu mien-chûng yì-chhù.',
 'watch'                => 'Kam-sṳ',
@@ -1053,7 +1046,7 @@
 'revertpage'                  => 'Fî-fu̍k yù [[Special:Contributions/$2|$2]] ([[User talk:$2|tui-fa]]) ke phiên-cho; kiên-kói fì-fu̍k [[User:$1|$1]] ke chui-heu yit-ke pán-pún', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'sessionfailure'              => 'Ngì-ke tên-ngi̍p sṳ-fû yû mun-thì, vi-liáu fòng-chṳ́ sêu-sit pûn làn-chiet, pún-chhṳ chhâu-chok yí-kîn chhí-sêu, chhiáng-on "song-yit-chông" chhùng-sîn chai-ngi̍p.',
 'protectlogpage'              => 'Pó-fu ngit-ki',
-'protectlogtext'              => 'Ha-mien he vùn-chông só-thin lâu chhí-sêu só-thin ke lie̍t-péu. Chhiáng chhâm-kháu [[Special:Protectedpages|Pó-fu vùn-chông chhîn-tân]] yî-khi̍p kiám-sṳ tông-chhièn chin-hàng ke vùn-chông pó-fu.',
+'protectlogtext'              => 'Ha-mien he vùn-chông só-thin lâu chhí-sêu só-thin ke lie̍t-péu. Chhiáng chhâm-kháu [[Special:ProtectedPages|Pó-fu vùn-chông chhîn-tân]] yî-khi̍p kiám-sṳ tông-chhièn chin-hàng ke vùn-chông pó-fu.',
 'protectedarticle'            => 'Yí-kîn pó-fu "[[$1]]"',
 'unprotectedarticle'          => 'yí-kîn kié-chhù pó-fu "[[$1]]"',
 'protect-title'               => 'Chang-chhai pó-fu "$1"',
@@ -1177,7 +1170,7 @@
 'ipbhidename'                 => 'Chhai chhà-fûng ngit-ki, fa̍t-chhiok chhà-fûng lie̍t-péu yî-khi̍p yung-fu lie̍t-péu chûng yún-chhòng yung-fu-miàng.',
 'badipaddress'                => 'IP-ke thi-tiám mò chṳn-khok.',
 'blockipsuccesssub'           => 'chhà-fûng sṳ̀n-kûng',
-'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] yí-kîn pûn chhà-fûng. <br />Chhâm-siòng [[Special:Ipblocklist|pûn-fûng IP thi-tiám lie̍t-péu]] yî fu̍k-sṳ́m chhà-fûng.',
+'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] yí-kîn pûn chhà-fûng. <br />Chhâm-siòng [[Special:IPBlockList|pûn-fûng IP thi-tiám lie̍t-péu]] yî fu̍k-sṳ́m chhà-fûng.',
 'ipb-edit-dropdown'           => 'Phiên-siá chhà-fûng ngièn-yîn',
 'ipb-unblock-addr'            => 'Kié-chhù fûng-kim $1',
 'ipb-unblock'                 => 'Kié-chhù kim-fûng yung-fu miàng fe̍t-chá IP thi-tiám',
@@ -1204,7 +1197,7 @@
 'autoblocker'                 => 'Ngì-ke IP lâu pûn fûng-liáu ke "$1" he yit-yong ke. Fûng-só ngièn-yîn: "$2".',
 'blocklogpage'                => 'Fûng-só ki-liu̍k',
 'blocklogentry'               => '"[[$1]]" yí-kîn pûn chhà-fûng $3, chûng-chṳ́ sṳ̀-kiên he $2',
-'blocklogtext'                => 'Liá-he kôan-yî yung-fu fûng-kim lâu kié-chhù fûng-kim chhâu-chok ke ki-liu̍k. Pûn chhṳ-thung fûng-kim ke IP thi-tiám mò-yû lie̍t-chhut. Chhiáng chhâm-kháu [[Special:Ipblocklist|Pûn chhà-fûng ke IP thi-tiám lâu yung-fu lie̍t-péu]].',
+'blocklogtext'                => 'Liá-he kôan-yî yung-fu fûng-kim lâu kié-chhù fûng-kim chhâu-chok ke ki-liu̍k. Pûn chhṳ-thung fûng-kim ke IP thi-tiám mò-yû lie̍t-chhut. Chhiáng chhâm-kháu [[Special:IPBlockList|Pûn chhà-fûng ke IP thi-tiám lâu yung-fu lie̍t-péu]].',
 'unblocklogentry'             => '"[[$1]]" yí-kîn pûn kié-fûng',
 'block-log-flags-anononly'    => 'Han-chṳ ngia̍k-miàng ke yung-fu',
 'block-log-flags-nocreate'    => 'Kim-chṳ́ chhṳ́ IP/Yung-fu kien-li̍p sîn chong-fu',
@@ -1257,8 +1250,6 @@
 *Sîn vùn-chông yí-kîn yû yit-ke pâu-hàm nui-yùng ke tui-fa-hiong, fe̍t-he
 *Ngì put kiêu-sién ha-mien ke fu̍k-sién khiông. Chhai liá-chúng chhìn-khóng hâ, pit-sî sú-kûng yì-thung fe̍t-he ha̍p-phîn vùn-chông.",
 'movearticle'             => 'Yì-thung vùn-chông',
-'movenologin'             => 'Hàn-mò tên-ngi̍p',
-'movenologintext'         => 'Ngì pit-sî he yit-miàng tên-ki yung-fu pin-chhiâ [[Special:Userlogin|tên-ngi̍p]] heu chhòi-nèn Yì-thung yit-ke vùn-chông.',
 'newtitle'                => 'Sîn phêu-thì',
 'move-watch'              => 'Kam-sṳ chhṳ́-chông',
 'movepagebtn'             => 'Yì-thung vùn-chông',
@@ -1276,7 +1267,7 @@
 'delete_and_move'         => 'Chhù-chhîn lâu yì-thung',
 'delete_and_move_text'    => '==Sî-yeu chhù-thet==
 
-Muk-phêu vùn-chông "[[$1]]" yí-kîn chhùn-chhai.
+Muk-phêu vùn-chông "[[:$1]]" yí-kîn chhùn-chhai.
 Ngì khok-ngin sî-yeu chhù-thet ngièn hong-mien khi̍p chin-hàng yì-thung mâ?',
 'delete_and_move_confirm' => 'Chhie̍t-tui, chhù-thet chhṳ́ hong-mien',
 'delete_and_move_reason'  => 'Chhù-thet yî-phien yì-thung',
@@ -1485,7 +1476,7 @@
 'show-big-image'       => 'Vàn-cháng ke kié-chhiong-thu',
 'show-big-image-thumb' => '<small>Liá-ke puk-suk-thù ke kié-chhiong-thu he: $1 × $2 chhiong-su</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Sîn-kien thù-chhiong ke va̍k-lòng',
 'imagelisttext'         => 'Yî-ha he on $2 phài-lie̍t ke $1-ke tóng-on lie̍t-péu.',
 'showhidebots'          => '($1 kî-hi-ngìn)',
@@ -1509,7 +1500,7 @@
 
 # External editor support
 'edit-externally'      => 'Yung ngoi-phu chhàng-sṳt phiên-siá chhṳ́ tóng-on',
-'edit-externally-help' => 'Chhiáng chhâm-siòng [http://meta.wikimedia.org/wiki/Help:External_editors sat-thin phu] liáu-kié siòng-se sin-sit.',
+'edit-externally-help' => 'Chhiáng chhâm-siòng [http://www.mediawiki.org/wiki/Manual:External_editors sat-thin phu] liáu-kié siòng-se sin-sit.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'Chhiòn-phu',
@@ -1560,7 +1551,7 @@
 'recreate'            => 'Chhùng-kien',
 
 # HTML dump
-'redirectingto' => 'Chhùng-thin-hiong to [[$1]]...',
+'redirectingto' => 'Chhùng-thin-hiong to [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Chhîn-chhù pún-chông chhòng-chhùn？
Index: languages/messages/MessagesPag.php
===================================================================
--- languages/messages/MessagesPag.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPag.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Arikasikis
- * @author SPQRobin
  */
 
 $messages = array(
@@ -122,7 +121,6 @@
 'blockededitsource'     => "Wadyad leksab so text na '''saray binalom''' anggag '''$1''':",
 'whitelistedittitle'    => 'Nakaukulan ya onloob umpian makapanbalo',
 'whitelistedittext'     => 'Nakaukulan mo ya $1 umpian nabalo o nadagdagan ray bolobolong.',
-'whitelistreadtext'     => 'Nakaukulan mon [[Special:Userlogin|onloob]] umpian basaen ramay bolong.',
 'confirmedittitle'      => 'Nakaukulan na e-mail confirmation para makapan-edit',
 'loginreqtitle'         => 'Nakaukulan kan Onloob',
 'loginreqlink'          => 'onloob',
@@ -182,7 +180,7 @@
 'sourcefilename'  => 'Filename na pinanlapuan:',
 'watchthisupload' => 'Bantayan yan bolong',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Ngaran',
 
 # Image description page
@@ -220,7 +218,7 @@
 'all-logs-page'     => 'Amin ran log',
 'log-search-submit' => 'Ula',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Amin ya bolobolong',
 'alphaindexline'    => '$1 anggad $2',
 'nextpage'          => 'Ontombok ya page ($1)',
@@ -246,7 +244,7 @@
 'mywatchlist'    => 'Listaan na babantayan ko',
 'watchnologin'   => 'Agka ni akaloob',
 'addedwatch'     => 'Enyarom ed listaan na bantayan',
-'addedwatchtext' => "Impila so bolong ya \"[[:\$1]]\" diad [[Special:Watchlist|listaan na babantayan]] mo. Isulat diman so saray ontombok ran idagdag o panagbalo ed sayan bolong san diad bolong na tongtongan. San akasulat ran '''mapatnag''' (bolded) ed [[Special:Recentchanges|listaan na saray sampot ran binalo]] umpian mas maganom ya nanengneng.
+'addedwatchtext' => "Impila so bolong ya \"[[:\$1]]\" diad [[Special:Watchlist|listaan na babantayan]] mo. Isulat diman so saray ontombok ran idagdag o panagbalo ed sayan bolong san diad bolong na tongtongan. San akasulat ran '''mapatnag''' (bolded) ed [[Special:RecentChanges|listaan na saray sampot ran binalo]] umpian mas maganom ya nanengneng.
 
 No labay mon ekalen may bolong diad listaan na babantayan, tapik mo labat so \"ekalen ed babantayan\" (unwatch) diad gilig ya bar.",
 'watch'          => 'bantayan',
@@ -345,7 +343,7 @@
 # Attribution
 'lastmodifiedatby' => 'Sampot ya binalo yan bolong nen agew ya $2, $1 nen $3.', # $1 date, $2 time, $3 user
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Anapen',
 
 # EXIF tags
Index: languages/messages/MessagesDv.php
===================================================================
--- languages/messages/MessagesDv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Glacious
  * @author MF-Warburg
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Glacious
  */
 
 $rtl = true;
@@ -247,7 +246,7 @@
 'uploadedfiles'     => 'ފޮނުވިފައިވާ ފައިލުތައް',
 'uploadwarning'     => 'ފައިލުފޮނުއްވުމުގެ ކުރިން ދެވޭ އިންޒާރު',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'ފައިލުތަކުގެ ފިހުރިސްތު',
 
 # Image description page
@@ -276,7 +275,7 @@
 # Book sources
 'booksources' => 'ފޮތްތަކުގެ މަސްދަރުތައް',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ހުރިހާ ޞަފްޙާތައް',
 'allarticles'    => 'ހުރިހާ މަޒުމޫނުތައް',
 'allinnamespace' => 'ހުރިހާ ޞަފްޙާތައް (ނުތުގު $1 ގައިވާ)',
@@ -365,7 +364,7 @@
 'allmessagesdefault' => 'ކުރީގެ މަތަން',
 'allmessagescurrent' => 'މިހާރުގެ މަތަން',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 ސެއްޓި)',
 'ilsubmit'     => 'ހޯއްދަވާ',
 
@@ -386,7 +385,7 @@
 'confirmemail' => 'އީމޭލު އެޑްރެސް ޔަގީންކުރައްވާ',
 
 # HTML dump
-'redirectingto' => 'މިސްރާބު ކުރެވެނީ [[$1]] އަށް...',
+'redirectingto' => 'މިސްރާބު ކުރެވެނީ [[:$1]] އަށް...',
 
 # action=purge
 'confirm_purge_button' => 'ރަނގަޅު',
Index: languages/messages/MessagesNan.php
===================================================================
--- languages/messages/MessagesNan.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNan.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -301,17 +301,13 @@
 'subject-preview'        => 'Ū-lám tê-bo̍k/piau-tê',
 'whitelistedittitle'     => 'Su-iàu teng-ji̍p chiah ē-sái siu-kái',
 'whitelistedittext'      => 'Lí ài $1 chiah ē-sái siu-kái.',
-'whitelistreadtitle'     => 'Su-iàu teng-ji̍p chiah ē-iong-tit tha̍k',
-'whitelistreadtext'      => 'Lí ài [[Special:Userlogin|teng-ji̍p]] chiah ē-sái tha̍k.',
-'whitelistacctitle'      => 'Bô ún-chún lí khui kháu-chō',
-'whitelistacctext'       => 'eh ē-tàng tiàm chit ê Wiki khui kháu-chō, lí su-iàu [[Special:Userlogin|teng-ji̍p]] jī-chhiáⁿ ū sek-tong ê hí-khó.',
 'confirmedittitle'       => 'Su-iàu khak-jīn e-mail chū-chí chiah ē-tit pian-chi̍p',
 'loginreqtitle'          => 'Su-iàu Teng-ji̍p',
 'accmailtitle'           => 'Bi̍t-bé kià chhut khì ah.',
 'accmailtext'            => '$1 ê bi̍t-bé í-keng kìa khì $2.',
 'newarticle'             => '(Sin)',
 'newarticletext'         => "Lí tòe 1 ê liân-kiat lâi kàu 1 bīn iáu-bōe chûn-chāi ê ia̍h. Beh khai-sí pian-chi̍p chit ia̍h, chhiáⁿ tī ē-kha ê bûn-jī keh-á lāi-té phah-jī. ([[{{MediaWiki:Helppage}}|Bo̍k-lio̍k]] kà lí án-choáⁿ chìn-hêng.) Ká-sú lí bô-tiuⁿ-tî lâi kàu chia, ē-sai chhi̍h liû-lám-khì ê '''téng-1-ia̍h''' tńg--khì.",
-'anontalkpagetext'       => "----''Pún thó-lūn-ia̍h bô kò·-tēng ê kháu-chō/hō·-thâu, kan-na ū 1 ê IP chū-chí (chhin-chhiūⁿ 123.456.789.123). In-ūi bô kāng lâng tī bô kāng sî-chūn ū khó-lêng tú-hó kong-ke kāng-ê IP, lâu tī chia ê oē ū khó-lêng hō· bô kāng lâng ê! Beh pī-bián chit khoán būn-tê, ē-sái khì [[Special:Userlogin|khui 1 ê hō·-thâu a̍h-sī teng-ji̍p]].''",
+'anontalkpagetext'       => "----''Pún thó-lūn-ia̍h bô kò·-tēng ê kháu-chō/hō·-thâu, kan-na ū 1 ê IP chū-chí (chhin-chhiūⁿ 123.456.789.123). In-ūi bô kāng lâng tī bô kāng sî-chūn ū khó-lêng tú-hó kong-ke kāng-ê IP, lâu tī chia ê oē ū khó-lêng hō· bô kāng lâng ê! Beh pī-bián chit khoán būn-tê, ē-sái khì [[Special:UserLogin|khui 1 ê hō·-thâu a̍h-sī teng-ji̍p]].''",
 'clearyourcache'         => "'''Chù-ì:''' Pó-chûn liáu-āu, tio̍h ē-kì leh kā liû-lám-khì ê cache piàⁿ tiāu chiah khoàⁿ-ē-tio̍h kái-piàn: '''Mozilla:''' chhi̍h ''reload/têng-sin chài-ji̍p'' (a̍h-sī ''Ctrl-R''), '''Internet Explorer kap Opera:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-R'', '''Konqueror''' ''Ctrl-R''.",
 'usercssjsyoucanpreview' => "<strong>Phiat-pō·</strong>: Pó-chûn chìn-chêng ē-sái chhi̍h 'Seng khoàⁿ-māi' kiám-cha sin ê CSS a̍h-sī JavaScript.",
 'usercsspreview'         => "'''Sè-jī! Lí hiān-chú-sî khoàⁿ--ê sī lí ê su-jîn css ê preview; che iáu-bōe pó-chûn--khí-lâi!'''",
@@ -384,7 +380,7 @@
 'preferences'           => 'Siat-tēng',
 'mypreferences'         => 'Góa ê siat-tēng',
 'prefsnologin'          => 'Bô teng-ji̍p',
-'prefsnologintext'      => 'Lí it-tēng ài [[Special:Userlogin|teng-ji̍p]] chiah ē-tàng chhiâu iōng-chiá ê siat-tēng.',
+'prefsnologintext'      => 'Lí it-tēng ài [[Special:UserLogin|teng-ji̍p]] chiah ē-tàng chhiâu iōng-chiá ê siat-tēng.',
 'prefsreset'            => 'Iōng-chiá siat-tēng í-keng chiàu goân siat-tēng têng-siat.',
 'qbsettings'            => 'Quickbar ê siat-tēng',
 'changepassword'        => 'Oāⁿ bi̍t-bé',
@@ -454,7 +450,7 @@
 'reupload'          => 'Têng sàng-chiūⁿ-bāng',
 'reuploaddesc'      => 'Tò khì sàng-chiūⁿ-bāng ê pió.',
 'uploadnologin'     => 'Bô teng-ji̍p',
-'uploadnologintext' => 'Bô [[Special:Userlogin|teng-ji̍p]] bē-sái-tit kā tóng-àn sàng-chiūⁿ-bāng.',
+'uploadnologintext' => 'Bô [[Special:UserLogin|teng-ji̍p]] bē-sái-tit kā tóng-àn sàng-chiūⁿ-bāng.',
 'uploaderror'       => 'Upload chhò-gō·',
 'uploadlogpagetext' => 'Í-hā sī chòe-kīn sàng-chiūⁿ-bāng ê tóng-àn ê lia̍t-toaⁿ.',
 'filename'          => 'Tóng-àn',
@@ -474,7 +470,7 @@
 'destfilename'      => 'Tóng-àn sin miâ:',
 'watchthisupload'   => 'Kàm-sī chit ia̍h',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'             => 'Iáⁿ-siōng lia̍t-toaⁿ',
 'imagelist_date'        => 'Ji̍t-kî',
 'imagelist_name'        => 'Miâ',
@@ -573,7 +569,7 @@
 'speciallogtitlelabel' => 'Sû-tiâu:',
 'logempty'             => 'Log lāi-bīn bô sio-tùi ê hāng-bo̍k.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Só·-ū ê ia̍h',
 'alphaindexline'    => '$1 kàu $2',
 'nextpage'          => 'Āu 1 ia̍h ($1)',
@@ -591,7 +587,7 @@
 
 # E-mail user
 'mailnologin'     => 'Bô siu-phoe ê chū-chí',
-'mailnologintext' => 'Lí it-tēng ài [[Special:Userlogin|teng-ji̍p]] jī-chhiáⁿ ū 1 ê ū-hāu ê e-mail chū-chí tī lí ê [[Special:Preferences|iōng-chiá siat-tēng]] chiah ē-tàng kià e-mail hō· pa̍t-ūi iōng-chiá.',
+'mailnologintext' => 'Lí it-tēng ài [[Special:UserLogin|teng-ji̍p]] jī-chhiáⁿ ū 1 ê ū-hāu ê e-mail chū-chí tī lí ê [[Special:Preferences|iōng-chiá siat-tēng]] chiah ē-tàng kià e-mail hō· pa̍t-ūi iōng-chiá.',
 'emailuser'       => 'Kià e-mail hō· iōng-chiá',
 'emailpage'       => 'E-mail iōng-chiá',
 'emailpagetext'   => 'Ká-sú chit ê iōng-chiá ū siat-tēng 1 ê ū-hāu ê e-mail chū-chí, lí tō ē-tàng ēng ē-kha chit tiuⁿ FORM hoat sìn-sek hō· i. Lí siat-tēng ê e-mail chū-chí ē chhut-hiān tī e-mail ê "Kià-phoe-jîn" (From) hit ūi. Án-ne siu-phoe-jîn chiah ū hoat-tō· kā lí hôe-phoe.',
@@ -611,9 +607,9 @@
 'watchlistfor'         => "('''$1''' ê)",
 'nowatchlist'          => 'Lí ê kàm-sī-toaⁿ bô pòaⁿ hāng.',
 'watchnologin'         => 'Bô teng-ji̍p',
-'watchnologintext'     => 'Lí it-tēng ài [[Special:Userlogin|teng-ji̍p]] chiah ē-tàng siu-kái lí ê kàm-sī-toaⁿ.',
+'watchnologintext'     => 'Lí it-tēng ài [[Special:UserLogin|teng-ji̍p]] chiah ē-tàng siu-kái lí ê kàm-sī-toaⁿ.',
 'addedwatch'           => 'Í-keng ka-ji̍p kàm-sī-toaⁿ',
-'addedwatchtext'       => "\"[[:\$1]]\" chit ia̍h í-keng ka-ji̍p lí ê [[Special:Watchlist|kàm-sī-toaⁿ]]. Bī-lâi chit ia̍h a̍h-sī siong-koan ê thó-lūn-ia̍h nā ū kái-piàn, ē lia̍t tī hia. Tông-sî tī [[Special:Recentchanges|Chòe-kīn ê kái-piàn]] ē iōng '''chho·-thé''' hián-sī ia̍h ê piau-tê, án-ne khah bêng-hián. Ká-sú lí beh chiōng chit ia̍h tùi lí ê kàm-sī-toaⁿ tû tiāu, khì khòng-chè-tiâu chhi̍h \"Mài kàm-sī\" chiū ē-sái-tit.",
+'addedwatchtext'       => "\"[[:\$1]]\" chit ia̍h í-keng ka-ji̍p lí ê [[Special:Watchlist|kàm-sī-toaⁿ]]. Bī-lâi chit ia̍h a̍h-sī siong-koan ê thó-lūn-ia̍h nā ū kái-piàn, ē lia̍t tī hia. Tông-sî tī [[Special:RecentChanges|Chòe-kīn ê kái-piàn]] ē iōng '''chho·-thé''' hián-sī ia̍h ê piau-tê, án-ne khah bêng-hián. Ká-sú lí beh chiōng chit ia̍h tùi lí ê kàm-sī-toaⁿ tû tiāu, khì khòng-chè-tiâu chhi̍h \"Mài kàm-sī\" chiū ē-sái-tit.",
 'removedwatch'         => 'Í-keng tùi kàm-sī-toaⁿ tû tiāu',
 'removedwatchtext'     => '"[[:$1]]" chit ia̍h í-keng tùi lí ê kàm-sī-toaⁿ tû tiāu.',
 'watch'                => 'kàm-sī',
@@ -704,14 +700,14 @@
 'ipbsubmit'          => 'Hong-só chit ūi iōng-chiá',
 'badipaddress'       => 'Bô-hāu ê IP chū-chí',
 'blockipsuccesssub'  => 'Hong-só sêng-kong',
-'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] í-keng pī hong-só. <br />Khì [[Special:Ipblocklist|IP hong-só lia̍t-toaⁿ]] review hong-só ê IP.',
+'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] í-keng pī hong-só. <br />Khì [[Special:IPBlockList|IP hong-só lia̍t-toaⁿ]] review hong-só ê IP.',
 'ipusubmit'          => 'Chhú-siau hong-só chit ê chū-chí',
 'ipblocklist'        => 'Siū hong-só ê IP chū-chí kap iōng-chiá miâ-chheng',
 'blocklink'          => 'hong-só',
 'contribslink'       => 'kòng-hiàn',
 'autoblocker'        => 'Chū-tōng kìm-chí lí sú-iōng, in-ūi lí kap "$1" kong-ke kāng 1 ê IP chū-chí (kìm-chí lí-iû "$2").',
 'blocklogentry'      => 'hong-só [[$1]], siat kî-hān chì $2 $3',
-'blocklogtext'       => 'Chit-ê log lia̍t-chhut block/unblock ê tōng-chok. Chū-tōng block ê IP chū-chí bô lia̍t--chhut-lâi ([[Special:Ipblocklist]] ū hiān-chú-sî ū-hāu ê block/ban o·-miâ-toaⁿ).',
+'blocklogtext'       => 'Chit-ê log lia̍t-chhut block/unblock ê tōng-chok. Chū-tōng block ê IP chū-chí bô lia̍t--chhut-lâi ([[Special:IPBlockList]] ū hiān-chú-sî ū-hāu ê block/ban o·-miâ-toaⁿ).',
 
 # Developer tools
 'locknoconfirm' => 'Lí bô kau "khak-tēng" ê keh-á.',
@@ -731,8 +727,6 @@
 Liâu--lo̍h-khì chìn-chêng, chhiáⁿ seng khak-tēng lí ū liáu-kái chiah-ê hiō-kó.",
 'movepagetalktext' => "Siong-koan ê thó-lūn-ia̍h (chún ū) oân-nâ ē chū-tōng tòe leh sóa-ūi. Í-hā ê chêng-hêng '''bô chún-sǹg''': *Beh kā chit ia̍h tùi 1 ê miâ-khong-kan (namespace) soá khì lēng-gōa 1 ê miâ-khong-kan, *Sin piau-tê í-keng ū iōng--kòe ê thó-lūn-ia̍h, he̍k-chiá *Ē-kha ê sió-keh-á bô phah-kau. Í-siōng ê chêng-hêng nā-chún tī leh, lí chí-hó iōng jîn-kang ê hong-sek sóa ia̍h a̍h-sī kā ha̍p-pèng (nā ū su-iàu).",
 'movearticle'      => 'Sóa ia̍h:',
-'movenologin'      => 'Bô teng-ji̍p',
-'movenologintext'  => 'Lí it-tēng ài sī chù-chheh ê iōng-chiá jī-chhiáⁿ ū [[Special:Userlogin|teng-ji̍p]] chiah ē-tàng sóa ia̍h.',
 'newtitle'         => 'Khì sin piau-tê:',
 'move-watch'       => 'Kàm-sī chit ia̍h',
 'movepagebtn'      => 'Sóa ia̍h',
@@ -798,7 +792,7 @@
 'file-nohires'         => '<small>Bô khah koân ê kái-sek-tō͘.</small>',
 'show-big-image-thumb' => '<small>Chit tiuⁿ ū-lám tô͘ (preview) ê toā-sè: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Sin iáⁿ-siōng oē-lóng',
 'imagelisttext' => "Í-hā sī '''$1''' tiuⁿ iáⁿ-siōng ê lia̍t-toaⁿ, $2 pâi-lia̍t.",
 'ilsubmit'      => 'Kiám-sek',
@@ -810,7 +804,7 @@
 
 # External editor support
 'edit-externally'      => 'Iōng gōa-pō· èng-iōng nńg-thé pian-chi̍p chit-ê tóng-àn',
-'edit-externally-help' => 'Chham-khó [http://meta.wikimedia.org/wiki/Help:External_editors Help:External_editors] ê soat-bêng.',
+'edit-externally-help' => 'Chham-khó [http://www.mediawiki.org/wiki/Manual:External_editors Help:External_editors] ê soat-bêng.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'choân-pō·',
@@ -860,7 +854,7 @@
 # Special:Version
 'version' => 'Pán-pún', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'Tóng-àn ê soàⁿ-lō·',
 
 # Special:SpecialPages
Index: languages/messages/MessagesHu.php
===================================================================
--- languages/messages/MessagesHu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,14 @@
  * @ingroup Language
  * @file
  *
+ * @author Balasyum
+ * @author Bdamokos
+ * @author Bennó
+ * @author Cerasus
  * @author Dani
- * @author Siebrand
+ * @author Dorgan
  * @author Samat
  * @author Tgr
- * @author Bdamokos
- * @author Cerasus
- * @author Dorgan
- * @author Balasyum
- * @author Bennó
  */
 
 $namespaceNames = array(
@@ -92,7 +91,7 @@
 	'Mostcategories'          => array( 'Legtöbb kategóriába tartozó lapok' ),
 	'Mostimages'              => array( 'Legtöbbet használt képek' ),
 	'Mostrevisions'           => array( 'Legtöbbet szerkesztett lapok' ),
-	'Fewestrevisions'         => array( 'Legtöbbet szerkesztett javítások' ),
+	'Fewestrevisions'         => array( 'Legkevesebbet szerkesztett lapok' ),
 	'Shortpages'              => array( 'Rövid lapok' ),
 	'Longpages'               => array( 'Hosszú lapok' ),
 	'Newpages'                => array( 'Új lapok' ),
@@ -164,115 +163,114 @@
 
 $magicWords = array(
 	'redirect'            => array( '0', '#ÁTIRÁNYÍTÁS', '#REDIRECT' ),
-	'notoc'               => array( '0', '__NOTOC__', '__NINCSTARTALOMJEGYZÉK__', '__NINCSTJ__' ),
-	'nogallery'           => array( '0', '__NOGALLERY__', '__NINCSGALÉRIA__' ),
-	'forcetoc'            => array( '0', '__FORCETOC__', '__LEGYENTARTALOMJEGYZÉK__', '__LEGYENTJ__' ),
-	'toc'                 => array( '0', '__TOC__', '__TARTALOMJEGYZÉK__', '__TJ__' ),
-	'noeditsection'       => array( '0', '__NOEDITSECTION__', '__NINCSSZERKESZTÉS__', '__NINCSSZERK__' ),
-	'currentmonth'        => array( '1', 'CURRENTMONTH', 'JELENLEGIHÓNAP' ),
-	'currentmonthname'    => array( '1', 'CURRENTMONTHNAME', 'JELENLEGIHÓNAPNEVE' ),
-	'currentmonthabbrev'  => array( '1', 'CURRENTMONTHABBREV', 'JELENLEGIHÓNAPRÖVID' ),
-	'currentday'          => array( '1', 'CURRENTDAY', 'MAINAP' ),
-	'currentday2'         => array( '1', 'CURRENTDAY2', 'MAINAP2' ),
-	'currentdayname'      => array( '1', 'CURRENTDAYNAME', 'MAINAPNEVE' ),
-	'currentyear'         => array( '1', 'CURRENTYEAR', 'JELENLEGIÉV' ),
-	'currenttime'         => array( '1', 'CURRENTTIME', 'JELENLEGIIDŐ' ),
-	'currenthour'         => array( '1', 'CURRENTHOUR', 'JELENLEGIÓRA' ),
-	'localmonth'          => array( '1', 'LOCALMONTH', 'HELYIHÓNAP' ),
-	'localmonthname'      => array( '1', 'LOCALMONTHNAME', 'HELYIHÓNAPNÉV' ),
-	'localmonthabbrev'    => array( '1', 'LOCALMONTHABBREV', 'HELYIHÓNAPRÖVIDÍTÉS' ),
-	'localday'            => array( '1', 'LOCALDAY', 'HELYINAP' ),
-	'localday2'           => array( '1', 'LOCALDAY2', 'HELYINAP2' ),
-	'localdayname'        => array( '1', 'LOCALDAYNAME', 'HELYINAPNEVE' ),
-	'localyear'           => array( '1', 'LOCALYEAR', 'HELYIÉV' ),
-	'localtime'           => array( '1', 'LOCALTIME', 'HELYIIDŐ' ),
-	'localhour'           => array( '1', 'LOCALHOUR', 'HELYIÓRA' ),
-	'numberofpages'       => array( '1', 'NUMBEROFPAGES', 'OLDALAKSZÁMA', 'LAPOKSZÁMA' ),
-	'numberofarticles'    => array( '1', 'NUMBEROFARTICLES', 'SZÓCIKKEKSZÁMA' ),
-	'numberoffiles'       => array( '1', 'NUMBEROFFILES', 'FÁJLOKSZÁMA', 'KÉPEKSZÁMA' ),
-	'numberofusers'       => array( '1', 'NUMBEROFUSERS', 'SZERKESZTŐKSZÁMA' ),
-	'numberofedits'       => array( '1', 'NUMBEROFEDITS', 'SZERKESZTÉSEKSZÁMA' ),
-	'pagename'            => array( '1', 'PAGENAME', 'OLDALNEVE' ),
-	'pagenamee'           => array( '1', 'PAGENAMEE', 'OLDALNEVEE' ),
-	'namespace'           => array( '1', 'NAMESPACE', 'NÉVTERE' ),
-	'namespacee'          => array( '1', 'NAMESPACEE', 'NÉVTEREE' ),
-	'talkspace'           => array( '1', 'TALKSPACE', 'VITATERE' ),
-	'talkspacee'          => array( '1', 'TALKSPACEE', 'VITATEREE' ),
-	'subjectspace'        => array( '1', 'SUBJECTSPACE', 'ARTICLESPACE', 'SZÓCIKKNÉVTERE' ),
-	'subjectspacee'       => array( '1', 'SUBJECTSPACEE', 'ARTICLESPACEE', 'SZÓCIKKNÉVTEREE' ),
-	'fullpagename'        => array( '1', 'FULLPAGENAME', 'LAPTELJESNEVE' ),
-	'fullpagenamee'       => array( '1', 'FULLPAGENAMEE', 'LAPTELJESNEVEE' ),
-	'subpagename'         => array( '1', 'SUBPAGENAME', 'ALLAPNEVE' ),
-	'subpagenamee'        => array( '1', 'SUBPAGENAMEE', 'ALLAPNEVEE' ),
-	'basepagename'        => array( '1', 'BASEPAGENAME', 'ALAPLAPNEVE' ),
-	'basepagenamee'       => array( '1', 'BASEPAGENAMEE', 'ALAPLAPNEVEE' ),
-	'talkpagename'        => array( '1', 'TALKPAGENAME', 'VITALAPNEVE' ),
-	'talkpagenamee'       => array( '1', 'TALKPAGENAMEE', 'VITALAPNEVEE' ),
-	'subjectpagename'     => array( '1', 'SUBJECTPAGENAME', 'ARTICLEPAGENAME', 'SZÓCIKKNEVE' ),
-	'subjectpagenamee'    => array( '1', 'SUBJECTPAGENAMEE', 'ARTICLEPAGENAMEE', 'SZÓCIKKNEVEE' ),
-	'msg'                 => array( '0', 'MSG:', 'ÜZENET:', 'ÜZ:' ),
-	'subst'               => array( '0', 'SUBST:', 'BEILLESZT:', 'BEMÁSOL:' ),
-	'img_thumbnail'       => array( '1', 'thumbnail', 'thumb', 'bélyegkép', 'bélyeg' ),
-	'img_manualthumb'     => array( '1', 'thumbnail=$1', 'thumb=$1', 'bélyegkép=$1', 'bélyeg=$1' ),
-	'img_right'           => array( '1', 'right', 'jobb', 'jobbra' ),
-	'img_left'            => array( '1', 'left', 'bal', 'balra' ),
-	'img_none'            => array( '1', 'none', 'semmi' ),
-	'img_width'           => array( '1', '$1px' ),
-	'img_center'          => array( '1', 'center', 'centre', 'közép', 'középre' ),
-	'img_framed'          => array( '1', 'framed', 'enframed', 'frame', 'keretezett' ),
-	'img_frameless'       => array( '1', 'frameless', 'keretnélküli' ),
-	'img_page'            => array( '1', 'page=$1', 'page $1', 'oldal=$1', 'oldal $1' ),
-	'img_upright'         => array( '1', 'upright', 'upright=$1', 'upright $1', 'fennjobbra', 'fennjobbra=$1', 'fennjobbra $1' ),
-	'img_border'          => array( '1', 'border', 'keret' ),
-	'img_baseline'        => array( '1', 'baseline', 'alapvonal' ),
-	'img_sub'             => array( '1', 'sub', 'ai', 'alsóindex' ),
-	'img_super'           => array( '1', 'super', 'sup', 'fi', 'felsőindex' ),
-	'img_top'             => array( '1', 'top', 'fenn', 'fent' ),
-	'img_text_top'        => array( '1', 'text-top', 'szöveg-fenn', 'szöveg-fent' ),
-	'img_middle'          => array( '1', 'middle', 'középen', 'középre' ),
-	'img_bottom'          => array( '1', 'bottom', 'lenn', 'lent' ),
-	'img_text_bottom'     => array( '1', 'text-bottom', 'szöveg-lenn', 'szöveg-lent' ),
-	'sitename'            => array( '1', 'SITENAME', 'OLDALNEVE', 'WIKINEVE' ),
-	'ns'                  => array( '0', 'NS:', 'NÉVTÉR:' ),
-	'localurl'            => array( '0', 'LOCALURL:', 'HELYIURL:' ),
-	'localurle'           => array( '0', 'LOCALURLE:', 'HELYIURLE:' ),
-	'server'              => array( '0', 'SERVER', 'SZERVER', 'KISZOLGÁLÓ' ),
-	'servername'          => array( '0', 'SERVERNAME', 'SZERVERNEVE', 'KISZOLGÁLÓNEVE' ),
-	'grammar'             => array( '0', 'GRAMMAR:', 'NYELVTAN:' ),
-	'currentweek'         => array( '1', 'CURRENTWEEK', 'JELENLEGIHÉT' ),
-	'currentdow'          => array( '1', 'CURRENTDOW', 'JELENLEGIHÉTNAPJA' ),
-	'localweek'           => array( '1', 'LOCALWEEK', 'HELYIHÉT' ),
-	'localdow'            => array( '1', 'LOCALDOW', 'HELYIHÉTNAPJA' ),
-	'revisionid'          => array( '1', 'REVISIONID', 'VÁLTOZATID' ),
-	'revisionday'         => array( '1', 'REVISIONDAY', 'VÁLTOZATNAP' ),
-	'revisionday2'        => array( '1', 'REVISIONDAY2', 'VÁLTOZATNAP2' ),
-	'revisionmonth'       => array( '1', 'REVISIONMONTH', 'VÁLTOZATHÓNAP' ),
-	'revisionyear'        => array( '1', 'REVISIONYEAR', 'VÁLTOZATÉV' ),
-	'revisiontimestamp'   => array( '1', 'REVISIONTIMESTAMP', 'VÁLTOZATIDŐBÉLYEG', 'VÁLTOZATIDŐ' ),
-	'plural'              => array( '0', 'PLURAL:', 'TÖBBESSZÁM:' ),
-	'fullurl'             => array( '0', 'FULLURL:', 'TELJESURL:' ),
-	'fullurle'            => array( '0', 'FULLURLE:', 'TELJESURLE:' ),
-	'lcfirst'             => array( '0', 'LCFIRST:', 'KISKEZDŐ:', 'KISKEZDŐBETŰ:' ),
-	'ucfirst'             => array( '0', 'UCFIRST:', 'NAGYKEZDŐ:', 'NAGYKEZDŐBETŰ:' ),
-	'lc'                  => array( '0', 'LC:', 'KISBETŰ:', 'KISBETŰK:', 'KB:', 'KISBETŰS:' ),
-	'uc'                  => array( '0', 'UC:', 'NAGYBETŰ:', 'NAGYBETŰK', 'NB:', 'NAGYBETŰS:' ),
-	'displaytitle'        => array( '1', 'DISPLAYTITLE', 'MEGJELENÍTENDŐCÍM', 'CÍM' ),
-	'newsectionlink'      => array( '1', '__NEWSECTIONLINK__', '__ÚJSZAKASZLINK__' ),
-	'currentversion'      => array( '1', 'CURRENTVERSION', 'JELENLEGIVÁLTOZAT' ),
-	'urlencode'           => array( '0', 'URLENCODE:', 'URLKÓDOLVA:' ),
-	'anchorencode'        => array( '0', 'ANCHORENCODE', 'HORGONYKÓDOLVA' ),
-	'currenttimestamp'    => array( '1', 'CURRENTTIMESTAMP', 'JELENLEGIIDŐBÉLYEG' ),
-	'localtimestamp'      => array( '1', 'LOCALTIMESTAMP', 'HELYIIDŐBÉLYEG' ),
-	'directionmark'       => array( '1', 'DIRECTIONMARK', 'DIRMARK', 'IRÁNYJELZŐ' ),
-	'language'            => array( '0', '#LANGUAGE:', '#NYELV:' ),
-	'contentlanguage'     => array( '1', 'CONTENTLANGUAGE', 'CONTENTLANG', 'TARTALOMNYELVE', 'TARTNYELVE' ),
-	'pagesinnamespace'    => array( '1', 'PAGESINNAMESPACE:', 'PAGESINNS:', 'OLDALAKNÉVTÉRBEN:', 'OLDALAKNBEN:' ),
-	'numberofadmins'      => array( '1', 'NUMBEROFADMINS', 'ADMINOKSZÁMA' ),
-	'formatnum'           => array( '0', 'FORMATNUM', 'FORMÁZOTTSZÁM', 'SZÁMFORMÁZÁS', 'SZÁMFORM' ),
-	'special'             => array( '0', 'special', 'speciális' ),
-	'defaultsort'         => array( '1', 'DEFAULTSORT:', 'DEFAULTSORTKEY:', 'DEFAULTCATEGORYSORT:', 'RENDEZÉS:', 'KULCS:' ),
-	'filepath'            => array( '0', 'FILEPATH:', 'ELÉRÉSIÚT:' ),
-	'hiddencat'           => array( '1', '__HIDDENCAT__', '__REJTETTKAT__', '__REJTETTKATEGÓRIA__' ),
+	'notoc'               => array( '0', '__NINCSTARTALOMJEGYZÉK__', '__NINCSTJ__', '__NOTOC__' ),
+	'nogallery'           => array( '0', '__NINCSGALÉRIA__', '__NOGALLERY__' ),
+	'forcetoc'            => array( '0', '__LEGYENTARTALOMJEGYZÉK__', '__LEGYENTJ__', '__FORCETOC__' ),
+	'toc'                 => array( '0', '__TARTALOMJEGYZÉK__', '__TJ__', '__TOC__' ),
+	'noeditsection'       => array( '0', '__NINCSSZERKESZTÉS__', '__NINCSSZERK__', '__NOEDITSECTION__' ),
+	'currentmonth'        => array( '1', 'JELENLEGIHÓNAP', 'CURRENTMONTH' ),
+	'currentmonthname'    => array( '1', 'JELENLEGIHÓNAPNEVE', 'CURRENTMONTHNAME' ),
+	'currentmonthabbrev'  => array( '1', 'JELENLEGIHÓNAPRÖVID', 'CURRENTMONTHABBREV' ),
+	'currentday'          => array( '1', 'MAINAP', 'CURRENTDAY' ),
+	'currentday2'         => array( '1', 'MAINAP2', 'CURRENTDAY2' ),
+	'currentdayname'      => array( '1', 'MAINAPNEVE', 'CURRENTDAYNAME' ),
+	'currentyear'         => array( '1', 'JELENLEGIÉV', 'CURRENTYEAR' ),
+	'currenttime'         => array( '1', 'JELENLEGIIDŐ', 'CURRENTTIME' ),
+	'currenthour'         => array( '1', 'JELENLEGIÓRA', 'CURRENTHOUR' ),
+	'localmonth'          => array( '1', 'HELYIHÓNAP', 'LOCALMONTH' ),
+	'localmonthname'      => array( '1', 'HELYIHÓNAPNÉV', 'LOCALMONTHNAME' ),
+	'localmonthabbrev'    => array( '1', 'HELYIHÓNAPRÖVIDÍTÉS', 'LOCALMONTHABBREV' ),
+	'localday'            => array( '1', 'HELYINAP', 'LOCALDAY' ),
+	'localday2'           => array( '1', 'HELYINAP2', 'LOCALDAY2' ),
+	'localdayname'        => array( '1', 'HELYINAPNEVE', 'LOCALDAYNAME' ),
+	'localyear'           => array( '1', 'HELYIÉV', 'LOCALYEAR' ),
+	'localtime'           => array( '1', 'HELYIIDŐ', 'LOCALTIME' ),
+	'localhour'           => array( '1', 'HELYIÓRA', 'LOCALHOUR' ),
+	'numberofpages'       => array( '1', 'OLDALAKSZÁMA', 'LAPOKSZÁMA', 'NUMBEROFPAGES' ),
+	'numberofarticles'    => array( '1', 'SZÓCIKKEKSZÁMA', 'NUMBEROFARTICLES' ),
+	'numberoffiles'       => array( '1', 'FÁJLOKSZÁMA', 'KÉPEKSZÁMA', 'NUMBEROFFILES' ),
+	'numberofusers'       => array( '1', 'SZERKESZTŐKSZÁMA', 'NUMBEROFUSERS' ),
+	'numberofedits'       => array( '1', 'SZERKESZTÉSEKSZÁMA', 'NUMBEROFEDITS' ),
+	'pagename'            => array( '1', 'OLDALNEVE', 'PAGENAME' ),
+	'pagenamee'           => array( '1', 'OLDALNEVEE', 'PAGENAMEE' ),
+	'namespace'           => array( '1', 'NÉVTERE', 'NAMESPACE' ),
+	'namespacee'          => array( '1', 'NÉVTEREE', 'NAMESPACEE' ),
+	'talkspace'           => array( '1', 'VITATERE', 'TALKSPACE' ),
+	'talkspacee'          => array( '1', 'VITATEREE', 'TALKSPACEE' ),
+	'subjectspace'        => array( '1', 'SZÓCIKKNÉVTERE', 'SUBJECTSPACE', 'ARTICLESPACE' ),
+	'subjectspacee'       => array( '1', 'SZÓCIKKNÉVTEREE', 'SUBJECTSPACEE', 'ARTICLESPACEE' ),
+	'fullpagename'        => array( '1', 'LAPTELJESNEVE', 'FULLPAGENAME' ),
+	'fullpagenamee'       => array( '1', 'LAPTELJESNEVEE', 'FULLPAGENAMEE' ),
+	'subpagename'         => array( '1', 'ALLAPNEVE', 'SUBPAGENAME' ),
+	'subpagenamee'        => array( '1', 'ALLAPNEVEE', 'SUBPAGENAMEE' ),
+	'basepagename'        => array( '1', 'ALAPLAPNEVE', 'BASEPAGENAME' ),
+	'basepagenamee'       => array( '1', 'ALAPLAPNEVEE', 'BASEPAGENAMEE' ),
+	'talkpagename'        => array( '1', 'VITALAPNEVE', 'TALKPAGENAME' ),
+	'talkpagenamee'       => array( '1', 'VITALAPNEVEE', 'TALKPAGENAMEE' ),
+	'subjectpagename'     => array( '1', 'SZÓCIKKNEVE', 'SUBJECTPAGENAME', 'ARTICLEPAGENAME' ),
+	'subjectpagenamee'    => array( '1', 'SZÓCIKKNEVEE', 'SUBJECTPAGENAMEE', 'ARTICLEPAGENAMEE' ),
+	'msg'                 => array( '0', 'ÜZENET:', 'ÜZ:', 'MSG:' ),
+	'subst'               => array( '0', 'BEILLESZT:', 'BEMÁSOL:', 'SUBST:' ),
+	'img_thumbnail'       => array( '1', 'bélyegkép', 'bélyeg', 'miniatűr', 'thumbnail', 'thumb' ),
+	'img_manualthumb'     => array( '1', 'bélyegkép=$1', 'bélyeg=$1', 'miniatűr=$1', 'thumbnail=$1', 'thumb=$1' ),
+	'img_right'           => array( '1', 'jobb', 'jobbra', 'right' ),
+	'img_left'            => array( '1', 'bal', 'balra', 'left' ),
+	'img_none'            => array( '1', 'semmi', 'none' ),
+	'img_center'          => array( '1', 'közép', 'középre', 'center', 'centre' ),
+	'img_framed'          => array( '1', 'keretezett', 'keretes', 'keretben', 'kerettel', 'framed', 'enframed', 'frame' ),
+	'img_frameless'       => array( '1', 'keretnélküli', 'frameless' ),
+	'img_page'            => array( '1', 'oldal=$1', 'oldal $1', 'page=$1', 'page $1' ),
+	'img_upright'         => array( '1', 'fennjobbra', 'fennjobbra=$1', 'fennjobbra $1', 'upright', 'upright=$1', 'upright $1' ),
+	'img_border'          => array( '1', 'keret', 'border' ),
+	'img_baseline'        => array( '1', 'alapvonal', 'baseline' ),
+	'img_sub'             => array( '1', 'ai', 'alsóindex', 'sub' ),
+	'img_super'           => array( '1', 'fi', 'felsőindex', 'super', 'sup' ),
+	'img_top'             => array( '1', 'fenn', 'fent', 'top' ),
+	'img_text_top'        => array( '1', 'szöveg-fenn', 'szöveg-fent', 'text-top' ),
+	'img_middle'          => array( '1', 'középen', 'középre', 'middle' ),
+	'img_bottom'          => array( '1', 'lenn', 'lent', 'bottom' ),
+	'img_text_bottom'     => array( '1', 'szöveg-lenn', 'szöveg-lent', 'text-bottom' ),
+	'sitename'            => array( '1', 'OLDALNEVE', 'WIKINEVE', 'SITENAME' ),
+	'ns'                  => array( '0', 'NÉVTÉR:', 'NS:' ),
+	'localurl'            => array( '0', 'HELYIURL:', 'LOCALURL:' ),
+	'localurle'           => array( '0', 'HELYIURLE:', 'LOCALURLE:' ),
+	'server'              => array( '0', 'SZERVER', 'KISZOLGÁLÓ', 'SERVER' ),
+	'servername'          => array( '0', 'SZERVERNEVE', 'KISZOLGÁLÓNEVE', 'SERVERNAME' ),
+	'grammar'             => array( '0', 'NYELVTAN:', 'GRAMMAR:' ),
+	'currentweek'         => array( '1', 'JELENLEGIHÉT', 'CURRENTWEEK' ),
+	'currentdow'          => array( '1', 'JELENLEGIHÉTNAPJA', 'CURRENTDOW' ),
+	'localweek'           => array( '1', 'HELYIHÉT', 'LOCALWEEK' ),
+	'localdow'            => array( '1', 'HELYIHÉTNAPJA', 'LOCALDOW' ),
+	'revisionid'          => array( '1', 'VÁLTOZATID', 'REVISIONID' ),
+	'revisionday'         => array( '1', 'VÁLTOZATNAP', 'REVISIONDAY' ),
+	'revisionday2'        => array( '1', 'VÁLTOZATNAP2', 'REVISIONDAY2' ),
+	'revisionmonth'       => array( '1', 'VÁLTOZATHÓNAP', 'REVISIONMONTH' ),
+	'revisionyear'        => array( '1', 'VÁLTOZATÉV', 'REVISIONYEAR' ),
+	'revisiontimestamp'   => array( '1', 'VÁLTOZATIDŐBÉLYEG', 'VÁLTOZATIDŐ', 'REVISIONTIMESTAMP' ),
+	'plural'              => array( '0', 'TÖBBESSZÁM:', 'PLURAL:' ),
+	'fullurl'             => array( '0', 'TELJESURL:', 'FULLURL:' ),
+	'fullurle'            => array( '0', 'TELJESURLE:', 'FULLURLE:' ),
+	'lcfirst'             => array( '0', 'KISKEZDŐ:', 'KISKEZDŐBETŰ:', 'LCFIRST:' ),
+	'ucfirst'             => array( '0', 'NAGYKEZDŐ:', 'NAGYKEZDŐBETŰ:', 'UCFIRST:' ),
+	'lc'                  => array( '0', 'KISBETŰ:', 'KISBETŰK:', 'KB:', 'KISBETŰS:', 'LC:' ),
+	'uc'                  => array( '0', 'NAGYBETŰ:', 'NAGYBETŰK', 'NB:', 'NAGYBETŰS:', 'UC:' ),
+	'displaytitle'        => array( '1', 'MEGJELENÍTENDŐCÍM', 'CÍM', 'DISPLAYTITLE' ),
+	'newsectionlink'      => array( '1', '__ÚJSZAKASZLINK__', '__NEWSECTIONLINK__' ),
+	'currentversion'      => array( '1', 'JELENLEGIVÁLTOZAT', 'CURRENTVERSION' ),
+	'urlencode'           => array( '0', 'URLKÓDOLVA:', 'URLENCODE:' ),
+	'anchorencode'        => array( '0', 'HORGONYKÓDOLVA', 'ANCHORENCODE' ),
+	'currenttimestamp'    => array( '1', 'JELENLEGIIDŐBÉLYEG', 'CURRENTTIMESTAMP' ),
+	'localtimestamp'      => array( '1', 'HELYIIDŐBÉLYEG', 'LOCALTIMESTAMP' ),
+	'directionmark'       => array( '1', 'IRÁNYJELZŐ', 'DIRECTIONMARK', 'DIRMARK' ),
+	'language'            => array( '0', '#NYELV:', '#LANGUAGE:' ),
+	'contentlanguage'     => array( '1', 'TARTALOMNYELVE', 'TARTNYELVE', 'CONTENTLANGUAGE', 'CONTENTLANG' ),
+	'pagesinnamespace'    => array( '1', 'OLDALAKNÉVTÉRBEN:', 'OLDALAKNBEN:', 'PAGESINNAMESPACE:', 'PAGESINNS:' ),
+	'numberofadmins'      => array( '1', 'ADMINOKSZÁMA', 'NUMBEROFADMINS' ),
+	'formatnum'           => array( '0', 'FORMÁZOTTSZÁM', 'SZÁMFORMÁZÁS', 'SZÁMFORM', 'FORMATNUM' ),
+	'special'             => array( '0', 'speciális', 'special' ),
+	'defaultsort'         => array( '1', 'RENDEZÉS:', 'KULCS:', 'DEFAULTSORT:', 'DEFAULTSORTKEY:', 'DEFAULTCATEGORYSORT:' ),
+	'filepath'            => array( '0', 'ELÉRÉSIÚT:', 'FILEPATH:' ),
+	'hiddencat'           => array( '1', '__REJTETTKAT__', '__REJTETTKATEGÓRIA__', '__HIDDENCAT__' ),
 );
 
 $linkTrail = '/^([a-záéíóúöüőűÁÉÍÓÚÖÜŐŰ]+)(.*)$/sDu';
@@ -452,7 +450,7 @@
 'unprotectthispage' => 'Lapvédelem megszüntetése',
 'newpage'           => 'Új lap',
 'talkpage'          => 'Lap megbeszélése',
-'talkpagelinktext'  => 'Vita',
+'talkpagelinktext'  => 'vita',
 'specialpage'       => 'Speciális lap',
 'personaltools'     => 'Személyes eszközök',
 'postcomment'       => 'Megjegyzés beküldése',
@@ -556,7 +554,7 @@
 'nosuchspecialpage' => 'Nem létezik ilyen speciális lap',
 'nospecialpagetext' => "<big>'''Érvénytelen speciális lapot akartál megtekinteni.'''</big>
 
-Az érvényes speciális lapok listáját a [[Special:Specialpages|Speciális lapok]] címen találod.",
+Az érvényes speciális lapok listáját a [[Special:SpecialPages|Speciális lapok]] címen találod.",
 
 # General errors
 'error'                => 'Hiba',
@@ -582,12 +580,12 @@
 'readonlytext'         => 'A wiki adatbázisa ideiglenesen le van zárva (valószínűleg adatbázis-karbantartás miatt). A lezárás időtartama alatt a lapok nem szerkeszthetők, és új szócikkek sem hozhatóak létre, az oldalak azonban továbbra is böngészhetőek.
 
 Az adminisztrátor, aki lezárta az adatbázist, az alábbi magyarázatot adta: $1',
-'missing-article'      => 'Az adatbázis nem találta annak a lapnak a szövegét, amelyet "$1" néven kellett volna találnia $2.
+'missing-article'      => 'Az adatbázisban nem található meg a(z) „$1” című lap szövege $2.
 
-Ezt általában egy elavult diff vagy laptörténeti link követése okozza egy lapra, amit töröltek.
+Ennek az oka általában az, hogy egy olyan lapra vonatkozó linket követtél, amit már töröltek.
 
-Egyéb esetben lehet, hogy egy hibát talált a szoftverben.
-Jelezd, kérlek egy adminisztrátornak, az URL-t említve.',
+Ha ez nem így van, lehet, hogy hibát találtál a szoftverben.
+Jelezd ezt egy [[Special:ListUsers/sysop|adminiszttrátornak]] az URL megadásával.',
 'missingarticle-rev'   => '(változat azonosítója: $1)',
 'missingarticle-diff'  => '(eltérés: $1, $2)',
 'readonly_lag'         => 'Az adatbázis automatikusan zárolásra került, amíg a mellékkiszolgálók utolérik a főkiszolgálót.',
@@ -635,12 +633,13 @@
 
 # Login and logout pages
 'logouttitle'                => 'Kijelentkezés',
-'logouttext'                 => '<strong>Kijelentkeztél.</strong>
+'logouttext'                 => '<strong>Sikeresen kijelentkeztél.</strong>
 
-Folytathatod névtelenül  a(z) {{SITENAME}} használatát, vagy ismét bejelentkezhetsz ugyanezzel, vagy egy másik szerkesztői névvel. Néhány oldalon lehet, hogy továbbra is azt látod, hogy be vagy jelentkezve, mindaddig, amíg nem üríted a böngésződ gyorsítótárát.',
+Folytathatod névtelenül  a(z) {{SITENAME}} használatát, vagy [[Special:UserLogin|ismét bejelentkezhetsz]] ugyanezzen, vagy egy másik névvel.
+Lehetséges, hogy néhány oldalon továbbra is azt látod, be vagy jelentkezve, mindaddig, amíg nem üríted a böngésződ gyorsítótárát.',
 'welcomecreation'            => '== Köszöntünk, $1! ==
 A felhasználói fiókodat létrehoztuk.
-Ne felejtsd el átnézni a személyes beállításaidat.',
+Ne felejtsd el átnézni a [[Special:Preferences|személyes beállításaidat]].',
 'loginpagetitle'             => 'Bejelentkezés',
 'yourname'                   => 'Felhasználói neved:',
 'yourpassword'               => 'Jelszavad:',
@@ -789,29 +788,28 @@
 Kapcsolatba léphetsz $1 szerkesztőnkkel, vagy egy másik [[{{MediaWiki:Grouppage-sysop}}|adminisztrátorral]], és megbeszélheted vele a blokkolást.
 Az 'E-mail küldése ennek a szerkesztőnek' funkciót nem használhatod, ha a megadott e-mail cím a
 [[Special:Preferences|fiókbeállításaidban]] nem érvényes, és nem blokkolták annak a használatát.
-Jelenlegi IP-címed: $3, a blokkolás azonosítószáma: #$5. Kérjük, hogy érdeklődés esetén lehetőleg mindkettőt add meg.",
+Jelenlegi IP-címed: $3, a blokkolás azonosítószáma: #$5.
+Kérjük, hogy érdeklődés esetén mindkettőt add meg.",
 'autoblockedtext'                  => "Az IP-címről automatikusan blokkolva lett, mert korábban egy olyan szerkesztő használta, akit $1 blokkolt, az alábbi indoklással:
 
 :''$2''
 
 *A blokk kezdete: '''$8'''
 *A blokk lejárata: '''$6'''
+*Blokkolt szerkesztő: '''$7'''
 
 Kapcsolatba léphetsz $1 szerkesztőnkkel, vagy egy másik [[{{MediaWiki:Grouppage-sysop}}|adminisztrátorral]], és megbeszélheted vele a blokkolást.
 
 Az 'E-mail küldése ennek a szerkesztőnek' funkciót nem használhatod, ha a megadott e-mail cím a
 [[Special:Preferences|fiókbeállításaidban]] nem érvényes, és nem blokkolták annak a használatát.
 
-A blokkolás azonosítószáma: $5. Kérjük, hogy érdeklődés esetén ezt add meg.",
+A jelenlegi IP-címed $3, a blokkolás azonosítószáma: $5.
+Kérjük, hogy érdeklődés esetén mindkettőt add meg.",
 'blockednoreason'                  => 'nem lett ok megadva',
 'blockedoriginalsource'            => "'''$1''' forrása alább látható:",
 'blockededitsource'                => "'''$1''' lapon '''általad végrehajtott szerkesztések''' szövege:",
-'whitelistedittitle'               => 'A szerkesztéshez be kell jelentkezned',
+'whitelistedittitle'               => 'A szerkesztéshez [[Special:UserLogin|be kell jelentkezned]]',
 'whitelistedittext'                => 'A szócikkek szerkesztéséhez $1.',
-'whitelistreadtitle'               => 'Az olvasáshoz be kell lépned',
-'whitelistreadtext'                => 'A lapok olvasásához [[Special:Userlogin|be kell lépned]].',
-'whitelistacctitle'                => 'Nem készíthetsz új felhasználói fiókot',
-'whitelistacctext'                 => 'Felhasználói fiókok létrehozásához [[Special:Userlogin|be kell jelentkezned]] a szükséges jogosultságokkal.',
 'confirmedittitle'                 => 'Szerkesztéshez az e-mail cím megerősítése szükséges',
 'confirmedittext'                  => 'A lapok szerkesztése előtt meg kell erősítened az e-mail címedet. Kérjük, hogy a [[Special:Preferences|szerkesztői beállításaidban]] írd be, majd erősítsd meg az e-mail címedet.',
 'nosuchsectiontitle'               => 'Nincs ilyen szakasz',
@@ -828,7 +826,10 @@
 A [[{{MediaWiki:Helppage}}|súgó]] lapon további információkat találsz, melyek segíthetnek eligazodni.
 
 Ha tévedésből jöttél ide, csak nyomd meg a böngésző '''Vissza/Back''' gombját.",
-'anontalkpagetext'                 => "----''Ez egy olyan anonim szerkesztő vitalapja, aki még nem regisztrált, vagy csak nem jelentkezett be. Ezért az IP-címét (<tt>{{PAGENAME}}</tt>) használjuk az azonosítására. Ugyanazon az IP-címen egy sor szerkesztő osztozhat az idők folyamán. Ha úgy látod, hogy az üzenetek, amiket ide kapsz, nem neked szólnak, regisztrálj vagy ha már regisztráltál, lépj be, hogy ne keverjenek össze másokkal.''",
+'anontalkpagetext'                 => "----''Ez egy olyan anonim szerkesztő vitalapja, aki még nem regisztrált, vagy csak nem jelentkezett be.
+Ezért az IP-címét használjuk az azonosítására.
+Ugyanazon az IP-címen egy sor szerkesztő osztozhat az idők folyamán.
+Ha úgy látod, hogy az üzenetek, amiket ide kapsz, nem neked szólnak, [[Special:UserLogin/signup|regisztrálj]] vagy ha már regisztráltál, [[Special:UserLogin|jelentkezz be]], hogy ne keverjenek össze másokkal.''",
 'noarticletext'                    => 'Ez a lap jelenleg nem tartalmaz szöveget. [[Special:Search/{{PAGENAME}}|Rákereshetsz erre a címszóra]], vagy [{{fullurl:{{FULLPAGENAME}}|action=edit}} szerkesztheted a lapot].',
 'userpage-userdoesnotexist'        => 'Nincs „$1” nevű regisztrált szerkesztő. Nézd meg, hogy valóban ezt a lapot szeretnéd létrehozni vagy szerkeszteni.',
 'clearyourcache'                   => "'''Megjegyzés: mentés után frissítened kell a böngésződ gyorsítótárát, hogy lásd a változásokat.''' '''Mozilla''' / '''Firefox''' / '''Safari:''' tartsd lenyomva a Shift gombot és kattints a ''Reload'' / ''Frissítés'' gombra az eszköztáron, vagy használd a ''Ctrl–F5'' billentyűkombinációt (Apple Mac-en ''Cmd–Shift–R''); '''Konqueror:''' egyszerűen csak kattints a ''Reload'' / ''Frissítés'' gombra vagy nyomj ''F5''-öt; '''Opera:''' ürítsd ki a gyorsítótárat az ''Eszközök→Személyes adatok törlése'' / ''Tools→Preferences'' menüben; '''Internet Explorer:''' tartsd nyomva a ''Ctrl''-t, és kattints a ''Reload / Frissítés'' gombra, vagy nyomj ''Ctrl–F5''-öt.",
@@ -840,12 +841,14 @@
 'note'                             => '<strong>Megjegyzés:</strong>',
 'previewnote'                      => '<strong>Ne feledd, hogy ez csak előnézet, a munkád még nincs elmentve!</strong>',
 'previewconflict'                  => 'Ez az előnézet a felső szerkesztőablakban levő szöveg mentés utáni megfelelőjét mutatja.',
-'session_fail_preview'             => '<strong>Sajnos nem tudtuk feldolgozni a szerkesztésedet, mert elveszett a session-adat. Kérjük próbálkozz újra! Amennyiben továbbra sem sikerül, próbálj meg kijelentkezni, majd ismét bejelentkezni!</strong>',
-'session_fail_preview_html'        => "<strong>Nem tudtuk feldolgozni a szerkesztésedet az elveszett munkamenetadatok miatt.</strong>
+'session_fail_preview'             => '<strong>Az elveszett munkamenetadatok miatt sajnos nem tudtuk feldolgozni a szerkesztésedet.
+Kérjük próbálkozz újra!
+Amennyiben továbbra sem sikerül, próbálj meg [[Special:UserLogout|kijelentkezni]], majd ismét bejelentkezni!</strong>',
+'session_fail_preview_html'        => "<strong>Az elveszett munkamenetadatok miatt sajnos nem tudtuk feldolgozni a szerkesztésedet.</strong>
 
 ''Mivel a wikiben engedélyezett a nyers HTML-kód használata, az előnézet el van rejtve a JavaScript-alapú támadások megakadályozása céljából.''
 
-<strong>Ha ez egy normális szerkesztési kísérlet, akkor próbáld újra. Ha még mindig problémáid adódnak, jelentkezz ki, majd jelentkezz vissza a wikibe.</strong>",
+<strong>Ha ez egy normális szerkesztési kísérlet, akkor próbálkozz újra. Amennyiben továbbra sem sikerül, próbálj meg [[Special:UserLogout|kijelentkezni]], majd ismét bejelentkezni!</strong>",
 'token_suffix_mismatch'            => '<strong>A szerkesztésedet elutasítottuk, mert a kliensprogramod megváltoztatta a központozó karaktereket
 a szerkesztési tokenben. A szerkesztés azért lett visszautasítva, hogy megelőzzük a lap szövegének sérülését.
 Ez a probléma akkor fordulhat elő, ha hibás, web-alapú proxyszolgáltatást használsz.</strong>',
@@ -889,7 +892,7 @@
 'edittools'                        => '<!-- Ez a szöveg a szerkesztés és a feltöltés űrlap alatt lesz látható. -->',
 'nocreatetitle'                    => 'Az oldallétrehozás korlátozott',
 'nocreatetext'                     => 'Ezen a webhelyen korlátozták az új oldalak készítését.
-Visszamehetsz és szerkeszthetsz egy létező lapot, valamint [[Special:Userlogin|bejelentkezhetsz vagy készíthetsz egy felhasználói fiókot]].',
+Visszamehetsz és szerkeszthetsz egy létező lapot, valamint [[Special:UserLogin|bejelentkezhetsz vagy készíthetsz egy felhasználói fiókot]].',
 'nocreate-loggedin'                => 'Nem hozhatsz létre új lapokat a(z) {{SITENAME}} wikiben.',
 'permissionserrors'                => 'Engedélyezési hiba',
 'permissionserrorstext'            => 'A művelet elvégzése nem engedélyezett a számodra, a következő {{PLURAL:$1|ok|okok}} miatt:',
@@ -914,7 +917,7 @@
 'undo-success' => 'A szerkesztés visszavonható. Kérlek ellenőrizd alább a változásokat, hogy valóban ezt szeretnéd-e tenni, majd kattints a lap mentése gombra a visszavonás véglegesítéséhez.',
 'undo-failure' => 'A szerkesztést nem lehet automatikusan visszavonni vele ütköző későbbi szerkesztések miatt.',
 'undo-norev'   => 'A szerkesztés nem állítható vissza, mert nem létezik vagy törölve lett.',
-'undo-summary' => 'Visszavontam [[Special:Contributions/$2|$2]] ([[User talk:$2|vita]]) szerkesztését (oldid: $1)',
+'undo-summary' => 'Visszavontam [[Special:Contributions/$2|$2]] ([[User talk:$2|vita]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]]) szerkesztését (oldid: $1)',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Felhasználói fiók létrehozása sikertelen',
@@ -1006,7 +1009,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Adatvédelmibiztos-napló',
-'suppressionlogtext' => 'Lenn látható az adminisztrátorok elől legutóbb elrejtett törlések és blokkok listája. Lásd a [[Special:Ipblocklist|blokkolt IP-címek listája]] lapot a jelenleg érvényben lévő kitiltásokhoz és blokkokhoz.',
+'suppressionlogtext' => 'Lenn látható az adminisztrátorok elől legutóbb elrejtett törlések és blokkok listája. Lásd a [[Special:IPBlockList|blokkolt IP-címek listája]] lapot a jelenleg érvényben lévő kitiltásokhoz és blokkokhoz.',
 
 # History merging
 'mergehistory'                     => 'Laptörténetek egyesítése',
@@ -1046,7 +1049,7 @@
 # Search results
 'searchresults'             => 'A keresés eredménye',
 'searchresulttext'          => 'A keresésről a [[{{MediaWiki:Helppage}}|{{int:help}}]] lapon találhatsz további információkat.',
-'searchsubtitle'            => 'Keresett kifejezés: „[[:$1]]”',
+'searchsubtitle'            => 'A keresett kifejezés: „[[:$1]]” ([[Special:Prefixindex/$1|minden, „$1” előtaggal kezdődő lap]] | [[Special:WhatLinksHere/$1|a(z) „$1” lapra hivatkozó lapok]])',
 'searchsubtitleinvalid'     => "A keresett kulcsszó: „'''$1'''”",
 'noexactmatch'              => "Nincs '''$1''' nevű lap. Készíthetsz egy [[:$1|új oldalt]] ezen a néven.",
 'noexactmatch-nocreate'     => "'''Nem található „$1” nevű lap.'''",
@@ -1092,7 +1095,7 @@
 'mypreferences'            => 'beállításaim',
 'prefs-edits'              => 'Szerkesztéseid száma:',
 'prefsnologin'             => 'Nem jelentkeztél be',
-'prefsnologintext'         => 'Ahhoz, hogy a beállításaidat rögzíthesd, [[Special:Userlogin|be kell jelentkezned]].',
+'prefsnologintext'         => 'Ahhoz, hogy a beállításaidat rögzíthesd, [[Special:UserLogin|be kell jelentkezned]].',
 'prefsreset'               => 'A beállítások visszaállításra kerültek a tárolóból.',
 'qbsettings'               => 'Gyorsmenü',
 'qbsettings-none'          => 'Nincs',
@@ -1165,7 +1168,7 @@
 'userrights-reason'           => 'A változtatás indoka:',
 'userrights-no-interwiki'     => 'Nincs jogod a szerkesztők jogainak módosításához más wikiken.',
 'userrights-nodatabase'       => '$1 adatbázis nem létezik vagy nem helyi.',
-'userrights-nologin'          => '[[Special:Userlogin|Be kell jelentkezned]] egy adminisztrátori fiókkal, hogy szerkesztői jogokat adhass.',
+'userrights-nologin'          => '[[Special:UserLogin|Be kell jelentkezned]] egy adminisztrátori fiókkal, hogy szerkesztői jogokat adhass.',
 'userrights-notallowed'       => 'A fiókoddal nincs jogod felhasználói jogokat osztani.',
 'userrights-changeable-col'   => 'Megváltoztatható csoportok',
 'userrights-unchangeable-col' => 'Nem megváltoztatható csoportok',
@@ -1202,7 +1205,7 @@
 'right-createaccount'        => 'új felhasználói fiók készítése',
 'right-minoredit'            => 'szerkesztések apróként jelölésének lehetősége',
 'right-move'                 => 'lapok átnevezése',
-'right-move-subpages'        => 'Lapok átnevezése az allapjukkal együtt',
+'right-move-subpages'        => 'lapok átnevezése az allapjukkal együtt',
 'right-suppressredirect'     => 'nem készít átirányítást a régi néven lapok átnevezésekor',
 'right-upload'               => 'fájlok feltöltése',
 'right-reupload'             => 'létező fájlok felülírása',
@@ -1234,7 +1237,7 @@
 'right-editusercssjs'        => 'más felhasználók CSS és JS fájljainak szerkesztése',
 'right-rollback'             => 'a lap utolsó szerkesztésének gyors visszaállítása',
 'right-markbotedits'         => 'visszaállított szerkesztések botként való jelölése',
-'right-noratelimit'          => 'Az arány határok nem érintik.',
+'right-noratelimit'          => 'sebességkorlát figyelmen kívül hagyása',
 'right-import'               => 'lapok importálása más wikikből',
 'right-importupload'         => 'lapok importálása fájl feltöltésével',
 'right-patrol'               => 'szerkesztések ellenőrzöttként való jelölése',
@@ -1295,12 +1298,12 @@
 'reupload'                    => 'Fájl feltöltése újra',
 'reuploaddesc'                => 'Visszatérés a feltöltési űrlaphoz.',
 'uploadnologin'               => 'Nem jelentkeztél be',
-'uploadnologintext'           => 'Csak regisztrált felhasználók tölthetnek fel fájlokat. [[Special:Userlogin|Jelentkezz be]] vagy regisztrálj!',
+'uploadnologintext'           => 'Csak regisztrált felhasználók tölthetnek fel fájlokat. [[Special:UserLogin|Jelentkezz be]] vagy regisztrálj!',
 'upload_directory_missing'    => 'A feltöltési könyvtár ($1) hiányzik vagy nem tudja létrehozni a kiszolgáló.',
 'upload_directory_read_only'  => 'A feltöltési könyvtár ($1) nem írható a szerver által.',
 'uploaderror'                 => 'Feltöltési hiba',
 'uploadtext'                  => "Az alábbi űrlap használatával tölthetsz fel fájlokat.
-A korábban feltöltött képek megtekintéséhez vagy a köztük való kereséshez menj a [[Special:Imagelist|feltöltött fájlok listájához]], a feltöltések és a törlések a [[Special:Log/upload|feltöltési naplóban]] is le vannak jegyezve.
+A korábban feltöltött képek megtekintéséhez vagy a köztük való kereséshez menj a [[Special:ImageList|feltöltött fájlok listájához]], a(z újra)feltöltések a [[Special:Log/upload|feltöltési naplóban]], a törlések a [[Special:Log/upload|törlési naplóban]] vannak jegyezve.
 
 Képet a következő módon illeszhetsz be egy oldalra: '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Kép.jpg]]</nowiki>''',
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Kép.png|alternatív szöveg]]</nowiki>''' vagy a közvetlen hivatkozáshoz használd a
@@ -1310,7 +1313,8 @@
 'upload-prohibited'           => 'Tiltott fájltípusok: $1.',
 'uploadlog'                   => 'feltöltési napló',
 'uploadlogpage'               => 'Feltöltési_napló',
-'uploadlogpagetext'           => 'Lentebb látható a legutóbbi felküldések listája.',
+'uploadlogpagetext'           => 'Lentebb látható a legutóbbi felküldések listája.
+Lásd még az [[Special:NewImages|új fáljlok galériáját]]',
 'filename'                    => 'Fájlnév',
 'filedesc'                    => 'Összegzés',
 'fileuploadsummary'           => 'Összefoglaló:',
@@ -1324,9 +1328,9 @@
 'badfilename'                 => 'A kép új neve „$1”.',
 'filetype-badmime'            => '„$1” MIME-típusú fájlokat nem lehet feltölteni.',
 'filetype-unwanted-type'      => "A(z) '''„.$1”''' nem javasolt fájltípus.
-Az ajánlott típusok: $2.",
+Az ajánlott {{PLURAL:$3|típus|típusok}}: $2.",
 'filetype-banned-type'        => "A(z) '''„.$1”''' nem megengedett fájltípus. 
-A megengedett típusok: $2.",
+Az engedélyezett {{PLURAL:$3|típus|típusok}}: $2.",
 'filetype-missing'            => 'A fájlnak nincs kiterjesztése (pl. „.jpg”).',
 'large-file'                  => 'Javasoljuk, hogy a fájl ne legyen nagyobb, mint $1;
 a fájl, amit fel akarsz tölteni $2.',
@@ -1403,7 +1407,7 @@
 'upload_source_url'  => ' (egy érvényes, nyilvánosan elérhető URL)',
 'upload_source_file' => ' (egy fájl a számítógépeden)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ezen a speciális lapon látható az összes feltöltött fájl.
 A legutóbb feltöltött fájlok vannak a lista elején.
 Az oszlopok címeire kattintva változtathatod meg a rendezést.',
@@ -1429,9 +1433,9 @@
 'filehist-filesize'              => 'Fájlméret',
 'filehist-comment'               => 'Megjegyzés',
 'imagelinks'                     => 'Képhivatkozások',
-'linkstoimage'                   => 'Az alábbi lapok hivatkoznak erre a képre:',
+'linkstoimage'                   => 'Az alábbi {{PLURAL:$1|lap hivatkozik|lapok hivatkoznak}} erre a fájlra:',
 'nolinkstoimage'                 => 'Erre a képre nem hivatkozik lap.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|További hivatkozások]] megtekintése',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|További hivatkozások]] megtekintése',
 'redirectstofile'                => 'A következő {{PLURAL:$1|fájl|$1 fájl}} van átirányítva erre a névre:',
 'duplicatesoffile'               => 'A következő {{PLURAL:$1|fájl|$1 fájl}} ennek a fájlnak a duplikátuma:',
 'sharedupload'                   => 'Ez a fájlt egy megosztott feltöltés, és más projektek használhatják.',
@@ -1525,8 +1529,10 @@
 A megfelelő szócikkre kellene mutatniuk inkább.<br />
 Egy oldal egyértelműsítő lapnak számít, ha tartalmazza a [[MediaWiki:Disambiguationspage]] oldalról belinkelt sablonok valamelyikét.",
 
-'doubleredirects'     => 'Dupla átirányítások',
-'doubleredirectstext' => '<strong>Figyelem:</strong> Ez a lista nem feltétlenül pontos. Ennek általában az oka az, hogy a #REDIRECT alatt további szöveg található.<br /> Minden sor tartalmazza az első és a második átirányítást, valamint a második átirányítás cikkének első sorát, ami általában a „valódi” célt tartalmazza, amire az elsőnek mutatnia kellene.',
+'doubleredirects'            => 'Dupla átirányítások',
+'doubleredirectstext'        => '<strong>Figyelem:</strong> Ez a lista nem feltétlenül pontos. Ennek általában az oka az, hogy a #REDIRECT alatt további szöveg található.<br /> Minden sor tartalmazza az első és a második átirányítást, valamint a második átirányítás cikkének első sorát, ami általában a „valódi” célt tartalmazza, amire az elsőnek mutatnia kellene.',
+'double-redirect-fixed-move' => '[[$1]] átnevezve, a továbbiakban átirányításként működik a(z) [[$2]] lapra',
+'double-redirect-fixer'      => 'Átirányításjavító',
 
 'brokenredirects'        => 'Nem létező lapra mutató átirányítások',
 'brokenredirectstext'    => 'Az alábbi átirányítások nem létező lapokra mutatnak.',
@@ -1615,7 +1621,7 @@
 'logempty'             => 'Nincs illeszkedő naplóbejegyzés.',
 'log-title-wildcard'   => 'Így kezdődő címek keresése',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Az összes lap listája',
 'alphaindexline'    => '$1 – $2',
 'nextpage'          => 'Következő lap ($1)',
@@ -1638,15 +1644,15 @@
 'special-categories-sort-count' => 'rendezés elemszám szerint',
 'special-categories-sort-abc'   => 'rendezés ABC szerint',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Szerkesztők listázása a következő névtől kezdve:',
 'listusers-submit'   => 'Megjelenítés',
 'listusers-noresult' => 'Nem található szerkesztő.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Szerkesztői csoportok jogai',
 'listgrouprights-summary'  => 'Lenn láthatóak a wikiben létező szerkesztői csoportok, valamint az azokhoz tartozó jogok.
-Az egyes csoportokról [[{{MediaWiki:Listgrouprights-helppage}}|itt]] található további információ.',
+Az egyes csoportokról további információt [[{{MediaWiki:Listgrouprights-helppage}}|itt]] találhatsz.',
 'listgrouprights-group'    => 'Csoport',
 'listgrouprights-rights'   => 'Jogok',
 'listgrouprights-helppage' => 'Help:Csoportok jogai',
@@ -1654,10 +1660,10 @@
 
 # E-mail user
 'mailnologin'     => 'Nincs feladó',
-'mailnologintext' => 'Ahhoz hogy másoknak e-mailt küldhess, [[Special:Userlogin|be kell jelentkezned]] és meg kell adnod egy érvényes email címet a [[Special:Preferences|beállításaidban]].',
+'mailnologintext' => 'Ahhoz hogy másoknak e-mailt küldhess, [[Special:UserLogin|be kell jelentkezned]] és meg kell adnod egy érvényes e-mail címet a [[Special:Preferences|beállításaidban]].',
 'emailuser'       => 'E-mail küldése ezen szerkesztőnek',
 'emailpage'       => 'E-mail küldése',
-'emailpagetext'   => 'Ha ez a felhasználó érvényes e-mail-címet adott meg, akkor ezen űrlap kitöltésével e-mailt tudsz neki küldeni. Feladóként a beállításaid között megadott e-mail-címed fog szerepelni, hogy a címzett válaszolni tudjon.',
+'emailpagetext'   => 'Ha ez a szerkesztő érvényes e-mail-címet adott meg a beállításainál, akkor ezen űrlap kitöltésével üzenetet tudsz neki küldeni. Feladóként a beállításaid között megadott e-mail-címed fog szerepelni, így a címzett tud majd válaszolni.',
 'usermailererror' => 'A postázó objektum által visszaadott hiba:',
 'defemailsubject' => '{{SITENAME}} e-mail',
 'noemailtitle'    => 'Nincs e-mail cím',
@@ -1681,10 +1687,10 @@
 'nowatchlist'          => 'Nincs lap a figyelőlistádon.',
 'watchlistanontext'    => 'A figyelőlistád megtekintéséhez és szerkesztéséhez $1.',
 'watchnologin'         => 'Nem vagy bejelentkezve',
-'watchnologintext'     => 'Ahhoz, hogy figyelőlistád lehessen, [[Special:Userlogin|be kell lépned]].',
+'watchnologintext'     => 'Ahhoz, hogy figyelőlistád lehessen, [[Special:UserLogin|be kell lépned]].',
 'addedwatch'           => 'Figyelőlistához hozzáfűzve',
 'addedwatchtext'       => "A(z) „[[:$1]]” lapot hozzáadtam a [[Special:Watchlist|figyelőlistádhoz]].
-Ezután minden, a lapon vagy annak vitalapján történő változást ott fogsz látni, és a lap '''vastagon''' fog szerepelni a [[Special:Recentchanges|friss változtatások]] lapon, hogy könnyen észrevehető legyen.",
+Ezután minden, a lapon vagy annak vitalapján történő változást ott fogsz látni, és a lap '''vastagon''' fog szerepelni a [[Special:RecentChanges|friss változtatások]] lapon, hogy könnyen észrevehető legyen.",
 'removedwatch'         => 'Figyelőlistáról eltávolítva',
 'removedwatchtext'     => 'A „<nowiki>$1</nowiki>” lapot eltávolítottam a figyelőlistáról.',
 'watch'                => 'Lap figyelése',
@@ -1695,7 +1701,7 @@
 'notvisiblerev'        => 'A változat törölve lett',
 'watchnochange'        => 'Egyik figyelt lap sem változott a megadott időintervallumon belül.',
 'watchlist-details'    => '{{PLURAL:$1|Egy|$1}} lap van a figyelőlistádon (a vitalapokon kívül).',
-'wlheader-enotif'      => '* Email értesítés engedélyezve.',
+'wlheader-enotif'      => '* E-mail értesítés engedélyezve.',
 'wlheader-showupdated' => "* Azok a lapok, amelyek megváltoztak, mióta utoljára megnézted őket, '''vastagon''' láthatóak.",
 'watchmethod-recent'   => 'a figyelt lapokon belüli legfrissebb szerkesztések',
 'watchmethod-list'     => 'a legfrissebb szerkesztésekben található figyelt lapok',
@@ -1787,10 +1793,10 @@
 'rollbacklink'                => 'visszaállítás',
 'rollbackfailed'              => 'A visszaállítás nem sikerült',
 'cantrollback'                => 'Nem lehet visszaállítani: az utolsó szerkesztést végző felhasználó az egyetlen, aki a lapot szerkesztette.',
-'alreadyrolled'               => '[[:$1]] utolsó, [[User:$2|$2]] ([[User talk:$2|Vita]]) általi szerkesztését nem lehet visszavonni:
+'alreadyrolled'               => '[[:$1]] utolsó, [[User:$2|$2]] ([[User talk:$2|vita]] | [[Special:Contributions/$2|{{int:contribslink}}]]) általi szerkesztését nem lehet visszavonni:
 időközben valaki már visszavonta, vagy szerkesztette a lapot.
 
-Az utolsó szerkesztést [[User:$3|$3]] ([[User talk:$3|vita]]) végezte.',
+Az utolsó szerkesztést [[User:$3|$3]] ([[User talk:$3|vita]] | [[Special:Contributions/$3|{{int:contribslink}}]]) végezte.',
 'editcomment'                 => 'A változtatás összefoglalója „<i>$1</i>” volt.', # only shown if there is an edit comment
 'revertpage'                  => 'Visszaállítottam a lap korábbi változatát: [[Special:Contributions/$2|$2]]  ([[User talk:$2|vita]]) szerkesztéséről [[User:$1|$1]] szerkesztésére', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '$1 szerkesztéseit visszaállítottam $2 utolsó változatára.',
@@ -1798,7 +1804,7 @@
 ez a művelet a munkamenet eltérítése miatti óvatosságból megszakadt.
 Kérjük, hogy nyomd meg a "vissza" gombot, és töltsd le újra az oldalt, ahonnan jöttél, majd próbáld újra.',
 'protectlogpage'              => 'Lapvédelmi_napló',
-'protectlogtext'              => 'Ez a lapok lezárásának és megnyitásának listája. A [[Special:Protectedpages|védett lapok listáján]] megtekintheted a jelenleg is érvényben lévő védelmeket.',
+'protectlogtext'              => 'Ez a lapok lezárásának és megnyitásának listája. A [[Special:ProtectedPages|védett lapok listáján]] megtekintheted a jelenleg is érvényben lévő védelmeket.',
 'protectedarticle'            => 'levédte a(z) [[$1]] lapot',
 'modifiedarticleprotection'   => 'a védelmi szint a következőre változott: "[[$1]]"',
 'unprotectedarticle'          => 'eltávolította a védelmet a(z) „[[$1]]” lapról',
@@ -1916,7 +1922,7 @@
 
 # What links here
 'whatlinkshere'            => 'Mi hivatkozik erre',
-'whatlinkshere-title'      => 'A(z) $1 lapra hivatkozó lapok',
+'whatlinkshere-title'      => 'A(z) „$1” lapra hivatkozó lapok',
 'whatlinkshere-page'       => 'Oldal:',
 'linklistsub'              => '(Hivatkozások )',
 'linkshere'                => 'Az alábbi lapok hivatkoznak erre: [[:$1]]',
@@ -1931,7 +1937,7 @@
 'whatlinkshere-hideredirs' => 'átirányítások $1',
 'whatlinkshere-hidetrans'  => 'beillesztések $1',
 'whatlinkshere-hidelinks'  => 'linkek $1',
-'whatlinkshere-hideimages' => '$1 képhivatkozás',
+'whatlinkshere-hideimages' => 'képhivatkozás $1',
 'whatlinkshere-filters'    => 'Szűrés',
 
 # Block/unblock
@@ -1965,7 +1971,7 @@
 'badipaddress'                    => 'Érvénytelen IP-cím',
 'blockipsuccesssub'               => 'Sikeres blokkolás',
 'blockipsuccesstext'              => '„[[Special:Contributions/$1|$1]]” felhasználót blokkoltad.
-<br />Lásd a [[Special:Ipblocklist|blokkolt IP-címek listáját]] az érvényben lévő blokkok áttekintéséhez.',
+<br />Lásd a [[Special:IPBlockList|blokkolt IP-címek listáját]] az érvényben lévő blokkok áttekintéséhez.',
 'ipb-edit-dropdown'               => 'Blokkolási okok szerkesztése',
 'ipb-unblock-addr'                => '$1 blokkjának feloldása',
 'ipb-unblock'                     => 'Felhasználónév vagy IP-cím blokkolásának feloldása',
@@ -1976,7 +1982,7 @@
 'ipusubmit'                       => 'Blokk feloldása',
 'unblocked'                       => '[[User:$1|$1]] blokkolása feloldva',
 'unblocked-id'                    => '$1 blokkolása feloldásra került',
-'ipblocklist'                     => 'Blokkolt IP-címek listája',
+'ipblocklist'                     => 'Blokkolt IP-címek és felhasználónevek listája',
 'ipblocklist-legend'              => 'Blokkolt felhasználó keresése',
 'ipblocklist-username'            => 'Felhasználónév vagy IP-cím:',
 'ipblocklist-submit'              => 'Keresés',
@@ -1989,13 +1995,13 @@
 'emailblock'                      => 'e-mail cím blokkolva',
 'ipblocklist-empty'               => 'A blokkoltak listája üres.',
 'ipblocklist-no-results'          => 'A kért IP-cím vagy felhasználónév nem blokkolt.',
-'blocklink'                       => 'Blokkolás',
+'blocklink'                       => 'blokkolás',
 'unblocklink'                     => 'blokk feloldása',
-'contribslink'                    => 'Szerkesztései',
+'contribslink'                    => 'szerkesztései',
 'autoblocker'                     => "Az általad használt IP-cím autoblokkolva van, mivel korábban a kitiltott „[[User:$1|$1]]” használta. ($1 blokkolásának indoklása: „'''$2'''”) Ha nem te vagy $1, lépj kapcsolatba valamelyik adminisztrátorral, és kérd az autoblokk feloldását. Ne felejtsd el megírni neki, hogy kinek szóló blokkba ütköztél bele!",
 'blocklogpage'                    => 'Blokkolási_napló',
 'blocklogentry'                   => '„$1” blokkolva $2 $3 időtartamra',
-'blocklogtext'                    => 'Ez a felhasználókra helyezett blokkoknak és azok feloldásának listája. Az IP-autoblokkok nem szerepelnek a listában. Lásd még [[Special:Ipblocklist|a jelenleg életben lévő blokkok listáját]].',
+'blocklogtext'                    => 'Ez a felhasználókra helyezett blokkoknak és azok feloldásának listája. Az IP-autoblokkok nem szerepelnek a listában. Lásd még [[Special:IPBlockList|a jelenleg életben lévő blokkok listáját]].',
 'unblocklogentry'                 => '„$1” blokkolása feloldva',
 'block-log-flags-anononly'        => 'csak névtelen felhasználók',
 'block-log-flags-nocreate'        => 'a fióklétrehozás letiltott',
@@ -2037,7 +2043,7 @@
 'lockdbsuccesssub'    => 'Az adatbázis zárolása sikerült',
 'unlockdbsuccesssub'  => 'Az adatbázis zárolásának eltávolítása kész',
 'lockdbsuccesstext'   => 'Az adatbázist zárolták.
-<br />A karbantartás befejezése után ne feledd el [[Special:Unlockdb|kinyitni]].',
+<br />A karbantartás befejezése után ne feledd el [[Special:UnlockDB|kinyitni]].',
 'unlockdbsuccesstext' => 'Az adatbázis kinyitása kész.',
 'lockfilenotwritable' => 'Az adatbázist zároló fájl nem írható. Az adatbázis zárolásához vagy kinyitásához ennek a webkiszolgáló által írhatónak kell lennie.',
 'databasenotlocked'   => 'Az adatbázis nincs lezárva.',
@@ -2045,26 +2051,24 @@
 # Move page
 'move-page'               => '$1 átnevezése',
 'move-page-legend'        => 'Lap átnevezése',
-'movepagetext'            => "Az alábbi űrlap használatával nevezhetsz át egy lapot, és helyezheted át előzményeit az új névre.
-A régi cím az új címre átirányító lap lesz.
-A régi lapcímre mutató hivatkozások változatlanok maradnak;
-a rossz átirányításokat ellenőrizd.
-Te vagy a felelős annak biztosításáért, hogy a hivatkozások továbbítsanak ahhoz a ponthoz, ahová feltehetőleg vinniük kell.
+'movepagetext'            => "Az alábbi űrlap használatával nevezhetsz át egy lapot, és helyezheted át teljes laptörténetét az új nevére.
+A régi cím az új címre való átirányítás lesz.
+Frissítheted az átirányításokat úgy, hogy azok automatikusan a megfelelő címre mutassanak;
+ha nem teszed, ellenőrízd a [[Special:DoubleRedirects|dupla]]- vagy [[Special:BrokenRedirects|hibás átirányításokat]].
+Neked kell biztosítani azt, hogy a linkek továbbra is oda mutassanak, ahová mutatniuk kell.
 
-A lap '''nem''' kerül áthelyezésre, ha már van olyan című új lap, hacsak nem üres vagy átirányítás, és nincs szerkesztési előzménye.
-Ez azt jelenti, hogy visszanevezheted az oldalt az eredeti nevére, ha hibázol, létező oldalt pedig nem tudsz felülírni.
+A lap '''nem''' nevezhető át, ha már van egy ugyanilyen című lap, hacsak nem üres vagy átirányítás, és nincs laptörténete.
+Ez azt jelenti, hogy visszanevezheted az oldalt az eredeti nevére, ha véletlenül hibázol, és létező oldalt nem tudsz felülírni.
 
 '''FIGYELEM!'''
 Népszerű oldalak esetén ez drasztikus és nem várt változtatás lehet;
-győződj meg róla a folytatás előtt, hogy tisztában vagy-e a következményekkel.",
+győződj meg a folytatás előtt arról, hogy tisztában vagy-e a következményekkel.",
 'movepagetalktext'        => "A laphoz tartozó vitalap automatikusan átneveződik, '''kivéve, ha:'''
 *már létezik egy nem üres vitalap az új helyen,
 *nem jelölöd be a lenti pipát.
 
 Ezen esetekben a vitalapot külön, kézzel kell átnevezned a kívánságaid szerint.",
 'movearticle'             => 'Lap átnevezése',
-'movenologin'             => 'Nem jelentkeztél be',
-'movenologintext'         => 'Ahhoz, hogy átnevezhess egy lapot, [[Special:Userlogin|be kell lépned]].',
 'movenotallowed'          => 'A lapok áthelyezése ebben a wikiben számodra nem engedélyezett.',
 'newtitle'                => 'Az új cím:',
 'move-watch'              => 'Figyeld a lapot',
@@ -2092,7 +2096,7 @@
 'delete_and_move'         => 'Törlés és átnevezés',
 'delete_and_move_text'    => '== Törlés szükséges ==
 
-Az átnevezés céljaként megadott „[[$1]]” szócikk már létezik.  Ha az átnevezést végre akarod hajtani, ezt a lapot törölni kell.  Valóban ezt szeretnéd?',
+Az átnevezés céljaként megadott „[[:$1]]” szócikk már létezik.  Ha az átnevezést végre akarod hajtani, ezt a lapot törölni kell.  Valóban ezt szeretnéd?',
 'delete_and_move_confirm' => 'Igen, töröld a lapot',
 'delete_and_move_reason'  => 'átnevezendő lap célneve felszabadítva',
 'selfmove'                => 'A cikk jelenlegi címe megegyezik azzal, amire át szeretnéd mozgatni. Egy szócikket saját magára mozgatni nem lehet.',
@@ -2100,6 +2104,7 @@
 'imagenocrossnamespace'   => 'A fájlok nem helyezhetőek át más névtérbe',
 'imagetypemismatch'       => 'Az új kiterjesztés nem egyezik meg a fájl típusával',
 'imageinvalidfilename'    => 'A célnév érvénytelen',
+'fix-double-redirects'    => 'Az eredeti címre mutató hivatkozások frissítése',
 
 # Export
 'export'            => 'Lapok exportálása',
@@ -2300,9 +2305,10 @@
 'markedaspatrollederror-noautopatrol' => 'A saját változtatásaid megjelölése ellenőrzöttként nem engedélyezett.',
 
 # Patrol log
-'patrol-log-page' => 'Ellenőrzési napló',
-'patrol-log-line' => 'megjelölve $1 / $2 ellenőrizve $3',
-'patrol-log-auto' => '(automatikus)',
+'patrol-log-page'   => 'Ellenőrzési napló',
+'patrol-log-header' => 'Ez az ellenőrzött változatok naplója.',
+'patrol-log-line'   => 'megjelölve $1 / $2 ellenőrizve $3',
+'patrol-log-auto'   => '(automatikus)',
 
 # Image deletion
 'deletedrevision'                 => 'Régebbi változat törölve: $1',
@@ -2331,11 +2337,11 @@
 'show-big-image'       => 'A kép nagyfelbontású változata',
 'show-big-image-thumb' => '<small>Az előnézet mérete: $1 × $2 képpont</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Új képek galériája',
 'imagelisttext'         => 'Lentebb $1 kép látható, $2 rendezve.',
-'newimages-summary'     => 'Ezen a speciális lapon láthatóak a legutóbb feltöltött fájlok',
-'showhidebots'          => '($1 robot)',
+'newimages-summary'     => 'Ezen a speciális lapon láthatóak a legutóbb feltöltött fájlok.',
+'showhidebots'          => '(botok szerkesztéseinek $1)',
 'noimages'              => 'Nem tekinthető meg semmi.',
 'ilsubmit'              => 'Keresés',
 'bydate'                => 'dátum szerint',
@@ -2615,7 +2621,7 @@
 
 # External editor support
 'edit-externally'      => 'A fájl szerkesztése külső alkalmazással',
-'edit-externally-help' => 'Lásd a [http://meta.wikimedia.org/wiki/Help:External_editors „setup instructions”] leírást (angolul) ennek használatához.',
+'edit-externally-help' => 'Lásd a [http://www.mediawiki.org/wiki/Manual:External_editors „setup instructions”] leírást (angolul) ennek használatához.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'összes',
@@ -2725,8 +2731,8 @@
 'livepreview-error'   => 'A csatlakozás nem sikerült: $1 "$2". Próbálkozz a normál előnézettel.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'A(z) $1 másodpercnél frissebb szerkesztések nem biztos, hogy megjelennek ezen a listán.',
-'lag-warn-high'   => 'Az adatbázisszerver túlterheltsége miatt a(z) $1 másodpercnél frissebb változtatások nem biztos, hogy megjelennek ezen a listán.',
+'lag-warn-normal' => '{{PLURAL:$1|Az egy|A(z) $1}} másodpercnél frissebb szerkesztések nem biztos, hogy megjelennek ezen a listán.',
+'lag-warn-high'   => 'Az adatbázisszerver túlterheltsége miatt {{PLURAL:$1|az egy|a(z) $1}} másodpercnél frissebb változtatások nem biztos, hogy megjelennek ezen a listán.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'A figyelőlistádon $1 cikk szerepel (a vitalapok nélkül).',
@@ -2778,7 +2784,7 @@
 'version-software-product'         => 'Termék',
 'version-software-version'         => 'Verzió',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Fájlelérés',
 'filepath-page'    => 'Fájl:',
 'filepath-submit'  => 'Elérés',
@@ -2816,7 +2822,7 @@
 'specialpages-group-redirects'   => 'Átirányító speciális lapok',
 'specialpages-group-spam'        => 'Spam eszközök',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Üres lap',
 'intentionallyblankpage' => 'Ez a lap szándékosan maradt üresen',
 
Index: languages/messages/MessagesDz.php
===================================================================
--- languages/messages/MessagesDz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Tenzin
  * @author CFynn
- * @author Siebrand
- * @author Jon Harald Søby
+ * @author Tenzin
  * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
  */
 
@@ -270,7 +268,7 @@
 'template-protected'     => '(ཉེན་སྐྱོབ་འབད་ཡོདཔ།)',
 'template-semiprotected' => '(ཉེན་སྐྱོབ་ཕྱེད་ཀ་འབད་ཡོདཔ་)',
 'nocreatetext'           => '{{SITENAME}} གིས་ ཤོག་ལེབ་གསརཔ་བཟོ་ནི་ལས་ བཀག་དམ་འབད་ཡོདཔ།
-ཁྱོད་ཀྱིས་ ལོག་འགྱོ་ཞིནམ་ལས་ ཡོད་བཞིན་པའི་ཤོག་ལེབ་འདི་ཞུན་དག་འབད་ ཡང་ན་  [[Special:Userlogin|ནང་བསྐྱོད་དང་ ཡངན་ རྩིས་ཐོ་གསརཔ་བཟོ་]].',
+ཁྱོད་ཀྱིས་ ལོག་འགྱོ་ཞིནམ་ལས་ ཡོད་བཞིན་པའི་ཤོག་ལེབ་འདི་ཞུན་དག་འབད་ ཡང་ན་  [[Special:UserLogin|ནང་བསྐྱོད་དང་ ཡངན་ རྩིས་ཐོ་གསརཔ་བཟོ་]].',
 'recreate-deleted-warn'  => "'''ཉེན་བརྡ་: ཁྱོད་ཀྱིས་ ཧ་མ་ལས་བཏོན་བཏང་ཡོད་པའི་ཤོག་ལེབ་ཅིག་ ལོག་གསར་བཟོ་འབདཝ་ཨིན་པས།'''
 
 ཁྱོད་ཀྱིས་ ཤོག་ལེབ་འདི་འཕྲོ་མཐུད་དེ་ཞུན་དག་འབད་ནི་གི་འོས་འབབ་ཡོད་མེད་བལྟ་དགོ།
@@ -358,7 +356,7 @@
 'uploadlogpage' => 'ལོག་སྐྱེལ་བཙུགས་འབད།',
 'uploadedimage' => '"[[$1]]" སྐྱེལ་བཙུགས་འབད་ཡོདཔ།',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'ཡིག་སྣོད་ཐོ་ཡིག།',
 
 # Image description page
@@ -445,7 +443,7 @@
 'log'                  => 'ལོགསི།',
 'all-logs-page'        => 'ལོག་སི་ཆ་མཉམ།',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ཤོག་ལེབ་ག་ར།',
 'alphaindexline' => '$1 ལས་ $2',
 'nextpage'       => 'ཤུལ་མའི་ཤོག་ལེབ་ ($1)',
@@ -467,7 +465,7 @@
 'watchlistfor'         => "('''$1''' གི་དོན་ལུ་)",
 'addedwatch'           => 'བལྟ་ཞིབ་ཐོ་ཡིག་ལུ་ཁ་སྐོང་རྐྱབ་ཅི།',
 'addedwatchtext'       => "ཤོག་ལེབ་  \"[[:\$1]]\" འདི་ ཁྱོད་རའི་ [[Special:Watchlist|watchlist]] ལུ་ ཁ་སྐོང་བརྐྱབས་ནུག།\\n
-ཤོག་ལེབ་དེ་ལུ་མ་འོངས་བསྒྱུར་བཅོས་དང་ དེ་གི་འབྲེལ་ཡོད་བློ་ཤོག་འདི་ དེ་ཁར་ཐོ་བཀོད་འབད་ནི་དང་ འཇམ་ཏོང་ཏོ་སྦེ་གདམ་ཁ་བརྐྱབ་ཚུགས་ནི་གི་དོན་ལུ་  ཤོག་ལེབ་འདི་ [[Special:Recentchanges|list of recent changes]] ནང་ལུ་ '''མངོན་གསལ་''' སྦེ་འབྱུང་འོང་།",
+ཤོག་ལེབ་དེ་ལུ་མ་འོངས་བསྒྱུར་བཅོས་དང་ དེ་གི་འབྲེལ་ཡོད་བློ་ཤོག་འདི་ དེ་ཁར་ཐོ་བཀོད་འབད་ནི་དང་ འཇམ་ཏོང་ཏོ་སྦེ་གདམ་ཁ་བརྐྱབ་ཚུགས་ནི་གི་དོན་ལུ་  ཤོག་ལེབ་འདི་ [[Special:RecentChanges|list of recent changes]] ནང་ལུ་ '''མངོན་གསལ་''' སྦེ་འབྱུང་འོང་།",
 'removedwatch'         => 'བལྟ་ཞིབ་ཐོ་ཡིག་ནང་ལས་བཏོན་བཀོག་ཡོདཔ།',
 'removedwatchtext'     => 'ཤོག་ལེབ་  "[[:$1]]" འདི་ ཁྱོད་རའི་བལྟ་ཞིབ་ཐོ་ཡིག་ནང་ལས་ བཏོན་བཀོག་ནུག།',
 'watch'                => 'བལྟ་ཞིབ་འབད།',
@@ -658,7 +656,7 @@
 'show-big-image'       => 'ཧུམ་ཆ་གང་།',
 'show-big-image-thumb' => '<small>སྔོན་ལྟའི་ཚད་: $1 × $2 པིག་སེལསི་</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'ཡིག་སྣོད་གསར་པའི་སྟོན་ཁང་།',
 
 # Bad image list
@@ -685,7 +683,7 @@
 
 # External editor support
 'edit-externally'      => 'ཕྱིའི་གློག་རིམ་ལག་ལེན་འཐབ་ཐོག་ལས་ ཡིག་སྣོད་འདི་ཞུན་དག་འབད།',
-'edit-externally-help' => 'བརྡ་དོན་ཁ་གསལ་གྱི་དོན་ལུ་ [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] ལུ་ལྟ།',
+'edit-externally-help' => 'བརྡ་དོན་ཁ་གསལ་གྱི་དོན་ལུ་ [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] ལུ་ལྟ།',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'ཆ་མཉམ།',
Index: languages/messages/MessagesBug.php
===================================================================
--- languages/messages/MessagesBug.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBug.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Kurniasan
- * @author SPQRobin
  */
 
 $fallback = "id";
@@ -84,7 +83,7 @@
 'preview'          => 'ᨄᨛᨑᨗᨅᨗᨐᨘ',
 'accmailtitle'     => 'Ada sandi ni riantarak.',
 'accmailtext'      => 'Ada sandi "$1" riantarak ri $2.',
-'anontalkpagetext' => "----''Ini adalah halaman diskusi untuk pengguna anonim yang belum membuat rekening atau tidak menggunakannya. Karena tidak membuat rekening, kami terpaksa memakai alamat IP untuk mengenalinya. Alamat IP seperti ini dapat dipakai oleh beberapa pengguna yang berbeda. Jika Anda adalah pengguna anonim dan merasa mendapatkan komentar-komentar yang tidak berkaitan dengan anda, kami anjurkan untuk [[Special:Userlogin|membuat rekening atau masuk log]] untuk menghindari kerancuan dengan pengguna anonim lain.''",
+'anontalkpagetext' => "----''Ini adalah halaman diskusi untuk pengguna anonim yang belum membuat rekening atau tidak menggunakannya. Karena tidak membuat rekening, kami terpaksa memakai alamat IP untuk mengenalinya. Alamat IP seperti ini dapat dipakai oleh beberapa pengguna yang berbeda. Jika Anda adalah pengguna anonim dan merasa mendapatkan komentar-komentar yang tidak berkaitan dengan anda, kami anjurkan untuk [[Special:UserLogin|membuat rekening atau masuk log]] untuk menghindari kerancuan dengan pengguna anonim lain.''",
 'editing'          => 'ᨙᨕᨉᨗᨈᨗ $1',
 
 # Recent changes
@@ -105,7 +104,7 @@
 'move'         => 'ᨙᨕᨔᨘ',
 'movethispage' => 'ᨙᨕᨔᨘᨀᨗ ᨕᨗᨙᨐᨙᨉ ᨒᨛᨄ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Maneng halamang',
 'alphaindexline' => '$1 ri $2',
 'allpagesfrom'   => 'Mappaitang halamang-halamang rimulai:',
@@ -119,7 +118,7 @@
 'addedwatch'     => 'Tamba ri jagaan',
 'addedwatchtext' => "Halamang \"[[:\$1]]\" ni ritamba ri ida [[Special:Watchlist|watchlist]].
 Halamang bicara éréngé gabungan halamang bicara pada wettu depan didaftarkan koe,
-éréngé halamang akan wessi '''umpek''' ri [[Special:Recentchanges|daftar pinra tanappa]] barak lebih lemmak ita.
+éréngé halamang akan wessi '''umpek''' ri [[Special:RecentChanges|daftar pinra tanappa]] barak lebih lemmak ita.
 
 Apak ida ronnak mappedde halamang édé ri daftar jagaan, klik \"Mangedda jaga\" pada kolom ri sedde.",
 
@@ -149,7 +148,7 @@
 # Media information
 'imagemaxsize' => 'Gangkai rapang pada keterangan rapang ri halamang hingga:',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ᨔᨄ',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesLt.php
===================================================================
--- languages/messages/MessagesLt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,14 +6,12 @@
  *
  * @author Garas
  * @author Hugo.arg
- * @author Siebrand
  * @author Matasg
  * @author Pdxx
  * @author Siggis
+ * @author Tomasdd
  * @author Vpovilaitis
- * @author Tomasdd
  * @author לערי ריינהארט
- * @author SPQRobin
  */
 
 $namespaceNames = array(
@@ -346,7 +344,7 @@
 'nosuchspecialpage' => 'Nėra tokio specialiojo puslapio',
 'nospecialpagetext' => "<big>'''Jūs prašėte neleistino specialiojo puslapio'''</big>
 
-Leistinų specialiųjų puslapių sąrašą galite rasti [[Special:Specialpages|specialiųjų puslapių sąraše]].",
+Leistinų specialiųjų puslapių sąrašą galite rasti [[Special:SpecialPages|specialiųjų puslapių sąraše]].",
 
 # General errors
 'error'                => 'Klaida',
@@ -379,7 +377,7 @@
 Paprastai tai būna dėl pasenusios skirtumo ar istorijos nuorodos į puslapį, kuris buvo ištrintas.
 
 Jei tai ne tas atvejis, jūs galbūt radote klaidą programinėje įrangoje.
-Prašome apie tai pranešti administratoriui, nepamiršdami nurodyti nuorodą.',
+Prašome apie tai pranešti [[Special:ListUsers/sysop|administratoriui]], nepamiršdami nurodyti nuorodą.',
 'missingarticle-rev'   => '(versija#: $1)',
 'missingarticle-diff'  => '(Skirt.: $1, $2)',
 'readonly_lag'         => 'Duomenų bazė buvo automatiškai užrakinta, kol pagalbinės duomenų bazės prisivys pagrindinę',
@@ -422,11 +420,16 @@
 'titleprotected'       => "[[User:$1|$1]] apsaugojo šį pavadinimą nuo sukūrimo.
 Duota priežastis yra ''$2''.",
 
+# Virus scanner
+'virus-badscanner'     => 'Neteisinga konfiguracija: nežinomas viruso skaneris: <i>$1</i>',
+'virus-scanfailed'     => 'skanavimas nepavyko (kodas $1)',
+'virus-unknownscanner' => 'nežinomas antivirusas:',
+
 # Login and logout pages
 'logouttitle'                => 'Naudotojo atsijungimas',
 'logouttext'                 => '<strong>Dabar jūs esate atsijungęs.</strong>
 
-Galite toliau naudoti {{SITENAME}} anonimiškai arba prisijunkite iš naujo tuo pačiu ar kitu naudotoju.
+Galite toliau naudoti {{SITENAME}} anonimiškai arba [[Special:UserLogin|prisijunkite]] iš naujo tuo pačiu ar kitu naudotoju.
 Pastaba: kai kuriuose puslapiuose ir toliau gali rodyti, kad esate prisijungęs iki tol, kol išvalysite savo naršyklės podėlį.',
 'welcomecreation'            => '== Sveiki, $1! ==
 
@@ -499,8 +502,8 @@
 'blocked-mailpassword'       => 'Jūsų IP adresas yra užblokuotas nuo redagavimo, taigi neleidžiama naudoti slaptažodžio priminimo funkcijos, kad apsisaugotume nuo piktnaudžiavimo.',
 'eauthentsent'               => 'Patvirtinimo laiškas buvo nusiųstas į paskirtąjį el. pašto adresą.
 Prieš išsiunčiant kitą laišką į jūsų dėžutę, jūs turite vykdyti nurodymus laiške, kad patvirtintumėte, kad dėžutė tikrai yra jūsų.',
-'throttled-mailpassword'     => 'Slaptažodžio priminimas jau buvo išsiųstas, per paskutinias $1 valandas.
-Norint apsisaugoti nuo piktnaudžiavimo, slaptažodžio priminimas gali būti išsiųstas tik kas $1 valandas.',
+'throttled-mailpassword'     => 'Slaptažodžio priminimas jau buvo išsiųstas, per {{PLURAL:$1|pasuktinę valandą|$1 paskutines valandas|$1 paskutinių valandų}}.
+Norint apsisaugoti nuo piktnaudžiavimo, slaptažodžio priminimas gali būti išsiųstas tik kas {{PLURAL:$1|valandą|$1 valandas|$1 valandų}}.',
 'mailerror'                  => 'Klaida siunčiant paštą: $1',
 'acct_creation_throttle_hit' => 'Atleiskite, bet jūs jau sukūrėte $1 paskyras. Daugiau nebegalima.',
 'emailauthenticated'         => 'Jūsų el. pašto adresas buvo patvirtintas $1.',
@@ -599,10 +602,6 @@
 'blockededitsource'                => "''Jūsų keitimų''' tekstas puslapiui '''$1''' yra rodomas žemiau:",
 'whitelistedittitle'               => 'Norint redaguoti reikia prisijungti',
 'whitelistedittext'                => 'Jūs turite $1, kad redaguotumėte puslapius.',
-'whitelistreadtitle'               => 'Norint skaityti reikia prisijungti',
-'whitelistreadtext'                => 'Jums reikia [[Special:Userlogin|prisijungti]], kad skaitytumėte puslapius.',
-'whitelistacctitle'                => 'Jums neleidžiama kurti paskyros',
-'whitelistacctext'                 => 'Norėdami leisti kurti paskyras {{SITENAME}}, jums reikia [[Special:Userlogin|prisijungti]] ir turėti atitinkamas teises.',
 'confirmedittitle'                 => 'Reikalingas el. pašto patvirtinimas, kad redaguotumėte',
 'confirmedittext'                  => 'Jums reikia patvirtinti el. pašto adresą, prieš redaguojant puslapius.
 Prašome nurodyti ir patvirtinti jūsų el. pašto adresą per jūsų [[Special:Preferences|naudotojo nustatymus]].',
@@ -621,7 +620,7 @@
 'anontalkpagetext'                 => "----''Tai yra anoniminio naudotojo, nesusikūrusio arba nenaudojančio paskyros, aptarimų puslapis.
 Dėl to naudojamas IP adresas jo identifikavimui.
 Šis IP adresas gali būti dalinamas keliems naudotojams.
-Jeigu Jūs esate anoniminis naudotojas ir atrodo, kad komentarai nėra skirti Jums, [[Special:Userlogin|sukurkite paskyrą arba prisijunkite]], ir nebūsite tapatinamas su kitais anoniminiais naudotojais.''",
+Jeigu Jūs esate anoniminis naudotojas ir atrodo, kad komentarai nėra skirti Jums, [[Special:UserLogin/signup|sukurkite paskyrą]] arba [[Special:UserLogin|prisijunkite]], ir nebūsite tapatinamas su kitais anoniminiais naudotojais.''",
 'noarticletext'                    => 'Šiuo metu šiame puslapyje nėra jokio teksto, jūs galite [[Special:Search/{{PAGENAME}}|ieškoti šio puslapio pavadinimo]] kituose puslapiuose arba [{{fullurl:{{FULLPAGENAME}}|action=edit}} redaguoti šį puslapį].',
 'userpage-userdoesnotexist'        => 'Naudotojo paskyra „$1“ yra neužregistruota. Prašom patikrinti, ar jūs norite kurti/redaguoti šį puslapį.',
 'clearyourcache'                   => "'''Dėmesio:''' Išsaugoję jums gali prireikti išvalyti jūsų naršyklės podėlį, kad pamatytumėte pokyčius. '''Mozilla / Safari / Konqueror:''' laikydami ''Shift'' pasirinkite ''Atsiųsti iš naujo'', arba paspauskite ''Ctrl-Shift-R'' (sistemoje Apple Mac ''Cmd-Shift-R''); '''IE:''' laikydami ''Ctrl'' paspauskite ''Atnaujinti'', arba paspauskite ''Ctrl-F5''; '''Konqueror:''' tiesiog paspauskite ''Perkrauti'' mygtuką, arba paspauskite ''F5''; '''Opera''' naudotojams gali prireikti pilnai išvalyti jų podėlį ''Priemonės→Nuostatos''.",
@@ -639,7 +638,7 @@
 
 ''Kadangi {{SITENAME}} grynasis HTML yra įjungtas, peržiūra yra paslėpta kaip atsargumo priemonė prieš JavaScript atakas.''
 
-<strong>Jei tai teisėtas keitimo bandymas, prašome pamėginti vėl. Jei tai nepadeda, pamėginkite atsijungti ir prisijungti atgal.</strong>",
+<strong>Jei tai teisėtas keitimo bandymas, prašome pamėginti vėl. Jei tai nepadeda, pamėginkite [[Special:UserLogout|atsijungti]] ir prisijungti atgal.</strong>",
 'token_suffix_mismatch'            => '<strong>Jūsų pakeitimas buvo atmestas, nes jūsų naršyklė iškraipė skyrybos ženklus keitimo žymėje. Keitimas buvo atmestas norint apsaugoti puslapio tekstą nuo sugadinimo. Taip kartais būna, kai jūs naudojate anoniminį tarpinio serverio paslaugą.</strong>',
 'editing'                          => 'Taisomas $1',
 'editingsection'                   => 'Taisomas $1 (skyrelis)',
@@ -684,7 +683,7 @@
 'edittools'                        => '<!-- Šis tekstas bus rodomas po redagavimo ir įkėlimo formomis. -->',
 'nocreatetitle'                    => 'Puslapių kūrimas apribotas',
 'nocreatetext'                     => '{{SITENAME}} apribojo galimybę kurti naujus puslapius.
-Jūs galite grįžti ir redaguoti jau esantį puslapį, arba [[Special:Userlogin|prisijungti arba sukurti paskyrą]].',
+Jūs galite grįžti ir redaguoti jau esantį puslapį, arba [[Special:UserLogin|prisijungti arba sukurti paskyrą]].',
 'nocreate-loggedin'                => 'Jūs neturite teisės sukurti puslapius šiame projekte.',
 'permissionserrors'                => 'Teisių klaida',
 'permissionserrorstext'            => 'Jūs neturite teisių tai daryti dėl {{PLURAL:$1|šios priežasties|šių priežasčių}}:',
@@ -710,7 +709,7 @@
 'undo-success' => 'Keitimas gali būti atšauktas. Prašome patikrinti palyginimą, esantį žemiau, kad patvirtintumėte, kad jūs tai ir norite padaryti, ir tada išsaugokite pakeitimus, esančius žemiau, kad užbaigtumėte keitimo atšaukimą.',
 'undo-failure' => 'Keitimas negali būti atšauktas dėl konfliktuojančių tarpinių keitimų.',
 'undo-norev'   => 'Keitimas negali būti atšauktas, kadangi jis neegzistuoja arba buvo ištrintas.',
-'undo-summary' => 'Atšaukti [[Special:Contributions/$2|$2]] ([[User talk:$2|Aptarimas]]) versiją $1',
+'undo-summary' => 'Atšaukti [[Special:Contributions/$2|$2]] ([[User talk:$2|Aptarimas]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]]) versiją $1',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Paskyrų kūrimas negalimas',
@@ -881,7 +880,7 @@
 'mypreferences'            => 'Mano nustatymai',
 'prefs-edits'              => 'Keitimų skaičius:',
 'prefsnologin'             => 'Neprisijungęs',
-'prefsnologintext'         => 'Jums reikia būti [[Special:Userlogin|prisijungusiam]], kad galėtumėte keisti savo nustatymus.',
+'prefsnologintext'         => 'Jums reikia būti [[Special:UserLogin|prisijungusiam]], kad galėtumėte keisti savo nustatymus.',
 'prefsreset'               => 'Nustatymai buvo atstatyti iš saugyklos.',
 'qbsettings'               => 'Greitasis pasirinkimas',
 'qbsettings-none'          => 'Nerodyti',
@@ -956,7 +955,7 @@
 'userrights-reason'           => 'Keitimo priežastis:',
 'userrights-no-interwiki'     => 'Jūs neturite leidimo keisti naudotojų teises kituose projektuose.',
 'userrights-nodatabase'       => 'Duomenų bazė $1 neegzistuoja arba yra ne vietinė.',
-'userrights-nologin'          => 'Jūs privalote [[Special:Userlogin|prisijungti]] kaip administratorius, kad galėtumėte priskirti naudotojų teises.',
+'userrights-nologin'          => 'Jūs privalote [[Special:UserLogin|prisijungti]] kaip administratorius, kad galėtumėte priskirti naudotojų teises.',
 'userrights-notallowed'       => 'Jūsų paskyra neturi teisių priskirti naudotojų teises.',
 'userrights-changeable-col'   => 'Grupės, kurias galite keisti',
 'userrights-unchangeable-col' => 'Grupės, kurių negalite keisti',
@@ -986,22 +985,41 @@
 'grouppage-suppress'      => '{{ns:project}}:Peržiūra',
 
 # Rights
-'right-read'          => 'Skaityti puslapius',
-'right-edit'          => 'Redaguoti puslapius',
-'right-createpage'    => 'Kurti puslapius (kurie nėra aptarimų puslapiai)',
-'right-createtalk'    => 'Kurti aptarimų puslapius',
-'right-createaccount' => 'Kurti naujas naudotojų paskyras',
-'right-minoredit'     => 'Žymeti keitimus kaip smulkius',
-'right-move'          => 'Pervadinti puslapius',
-'right-upload'        => 'Įkelti failus',
-'right-reupload'      => 'Perrašyti egzistuojantį failą',
-'right-reupload-own'  => 'Perrašyti paties įkeltą egzistuojantį failą',
-'right-upload_by_url' => 'Įkelti failą iš URL adreso',
-'right-autoconfirmed' => 'Redaguoti pusiau užrakintus puslapius',
-'right-delete'        => 'Trinti puslapius',
-'right-browsearchive' => 'Ieškoti ištrintų puslapių',
-'right-undelete'      => 'Atstatyti puslapį',
-'right-userrights'    => 'Redaguoti visų naudotojų teises',
+'right-read'             => 'Skaityti puslapius',
+'right-edit'             => 'Redaguoti puslapius',
+'right-createpage'       => 'Kurti puslapius (kurie nėra aptarimų puslapiai)',
+'right-createtalk'       => 'Kurti aptarimų puslapius',
+'right-createaccount'    => 'Kurti naujas naudotojų paskyras',
+'right-minoredit'        => 'Žymeti keitimus kaip smulkius',
+'right-move'             => 'Pervadinti puslapius',
+'right-move-subpages'    => 'Perkelti puslapius su jų subpuslapiais',
+'right-suppressredirect' => 'Nekurti peradresavimo iš seno pavadinimo kuomet puslapis pervadinamas',
+'right-upload'           => 'Įkelti failus',
+'right-reupload'         => 'Perrašyti egzistuojantį failą',
+'right-reupload-own'     => 'Perrašyti paties įkeltą egzistuojantį failą',
+'right-upload_by_url'    => 'Įkelti failą iš URL adreso',
+'right-autoconfirmed'    => 'Redaguoti pusiau užrakintus puslapius',
+'right-delete'           => 'Trinti puslapius',
+'right-bigdelete'        => 'Ištrinti puslapius su ilga istorija',
+'right-deleterevision'   => 'Ištrinti ir atstatyti specifines puslapių revizijas',
+'right-browsearchive'    => 'Ieškoti ištrintų puslapių',
+'right-undelete'         => 'Atstatyti puslapį',
+'right-suppressrevision' => 'Peržiūrėti ir atstatyti revizijas, paslėptas nuo administratorių',
+'right-suppressionlog'   => 'Žiūrėti privačius logus',
+'right-block'            => 'Blokuoti redagavimo galimybę kitiems naudotojams',
+'right-blockemail'       => 'Blokuoti elektroninio pašto siuntimo galimybę naudotojui',
+'right-hideuser'         => 'Blokuoti naudotojo vardą, paslėpiant jį nuo viešinimo',
+'right-ipblock-exempt'   => 'Apeiti IP blokavimus, autoblokavimus ir pakopinius blokavimus',
+'right-proxyunbannable'  => 'Apeiti automatinius proxy serverių blokavimus',
+'right-protect'          => 'Pakeisti apsaugos lygius ir redaguoti apsaugotus puslapius',
+'right-editprotected'    => 'Redaguoti apsaugotus puslapius (be pakopinės apsaugos)',
+'right-editinterface'    => 'Redaguoti naudotojo aplinką',
+'right-editusercssjs'    => 'Redaguoti kitų naudotojų CSS ir JS failus',
+'right-import'           => 'Importuoti puslapius iš kitų wiki',
+'right-unwatchedpages'   => 'Žiūrėti nestebimų puslapių sąrašą',
+'right-mergehistory'     => 'Sulieti puslapių istorijas',
+'right-userrights'       => 'Redaguoti visų naudotojų teises',
+'right-siteadmin'        => 'Atrakinti ir užrakinti duomenų bazę',
 
 # User rights log
 'rightslog'      => 'Naudotojų teisių istorija',
@@ -1014,7 +1032,7 @@
 'recentchanges'                     => 'Paskutiniai keitimai',
 'recentchangestext'                 => 'Šiame puslapyje yra patys naujausi pakeitimai šiame projekte.',
 'recentchanges-feed-description'    => 'Sekite pačius naujausius projekto keitimus šiame šaltinyje.',
-'rcnote'                            => "Žemiau yra '''$1''' {{PLURAL:$1|paskutinis pakeitimas|paskutiniai pakeitimai|paskutinių pakeitimų}} per $2 {{PLURAL:$2|paskutiniąją dieną|paskutiniąsias dienas|paskutiniųjų dienų}} skaičiuojant nuo $3.",
+'rcnote'                            => "Žemiau yra {{PLURAL:$1|'''1''' pakeitimas|paskutiniai '''$1''' pakeitimai|paskutinių '''$1''' pakeitimų}} per {{PLURAL:$2|dieną|paskutiniąsias '''$2''' dienas|paskutiniųjų '''$2''' dienų}} skaičiuojant nuo $5, $4.",
 'rcnotefrom'                        => "Žemiau yra pakeitimai pradedant '''$2''' (rodoma iki '''$1''' pakeitimų).",
 'rclistfrom'                        => 'Rodyti naujus pakeitimus pradedant $1',
 'rcshowhideminor'                   => '$1 smulkius keitimus',
@@ -1050,16 +1068,17 @@
 'reupload'                    => 'Pakartoti įkėlimą',
 'reuploaddesc'                => 'Atšaukti įkėlimą ir grįžti į įkėlimo formą.',
 'uploadnologin'               => 'Neprisijungęs',
-'uploadnologintext'           => 'Norėdami įkelti failą, turite būti [[Special:Userlogin|prisijungęs]].',
+'uploadnologintext'           => 'Norėdami įkelti failą, turite būti [[Special:UserLogin|prisijungęs]].',
+'upload_directory_missing'    => 'Įkėlimo direktorija ($1) praleista ir negali būti sukurta tinklo serverio.',
 'upload_directory_read_only'  => 'Tinklapio serveris negali rašyti į įkėlimo aplanką ($1).',
 'uploaderror'                 => 'Įkėlimo klaida',
-'uploadtext'                  => "Naudokitės žemiau pateikta forma failų įkėlimui
-Norėdami peržiūrėti ar ieškoti anksčiau įkeltų paveikslėlių, eikite į [[Special:Imagelist|įkeltų failų sąrašą]], įkėlimai ir trynimai yra registruojami [[Special:Log/upload|įkėlimų istorijoje]].
+'uploadtext'                  => "Naudokitės žemiau pateikta forma failų įkėlimui.
+Norėdami peržiūrėti ar ieškoti anksčiau įkeltų paveikslėlių, eikite į [[Special:ImageList|įkeltų failų sąrašą]], įkėlimai ir trynimai yra registruojami [[Special:Log/upload|įkėlimų istorijoje]], trynimai - [[Special:Log/delete|trynimų istorijoje]].
 
-Norėdami panaudoti įkeltą failą puslapyje, naudokite tokias nuorodas
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Failas.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Failas.png|alternatyvusis tekstas]]</nowiki>''' arba
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Failas.ogg]]</nowiki>''' tiesioginei nuorodai į failą.",
+Norėdami panaudoti įkeltą failą puslapyje, naudokite tokias nuorodas:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>'''
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alt text]]</nowiki></tt>''' arba
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' tiesioginei nuorodai į failą.",
 'upload-permitted'            => 'Leidžiami failų tipai: $1.',
 'upload-preferred'            => 'Pageidautini failų tipai: $1.',
 'upload-prohibited'           => 'Uždrausti failų tipai: $1.',
@@ -1078,8 +1097,8 @@
 'illegalfilename'             => 'Failo varde „$1“ yra simbolių, neleidžiamų puslapio pavadinimuose. Prašome pervadint failą ir mėginkite įkelti jį iš naujo.',
 'badfilename'                 => 'Failo pavadinimas pakeistas į „$1“.',
 'filetype-badmime'            => 'Neleidžiama įkelti „$1“ MIME tipo failų.',
-'filetype-unwanted-type'      => "'''„.$1“''' yra nepageidautinas failo tipas. Pageidautini failų tipai yra $2.",
-'filetype-banned-type'        => "'''„.$1“''' nėra leistinas failo tipas. Leistini failų tipai yra $2.",
+'filetype-unwanted-type'      => "„.$1“''' yra nepageidautinas failo tipas. {{PLURAL:$3|Pageidautinas failų tipas|pageidautini failų tipai}} yra $2.",
+'filetype-banned-type'        => "„.$1“''' nėra leistinas failo tipas. {{PLURAL:$3|Leistinas failų tipas|Leistini failų tipai}} yra $2.",
 'filetype-missing'            => 'Failas neturi galūnės (pavyzdžiui „.jpg“).',
 'large-file'                  => 'Rekomenduojama, kad failų dydis būtų nedidesnis nei $1; šio failo dydis yra $2.',
 'largefileserver'             => 'Šis failas yra didesnis nei serveris yra sukonfigūruotas leisti.',
@@ -1099,6 +1118,7 @@
 prašome eiti atgal ir įkelti šį failą kitu vardu. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Failas tokiu vardu jau egzistuoja bendrojoje failų saugykloje;
 prašome eiti atgal ir įkelti šį failą kitu vardu. [[Image:$1|thumb|center|$1]]',
+'file-exists-duplicate'       => 'Šis failas yra {{PLURAL:$1|šio failo|šių failų}} dublikatas:',
 'successfulupload'            => 'Įkelta sėkmingai',
 'uploadwarning'               => 'Dėmesio',
 'savefile'                    => 'Išsaugoti failą',
@@ -1139,7 +1159,7 @@
 'upload_source_url'  => ' (tikras, viešai prieinamas URL)',
 'upload_source_file' => ' (failas jūsų kompiuteryje)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Šis specialus puslapis rodo visus įkeltus failus.
 Pagal numatymą paskutiniai įkelti failai rodomi sąrašo viršuje.
 Paspaudę ant stulpelio antraštės pakeiste išrikiavimą.',
@@ -1167,7 +1187,9 @@
 'imagelinks'                     => 'Nuorodos',
 'linkstoimage'                   => '{{PLURAL:$1|Šis puslapis|Šie puslapiai}} nurodo į šį failą:',
 'nolinkstoimage'                 => 'Į failą nenurodo joks puslapis.',
-'morelinkstoimage'               => 'Žiūrėti [[Special:Whatlinkshere/$1|daugiau nuorodų]] į šį failą.',
+'morelinkstoimage'               => 'Žiūrėti [[Special:WhatLinksHere/$1|daugiau nuorodų]] į šį failą.',
+'redirectstofile'                => '{{PLURAL:$1|Šis failas|$1 failai}} peradresuoja į šį failą:',
+'duplicatesoffile'               => '{{PLURAL:$1|failas yra dublikatas|$1 failai yra dublikatai}} šio failo:',
 'sharedupload'                   => 'Šis failas yra įkeltas bendram naudojimui ir gali būti naudojamas kituose projektuose.',
 'shareduploadwiki'               => 'Žiūrėkite $1 tolimesnei informacijai.',
 'shareduploadwiki-desc'          => 'Aprašymas iš jo $1 bendrojoje saugykloje yra rodomas žemiau.',
@@ -1249,7 +1271,7 @@
 Iš to išeina, kad vidutiniškai kiekvienas puslapis keistas '''$5''' karto, bei parodytas '''$6''' karto per pakeitimą.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Užduočių eilės] ilgis yra '''$7'''.",
-'userstatstext'          => "Šiuo metu yra '''$1''' [[Special:Listusers|{{PLURAL:$1|registruotas naudotojas|registruoti naudotojai|registruotų naudotojų}}]], iš jų
+'userstatstext'          => "Šiuo metu yra '''$1''' [[Special:ListUsers|{{PLURAL:$1|registruotas naudotojas|registruoti naudotojai|registruotų naudotojų}}]], iš jų
 '''$2''' (arba '''$4%''') yra $5.",
 'statistics-mostpopular' => 'Daugiausiai rodyti puslapiai',
 
@@ -1259,8 +1281,10 @@
 Nuorodos turėtų būti patikslintos, kad rodytų į konkretų puslapį.<br />
 Puslapis laikomas daugiaprasmiu puslapiu, jei jis naudoja šabloną, kuris yra nurodomas iš [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Dvigubi peradresavimai',
-'doubleredirectstext' => 'Šie peradresavimai nurodo į kitus peradresavimo puslapius. Kiekvienoje eilutėje išvardintas pirmasis ir antrasis peradresavimai, taip pat antrojo peradresavimo paskirtis, kuri paprastai ir nurodo į tikrąjį puslapį, į kurį pirmasis peradresavimas ir turėtų rodyti.',
+'doubleredirects'            => 'Dvigubi peradresavimai',
+'doubleredirectstext'        => 'Šie peradresavimai nurodo į kitus peradresavimo puslapius. Kiekvienoje eilutėje išvardintas pirmasis ir antrasis peradresavimai, taip pat antrojo peradresavimo paskirtis, kuri paprastai ir nurodo į tikrąjį puslapį, į kurį pirmasis peradresavimas ir turėtų rodyti.',
+'double-redirect-fixed-move' => '[[$1]] buvo perkeltas, dabar tai peradresavimas į [[$2]]',
+'double-redirect-fixer'      => 'Peradresavimų tvarkyklė',
 
 'brokenredirects'        => 'Peradresavimai į niekur',
 'brokenredirectstext'    => 'Žemiau išvardinti peradresavimo puslapiai rodo į neegzistuojančius puslapius:',
@@ -1293,6 +1317,7 @@
 'popularpages'            => 'Populiarūs puslapiai',
 'wantedcategories'        => 'Geidžiamiausios kategorijos',
 'wantedpages'             => 'Geidžiamiausi puslapiai',
+'missingfiles'            => 'Praleisti failai',
 'mostlinked'              => 'Daugiausiai nurodomi puslapiai',
 'mostlinkedcategories'    => 'Daugiausiai nurodomos kategorijos',
 'mostlinkedtemplates'     => 'Daugiausiai nurodomi šablonai',
@@ -1321,6 +1346,8 @@
 'unusedcategoriestext'    => 'Šie kategorijų puslapiai sukurti, nors joks kitas puslapis ar kategorija jo nenaudoja.',
 'notargettitle'           => 'Nenurodytas objektas',
 'notargettext'            => 'Jūs nenurodėte norimo puslapio ar naudotojo, kuriam įvykdyti šią funkciją.',
+'nopagetitle'             => 'Nėra puslapio tokiu adresu',
+'nopagetext'              => 'Adresas, kurį nurodėte, neegzistuoja.',
 'pager-newer-n'           => '$1 {{PLURAL:$1|naujesnis|naujesni|naujesnių}}',
 'pager-older-n'           => '$1 {{PLURAL:$1|senesnis|senesni|senesnių}}',
 'suppress'                => 'Peržiūra',
@@ -1343,7 +1370,7 @@
 'logempty'             => 'Istorijoje nėra jokių atitinkančių įvykių.',
 'log-title-wildcard'   => 'Ieškoti pavadinimų, prasidedančių šiuo tekstu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Visi puslapiai',
 'alphaindexline'    => 'Nuo $1 iki $2',
 'nextpage'          => 'Kitas puslapis ($1)',
@@ -1362,18 +1389,19 @@
 # Special:Categories
 'categories'                    => 'Kategorijos',
 'categoriespagetext'            => 'Šios kategorijos turi puslapių ar failų.',
+'categoriesfrom'                => 'Vaizduoti kategorijas pradedant nuo:',
 'special-categories-sort-count' => 'rikiuoti pagal skaičių',
 'special-categories-sort-abc'   => 'rikiuoti pagal abėcėlę',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Rodyti naudotojus pradedant nuo:',
 'listusers-submit'   => 'Rodyti',
 'listusers-noresult' => 'Nerasta jokių naudotojų.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Naudotojų grupių teisės',
 'listgrouprights-summary'  => 'Žemiau pateiktas naudotojų grupių, apibrėžtų šioje wiki, ir su jomis susijusių teisių sąrašas.
-Papildoma informacija apie individualias teises gali būti randama [[{{MediaWiki:Listgrouprights-helppage}}]].',
+Čia gali būti [[{{MediaWiki:Listgrouprights-helppage}}|papildoma informacija]] apie individualias teises.',
 'listgrouprights-group'    => 'Grupė',
 'listgrouprights-rights'   => 'Teisės',
 'listgrouprights-helppage' => 'Help:Grupės teisės',
@@ -1381,7 +1409,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nėra adreso',
-'mailnologintext' => 'Jums reikia būti [[Special:Userlogin|prisijungusiam]] ir turi būti įvestas teisingas el. pašto adresas jūsų [[Special:Preferences|nustatymuose]], kad siųstumėte el. laiškus kitiems nautotojams.',
+'mailnologintext' => 'Jums reikia būti [[Special:UserLogin|prisijungusiam]] ir turi būti įvestas teisingas el. pašto adresas jūsų [[Special:Preferences|nustatymuose]], kad siųstumėte el. laiškus kitiems nautotojams.',
 'emailuser'       => 'Rašyti laišką šiam naudotojui',
 'emailpage'       => 'Siųsti el. laišką naudotojui',
 'emailpagetext'   => 'Jei šis naudotojas yra įvedęs teisingą el. pašto adresą
@@ -1401,6 +1429,7 @@
 'emailccsubject'  => 'Laiško kopija naudotojui $1: $2',
 'emailsent'       => 'El. laiškas išsiųstas',
 'emailsenttext'   => 'Jūsų el. pašto žinutė išsiųsta.',
+'emailuserfooter' => 'Šis elektrninis laiškas buvo išsiųstas naudotojo $1 naudotojui $2 naudojant „Rašyti elektroninį laišką“ funkciją projekte {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Stebimi puslapiai',
@@ -1409,11 +1438,11 @@
 'nowatchlist'          => 'Neturite nei vieno stebimo puslapio.',
 'watchlistanontext'    => 'Prašome $1, kad peržiūrėtumėte ar pakeistumėte elementus savo stebimųjų sąraše.',
 'watchnologin'         => 'Neprisijungęs',
-'watchnologintext'     => 'Jums reikia būti [[Special:Userlogin|prisijungusiam]], kad pakeistumėte savo stebimųjų sąrašą.',
+'watchnologintext'     => 'Jums reikia būti [[Special:UserLogin|prisijungusiam]], kad pakeistumėte savo stebimųjų sąrašą.',
 'addedwatch'           => 'Pridėta į Stebimųjų sąrašą',
 'addedwatchtext'       => "Puslapis „[[:$1]]“ pridėtas į [[Special:Watchlist|stebimųjų sąrašą]].
 Būsimi puslapio bei atitinkamo aptarimo puslapio pakeitimai bus rodomi stebimųjų puslapių sąraše,
-taip pat bus '''paryškinti''' [[Special:Recentchanges|naujausių keitimų sąraše]], kad išsiskirtų iš kitų puslapių.",
+taip pat bus '''paryškinti''' [[Special:RecentChanges|naujausių keitimų sąraše]], kad išsiskirtų iš kitų puslapių.",
 'removedwatch'         => 'Pašalinta iš stebimų',
 'removedwatchtext'     => 'Puslapis „[[:$1]]“ pašalintas iš jūsų stebimųjų sąrašo.',
 'watch'                => 'Stebėti',
@@ -1507,17 +1536,17 @@
 ** Autorystės teisių pažeidimas
 ** Vandalizmas',
 'delete-edit-reasonlist'      => 'Keisti trynimo priežastis',
-'delete-toobig'               => 'Šis puslapis turi ilgą keitimų istoriją, daugiau nei $1 versijų. Tokių puslapių trynimas yra apribotas, kad būtų išvengta atsitiktinio {{SITENAME}} žlugdymo.',
-'delete-warning-toobig'       => 'Šis puslapis turi ilgą keitimų istoriją, daugiau nei $1 versijų. Trinant jis gali sutrikdyti {{SITENAME}} duomenų bazės operacijas; būkite atsargūs.',
+'delete-toobig'               => 'Šis puslapis turi ilgą keitimų istoriją, daugiau nei $1 {{PLURAL:$1|revizija|revizijos|revizijų}}. Tokių puslapių trynimas yra apribotas, kad būtų išvengta atsitiktinio {{SITENAME}} žlugdymo.',
+'delete-warning-toobig'       => 'Šis puslapis turi ilgą keitimų istoriją, daugiau nei $1 {{PLURAL:$1|revizija|revizijos|revizijų}}. Trinant jis gali sutrikdyti {{SITENAME}} duomenų bazės operacijas; būkite atsargūs.',
 'rollback'                    => 'Atmesti keitimus',
 'rollback_short'              => 'Atmesti',
 'rollbacklink'                => 'atmesti',
 'rollbackfailed'              => 'Atmetimas nepavyko',
 'cantrollback'                => 'Negalima atmesti redagavimo; paskutinis keitęs naudotojas yra šio puslapio autorius.',
-'alreadyrolled'               => 'Nepavyko atmesti paskutinio [[User:$2|$2]] ([[User talk:$2|Aptarimas]]) daryto puslapio [[:$1]] keitimo;
+'alreadyrolled'               => 'Nepavyko atmesti paskutinio [[User:$2|$2]] ([[User talk:$2|Aptarimas]] | [[Special:Contributions/$2|{{int:contribslink}}]]) daryto puslapio [[:$1]] keitimo;
 kažkas jau pakeitė puslapį arba suspėjo pirmas atmesti keitimą.
 
-Paskutimas keitimas darytas naudotojo [[User:$3|$3]] ([[User talk:$3|Aptarimas]]).',
+Paskutimas keitimas darytas naudotojo [[User:$3|$3]] ([[User talk:$3|Aptarimas]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Redagavimo komentaras: „<i>$1</i>“.', # only shown if there is an edit comment
 'revertpage'                  => 'Atmestas [[Special:Contributions/$2|$2]] ([[User talk:$2|Aptarimas]]) pakeitimas; sugrąžinta naudotojo [[User:$1|$1]] versija', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Atmesti $1 keitimai; grąžinta į paskutinę $2 versiją.',
@@ -1525,7 +1554,7 @@
 Prašome paspausti „atgal“ ir perkraukite puslapį iš kurio atėjote, ir pamėginkite vėl.',
 'protectlogpage'              => 'Rakinimų istorija',
 'protectlogtext'              => 'Žemiau yra puslapių užrakinimų bei atrakinimų istorija.
-Dabar veikiančių puslapių apsaugų sąrašą rasite [[Special:Protectedpages|apsaugotų puslapių sąraše]].',
+Dabar veikiančių puslapių apsaugų sąrašą rasite [[Special:ProtectedPages|apsaugotų puslapių sąraše]].',
 'protectedarticle'            => 'užrakino „[[$1]]“',
 'modifiedarticleprotection'   => 'pakeistas „[[$1]]“ apsaugos lygis',
 'unprotectedarticle'          => 'atrakino „[[$1]]“',
@@ -1576,6 +1605,7 @@
 'viewdeletedpage'              => 'Rodyti ištrintus puslapius',
 'undeletepagetext'             => 'Žemiau išvardinti puslapiai yra ištrinti, bet dar laikomi
 archyve, todėl jie gali būti atstatyti. Archyvas gali būti periodiškai valomas.',
+'undelete-fieldset-title'      => 'Atstatyti revizijas',
 'undeleteextrahelp'            => "Norėdami atkurti visą puslapį, palikite visas varneles nepažymėtas ir
 spauskite '''''Atkurti'''''. Norėdami atlikti pasirinktinį atstatymą, pažymėkite varneles tų versijų, kurias norėtumėte atstatyti, ir spauskite '''''Atkurti'''''. Paspaudus
 '''''Iš naujo''''' bus išvalytos visos varnelės bei komentaro laukas.",
@@ -1637,7 +1667,7 @@
 
 # What links here
 'whatlinkshere'            => 'Susiję puslapiai',
-'whatlinkshere-title'      => 'Puslapiai, kurie nurodo į $1',
+'whatlinkshere-title'      => 'Puslapiai, kurie nurodo į "$1"',
 'whatlinkshere-page'       => 'Puslapis:',
 'linklistsub'              => '(Nuorodų sąrašas)',
 'linkshere'                => "Šie puslapiai rodo į '''[[:$1]]''':",
@@ -1650,6 +1680,7 @@
 'whatlinkshere-next'       => '$1 {{PLURAL:$1|kitas|kiti|kitų}}',
 'whatlinkshere-links'      => '← nuorodos',
 'whatlinkshere-hideredirs' => '$1 nukreipimus',
+'whatlinkshere-hidetrans'  => '$1 įtraukimus',
 'whatlinkshere-hidelinks'  => '$1 nuorodas',
 'whatlinkshere-hideimages' => '$1 paveikslėlių nuorodos',
 'whatlinkshere-filters'    => 'Filtrai',
@@ -1687,7 +1718,7 @@
 'badipaddress'                => 'Neleistinas IP adresas',
 'blockipsuccesssub'           => 'Užblokavimas pavyko',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] buvo užblokuotas.<br />
-Aplankykite [[Special:Ipblocklist|IP blokavimų istoriją]] norėdami jį peržiūrėti.',
+Aplankykite [[Special:IPBlockList|IP blokavimų istoriją]] norėdami jį peržiūrėti.',
 'ipb-edit-dropdown'           => 'Redaguoti blokavimų priežastis',
 'ipb-unblock-addr'            => 'Atblokuoti $1',
 'ipb-unblock'                 => 'Atblokuoti naudotojo vardą arba IP adresą',
@@ -1720,7 +1751,7 @@
 'blocklogentry'               => 'blokavo [[$1]], blokavimo laikas - $2 $3',
 'blocklogtext'                => 'Čia yra naudotojų blokavimo ir atblokavimo sąrašas.
 Automatiškai blokuoti IP adresai nėra išvardinti.
-Jei norite pamatyti dabar blokuojamus adresus, žiūrėkite [[Special:Ipblocklist|IP blokavimų istoriją]].',
+Jei norite pamatyti dabar blokuojamus adresus, žiūrėkite [[Special:IPBlockList|IP blokavimų istoriją]].',
 'unblocklogentry'             => 'atblokavo $1',
 'block-log-flags-anononly'    => 'tik anoniminiai naudotojai',
 'block-log-flags-nocreate'    => 'paskyrų kūrimas išjungtas',
@@ -1728,6 +1759,7 @@
 'block-log-flags-noemail'     => 'el. paštas užblokuotas',
 'range_block_disabled'        => 'Administratoriaus galimybė kurti intevalinius blokus yra išjungta.',
 'ipb_expiry_invalid'          => 'Galiojimo laikas neleistinas.',
+'ipb_expiry_temp'             => 'Paslėptų naudotojų vardų blokavimas turi būti nuolatinis.',
 'ipb_already_blocked'         => '„$1“ jau užblokuotas',
 'ipb_cant_unblock'            => 'Klaida: Blokavimo ID $1 nerastas. Galbūt jis jau atblokuotas.',
 'ipb_blocked_as_range'        => 'Klaida: IP $1 nebuvo užblokuotas tiesiogiai, tad negali būti atblokuotas. Tačiau jis buvo užblokuotas kaip srities $2 dalis, kuri gali būti atblokuota.',
@@ -1760,7 +1792,7 @@
 'lockdbsuccesssub'    => 'Duomenų bazės užrakinimas pavyko',
 'unlockdbsuccesssub'  => 'Duomenų bazės užrakinimas pašalintas',
 'lockdbsuccesstext'   => 'Duomenų bazė buvo užrakinta.
-<br />Nepamirškite [[Special:Unlockdb|pašalinti užraktą]], kai techninė profilaktika bus baigta.',
+<br />Nepamirškite [[Special:UnlockDB|pašalinti užraktą]], kai techninė profilaktika bus baigta.',
 'unlockdbsuccesstext' => 'Duomenų bazė buvo atrakinta.',
 'lockfilenotwritable' => 'Duomenų bazės užrakto failas nėra įrašomas. Norint užrakinti ar atrakinti duomenų bazę, tinklapio serveris privalo turėti įrašymo teises šiam failui.',
 'databasenotlocked'   => 'Duomenų bazė neužrakinta.',
@@ -1772,8 +1804,8 @@
 neprarasdami jo istorijos.
 Senasis pavadinimas taps nukreipiamuoju - rodys į naująjį.
 Nuorodos į senąjį puslapį nebus automatiškai pakeistos, todėl būtinai
-patikrinkite ar nesukūrėte dvigubų ar
-neveikiančių nukreipimų.
+patikrinkite ar nesukūrėte [[Special:DoubleRedirects|dvigubų]] ar
+[[Special:BrokenRedirects|neveikiančių]] nukreipimų.
 Jūs esate atsakingas už tai, kad nuorodos rodytų į ten, kur ir norėta.
 
 Primename, kad puslapis '''nebus''' pervadintas, jei jau yra puslapis
@@ -1792,13 +1824,12 @@
 
 Šiais atvejais jūs savo nuožiūra turite perkelti arba apjungti aptarimo puslapį.",
 'movearticle'             => 'Pervardinti puslapį:',
-'movenologin'             => 'Neprisijungęs',
-'movenologintext'         => 'Norėdami pervadinti puslapį, turite būti užsiregistravęs naudotojas ir būti  [[Special:Userlogin|prisijungęs]].',
 'movenotallowed'          => 'Jūs neturite teisių pervadinti puslapių šiame projekte.',
 'newtitle'                => 'Naujas pavadinimas:',
 'move-watch'              => 'Stebėti šį puslapį',
 'movepagebtn'             => 'Pervadinti puslapį',
 'pagemovedsub'            => 'Pervadinta sėkmingai',
+'movepage-moved'          => '<big>\'\'\'"$1" buvo pervadintas į "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Puslapis tokiu pavadinimu jau egzistuoja
 arba pasirinktas vardas yra neteisingas.
 Pasirinkite kitą pavadinimą.',
@@ -1808,6 +1839,9 @@
 Prašome sujungti šiuos puslapius.'''",
 'movedto'                 => 'pervardintas į',
 'movetalk'                => 'Perkelti susijusį aptarimo puslapį.',
+'move-subpages'           => 'Perkelti visus subpuslapius, jei tai įmanoma',
+'move-talk-subpages'      => 'Perkelti visus aptarimo subpuslapius, jei tai įmanoma',
+'movepage-page-exists'    => 'Puslapis $1 jau egzistuoja ir negali būti automatiškai perrašytas.',
 'movepage-page-moved'     => 'Puslapis $1 perkeltas į $2.',
 'movepage-page-unmoved'   => 'Puslapio $1 negalima perkelti į $2.',
 '1movedto2'               => '[[$1]] pervadintas į [[$2]]',
@@ -1819,12 +1853,15 @@
 'delete_and_move'         => 'Ištrinti ir perkelti',
 'delete_and_move_text'    => '==Reikalingas ištrynimas==
 
-Paskirties puslapis „[[$1]]“ jau yra. Ar norite jį ištrinti, kad galėtumėte pervardinti?',
+Paskirties puslapis „[[:$1]]“ jau yra. Ar norite jį ištrinti, kad galėtumėte pervardinti?',
 'delete_and_move_confirm' => 'Taip, trinti puslapį',
 'delete_and_move_reason'  => 'Ištrinta dėl perkėlimo',
 'selfmove'                => 'Šaltinio ir paskirties pavadinimai yra tokie patys; negalima pervardinti puslapio į save.',
 'immobile_namespace'      => 'Šaltinio arba paskirties pavadinimas yra specialiojo tipo; negalima pervadinti iš ir į tą vardų sritį.',
 'imagenocrossnamespace'   => 'Negalima pervadinti failo į ne failo vardų sritį',
+'imagetypemismatch'       => 'Naujas failo plėtinys neatitinka jo tipo',
+'imageinvalidfilename'    => 'Failo adreso pavadinimas yra klaidingas',
+'fix-double-redirects'    => 'Atnaujinti peradresavimus, kad šie rodytų į originalų straipsnio pavadinimą',
 
 # Export
 'export'            => 'Eksportuoti puslapius',
@@ -2054,10 +2091,10 @@
 'show-big-image'       => 'Pilna raiška',
 'show-big-image-thumb' => '<small>Šios peržiūros dydis: $1 × $2 taškų</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Naujausių failų galerija',
 'imagelisttext'         => "Žemiau yra '''$1''' {{PLURAL:$1|failo|failų|failų}} sąrašas, surūšiuotas $2.",
-'newimages-summary'     => 'Šis specialus puslapis rodo paskiausiai įkeltus failus',
+'newimages-summary'     => 'Šis specialus puslapis rodo paskiausiai įkeltus failus.',
 'showhidebots'          => '($1 robotus)',
 'noimages'              => 'Nėra ką parodyti.',
 'ilsubmit'              => 'Ieškoti',
@@ -2340,7 +2377,7 @@
 
 # External editor support
 'edit-externally'      => 'Atverti išoriniame redaktoriuje',
-'edit-externally-help' => 'Norėdami gauti daugiau informacijos, žiūrėkite [http://meta.wikimedia.org/wiki/Help:External_editors diegimo instrukcijas].',
+'edit-externally-help' => 'Norėdami gauti daugiau informacijos, žiūrėkite [http://www.mediawiki.org/wiki/Manual:External_editors diegimo instrukcijas].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'visos',
@@ -2409,7 +2446,7 @@
 'recreate'            => 'Atkurti',
 
 # HTML dump
-'redirectingto' => 'Peradresuojama į [[$1]]...',
+'redirectingto' => 'Peradresuojama į [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Išvalyti šio puslapio podėlį?
@@ -2506,7 +2543,7 @@
 'version-software-product'         => 'Produktas',
 'version-software-version'         => 'Versija',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Failo kelias',
 'filepath-page'    => 'Failas:',
 'filepath-submit'  => 'Kelias',
@@ -2544,4 +2581,8 @@
 'specialpages-group-redirects'   => 'Specialieji nukreipimo puslapiai',
 'specialpages-group-spam'        => 'Šlamšto valdymo priemonės',
 
+# Special:BlankPage
+'blankpage'              => 'Tuščias puslapis',
+'intentionallyblankpage' => 'Šis puslapis specialiai paliktas tuščias',
+
 );
Index: languages/messages/MessagesHaw.php
===================================================================
--- languages/messages/MessagesHaw.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHaw.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Singularity
  * @author Kalani
- * @author SPQRobin
  * @author Node ue
- * @author Siebrand
+ * @author Singularity
  */
 
 $messages = array(
@@ -281,6 +279,9 @@
 'italic_tip'      => 'Ho‘ohiō',
 'extlink_tip'     => 'Loulou kūwaho (e ho‘omana‘o i ka poʻo pāʻālua http://)',
 'headline_sample' => 'Po‘o‘ōlelo',
+'math_tip'        => 'Ha‘ilula makemakika (LaTeX)',
+'media_tip'       => 'Loulou waihona',
+'sig_tip'         => 'Kou kākau inoa ame ka manawa',
 'hr_tip'          => 'Laina ‘ilikai (e ho‘ohana pākiko)',
 
 # Edit pages
@@ -300,7 +301,7 @@
 'loginreqlink'           => 'E komo',
 'accmailtitle'           => 'Ua ho‘ouna ‘ia ka hua‘ōlelo huna',
 'newarticle'             => '(Hou)',
-'anontalkpagetext'       => "---''‘O kēia ke kūkākūkā no he mea ho‘ohana ‘a‘ohe i hō‘ike‘ia ka inoa i hana ʻia he mea ho‘ohana ai‘ole ‘a‘ole ho‘ohana ia. Pēlā, e pono mākou ke ho‘ohana ka wahi noho IP e hōʻoia ‘oia. Inā he mea ho‘ohana ‘a‘ohe i hō‘ike‘ia ka inoa ‘oe, ke ho‘olale nei ‘ia ‘oe [[Special:Userlogin|e hana he mea ho‘ohana ai‘ole e komo]].''",
+'anontalkpagetext'       => "---''‘O kēia ke kūkākūkā no he mea ho‘ohana ‘a‘ohe i hō‘ike‘ia ka inoa i hana ʻia he mea ho‘ohana ai‘ole ‘a‘ole ho‘ohana ia. Pēlā, e pono mākou ke ho‘ohana ka wahi noho IP e hōʻoia ‘oia. Inā he mea ho‘ohana ‘a‘ohe i hō‘ike‘ia ka inoa ‘oe, ke ho‘olale nei ‘ia ‘oe [[Special:UserLogin|e hana he mea ho‘ohana ai‘ole e komo]].''",
 'previewnote'            => '<strong>‘O keia ka nāmua;
 ‘a‘ole i mālama ‘ia ka ho‘ololi!</strong>',
 'editing'                => 'Ke ho‘ololi nei iā $1',
@@ -381,7 +382,7 @@
 'filedesc'          => "Hō'ulu'ulu mana'o",
 'fileuploadsummary' => "Hō'ulu'ulu mana'o:",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Inoa',
 
 # Image description page
@@ -414,7 +415,7 @@
 # Special:Log
 'log' => 'Nā mo‘olelo',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Nā ‘ao‘ao loa apau',
 'alphaindexline' => '$1 i $2',
 'allarticles'    => 'Nā mo‘olelo apau loa',
@@ -425,7 +426,7 @@
 # Special:Categories
 'categories' => 'Nā mahele',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Hō‘ike',
 
 # E-mail user
@@ -527,6 +528,7 @@
 'tooltip-n-recentchanges'  => 'Nā loli hou ma ka wiki.',
 'tooltip-n-randompage'     => 'Ho‘ouka i he akikala kaulele',
 'tooltip-n-help'           => 'Ka wahi e kōkua ai iā‘oe.',
+'tooltip-t-whatlinkshere'  => 'Ka papa o nā ‘ao‘ao āpau e loulou mai',
 'tooltip-t-upload'         => 'Ho‘ouka i nā waihona',
 'tooltip-t-specialpages'   => 'Helu o nā papa nui apau',
 'tooltip-ca-nstab-project' => 'Nānā i ka ‘ao‘ao papahana',
@@ -535,7 +537,7 @@
 # Media information
 'show-big-image' => 'Miomio piha',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Huli',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesRif.php
===================================================================
--- languages/messages/MessagesRif.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRif.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -17,8 +17,8 @@
 'thu'           => 'Akwas',
 'fri'           => 'Asimwas',
 'sat'           => 'Asiḍyas',
-'january'       => 'Yannayr',
-'february'      => 'Yebrayr',
+'january'       => 'Yannayer',
+'february'      => 'Yebrayer',
 'march'         => 'Mars',
 'april'         => 'Yebrir',
 'may_long'      => 'Mayu',
@@ -29,8 +29,8 @@
 'october'       => 'Ktubr',
 'november'      => 'Nuwanbir',
 'december'      => 'Dujanbir',
-'january-gen'   => 'Yannayr',
-'february-gen'  => 'Yebrayr',
+'january-gen'   => 'Yannayer',
+'february-gen'  => 'Yebrayer',
 'march-gen'     => 'Mars',
 'april-gen'     => 'Yebrir',
 'may-gen'       => 'Mayu',
@@ -41,8 +41,8 @@
 'october-gen'   => 'Ktubr',
 'november-gen'  => 'Nuwanbir',
 'december-gen'  => 'Dujanbir',
-'jan'           => 'Yannayr',
-'feb'           => 'Yebrayr',
+'jan'           => 'Yannayer',
+'feb'           => 'Yebrayer',
 'mar'           => 'Mars',
 'apr'           => 'Yebrir',
 'may'           => 'Mayu',
@@ -57,20 +57,20 @@
 # Categories related messages
 'category_header'        => 'Tisebtar di Taggayt "$1"',
 'subcategories'          => 'Tadu-ggayin',
-'category-media-header'  => 'imediaten di ucategory "$1"',
+'category-media-header'  => 'Media di category "$1"',
 'listingcontinuesabbrev' => 'Amesedfar.',
 
-'about'          => 'Xf',
-'newwindow'      => '(Areẓm di tburjet ttamaynut)',
+'about'          => 'Xeff',
+'newwindow'      => '(Areẓm di tburjet d-tamaynut)',
 'cancel'         => 'ur tegg ca',
 'qbfind'         => 'Aff',
 'qbedit'         => 'Ẓreg',
 'qbspecialpages' => 'Tudmawin Special',
-'mytalk'         => 'Awal inu',
+'mytalk'         => 'Asiwl inu',
 'navigation'     => 'Asari',
 
 'errorpagetitle'   => 'Anezri',
-'returnto'         => 'Dwal ɣa $1.',
+'returnto'         => 'Dwal ɣar $1.',
 'tagline'          => 'Zi {{SITENAME}}',
 'help'             => 'Tallalt',
 'search'           => 'Tarezzut',
@@ -80,19 +80,19 @@
 'history'          => 'Amzruy n tsebtert',
 'history_short'    => 'Amzruy',
 'printableversion' => 'Talqemt n usiggez',
-'permalink'        => 'Tazdayt d tamɣlalt',
+'permalink'        => 'Tazdayt war tbeddil',
 'edit'             => 'Ẓreg',
 'editthispage'     => 'Ẓreg Tasebtert a',
 'delete'           => 'Kkes',
 'protect'          => 'ẓarq',
-'newpage'          => 'Tasebtert ttamaynut',
+'newpage'          => 'Tasebtert d-tamaynut',
 'talkpage'         => 'siwl x Tasebtert a',
 'talkpagelinktext' => 'Awal',
 'personaltools'    => 'imassen inu',
 'talk'             => 'Asiwl',
 'views'            => 'Tiẓritin',
 'toolbox'          => 'imassen',
-'redirectedfrom'   => '(i twassek-d zi $1)',
+'redirectedfrom'   => '(i twassek-ad zi $1)',
 'redirectpagesub'  => 'Tasebtert n (Redirect)',
 'jumpto'           => 'Ndu ɣa:',
 'jumptonavigation' => 'Asari',
@@ -103,7 +103,7 @@
 'aboutpage'            => 'Project:Xeff',
 'copyrightpage'        => '{{ns:project}}:izrefan ussenɣel',
 'currentevents'        => 'Mayn itemsaren rux',
-'currentevents-url'    => 'Project:mayn itmesaren rux',
+'currentevents-url'    => 'Project:mayn itmesaren ruxa',
 'disclaimers'          => 'Unnuten',
 'disclaimerpage'       => 'Project:unnuten n umatu',
 'edithelp'             => 'Tallalt deg uẓareg',
@@ -113,8 +113,8 @@
 'mainpage-description' => 'Tasebtert Tamzwarut',
 'portal'               => 'Tawwart n timetti(Community)',
 'portal-url'           => 'Project:tawwart n timetti(Community)',
-'privacy'              => 'tasligt',
-'privacypage'          => 'Project:tasligt',
+'privacy'              => 'Tasrtit n tusligt',
+'privacypage'          => 'Project:Tasrtit n tusligt',
 
 'retrievedfrom'       => 'itwar-d zi "$1"',
 'youhavenewmessages'  => 'ɣak $1 ($2).',
@@ -146,10 +146,10 @@
 # Login and logout pages
 'yourname'                => 'isem useqdac:',
 'yourpassword'            => 'Tawalt uεeddu:',
-'remembermypassword'      => 'Ajj login inu deg uselkim(computer) a',
+'remembermypassword'      => 'ejj (login) inu deg uselkim a',
 'login'                   => 'Adeff',
 'nav-login-createaccount' => 'Adeff / egg amiḍan',
-'loginprompt'             => 'itxessa a ṭeṭfeḍ cookies bac ad tadfed ɣa {{SITENAME}}.',
+'loginprompt'             => 'You must have cookies enabled to [[Special:UserLogin|log in to {{SITENAME}}]].',
 'userlogin'               => 'Adeff / egg amiḍan',
 'logout'                  => 'Ffeɣ',
 'userlogout'              => 'Ffeɣ',
@@ -171,69 +171,79 @@
 'wrongpassword'           => 'Tawalt n uεddu war tceni ca. Sideff tenni nican.',
 'wrongpasswordempty'      => 'Tawalt n uεddu i tucid texwa. Sideff tenni nican.',
 'passwordtooshort'        => 'Tawalt n uεeddu inec war d tusi ca.
-itxessa tt a dis yili bεeda {{PLURAL:$1|1 usekkil|$1 isekkilen}} u ad tili temṣebda x isem n useqdac inec.',
+itxessat ad di-s tili {{PLURAL:$1|1 usekkil|$1 isekkilen}} u ad tili temṣebda x isem n useqdac inec.',
 'mailmypassword'          => 'Sekk tawalt n uεddu di E-mail',
-'passwordremindertitle'   => 'Tawalt n εuddu tamaynut n rux waha {{SITENAME}}',
-'noemail'                 => 'War illi ca n e-mail ɣa wseqdac a "$1".',
+'passwordremindertitle'   => 'Tawalt n εuddu tamaynut n ruxa waha {{SITENAME}}',
+'noemail'                 => 'War illi ca n e-mail ɣar useqdac a "$1".',
 'passwordsent'            => 'Tawalt n εuddu tamaynut twassekked i e-mail  "$1".
-adeff-d xmi ɣa tetfed.',
+adeff-d xmi ad-tetfed.',
 
 # Edit page toolbar
-'bold_sample'    => 'Tirra ttiqebbuzin',
-'bold_tip'       => 'Tirra ttiqebbuzin',
+'bold_sample'    => 'Tirra d-tiqebbuzin',
+'bold_tip'       => 'Tirra d-tiqebbuzin',
 'italic_sample'  => 'Tirra titalyanin',
 'italic_tip'     => 'Tirra titalyanin',
 'link_sample'    => 'isem n tzedayt',
-'link_tip'       => 'Tazdayt n ddixl',
+'link_tip'       => 'Tazdayt n dixl',
 'extlink_sample' => 'http://www.example.com isem n tezdayt',
 'extlink_tip'    => 'Tazdayt n baṛṛa (qa tettud http:// prefix)',
 'math_sample'    => 'Egg ijj n formula da',
-'math_tip'       => 'Tasemselt tusnakt (LaTeX)',
+'math_tip'       => 'Mathematical formula (LaTeX)',
 'nowiki_sample'  => 'Sideff da tirra bla taseddast(formatting) n wiki',
 'nowiki_tip'     => 'Ur tawi x taseddast(formatting) n wiki',
 'image_tip'      => 'Afaylu war-itmesebḍi',
 'media_tip'      => 'Tazdayt ufaylu',
-'sig_tip'        => 'Azewl(signature) inec ag Lwaqt .',
+'sig_tip'        => 'Azewl(signature) inec ag ukud(time) .',
 
 # Edit pages
 'summary'                => 'Asgeber',
-'minoredit'              => 'Ta d taẓrigt ttamẓeyant',
+'subject'                => 'Subject/headline',
+'minoredit'              => 'Ta d taẓrigt d-tamẓeyant',
 'watchthis'              => 'Ẓar tasebtert a',
 'savearticle'            => 'Ḥaḍ Tasebtert',
 'preview'                => 'Azar-ascan',
 'showpreview'            => 'Ẓar Azar-ascan',
 'showdiff'               => 'Semmel-ad mayn teẓregd.',
-'anoneditwarning'        => "'''aya-ɣak:''' war tudifd ca s isem inec.
+'anoneditwarning'        => "'''ɣark:''' war tudifd ca s isem inec.
 Tansa n IP inac ad-iqqim deg umezruy n teẓrigin n tsebtert a .",
 'summary-preview'        => 'Azar-ascan n ugzul',
 'newarticle'             => '(Amaynu)',
-'newarticletext'         => "Tdefar-d tazdayt n tsebtert εad war telli .
-bac attegged , arri di taflwit a swadday (xemm i [[{{MediaWiki:Helppage}}| Tasebtert Tallalt]] i ktar n inɣmisen).
-mala qacek da s ɣalaṭ waha, tecca di tbutunt n '''deffar''' di browser inec .",
+'newarticletext'         => "You have followed a link to a page that does not exist yet.
+To create the page, start typing in the box below (see the [[{{MediaWiki:Helppage}}|help page]] for more info).
+If you are here by mistake, click your browser's '''back''' button.",
 'noarticletext'          => 'walu tirra di tsebtert a , tzemred [[Special:Search/{{PAGENAME}}|a tarzud isem n tsebtert a]] di tisebtar nniḍn niɣ [{{fullurl:{{FULLPAGENAME}}|action=edit}} egg tsebtert a cek].',
 'previewnote'            => '<strong>Wa d Azar-ascan waha;
 tiẓrigin εad war twaḥḍent!</strong>',
 'editing'                => 'Aẓreg di $1',
 'editingsection'         => 'Aẓrag  di $1 (tigezmi)',
+'copyrightwarning'       => 'Please note that all contributions to {{SITENAME}} are considered to be released under the $2 (see $1 for details).
+If you do not want your writing to be edited mercilessly and redistributed at will, then do not submit it here.<br />
+You are also promising us that you wrote this yourself, or copied it from a public domain or similar free resource.
+<strong>DO NOT SUBMIT COPYRIGHTED WORK WITHOUT PERMISSION!</strong>',
 'templatesused'          => 'Timudmiwin itwaggen di tsebtert a:',
 'templatesusedpreview'   => 'Timudmiwin igg itwasxdemen dg uzar-ascan a :',
 'template-protected'     => '(twaḥḍa)',
-'template-semiprotected' => '(tuẓgen-ẓarq)',
+'template-semiprotected' => '(semi-protected)',
+'nocreatetext'           => '{{SITENAME}} war iqqim ca itejja iwdan ad ggen tisebtar timaynutin.
+tzemred addewred ɣar deffar, niɣ [[Special:UserLogin|Adeff niɣ egg amiḍan]].',
 
 # History pages
-'viewpagelogs'     => 'Ẓar aɣmis n tsebtert a',
-'currentrev'       => 'Afegged n ruxa',
-'revisionasof'     => 'Affegged am $1',
-'previousrevision' => '←Affegged n zic',
-'cur'              => 'N rux',
-'last'             => 'anggaru',
-'page_first'       => 'amzwaru',
-'page_last'        => 'anggaru',
-'histfirst'        => 'Amzwaru qaε',
-'histlast'         => 'Anggaru qaε',
+'viewpagelogs'        => 'Ẓar aɣmis n tsebtert a',
+'currentrev'          => 'Afegged n ruxa',
+'revisionasof'        => 'Affegged am $1',
+'revision-info'       => 'Afegged am $1 s $2',
+'previousrevision'    => '←Affegged n zik/zic',
+'nextrevision'        => 'Afegged d amaynu→',
+'currentrevisionlink' => 'Afegged n rux',
+'cur'                 => 'N ruxa',
+'last'                => 'anggaru',
+'page_first'          => 'amzwaru',
+'page_last'           => 'anggaru',
+'histfirst'           => 'Amzwaru qaε',
+'histlast'            => 'Anggaru qaε',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 ɣa $2', # user at time
+'history-feed-item-nocomment' => '$1 ɣar $2', # user at time
 
 # Diffs
 'history-title'           => 'Amezruy n ufegged n "$1"',
@@ -243,8 +253,8 @@
 'editundo'                => 'Dwel',
 
 # Search results
-'noexactmatch' => "'''war tlli ca n tsebtert qarn-as \"\$1\".'''
-tzemred ad [[:\$1|tt-arnid cek]].",
+'noexactmatch' => "'''war telli ca n tsebtert qarn-as \"\$1\".'''
+tzemred ad [[:\$1|tarnid cek]].",
 'prevn'        => 'ẓẓat $1',
 'nextn'        => 'ẓẓffar $1',
 'viewprevnext' => 'Ẓar ($1) ($2) ($3)',
@@ -263,35 +273,35 @@
 'grouppage-sysop' => '{{ns:project}}:inedbalen',
 
 # User rights log
-'rightslog' => 'Aɣmis n izerfan n user',
+'rightslog' => 'Aɣmis n izerfan n useqdac',
 
 # Recent changes
 'nchanges'                       => '$1 {{PLURAL:$1|tiẓregt|tiẓrigin}}',
 'recentchanges'                  => 'Tiẓrigin tinggura',
-'recentchanges-feed-description' => 'Bbar tiẓrigin timayutin di wiki dg usudem a .',
+'recentchanges-feed-description' => 'Bbar tiẓrigin timayutin di wiki deg usudem(feed) a .',
 'rcnote'                         => "Awadday {{PLURAL:$1|d '''1''' taẓarigt|d '''$1''' tiẓrigin tinggura}} deg {{PLURAL:$2|ass anggaru |'''$2''' ussan inggura}}, am di $5, $4.",
-'rcnotefrom'                     => "ɣa wadday d tiẓrigin zi '''$2''' (ar '''$1''' ttewamlent-id).",
-'rclistfrom'                     => 'Semml-d tiẓrigin timaynutin ig ibeddan zi $1',
-'rcshowhideminor'                => '$1 tiẓrigin ttimeẓyanin',
-'rcshowhidebots'                 => '$1 iroboten',
+'rcnotefrom'                     => "ɣa wadday d tiẓrigin zi '''$2''' (ar '''$1''' ).",
+'rclistfrom'                     => 'Semml-ad tiẓrigin timaynutin ig ibeddan zi $1',
+'rcshowhideminor'                => '$1 tiẓrigin d-timeẓyanin',
+'rcshowhidebots'                 => '$1 iroboten(robots)',
 'rcshowhideliu'                  => '$1 users ig yudeffen',
 'rcshowhideanons'                => '$1 users war twasnen',
 'rcshowhidemine'                 => '$1 tiẓrigin inu',
-'rclinks'                        => 'Mmel-d $1 tiẓrigin tinggura di $2 n wussan inggura <br />$3',
+'rclinks'                        => 'Mmel-ad $1 tiẓrigin tinggura di $2 n ussan inggura <br />$3',
 'diff'                           => 'imṣebḍan',
 'hist'                           => 'Amezruy',
 'hide'                           => 'Snuffar',
-'show'                           => 'smmel-d',
+'show'                           => 'smmel-ad',
 'minoreditletter'                => 'm',
 'newpageletter'                  => 'N',
 'boteditletter'                  => 'b',
 
 # Recent changes linked
 'recentchangeslinked'          => 'Tiẓrigin ag ta',
-'recentchangeslinked-title'    => 'Tiẓrigin ssaɣan-d ɣa "$1"',
-'recentchangeslinked-noresult' => 'War llint ca n tiẓrigin di tsebtert a di lwaqt i d tucid .',
-'recentchangeslinked-summary'  => "Ta d Tabdart n tirra ytwaggen εad mamc di tsebtert i d-yzdin (ytwaqnen) zg ijjen n Tsebtert nnaḍni (niɣ iwdan zi category nnḍni).
-Tisebtar di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''bold'''.",
+'recentchangeslinked-title'    => 'Tiẓrigin ssaɣant-id ɣa "$1"',
+'recentchangeslinked-noresult' => 'War llint ca n tiẓrigin di tsebtert a di lwaqt id-tucid .',
+'recentchangeslinked-summary'  => "Ta d Tabdart n tirra itwaggen εad mamc di tsebtert id-izdin (iqnen) zg ijjen n Tsebtert nniḍn (niɣ iwdan zi category nniḍn).
+Tisebtar di [[Special:Watchlist|Tabdart uḥṭṭu inec]] d '''tiqebbuzin'''.",
 
 # Upload
 'upload'            => 'Zdem-d afaylu',
@@ -302,12 +312,12 @@
 'uploadedimage'     => 'itwazdem-d "[[$1]]"',
 'watchthisupload'   => 'Xm tasbtirt a',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Tabdart n ifayluten',
 
 # Image description page
 'filehist'                  => 'Amzruy n ufaylu',
-'filehist-help'             => 'Tecca di date/time bac atẓerd afaylu mamec ja d-itban di Lwaqt a .',
+'filehist-help'             => 'Tka di date/time bac ad tẓerd afaylu mamec ja d-itban di Lwaqt a .',
 'filehist-deleteone'        => 'sfaḍ',
 'filehist-current'          => 'Lux a',
 'filehist-datetime'         => 'Azemz/Akud',
@@ -316,11 +326,11 @@
 'filehist-filesize'         => 'Tiddi n ufaylu',
 'filehist-comment'          => 'Tinit',
 'imagelinks'                => 'Tizdayin',
-'linkstoimage'              => '{{PLURAL:$1|tasebtert a teqned|$1 Tisebtar a qnent-id}} ɣa wfaylu ya :',
-'nolinkstoimage'            => 'war telli ca n tsebtert teqqen-d ɣa wfaylu ya.',
+'linkstoimage'              => '{{PLURAL:$1|tasebtert a teqn-ad|$1 Tisebtar a qnent-id}} ɣa ufaylu ya :',
+'nolinkstoimage'            => 'war telli ca n tsebtert teqqen-d ɣa ufaylu ya.',
 'sharedupload'              => 'Wa d ijj ufaylu itwacrec jar aṭṭas n isenfaren(projects).',
-'noimage'                   => 'war illi ca n ufaylu s isem a , tzemred at $1.',
-'noimage-linktext'          => 'Zdem-it id',
+'noimage'                   => 'war illi ca n ufaylu s isem a , tzemred ad $1.',
+'noimage-linktext'          => 'Zdem-it-id',
 'uploadnewversion-linktext' => 'Zdem-d talqemt d tamaynut n ufaylu a',
 
 # File deletion
@@ -344,8 +354,10 @@
 'withoutinterwiki'        => 'Tasebtert bla tiẓdayin n tutlayt',
 'withoutinterwiki-submit' => 'Smmrad',
 
+'fewestrevisions' => 'Tisebtar s cwayt n ifeggiden',
+
 # Miscellaneous special pages
-'nbytes'                  => '$1 {{PLURAL:$1|atamanḍ|itamḍanen}}',
+'nbytes'                  => '$1 {{PLURAL:$1|atamḍan|itamḍanen}}',
 'nlinks'                  => '$1 {{PLURAL:$1|Tazdayt|Tizdayin}}',
 'nmembers'                => '$1 {{PLURAL:$1|amaslad|imasladen}}',
 'lonelypages'             => 'Tisebtar tiyujilin',
@@ -356,12 +368,12 @@
 'unusedcategories'        => 'Taggayin war twasxedment ca',
 'unusedimages'            => 'ifayluten war twasxedmen',
 'wantedcategories'        => 'Taggayin twaxsent',
-'wantedpages'             => 'Tisebtar ttewaxsent aṭṭas',
-'mostlinked'              => 'Tisebtar iɣa-ad ttewaqqenen aṭṭas',
-'mostlinkedcategories'    => 'Taggayin iɣa-ad ttewaqqenen aṭṭas',
-'mostlinkedtemplates'     => 'Timudmiwin iɣa d tewaqqenen aṭṭas',
-'mostcategories'          => 'Tasebtert iɣa ylla taggayin aṭṭas',
-'mostimages'              => 'ifayluten iɣa d tewaqqenen aṭṭas',
+'wantedpages'             => 'Tisebtar tewaxsent aṭṭas',
+'mostlinked'              => 'Tisebtar iɣar-d tewaqqenen aṭṭas',
+'mostlinkedcategories'    => 'Taggayin iɣar-d tewaqqenen aṭṭas',
+'mostlinkedtemplates'     => 'Timudmiwin iɣar-d tewaqqenen aṭṭas',
+'mostcategories'          => 'Tasebtert iɣar llan taggayin aṭṭas',
+'mostimages'              => 'ifayluten iɣar-d tewaqqenen aṭṭas',
 'shortpages'              => 'Tasebtert d taqudat',
 'longpages'               => 'Tisebtar ttizirarin',
 'protectedpages'          => 'Tisebtar ẓarqent',
@@ -382,19 +394,19 @@
 'all-logs-page'        => 'Maṛṛa iɣmisen',
 'log-search-submit'    => 'Raḥ ɣa',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Maṛṛa Tisebtar',
 'alphaindexline' => '$1 ɣa $2',
 'nextpage'       => 'Tasebtert ẓẓat ($1)',
 'prevpage'       => 'Tasebtert Ẓẓat ($1)',
-'allpagesfrom'   => 'Scan-d tisebetar beddant zi:',
+'allpagesfrom'   => 'Scan-ad tisebetar beddant zi:',
 'allarticles'    => 'Maṛṛa Tisebtar',
 'allpagessubmit' => 'Raḥ ɣa',
 
 # Special:Categories
 'categories' => 'Taggayin',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Smmrad',
 
 # E-mail user
@@ -404,13 +416,13 @@
 'watchlist'            => 'Tabdart uḥṭṭu inu',
 'mywatchlist'          => 'Tabdart uḥṭṭu inu',
 'watchlistfor'         => "(i '''$1''')",
-'addedwatch'           => 'Temmarni ɣa Tabdart uḥṭṭu',
+'addedwatch'           => 'Temmarni ɣar Tabdart uḥṭṭu',
 'removedwatch'         => 'twakkes zi Tabdart uḥṭṭu',
-'removedwatchtext'     => 'Tasebtert "[[:$1]]" twakkes zi Tabdart uḥṭṭu inec.',
+'removedwatchtext'     => 'Tasebtert "[[:$1]]" twakkes zi [[Special:Watchlist|Tabdart uḥṭṭu inec]].',
 'watch'                => 'Ẓar',
 'watchthispage'        => 'Ẓar tasebtert a',
 'unwatch'              => 'War-twaẓer',
-'wlshowlast'           => 'Sseml-d $1 tisεεatin $2 ussan $3 inggura',
+'wlshowlast'           => 'Sseml-ad $1 tisεεatin $2 ussan $3 inggura',
 'watchlist-hide-bots'  => 'Senuffar tiẓrigin n urobot',
 'watchlist-hide-own'   => 'Snuffar tiẓrigin inu',
 'watchlist-hide-minor' => 'Senuffar tiẓrigin timeẓyanin',
@@ -422,7 +434,7 @@
 # Delete/protect/revert
 'deletepage'                  => 'kkes tasebtert',
 'delete-legend'               => 'Sfaḍ',
-'historywarning'              => 'Aya-ɣak: tasebtert i txisd atekesd ɣars amzruy :',
+'historywarning'              => 'ɣark: tasebtert i txisd atekesd ɣars amzruy :',
 'actioncomplete'              => 'Tiggawt tsala',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" Twakkes.
 Xemm $2 i tikkas timaynutin.',
@@ -431,13 +443,16 @@
 'deletecomment'               => 'Mayemmi ɣa tteksed:',
 'deleteotherreason'           => 'Ca n ssebba nniḍn:',
 'deletereasonotherlist'       => 'Ssebba nniḍn',
-'rollbacklink'                => 'Ar-d',
+'rollbacklink'                => 'Ar-ad',
 'protectlogpage'              => 'Aɣmis n uẓarq',
 'protectcomment'              => 'Tinit:',
 'protectexpiry'               => 'itsala:',
 'protect_expiry_invalid'      => 'Akud n usali war icni ca.',
 'protect_expiry_old'          => 'Akud usali yeεda.',
 'protect-unchain'             => 'Arzem ipirmiyen n usnaqel',
+'protect-text'                => 'tezemred ad teẓred u atbedeld aswir n uḥeṭṭu n tsebtert a da <strong><nowiki>$1</nowiki></strong>.',
+'protect-locked-access'       => 'Amiḍan inecc war ɣars pirmi bac ad ibeddel aswir n uḥeṭṭu n tsebtert .
+Aqa (settings) n tsebtert <strong>$1</strong>:',
 'protect-default'             => '(amzwar)',
 'protect-fallback'            => 'itxessat "$1"',
 'protect-level-autoconfirmed' => 'Bluka iseqdacen war ɣasen ca amiḍan',
@@ -453,7 +468,7 @@
 'restriction-edit' => 'Arri',
 
 # Undelete
-'undeletebtn'            => 'Ar-d',
+'undeletebtn'            => 'Ar-ad',
 'undelete-search-submit' => 'Tarzzut',
 
 # Namespace form on various pages
@@ -464,17 +479,17 @@
 'contributions' => 'Tiggawin n useqdac',
 'mycontris'     => 'Tiggawin inu',
 'contribsub2'   => 'i $1 ($2)',
-'uctop'         => '(g°jnna)',
-'month'         => 'Zg yur (ar amzwaru):',
-'year'          => 'Zi asggas (d zik):',
+'uctop'         => '(ajnna)',
+'month'         => 'Zeg ayur (ar amzwaru):',
+'year'          => 'Zi asgg°as (d zik):',
 
 'sp-contributions-newbies-sub' => 'i imiḍan imaynuten',
 'sp-contributions-blocklog'    => 'Aɣmis n iẓariqqen',
 'sp-contributions-submit'      => 'Tarzzut',
 
 # What links here
-'whatlinkshere'       => 'Mayn i d-yzdin (ggin tazdayt) da',
-'whatlinkshere-title' => 'Tisebtar id-izdin(iqnen) ɣa $1',
+'whatlinkshere'       => 'Mayn id-izdin (iqnen) da',
+'whatlinkshere-title' => 'Tisebtar id-izdin(iqnen) ɣar "$1"',
 'linklistsub'         => '(Tabdart n tizdayin)',
 'linkshere'           => "Tasebtert a tzedi(teqqen) ɣa '''[[:$1]]''':",
 'nolinkshere'         => "war tlli ca n tsebtert tqqen-d da '''[[:$1]]'''.",
@@ -487,20 +502,21 @@
 # Block/unblock
 'blockip'            => 'Bluka aseqdac a',
 'ipboptions'         => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite', # display1:time1,display2:time2,...
-'ipblocklist'        => 'Tabdart n tansiwin IP d isemawen n iseqdacen igi tteblukan',
+'ipblocklist'        => 'Tabdart n tansiwin IP d isemawen n iseqdacen ig iteblukan',
 'ipblocklist-submit' => 'Tarzzut',
 'blocklink'          => 'Ẓareqq',
 'unblocklink'        => 'Arzem',
 'contribslink'       => 'Tiggawin',
 'blocklogpage'       => 'Ẓareqq aɣmis',
+'blocklogentry'      => 'ibloka [[$1]] ar $2 $3',
 
 # Move page
 'movearticle'    => 'Snaqel tasebtert:',
-'newtitle'       => 'ɣa isem amaynu:',
+'newtitle'       => 'ɣar isem amaynu:',
 'move-watch'     => 'Ẓar tasebtert a',
 'movepagebtn'    => 'Snaqel tudemt',
 'pagemovedsub'   => 'Asnaqel itwagg',
-'movepage-moved' => '<big>\'\'\'"$1" twanql ɣa "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved' => '<big>\'\'\'"$1" twanql ɣar "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'  => 'Tasebtert s isem a tella da, niɣ isem itucid war icni.
 ixdar isem nniḍn.',
 'talkexists'     => "'''Tasebtert s ixf ins twanql , maca tasebtert n usiwl ins war twanqel ca maymmi qaddin ict nninḍ.
@@ -520,37 +536,37 @@
 
 # Thumbnails
 'thumbnail-more'  => 'Semɣar',
-'thumbnail_error' => 'war ttewagg ca tawlaft-tamẓyant (thumbnail): $1',
+'thumbnail_error' => 'Error creating thumbnail: $1',
 
 # Import log
-'importlogpage' => 'Kter-d aɣmis',
+'importlogpage' => 'Siri-d aɣmis',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Tasebtert inu',
 'tooltip-pt-mytalk'               => 'Tasebtert usiwl inu',
 'tooltip-pt-preferences'          => 'iɣewwaren inu',
-'tooltip-pt-watchlist'            => 'Tabdart n Tsebtar umi txmamd bac aten teẓregd',
+'tooltip-pt-watchlist'            => 'Tabdart n Tsebtar umi txmamd bac ad-ten teẓregd',
 'tooltip-pt-mycontris'            => 'Tabdart n tiggawin inu',
 'tooltip-pt-login'                => 'Neqqar-ac adeff, macca war illi bessif .',
 'tooltip-pt-logout'               => 'Ffeɣ',
-'tooltip-ca-talk'                 => 'Asiwl x mayn dis di Tsebtert',
-'tooltip-ca-edit'                 => 'Tzemred at-ẓerged Tasebtert a. Tca x aẓat-ẓari  button ẓẓat ma tteḥḥaḍeḍ .',
-'tooltip-ca-addsection'           => 'Arni tinit dg usiwl a.',
-'tooltip-ca-viewsource'           => 'Tasebtert a tẓarq. tzemred atẓred aɣbal nnes.',
+'tooltip-ca-talk'                 => 'Asiwl x mayn di-s di Tsebtert',
+'tooltip-ca-edit'                 => 'Tzemred ad tẓerged Tasebtert a. Tca x tabutunt(button) n Azar-ascan ẓẓat ma ad teḥḥaḍeḍ .',
+'tooltip-ca-addsection'           => 'Arni tinit deg usiwl a.',
+'tooltip-ca-viewsource'           => 'Tasebtert a tẓarq. tzemred atẓred aɣbal ines.',
 'tooltip-ca-protect'              => 'Ẓarq tasebtert a',
 'tooltip-ca-delete'               => 'Kkes Tasebtert a',
 'tooltip-ca-move'                 => 'Snaql Tasebtert a',
-'tooltip-ca-watch'                => 'Arni tasebtert a ɣa Tebdart uḥṭṭu inec',
+'tooltip-ca-watch'                => 'Arni tasebtert a ɣar Tebdart uḥṭṭu inec',
 'tooltip-ca-unwatch'              => 'Kkes tasebtert a zi Tabdart uḥṭṭu inec',
 'tooltip-search'                  => 'Tarezzut {{SITENAME}}',
 'tooltip-p-logo'                  => 'Tasbtirt Tamzwarut',
-'tooltip-n-mainpage'              => 'Raḥ ɣa Tsebtert Tamzwarut',
+'tooltip-n-mainpage'              => 'Raḥ ɣar Tasebtert Tamzwarut',
 'tooltip-n-portal'                => 'Xeff usenfar, mayn tezmerd ad tegged, mani ɣa tafed tilɣa',
-'tooltip-n-currentevents'         => 'Aff tilɣa x manaya',
+'tooltip-n-currentevents'         => 'Aff tilɣa(information) x manaya',
 'tooltip-n-recentchanges'         => 'Tabdart n teẓrigin timaynutin di wiki.',
 'tooltip-n-randompage'            => 'Ẓar Tasebtert zi ṭṭarf',
 'tooltip-n-help'                  => 'Raq di ɣa tafd.',
-'tooltip-t-whatlinkshere'         => 'Tabdart n maṛṛa Tisebtar n wiki i d-yzdin (qnen) da',
+'tooltip-t-whatlinkshere'         => 'Tabdart n maṛṛa Tisebtar n wiki id-izdin (iqnen) da',
 'tooltip-t-contributions'         => 'Ẓar Tabdart n tiggawin n useqdac a',
 'tooltip-t-emailuser'             => 'Sekk e-mail i bnadem a',
 'tooltip-t-upload'                => 'Zdem-d ifayluten',
@@ -561,10 +577,10 @@
 'tooltip-ca-nstab-template'       => 'Ẓar Tamudemt',
 'tooltip-ca-nstab-help'           => 'Ẓar Tasebtert n tallalt',
 'tooltip-ca-nstab-category'       => 'Ẓar Tasebtert n taggayt(category)',
-'tooltip-minoredit'               => 'egg-it am taẓrigt ttamẓyant',
+'tooltip-minoredit'               => 'egg-it am taẓrigt d-tamẓyant',
 'tooltip-save'                    => 'Ḥaḍ-itt',
-'tooltip-preview'                 => 'Ẓar mayn turid, ẓẓat ma ttssidfad!',
-'tooltip-diff'                    => 'Semmel-d tiẓrigin i teggid di tarrat a.',
+'tooltip-preview'                 => 'Ẓar mayn turid, ẓẓat ma ad teḥḥaḍeḍ!',
+'tooltip-diff'                    => 'Semmel-ad tiẓrigin i teggid di tarrat a.',
 'tooltip-compareselectedversions' => 'Ẓar imsebeḍiyen jar Tilqimin a di Tasebtert a.',
 'tooltip-watch'                   => 'Arni tasebtert a ɣa Tabdart uḥṭṭu inec',
 
@@ -579,16 +595,16 @@
 'show-big-image'       => 'Resolution ameqran',
 'show-big-image-thumb' => '<small>Tiddi n uzar-ascan: $1 × $2 pixel </small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Amewlaf n ifayluten imaynuten',
 'ilsubmit'  => 'Tarzzut',
 
 # Bad image list
-'bad_image_list' => 'Tameslayt amya :
+'bad_image_list' => 'The format is as follows:
 
-imagraden n tebdart (ɣasent * g umzwaru) ig iteten waha.
-Tazdayt tamzwarut di tebrit ixessa atzdi ɣa afaylu war icni  .
-kur tazdayt tdeffad a tmekkas .',
+Only list items (lines starting with *) are considered.
+The first link on a line must be a link to a bad file.
+Any subsequent links on the same line are considered to be exceptions, i.e. pages where the file may occur inline.',
 
 # Metadata
 'metadata'          => 'adfer-sefku',
@@ -597,7 +613,7 @@
 
 # External editor support
 'edit-externally'      => 'Ẓreg afaylu a s usnas zi baṛṛa',
-'edit-externally-help' => 'Xemm [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] i bezzaf n inemiɣsen.',
+'edit-externally-help' => 'Xemm [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] i bezzaf n inemiɣsen.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'maṛṛa',
@@ -613,7 +629,7 @@
 'table_pager_limit_submit' => 'Raḥ ɣa',
 
 # Watchlist editing tools
-'watchlisttools-view' => 'Sicen ibeddilen i ssaɣan ɣa wayawya',
+'watchlisttools-view' => 'Sicen ibeddilen i ssaɣan ɣar wayawya',
 'watchlisttools-edit' => 'Ẓar d tẓregd Tabdart uḥṭṭu',
 'watchlisttools-raw'  => 'Ẓreg Tabdart uḥṭṭu tamenzut',
 
Index: languages/messages/MessagesHy.php
===================================================================
--- languages/messages/MessagesHy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
+ * @author Ruben Vardanyan (me@RubenVardanyan.com)
  * @author Teak
  * @author Togaed
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Ruben Vardanyan (me@RubenVardanyan.com)
  */
 
 $separatorTransformTable = array(
@@ -545,7 +543,7 @@
 'nosuchspecialpage' => 'Նման սպասարկող էջ չկա',
 'nospecialpagetext' => "<big>'''Ձեր հայցված սպասարկող էջը գոյություն չունի։'''</big>
 
-Տեսեք [[Special:Specialpages|սպասարկող էջերի ցանկը]]։",
+Տեսեք [[Special:SpecialPages|սպասարկող էջերի ցանկը]]։",
 
 # General errors
 'error'                => 'Սխալ',
@@ -761,10 +759,6 @@
 'blockededitsource'         => "«'''$1'''» էջի '''ձեր խմբագրումները''' հետևյալն են.",
 'whitelistedittitle'        => 'Խմբագրման համար հարկավոր է մտնել համակարգ',
 'whitelistedittext'         => 'Անհրաժեշտ է $1 էջերը խմբագրելու համար։',
-'whitelistreadtitle'        => 'Ընթերցելու համար անհրաժեշտ է մտնել համակարգ',
-'whitelistreadtext'         => 'Անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]] էջերը ընթերցելու համար։',
-'whitelistacctitle'         => 'Ձեզ չի թույլատրվում ստեղծել մասնակցային հաշիվ',
-'whitelistacctext'          => 'Այս վիքիում մասնակցային հաշիվներ ստեղծելու համար անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]] և ունենալ համապատասխան իրավունքներ։',
 'confirmedittitle'          => 'Խբագրելու համար անհրաժեշտ է էլ-հասցեի վավերացում',
 'confirmedittext'           => 'Էջերի խմբագրումից առաջ անհրաժեշտ է վավերացնել էլ-հասցեն։
 Խնդրում ենք նշել և վավերացնել ձեր էլ-փոստի հասցեն ձեր [[Special:Preferences|նախընտրությունների]] մեջ։',
@@ -777,7 +771,7 @@
 'accmailtext'               => "'$1' մասնակցի գաղտնաբառը ուղարկված է $2 հասցեին։",
 'newarticle'                => '(Նոր)',
 'newarticletext'            => "Դուք հղվել եք դեռևս գոյություն չունեցող էջի։ Էջը ստեղծելու համար սկսեք տեքստի մուտքագրումը ներքևի արկղում (այցելեք [[{{MediaWiki:Helppage}}|օգնության էջը]]՝ մանրամասն տեղեկությունների համար)։ Եթե դուք սխալմամաբ եք այստեղ հայտնվել, ապա մատնահարեք ձեր բրաուզերի '''back''' կոճակը։",
-'anontalkpagetext'          => "----''Այս քննարկման էջը պատկանում է անանուն մասնակցին, որը դեռ չի ստեղծել մասնակցային հաշիվ կամ չի մտել համակարգ մասնակցի անունով։ Այդ իսկ պատճառով օգտագործվում է թվային IP-հասցեն։ Նման IP-հասցեից կարող են օգտվել մի քանի մասնակիցներ։ Եթե դուք անանուն մասնակից եք, բայց կարծում եք, որ ուրիշներին վերաբերող դիտողությունները արվում են ձեր հասցեով, ապա խնդրում ենք պարզապես [[Special:Userlogin|գրանցվել կամ մտնել համակարգ]], որպեսզի հետագայում ձեզ չշփոթեն այլ մասնակիցների հետ և չվերագրեն ձեզ նրանց կատարած գործողությունները։''",
+'anontalkpagetext'          => "----''Այս քննարկման էջը պատկանում է անանուն մասնակցին, որը դեռ չի ստեղծել մասնակցային հաշիվ կամ չի մտել համակարգ մասնակցի անունով։ Այդ իսկ պատճառով օգտագործվում է թվային IP-հասցեն։ Նման IP-հասցեից կարող են օգտվել մի քանի մասնակիցներ։ Եթե դուք անանուն մասնակից եք, բայց կարծում եք, որ ուրիշներին վերաբերող դիտողությունները արվում են ձեր հասցեով, ապա խնդրում ենք պարզապես [[Special:UserLogin|գրանցվել կամ մտնել համակարգ]], որպեսզի հետագայում ձեզ չշփոթեն այլ մասնակիցների հետ և չվերագրեն ձեզ նրանց կատարած գործողությունները։''",
 'noarticletext'             => 'Ներկայումս այս էջում որևէ տեքստ չկա։ Դուք կարող եք [[Special:Search/{{PAGENAME}}|որոնել այս էջի անվանումը]] այլ էջերում կամ [{{fullurl:{{FULLPAGENAME}}|action=edit}} ստեղծել նոր էջ այս անվանմամբ]։',
 'clearyourcache'            => "'''Ծանուցում.''' Հիշելուց հետո կատարված փոփոխությունները տեսնելու համար մաքրեք ձեր բրաուզերի քեշը. '''Mozilla / Firefox'''՝ ''Ctrl+Shift+R'', '''IE'''՝ ''Ctrl+F5'', '''Safari'''՝ ''Cmd+Shift+R'', '''Konqueror'''՝ ''F5'', '''Opera'''՝ ''Tools→Preferences'' ընտրացանկից։",
 'usercssjsyoucanpreview'    => '<strong>Հուշում.</strong> Էջը հիշելուց առաջ օգտվեք նախադիտման կոճակից՝ ձեր նոր CSS/JS-ֆայլը ստուգելու համար։',
@@ -829,7 +823,7 @@
 'edittools'                 => '<!-- Այստեղ տեղադրված տեքստը կցուցադրվի խմբագրման և բեռնման ձևերի տակ։ -->',
 'nocreatetitle'             => 'Էջերի ստեղծումը սահմանափակված է',
 'nocreatetext'              => 'Այս կայքում էջերի ստեղծման հնարավորությունը սահմանափակված է։
-Դուք կարող եք վերադառնալ և խմբագրել գոյություն ունեցող էջ կամ էլ [[Special:Userlogin|գրանցվել կամ մտնել համակարգ]]։',
+Դուք կարող եք վերադառնալ և խմբագրել գոյություն ունեցող էջ կամ էլ [[Special:UserLogin|գրանցվել կամ մտնել համակարգ]]։',
 'nocreate-loggedin'         => 'Ձեզ չի թույլատրվում նոր էջեր ստեղծել այս վիքիում։',
 'permissionserrors'         => 'Թույլատրության Սխալներ',
 'permissionserrorstext'     => 'Ձեզ չի թույլատրվում դա անել հետևյալ {{PLURAL:$1|պատճառով|պատճառներով}}.',
@@ -957,7 +951,7 @@
 'mypreferences'            => 'Իմ նախընտրությունները',
 'prefs-edits'              => 'Խմբագրումների քանակը.',
 'prefsnologin'             => 'Դուք չեք մտել համակարգ',
-'prefsnologintext'         => 'Մասնակցային նախընտրությունները փոփոխելու համար անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]]։',
+'prefsnologintext'         => 'Մասնակցային նախընտրությունները փոփոխելու համար անհրաժեշտ է [[Special:UserLogin|մտնել համակարգ]]։',
 'prefsreset'               => 'Լռությամբ նախընտրությունները վերականգնված են։',
 'qbsettings'               => 'Արագ անցման վահանակ',
 'qbsettings-none'          => 'Չցուցադրել',
@@ -1091,10 +1085,10 @@
 'reupload'                    => 'Վերբեռնել',
 'reuploaddesc'                => 'Վերադառնալ բեռնման ձևին։',
 'uploadnologin'               => 'Դուք չեք մտել համակարգ',
-'uploadnologintext'           => 'Ֆայլեր բեռնելու համար անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]]։',
+'uploadnologintext'           => 'Ֆայլեր բեռնելու համար անհրաժեշտ է [[Special:UserLogin|մտնել համակարգ]]։',
 'upload_directory_read_only'  => 'Վեբ-սերվերը չունի գրելու իրավունք բեռնումների թղթապանակում ($1)։',
 'uploaderror'                 => 'Բեռնման սխալ',
-'uploadtext'                  => "Ֆայլ բեռնելու համար օգտագործեք ստորև բերված ձևը։ Նախկինում բեռնված ֆայլերը դիտելու կամ որոնելու համար այցելեք [[Special:Imagelist|բեռնված ֆայլերի ցանկը]]։ Բեռնումները և ջնջումները նաև գրանցվում են [[Special:Log/upload|բեռնումների տեղեկամատյանում]]։
+'uploadtext'                  => "Ֆայլ բեռնելու համար օգտագործեք ստորև բերված ձևը։ Նախկինում բեռնված ֆայլերը դիտելու կամ որոնելու համար այցելեք [[Special:ImageList|բեռնված ֆայլերի ցանկը]]։ Բեռնումները և ջնջումները նաև գրանցվում են [[Special:Log/upload|բեռնումների տեղեկամատյանում]]։
 
 Այս ֆայլը որևէ էջում ընդգրկելու համար օգտագործեք հետևյալ հղման ձևերը.
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1168,7 +1162,7 @@
 'upload_source_url'  => ' (գործուն, հանրամատչելի URL-հասցե)',
 'upload_source_file' => ' (ֆայլ ձեր համակարգչի վրա)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Որոնել պատկերի անվանմամբ.',
 'imgfile'               => 'ֆայլ',
 'imagelist'             => 'Ֆայլերի ցանկ',
@@ -1203,18 +1197,18 @@
 # File reversion
 'filerevert'                => 'Ետ շրջել $1',
 'filerevert-legend'         => 'Ետ շրջել ֆայլ',
-'filerevert-intro'          => '<span class="plainlinks">Դուք ետ եք շրջում \'\'\'[[Media:$1|$1]]\'\'\' ֆայլը [$4 տարբերակի՝ $3, $2 պահով]։</span>',
+'filerevert-intro'          => "Դուք ետ եք շրջում '''[[Media:$1|$1]]''' ֆայլը [$4 տարբերակի՝ $3, $2 պահով]։",
 'filerevert-comment'        => 'Մեկնաբանություն.',
 'filerevert-defaultcomment' => 'Ետ է շրջվում հին տարբերակին՝ $2, $1 պահով',
 'filerevert-submit'         => 'Ետ շրջել',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ֆայլը ետ է շրջվել [$4 տարբերակին՝ $3, $2 պահով]։</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ֆայլը ետ է շրջվել [$4 տարբերակին՝ $3, $2 պահով]։",
 'filerevert-badversion'     => 'Այս ֆայլի նախորդ տեղական տարբերակ նշված ժամդրոշմով չկա։',
 
 # File deletion
 'filedelete'             => 'Ջնջում $1',
 'filedelete-legend'      => 'Ջնջել ֆայլը',
 'filedelete-intro'       => "Դուք ջնջում եք '''[[Media:$1|$1]]'''։",
-'filedelete-intro-old'   => '<span class="plainlinks">Դուք ջնջում եք \'\'\'[[Media:$1|$1]]\'\'\' ֆայլի [$4 $3, $2 պահով] տարբերակը։</span>',
+'filedelete-intro-old'   => "Դուք ջնջում եք '''[[Media:$1|$1]]''' ֆայլի [$4 $3, $2 պահով] տարբերակը։",
 'filedelete-comment'     => 'Մեկնաբանություն.',
 'filedelete-submit'      => 'Ջնջել',
 'filedelete-success'     => "'''$1''' ֆայլը ջնջված է։",
@@ -1347,7 +1341,7 @@
 'logempty'             => 'Տեղեկամատյանում չկան համընկնող տարրեր։',
 'log-title-wildcard'   => 'Որոնել այս տեքստով սկսվող անվանումներ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Բոլոր էջերը',
 'alphaindexline'    => '$1 -ից` $2',
 'nextpage'          => 'Հաջորդ էջը ($1)',
@@ -1367,14 +1361,14 @@
 'categories'         => 'Կատեգորիաներ',
 'categoriespagetext' => 'Հետևյալ կատեգորիաները պարունակում են էջեր կամ մեդիա։',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Ցուցադրել մասնակիցներին՝ սկսած.',
 'listusers-submit'   => 'Ցուցադրել',
 'listusers-noresult' => 'Այդպիսի մասնակիցներ չգտնվեցին։',
 
 # E-mail user
 'mailnologin'     => 'Ուղարկման հասցե չկա',
-'mailnologintext' => 'Անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]] և ունենալ գործող էլ-փոստի հասցե ձեր [[Special:Preferences|նախընտրություններում]]՝ ուրիշ մասնակիցներին էլեկտրոնային նամակներ ուղարկելու համար։',
+'mailnologintext' => 'Անհրաժեշտ է [[Special:UserLogin|մտնել համակարգ]] և ունենալ գործող էլ-փոստի հասցե ձեր [[Special:Preferences|նախընտրություններում]]՝ ուրիշ մասնակիցներին էլեկտրոնային նամակներ ուղարկելու համար։',
 'emailuser'       => 'էլ-նամակ ուղարկել այս մասնակցին',
 'emailpage'       => 'Էլ-նամակ ուղարկել մասնակցին',
 'emailpagetext'   => 'Եթե այս մասնակիցը նշել է գործող էլ-փոստի հասցե իր նախընտրություններում, ապա ստորև բերված ձևով հնարավոր է ուղարկել նրան էլ-նամակ։
@@ -1400,9 +1394,9 @@
 'nowatchlist'          => 'Ձեր հսկողության ցանկը դատարկ է։',
 'watchlistanontext'    => 'Անհրաժեշտ է $1՝ հսկացանկը դիտելու կամ խմբագրելու համար։',
 'watchnologin'         => 'Չեք մտել համակարգ',
-'watchnologintext'     => 'Անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]]՝ հսկացանկը փոփոխելու համար։',
+'watchnologintext'     => 'Անհրաժեշտ է [[Special:UserLogin|մտնել համակարգ]]՝ հսկացանկը փոփոխելու համար։',
 'addedwatch'           => 'Ավելացված է հսկացանկին',
-'addedwatchtext'       => '«[[:$1]]» էջը ավելացված է ձեր [[Special:Watchlist|հսկացանկին]]։ Այս էջի և նրան կապված քննարկումների էջի հետագա փոփոխությունները կգրանցվեն այդտեղ, և կցուցադրվեն թավատառ [[Special:Recentchanges|վերջին փոփոխությունների]] ցանկում։
+'addedwatchtext'       => '«[[:$1]]» էջը ավելացված է ձեր [[Special:Watchlist|հսկացանկին]]։ Այս էջի և նրան կապված քննարկումների էջի հետագա փոփոխությունները կգրանցվեն այդտեղ, և կցուցադրվեն թավատառ [[Special:RecentChanges|վերջին փոփոխությունների]] ցանկում։
 
 Հետագայում հսկացանկից էջը հեռացնելու ցանկության դեպքում մատնահարեք էջի վերնամասի ընտրացանկում գտնվող «հանել հսկումից» կոճակին։',
 'removedwatch'         => 'Հանված է հսկման ցանկից',
@@ -1501,7 +1495,7 @@
 այս գործողությունը բեկանվել է սեսիայի հափշտակման կանխման նպատակով։
 Խնդրում ենք սեղմել «back» կոճակը և վերբեռնել այն էջը որտեղից եկել եք ու փորձել կրկին։',
 'protectlogpage'              => 'Պաշտպանման տեղեկամատյան',
-'protectlogtext'              => 'Ստորև բերված է պաշտպանված և պաշտպանումից հանված էջերի ցանկը։ Տես նաև [[Special:Protectedpages|ներկայումս պաշտպանված էջերի ցանկը]]։',
+'protectlogtext'              => 'Ստորև բերված է պաշտպանված և պաշտպանումից հանված էջերի ցանկը։ Տես նաև [[Special:ProtectedPages|ներկայումս պաշտպանված էջերի ցանկը]]։',
 'protectedarticle'            => 'պաշտպանվեց «[[$1]]» էջը',
 'modifiedarticleprotection'   => 'փոխվեց պաշտպանման մակարդակը «[[$1]]» էջի համար',
 'unprotectedarticle'          => 'պաշտպանումը հանված է «[[$1]]» էջից',
@@ -1645,7 +1639,7 @@
 'badipaddress'                => 'Սխալ IP-հասցե',
 'blockipsuccesssub'           => 'Արգելափակումը կատարված է',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|«$1»]] արգելափակված է։
-<br />Տես [[Special:Ipblocklist|արգելափակված IP-հասցեների ցանկը]]։',
+<br />Տես [[Special:IPBlockList|արգելափակված IP-հասցեների ցանկը]]։',
 'ipb-edit-dropdown'           => 'Խմբագրել արգելափակման պատճառները',
 'ipb-unblock-addr'            => 'Անարգելել $1 մասնակցին',
 'ipb-unblock'                 => 'Անարգելել որևէ մասնակից կամ IP-հասցե',
@@ -1677,7 +1671,7 @@
 'blocklogentry'               => 'արգելափակվել է  "$1". արգելափակման ժամկետն է՝  $2 $3',
 'blocklogtext'                => 'Սա մասնակիցների արգելափակման և անարգելման գործողությունների տեղեկամատյանն է։
 Ավտոմատիկ արգելափակված IP-հասցեները ընդգրկված չեն այստեղ։
-Տես [[Special:Ipblocklist|նաերկայումս գործող արգելափակումների ցանկը]]։',
+Տես [[Special:IPBlockList|նաերկայումս գործող արգելափակումների ցանկը]]։',
 'unblocklogentry'             => 'անարգելված է $1',
 'block-log-flags-anononly'    => 'միայն անանուն մասնակիցներ',
 'block-log-flags-nocreate'    => 'մասնակցային հաշվի ստեղծումը արգելված է',
@@ -1707,7 +1701,7 @@
 'lockdbsuccesssub'    => 'Տվյալների բազան կողպված է',
 'unlockdbsuccesssub'  => 'Տվյալների բազան բանված է։',
 'lockdbsuccesstext'   => 'Տվյալների բազան կողպված է։<br />
-Չմոռանաք [[Special:Unlockdb|բանալ այն]] սպասարկման ավարտից հետո։',
+Չմոռանաք [[Special:UnlockDB|բանալ այն]] սպասարկման ավարտից հետո։',
 'unlockdbsuccesstext' => 'Տվյալների բազան բանված է։',
 'lockfilenotwritable' => 'Տվյալների բազայի կողպման ֆայլը գրելի չէ։ Տվյալների բազան կողպելու կամ բանալու համար վեբ-սերվերը պետք է ունենա այս ֆայլը փոփոխելու իրավունք։',
 'databasenotlocked'   => 'Տվյալների բազան կողպված չէ։',
@@ -1728,8 +1722,6 @@
 
 Այսպիսի դեպքերում հարկավոր է տեղափոխել կամ միաձուլել էջերը ձեռքով, եթե դա ցանկանաք։",
 'movearticle'             => 'Տեղափոխել էջը',
-'movenologin'             => 'Դուք չեք մտել համակարգ',
-'movenologintext'         => 'Անհրաժեշտ է [[Special:Userlogin|մտնել համակարգ]]՝ էջը տեղափոխելու համար։',
 'movenotallowed'          => 'Դուք չունեք {{SITENAME}}ում էջերի տեղափոխման իրավունք։',
 'newtitle'                => 'Նոր անվանում.',
 'move-watch'              => 'Հսկել էջը',
@@ -1749,7 +1741,7 @@
 'delete_and_move'         => 'Ջնջել և տեղափոխել',
 'delete_and_move_text'    => '==Պահանջվում է ջնջում==
 
-«[[$1]]» անվանմամբ էջ արդեն գոյություն ունի։ Ուզո՞ւմ եք այն ջնջել՝ տեղափոխումը իրականացնելու համար։',
+«[[:$1]]» անվանմամբ էջ արդեն գոյություն ունի։ Ուզո՞ւմ եք այն ջնջել՝ տեղափոխումը իրականացնելու համար։',
 'delete_and_move_confirm' => 'Այո, ջնջել էջը',
 'delete_and_move_reason'  => 'Ձնջված է՝ տեղափոխման տեղ ազատելու համար',
 'selfmove'                => 'Ելակետային և նոր անվանումները համընկնում են. անհնար է տեղափոխել էջը ինքն իրեն։',
@@ -1973,7 +1965,7 @@
 'show-big-image'       => 'Լրիվ թույլատվությամբ',
 'show-big-image-thumb' => '<small>Նախադիտման չափ. $1 × $2 փիքսել</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Նոր ֆայլերի սրահ',
 'imagelisttext'         => "Ստորև բերված է '''$1''' {{PLURAL:$1|ֆայլի|ֆայլերի}} ցանկ՝ դասավորված ըստ $2։",
 'showhidebots'          => '($1 բոտերին)',
@@ -2015,7 +2007,7 @@
 
 # External editor support
 'edit-externally'      => 'Խմբագրել այս ֆայլը արտաքին խմբագրիչով',
-'edit-externally-help' => 'Մանրամասնությունների համար տես [http://meta.wikimedia.org/wiki/Help:External_editors Meta:Help:External_editors]։',
+'edit-externally-help' => 'Մանրամասնությունների համար տես [http://www.mediawiki.org/wiki/Manual:External_editors Meta:Help:External_editors]։',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'բոլոր',
@@ -2076,7 +2068,7 @@
 'unit-pixel' => ' փիքսել',
 
 # HTML dump
-'redirectingto' => 'Վերահղվում է դեպի [[$1]]…',
+'redirectingto' => 'Վերահղվում է դեպի [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Մաքրե՞լ այս էջի քեշը։
Index: languages/messages/MessagesTn.php
===================================================================
--- languages/messages/MessagesTn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Hakka
  * @author Cbrown1023
+ * @author Hakka
  */
 
-
-
 $messages = array(
 # Dates
 'sunday'        => 'Tshipi',
@@ -155,7 +153,6 @@
 # Move page
 'move-page-legend' => 'Sutisa tsebe',
 'movearticle'      => 'Sutisa tsebe:',
-'movenologin'      => 'Ga o a ikwadisa',
 'movepagebtn'      => 'Sutisa tsebe',
 'movedto'          => 'sutela kwa',
 '1movedto2'        => '[[$1]] o sutisediwa kwa go [[$2]]',
Index: languages/messages/MessagesPs.php
===================================================================
--- languages/messages/MessagesPs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author Ahmed-Najib-Biabani-Ibrahimkhel
- * @author SPQRobin
- * @author Siebrand
  */
 
 $specialPageAliases = array(
@@ -191,8 +189,14 @@
 'category-file-count-limited' => 'په اوسنۍ وېشنيزه کې {{PLURAL:$1|يوه دوتنه ده|$1 دوتنې دي}}.',
 'listingcontinuesabbrev'      => 'پرله پسې',
 
-'mainpagetext' => "<big>'''MediaWiki په برياليتوب سره نصب شو.'''</big>",
+'mainpagetext'      => "<big>'''MediaWiki په برياليتوب سره نصب شو.'''</big>",
+'mainpagedocfooter' => "Consult the [http://meta.wikimedia.org/wiki/Help:Contents User's Guide] for information on using the wiki software.
 
+== پيلول ==
+* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Configuration settings list]
+* [http://www.mediawiki.org/wiki/Manual:FAQ د ميډياويکي ډېرځليزې پوښتنې]
+* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]",
+
 'about'          => 'په اړه',
 'article'        => 'د منځپانګې مخ',
 'newwindow'      => '(په نوې کړکۍ کې پرانيستل کېږي)',
@@ -272,6 +276,7 @@
 'bugreports'           => 'د ستونزو راپورونه',
 'bugreportspage'       => 'Project:د ستونزو راپور',
 'copyright'            => 'دا مېنځپانګه د $1 له مخې ستاسو لاس رسي لپاره دلته ده.',
+'copyrightpagename'    => 'د {{SITENAME}} رښتې',
 'copyrightpage'        => '{{ns:project}}:رښتې',
 'currentevents'        => 'اوسنۍ پېښې',
 'currentevents-url'    => 'Project:اوسنۍ پېښې',
@@ -331,7 +336,7 @@
 'nosuchspecialpage' => 'داسې هېڅ کوم ځانګړی مخ نشته',
 'nospecialpagetext' => "<big>'''تاسو د يو ناسم ځانګړي مخ غوښتنه کړې.'''</big>
 
-تاسو کولای شی چې د سمو ځانګړو مخونو لړليک په [[Special:Specialpages|{{int:specialpages}}]] کې ومومۍ.",
+تاسو کولای شی چې د سمو ځانګړو مخونو لړليک په [[Special:SpecialPages|{{int:specialpages}}]] کې ومومۍ.",
 
 # General errors
 'error'                => 'تېروتنه',
@@ -358,11 +363,13 @@
 
 # Login and logout pages
 'logouttitle'                => 'کارن-حساب نه وتنه',
-'logouttext'                 => '<strong>تاسو اوس د غونډال نه ووتلی.</strong><br />
-تاسو کولای شی چې پرته د کارن-نوم نه {{SITENAME}} په ورکنومي توګه وکاروی، او يا هم تاسو کولای شی چې په همدې کارن-نوم يا په کوم بل کارن-نوم خپلې ليکنې خپرې کړی. يادونه دې وي چې ځينې مخونو کې به تاسو لا تر اوسه پورې غونډال کې ننوتي ښکاری، تر څو تاسو د خپل کتنمل حافظه نه وي سپينه کړی.',
+'logouttext'                 => '<strong>تاسو اوس د غونډال نه ووتلی.</strong>
+
+تاسو کولای شی چې پرته د کارن-نوم نه {{SITENAME}} په ورکنومي توګه وکاروی، او يا هم تاسو کولای شی چې په همدې کارن-نوم يا په کوم بل کارن-نوم خپلې ليکنې خپرې کړی. 
+يادونه دې وي چې ځينې مخونو کې به تاسو لا تر اوسه پورې غونډال کې ننوتي ښکاری، تر څو تاسو د خپل کتنمل حافظه نه وي سپينه کړی.',
 'welcomecreation'            => '==$1 ښه راغلاست! ==
 
-ستاسو کارن-حساب جوړ شو. لطفاً د {{SITENAME}} لپاره خپلې خوښونې او غورتوبونه بدلول مه هېروی.',
+ستاسو کارن-حساب جوړ شو. لطفاً د [[Special:Preferences|{{SITENAME}} غوره توبونو]] بدلول مو مه هېروی.',
 'loginpagetitle'             => 'کارن-حساب ته ننوتنه',
 'yourname'                   => 'کارن-نوم:',
 'yourpassword'               => 'پټنوم:',
@@ -371,7 +378,7 @@
 'loginproblem'               => '<b>همدې غونډال ته ستاسو په ننوتنه کې يوه ستونزه راپېښه شوه!</b><br />بيا يې وآزمويۍ!',
 'login'                      => 'ننوتل',
 'nav-login-createaccount'    => 'ننوتل / کارن-حساب جوړول',
-'loginprompt'                => 'ددې لپاره چې {{SITENAME}} کې ننوځۍ نو بايد چې ستاسو د کمپيوټر کوکيز (cookies) <br />چارن وي.',
+'loginprompt'                => 'ددې لپاره چې {{SITENAME}} کې ننوځۍ نو بايد چې ستاسو د کمپيوټر کوکيز چارن وي.',
 'userlogin'                  => 'ننوتل / کارن-حساب جوړول',
 'logout'                     => 'وتل',
 'userlogout'                 => 'وتل',
@@ -385,7 +392,7 @@
 'badretype'                  => 'دا پټنوم چې تاسو ليکلی د پخواني پټنوم سره ورته نه دی.',
 'userexists'                 => 'کوم کارن نوم چې تاسو ورکړی هغه بل چا کارولی. لطفاً يو بل ډول نوم وټاکۍ.',
 'youremail'                  => 'برېښليک *',
-'username'                   => 'کارن نوم:',
+'username'                   => 'کارن-نوم:',
 'uid'                        => 'د کارونکي پېژندنه:',
 'yourrealname'               => 'اصلي نوم:',
 'yourlanguage'               => 'ژبه:',
@@ -484,9 +491,6 @@
 'blockedoriginalsource'    => "د '''$1''' سرچينې لاندې ښودل شوي:",
 'whitelistedittitle'       => 'که د سمادولو تکل لری نو بايد غونډال ته ورننوځۍ.',
 'whitelistedittext'        => 'ددې لپاره چې سمادول ترسره کړی تاسو بايد $1.',
-'whitelistreadtitle'       => 'د همدغې ليکنې د لوستلو لپاره بايد تاسو غونډال ته ننوځۍ.',
-'whitelistreadtext'        => 'که د پاڼو د لوستلو تکل لری نو بايد غونډال کې [[Special:Userlogin|ننوتنه]] ترسره کړۍ.',
-'whitelistacctitle'        => 'تاسو د کارن نوم جوړولو اجازه نه لرۍ',
 'loginreqtitle'            => 'غونډال کې ننوتنه پکار ده',
 'loginreqlink'             => 'ننوتل',
 'loginreqpagetext'         => 'د نورو مخونو د کتلو لپاره تاسو بايد $1 وکړۍ.',
@@ -496,7 +500,7 @@
 'newarticletext'           => "تاسو د يوه داسې تړنې څارنه کړې چې لا تر اوسه پورې شتون نه لري.
 که همدا مخ ليکل غواړۍ، نو په لانديني چوکاټ کې خپل متن وټاپۍ (د لا نورو مالوماتو لپاره د [[{{MediaWiki:Helppage}}|لارښود مخ]] وګورۍ).
 که چېرته تاسو دلته په غلطۍ سره راغلي ياست، نو يواځې د خپل د کتنمل '''مخ پر شا''' تڼۍ مو وټوکۍ.",
-'anontalkpagetext'         => "----''دا د بې نومه کارونکو لپاره چې کارن نوم يې نه دی جوړ کړی او يا هم خپل کارن نوم نه دی کارولی، د سکالو پاڼه ده. نو ددې پخاطر مونږ د هغه کارونکي/هغې کارونکې د انټرنېټ شمېره يا IP پته د نوموړي/نوموړې د پېژندلو لپاره کاروو. داسې يوه IP پته د ډېرو کارونکو لخوا هم کارېدلی شي. که تاسو يو بې نومه کارونکی ياست او تاسو ته نااړونده پېغامونه او تبصرې اشاره شوي، نو لطفاً د نورو بې نومو کارونکو او ستاسو ترمېنځ د ټکنتوب مخ نيونې لپاره [[Special:Userlogin|کارن-حساب جوړول يا ننوتنه]] وټوکۍ.''",
+'anontalkpagetext'         => "----''دا د بې نومه کارونکو لپاره چې کارن نوم يې نه دی جوړ کړی او يا هم خپل کارن نوم نه دی کارولی، د سکالو پاڼه ده. نو ددې پخاطر مونږ د هغه کارونکي/هغې کارونکې د انټرنېټ شمېره يا IP پته د نوموړي/نوموړې د پېژندلو لپاره کاروو. داسې يوه IP پته د ډېرو کارونکو لخوا هم کارېدلی شي. که تاسو يو بې نومه کارونکی ياست او تاسو ته نااړونده پېغامونه او تبصرې اشاره شوي، نو لطفاً د نورو بې نومو کارونکو او ستاسو ترمېنځ د ټکنتوب مخ نيونې لپاره [[Special:UserLogin|کارن-حساب جوړول يا ننوتنه]] وټوکۍ.''",
 'noarticletext'            => 'دم مهال په همدې مخ کې هېڅ متن نشته، تاسو کولای شی چې  په نورو مخونو کې [[Special:Search/{{PAGENAME}}|د همدې سرليک لپاره پلټنه]] وکړۍ، او يا هم [{{fullurl:{{FULLPAGENAME}}|action=edit}} همدا مخ سماد کړۍ].',
 'clearyourcache'           => "'''يادونه:''' د غوره توبونو د خوندي کولو وروسته، ددې لپاره چې تاسو خپل سر ته رسولي ونجونه وګورۍ نو پکار ده چې د خپل بروزر ساتل شوې حافظه تازه کړی. د '''Mozilla / Firefox / Safari:''' لپاره د ''Shift'' تڼۍ نيولې وساتی کله مو چې په ''Reload''، ټک واهه، او يا هم ''Ctrl-Shift-R'' تڼۍ کېښکاږۍ (په Apple Mac کمپيوټر باندې ''Cmd-Shift-R'' کېښکاږۍ); '''IE:''' د ''Ctrl'' تڼۍ کېښکاږۍ کله مو چې په ''Refresh'' ټک واهه، او يا هم د ''Ctrl-F5'' تڼۍ کېښکاږۍ; '''Konqueror:''' بروزر کې يواځې ''Reload'' ته ټک ورکړۍ، او يا په ''F5''; د '''Opera''' کارونکو ته پکار ده چې په بشپړه توګه د خپل کمپيوټر ساتل شوې حافظه تازه کړي چې پدې توګه کېږي ''Tools→Preferences''.",
 'updated'                  => '(تازه)',
@@ -520,7 +524,7 @@
 'template-protected'       => '(ژغورل شوی)',
 'template-semiprotected'   => '(نيم-ژغورلی)',
 'nocreatetext'             => '{{SITENAME}} د نوو مخونو د جوړولو وړتيا محدوده کړې.
-تاسو بېرته پر شا تللای شی او په شته مخونو کې سمادېدنې ترسره کولای شی، او يا هم [[Special:Userlogin|غونډال ته ننوتلای او يو کارن-حساب جوړولای شی]].',
+تاسو بېرته پر شا تللای شی او په شته مخونو کې سمادېدنې ترسره کولای شی، او يا هم [[Special:UserLogin|غونډال ته ننوتلای او يو کارن-حساب جوړولای شی]].',
 'recreate-deleted-warn'    => "'''ګواښ: تاسو د يو داسې مخ بياجوړونه کوی کوم چې يو ځل پخوا ړنګ شوی وو.'''
 
 پکار ده چې تاسو په دې ځان پوه کړی چې ايا دا تاسو ته وړ ده چې د همدې مخ سمادېدنه په پرله پسې توګه وکړی.
@@ -556,7 +560,9 @@
 'history-feed-item-nocomment' => '$1 په $2', # user at time
 
 # Revision deletion
-'rev-delundel' => 'ښکاره کول/ پټول',
+'rev-delundel'    => 'ښکاره کول/ پټول',
+'pagehist'        => 'د مخ پېښليک',
+'revdelete-uname' => 'کارن-نوم',
 
 # Diffs
 'history-title'           => 'د "$1" د پېښليک مخليدنه',
@@ -575,6 +581,7 @@
 'nextn'                 => 'راتلونکي $1',
 'viewprevnext'          => '($1) ($2) ($3) ښکاره کول',
 'search-suggest'        => 'آيا همدا ستاسو موخه ده: $1',
+'search-relatedarticle' => 'اړونده',
 'searchall'             => 'ټول',
 'powersearch'           => 'پرمختللې پلټنه',
 'powersearch-legend'    => 'پرمختللې پلټنه',
@@ -584,7 +591,7 @@
 'mypreferences'         => 'زما غوره توبونه',
 'prefs-edits'           => 'د سمادونو شمېر:',
 'prefsnologin'          => 'غونډال کې نه ياست ننوتي',
-'prefsnologintext'      => 'ددې لپاره چې د کارونکي غوره توبونه وټاکۍ نو تاسو ته پکار ده چې لومړی غونډال کې [[Special:Userlogin|ننوتنه]] ترسره کړی.',
+'prefsnologintext'      => 'ددې لپاره چې د کارونکي غوره توبونه وټاکۍ نو تاسو ته پکار ده چې لومړی غونډال کې [[Special:UserLogin|ننوتنه]] ترسره کړی.',
 'qbsettings-none'       => 'هېڅ',
 'changepassword'        => 'پټنوم بدلول',
 'skin'                  => 'بڼه',
@@ -670,9 +677,9 @@
 'uploadbtn'             => 'دوتنه پورته کول',
 'reupload'              => 'بيا پورته کول',
 'uploadnologin'         => 'غونډال کې نه ياست ننوتي',
-'uploadnologintext'     => 'ددې لپاره چې دوتنې پورته کړای شۍ، تاسو ته پکار ده چې لومړی غونډال کې [[Special:Userlogin|ننوتنه]] ترسره کړی.',
+'uploadnologintext'     => 'ددې لپاره چې دوتنې پورته کړای شۍ، تاسو ته پکار ده چې لومړی غونډال کې [[Special:UserLogin|ننوتنه]] ترسره کړی.',
 'uploaderror'           => 'د پورته کولو ستونزه',
-'uploadtext'            => "د دوتنو د پورته کولو لپاره د لانديني چوکاټ نه کار واخلۍ، که چېرته غواړۍ چې د پخوانيو پورته شوو انځورونو په اړه لټون وکړۍ او يا يې وکتلای شۍ نو بيا د [[Special:Imagelist|پورته شوو دوتنو لړليک]] ته لاړ شی، د پورته شوو دوتنو او ړنګ شوو دوتنو يادښتونه په [[Special:Log/upload|پورته شوي يادښت]] کې کتلای شی.
+'uploadtext'            => "د دوتنو د پورته کولو لپاره د لانديني چوکاټ نه کار واخلۍ، که چېرته غواړۍ چې د پخوانيو پورته شوو انځورونو په اړه لټون وکړۍ او يا يې وکتلای شۍ نو بيا د [[Special:ImageList|پورته شوو دوتنو لړليک]] ته لاړ شی، د پورته شوو دوتنو او ړنګ شوو دوتنو يادښتونه په [[Special:Log/upload|پورته شوي يادښت]] کې کتلای شی.
 
 ددې لپاره چې يوه مخ ته انځور ورواچوی، نو بيا پدې ډول تړن (لېنک) وکاروی
 '''<nowiki>[[</nowiki>Image:File.jpg<nowiki>]]</nowiki>''',
@@ -709,7 +716,7 @@
 'nolicense'          => 'هېڅ نه دي ټاکل شوي',
 'upload_source_file' => '(ستاسو په کمپيوټر کې يوه دوتنه)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'د انځور د نوم لټون:',
 'imgfile'               => 'دوتنه',
 'imagelist'             => 'د دوتنو لړليک',
@@ -754,6 +761,9 @@
 'filedelete-success'          => "'''$1''' ړنګ شو.",
 'filedelete-otherreason'      => 'بل/اضافه سبب:',
 'filedelete-reason-otherlist' => 'بل سبب',
+'filedelete-reason-dropdown'  => '*د ړنګولو ټولګړی سبب
+** د رښتو نه غاړه غړونه
+** کټ مټ دوه ګونې دوتنه',
 
 # MIME search
 'mimesearch' => 'MIME پلټنه',
@@ -823,7 +833,7 @@
 'protectedtitles'         => 'ژغورلي سرليکونه',
 'listusers'               => 'د کارونکو لړليک',
 'newpages'                => 'نوي مخونه',
-'newpages-username'       => 'کارن نوم:',
+'newpages-username'       => 'کارن-نوم:',
 'ancientpages'            => 'تر ټولو زاړه مخونه',
 'move'                    => 'لېږدول',
 'movethispage'            => 'دا مخ ولېږدوه',
@@ -842,7 +852,7 @@
 'log-search-legend'    => 'د يادښتونو لپاره لټون',
 'log-search-submit'    => 'ورځه',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'ټول مخونه',
 'alphaindexline'    => '$1 نه تر $2 پورې',
 'nextpage'          => 'بل مخ ($1)',
@@ -862,13 +872,14 @@
 'categoriespagetext'          => 'په دغه ويکي (wiki) کې همدا لاندينۍ وېشنيزې دي.',
 'special-categories-sort-abc' => 'د ابېڅو له مخې اوډل',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'هغه کارونکي ښکاره کړه چې نومونه يې پېلېږي په:',
 'listusers-submit'   => 'ښکاره کول',
 'listusers-noresult' => 'هېڅ کوم کارونکی و نه موندل شو.',
 
-# Special:Listgrouprights
-'listgrouprights-group' => 'ډله',
+# Special:ListGroupRights
+'listgrouprights-group'   => 'ډله',
+'listgrouprights-members' => '(د غړو لړليک)',
 
 # E-mail user
 'mailnologin'     => 'هېڅ کومه لېږل شوې پته نشته',
@@ -892,11 +903,11 @@
 'watchlistfor'         => "(د '''$1''')",
 'nowatchlist'          => 'ستاسو په کتلي لړليک کې هېڅ نه شته.',
 'watchnologin'         => 'غونډال کې نه ياست ننوتي.',
-'watchnologintext'     => 'ددې لپاره چې خپل کتل شوي لړليک کې بدلون راولی نو تاسو ته پکار ده چې لومړی غونډال کې [[Special:Userlogin|ننوتنه]] ترسره کړی.',
+'watchnologintext'     => 'ددې لپاره چې خپل کتل شوي لړليک کې بدلون راولی نو تاسو ته پکار ده چې لومړی غونډال کې [[Special:UserLogin|ننوتنه]] ترسره کړی.',
 'addedwatch'           => 'په کتلي لړليک کې ورګډ شو.',
 'addedwatchtext'       => "د \"[[:\$1]]\" په نوم يو مخ ستاسو [[Special:Watchlist|کتلي لړليک]] کې ورګډ شو.
 په راتلونکې کې چې په دغه مخ او ددغه مخ په اړونده بحث کې کوم بدلونونه راځي نو هغه به ستاسو کتلي لړليک کې وښوولی شي,
-او په همدې توګه هغه مخونه به د [[Special:Recentchanges|وروستي بدلونونو]] په لړليک کې په '''روڼ''' ليک ليکل شوی وي ترڅو په اسانۍ سره څوک وپوهېږي چې په کوم کوم مخونو کې بدلونونه ترسره شوي.
+او په همدې توګه هغه مخونه به د [[Special:RecentChanges|وروستي بدلونونو]] په لړليک کې په '''روڼ''' ليک ليکل شوی وي ترڅو په اسانۍ سره څوک وپوهېږي چې په کوم کوم مخونو کې بدلونونه ترسره شوي.
 
 که چېرته تاسو بيا وروسته غواړۍ چې کومه پاڼه د خپل کتلي لړليک نه ليرې کړۍ، نو په \"نه کتل\" تڼۍ باندې ټک ورکړۍ.",
 'removedwatch'         => 'د کتلي لړليک نه لرې شو',
@@ -976,8 +987,11 @@
 
 # Undelete
 'undelete'               => 'ړنګ شوي مخونه کتل',
+'undeletepage'           => 'ړنګ شوي مخونه کتل او بېرته پرځای کول',
 'viewdeletedpage'        => 'ړنګ شوي مخونه کتل',
-'undeletebtn'            => 'بيا پرځای کول',
+'undeletebtn'            => 'بېرته پرځای کول',
+'undeletelink'           => 'بېرته پرځای کول',
+'undeletereset'          => 'بياايښودل',
 'undeletecomment'        => 'تبصره:',
 'undeletedarticle'       => '"[[$1]]" بېرته پرځای شو',
 'undelete-search-box'    => 'ړنګ شوي مخونه لټول',
@@ -1029,7 +1043,7 @@
 'badipaddress'             => 'ناسمه IP پته',
 'blockipsuccesssub'        => 'مخنيوی په برياليتوب سره ترسره شو',
 'blockipsuccesstext'       => 'د [[Special:Contributions/$1|$1]] مخه نيول شوې.
-<br />د مخنيول شويو خلکو د کتنې لپاره، د [[Special:Ipblocklist|مخنيول شويو IP لړليک]] وګورۍ.',
+<br />د مخنيول شويو خلکو د کتنې لپاره، د [[Special:IPBlockList|مخنيول شويو IP لړليک]] وګورۍ.',
 'ipblocklist'              => 'د مخنيول شويو IP پتو او کارن نومونو لړليک',
 'ipblocklist-username'     => 'کارن-نوم يا IP پته:',
 'ipblocklist-submit'       => 'پلټل',
@@ -1051,7 +1065,7 @@
 'movepagetext'            => "د لاندينۍ فورمې په کارولو سره تاسو د يوه مخ نوم بدلولی شی، چې په همدې توګه به د يوه مخ ټول پېښليک د هغه د نوي نوم سرليک ته ولېږدېږي.
 د يوه مخ، پخوانی نوم به د نوي نوم ورګرځونکی مخ وګرځي او نوي سرليک ته به وګرځولی شي.
 هغه تړنې چې په زاړه مخ کې دي په هغو کې به هېڅ کوم بدلون را نه شي;
-د ماتو ورګرځونو يا دوه ځله ورګرځونو د ستونزو د پېښېدو په خاطر ځان ډاډه کړی چې ستاسې ورګرځونې ماتې يا دوه ځله نه وي.
+[[Special:BrokenRedirects|د ماتو ورګرځونو]] يا [[Special:DoubleRedirects|دوه ځله ورګرځونو]] د ستونزو د پېښېدو په خاطر ځان ډاډه کړی چې ستاسې ورګرځونې ماتې يا دوه ځله نه وي.
 دا ستاسو پازه ده چې ځان په دې هم ډاډمن کړی چې آيا هغه تړنې کوم چې د يو مخ سره پکار دي چې وي، همداسې په پرله پسې توګه پېيلي او خپل موخن ځايونو سره اړونده دي.
 
 په ياد مو اوسه چې يو مخ به '''هېڅکله''' و نه لېږدېږي که چېرته د پخوا نه په هماغه نوم يو مخ شتون ولري، خو که چېرته يو مخ تش وه او يا هم يو ورګرځېدلی مخ وه چې پېښليک کې يې بدلون نه وي راغلی. نو دا په دې مانا ده چې تاسو کولای شی چې د يو مخ نوم بدل کړی بېرته هماغه پخواني نوم ته چې د پخوا نه يې درلوده، که چېرته تاسو تېرووځۍ نو په داسې حال کې تاسو نه شی کولای چې د يوه مخ پر سر يو څه وليکۍ.
@@ -1065,8 +1079,6 @@
 
 نو په هغه وخت کې پکار ده چې د خبرواترو د مخ لېږدونه او د نوي مخ سره د يوځای کولو کړنه په لاسي توګه ترسره کړی.",
 'movearticle'             => 'مخ لېږدول',
-'movenologin'             => 'غونډال کې نه ياست ننوتي',
-'movenologintext'         => 'ددې لپاره چې يو مخ ولېږدوی، نو تاسو بايد يو ثبت شوی کارونکی او غونډال کې [[Special:Userlogin|ننوتي]] اوسۍ.',
 'newtitle'                => 'يو نوي سرليک ته:',
 'move-watch'              => 'همدا مخ کتل',
 'movepagebtn'             => 'مخ لېږدول',
@@ -1179,7 +1191,7 @@
 'show-big-image'       => 'بشپړه بېلن نښې',
 'show-big-image-thumb' => '<small>د همدې مخکتنې کچه: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'د نوو دوتنو نندارتون',
 'imagelisttext'         => "دلته لاندې د '''$1''' {{PLURAL:$1|دوتنه|دوتنې}} يو لړليک دی چې اوډل شوي $2.",
 'newimages-summary'     => 'هغه دوتنې چې غونډال کې تازه پورته شوي، په همدې ځانګړي مخ کې ښکاري',
@@ -1214,6 +1226,7 @@
 
 # EXIF tags
 'exif-imagedescription' => 'د انځور سرليک',
+'exif-model'            => 'د کامرې ماډل',
 'exif-artist'           => 'ليکوال',
 'exif-usercomment'      => 'د کارونکي تبصرې',
 'exif-filesource'       => 'د دوتنې سرچينه',
@@ -1243,7 +1256,7 @@
 
 # External editor support
 'edit-externally'      => 'د باندنيو پروګرامونو په کارولو سره دا دوتنه سمادول',
-'edit-externally-help' => 'د نورو مالوماتو لپاره د [http://meta.wikimedia.org/wiki/Help:External_editors امستنو لارښوونې] وګورۍ.',
+'edit-externally-help' => 'د نورو مالوماتو لپاره د [http://www.mediawiki.org/wiki/Manual:External_editors امستنو لارښوونې] وګورۍ.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ټول',
@@ -1280,7 +1293,10 @@
 'hideresults'      => 'پايلې پټول',
 
 # Multipage image navigation
-'imgmultigo' => 'ورځه!',
+'imgmultipageprev' => '← پخوانی مخ',
+'imgmultipagenext' => 'راتلونکی مخ →',
+'imgmultigo'       => 'ورځه!',
+'imgmultigoto'     => 'د $1 مخ ته ورځه',
 
 # Table pager
 'ascending_abbrev'         => 'ختند',
@@ -1303,9 +1319,12 @@
 'livepreview-loading' => 'د برسېرېدلو په حال کې...',
 
 # Watchlist editor
+'watchlistedit-noitems'    => 'ستاسو په کتلي لړليک کې هېڅ کوم سرليک نشته.',
 'watchlistedit-raw-title'  => 'خام کتلی لړليک سمادول',
 'watchlistedit-raw-legend' => 'خام کتلی لړليک سمادول',
 'watchlistedit-raw-titles' => 'سرليکونه:',
+'watchlistedit-raw-submit' => 'کتلی لړليک تازه کول',
+'watchlistedit-raw-done'   => 'ستاسو کتلی لړليک تازه شو.',
 
 # Watchlist editing tools
 'watchlisttools-view' => 'اړونده بدلونونه کتل',
@@ -1329,12 +1348,14 @@
 # Special:Version
 'version'              => 'بڼه', # Not used as normal message but as header for the special page itself
 'version-specialpages' => 'ځانګړي مخونه',
+'version-other'        => 'بل',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'دوتنه:',
 
 # Special:FileDuplicateSearch
-'fileduplicatesearch-submit' => 'پلټل',
+'fileduplicatesearch-filename' => 'د دوتنې نوم:',
+'fileduplicatesearch-submit'   => 'پلټل',
 
 # Special:SpecialPages
 'specialpages'                 => 'ځانګړي مخونه',
Index: languages/messages/MessagesAb.php
===================================================================
--- languages/messages/MessagesAb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,7 +1,20 @@
 <?php
-/**
+/** Abkhazian (Аҧсуа)
+ *
  * @ingroup Language
  * @file
+ *
+ * @author ОйЛ
  */
 
 $fallback = 'ru';
+
+$messages = array(
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'mainpage'             => 'Ихадоу адаҟьа',
+'mainpage-description' => 'Ихадоу адаҟьа',
+
+# Edit pages
+'summary' => 'Ятарлă саспаллисем:',
+
+);
Index: languages/messages/MessagesKsh.php
===================================================================
--- languages/messages/MessagesKsh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKsh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Caesius noh en Idee vum Manes
  * @author Purodha
- * @author Siebrand
- * @author Caesius noh en Idee vum Manes
  */
 
 /**
@@ -117,7 +116,7 @@
 'tog-highlightbroken'         => 'Zeich de Links op Sigge, die et noch nit jitt, esu met: „<a href="" class="new">Lemma</a>“ aan.<br />Wann De dat nit wells, weed et esu: „Lemma<a href="" class="internal">?</a>“ jezeich.',
 'tog-justify'                 => 'Dun de Avschnedde em Blocksatz aanzeije',
 'tog-hideminor'               => 'Dun de klein Mini-Änderunge (<strong>M</strong>) en de Liss  met „{{int:Recentchanges}}“ <strong>nit</strong> aanzeije',
-'tog-extendwatchlist'         => 'Verjrößer de Oppassliss för jede Aat vun möchliche Änderunge ze zeije',
+'tog-extendwatchlist'         => 'Verjrößer de Oppassliss för jede Aat vun müjjelich Änderunge ze zeije',
 'tog-usenewrc'                => 'Dun de opgemotzte Liss met „{{int:Recentchanges}}“ aanzeije (bruch Java_Skripp)',
 'tog-numberheadings'          => 'Dun de Üvverschrefte automatisch nummereere',
 'tog-showtoolbar'             => 'Zeich de Werkzeuchliss zom Ändere aan (bruch Java_Skripp)',
@@ -362,13 +361,13 @@
 'thisisdeleted'           => '$1 - aanluure oder widder zeröckholle?',
 'viewdeleted'             => '$1 aanzeije?',
 'restorelink'             => '{{PLURAL:$1|eijn fottjeschmesse Änderung|$1 fottjeschmesse Änderunge|keij fottjeschmesse Änderunge}}',
-'feedlinks'               => 'Feed:',
-'feed-invalid'            => 'Esu en Zoot Abonnemang jitt et nit.',
-'feed-unavailable'        => 'Mer han kein es en Feeds en dämm Wiki.',
-'site-rss-feed'           => 'RSS-Feed för $1',
-'site-atom-feed'          => 'Atom-Feed för $1',
-'page-rss-feed'           => 'RSS-Feed för „$1“',
-'page-atom-feed'          => 'Atom-Feed för „$1“',
+'feedlinks'               => 'Abonnomang-Kannal (<i lang="en">Feed</i>):',
+'feed-invalid'            => 'Esu en Zoot Abonnomang-Kannal (<i lang="en">Feed</i>) jitt et nit.',
+'feed-unavailable'        => 'Mer han kein esu en Abonnomangs-Kannäl (<i lang="en">Feeds</i>) en dämm Wiki aam Loufe.',
+'site-rss-feed'           => 'RSS-Abonnomang-Kannal (<i lang="en">Feed</i>) för de „$1“',
+'site-atom-feed'          => 'Atom-Abonnomang-Kannal (<i lang="en">Feed</i>) för de „$1“',
+'page-rss-feed'           => 'RSS-Abonnomang-Kannal (<i lang="en">Feed</i>) för de Sigg „$1“',
+'page-atom-feed'          => 'Atom-Abonnomang-Kannal (<i lang="en">Feed</i>) för de Sigg „$1“',
 'red-link-title'          => '$1 — en Sigg, die et noch nit jitt',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
@@ -387,7 +386,7 @@
 'nosuchaction'      => 'Die Aufgab (action) kenne mer nit',
 'nosuchactiontext'  => '<strong>Na su jet:</strong> De Aufgab us dä URL, die do hinger „<code>action=</code>“ dren steiht, jo die kennt hee dat Wiki jar nit.',
 'nosuchspecialpage' => "Esu en Sondersigg ha'mer nit",
-'nospecialpagetext' => 'De aanjefrochte Sondersigg jitt et nit, de [[Special:Specialpages|Liss met de Sondersigge]] helf Der wigger.',
+'nospecialpagetext' => 'De aanjefrochte Sondersigg jitt et nit, de [[Special:SpecialPages|Liss met de Sondersigge]] helf Der wigger.',
 
 # General errors
 'error'                => 'Fähler',
@@ -406,19 +405,21 @@
 MySQL meld dä Fähler: „<code>$3: $4</code>“.',
 'noconnect'            => 'Schad! Mer kunnte kein Verbindung met däm Daatebanksörver op „$1“ krije.',
 'nodb'                 => 'Kunnt de Daatebank „$1“ nit uswähle',
-'cachederror'          => 'Dat hee es en Kopie vun dä Sigg us em Cache. Möchlich, se es nit aktuell.',
+'cachederror'          => 'Dat hee es en Kopie vun dä Sigg us em Cache. Künnt sin, se es nit aktuell.',
 'laggedslavemode'      => '<strong>Opjepass:</strong> Künnt sin, dat hee nit dä neuste Stand vun dä Sigg aanjezeich weed.',
 'readonly'             => 'De Daatebank es jesperrt',
 'enterlockreason'      => 'Jevv aan, woröm un för wie lang dat de Daatebank jesperrt wääde soll',
 'readonlytext'         => 'De Daatebank es jesperrt. Neu Saache dren avspeichere jeiht jrad nit, un ändere och nit. Dä Jrund: „$1“',
 'missing-article'      => 'Dä Tex för de Sigg „$1“ $2 kunnte mer nit en de Daatebank finge.
 De Sigg es villeich fottjeschmesse oder ömjenannt woode.
-Wann dat esu nit sin sollt, dann hadder villeich ene Fähler en de Soffwär jefunge.
-Verzällt et enem Wiki_Köbes,
+Wann dat nidd esu sin sollt, dann hadder villeich ene Fähler en de Soffwär jefunge.
+Verzällt et enem [[Special:ListUsers/sysop|Wiki_Köbes]],
 un doht em och de URL vun dä Sigg hee sage.',
 'missingarticle-rev'   => '(Version Numero: $1)',
+'missingarticle-diff'  => '(Ongerscheed zwesche de Versione $1 un $2)',
 'readonly_lag'         => 'De Daatebank es för en koote Zigg jesperrt, för de Daate avzejliche.',
 'internalerror'        => 'De Wiki-Soffwär hät ene Fähler jefunge',
+'internalerror_info'   => 'Enne ennere Fäähler en de ßofwäer es opjetrodde: $1',
 'filecopyerror'        => 'Kunnt de Datei „$1“ nit noh „$2“ kopeere.',
 'filerenameerror'      => 'Kunnt de Datei „$1“ nit op „$2“ ömdäufe.',
 'filedeleteerror'      => 'Kunnt de Datei „$1“ nit fottschmieße.',
@@ -428,7 +429,7 @@
 'unexpected'           => 'Domet hät keiner jerechnet: „$1“=„$2“',
 'formerror'            => 'Dat es donevve jejange: Wor nix, met däm Fomular.',
 'badarticleerror'      => 'Dat jeiht met hee dä Sigg nit ze maache.',
-'cannotdelete'         => 'De Sigg oder de Datei hee fottzeschmieße es nit möchlich. Möchlich, dat ene andere Metmaacher flöcker wor, hät et vürher hee jo ald jedon, un jetz es die Sigg ald fott.',
+'cannotdelete'         => 'De Sigg oder de Datei hee fottzeschmieße es nit müjjelich. Mach sin, dat ene andere Metmaacher flöcker wor, hät et vürher hee jo ald jedon, un jetz es die Sigg ald fott.',
 'badtitle'             => 'Verkihrte Üvverschreff',
 'badtitletext'         => 'De Üvverschreff es esu nit en Odenung. Et muss jet dren stonn.
 Et künnt sin, dat ein vun de speziell Zeiche dren steiht,
@@ -467,26 +468,26 @@
 'virus-unknownscanner' => 'Dat Projamm fö noh Komjuterviere ze sööke kenne mer nit:',
 
 # Login and logout pages
-'logouttitle'                => 'Ußß_Logge',
+'logouttitle'                => 'Uslogge',
 'logouttext'                 => '<strong>Jetz bes de usjelogg</strong>
 
-Do künnts op de {{SITENAME}} wigger maache, als ene namelose Metmaacher. Do kanns De ävver och widder enlogge, als däselve oder och ene andere Metmaacher.
-Es möchlich, dat De de ein oder ander Sigg immer wigger aanjezeich kriss, wie wann de noch enjelogg wörs. Dun Dingem Brauser singe Cache fottschmieße oder leddich maache, öm us dä Nummer erus ze kumme!',
+Do künnts op de {{SITENAME}} wigger maache, als ene namelose Metmaacher. Do kanns De ävver och [[Special:UserLogin|widder enlogge]], als däselve oder och ene andere Metmaacher.
+Künnt sin, dat De de ein oder ander Sigg immer wigger aanjezeich kriss, wie wann de noch enjelogg wörs. Dun Dingem Brauser singe Cache fottschmieße oder leddich maache, öm us dä Nummer erus ze kumme!',
 'welcomecreation'            => '== Dach, $1! ==
 Dinge Zojang för hee es do.
 Do bes jetz aanjemeldt.
-Denk dran, Do künnts der Ding Enstellunge hee op de {{SITENAME}} zeräächmaache.',
+Denk dran, Do künnts Der [[Special:Preferences|Ding Enstellunge hee op de {{SITENAME}} zeräächmaache]].',
 'loginpagetitle'             => 'Enlogge',
 'yourname'                   => 'Metmaacher Name:',
 'yourpassword'               => 'Passwood',
 'yourpasswordagain'          => 'Noch ens dat Passwood',
 'remembermypassword'         => 'Op Duur Aanmelde',
 'yourdomainname'             => 'Ding Domain',
-'externaldberror'            => 'Do woo enne Fääler en de äxtärrne Daate_Bangk, oddo Do darrəfß Ding äxtärrn Daate nit änndere. Dat Aanmällde jingk donävve.',
-'loginproblem'               => '<strong>Med däm Ėnnlogge eß jëtt schëijf jeloufe.</strong><br />Beß esu jood, un důnn_et norr_enß fosööhke!',
-'login'                      => 'Ėnnlogge',
+'externaldberror'            => 'Do wor ene Fähler en de externe Daatebank, oder Do darfs Ding extern Daate nit ändere. Dat Aanmelde jingk jedenfalls donevve.',
+'loginproblem'               => '<strong>Met däm Enlogge es jet scheiv jelaufe.</strong><br />Bes esu jod, un dun et noch ens versöke!',
+'login'                      => 'Enlogge',
 'nav-login-createaccount'    => 'Enlogge, Aanmälde',
-'loginprompt'                => 'Öm op de {{SITENAME}} enlogge ze künne, muss De de Cookies en Dingem Brauser enjeschalt han.',
+'loginprompt'                => 'Öm [[Special:UserLogin|op de {{SITENAME}} enlogge]] ze künne, muss De de Cookies en Dingem Brauser enjeschalt han.',
 'userlogin'                  => 'Enlogge odder Metmaacher wääde',
 'logout'                     => 'Uslogge',
 'userlogout'                 => 'Uslogge',
@@ -497,23 +498,22 @@
 'gotaccount'                 => 'Do bes ald aanjemeldt op de {{SITENAME}}? Dann jangk nohm $1.',
 'gotaccountlink'             => 'Enlogge',
 'createaccountmail'          => 'Scheck mer en E-Mail met Passwood',
-'badretype'                  => 'Ding zwëij ennjejovvene Paßßwööter sinn ungerscheedlish. Do moßß_De Desch fö_ëijn änntschëijde.',
-'userexists'                 => 'Enne Metmaacher med_däm name jidd_et alld.
-Doh moßß De Der_enne anndere Naame ußdängke.',
+'badretype'                  => 'Ding zwëij ennjejovve Paßßwööter sinn nit ejaal. Do muss De Dich för ein entscheide.',
+'userexists'                 => 'Ene Metmaacher met däm Name jitt et ald. Schad. Do muss De Der ene andere Name usdenke.',
 'youremail'                  => 'E-Mail *',
 'username'                   => 'Metmaacher Name:',
 'uid'                        => 'Metmaacher Nommer:',
-'prefs-memberingroups'       => 'Bes en {{PLURAL:$1|de Metmaacherjrupp|<strong>$1</strong> Metmaacherjruppe|keijn Metmaacherjruppe}}',
+'prefs-memberingroups'       => 'Bes en {{PLURAL:$1|de Metmaacherjrupp:|<strong>$1</strong> Metmaacherjruppe:|keijn Metmaacherjruppe.}}',
 'yourrealname'               => 'Dinge richtije Name *',
 'yourlanguage'               => 'Die Sproch, die et Wiki kalle soll:',
 'yourvariant'                => 'Ding Variant',
 'yournick'                   => 'Name för en Ding Ungerschreff:',
 'badsig'                     => 'Di Ungeschreff jëijd_esu nit — luer noh dem HTML do_dren un maach et rėshtėsh.',
-'badsiglength'               => 'Ding Unterschref darf nit länger wi {{PLURAL:$1|eij|$1|keij}} Zeische änthallde.',
+'badsiglength'               => 'Ding Unterschref darf nit länger wi {{PLURAL:$1|eij|$1|keij}} Zeische sin.',
 'email'                      => 'e-mail',
 'prefs-help-realname'        => '* Dinge richtije Name - kanns De fott looße - wann De en nenne wells, dann weed hee jebruch, öm Ding Beidräch domet ze schmöcke.',
 'loginerror'                 => 'Fähler beim Enlogge',
-'prefs-help-email'           => '* E-mail - kanns De fottlooße, un es för Andre nit ze sinn - mäht et ävver möchlich, dat mer met Dir en Kontak kumme kann, ohne dat mer Dinge Name oder Ding E-Mail Adress kenne dät.',
+'prefs-help-email'           => '* E-mail - kanns De fottlooße, un es för Andre nit ze sinn - mäht et ävver müjjelich, dat mer met Dir en Kontak kumme kann, ohne dat mer Dinge Name oder Ding E-Mail Adress kenne dät.',
 'prefs-help-email-required'  => 'Do moß en jöltije E-Mail-Adress aanjevve.',
 'nocookiesnew'               => 'Dinge neue Metmaacher Name es enjerich, ävver dat automatisch Enlogge wor dann nix. 
 Schad.
@@ -526,7 +526,7 @@
 'loginsuccess'               => '<br />Do bes jetz enjelogg bei de <strong>{{SITENAME}}</strong>, un Dinge Metmaacher Name es „<strong>$1</strong>“.<br />',
 'nosuchuser'                 => 'Dat Passwood oder dä Metmaacher Name „$1“ wor verkihrt.
 Jetz muss De et noch ens versöke.
-Oder_<span class="plainlinks">[{{FULLURL:Special:Userlogin|type=signup}} ene neue Metmaacher aanmelde]</span>.',
+Oder_<span class="plainlinks">[{{FULLURL:Special:UserLogin|type=signup}} ene neue Metmaacher aanmelde]</span>.',
 'nosuchusershort'            => 'Dä Metmaacher Name „<nowiki>$1</nowiki>“ wor verkihrt. Jetz muss De et noch ens versöke.',
 'nouserspecified'            => 'Dat jeiht nit als ene Metmaacher Name',
 'wrongpassword'              => 'Dat Passwood oder dä Metmaacher Name wor verkihrt. Jetz muss De et noch ens versöke.',
@@ -534,7 +534,7 @@
 'passwordtooshort'           => 'Dat Passwood es jet koot - et mööte ald winnichstens <strong>$1</strong> Zeiche, Zeffer{{PLURAL:$1||e|e}}, un Buchstave do dren sin.',
 'mailmypassword'             => 'Passwood verjesse?',
 'passwordremindertitle'      => 'Enlogge op {{SITENAME}}',
-'passwordremindertext'       => 'Jod möchlich, Do wors et selver,
+'passwordremindertext'       => 'Jod müjjelich, Do wors et selver,
 vun de IP Adress $1,
 jedenfalls hät eine aanjefroch, dat
 mer Dir e neu Passwood zoschecke soll,
@@ -572,7 +572,7 @@
 eets  ens bestätich woode sin. Wat mer doför maache muss, steiht en dä E-Mail dren, die jrad avjescheck woode es.',
 'throttled-mailpassword'     => 'En Erennerung för di Passwood es ungerwähs. Domet ene fiese Möpp keine Dress fabrizeet, passeet dat hüchstens eimol en {{PLURAL:$1|der Stund|$1 Stunde|nidd ens eine Stund}}.',
 'mailerror'                  => 'Fähler beim E-Mail Verschecke: $1.',
-'acct_creation_throttle_hit' => '<b>Schad.</b> Do häs ald {{PLURAL:$1|eine|$1|keine}} Metmaacher Name aanjelaht. Mieh sin nit möchlich.',
+'acct_creation_throttle_hit' => '<b>Schad.</b> Do häs ald {{PLURAL:$1|eine|$1|keine}} Metmaacher Name aanjelaht. Mieh sin nit müjjelich.',
 'emailauthenticated'         => 'Ding E-Mail Adress wood bestätich om: <strong>$1</strong>.',
 'emailnotauthenticated'      => 'Ding E-Mail Adress es <strong>nit</strong> bestätich. Dröm kann kein E-Mail aan Dich jescheck wääde för:',
 'noemailprefs'               => 'Dun en E-Mail Adress endrage, domet dat et all fluppe kann.',
@@ -592,8 +592,15 @@
 'loginlanguagelabel'         => 'Sproch: $1',
 
 # Password reset dialog
-'resetpass_text'    => '<!-- Donn der Täx hee dobei -->',
-'resetpass_missing' => "'''Fähler:''' Nix enjejovve, odder de Daate ussem Fomulaa sen fott.",
+'resetpass'               => 'Neu Zweschepasswoot övver e-mail bekumme',
+'resetpass_announce'      => 'De beß jez enjelogg med ennem Zweschepasswoot, wat De övver e-mail krääje häs. Dat kanns De nit einfar_esu behallde. Alsu donn jetz e neu Passwoot för op Duur aanjevve.',
+'resetpass_text'          => '<!-- Donn der Täx hee dobei -->',
+'resetpass_header'        => 'Neu Passwood',
+'resetpass_submit'        => 'E neu Zweschepasswood övvermeddele un aanmellde',
+'resetpass_success'       => 'Passwood jeändert. Jetz küdd_et Enlogge&nbsp;…',
+'resetpass_bad_temporary' => 'Da Zweschepasswoot es nix. Do häs ald ding Passwoot jeändert, udder De häs zweschedren ald widder e neu Passwoot pä e-mail jescheck bekumme.',
+'resetpass_forbidden'     => 'E Passwoot kann in de {{SITENAME}} nit jeändert wääde.',
+'resetpass_missing'       => "'''Fähler:''' Nix enjejovve, odder de Daate ussem Fomulaa sen fott.",
 
 # Edit page toolbar
 'bold_sample'     => 'Fett Schreff',
@@ -634,25 +641,25 @@
 'summary-preview'                  => 'Vör-Aansich vun „Koot Zosammejefass, Quell“',
 'subject-preview'                  => 'Vör-Aansich vun de Üvverschreff',
 'blockedtitle'                     => 'Dä Metmaacher es jesperrt',
-'blockedtext'                      => "<big>'''Dinge Metmaacher-Name oder IP Adress es vun „\$1“ jesperrt woode.'''</big>
+'blockedtext'                      => '<big>\'\'\'Dinge Metmaacher-Name oder IP Adress es vun „$1“ jesperrt woode.\'\'\'</big>
 
-Als Jrund es enjedrage: „''\$2''“
+Als Jrund es enjedrage: „\'\'$2\'\'“
 
 Do kanns hee em Wiki immer noch lesse. Do sühß ävver di Sigg hee, wann De op rude Links klicks, neu Sigge aanlääje, odder Sigge ändere wells, denn doför bes De jetz jesperrt.
 
-Do kanns met \$1 oder enem andere [[{{MediaWiki:Grouppage-sysop}}|Wiki-Köbes]] üvver dat Sperre schwaade, wann De wells.
-Do kanns ävver nor dann „''E-Mail aan dä Metmaacher''“ aanwende, wann De ald en E-Mail Adress en Dinge [[Special:Preferences|Enstellunge]] enjedrage un freijejovve häs un wann et E-mail schecke nit metjesperrt es.
+Do kanns met $1 oder enem andere [[{{MediaWiki:Grouppage-sysop}}|Wiki-Köbes]] üvver dat Sperre schwaade, wann De wells.
+Do kanns ävver nor dann „\'\'E-Mail aan dä Metmaacher\'\'“ aanwende, wann De ald en E-Mail Adress en Dinge [[Special:Preferences|Enstellunge]] enjedrage un freijejovve häs un wann et E-mail schecke nit metjesperrt es.
 
 Dun en Ding Aanfroge nenne:
-* Dä Wiki-Köbeß, dä jesperrt hät: \$1
-* Der Jrond för et Sperre: \$2
-* Da wood jesperrt: \$8
-* De Sperr soll loufe bes: \$6
-* De Nommer vun dä Sperr: #\$5
-* Ding IP-Adress is jetz: \$3
-* Di Sperr es wäje odde jäje: \$7
+* Dä Wiki-Köbeß, dä jesperrt hät: $1
+* Der Jrond för et Sperre: $2
+* Da wood jesperrt: $8
+* De Sperr soll loufe bes: $6
+* De Nommer vun dä Sperr: #$5
+* Ding IP-Adress is jetz: $3
+* Di Sperr es wäje odde jäje: $7
 
-Do kanns och noch en et <span class=\"plainlinks\">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}\$5 Logbooch met de Sperre ]</span> loore.",
+Do kanns och noch en et <span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=$3}}$5 Logboch met de Sperre ]</span> loore.',
 'autoblockedtext'                  => "<big>'''Ding IP Adress es automattesch jesperrt woode.'''</big>
 <br />
 '''Se wor vun enem Metmaacher jebruch woode, dä vun „\$1“ jesperrt woode es.'''
@@ -673,22 +680,18 @@
 * Ding IP-Adress is jetz: \$3
 * Di Sperr es wäje odde jäje: \$7
 
-Do kanns och noch en et <span class=\"plainlinks\">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}\$5 Logbooch met de Sperre ]</span> loore.",
+Do kanns och noch en et <span class=\"plainlinks\">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}\$5 Logboch met de Sperre ]</span> loore.",
 'blockednoreason'                  => 'Keine Aanlass aanjejovve',
 'blockedoriginalsource'            => 'Dä orjenal Wiki Tex vun dä Sigg „<strong>$1</strong>“ steiht hee drunger:',
 'blockededitsource'                => 'Dä Wiki Tex vun <strong>Dinge Änderunge</strong> aan dä Sigg „<strong>$1</strong>“ steiht hee drunger:',
-'whitelistedittitle'               => 'Enlogge es nüdich för Sigge ze Ändere',
+'whitelistedittitle'               => '[[Special:UserLogin|Enlogge]] es nüdich för Sigge ze Ändere',
 'whitelistedittext'                => 'Do mööts ald $1, öm hee em Wiki Sigge ändere ze dürfe.',
-'whitelistreadtitle'               => 'Enlogge es nüdich för ze Lese',
-'whitelistreadtext'                => 'Do mööts ald_[[Special:Userlogin|enjelogg sin]], öm hee Sigge lese ze dürfe.',
-'whitelistacctitle'                => 'Kei Rääch för Metmaacher aanzeläje.',
-'whitelistacctext'                 => 'Do mööts ald [[Special:Userlogin|enjelogg sin]] un speziell et Rääch doför han, öm hee en däm Wiki Metmaacher enrichte un aanläje ze dürfe.',
 'confirmedittitle'                 => 'För et Sigge Ändere muss De Ding E-Mail Adress ald bestätich han.',
 'confirmedittext'                  => 'Do muss Ding E-Mail Adress ald bestätich han, ih dat De hee Sigge ändere darfs.
 Drag Ding E-Mail Adress en Ding [[Special:Preferences|ming Enstellunge]] en, un dun „Dun Ding E-Mail Adress bestätije looße“ klicke.',
 'nosuchsectiontitle'               => "Dä Afschnitt ham'mer nit",
-'nosuchsectiontext'                => 'Do häß versooch, ene Avschnet ze ändere, dä mer janit han,
-de Nommer <strong>„$1“</strong>.
+'nosuchsectiontext'                => 'Do häß versooch, ene Avschnet ze ändere,
+dä mer janit han, däm sing Nommer es <strong>„$1“</strong>.
 Esu lang wie et dä nit jit, hätte mer keine Plaz, wo hen met Dingem Täx.',
 'loginreqtitle'                    => 'Enlogge es nüdich',
 'loginreqlink'                     => 'enjelogg sin',
@@ -706,8 +709,8 @@
 Su en IP Adress kann vun janz vill Metmaacher jebruch wääde, un eine Metmaacher kann janz flöck 
 zwesche de ungerscheedlichste IP Adresse wähßele, womöchlich ohne dat hä et merk. Wann Do jetz ene namenlose 
 Metmaacher bes, un fings, dat hee Saache an Dich jeschrevve wääde, wo Do jar nix met am Hot häs, dann bes Do 
-wahrscheinlich och nit jemeint. Denk villeich ens drüvver noh, datte Dich [[Special:Userlogin|anmelde]] deis, 
-domet De dann donoh nit mieh met esu en Ömständ ze dun häs, wie de andere namenlose Metmaacher hee.</i>',
+wahrscheinlich och nit jemeint. Denk villeich ens drüvver noh, datte Dich [[Special:UserLogin/signup|anmelde]] deis, 
+domet De dann donoh nit mieh met esu en Ömständ ze dun häs, wie de andere namenlose Metmaacher hee. Wann de aanjemelldt bes un deis [[Special:UserLogin|enlogge]], dann kam_mer Desch och dun alle andere Metmaacher ongerschejde.</i>',
 'noarticletext'                    => '<span class="plainlinks">Em Momang es keine Tex op dä Sigg. Jangk en de Texte vun ander Sigge [[Special:Search/{{PAGENAME}}|noh däm Titel söke]], oder [{{FULLURL:{{FULLPAGENAME}}|action=edit}} fang die Sigg aan] ze schrieve, oder jangk zeröck wo de her koms. Dinge Brauser hät ene Knopp doför.</span>',
 'userpage-userdoesnotexist'        => 'Enne Metmaacher „$1“ hammer nit, beß De secher, dat De die Metmaachersigg ändere oder aanläje wellss?.',
 'clearyourcache'                   => "<br clear=\"all\" style=\"clear:both\">
@@ -749,12 +752,13 @@
 Esu wööd dä Atikkel ussinn, wann De n jetz avspeichere däts.',
 'session_fail_preview'             => '<strong>Schad: Ding Änderunge kunnte mer su nix met aanfange.
 Versök et jrad noch ens.
-Wann dat widder nit flupp, dann versök et ens met Uslogge un widder Enlogge.</strong>',
+Wann dat widder nit flupp, dann versök et ens met [[Special:UserLogout|Uslogge]] un widder Enlogge.</strong>',
 'session_fail_preview_html'        => "<strong>Schad: Ding Änderunge kunnte mer su nix met aanfange. De Daate vun Dinge Login-Säschen sin nit öntlich erüvver jekumme, oder einfach ze alt.</strong>
 
 ''Dat Wiki hee hät rüh HTML zojelooße, dröm weed de Vör-Aansich nit jezeich. Domet solls De jeschötz wääde - hoffe mer - un Aanjreffe met Java_Skripp jäje Dinge Kompjuter künne Der nix aandun.''
 
-<strong>Falls för Dich söns alles jod ussüht, versök et jrad noch ens. Wann dat widder nit flupp, dann versök et ens met Uslogge un widder Enlogge.</strong>",
+<strong>Falls för Dich söns alles jod ussüht, versök et jrad noch ens. Wann dat widder nit flupp, dann versök et ens met [[Special:UserLogout|Uslogge]] un widder Enlogge.</strong>",
+'token_suffix_mismatch'            => '<strong>Ding Änderung ham_mer nit övvernomme. Dinge Brauser hät Sazzeijche em verstoche <i lang="en">Token</i> för et Ändere versout. Dat paßeet och ens, wann enne <i lang="en">Proxy</i> nit fungkßjeneet. Et Affspeichere wör do jefährlesch, do künt dä Sigge_Enhaldt kapott bei jon.</strong>',
 'editing'                          => 'De Sigg „$1“ ändere',
 'editingsection'                   => 'Ne Avschnedd vun dä Sigg: „$1“ ändere',
 'editingcomment'                   => '„$1“ Ändere (ene neue Avschnedd schrieve)',
@@ -802,8 +806,7 @@
 Dun se bei Dir om Rechner fasshalde un versök et späder noch ens.',
 'protectedpagewarning'             => "'''Opjepass:''' Die Sigg hee es jäje Veränderunge jeschötz. Nor de Wiki-Köbese künne se ändere.</strong>",
 'semiprotectedpagewarning'         => "'''Opjepass:''' Die Sigg hee es halv jesperrt, wie mer sage, dat heiß, Do muss aanjemeldt un enjelogg sin, wann De dran ändere wells.",
-'cascadeprotectedwarning'          => "'''Opjepaß:''' Die Sigg es jeschöz, un nur de Wiki-Köbesse künne se ändere. Se es en en Schotz-Kaskad enjebonge, zosamme met dä {{PLURAL:$1|Sigg|Sigge}}:
-$2",
+'cascadeprotectedwarning'          => "'''Opjepaß:''' Die Sigg es jeschöz, un nur de Wiki-Köbesse künne se ändere. Se es en en Schotz-Kaskad enjebonge, zosamme met dä {{PLURAL:$1|Sigg|Sigge}}:",
 'titleprotectedwarning'            => '<strong> <span style="text-transform:uppercase"> Opjepaß! </span> Di Sigg hee is jesperrt woode. Bloß bestemmpte Metmaacher dörve di Sigg neu aanläje.</strong>',
 'templatesused'                    => 'De Schablone, die vun dä Sigg hee jebruch wääde, sinn:',
 'templatesusedpreview'             => 'Schablone en dä Vör-Aansich hee:',
@@ -812,8 +815,8 @@
 'template-semiprotected'           => '(halfjeschöz - tabu för neu Metmaacher un ohne Enlogge)',
 'hiddencategories'                 => 'Die Sigg hee is en {{PLURAL:$1|de verstoche Saachjrupp: |$1 verstoche Saachjruppe: |keij verstoche Saachjruppe dren.}}',
 'edittools'                        => '<!-- Dä Tex hee zeich et Wiki unger däm Texfeld zom „Ändere/Bearbeide“ un beim Texfeld vum „Huhlade“. -->',
-'nocreatetitle'                    => 'Neu Sigge Aanläje eß nit einfach esu mööschlesch.',
-'nocreatetext'                     => 'Sigge neu aanläje es nor möchlich, wann de [[Special:Userlogin|enjelogg]] bes. Der ohne kanns De ävver Sigge ändere, die ald do sin.',
+'nocreatetitle'                    => 'Neu Sigge Aanläje eß nit einfach esu müjjelesch.',
+'nocreatetext'                     => 'Sigge neu aanläje es nor müjjelich, wann de [[Special:UserLogin|enjelogg]] bes. Der ohne kanns De ävver Sigge ändere, die ald do sin.',
 'nocreate-loggedin'                => 'Do häs nit dat Rääch, neu Sigge hee en däm Wiki aanzelääje.',
 'permissionserrors'                => 'Dat jeit nit, dat darfs de nit.',
 'permissionserrorstext'            => 'Do häs nit dat Rääch, dat ze maache, {{PLURAL:$1|dä Jrund es:|de Jründe sin:|oohne Jrund.}}',
@@ -821,9 +824,19 @@
 {{PLURAL:$1|dä Jrund es:|de Jründe sin:|oohne Jrund.}}',
 'recreate-deleted-warn'            => "'''Opjepaß:''' Do bes om bäste Wääsh, en Sigg neu aanzelääje, di doför ald ens fottjeschmeße woode wohr.
 Bes förseschtesch un övverlääsch Der, of dat en joode Idee es, di Sigg widder opzemaache.
-Domet De Bescheid weiß, hee dä Endraach em Logbooch vum Sigge-Fottschmieße mem Jrond,
+Domet De Bescheid weiß, hee dä Endraach em Logboch vum Sigge-Fottschmieße mem Jrond,
 woröm di Sigg dohmohls fottjeschmesse woode es:",
 
+# Parser/template warnings
+'expensive-parserfunction-warning'        => "'''Opjepaß:''' Die Sigge hee määt zovill Opwand met Paaser-Funkßjohne.
+
+{{PLURAL:$2|Eine Oproof|Beß $2 Oproofe|Keine Oproof}} es älaup, {{PLURAL:$1|un eine Oproof|ävver $1 Oproofe|un keine Oproof}} määt di Sigg.",
+'expensive-parserfunction-category'       => 'Sigge met zovill Opwand en Paaser-Funkßjohne',
+'post-expand-template-inclusion-warning'  => 'Warnung: Hee in di Sigg wääde zo fill Bytes övver Schablone erin jebraat. Nit all di Schablone künne enjbonge wäde.',
+'post-expand-template-inclusion-category' => 'Sigge met zoh jruuße Schablone enjebonge',
+'post-expand-template-argument-warning'   => 'Opjepaß: Di Sigg hee hät winnischßdens eine Parrammeeter en ennem Schablone-Oprof wat ze jroß weed beim Enfölle. Esu en Parrameetere möße mer övverjonn.',
+'post-expand-template-argument-category'  => 'Sigge met övverjange Parrammeeter fun Schablone',
+
 # "Undo" feature
 'undo-success' => 'De Änderung könnte mer zeröck nämme. Beloor Der de Ungerscheed un dann donn di Sigg avspeichere, wann De dengks, et es en Oodenung esu.',
 'undo-failure' => '<span class="error">Dat kunnt mer nit zeröck nämme, dä Afschnedd wood enzwesche ald widder beärbeidt.</span>',
@@ -867,15 +880,15 @@
 'historyempty'        => '(leddich)',
 
 # Revision feed
-'history-feed-title'          => 'Versione',
+'history-feed-title'          => 'De Versione',
 'history-feed-description'    => 'Ählere Versione vun dä Sigg en de {{SITENAME}}',
 'history-feed-item-nocomment' => '$1 öm $2', # user at time
-'history-feed-empty'          => 'De aanjefrochte Sigg jitt et nit. Künnt sin, dat se enzwesche fottjeschmesse oder ömjenannt woode es. Kanns jo ens [[Special:Search|em Wiki söke looße]], öm zopass neu Sigge ze finge.',
+'history-feed-empty'          => 'De aanjefrochte Sigg jitt et nit. Künnt sin, dat se enzwesche fottjeschmesse udder ömjenannt woode es. Kanns jo ens [[Special:Search|em Wiki söke looße]], öm de zopass, neu Sigge ze finge.',
 
 # Revision deletion
 'rev-deleted-comment'         => '(„Koot Zosammejefass, Quell“ usjeblendt)',
 'rev-deleted-user'            => '(Metmaacher Name usjeblendt)',
-'rev-deleted-event'           => '(Logbooch-Enndraach fottjenomme)',
+'rev-deleted-event'           => '(Logboch-Enndraach fottjenomme)',
 'rev-deleted-text-permission' => '<div class="mw-warning plainlinks">Die Version es fottjeschmesse woode.
 Jetz ka\'mer se nit mieh beluure.
 Ene Wiki Köbes künnt se ävver zeröck holle.
@@ -887,20 +900,25 @@
 'revdelete-nooldid-title'     => 'Kein Version aanjejovve, oddeer en Stuß-Nommer',
 'revdelete-nooldid-text'      => 'Do häs kein Version aanjejovve, womet mer dat maache sulle. Odder de Nommer wohr Stuß, verkeeht, et jitt se nit, odder De wellß de neuste Version fott maache.',
 'revdelete-selected'          => '{{PLURAL:$2|Ein usjewählte Version|$2 usjewählte Versione|Kein Version usjewählt}} vun [[:$1]]:',
+'logdelete-selected'          => '{{PLURAL:$1|Dä ußjewählte Logboch-Endrach|De Ußjewählte Logboch-Endrähsch}}:',
 'revdelete-text'              => 'Dä fottjeschmesse Sigge ehre Enhald kanns De nit mieh aanluure. Se blieve ävver en de Liss met de Versione dren.
 
 Ene Wiki Köbes kann de fottjeschmessene Krom immer noch aanluere un kann en och widder herholle, usser wann bei 
 dem Wiki singe Installation dat anders fassjelaht woode es.',
 'revdelete-legend'            => 'Dä öffentlije Zojang enschränke',
 'revdelete-hide-text'         => 'Dä Tex vun dä Version versteiche',
-'revdelete-hide-name'         => 'Der Förjang, un och der Enndraach uss_em Logbooch, versteiche',
+'revdelete-hide-name'         => 'Der Förjang, un och der Enndraach uss_em Logboch, versteiche',
 'revdelete-hide-comment'      => 'Dä Enhald vun „Koot Zosammejefass, Quell“ usblende',
 'revdelete-hide-user'         => 'Däm Bearbeider sing IP Adress oder Metmaacher Name versteiche',
 'revdelete-hide-restricted'   => 'Dun dat och för de Wiki Köbese esu maache wie för jede Andere',
+'revdelete-suppress'          => 'Donn dä Jrond och för de Wiki-Köbesse versteische',
 'revdelete-hide-image'        => 'De Enhallt vun däm Beld versteiche',
+'revdelete-unsuppress'        => 'De Beschrängkonge för der widderjehollte Versione ophevve',
 'revdelete-log'               => 'Bemerkung för et LogBoch:',
 'revdelete-submit'            => 'Op de aanjekrützte Version aanwende',
 'revdelete-logentry'          => 'Zojang zo de Versione verändert för „[[$1]]“',
+'logdelete-logentry'          => '„[[$1]]“ verstoche udder widder seeschba jemaat',
+'revdel-restore'              => 'Versteische udder Seeschba maache',
 'pagehist'                    => 'Älldere Versione',
 'deletedhist'                 => 'Fottjeschmesse Versione',
 'revdelete-content'           => 'dä Enhalt fun dä Sigg',
@@ -911,7 +929,38 @@
 'revdelete-hid'               => '$1 verstoche',
 'revdelete-unhid'             => '$1 weder seeschbaa jemaat',
 'revdelete-log-message'       => 'hät för {{PLURAL:$1|eij Version|$2 Versione|nix}} $1',
+'logdelete-log-message'       => '$1 för {{PLURAL:$2|eine Endraach|$2 Endräch|keine Endraach}} em Logbooch',
 
+# Suppression log
+'suppressionlogtext' => 'Hee noh kütt et Logboch fum Versteiche, woh Versione fun Sigge, Zosammefassunge, Quelle, Metmaachername un Metmaacher-Sperre ze fenge sin, di fun de Oure vun de Öffentleschkeit, un och fun de Wiki-Köbesse verstoche woodte, udder widder zeröck op nommaal jebraat woodte.',
+
+# History merging
+'mergehistory'                     => 'Versione fun Sigge zosamme schmiiße',
+'mergehistory-header'              => 'Met hee dä Sündersigge kanns Du de Versione fun en Urshprongssigg met de Versione fun en neuer Zielsigg zosamme läje. Donn drop aade, dat der Zosammehang fun dä Versione am Engk reschtesch es.',
+'mergehistory-box'                 => 'Versione fun zwei Sigge zosamme läje',
+'mergehistory-from'                => 'Ursprongssigg:',
+'mergehistory-into'                => 'Zielsigg:',
+'mergehistory-list'                => 'Versione, di zosamme jelaat wäde künne',
+'mergehistory-merge'               => 'De Versione onge künne fun „[[:$1]]“ noh „[[:$2]]“ övverdraare wäde.
+Donn de Version makeere bes wohen (inklusive) dat övverdraare wäde sull. Donn drop aachjevve, dat de Ußwahl fott es, wann De op eine fun dä Links klicks.',
+'mergehistory-go'                  => 'Don Versione zeije, di mer zosamme läje künne',
+'mergehistory-submit'              => 'Versione zosamme läje',
+'mergehistory-empty'               => 'Mer han kei Versione för zesammezeläje',
+'mergehistory-success'             => '{{PLURAL:$3|Ein Version es|$3 Versione sen|Kei Version wood}} fun „[[:$1]]“ noh „[[:$2]]“ övverdraare un domet zosamme jelaat.',
+'mergehistory-fail'                => 'Dat Versione zesamme läje is nit müjjelisch. Don ens di Sigge un de Zigge pröfe!',
+'mergehistory-no-source'           => 'En Ursprungssigg „$1“ jidd_et nit.',
+'mergehistory-no-destination'      => 'En Zielsigg „$1“ jidd_et nit.',
+'mergehistory-invalid-source'      => 'De Ursprungssigg ier Name moß och ene reschtijje Siggetittel sin.',
+'mergehistory-invalid-destination' => 'De Zielsigg ier Name moß och ene reschtijje Siggetittel sin.',
+'mergehistory-autocomment'         => '„[[:$1]]“ es jetz zosamme jelaat met „[[:$2]]“',
+'mergehistory-comment'             => '„[[:$1]]“ zosamme jelaat met „[[:$2]]“ — $3',
+
+# Merge log
+'mergelog'           => 'Logboch fum Sigge zesamme Läje',
+'pagemerge-logentry' => 'Versione beß $3 fun „[[:$1]]“ zosamme jelaat met „[[:$2]]“',
+'revertmerge'        => 'Dat Zosammelääje widder retuur maache',
+'mergelogpagetext'   => 'Dat hee is dat Logbooch fun de zesammejelaate Versione fun Sigge',
+
 # Diffs
 'history-title'           => 'Liss met Versione vun „$1“',
 'difference'              => '(Ungerscheed zwesche de Versione)',
@@ -923,11 +972,12 @@
 # Search results
 'searchresults'             => 'Wat beim Söke eruskom',
 'searchresulttext'          => 'Luur en de [[{{MediaWiki:Helppage}}|{{int:help}}]]-Sigge noh, wann de mieh drüvver wesse wells, wie mer en de {{SITENAME}} jet fingk.',
-'searchsubtitle'            => 'För Ding Froch noh „[[:$1]]“.',
+'searchsubtitle'            => 'För Ding Froch noh „[[:$1|$1]]“ — ([[Special:Prefixindex/$1|Sigge, di met „$1“ annfange]] | [[Special:WhatLinksHere/$1|Sigge, di Links noh „$1“ han]])',
 'searchsubtitleinvalid'     => 'För Ding Froch noh „$1“',
 'noexactmatch'              => 'Mer han kein Sigg met jenau däm Name „<strong>$1</strong>“ jefunge.
 Do kanns se [[:$1|aanläje]], wann De wells.',
 'noexactmatch-nocreate'     => "'''Et jitt kei Sigg met däm Titel „$1“.'''",
+'toomanymatches'            => 'Dat wore zo vill Treffer, beß esu joot, un donn en annder Ußwahl probeere!',
 'titlematches'              => 'Zopass Üvverschrefte',
 'notitlematches'            => 'Kein zopass Üvverschrefte',
 'textmatches'               => 'Sigge met däm Täx',
@@ -936,17 +986,22 @@
 'nextn'                     => 'de nächste $1 zeije',
 'viewprevnext'              => 'Bläddere: ($1) ($2) ($3).',
 'search-result-size'        => '$1 ({{PLURAL:$2|Eij Woot|$2 Wööter|Keij Woot}})',
+'search-result-score'       => 'Jeweesch: $1%',
 'search-redirect'           => '(Ömleitung $1)',
 'search-section'            => '(Avschnett $1)',
 'search-suggest'            => 'Häß De „$1“ jemeint?',
+'search-interwiki-caption'  => 'Schwesterprojekte',
+'search-interwiki-default'  => '$1 hät hee di Träffer jefonge:',
 'search-interwiki-more'     => '(mieh)',
 'search-mwsuggest-enabled'  => 'met Vürschläsh',
 'search-mwsuggest-disabled' => 'ohne Vürschläsh',
+'search-relatedarticle'     => 'Ähnlesch',
 'mwsuggest-disable'         => 'Kein automatische Hölp-Liss per Ajax beim Tippe em Feld för et Söke',
 'searchrelated'             => 'ähnlesch',
 'searchall'                 => 'all',
 'showingresults'            => 'Unge {{PLURAL:$1|weed <strong>eine</strong>|wääde bes <strong>$1</strong>|weed <strong>keine</strong>}} vun de jefunge Endräch jezeich, vun de Nummer <strong>$2</strong> av.',
 'showingresultsnum'         => 'Unge {{PLURAL:$3|es ein|sin <strong>$3</strong>|sin <strong>kein</strong>}} vun de jefunge Endräch opjeliss, vun de Nummer <strong>$2</strong> av.',
+'showingresultstotal'       => "Hee {{PLURAL:$4|kütt der Treffer Numero '''$1''' uß|kumme de Treffer '''$1''' beß '''$2''' fun}} '''$3:'''",
 'nonefound'                 => '<strong>Opjepass:</strong>
 Wann beim Söke nix erus kütt, do kann dat dran lije, dat mer esu janz jewöhnliche Wööd, wie „hät“, „alsu“, „wääde“, un „sin“, uew. jar nit esu en de Daatebank dren han, dat se jefonge wääde künnte.',
 'powersearch'               => 'Söke',
@@ -954,6 +1009,7 @@
 'powersearch-ns'            => 'Söök en de Apachtemangs:',
 'powersearch-redir'         => 'Ömleidunge aanzeije',
 'powersearch-field'         => 'Söök noh:',
+'search-external'           => 'Söke fun Ußerhallef',
 'searchdisabled'            => 'Dat Söke hee op de {{SITENAME}} es em Momang avjeschalt.
 Dat weed op dänne Sörver ad ens jemaat, domet de Lass op inne nit ze jroß weed,
 un winnichstens dat normale Sigge Oprofe flöck jenoch jeiht.
@@ -969,7 +1025,7 @@
 'mypreferences'            => 'Ming Enstellunge',
 'prefs-edits'              => 'Aanzahl Änderunge am Wiki:',
 'prefsnologin'             => 'Nit Enjelogg',
-'prefsnologintext'         => 'Do mööts ald [[Special:Userlogin|enjelogg]] sin, öm Ding Enstellunge ze ändere.',
+'prefsnologintext'         => 'Do mööts ald [[Special:UserLogin|enjelogg]] sin, öm Ding Enstellunge ze ändere.',
 'prefsreset'               => 'De Enstellunge woodte jetz op Standard zeröck jesatz.',
 'qbsettings'               => '„Flöcke Links“',
 'qbsettings-none'          => 'Fottlooße, dat well ich nit sinn',
@@ -1044,7 +1100,7 @@
 'userrights-reason'           => 'Aanlaß odder Jrund:',
 'userrights-no-interwiki'     => 'Do häs nit dat Rääsch, Metmaacher ier Rääschte in ander Wikis ze ändere.',
 'userrights-nodatabase'       => 'De Datebank „<strong>$1</strong>“ is nit doh, oder se litt op enem andere Söver.',
-'userrights-nologin'          => 'Do moss als ene Wiki-Köbes [[Special:Userlogin|enjelog sin]], för dat De Metmaacher ier Rääschte ändere kanns.',
+'userrights-nologin'          => 'Do moss als ene Wiki-Köbes [[Special:UserLogin|enjelog sin]], för dat De Metmaacher ier Rääschte ändere kanns.',
 'userrights-notallowed'       => 'Do häs nit dat Rääsch, Rääschte aan Metmaacher ze verdeile.',
 'userrights-changeable-col'   => 'Jruppe, die De ändere kanns',
 'userrights-unchangeable-col' => 'Jruppe, die De nit ändere kanns',
@@ -1113,6 +1169,7 @@
 'right-editusercssjs'        => 'Anderlücks CSS- un JS-Dateie ändere',
 'right-rollback'             => 'All de letzte Änderunge fom letzte Metmaacher aan ene Sigg retur maache',
 'right-markbotedits'         => 'Retur jemaate Änderonge als Bot-Änderung makeere',
+'right-noratelimit'          => 'Kein Beschränkunge dorch Jrenze (<i lang="en">[http://www.mediawiki.org/wiki/Manual:%24wgRateLimits $wgRateLimits]</i>)',
 'right-import'               => 'Sigge uß ander Wikis Empochteere',
 'right-importupload'         => 'Sigge övver et XML-Datei-Huhlade empochteere',
 'right-patrol'               => 'Anderlücks Änderunge aan Sigge als „nohjeloort“ makeere',
@@ -1135,7 +1192,7 @@
 'nchanges'                          => '{{PLURAL:$1|Ein Änderung|$1 Änderunge|Kein Änderung}}',
 'recentchanges'                     => 'Neuste Änderunge',
 'recentchangestext'                 => 'Op dä Sigg hee sin de neuste Änderunge am Wiki opjeliss.',
-'recentchanges-feed-description'    => 'Op dämm Feed kannze de {{int:recentchanges}} aam Wiki en Laif un en Färve metloore.',
+'recentchanges-feed-description'    => 'Op dämm Abonnomang-Kannal (<i lang="en">Feed</i>) kannze de {{int:recentchanges}} aam Wiki en Laif un en Färve metloore.',
 'rcnote'                            => '{{PLURAL:$1|Hee is de letzte Änderung us|Hee sin de letzte <strong>$1</strong> Änderunge us|Et jit <strong>kei</strong> Änderunge en}} {{PLURAL:$2|däm letzte Dag|de letzte <strong>$2</strong> Dage|dä Zick}} vum $4 aff $5 Uhr beß jetz.',
 'rcnotefrom'                        => 'Hee sin bes <strong>$1</strong> fun de Änderunge zick <strong>$2</strong> opjeliss.',
 'rclistfrom'                        => 'Zeich de neu Änderunge vum $1 av',
@@ -1165,7 +1222,7 @@
 'recentchangeslinked-noresult' => 'Et woodte kein Änderunge aan verlinkte Sigge jemaat en dä Zick.',
 'recentchangeslinked-summary'  => "Hee die Sondersigg hät en Liß met Änderunge aan Sigge, di vun de aanjejovve Sigg uß verlink sin.
 Bei Saachjruppe sen et de Sigge en dä Saachjrupp.
-Sigge uß Dinge [[{{#special:watchlist}}|Oppaßliß]] sin '''fett''' jeschrevve.",
+Sigge uß Dinge [[Special:Watchlist|Oppaßliß]] sin '''fett''' jeschrevve.",
 'recentchangeslinked-page'     => 'Dä Sigg iere Tittel:',
 'recentchangeslinked-to'       => 'Zeish de Änderonge fun dä Sigge, wo Lengks noh hee drop sin',
 
@@ -1175,7 +1232,7 @@
 'reupload'                    => 'Noch ens huhlade',
 'reuploaddesc'                => 'Zeröck noh de Sigg zem Huhlade.',
 'uploadnologin'               => 'Nit Enjelogg',
-'uploadnologintext'           => 'Do mööts ald [[Special:Userlogin|enjelogg]] sin, öm Daate huhzelade.',
+'uploadnologintext'           => 'Do mööts ald [[Special:UserLogin|enjelogg]] sin, öm Daate huhzelade.',
 'upload_directory_missing'    => "<b>Doof:</b> 
 Dat Fo'zeishnis <code>$1</code> för de huhjelaade Dateie es fott, un dat Websörver Projramm kunnd_et och nit aanlääje.",
 'upload_directory_read_only'  => '<b>Doof:</b> En dat Verzeichnis <code>$1</code> för Dateie dren huhzelade, do kann dat Websörver Projramm nix erenschrieve.',
@@ -1184,15 +1241,18 @@
 <ul style=\"list-style:none outside none; 
 list-style-position:outside; list-style-image:none; list-style-type:none\"><li style=\"list-style:none outside none; 
 list-style-position:outside; list-style-image:none; 
-list-style-type:none\"><code>'''[[{{ns:image}}:'''''Beldche'''''.jpg]]'''</code></li><li
+list-style-type:none\"><code>'''<nowiki>[[</nowiki>{{ns:image}}:'''''Beldche'''''.jpg]]'''</code></li><li style=\"list-style:none outside none; 
+list-style-position:outside; list-style-image:none; 
+list-style-type:none\"><code>'''<nowiki>[[</nowiki>{{ns:image}}:'''''Beld'''''.svg| '''''200''''' px|thumb]]'''</code></li><li
 style=\"list-style:none outside none; list-style-position:outside; list-style-image:none; 
-list-style-type:none\"><code>'''[[{{ns:image}}:'''''Su süht dat us'''''.png | '''''ene Tex, för zem zeije, wann Brausere kein Belder zeije künne oder kein Belder zeije sulle'''']]'''</code></li><li style=\"list-style:none outside none; 
+list-style-type:none\"><code>'''<nowiki>[[</nowiki>{{ns:image}}:'''''Su süht dat us'''''.png | '''''ene Tex, för zem zeije, wann Brausere kein Belder zeije künne oder kein Belder zeije sulle''''' ]]'''</code></li><li style=\"list-style:none outside none; 
 list-style-position:outside; list-style-image:none; 
-list-style-type:none\"><code>'''[[{{ns:media}}:'''''Esu hürt sich dat aan'''''.ogg]]'''</code></li></ul>
-Usführlich met alle Möchlichkeite fings de dat bei de Hölp.
+list-style-type:none\"><code>'''<nowiki>[[</nowiki>{{ns:media}}:'''''Esu hürt sich dat aan'''''.ogg]]'''</code></li></ul>
+Usführlich met alle Müjjelichkeite fings de dat bei de Hölp.
 Wann De jetz entschlosse bes, dat De et hee huhlade wells:
-* Aanluure, wat mer hee en de {{SITENAME}} ald han, kanns De en uns [[{{#special:Imagelist}}|Belder Liss]].
-* Wenn De jet söke wells, eets ens nohluure wells, wat ald huhjelade, oder villeich widder fottjeschmesse wood, dat steiht em [[{{#special:Log}}/upload|Logboch vum Huhlade]].
+* Aanluure, wat mer hee en de {{SITENAME}} ald han, kanns De en uns [[Special:ImageList|Liss med huhjelade Dateie]].
+* Wenn De jet söke wells, eets ens nohluure wells, wat ald huhjelade, oder villeich widder fottjeschmesse wood, dat steiht em [[Special:Log/upload|Logboch vum Huhlade]].
+* Nohluure, wat fottjeschmesse wood, kanns De em [[Special:Log/delete|Logboch vum Sigge Fottschmie0e]].
 Esu, un jetz loss jonn:</div>
 == <span dir=\"ltr\">Daate en de {{SITENAME}} lade</span> ==",
 'upload-permitted'            => 'Nor de Dateitüpe <code>$1</code> sin zojelohße.',
@@ -1200,7 +1260,8 @@
 'upload-prohibited'           => 'Verbodde Zoote Dateie: $1.',
 'uploadlog'                   => 'LogBoch vum Dateie Huhlade',
 'uploadlogpage'               => 'Logboch met de huhjelade Dateie',
-'uploadlogpagetext'           => 'Hee sin de Neuste huhjelade Dateie opjeliss un wä dat jedon hät.',
+'uploadlogpagetext'           => 'Hee sin de Neuste huhjelade Dateie opjeliss un wä dat jedon hät.
+(En de [[Special:NewImages|Jalleri met neu Dateie]] kriß De ene Övverbleck med Belldsche)',
 'filename'                    => 'Dä Name vun dä Datei',
 'filedesc'                    => 'Beschrievungstex un Zosammefassung',
 'fileuploadsummary'           => 'Beschrievungstex un Zosammefassung:',
@@ -1219,7 +1280,7 @@
 un dann muss de dat Dinge noch ens huhlade.',
 'badfilename'                 => 'De Datei es en „$1“ ömjedäuf.',
 'filetype-badmime'            => 'Dateie mem MIME-Typ „<code>$1</code>“ wulle mer nit huhjelade krijje.',
-'filetype-unwanted-type'      => "Dat Dateifommaat '''„<code>.$1</code>“''' wulle mer nit esu jään huhjelaade krijje. Leever ham_mer: $2.",
+'filetype-unwanted-type'      => "Dat Dateifommaat '''„<code>.$1</code>“''' wulle mer nit esu jään huhjelaade krijje. Leever {{PLURAL:$3|ham_mer|ham_mer ein fun|ham_mer nix}}: $2.",
 'filetype-banned-type'        => "Dat Dateifommaat '''„<code>.$1</code>“''' wulle mer nit huhjelaade krijje. Älaup {{PLURAL:$3|es|sin_er}}: $2.",
 'filetype-missing'            => 'Di Datei, di De huhlaade wells, hät keij Fommaat em Name, wi zem Beijspöll „<code>.jpg</code>“, esu jet hätte mer ävver jähn.',
 'large-file'                  => 'Dateie sullte nit jröößer wääde, wi $1, ävver Ding Datei es $2 jroß.',
@@ -1230,7 +1291,7 @@
 'fileexists-extension'        => '<table cellspacing="0" cellpadding="0" border="0"><tr><td colspan="2">Mer han ald en Dattei, di bahl jenou esu heijß:</td></tr><tr><td>Huh am laade sim_mer:&nbsp;</td><td><strong><tt>$1</tt></strong></td></tr><tr><td>Ald om ßörve eß:</td><td><strong><tt>$2</tt></strong></td></tr><tr><td colspan="2">Bes esu joot un söök Der ene ander Name fö di Datei us.</td></tr></table>',
 'fileexists-thumb'            => "<center>'''Datei'''</center>",
 'fileexists-thumbnail-yes'    => 'Dat süühd uß, wi wann dat hee en Minni-Beldsche em Breefmarrke-Fommaat (<i><span lang="en">thumbnail</span></i>) wöhr. Don ens di Dattei <strong><tt>$1</tt></strong> prööfe. Wann dat de Orjinaaljrüß es, do moß keij för dat Beld keij extra Vör-Aansich huhjelade wäde.',
-'file-thumbnail-no'           => 'Dä Name fö di Datei fängk met <strong><tt>$1</tt></strong> aan. Dat süühd uß, wi wann dat en Minni-Beldsche em Breefmarrke-Fommaat (<i><span lang="en">thumbnail</span></i>) wöhr. Don ens di Dattei <strong><tt>$1</tt></strong> prööfe, of de nit e besser opjelööß Beld dofun häß, un don dat met singe Orjinaaljrüß huhlade, wann mööschlesch.',
+'file-thumbnail-no'           => 'Dä Name fö di Datei fängk met <strong><tt>$1</tt></strong> aan. Dat süühd uß, wi wann dat en Minni-Beldsche em Breefmarrke-Fommaat (<i><span lang="en">thumbnail</span></i>) wöhr. Don ens di Dattei <strong><tt>$1</tt></strong> prööfe, of de nit e besser opjelööß Beld dofun häß, un don dat met singe Orjinaaljrüß huhlade, wann müjjelesch.',
 'fileexists-forbidden'        => 'Et jitt ald en Datei met däm Name.
 Jangk zeröck un lad se unger enem andere Name huh. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Et jitt ald en Datei met däm Name em jemeinsame Speicher.
@@ -1257,19 +1318,26 @@
 De Einzelheite: $1',
 'sourcefilename'              => 'Datei zem huhlade:',
 'destfilename'                => 'Unger däm Dateiname avspeichere:',
-'upload-maxfilesize'          => 'Der jüütßte mööschlesche Ömfang för en Datei es $1.',
+'upload-maxfilesize'          => 'Der jrüütßte müjjelesche Ömfang för en Datei es $1.',
 'watchthisupload'             => 'Op die Datei hee oppasse',
 'filewasdeleted'              => 'Unger däm Name wood ald ens en Datei huhjelade. Die es enzwesche ävver widder fottjeschmesse woode. Luur leever eets ens en et $1 ih dat De se dann avspeichere deis.',
+'upload-wasdeleted'           => "'''Opjepaß:''' Do bes en Datei huh am lade, di ald doför doh wohr un fottjeschmesse wohdt.
 
-'upload-proto-error'     => 'Verkihrt Protokoll',
-'upload-file-error'      => 'Fääler em Wiki beim Huhlade',
-'upload-file-error-text' => 'Ene ennere Fääler es opjekumme beim Aanläje vun en Datei om Server.
-Verzäll et enem Eiki-Köbes.',
-'upload-misc-error'      => 'Dat Huhlaade jing donevve',
-'upload-misc-error-text' => 'Dat Huhlaade jing donevve.
+Bes esu joot un don Der övverlääje, of di Dattei mem sellve Name norr_ens huh ze lade en Odenung es.
+Hee es dat Logbooch met de fotjeschmesse Dateie, met däm Jrond, woröm di Dattei dohmohls fottjeschmesse woode es:",
+'filename-bad-prefix'         => 'Dä Datei ier Name fängk met <strong>„$1“</strong> aan. dat eß fä jewöhnlesch ene Name, dä en dijjitaale Kammerra iere Belder jitt. Esu en Name donn uns esu winnisch verzälle, dat mer se nit jän em Wiki han wulle.
+Bes esu joot un jiff dä enne Name, wo mer mieh met aanfange, öm ze wesse, wat en dä Datei dren es.',
+
+'upload-proto-error'      => 'Verkihrt Protokoll',
+'upload-proto-error-text' => 'Ene URL för en Datei fun huhzelade moß met <code>http://</code> uder <code>ftp://</code> aafange.',
+'upload-file-error'       => 'Fääler em Wiki beim Huhlade',
+'upload-file-error-text'  => 'Ene ennere Fääler es opjekumme beim Aanläje vun en Datei om Server.
+Verzäll et enem [[Special:ListUsers/sysop|Wiki-Köbes]].',
+'upload-misc-error'       => 'Dat Huhlaade jing donevve',
+'upload-misc-error-text'  => 'Dat Huhlaade jing donevve.
 Mer wesse nit woröm.
 Pröf de URL un versök et noch ens.
-Wann et nit flupp, verzäll et enem Wiki-Köbes.',
+Wann et nit flupp, verzäll et enem [[Special:ListUsers/sysop|Wiki-Köbes]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Keij Antwoot vun dä URL',
@@ -1286,7 +1354,7 @@
 'upload_source_url'  => ' (richtije öffentlije URL)',
 'upload_source_file' => ' (en Datei op Dingem Kompjuter)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Hee sin de huhjeladene Dateie opjelis. Et eetz wäde de zoletz huhjeladene Dateie aanjezeich. Wa'mer op de Övverschreff von ene Spalt klick, weed die Spalt sotteet, wa'mer norrens klick, weed de Reiejfolg ömjedrieht.",
 'imagelist_search_for'  => 'Sök noh däm Name vun däm Beld:',
 'imgfile'               => 'Datei',
@@ -1298,41 +1366,59 @@
 'imagelist_description' => 'Wat es op däm Beld drop?',
 
 # Image description page
-'filehist'                  => 'De Versione vun dä Datei',
-'filehist-help'             => 'Di domohlije Version kriß De jezeich övver dä Link op em Dattum.',
-'filehist-deleteall'        => 'All Versione fottschmieße',
-'filehist-deleteone'        => 'Schmieß die Version fott',
-'filehist-revert'           => 'Zeröck nemme',
-'filehist-current'          => 'Von jetz',
-'filehist-datetime'         => 'Version vom',
-'filehist-user'             => 'Metmaacher',
-'filehist-dimensions'       => 'Pixelle Breed×Hühte (Dateiömfang)',
-'filehist-filesize'         => 'Dateiömfang',
-'filehist-comment'          => 'Aanmerkung',
-'imagelinks'                => 'Jebruch en',
-'linkstoimage'              => 'Hee {{PLURAL:$1|kütt di Sigg|kumme de Sigge|sin keij Sigge}}, die op die Datei linke dun:',
-'nolinkstoimage'            => 'Nix link op hee die Datei.',
-'duplicatesoffile'          => 'De Datei{{PLURAL:$1||e|e}} hee noh {{PLURAL:$1|is en|sen}} dubbelte fon he dä Datei, un {{PLURAL:$1|hät|han|}} dersellve Enhalldt:',
-'sharedupload'              => 'De Datei es esu parat jelaht, dat se en diverse, ungerscheedlije Projekte jebruch wääde kann.',
-'shareduploadwiki'          => 'Mieh Informatione fings De hee: $1.',
-'shareduploadwiki-linktext' => 'Hee es en Datei beschrevve',
-'noimage'                   => 'Mer han kein Datei met däm Name, kanns De ävver $1.',
-'noimage-linktext'          => 'Kanns De huhlade!',
-'uploadnewversion-linktext' => 'Dun en neu Version vun dä Datei huhlade',
+'filehist'                       => 'De Versione vun dä Datei',
+'filehist-help'                  => 'Di domohlije Version kriß De jezeich övver dä Link op em Dattum.',
+'filehist-deleteall'             => 'All Versione fottschmieße',
+'filehist-deleteone'             => 'Schmieß die Version fott',
+'filehist-revert'                => 'Zeröck nemme',
+'filehist-current'               => 'Von jetz',
+'filehist-datetime'              => 'Version vom',
+'filehist-user'                  => 'Metmaacher',
+'filehist-dimensions'            => 'Pixelle Breed×Hühte (Dateiömfang)',
+'filehist-filesize'              => 'Dateiömfang',
+'filehist-comment'               => 'Aanmerkung',
+'imagelinks'                     => 'Jebruch en',
+'linkstoimage'                   => 'Hee {{PLURAL:$1|kütt di Sigg|kumme de Sigge|sin keij Sigge}}, die op die Datei linke dun:',
+'nolinkstoimage'                 => 'Nix link op hee die Datei.',
+'morelinkstoimage'               => 'Belohr Der [[Special:WhatLinksHere/$1|de Links]] op di Datei.',
+'redirectstofile'                => 'Di {{PLURAL:$1|Datei heenoh leid|$1 Dateie leide}} op he di Datei öm:',
+'duplicatesoffile'               => 'De Datei{{PLURAL:$1||e|e}} hee noh {{PLURAL:$1|is en|sen}} dubbelte fon he dä Datei, un {{PLURAL:$1|hät|han|}} dersellve Enhalldt:',
+'sharedupload'                   => 'De Datei es esu parat jelaht, dat se en diverse, ungerscheedlije Projekte jebruch wääde kann.',
+'shareduploadwiki'               => 'Mieh Informatione fings De op dä $1.',
+'shareduploadwiki-desc'          => 'Hee noh kütt dä Enhalt fun dä $1 uß dämm jemeinsame Beshtand.',
+'shareduploadwiki-linktext'      => 'Sigg övver de Datei',
+'shareduploadduplicate'          => 'Di Datei es dubbelt met „$1“ ussem jemeinsame Beshtand.',
+'shareduploadduplicate-linktext' => 'fun dä ander Datei',
+'shareduploadconflict'           => 'Di Datei hät dersellve Namen wi „$1“ uss_em jemeinsame Beshtand.',
+'shareduploadconflict-linktext'  => 'di ander Datei',
+'noimage'                        => 'Mer han kein Datei met däm Name, kanns De ävver $1.',
+'noimage-linktext'               => 'Kanns De huhlade!',
+'uploadnewversion-linktext'      => 'Dun en neu Version vun dä Datei huhlade',
+'imagepage-searchdupe'           => 'Sök noh dubelte Dateie',
 
 # File reversion
-'filerevert-submit' => 'Zeröcknemme',
+'filerevert'            => '„$1“ zerök holle',
+'filerevert-comment'    => 'Jrond:',
+'filerevert-submit'     => 'Zeröcknemme',
+'filerevert-badversion' => 'Mer han kei Version fun dä Datei för dä aanjejovve Zickpunk.',
 
 # File deletion
 'filedelete'                  => 'Schmieß „$1“ fott',
 'filedelete-legend'           => 'Schmieß de Datei fott',
+'filedelete-intro'            => "Do beß di Datei '''„[[:Media:$1|$1]]“''' am Fottschmieße.",
+'filedelete-intro-old'        => 'Do schmiiß de Version $4 fum $2 öm $3 Uhr fun dä Datei „[[Media:$1|$1]]“ fott.',
 'filedelete-comment'          => 'Der Jrund för et Fottschmieße:',
 'filedelete-submit'           => 'Fottschmieße',
+'filedelete-success'          => "'''„$1“''' es fottjeschmeße.",
+'filedelete-success-old'      => "Fun dä Datei '''„[[:Media:$1|$1]]“''' es jäz di Version fum $2 öm $3 Uhr fottjeschmeße woode.",
+'filedelete-nofile'           => "'''„$1“''' jidd_et nit en de {{SITENAME}}.",
+'filedelete-nofile-old'       => "Fun '''„$1“''' ham_mer kein arschiveete Version met dä Eijeschaffte.",
+'filedelete-iscurrent'        => 'Ih dat De de neuste Version fun dä Datei fottschmieße kanns, wat jrad versoht häs, do mos De ehts ens op en älldere Version zeröck jonn, di aanjezeish wäde soll, söns weet dat nix!',
 'filedelete-otherreason'      => 'Ander Jrund oder Zosätzlich:',
 'filedelete-reason-otherlist' => 'Ne andere Jrund',
-'filedelete-reason-dropdown'  => '* Alljemein Jrönde
-** dä Uploader wollt et esu
-** wohr jäje et Urhävverrääsch
+'filedelete-reason-dropdown'  => '* Alljemein Jrönd
+** Wä dat Denge huhjelade hät, wollt et esu
+** Wohr jäje et Urhävverrääsch
 ** Dubbelt',
 'filedelete-edit-reasonlist'  => 'De Jrönde för et Fottschmieße beärbeide',
 
@@ -1390,14 +1476,16 @@
 
 (En Atikel jellt als en „(Watt ėßß datt?)“-Sigg un weed hee jeliss, wann en dä Sigg [[MediaWiki:Disambiguationspage]] ene Link op en drop dren is. Alles wat keij Atikelle sin, weed dobei jaa nit eez metjezallt)',
 
-'doubleredirects'     => 'Ömleitunge op Ömleitunge',
-'doubleredirectstext' => 'Dubbel Ömleitunge sin immer verkihrt, weil däm Wiki sing Soffwär de eetse Ömleitung 
+'doubleredirects'            => 'Ömleitunge op Ömleitunge',
+'doubleredirectstext'        => 'Dubbel Ömleitunge sin immer verkihrt, weil däm Wiki sing Soffwär de eetse Ömleitung 
 folg, de zweite Ömleitung ävver dann aanzeije deit - un dat well mer jo normal nit han.
 Hee fings De en jede Reih ene Link op de iertste un de zweite Ömleitung, donoh ene Link op de Sigg, wo de 
 zweite Ömleitung hin jeiht. För jewöhnlich es dat dann och de richtije Sigg, wo de iertste Ömleitung ald hin 
 jonn sollt.
 Met däm „(Ändere)“-link kanns De de eetste Sigg tirek aanpacke. Tipp: Merk Der dat Lemma - de Üvverschreff - 
 vun dä Sigg dovör.',
+'double-redirect-fixed-move' => 'dubbel Ömleidung nohm Ömnenne automattesch opjelös: [[$1]] → [[$2]]',
+'double-redirect-fixer'      => '(Opjaveleß)',
 
 'brokenredirects'        => 'Ömleitunge, die en et Leere jonn',
 'brokenredirectstext'    => 'Die Ömleitunge hee jonn op Sigge, die mer jar nit han:',
@@ -1406,6 +1494,7 @@
 
 'withoutinterwiki'         => 'Atikele ohne Links op annder Shprooche',
 'withoutinterwiki-summary' => 'He sin Sigge jeliß, di nit op annder Shprooche jelingk sin.',
+'withoutinterwiki-legend'  => 'Aanfang fum Sigge-Tittel',
 'withoutinterwiki-submit'  => 'Zeije',
 
 'fewestrevisions' => 'Arikele met de winnischste Versione',
@@ -1486,6 +1575,7 @@
 'speciallogtitlelabel' => 'Siggename:',
 'log'                  => 'Logböcher ehr Opzeichnunge (all)',
 'all-logs-page'        => 'All Logböcher',
+'log-search-legend'    => 'En de Logböcher söke',
 'log-search-submit'    => 'Loß Jonn!',
 'alllogstext'          => "Dat hee es en jesamte Liss us all dä Logböcher.
 Dä Logböcher ehre Enhald ka'mer all noh de Aat, de Metmaacher, oder de Sigge ehr Name, un esu, einzel zoteet 
@@ -1493,7 +1583,7 @@
 'logempty'             => '<i>Mer han kein zopass Endräch en däm Logboch.</i>',
 'log-title-wildcard'   => 'Sök noh Titelle, di aanfange met …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'All Sigge',
 'alphaindexline'    => '$1 … $2',
 'nextpage'          => 'De nächste Sigg: „$1“',
@@ -1513,16 +1603,16 @@
 # Special:Categories
 'categories'                    => 'Saachjruppe',
 'categoriespagetext'            => 'Hee sin nur Saachjruppe met jät dren jeliss.',
-'categoriesfrom'                => 'Zeich Saachjruppe vun af:',
+'categoriesfrom'                => 'Zeich Saachjruppe vun hee af:',
 'special-categories-sort-count' => 'Zoteere noh de Aanzahl',
 'special-categories-sort-abc'   => 'Zoteere nohm Alphabett',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Zeich de Metmaacher vun:',
 'listusers-submit'   => 'Zeije',
 'listusers-noresult' => 'Keine Metmaacher jefonge.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Metmaacher-Jruppe-Rääschte',
 'listgrouprights-summary'  => 'Hee kütt de Liss met dä Medmaacher-Jruppe, di dat Wiki hee kennt, un denne ier Rääschte.
 Mieh övver de einzel Rääschte fenkt Er op de [[{{MediaWiki:Listgrouprights-helppage}}|Hölp-Sigg övver de Medmaacher ier Rääschte]].',
@@ -1533,15 +1623,16 @@
 
 # E-mail user
 'mailnologin'     => 'Keij E-Mail Adress',
-'mailnologintext' => 'Do mööts ald aanjemeldt un [[Special:Userlogin|enjelogg]] sin, un en jode E-Mail 
+'mailnologintext' => 'Do mööts ald aanjemeldt un [[Special:UserLogin|enjelogg]] sin, un en jode E-Mail 
 Adress en Dinge [[Special:Preferences|ming Enstellunge]] stonn han, öm en E-Mail aan andere Metmaacher ze 
 schecke.',
 'emailuser'       => 'E-mail aan dä Metmaacher',
 'emailpage'       => 'E-mail aan ene Metmaacher',
-'emailpagetext'   => 'Wann dä Metmaacher en E-mail Adress aanjejovve hätt en singe Enstellunge, un die 
-deit et och, dann kanns De met däm Fomular hee unge, en einzelne E-Mail aan dä Metmaacher schecke. Ding E-mail 
-Adress, die De en Ding eije Enstellunge aanjejovve häs, die weed als de Avsender Adress en die E-Mail 
-enjedrage. Domet kann, wä die E-Mail kritt, drop antwoode, un die Antwood jeiht tirek aan Dich.
+'emailpagetext'   => 'Wann dä Metmaacher en E-mail Adress aanjejovve hätt en singe Enstellunge,
+un die deit et och, dann kanns De met däm Fomular hee unge en einzelne E-Mail aan dä Metmaacher schecke.
+Ding E-mail  Adress, die De en [[Special:Preferences|Ding eije Enstellunge]] aanjejovve häs,
+die weed als de Avsender Adress en die E-Mail enjedrage.
+Domet kann, wä die E-Mail kritt, drop antwoode, un die Antwood jeiht tirek aan Dich.
 Alles klor?',
 'usermailererror' => 'Dat E-Mail-Objek jov ene Fähler us:',
 'defemailsubject' => 'E-Mail üvver de {{SITENAME}}.',
@@ -1565,15 +1656,15 @@
 'nowatchlist'          => 'En Ding Oppassliss es nix dren.',
 'watchlistanontext'    => 'Do muss $1, domet de en Ding Oppassliss erenluure kanns, oder jet dran ändere.',
 'watchnologin'         => 'Nit enjelogg',
-'watchnologintext'     => 'Öm Ding Oppassliss ze ändere, mööts de ald [[Special:Userlogin|enjelogg]] sin.',
+'watchnologintext'     => 'Öm Ding Oppassliss ze ändere, mööts de ald [[Special:UserLogin|enjelogg]] sin.',
 'addedwatch'           => 'En de Oppassliss jedon',
-'addedwatchtext'       => 'Die Sigg „[[$1]]“ es jetz en Ding [[Special:Watchlist|Oppassliss]]. Av jetz, wann die Sigg 
+'addedwatchtext'       => "Die Sigg „[[:$1]]“ es jetz en Ding [[Special:Watchlist|Oppassliss]]. Av jetz, wann die Sigg 
 verändert weed, oder ehr Klaafsigg, dann weed dat en de Oppassliss jezeich. Dä Endrach för die Sigg kütt en 
-Fettschreff en de „[[Special:Recentchanges|Neuste Änderunge]]“, domet De dä do och flöck fings.
+'''Fettschreff''' en de „[[Special:RecentChanges|Neuste Änderunge]]“, domet De dä do och flöck fings.
 Wann de dä widder loss wääde wells us Dinger Oppassliss, dann klick op „Nimieh drop oppasse“ wann De die Sigg om 
-Schirm häs.',
+Schirm häs.",
 'removedwatch'         => 'Us de Oppassliss jenomme',
-'removedwatchtext'     => 'Die Sigg „[[$1]]“ es jetz us de Oppassliss erusjenomme.',
+'removedwatchtext'     => 'Die Sigg „[[:$1]]“ es jetz us de [[Special:Watchlist|Oppassliss]] erusjenomme.',
 'watch'                => 'Drop Oppasse',
 'watchthispage'        => 'Op die Sigg oppasse',
 'unwatch'              => 'Nimieh drop Oppasse',
@@ -1609,6 +1700,7 @@
 'created'                      => 'neu aanjelaht',
 'enotif_subject'               => '{{SITENAME}}: Sigg "$PAGETITLE" vun "$PAGEEDITOR" $CHANGEDORCREATED.',
 'enotif_lastvisited'           => 'Luur unger „$1“ - do fings de all die Änderunge zick Dingem letzte Besoch hee.',
+'enotif_lastdiff'              => 'Loor noh $1 öm di änderung ze sinn.',
 'enotif_anon_editor'           => 'Dä namelose Metmaacher $1',
 'enotif_body'                  => 'Leeven $WATCHINGUSERNAME,
 en de {{SITENAME}} wood die Sigg „$PAGETITLE“ am $PAGEEDITDATE vun „$PAGEEDITOR“ $CHANGEDORCREATED, unger 
@@ -1646,6 +1738,7 @@
 'actioncomplete'              => 'Erledich',
 'deletedtext'                 => 'De Sigg „<nowiki>$1</nowiki>“ es jetz fottjeschmesse woode. Luur Der „$2“ aan, do häs De en Liss met de Neuste fottjeschmesse Sigge.',
 'deletedarticle'              => 'hät fottjeschmesse: „[[$1]]“',
+'suppressedarticle'           => 'han „[[$1]]“ verstoche',
 'dellogpage'                  => 'Logboch met de fottjeschmesse Sigge',
 'dellogpagetext'              => 'Hee sin de Sigge oppjeliss, die et neus fottjeschmesse woodte.',
 'deletionlog'                 => 'Dat Logboch fum Sigge-Fottschmieße',
@@ -1660,14 +1753,16 @@
 ** et wohr bloß Keu
 ** mem Name verdonn bemm Aanläje',
 'delete-edit-reasonlist'      => 'De Jrönde för et Fottschmieße beärbeide',
+'delete-toobig'               => 'Di Sigg hät {{PLURAL:$1|ein Version|$1 Versione|jakein Version}}. Dat sinn_er ärsch fill. Domet unsere ßööver do nit draan en de Kneen jeit, dom_mer esu en Sigg nit fottschmieße.',
+'delete-warning-toobig'       => 'Di Sigg hät {{PLURAL:$1|ein Version|$1 Versione|jakein Version}}. Dat sinn_er ärsch fill. Wann De die all fottschmieße wells, dat kann dem Wiki sing Datenbangk schwer ußbremse.',
 'rollback'                    => 'Änderunge Zeröcknemme',
 'rollback_short'              => 'Zeröcknemme',
 'rollbacklink'                => 'Zeröcknemme',
 'rollbackfailed'              => 'Dat Zeröcknemme jingk scheiv',
-'cantrollback'                => 'De letzte Änderung zeröckzenemme es nit möchlich. Dä letzte Schriever es dä einzije, dä aan dä Sigg hee jet jedon hät!',
-'alreadyrolled'               => 'Mer künne de letzte Änderunge vun dä Sigg „[[:$1]]“ vum Metmaacher „[[User:$2|$2]]“ ([[User talk:$2|däm sing Klaafsigg]]) nimieh zeröcknemme, dat hät ene Andere enzwesche ald jedon.
+'cantrollback'                => 'De letzte Änderung zeröckzenemme es nit müjjelich. Dä letzte Schriever es dä einzije, dä aan dä Sigg hee jet jedon hät!',
+'alreadyrolled'               => 'Mer künne de letzte Änderunge vun dä Sigg „[[:$1]]“ vum Metmaacher „[[User:$2|$2]]“ ([[User talk:$2|Klaaf]] | [[Special:Contributions/$2|{{int:contribslink}}]]) nimieh zeröcknemme, dat hät ene Andere enzwesche ald jedon, udder de Sigg ömjeändert.
 
-De Neuste letzte Änderung es jetz vun däm Metmaacher „[[User:$3|$3]]“ ([[User talk:$3|däm sing Klaafsigg]]).',
+De Neuste Änderung aan dä Sigg es jetz vun däm Metmaacher „[[User:$3|$3]]“ ([[User talk:$3|Klaaf]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Bei dä Änderung stundt: „<i>$1</i>“.', # only shown if there is an edit comment
 'revertpage'                  => 'Änderunge vun däm Metmaacher „[[Special:Contributions/$2|$2]]“ ([[User talk:$2|däm sing Klaafsigg]]) fottjeschmesse, un doför de letzte Version vum „[[User:$1|$1]]“ widder zeröckjehollt', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'De Änderungen vum $1 zeröckjenumme, un dobei de letzte Version vum $2 widder jehollt.',
@@ -1685,6 +1780,9 @@
 'protect_expiry_old'          => 'Do häs De Desch verdonn. Die Zick för ze Schötze es doch ald eröm!',
 'protect-unchain'             => 'Et Schötze jäje Ömnenne extra enstelle looße',
 'protect-text'                => 'Hee kanns De dä Schotz jäje Veränderunge för de Sigg „<strong><nowiki>$1</nowiki></strong>“ aanluure un ändere.',
+'protect-locked-blocked'      => 'Do kanns nit der Siggeschotz ändere, esu lang wi Dinge Zojang zom Wiki jesperrt es. Hee es der aktuelle Stand fum Siggeschotz för di Sigg <strong>„$1“:</strong>',
+'protect-locked-dblock'       => 'De Datebank es jesperrt. Dröm künne mer der Siggeschotz nit ändere.
+Hee es der aktuelle Stand fum Siggeschotz för di Sigg <strong>„$1“:</strong>',
 'protect-locked-access'       => 'Do häs nit dat Rääsch, hee em Wiki Sigge ze schötze udder dä Schotz widder opzehevve.
 Di Sigg <strong>„$1“:</strong> es jetz jrad:',
 'protect-cascadeon'           => 'Die Sigg es en enne Schotz-Kaskad. Se es enjebonge en {{PLURAL:$1|die Sigg|$1 Sigge|kein Sigg}}, die per Kaskade-Schotz jeschötz {{PLURAL:$1|es|sin|es}}. Do kanns dä Schotz för die Sigg hee ändere, ävver di Kaskad blief bestonn. Dat hee sin die Sigge en dä Kaskad:',
@@ -1714,37 +1812,53 @@
 'restriction-level-all'           => 'jeede',
 
 # Undelete
-'undelete'                 => 'Fottjeschmessene Krom aanluure odder zeröck holle',
-'undeletepage'             => 'Fottjeschmesse Sigge aanluure un widder zeröckholle',
-'viewdeletedpage'          => 'Fottjeschmesse Sigge aanzeije',
-'undeletepagetext'         => 'De Sigge heenoh sin fottjeschmesse, mer künne se ävver immer noch usem Müllemmer eruskrose.',
-'undeleteextrahelp'        => 'Öm de janze Sigg met all ehre Versione widder ze holle, looß all de Versione ohne Hökche, un klick op „<b style="padding:2px; background-color:#ddd; color:black">Zeröckholle!</b>“.
+'undelete'                     => 'Fottjeschmessene Krom aanluure odder zeröck holle',
+'undeletepage'                 => 'Fottjeschmesse Sigge aanluure un widder zeröckholle',
+'undeletepagetitle'            => "'''He dat sin de fottjeschmeße Versione fun [[:$1|$1]]'''",
+'viewdeletedpage'              => 'Fottjeschmesse Sigge aanzeije',
+'undeletepagetext'             => 'De Sigge heenoh sin fottjeschmesse, mer künne se ävver immer noch usem Müllemmer eruskrose.',
+'undelete-fieldset-title'      => 'Versione zeröck holle',
+'undeleteextrahelp'            => 'Öm de janze Sigg met all ehre Versione widder ze holle, looß all de Versione ohne Hökche, un klick op „<b style="padding:2px; background-color:#ddd; color:black">Zeröckholle!</b>“.
 Öm bloß einzel Versione zeröckzeholle, maach Hökche aan die Versione, die De widder han wells, un dann dun „<b style="padding:2px; background-color:#ddd; color:black">Zeröckholle!</b>“ klicke.
 Op „<b style="padding:2px; background-color:#ddd; color:black">De Felder usleere</b>“
 klick, wann De all Ding Hökche un Ding „Erklärung (för en et Logboch):“ widder fott han wells.',
-'undeleterevisions'        => '{{PLURAL:$1|Ein Version|<strong>$1</strong> Versione|<strong>Kein</strong> Version}} en et Archiv jedon',
-'undeletehistory'          => 'Wann De die Sigg widder zeröckholls,
+'undeleterevisions'            => '{{PLURAL:$1|Ein Version|<strong>$1</strong> Versione|<strong>Kein</strong> Version}} en et Archiv jedon',
+'undeletehistory'              => 'Wann De die Sigg widder zeröckholls,
 dann kriss De all fottjeschmesse Versione widder.
 Wann enzwesche en neu Sigg unger däm ahle Name enjerich woode es,
 dann wääde de zeröckjehollte Versione einfach als zosätzlije äldere Versione för die neu Sigg enjerich.
 Die neu Sigg weed nit ersetz.',
-'undeletehistorynoadmin'   => 'Die Sigg es fottjeschmesse woode. Dä Jrund döför es en de Liss unge ze finge, jenau esu wie de Metmaacher, wo de Sigg verändert han, ih dat se fottjeschmesse wood. Wat op dä Sigg ehre fottjeschmesse ahle Versione stundt, dat künne nor de Wiki Köbese noch aansinn (un och widder zeröckholle)',
-'undeleterevision-missing' => 'De Version stemmp nit. Dat wor ene verkihrte Link, oder de Version wood usem Archiv zeröck jehollt, oder fottjeschmesse.',
-'undeletebtn'              => 'Zeröckholle!',
-'undeletelink'             => 'widder zeröckholle',
-'undeletereset'            => 'De Felder usleere',
-'undeletecomment'          => 'Erklärung (för en et Logboch):',
-'undeletedarticle'         => '„$1“ zeröckjehollt',
-'undeletedrevisions'       => '{{PLURAL:$1|ein Version|$1 Versione}} zeröckjehollt',
-'undeletedrevisions-files' => 'Zesammejenomme {{PLURAL:$1|Ein Version|<strong>$1</strong> Versione|<strong>Kein</strong> Version}} vun {{PLURAL:$2|eine Datei|<strong>$2</strong> Dateie|<strong>nix</strong>}} zeröckjehollt',
-'undeletedfiles'           => '{{PLURAL:$1|Ein Datei|<strong>$1</strong> Dateie|<strong>Kein</strong> Dateie}} zeröckjehollt',
-'cannotundelete'           => '<strong>Dä.</strong> Dat Zeröckholle jing donevve. Möchlich, dat ene andere Metmaacher flöcker wor, un et ald et eets jedon hät, un jetz es die Sigg ald widder do jewäse.',
-'undeletedpage'            => '<big><strong>De Sigg „$1“ es jetz widder do</strong></big>
+'undeleterevdel'               => 'Dat Zeröckholle flupp nit, wann de neuste Version verstoche es udder verstoche Aandeile do dren sin. En esu en Fäll darrf de neuste Version kei Höksche krijje, udder se moß eets ens en en nommaale Version ömjewandelt wääde, di nit mieh verstoche es.',
+'undeletehistorynoadmin'       => 'Die Sigg es fottjeschmesse woode. Dä Jrund döför es en de Liss unge ze finge, jenau esu wie de Metmaacher, wo de Sigg verändert han, ih dat se fottjeschmesse wood. Wat op dä Sigg ehre fottjeschmesse ahle Versione stundt, dat künne nor de Wiki Köbese noch aansinn (un och widder zeröckholle)',
+'undelete-revision'            => 'Fottjeschmeße Version fun dä Sigg „$1“ fum $2, et letz jändert fum $3:',
+'undeleterevision-missing'     => 'De Version stemmp nit. Dat wor ene verkihrte Link, oder de Version wood usem Archiv zeröck jehollt, oder fottjeschmesse.',
+'undelete-nodiff'              => 'Mer han kei ällder Version jefonge.',
+'undeletebtn'                  => 'Zeröckholle!',
+'undeletelink'                 => 'widder zeröckholle',
+'undeletereset'                => 'De Felder usleere',
+'undeletecomment'              => 'Erklärung (för en et Logboch):',
+'undeletedarticle'             => '„$1“ zeröckjehollt',
+'undeletedrevisions'           => '{{PLURAL:$1|ein Version|$1 Versione}} zeröckjehollt',
+'undeletedrevisions-files'     => 'Zesammejenomme {{PLURAL:$1|Ein Version|<strong>$1</strong> Versione|<strong>Kein</strong> Version}} vun {{PLURAL:$2|eine Datei|<strong>$2</strong> Dateie|<strong>nix</strong>}} zeröckjehollt',
+'undeletedfiles'               => '{{PLURAL:$1|Ein Datei|<strong>$1</strong> Dateie|<strong>Kein</strong> Dateie}} zeröckjehollt',
+'cannotundelete'               => '<strong>Dä.</strong> Dat Zeröckholle jing donevve. Mach sinn, dat ene andere Metmaacher flöcker wor, un et ald et eets jedon hät, un jetz es die Sigg ald widder do jewäse.',
+'undeletedpage'                => '<big><strong>De Sigg „$1“ es jetz widder do</strong></big>
 Luur Der et [[Special:Log/delete|Logboch met de fottjeschmesse Sigge]] aan, do häs De de Neuste fottjeschmesse 
 un widder herjehollte Sigge.',
-'undelete-search-submit'   => 'Sööke',
-'undelete-cleanup-error'   => 'Fähler beim Fottschmieße vun de Archiv-Version „$1“, die nit jebruch wood.',
+'undelete-header'              => 'Loor Der [[Special:Log/delete|{{LCFIRST:{{int:deletionlog}}}}]] aan, doh fengks De de och neulesch fottjeschmesse Sigge.',
+'undelete-search-box'          => 'Noh fottjeschmesse Sigge söke',
+'undelete-search-prefix'       => 'Zeisch Sigge, di aanfange met:',
+'undelete-search-submit'       => 'Sööke',
+'undelete-no-results'          => 'Mer han em Aschiif kei Sigg, wo dä Bejreff drop paß, womet De am Söke beß.',
+'undelete-filename-mismatch'   => 'Dä Dattei ier Version fun dä Zick $1 kunnte mer nit zeröck holle: Di Datteiname paßße nit zersamme.',
+'undelete-bad-store-key'       => 'Dä Dattei ier Version fun dä Zick $1 kunnte mer nit zeröck holle: Di Datei wohr ald beim Fottschmieße ja nimmieh do.',
+'undelete-cleanup-error'       => 'Fähler beim Fottschmieße vun de Archiv-Version „$1“, die nit jebruch wood.',
+'undelete-missing-filearchive' => 'De Datei met dä Archiv-Nommer $1 künne mer nit zerök holle. Di ham_mer nit in de Datebangk. Künnt sinn, di es ald zeröckjehollt.',
+'undelete-error-short'         => 'Fähler beim Zerökholle fun de Datei $1',
+'undelete-error-long'          => 'Mer wollte en Datei widder zeröckholle, ävver dobei sin_er Fääler opjefalle:
 
+$1',
+
 # Namespace form on various pages
 'namespace'      => 'Appachtemeng:',
 'invert'         => 'dun de Uswahl ömdrije',
@@ -1767,32 +1881,41 @@
 'sp-contributions-submit'      => 'Sööke',
 
 # What links here
-'whatlinkshere'       => 'Wat noh hee link',
-'whatlinkshere-title' => 'Sigge, woh Links op „$1“ dren sen',
-'linklistsub'         => '(Liss met de Links)',
-'linkshere'           => 'Dat sin de Sigge, die op <strong>„[[:$1]]“</strong> linke dun:',
-'nolinkshere'         => 'Kein Sigg link noh <strong>„[[:$1]]“</strong>.',
-'nolinkshere-ns'      => 'Nix link op <strong>„[[:$1]]“</strong> en dämm Appachtemang.',
-'isredirect'          => 'Ömleitungssigg',
-'istemplate'          => 'weed enjeföch',
-'whatlinkshere-prev'  => 'de vörijje {{PLURAL:$1||$1|noll}} zeije',
-'whatlinkshere-next'  => 'de nächste {{PLURAL:$1||$1|noll}} zeije',
-'whatlinkshere-links' => '← Links',
+'whatlinkshere'            => 'Wat noh hee link',
+'whatlinkshere-title'      => 'Sigge, woh Links op „$1“ dren sen',
+'whatlinkshere-page'       => 'Sigg:',
+'whatlinkshere-barrow'     => '>',
+'linklistsub'              => '(Liss met de Links)',
+'linkshere'                => 'Dat sin de Sigge, die op <strong>„[[:$1]]“</strong> linke dun:',
+'nolinkshere'              => 'Kein Sigg link noh <strong>„[[:$1]]“</strong>.',
+'nolinkshere-ns'           => 'Nix link op <strong>„[[:$1]]“</strong> en dämm Appachtemang.',
+'isredirect'               => 'Ömleitungssigg',
+'istemplate'               => 'weed enjeföch',
+'isimage'                  => 'Link obb_en Datei',
+'whatlinkshere-prev'       => 'de vörijje {{PLURAL:$1||$1|noll}} zeije',
+'whatlinkshere-next'       => 'de nächste {{PLURAL:$1||$1|noll}} zeije',
+'whatlinkshere-links'      => '← Links',
+'whatlinkshere-hideredirs' => 'Ömleidunge $1',
+'whatlinkshere-hidetrans'  => '$1 de Oproofe',
+'whatlinkshere-hidelinks'  => '$1 de nommale Links',
+'whatlinkshere-hideimages' => '$1 de Links op Dateie',
+'whatlinkshere-filters'    => 'Ußsööke',
 
 # Block/unblock
-'blockip'                     => 'Metmaacher sperre',
-'blockiptext'                 => 'Hee kanns De bestemmte Metmaacher oder IP-Adresse sperre, su dat se hee em Wiki nit mieh schrieve und Sigge ändere künne.
+'blockip'                         => 'Metmaacher sperre',
+'blockip-legend'                  => 'Metmaacher ov IP-Adresse Sperre',
+'blockiptext'                     => 'Hee kanns De bestemmte Metmaacher oder IP-Adresse sperre, su dat se hee em Wiki nit mieh schrieve und Sigge ändere künne.
 Dat sollt nor jedon wääde om sujenannte Vandaale ze bremse. Un mer müsse uns dobei natörlich aan uns [[{{MediaWiki:Policy-url}}|Rejelle]] för esu en Fäll halde.
 Drag bei „Aanlass“ ene möchlichs jenaue Jrund en, wöröm dat Sperre passeet. Nenn un Link op de Sigge wo Einer kapott jemaat hät, zem Beispill.',
-'ipaddress'                   => 'IP-Adress',
-'ipadressorusername'          => 'IP Adress oder Metmaacher Name',
-'ipbexpiry'                   => 'Duur, för wie lang',
-'ipbreason'                   => 'Aanlass:',
-'ipbreasonotherlist'          => 'Ne andere Bejründung',
-'ipbreason-dropdown'          => '* Alljemein Jrönd för et Sperre
+'ipaddress'                       => 'IP-Adress',
+'ipadressorusername'              => 'IP Adress oder Metmaacher Name',
+'ipbexpiry'                       => 'Duur, för wie lang',
+'ipbreason'                       => 'Aanlass:',
+'ipbreasonotherlist'              => 'Ne andere Bejründung',
+'ipbreason-dropdown'              => '* Alljemein Jrönd för et Sperre
 ** hät fekeehte Behouptunge udder Leeje en Atikelle jeschrevve
 ** hät Sigge fottjeschmesse udder leddig jemaat
-** hält sesch iewesch nit aan de Rejelle övver de Links op anger Websigge un jäje Link-SPAM
+** hält sesch iewesch nit aan de Rejelle övver de Links op anger Websigge un jäje der Link-SPAM
 ** hät Sigge met Shtuß drop aajelaat
 ** deit Medmaacher bedrohe, beleijije, schlääsch maache
 ** hät mieh wie eine Metmaachername un deit domet Schmuu maache
@@ -1800,61 +1923,81 @@
 ** esu ene Metmaacher-Name wolle mer nit 
 * Op en IP-Adräß betrocke Jrönd
 ** dat es en Proxy ßööver övver dänn de Lück zo vill Driß aanjestellt han',
-'ipbanononly'                 => 'Nor de namelose Metmaacher sperre',
-'ipbcreateaccount'            => 'et neu Aanmelde verbeede',
-'ipbemailban'                 => 'Et e-mail-Verschecke ongerbenge',
-'ipbenableautoblock'          => 'Dun automatisch de letzte IP-Adress sperre, die dä Metmaacher jehatt hät, un och all die IP-Adresse, vun wo dä versök, jet ze ändere.',
-'ipbsubmit'                   => 'Dun dä Metmaacher sperre',
-'ipbother'                    => 'För en ander Duur:',
-'ipboptions'                  => '1 Stund:1 hour,2 Stund:2 hours,3 Stund:3 hours,6 Stund:6 hours,12 Stund:12 hours,1 Dach:1 day,3 Däch:3 days,1 Woch:1 week,2 Woche:2 weeks,3 Woche:3 weeks,1 Mond:1 month,3 Mond:3 months,6 Mond:6 months,9 Mond:9 months,1 Johr:1 year,2 Johre:2 years,3 Johre:3 years,Unbejrenz:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'Söns wie lang',
-'ipbotherreason'              => 'Ander Jrund oder Zosätzlich:',
-'badipaddress'                => 'Wat De do jeschrevve häs, dat es kein öntlije IP-Adress.',
-'blockipsuccesssub'           => 'De IP-Adress es jetz jesperrt',
-'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] es jetz jesperrt.
-Luur op [[Special:Ipblocklist|de Liss met jesperrte IP_Adresse]] wann de ne Üvverbleck üvver de Sperre han wells, 
+'ipbanononly'                     => 'Nor de namelose Metmaacher sperre',
+'ipbcreateaccount'                => 'et neu Aanmelde verbeede',
+'ipbemailban'                     => 'Et e-mail-Verschecke ongerbenge',
+'ipbenableautoblock'              => 'Dun automatisch de letzte IP-Adress sperre, die dä Metmaacher jehatt hät, un och all die IP-Adresse, vun wo dä versök, jet ze ändere.',
+'ipbsubmit'                       => 'Dun dä Metmaacher sperre',
+'ipbother'                        => 'För en ander Duur:',
+'ipboptions'                      => '1 Stund:1 hour,2 Stund:2 hours,3 Stund:3 hours,6 Stund:6 hours,12 Stund:12 hours,1 Dach:1 day,3 Däch:3 days,1 Woch:1 week,2 Woche:2 weeks,3 Woche:3 weeks,1 Mond:1 month,3 Mond:3 months,6 Mond:6 months,9 Mond:9 months,1 Johr:1 year,2 Johre:2 years,3 Johre:3 years,Unbejrenz:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'Söns wie lang',
+'ipbotherreason'                  => 'Ander Jrund oder Zosätzlich:',
+'ipbhidename'                     => 'Don däm Metmaacher singe Name versteiche: Em [[Special:Log/block|{{int:blocklogpage}}]], en de [[Special:IPBlockList|{{int:ipblocklist}}]], un en de [[Special:ListUsers|{{int:listusers}}]].',
+'ipbwatchuser'                    => 'Op däm Metmaacher sing Metmaachersigg un Klaafsigg oppasse',
+'badipaddress'                    => 'Wat De do jeschrevve häs, dat es kein öntlije IP-Adress.',
+'blockipsuccesssub'               => 'De IP-Adress es jetz jesperrt',
+'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] es jetz jesperrt.
+Luur op [[Special:IPBlockList|de Liss met jesperrte IP_Adresse]] wann de ne Üvverbleck üvver de Sperre han wells, 
 un och wann De se ändere wells.',
-'ipb-unblock-addr'            => '„$1“ widder zohlohße',
-'ipb-unblock'                 => 'En IP-Addräß ov ene Metmaacher widder zohlohße',
-'unblockip'                   => 'Dä Medmacher widder maache looße',
-'unblockiptext'               => 'Hee kanns De vörher jesperrte IP_Adresse oder Metmaacher widder freijevve, un dänne esu dat Rääch för ze Schrieve hee em Wiki widder jevve.',
-'ipusubmit'                   => 'Dun de Sperr för die Adress widder ophevve',
-'unblocked'                   => '[[User:$1|$1]] wood widder zojelooße',
-'ipblocklist'                 => 'Liss met jesperrte IP-Adresse un Metmaacher Name',
-'ipblocklist-submit'          => 'Sööke',
-'blocklistline'               => '$1, $2 hät „$3“ jesperrt ($4)',
-'infiniteblock'               => 'för iwich',
-'expiringblock'               => 'leuf am $1 uß',
-'anononlyblock'               => 'nor namelose',
-'noautoblockblock'            => 'automatisch Sperre avjeschalt',
-'createaccountblock'          => 'Aanmelde nit möchlich',
-'blocklink'                   => 'Sperre',
-'unblocklink'                 => 'widder freijevve',
-'contribslink'                => 'Beidräch',
-'autoblocker'                 => 'Automatich jesperrt. Ding IP_Adress wood vör kootem vun däm Metmaacher „[[User:$1|$1]]“ jebruch. Dä es jesperrt woode wäje: „<i>$2</i>“',
-'blocklogpage'                => 'Logboch met Metmaacher-Sperre',
-'blocklogentry'               => 'hät „[[$1]]“ fö de Zick vun $2 un $3 jesperrt.',
-'blocklogtext'                => 'Hee es dat Logboch för et Metmaacher Sperre un Freijevve.
-Automatich jesperrte IP-Adresse sin nit hee, ävver em [[Special:Ipblocklist|Logboch met jesperrte IP-Adresse]] ze finge.',
-'unblocklogentry'             => 'Metmaacher „$1“ freijejovve',
-'range_block_disabled'        => 'Adresse Jebeede ze sperre, es nit erlaub.',
-'ipb_expiry_invalid'          => 'De Duur es Dress. Jevv se richtich aan.',
-'ipb_already_blocked'         => '„$1“ es ald jesperrt',
-'ipb_cant_unblock'            => '<strong>Ene Fähler:</strong> En Sperr met dä Nummer $1 es nit ze finge. Se künnt ald widder freijejovve woode sin.',
-'ip_range_invalid'            => 'Dä Bereich vun IP_Adresse es nit en Oodnung.',
-'proxyblocker'                => 'Proxy_Blocker',
-'proxyblockreason'            => 'Unger Ding IP_Adress läuf ene offe Proxy.
+'ipb-edit-dropdown'               => 'De Jründ för et Sperre beärrbejde',
+'ipb-unblock-addr'                => '„$1“ widder zohlohße',
+'ipb-unblock'                     => 'En IP-Addräß ov ene Metmaacher widder zohlohße',
+'ipb-blocklist-addr'              => 'All de Sperre för „$1“ aanzeije, die jrad bestonn',
+'ipb-blocklist'                   => 'All de Sperre för Metmaacher un IP-Adresse aanzeije, die jrad bestonn',
+'unblockip'                       => 'Dä Medmacher widder maache looße',
+'unblockiptext'                   => 'Hee kanns De vörher jesperrte IP_Adresse oder Metmaacher widder freijevve, un dänne esu dat Rääch för ze Schrieve hee em Wiki widder jevve.',
+'ipusubmit'                       => 'Dun de Sperr för die Adress widder ophevve',
+'unblocked'                       => '[[User:$1|$1]] wood widder zojelooße',
+'unblocked-id'                    => 'De Sperr met dä Nommer $1 es opjehovve',
+'ipblocklist'                     => 'Liss met jesperrte IP-Adresse un Metmaacher Name',
+'ipblocklist-legend'              => 'Ene jesperrte Metmaacher fenge',
+'ipblocklist-username'            => 'Metmaacher-Name udder IP-Address:',
+'ipblocklist-submit'              => 'Sööke',
+'blocklistline'                   => '$1, $2 hät „$3“ jesperrt ($4)',
+'infiniteblock'                   => 'för iwich',
+'expiringblock'                   => 'leuf am $1 uß',
+'anononlyblock'                   => 'nor namelose',
+'noautoblockblock'                => 'automatisch Sperre avjeschalt',
+'createaccountblock'              => 'Aanmelde es nit müjjelich',
+'emailblock'                      => 'Et E-Mail-Schecke es jrad jespert',
+'ipblocklist-empty'               => 'Do es nix en de Sperrleß.',
+'ipblocklist-no-results'          => 'Dä Metmaacher udder di IP-Adrress es janit jesperrt.',
+'blocklink'                       => 'Sperre',
+'unblocklink'                     => 'widder freijevve',
+'contribslink'                    => 'Beidräch',
+'autoblocker'                     => 'Automatich jesperrt. Ding IP_Adress wood vör kootem vun däm Metmaacher „[[User:$1|$1]]“ jebruch. Dä es jesperrt woode wäje: „<i>$2</i>“',
+'blocklogpage'                    => 'Logboch met Metmaacher-Sperre',
+'blocklogentry'                   => 'hät „[[$1]]“ fö de Zick vun $2 jesperrt. $3',
+'blocklogtext'                    => 'Hee es dat Logboch för et Metmaacher Sperre un Freijevve.
+Automatich jesperrte IP-Adresse sin nit hee, ävver en de [[Special:IPBlockList|{{int:ipblocklist}}]] ze finge.',
+'unblocklogentry'                 => 'Metmaacher „$1“ freijejovve',
+'block-log-flags-anononly'        => 'nor de namelose Metmaacher sperre',
+'block-log-flags-nocreate'        => 'neu Metmaacher aanlääje es verbeede',
+'block-log-flags-noautoblock'     => 'nit automatesch all däm sing IP-Adresse sperre',
+'block-log-flags-noemail'         => 'och et E-Mail Verschecke sperre',
+'block-log-flags-angry-autoblock' => 'automatesch all däm sing IP-Adresse sperre, un noch mieh',
+'range_block_disabled'            => 'Adresse Jebeede ze sperre, es nit erlaub.',
+'ipb_expiry_invalid'              => 'De Duur es Dress. Jevv se richtich aan.',
+'ipb_expiry_temp'                 => 'Sperre för Metmaacher met verstoche Name mößße för iewish doore.',
+'ipb_already_blocked'             => '„$1“ es ald jesperrt',
+'ipb_cant_unblock'                => '<strong>Ene Fähler:</strong> En Sperr met dä Nummer $1 es nit ze finge. Se künnt ald widder freijejovve woode sin.',
+'ipb_blocked_as_range'            => 'Dat jeit nit. De IP-Adress „$1“ es nit tirek jesperrt. Se es ävver en däm jesperrte Bereich „$2“ dren. Die Sperr kam_mer ophevve. Donoh kam_mer och kleiner Aandeile fun däm Bereich widder neu sperre. Di Adress alleins kam_mer ävver nit freijevve.',
+'ip_range_invalid'                => 'Dä Bereich vun IP_Adresse es nit en Oodnung.',
+'proxyblocker'                    => 'Proxy_Blocker',
+'proxyblocker-disabled'           => 'Di Funxjon es ußjeschalldt.',
+'proxyblockreason'                => 'Unger Ding IP_Adress läuf ene offe Proxy.
 Dröm kanns De hee em Wiki nix maache.
 Schwaad met Dingem System-Minsch oder Netzwerk-Techniker (ISP Internet Service Provider) un verzäll dänne vun däm Risiko för ehr Secherheit!',
-'proxyblocksuccess'           => 'Fäädich',
-'sorbsreason'                 => 'Ding IP-Adress weed en de DNSbl als ene offe Proxy jeliss. Schwaad met Dingem System-Minsch oder Netzwerk-Techniker (ISP Internet Service Provider) drüvver, un verzäll dänne vun däm Risiko för ehr Secherheit!',
-'sorbs_create_account_reason' => 'Ding IP-Adress weed en de DNSbl als ene offe Proxy jeliss. Dröm kanns De Dich hee em Wiki nit als ene neue Metmaacher aanmelde. Schwaad met Dingem System-Minsch oder Netzwerk-Techniker oder (ISP Internet Service Provider) drüvver, un verzäll dänne vun däm Risiko för ehr Secherheit!',
+'proxyblocksuccess'               => 'Fäädich',
+'sorbs'                           => 'DNSBL',
+'sorbsreason'                     => 'Ding IP-Adress weed en de DNSbl als ene offe Proxy jeliss. Schwaad met Dingem System-Minsch oder Netzwerk-Techniker (ISP Internet Service Provider) drüvver, un verzäll dänne vun däm Risiko för ehr Secherheit!',
+'sorbs_create_account_reason'     => 'Ding IP-Adress weed en de DNSbl als ene offe Proxy jeliss. Dröm kanns De Dich hee em Wiki nit als ene neue Metmaacher aanmelde. Schwaad met Dingem System-Minsch oder Netzwerk-Techniker oder (ISP Internet Service Provider) drüvver, un verzäll dänne vun däm Risiko för ehr Secherheit!',
 
 # Developer tools
 'lockdb'              => 'Daatebank sperre',
 'unlockdb'            => 'Daatebank freijevve',
 'lockdbtext'          => 'Nohm Sperre kann keiner mieh Änderunge maache an sing Oppassliss, aan Enstellunge, Atikelle, uew. un neu Metmaacher jitt et och nit. Bes de secher, datte dat wells?',
-'unlockdbtext'        => 'Nohm Freijevve es de Daatebank nit mieh jesperrt, un all de normale Änderunge wääde widder möchlich. Bes de secher, datte dat wells?',
+'unlockdbtext'        => 'Nohm Freijevve es de Daatebank nit mieh jesperrt, un all de normale Änderunge wääde widder müjjelich. Bes de secher, dat De dat wells?',
 'lockconfirm'         => 'Jo, ich well de Daatebank jesperrt han.',
 'unlockconfirm'       => 'Jo, ich well de Daatebank freijevve.',
 'lockbtn'             => 'Daatebank sperre',
@@ -1869,14 +2012,18 @@
 
 # Move page
 'move-page'               => 'De Sigg „$1“ ömnenne',
+'move-page-backlink'      => '← $1',
 'move-page-legend'        => 'Sigg Ömnenne',
-'movepagetext'            => "Hee kanns De en Sigg en de {{SITENAME}} ömnenne.
+'movepagetext'            => "Hee kanns De en Sigg ömnenne.
 Domet kritt die Sigg ene neue Name, un all vörherije Versione vun dä Sigg och.
 Unger däm ahle Name weed automatisch en Ömleitung op dä neue Name enjedrage.
-Links op dä ahle Name blieve ävver wie se wore.
-Dat heiß, Do muss selver nohluure, ov do jetz [[{{#special:doubleredirects}}|dubbelde]] oder [[{{#special:brokenredirects}}|kapodde]] Ömleitunge bei eruskumme.
+
+Do kannß dat Höksche setze domet Ömleidonge automattesch aanjepaß wääde, di op dä ahle Name zeije — dat weet ävver nur allmählesch pö a pö hengerher jemaat.
+Links op dä ahle Name blieve ävver wie se wore, wann De dat Höksche nit setz.
+Dat heiß, Do muss selver nohluure, ov do jetz [[Special:DoubleRedirects|dubbelde Ömleidunge]] <!-- udder [[Special:BrokenRedirects|kapodde Ömleidunge]] --> bei eruskumme.
 Wann De en Sigg ömnenne deis, häs Do och doför ze sorje, dat de betroffene Links do henjonn, wo se hen jonn solle. 
-Alsu holl Der de Liss „Wat noh hee link“ un jangk se durch!
+Alsu holl Der de Liss „Wat noh hee link“ fun dä Sigg hee un jangk se durch!
+
 De Sigg weed '''nit''' ömjenannt, wann et met däm neue Name ald en Sigg jitt, <strong>usser</strong> do es nix drop, oder et es en Ömleitung un se es noch nie jeändert woode.
 Esu ka'mer en Sigg jlich widder zeröck ömnenne, wa'mer sich mem Ömnenne verdonn hät, un mer kann och kein Sigge kapottmaache, wo ald jet drop steiht.
 
@@ -1889,8 +2036,6 @@
 * De unge en däm Kääsje '''kei''' Hökche aan häs.
 En dänne Fäll, muss De Der dä Enhald vun dä Klaafsigge selvs vörnemme, un eröm kopeere watte bruchs.",
 'movearticle'             => 'Sigg zem Ömnenne:',
-'movenologin'             => 'Nit Enjelogg',
-'movenologintext'         => 'Do mööts ald aanjemeldt un [[Special:Userlogin|enjelogg]] sin, öm en Sigg ömzenenne.',
 'movenotallowed'          => 'Do kriss nit erlaub, en däm Wiki hee de Sigge ömzenenne.',
 'newtitle'                => 'op dä neue Name',
 'move-watch'              => 'Op die Sigg hee oppasse',
@@ -1898,7 +2043,7 @@
 'pagemovedsub'            => 'Dat Ömnenne hät jeflupp',
 'movepage-moved'          => "<big>'''De Sigg „$1“ es jez en „$2“ ömjenannt.'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => "De Sigg met däm Name jitt et ald, oder dä Name ka'mer oder darf mer nit bruche.<br />Do muss Der ene andere Name ussöke.",
-'cantmove-titleprotected' => 'Die Sigg ömzenänne es ni mööschlesch, dä neue Name vun dä Sigg es jäje et neu Aanlääje jeschötz.',
+'cantmove-titleprotected' => 'Die Sigg ömzenänne es esu nit müjjelesch, dänn dä neu Name vun dä Sigg es jäje et Neu-Aanlääje jeschötz.',
 'talkexists'              => '<strong>Opjepass:</strong> De Sigg selver woodt jetz ömjenannt, ävver dä ehr Klaafsigg kunnte mer nit met ömnenne. Et jitt ald ein met däm neue Name. Bes esu jod un dun die zwei vun Hand zosamme läje!',
 'movedto'                 => 'ömjenannt en',
 'movetalk'                => 'dä ehr Klaafsigg met ömnenne, wat et jeiht',
@@ -1916,16 +2061,19 @@
 'revertmove'              => 'Et Ömnänne zerök_nämme',
 'delete_and_move'         => 'Fottschmieße un Ömnenne',
 'delete_and_move_text'    => '== Dä! Dubbelte Name ==
-Dä Atikkel „[[$1]]“ jitt et ald. Wollts De en fottschmieße, öm hee dä Atikkel ömnenne ze künne?',
-'delete_and_move_confirm' => 'Jo, dun dä Atikkel fottschmieße.',
+Di Sigg „[[:$1]]“ jitt et ald. Wollts De se fottschmieße, öm hee di Sigg ömnenne ze künne?',
+'delete_and_move_confirm' => 'Jo, dun di Sigg fottschmieße.',
 'delete_and_move_reason'  => 'Fottjeschmesse, öm Platz för et Ömnenne ze maache',
 'selfmove'                => 'Du Doof! - dä ahle Name un dä neue Name es däselve - do hät et Ömnenne winnich Senn.',
 'immobile_namespace'      => 'Do künne mer Sigge nit hen ömnenne, dat Appachtemeng es speziell, un dä neue Name för de Sigg jeiht deswäje nit.',
+'imagenocrossnamespace'   => 'Bellder kam_mer nor in et Appachtemang „{{ns:image}}“ donn, noh wonaders hen kam_mer se och nit ömnemme!',
+'imagetypemismatch'       => 'De neu Datei-Endong moß met däm Datei-Tüp zesamme passe',
 'imageinvalidfilename'    => 'Dä Ziel-Name för de Datei es verkeht',
+'fix-double-redirects'    => 'Don noh em Ömnenne de Ömleidunge automattesch ändere, di noch op dä ahle Tittel zeije, also de neu entshtande dubbelte Ömleidunge oplöse.',
 
 # Export
-'export'          => 'Sigge Exporteere',
-'exporttext'      => "Hee exportees De dä Tex un de Eijeschaffte vun ener Sigg, oder vun enem Knubbel Sigge, de aktuelle Version, met oder ohne ehr ählere Versione.
+'export'            => 'Sigge Exporteere',
+'exporttext'        => "Hee exportees De dä Tex un de Eijeschaffte vun ener Sigg, oder vun enem Knubbel Sigge, de aktuelle Version, met oder ohne ehr ählere Versione.
 Dat Janze es enjepack en XML.
 Dat ka'mer en en ander Wiki — wann et och met dä MediaWiki-Soffwär läuf — üvver de Sigg „[[Special:Import|Import]]“ do widder importeere.
 
@@ -1933,12 +2081,15 @@
 Dann dun onoch ussöke, ov De all de vörherije Versione vun dä Sigge han wells, oder nor de aktuelle met dä Informatione vun de letzte Änderung.
 
 En däm Fall künns De, för en einzelne Sigg, och ene tirekte Link bruche, zom Beispill „[[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]]“ för de Sigg „[[{{MediaWiki:Mainpage}}]]“ ze exporteere.",
-'exportcuronly'   => 'Bloß de aktuelle Version usjevve (un <strong>nit</strong> de janze ahle Versione onoch met dobei dun)',
-'exportnohistory' => '----
+'exportcuronly'     => 'Bloß de aktuelle Version usjevve (un <strong>nit</strong> de janze ahle Versione onoch met dobei dun)',
+'exportnohistory'   => '----
 <strong>Opjepass:</strong> de janze Versione Exporteere es hee em Wiki avjeschalt. Schad, ävver et wör en 
 zo jroße Lass för dä Sörver.',
-'export-submit'   => 'Loss_Jonn!',
-'export-addcat'   => 'Dobei donn',
+'export-submit'     => 'Loss_Jonn!',
+'export-addcattext' => 'Sigge dobei donn us dä Saachjrupp:',
+'export-addcat'     => 'Dobei donn',
+'export-download'   => 'Als en XML-Datei afspeichere',
+'export-templates'  => 'De Schablone met expochteere, die die Sigge bruche',
 
 # Namespace 8 related
 'allmessages'               => 'All Tex, Baustein un Aanzeije vum Wiki-System',
@@ -1952,9 +2103,13 @@
 'allmessagesmodified'       => 'Dun nor de Veränderte aanzeije',
 
 # Thumbnails
-'thumbnail-more'  => 'Jrößer aanzeije',
-'filemissing'     => 'Datei es nit do',
-'thumbnail_error' => 'Ene Fähler es opjetauch beim Maache vun enem Breefmarke/Thumbnail-Beldche: „$1“',
+'thumbnail-more'           => 'Jrößer aanzeije',
+'filemissing'              => 'Datei es nit do',
+'thumbnail_error'          => 'Ene Fähler es opjetauch beim Maache vun enem Breefmarke/Thumbnail-Beldche: „$1“',
+'djvu_page_error'          => 'De DjVu-Sgg es ußerhallef',
+'djvu_no_xml'              => 'De XML-Date för di DjVu-Datei kunnte mer nit afrofe',
+'thumbnail_invalid_params' => 'Ene Parameter för et Breefmarke-Belldsche (<i lang="en">thumbnail</i>) Maache wohr nit en Odenung',
+'thumbnail_dest_directory' => 'Dat Verzeichnis för dat erin ze donn kunte mer nit aanlääje.',
 
 # Special:Import
 'import'                     => 'Sigge Emporteere',
@@ -1975,18 +2130,23 @@
 'importbadinterwiki'         => 'Verkihrte Interwiki Link',
 'importnotext'               => 'En dä Datei wor nix dren enthallde, oder winnichstens keine Tex',
 'importsuccess'              => 'Dat Emporteere hät jeflupp!',
-'importhistoryconflict'      => 'Mer han zwei ahle Versione jefunge, die dun sich bieße - die ein wor ald do - de ander en dä Emport Datei. Möchlich, Ehr hatt die Daate ald ens emporteet.',
+'importhistoryconflict'      => 'Mer han zwei ahle Versione jefunge, die dun sich bieße - die ein wor ald do - de ander en dä Emport Datei. Künnt sin, Ehr hatt die Daate ald ens emporteet.',
 'importnosources'            => 'Hee es kein Quell för dä Tikek-Emport vun ander Wikis enjerich.
-Dat ahle Versione Huhlade es avjeschalt, un es nit möchlich.',
+Dat ahle Versione Huhlade es avjeschalt, un es nit müjjelich.',
 'importnofile'               => 'Et wood kein Datei huhjelade för ze Emporteere.',
+'importuploaderrorsize'      => 'De Import-Datei huhzelade jingk scheif, weil dat Denge jrößer wi äloup es.',
+'importuploaderrorpartial'   => 'De Import-Datei huhzelade jingk scheif, weil dat Denge nit komplett zo eng transpotteet woode es. Do fäählt jet.',
+'importuploaderrortemp'      => 'De Import-Datei huhzelade jingk scheif, weil e Zwescheverzeichnis fäählt.',
+'import-parse-failure'       => 'Fäähler bem Import per XML:',
 'import-noarticle'           => 'Kein Sigge do, för ze Emporteere!',
+'import-nonewrevisions'      => 'Et sin kein neue Versione do, för ze Importeere, weil all de Version hee ald fröjer emporteet wodte.',
 'xml-error-string'           => '$1 — en {{PLURAL:$2|eetz|$2-}}te Reih en de {{PLURAL:$3|eetz|$3-}}te Spalde, dat ess_et {{PLURAL:$4|eetz|$4-}}te Byte: $5',
 'import-upload'              => 'En XML-Datei impochteere',
 
 # Import log
 'importlogpage'                    => 'Logboch met emporteerte Sigge',
 'importlogpagetext'                => 'Sigge met ehre Versione vun ander Wikis emporteere.',
-'import-logentry-upload'           => '„[[$1]]“ emporteet',
+'import-logentry-upload'           => '„[[$1]]“ emporteet fun enne huhjelade Dattei',
 'import-logentry-upload-detail'    => '{{PLURAL:$1|ein Version|$1 Versione|kein Version}} emporteet',
 'import-logentry-interwiki'        => 'hät tirek vum ander Wiki emporteet: „$1“',
 'import-logentry-interwiki-detail' => '{{PLURAL:$1|ein Version|$1 Versione|kein Version}} vun „$2“',
@@ -2025,14 +2185,14 @@
 'tooltip-n-help'                  => 'Do kriss De jehollfe',
 'tooltip-t-whatlinkshere'         => 'En Liss met all de Sigge, die ene Link noh hee han',
 'tooltip-t-recentchangeslinked'   => 'De neuste Änderunge aan Sigge, wo vun hee dä Sigg uß Links drop jon',
-'tooltip-feed-rss'                => 'Dä RSS-Feed för hee die Sigg',
-'tooltip-feed-atom'               => 'Dä Atom-Feed för hee die Sigg',
+'tooltip-feed-rss'                => 'Dä RSS-Abonnomang-Kannal (Feed) för hee die Sigg',
+'tooltip-feed-atom'               => 'Dä Atom-Abonnomang-Kannal (Feed) för hee die Sigg',
 'tooltip-t-contributions'         => 'Donn de Liß met Bedträch vun däm Metmaacher beloore',
 'tooltip-t-emailuser'             => 'Scheck en E-Mail aan dä Metmaacher',
 'tooltip-t-upload'                => 'Dateie huhlade',
 'tooltip-t-specialpages'          => 'Liss met Sondersigge',
 'tooltip-t-print'                 => 'De Drock-Aansich för hee die Sigg',
-'tooltip-t-permalink'             => 'Ene iewich haltbare Lenk (Permalink) op jenou die Version vun hee dä Sigg, die de jrad süühß',
+'tooltip-t-permalink'             => 'Ene iewich haltbare Lenk (Permalink) op jenou die Version vun hee dä Sigg, die de jrad süühß un am beloore bes',
 'tooltip-ca-nstab-main'           => 'Don dä Enhallt vun dä Sigg aanzeije',
 'tooltip-ca-nstab-user'           => 'Dun die Metmaachersig aanzeije',
 'tooltip-ca-nstab-media'          => 'Don de Sigg övver en Mediendatei aanzeije',
@@ -2117,10 +2277,10 @@
 # Math options
 'mw_math_png'    => 'Immer nor PNG aanzeije',
 'mw_math_simple' => 'En einfache Fäll maach HTML, söns PNG',
-'mw_math_html'   => 'Maach HTML wann möchlich, un söns PNG',
+'mw_math_html'   => 'Maach HTML wann müjjelich, un söns PNG',
 'mw_math_source' => 'Lohß et als TeX (jod för de Tex-Brausere)',
 'mw_math_modern' => 'De bess Enstellung för de Brauser vun hück',
-'mw_math_mathml' => 'Nemm „MathML“ wann möchlich (em Probierstadium)',
+'mw_math_mathml' => 'Nemm „MathML“ wann müjjelich (em Probierstadium)',
 
 # Patrolling
 'markaspatrolleddiff'                 => 'Nohjeluurt. Dun dat fasshallde.',
@@ -2128,20 +2288,29 @@
 'markedaspatrolled'                   => 'Et Kennzeiche „Nohjeluurt“ speichere',
 'markedaspatrolledtext'               => 'Et es jetz fassjehallde, datte usjewählte Änderunge nohjeluurt sin.',
 'rcpatroldisabled'                    => 'Et Nohluure vun de letzte Änderunge es avjeschalt',
-'rcpatroldisabledtext'                => 'Et Nohluure fun de letzte Änderunge es em Momang nit möchlich.',
+'rcpatroldisabledtext'                => 'Et Nohluure fun de letzte Änderunge es em Momang nit müjjelich.',
 'markedaspatrollederror'              => 'Dat Kennzeiche „Nohjeluurt“ kunnt ich nit avspeichere.',
 'markedaspatrollederrortext'          => 'Do muss en bestemmte Version ussöke.',
-'markedaspatrollederror-noautopatrol' => 'Do darrefs ding eije Änderunge nit op „Nohjeloort“ setze!',
+'markedaspatrollederror-noautopatrol' => 'Do darrefs Ding eije Änderunge nit op „Nohjeloort“ setze!',
 
 # Patrol log
-'patrol-log-page' => 'Logboch vun de nohjeloorte Änderunge',
-'patrol-log-line' => 'hät $1 von „$2“ $3 nohjeloort.',
-'patrol-log-auto' => '(automatisch)',
-'patrol-log-diff' => 'de Version $1',
+'patrol-log-page'   => 'Logboch vun de nohjeloorte Änderunge',
+'patrol-log-header' => '<!-- -->',
+'patrol-log-line'   => 'hät $1 von „$2“ $3 nohjeloort.',
+'patrol-log-auto'   => '(automatisch)',
+'patrol-log-diff'   => 'de Version $1',
 
 # Image deletion
-'deletedrevision' => 'De ahl Version „$1“ es fottjeschmesse',
+'deletedrevision'                 => 'De ahl Version „$1“ es fottjeschmesse',
+'filedeleteerror-short'           => 'Fäähler bem Datei-Fottschmieße: $1',
+'filedeleteerror-long'            => 'Bem fosooch, de Datei fottzeschmieße, hatte mer Fäähler:
 
+$1',
+'filedelete-missing'              => 'De Datei „$1“ künne mer nit fottschmieße, Leevje, di jidd_et janit.',
+'filedelete-old-unregistered'     => 'En Version „$1“ fun dä Datei ham_mer nit in de Datebank.',
+'filedelete-current-unregistered' => 'De aanjejovve Datei „$1“ ham_mer nit in de Datebank.',
+'filedelete-archive-read-only'    => 'Unsere Webßöver kann udder darf nix en dat Aschif-Verzeichnis „$1“ eren schrieve.',
+
 # Browsing diffs
 'previousdiff' => '← De Ungerscheede dovör zeije',
 'nextdiff'     => 'De Ungerscheede donoh zeije →',
@@ -2158,7 +2327,7 @@
 'show-big-image'       => 'Jröößer Oplöösung',
 'show-big-image-thumb' => '<small>Di Vör-Aansich es $1 × $2 Pixelle jroß</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Belder, Tön, uew. als Jalerie',
 'imagelisttext'         => 'Hee küt en Liss vun <strong>$1</strong> Datei{{PLURAL:$1||e}}, zoteet $2.',
 'newimages-summary'     => 'Hee die Sigg zeig die zoletz huhjeladene Belder un Dateie aan.',
@@ -2193,28 +2362,170 @@
 * focallength', # Do not translate list items
 
 # EXIF tags
-'exif-imagewidth'  => 'Breejd',
-'exif-imagelength' => 'Läng',
-'exif-make'        => 'dä Kammera ier Heershtäller',
-'exif-model'       => 'dat Kammerra-Modäll',
-'exif-flash'       => 'Bletz',
-'exif-contrast'    => 'der Kontraß',
-'exif-saturation'  => 'de Färfsättijung',
-'exif-sharpness'   => 'de Beldschärf',
+'exif-imagewidth'                  => 'Breejd',
+'exif-imagelength'                 => 'Läng',
+'exif-bitspersample'               => 'Bits per Färvaandeil',
+'exif-compression'                 => 'Kompräßjonßtüp',
+'exif-photometricinterpretation'   => 'Zosammesetzung fun Pixelle',
+'exif-orientation'                 => 'Ußrechtung fun de Kammera',
+'exif-samplesperpixel'             => 'Aanzahl Färvaandeile',
+'exif-ycbcrsubsampling'            => 'Ongerafftastongsroht fun Y bes C',
+'exif-ycbcrpositioning'            => 'Y un C Posizjioneerung',
+'exif-xresolution'                 => 'Oplösung fun Lenks noh Räähß',
+'exif-yresolution'                 => 'Oplösung fun Bovve noh Onge',
+'exif-jpeginterchangeformat'       => 'Bytes Affshtand zom JPEG SOI',
+'exif-jpeginterchangeformatlength' => 'Bytes aan JPEG-Date',
+'exif-transferfunction'            => 'Övverdrarongsfungxjohn',
+'exif-whitepoint'                  => 'Fun Hand met Messung',
+'exif-ycbcrcoefficients'           => 'YCbCr-Geweeschte',
+'exif-referenceblackwhite'         => 'Schwazz-Wiiß-Bezochs-Punk-Paare',
+'exif-datetime'                    => 'Zickpunk fum Affshpeischere',
+'exif-imagedescription'            => 'Dem Beld singe Tittel',
+'exif-make'                        => 'Dä Kammera ier Heershtäller',
+'exif-model'                       => 'Dat Kammerra-Modäll',
+'exif-software'                    => 'De enjesatz ßoffwär',
+'exif-artist'                      => 'Fotojraf odder Maacher',
+'exif-copyright'                   => 'Wä et Urhävverrääsch hät',
+'exif-exifversion'                 => 'Exif-Version',
+'exif-flashpixversion'             => 'De ongershtözte <i lang="en">Flashpix</i>-Version',
+'exif-colorspace'                  => 'Färveroum',
+'exif-componentsconfiguration'     => 'Bedüggening fun all de enkele Komponente',
+'exif-compressedbitsperpixel'      => 'Aat fun de Kompreßjohn fun däm Beld',
+'exif-pixelydimension'             => 'Pixelle jöltije Beld-Breed',
+'exif-pixelxdimension'             => 'Pixelle jöltije Beld-Hühde',
+'exif-makernote'                   => 'Aanmerkong fum Hersteller',
+'exif-usercomment'                 => 'Aanmerkong fum Aanwender',
+'exif-relatedsoundfile'            => 'De Tondatei, di do bei jehööt',
+'exif-datetimeoriginal'            => 'Zickpunk fun de Opzeischnong fun de Date',
+'exif-datetimedigitized'           => 'Zickpunk fun de Dijjitalisierong',
+'exif-subsectime'                  => 'Honderstel Sekonde fun däm Zickpunk',
+'exif-subsectimeoriginal'          => 'Honderstel Sekonde fun däm Zickpunk fun de Opzeichnung fun de Date',
+'exif-subsectimedigitized'         => 'Honderstel Sekonde fun däm Zickpunk fun de Dijjitalisierong fun de Date',
+'exif-exposuretime'                => 'Beleeshtungsduur',
+'exif-exposuretime-format'         => '$1 Sekund{{PLURAL:$1||e|Sekund}} ($2)',
+'exif-fnumber'                     => 'Blende',
+'exif-exposureprogram'             => 'Beleeshtungsprojramm',
+'exif-spectralsensitivity'         => 'Emfendleschkeit för et Färvespäktrom',
+'exif-isospeedratings'             => 'Dem Fillem odder Sensor sing Emfindlischkeit (als ISO Wäät)',
+'exif-shutterspeedvalue'           => 'Jeschwendieschkeit fum Verschoß bem Beleeschte',
+'exif-aperturevalue'               => 'De Blend iere Wäät',
+'exif-brightnessvalue'             => 'De Hellishkeit',
+'exif-subjectdistance'             => 'Affshtand nohm Motif',
+'exif-lightsource'                 => 'Leechquell',
+'exif-flash'                       => 'Bletz',
+'exif-focallength'                 => 'De Brennwigde fun de Lenß',
+'exif-subjectarea'                 => 'Em Motiv singe Bereich',
+'exif-flashenergy'                 => 'Dem Bletz sing Ennäjii',
+'exif-subjectlocation'             => 'Dä Plaz fun dämm Motif',
+'exif-filesource'                  => 'Dä Datei ier Quell',
+'exif-whitebalance'                => 'Wießaffjleich',
+'exif-digitalzoomratio'            => 'Dijitalzoom',
+'exif-focallengthin35mmfilm'       => 'De Brennwigde op 35 Millimeeter Kleinbeldfillem betrocke',
+'exif-contrast'                    => 'der Kontraß',
+'exif-saturation'                  => 'de Färfsättijung',
+'exif-sharpness'                   => 'de Beldschärf',
+'exif-subjectdistancerange'        => 'Em Motif singe Affshtandsbereisch',
+'exif-imageuniqueid'               => 'Eindeutije Kännong för dat Beld',
+'exif-gpslatituderef'              => 'nöödlesch udder södlesch Breed fum GPS',
+'exif-gpslatitude'                 => 'De Breed om Äädball fum GPS',
+'exif-gpslongituderef'             => 'ösßlesch udder weßlesch Läng fum GPS',
+'exif-gpslongitude'                => 'Läng om Äädball fum GPS',
+'exif-gpsaltituderef'              => 'Wo drop de Hühde nohm GPS betrocke es',
+'exif-gpsaltitude'                 => 'Hühde nohm GPS',
+'exif-gpstimestamp'                => 'Zick fun de Atom-Uhr nohm GPS',
+'exif-gpssatellites'               => 'Dem GPS sing Sattelitte för disse Meßvörjang',
+'exif-gpsstatus'                   => 'Dä Shtattus fum GPS Emfangsjeräät',
+'exif-gpsmeasuremode'              => 'Dat GPS-Meßverfahre',
+'exif-gpsdop'                      => 'De Jenoueschkeit beim Meßße vum GPS',
+'exif-gpsspeedref'                 => 'De Moß_Einheit fun de Jeschwendeshkeit',
+'exif-gpsspeed'                    => 'Dem GPS-Emfangsejeräät sing Tempo',
+'exif-gpstrackref'                 => 'Der Bezoch för de Bewääjong nohm GPS  ier Reeschtong',
+'exif-gpstrack'                    => 'De Bewäjong nohm GPS ier Reeshtong',
+'exif-gpsimgdirectionref'          => 'Der Bezoch för de Ußreschtong fum Beld nohm GPS',
+'exif-gpsimgdirection'             => 'Ußreschtong fum Beld nohm GPS',
+'exif-gpsmapdatum'                 => 'Jeodätisches Beobachtongs-Dattum nohm GPS jebruch',
+'exif-gpsdestlatituderef'          => 'Bezoch för de Breed fum Ziel nohm GPS',
+'exif-gpsdestlatitude'             => 'De Breed fum Ziel nohm GPS',
+'exif-gpsdestlongituderef'         => 'Bezoch för de Läng fum Ziel nohm GPS',
+'exif-gpsdestlongitude'            => 'De Läng fum Ziel nohm GPS',
+'exif-gpsdestbearingref'           => 'Bezoch för de Reschtong fum Mottif nohm GPS',
+'exif-gpsdestbearing'              => 'De Reschtong fum Mottif nohm GPS',
+'exif-gpsdestdistanceref'          => 'Bezoch för de Entfernong fum Mottif nohm GPS',
+'exif-gpsdestdistance'             => 'De Entfernong fum Mottif nohm GPS',
+'exif-gpsprocessingmethod'         => 'Dä Name fum GPS-Verfahre',
+'exif-gpsareainformation'          => 'Dä Name fum GPS-Jebeet',
+'exif-gpsdatestamp'                => 'GPS-Dattum',
+'exif-gpsdifferential'             => 'De Differenzjahl-Bereschtijong fum GPS',
 
-'exif-orientation-1' => 'Nomal', # 0th row: top; 0th column: left
+# EXIF attributes
+'exif-compression-1' => 'Oohne Kompressjuhn',
 
+'exif-unknowndate' => 'Dattum onbikannt',
+
+'exif-orientation-1' => 'Nommaal', # 0th row: top; 0th column: left
+'exif-orientation-2' => 'Op der Kopp jespeejelt', # 0th row: top; 0th column: right
+'exif-orientation-3' => 'Op der Kopp jedrieht', # 0th row: bottom; 0th column: right
+'exif-orientation-4' => 'Links-Räähß jespeejelt', # 0th row: bottom; 0th column: left
+'exif-orientation-5' => 'En Veedelsdriejong mem Uhrzeijer un dann links-räähß jespeejelt', # 0th row: left; 0th column: top
+'exif-orientation-6' => 'En Veedelsdriejong mem Uhrzeijer', # 0th row: right; 0th column: top
+'exif-orientation-7' => 'En Veedelsdriejong jääje der Uhrzeijer un dann links-räähß jespeejelt', # 0th row: right; 0th column: bottom
+'exif-orientation-8' => 'En Veedelsdriejong jääje der Uhrzeijer', # 0th row: left; 0th column: bottom
+
+'exif-componentsconfiguration-0' => 'Jidd_et nit',
+
+'exif-exposureprogram-1' => 'Vun Hand',
+'exif-exposureprogram-7' => 'Us de Nöhde en huhkant opjenomme, mem Bleck op Fürre',
+'exif-exposureprogram-8' => 'Landschaff em Querfommaat opjenomme, mem Bleck op der Hengerjrond',
+
+'exif-subjectdistance-value' => '{{PLURAL:$1|eine|$1|keine}} Meter',
+
+'exif-meteringmode-0'   => 'Onbikannt',
+'exif-meteringmode-1'   => 'Meddelmääßesch',
+'exif-meteringmode-3'   => 'Punkmessung',
+'exif-meteringmode-4'   => 'Miehpunkmessung',
+'exif-meteringmode-5'   => 'Muster',
+'exif-meteringmode-6'   => 'Deijl fum Beld',
 'exif-meteringmode-255' => 'Ander',
 
-'exif-lightsource-4' => 'Bletz',
+'exif-lightsource-0'   => 'Onbikannt',
+'exif-lightsource-1'   => 'Daresleech',
+'exif-lightsource-4'   => 'Bletz',
+'exif-lightsource-9'   => 'Joodt Wedder',
+'exif-lightsource-10'  => 'Wedder met Wolke',
+'exif-lightsource-11'  => 'Schadde',
+'exif-lightsource-17'  => 'Standat Leech Tüp A',
+'exif-lightsource-18'  => 'Standat Leech Tüp B',
+'exif-lightsource-19'  => 'Standat Leech Tüp C',
+'exif-lightsource-255' => 'Söns en Leechquell',
 
+'exif-focalplaneresolutionunit-2' => 'Zoll',
+
+'exif-sensingmethod-1' => 'Onbikannt',
+'exif-sensingmethod-2' => 'Ene Sensor fö Färve op einem Bousteijn',
+'exif-sensingmethod-3' => 'Ene Sensor fö Färve op zweij Bousteijn',
+'exif-sensingmethod-4' => 'Ene Sensor fö Färve op dreij Bousteijn',
+'exif-sensingmethod-5' => 'Ene sequenzjelle Bereijschs-Sensor fö Färve',
+'exif-sensingmethod-7' => 'Ene trilinejare sequenzjelle Sensor fö Färve',
+'exif-sensingmethod-8' => 'Ene linejare sequenzjelle Sensor fö Färve',
+
 'exif-scenecapturetype-0' => 'Nomaal',
+'exif-scenecapturetype-1' => 'Queerfommaat',
+'exif-scenecapturetype-2' => 'Huhkant',
+'exif-scenecapturetype-3' => 'Et Naakß',
 
+'exif-gaincontrol-0' => 'Nix',
+
 'exif-contrast-0' => 'Nomal',
+'exif-contrast-1' => 'Weijsch',
+'exif-contrast-2' => 'Hatt',
 
 'exif-saturation-0' => 'Nomal',
+'exif-saturation-1' => 'Winnisch Sättejung',
+'exif-saturation-2' => 'En hue Sättejung',
 
 'exif-sharpness-0' => 'Nomal',
+'exif-sharpness-1' => 'Nit esu scharf',
+'exif-sharpness-2' => 'Scharf',
 
 'exif-subjectdistancerange-0' => 'Onbikannt',
 'exif-subjectdistancerange-1' => 'Janz deesch draan (Makro-Opnahm)',
@@ -2232,13 +2543,18 @@
 'exif-gpsmeasuremode-2' => 'Zweidimensjonal Mohß',
 'exif-gpsmeasuremode-3' => 'Dreidimensjonal Mohß',
 
+# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+'exif-gpsspeed-k' => 'Killomeeter en de Shtondt',
+'exif-gpsspeed-m' => 'Miehle en de Shtondt',
+'exif-gpsspeed-n' => 'Knote',
+
 # Pseudotags used for GPSTrackRef, GPSImgDirectionRef and GPSDestBearingRef
 'exif-gpsdirection-t' => 'Wohre Rechtung',
 'exif-gpsdirection-m' => 'Mangneetesche Rechtung',
 
 # External editor support
 'edit-externally'      => 'Dun de Datei met enem externe Projramm bei Dr om Rechner bearbeide',
-'edit-externally-help' => 'Luur en de [http://meta.wikimedia.org/wiki/Help:External_editors Installationsaanweisunge] noh Hinwies, wie mer esu en extern Projramm ennrechte un installeere deit.',
+'edit-externally-help' => 'Luur en de [http://www.mediawiki.org/wiki/Manual:External_editors Installationsaanweisunge] noh Hinwies, wie mer esu en extern Projramm ennrechte un installeere deit.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'all',
@@ -2251,7 +2567,7 @@
 'confirmemail'             => 'E-Mail Adress bestätije',
 'confirmemail_noemail'     => 'En [[Special:Preferences|Ding Enstellunge]] es kein öntlich E-Mail Adress.',
 'confirmemail_text'        => 'Ih datte en däm Wiki hee de E-Mail bruche kanns, muss De Ding E-Mail Adress bestätich han, dat se en Oodnung es un dat se och Ding eijene es. Klick op dä Knopp un Do kriss en E-Mail jescheck. Do steiht ene Link met enem Code dren. Wann De met Dingem Brauser op dä Link jeihs, dann deis De domet bestätije, dat et wirklich Ding E-Mail Adress es. Dat es nit allzo secher, alsu wör nix för Die Bankkonto oder bei de Sparkass, ävver et sorg doför, dat nit jede Peijaß met Dinger E-Mail oder Dingem Metmaachername eröm maache kann.',
-'confirmemail_pending'     => '<div class="error">Do häs ald ene Kood för de Bestätijung med ene E-Mail zojeschek bekumme. Wann De Ding Aanmeldung eez jraad jemaat häs, dann donn noch ene Moment waade, ih dat De ene neue Kood hölls.</div>',
+'confirmemail_pending'     => '<div class="error">Do häs ald ene Kood för de Bestätijung med ene E-Mail zojeschek bekumme. Wann De Ding Aanmeldung eez jraad jemaat häs, dann donn noch ene Moment waade, ih dat De Der ene neue Kood hölls.</div>',
 'confirmemail_send'        => 'Scheck en E-Mail zem Bestätije',
 'confirmemail_sent'        => 'En E-Mail, för Ding E-Mail Adress ze bestätije, es ungerwähs.',
 'confirmemail_oncreate'    => 'Do häs jetz ene Kood för de Bestätijung med ene E-Mail zojeschek bekumme. För em Wiki jet ze maache, un för et Enlogge, do bruchs De der Kode nit, ävver domet de e-Mail övver et Wiki schecke un krijje kanns, doför moß De en ejmool ens bestätijje, domet secher es, dat Ding E-Mail Adress och rechtich jetipp wohr.',
@@ -2266,8 +2582,8 @@
 'confirmemail_loggedin'    => 'Ding E-Mail Adress es jetz bestätich!',
 'confirmemail_error'       => 'Beim E-Mail Adress Bestätije es jet donevve jejange, de Bestätijung kunnt nit avjespeichert wääde.',
 'confirmemail_subject'     => 'Dun Ding E-Mail Adress bestätije för de {{SITENAME}}.',
-'confirmemail_body'        => 'Jod möchlich, Do wors et selver,
-vun de IP_Adress $1,
+'confirmemail_body'        => 'Künnt jod sin, Do wors et selver,
+vun de IP_Adress $1
 hät sich jedenfalls einer aanjemeldt,
 un well dä Metmaacher „$2“ op de {{SITENAME}}
 wääde, un hät en E-Mail Adress aanjejovve.
@@ -2289,8 +2605,8 @@
 
 $5
 
-Domet deiß De tirek sare, dat De Adress vun
-Ding E-Mail nit bestätije wells.
+Domet deiß De tirek sare, dat De Adress
+nit bestätije wells.
 
 Wann de jetz neujeerich jewoode bes un wells
 wesse, wat met de {{SITENAME}} loss es,
@@ -2327,7 +2643,7 @@
 'recreate'            => 'Widder neu aanlääje',
 
 # HTML dump
-'redirectingto' => 'Leit öm op: „[[$1]]“',
+'redirectingto' => 'Leit öm op: „[[:$1]]“',
 
 # action=purge
 'confirm_purge'        => 'Dä Zweschespeicher för die Sigg fottschmieße?
@@ -2369,20 +2685,23 @@
 'autosumm-new'     => 'Neu Sigg: $1',
 
 # Size units
-'size-bytes' => '$1 Bytes',
+'size-bytes'     => '$1 Bytes',
+'size-kilobytes' => '$1 KB',
+'size-megabytes' => '$1 MB',
+'size-gigabytes' => '$1 GB',
 
 # Live preview
 'livepreview-loading' => 'Ben am Lade …',
 'livepreview-ready'   => 'Fädesch jelaade.',
 'livepreview-failed'  => 'De lebendije Vör-Ansich klapp jrad nit.
 Don de nomaale Vör-Ansich nemme.',
-'livepreview-error'   => 'Kein Verbendung möschlesch: $1 „$2“.
+'livepreview-error'   => 'Kein Verbendung müjjelisch: $1 „$2“.
 Don de nomaale Vör-Ansich nemme.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Änderunge us de letzte {{PLURAL:$1|Sekund|$1 Sekunde|knappe Sekund}} sin en dä Leß noch nit opjenomme.',
-'lag-warn-high'   => 'Dä Datebankßööver hät jrad vill ze donn,
-Änderunge us de letzte {{PLURAL:$1|Sekund|$1 Sekunde|knappe Sekund}} sin dröm en dä Leß hee noch nit opjenomme.',
+'lag-warn-normal' => 'Änderunge us de letzte {{PLURAL:$1|Sekund|$1 Sekunde|knappe Sekund}} sin en dä Leß wall noch nit opjenomme.',
+'lag-warn-high'   => 'Dä Datebankßööver hät jrad vill ze donn.
+Änderunge us de letzte {{PLURAL:$1|Sekund|$1 Sekunde|knappe Sekund}} sin dröm en dä Leß hee wall noch nit opjenomme.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'En Dinge Oppassliss {{PLURAL:$1|es eine Endrach|sen $1 Endräsch|es keine Endrach}} — Klaafsigge dozoh zälle nit ëxtra.',
@@ -2437,7 +2756,7 @@
 'version-software-product'         => 'Produk',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Bellder, Tööhn, uew. zëije, med ier URL',
 'filepath-page'    => 'Dattëij_Name:',
 'filepath-submit'  => 'Zëĳsh dä Pahdt',
@@ -2453,7 +2772,7 @@
 'fileduplicatesearch-legend'   => 'Sök noh ene dubbelte Datei',
 'fileduplicatesearch-filename' => 'Dateiname:',
 'fileduplicatesearch-submit'   => 'Sööke',
-'fileduplicatesearch-info'     => '{{PLURAL|$1|Ei Pixel|$1 Pixelle|Nit}} breed × {{PLURAL:$2|Ei Pixel|$2 Pixelle|nix}} huh<br />Dateiömfang: $3<br />MIME-Tüp: <code>$4</code>',
+'fileduplicatesearch-info'     => '{{PLURAL:$1|Ei Pixel|$1 Pixelle|Nit}} breed × {{PLURAL:$2|Ei Pixel|$2 Pixelle|nix}} huh<br />Dateiömfang: $3<br />MIME-Tüp: <code>$4</code>',
 'fileduplicatesearch-result-1' => 'Mer han kein akoraat dubbelte Dateie för „$1“ jefonge.',
 'fileduplicatesearch-result-n' => "Vun dä Datei „$1“ ham'mer '''{{PLURAL:$2|ein|$2|kein}}''' dubbelte mem selve Enhalt jefonge.",
 
@@ -2475,7 +2794,7 @@
 'specialpages-group-redirects'   => 'Sondersigge, die ömleite, söke, un finge',
 'specialpages-group-spam'        => 'Werrekzeuch jäje SPÄM',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Vakat-Sigg',
 'intentionallyblankpage' => 'Op dä Sigg es med Afseesh nix drop.',
 
Index: languages/messages/MessagesTr.php
===================================================================
--- languages/messages/MessagesTr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,20 +4,18 @@
  * @ingroup Language
  * @file
  *
- * @author Srhat
- * @author SPQRobin
- * @author Uğur Başak
  * @author Dbl2010
- * @author Karduelis
- * @author Suelnur
  * @author Erkan Yilmaz
- * @author Runningfridgesrule
- * @author Siebrand
+ * @author Karduelis
  * @author Katpatuka
  * @author Mach
- * @author לערי ריינהארט
  * @author Mskyrider
  * @author Myildirim2007
+ * @author Runningfridgesrule
+ * @author Srhat
+ * @author Suelnur
+ * @author Uğur Başak
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -319,7 +317,7 @@
 'nosuchaction'      => 'Böyle bir eylem yok',
 'nosuchactiontext'  => 'URL tarafından tanımlanan eylem Viki tarafından algılanamadı.',
 'nosuchspecialpage' => 'Bu isimde bir özel sayfa yok',
-'nospecialpagetext' => 'Bulunmayan bir özel sayfaya girdiniz. Varolan tüm özel sayfaları [[Special:Specialpages]] sayfasında görebilirsiniz.',
+'nospecialpagetext' => 'Bulunmayan bir özel sayfaya girdiniz. Varolan tüm özel sayfaları [[Special:SpecialPages]] sayfasında görebilirsiniz.',
 
 # General errors
 'error'                => 'Hata',
@@ -571,10 +569,6 @@
 'blockededitsource'                => "'''$1''' sayfasında '''yaptığınız değişikliğe''' ait metin aşağıdadır:",
 'whitelistedittitle'               => 'Değişiklik yapmak için oturum açmalısınız',
 'whitelistedittext'                => 'Değişiklik yapabilmek için $1.',
-'whitelistreadtitle'               => 'Okumak için oturum açmalısınız',
-'whitelistreadtext'                => 'Sayfaları okuyabilmek için [[Special:Userlogin|oturum açmalısınız]].',
-'whitelistacctitle'                => 'Hesap açma izniniz yok.',
-'whitelistacctext'                 => '{{SITENAME}} sitesinde kullanıcı hesapları oluşturabilmek için [[Special:Userlogin|giriş yapmak]] ve gerekli izinlere sahip olmak zorundasınız',
 'confirmedittitle'                 => 'Değişiklik yapmak için e-posta onaylaması gerekiyor',
 'confirmedittext'                  => 'Sayfa değiştirmeden önce e-posta adresinizi onaylamalısınız. Lütfen [[Special:Preferences|tercihler]] kısmından e-postanızı ekleyin ve onaylayın.',
 'nosuchsectiontitle'               => 'Böyle bir bölüm yok',
@@ -587,7 +581,7 @@
 'newarticle'                       => '(Yeni)',
 'newarticletext'                   => "Henüz varolmayan bir sayfaya konulmuş bir bağlantıya tıkladınız. Bu sayfayı yaratmak için aşağıdaki metin kutusunu kullanınız. Bilgi için [[{{MediaWiki:Helppage}}|yardım sayfasına]] bakınız. Buraya yanlışlıkla geldiyseniz, programınızın '''Geri''' tuşuna tıklayınız.",
 'anontalkpagetext'                 => "----
-''Bu kayıtlı olmayan ya da kayıtlı adıyla sisteme giriş yapmamış bir kullanıcının mesaj sayfasıdır. Bu sebeple kimliği IP adresi ile gösterilmektedir. Bu tür IP adresleri diğer kişiler tarafından payşılabilir. Eğer siz de bir anonim kullanıcı iseniz ve yöneltilen yorumlar sizle ilgili değilse, [[Special:Userlogin|kayıt olun ya da sisteme girin ki]] ileride başka yanlış anlaşılma olmasın.''",
+''Bu kayıtlı olmayan ya da kayıtlı adıyla sisteme giriş yapmamış bir kullanıcının mesaj sayfasıdır. Bu sebeple kimliği IP adresi ile gösterilmektedir. Bu tür IP adresleri diğer kişiler tarafından payşılabilir. Eğer siz de bir anonim kullanıcı iseniz ve yöneltilen yorumlar sizle ilgili değilse, [[Special:UserLogin|kayıt olun ya da sisteme girin ki]] ileride başka yanlış anlaşılma olmasın.''",
 'noarticletext'                    => 'Bu sayfa boştur. Bu başlığı diğer sayfalarda [[Special:Search/{{PAGENAME}}|arayabilir]] veya bu sayfayı siz  [{{fullurl:{{FULLPAGENAME}}|action=edit}} yazabilirsiniz].',
 'userpage-userdoesnotexist'        => '"$1" kullanıcı hesabı kayıtlı değil. Bu sayfayı oluşturmak/değiştirmek istiyorsanız lütfen kontrol edin.',
 'clearyourcache'                   => "'''Not:''' Ayarlarınızı kaydettikten sonra, tarayıcınızın belleğini de temizlemeniz gerekmektedir: '''Mozilla / Firefox / Safari:''' ''Shift'' e basılıyken safyayı yeniden yükleyerek veya ''Ctrl-Shift-R'' yaparak (Apple Mac için ''Cmd-Shift-R'');, '''IE:''' ''Ctrl-F5'', '''Konqueror:''' Sadece sayfayı yeniden yükle tuşuna basarak.",
@@ -634,7 +628,7 @@
 'hiddencategories'                 => 'Bu sayfa {{PLURAL:$1|1 gizli kategoriye|$1 gizli kategoriye}} mensuptur:',
 'nocreatetitle'                    => 'Sayfa oluşturulması limitlendi',
 'nocreatetext'                     => '{{SITENAME}}, yeni sayfa oluşturulabilmesini engelledi.
-Geri giderek varolan sayfayı değiştirebilirsiniz ya da kayıtlı iseniz [[Special:Userlogin|oturum açabilir]], değilseniz [[Special:Userlogin|kayıt olabilirsiniz]].',
+Geri giderek varolan sayfayı değiştirebilirsiniz ya da kayıtlı iseniz [[Special:UserLogin|oturum açabilir]], değilseniz [[Special:UserLogin|kayıt olabilirsiniz]].',
 'nocreate-loggedin'                => '{{SITENAME}} üzerinde yeni sayfalar oluşturmaya yetkiniz yok.',
 'permissionserrors'                => 'İzin hataları',
 'permissionserrorstext'            => 'Aşağıdaki {{PLURAL:$1|sebep|sebepler}}den dolayı, bunu yapmaya yetkiniz yok:',
@@ -795,7 +789,7 @@
 'mypreferences'            => 'Tercihlerim',
 'prefs-edits'              => 'Değişikilik sayısı:',
 'prefsnologin'             => 'Oturum açık değil',
-'prefsnologintext'         => 'Kullanıcı tercihlerinizi ayarlamak için [[Special:Userlogin|giriş yapmış]] olmalısınız.',
+'prefsnologintext'         => 'Kullanıcı tercihlerinizi ayarlamak için [[Special:UserLogin|giriş yapmış]] olmalısınız.',
 'prefsreset'               => 'Tercihler hafızadan sıfırlandı.',
 'qbsettings'               => 'Hızlı erişim sütun ayarları',
 'qbsettings-none'          => 'Hiçbiri',
@@ -861,7 +855,7 @@
 'userrights-reason'           => 'Değiştirme nedeni:',
 'userrights-no-interwiki'     => 'Diğer vikilerdeki kullanıcıların izinlerini değiştirmeye yetkiniz yok.',
 'userrights-nodatabase'       => '$1 veritabanı mevcut veya bölgesel değil',
-'userrights-nologin'          => 'Kullanıcı haklarını atamak için yönetici hesabı ile [[Special:Userlogin|giriş yapmanız gerekir]].',
+'userrights-nologin'          => 'Kullanıcı haklarını atamak için yönetici hesabı ile [[Special:UserLogin|giriş yapmanız gerekir]].',
 'userrights-notallowed'       => 'Kullanıcı hesabınızın kullanıcı haklarını atamak için izni yok.',
 'userrights-changeable-col'   => 'Değiştirebildiğiniz gruplar',
 'userrights-unchangeable-col' => 'Değiştirebilmediğiniz gruplar',
@@ -947,11 +941,11 @@
 'reupload'                    => 'Yeniden yükle',
 'reuploaddesc'                => 'Yükleme formuna geri dön.',
 'uploadnologin'               => 'Oturum açık değil',
-'uploadnologintext'           => 'Dosya yükleyebilmek için [[Special:Userlogin|oturum aç]]manız gerekiyor.',
+'uploadnologintext'           => 'Dosya yükleyebilmek için [[Special:UserLogin|oturum aç]]manız gerekiyor.',
 'upload_directory_read_only'  => 'Dosya yükleme dizinine ($1) web sunucusunun yazma izni yok.',
 'uploaderror'                 => 'Yükleme hatası',
 'uploadtext'                  => "Dosya yüklemek için aşağıdaki formu kullanın,
-Önceden yüklenmiş resimleri görmek için  [[Special:Imagelist|resim listesine]] bakın,
+Önceden yüklenmiş resimleri görmek için  [[Special:ImageList|resim listesine]] bakın,
 yüklenenler ve silinmişler [[Special:Log/upload|yükleme kaydı sayfasında da]] görülebilir.
 
 Sayfaya resim koymak için formdaki linklerdimelerşi kullanın;
@@ -1019,7 +1013,7 @@
 'upload_source_url'  => ' (geçerli, herkesin ulaşabileceği bir URL)',
 'upload_source_file' => ' (bilgisayarınızdaki bir dosya)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Medya adı ara:',
 'imgfile'               => 'dosya',
 'imagelist'             => 'Resim listesi',
@@ -1110,7 +1104,7 @@
 Toplam sayfa görüntülenme sayısı '''\$3''', değişiklik başına görüntüleme sayısı '''\$6''' olmuştur.
 
 Şu andaki [http://www.mediawiki.org/wiki/Manual:Job_queue iş kuyruğu] sayısı '''\$7'''.",
-'userstatstext'          => "'''$1''' kayıtlı [[Special:Listusers|kullanıcı]] var. Bunlardan '''$2''' tanesi (ya da '''$4%''') $5 haklarına sahiptir.",
+'userstatstext'          => "'''$1''' kayıtlı [[Special:ListUsers|kullanıcı]] var. Bunlardan '''$2''' tanesi (ya da '''$4%''') $5 haklarına sahiptir.",
 'statistics-mostpopular' => 'En popüler maddeler',
 
 'disambiguations'      => 'Anlam ayrım sayfaları',
@@ -1189,7 +1183,7 @@
 'logempty'             => 'Kayıtlarda eşleşen bilgi yok.',
 'log-title-wildcard'   => 'Bu metinle başlayan başlıklar ara',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tüm sayfalar',
 'alphaindexline'    => '$1 sayfası ile $2 sayfası arasındaki sayfaların listesi',
 'nextpage'          => 'Sonraki sayfa ($1)',
@@ -1210,18 +1204,18 @@
 'special-categories-sort-count' => 'sayılarına göre sırala',
 'special-categories-sort-abc'   => 'alfabetik olarak sırala',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Göster',
 'listusers-noresult' => 'Kullanıcı bulunamadı.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'   => 'grup',
 'listgrouprights-rights'  => 'Haklar',
 'listgrouprights-members' => '(üyelerin listesi)',
 
 # E-mail user
 'mailnologin'     => 'Gönderi adresi yok.',
-'mailnologintext' => 'Diğer kullanıcılara e-posta gönderebilmeniz için [[Special:Userlogin|oturum aç]]malısınız ve [[Special:Preferences|tercihler]] sayfasında geçerli bir e-posta adresiniz olmalı.',
+'mailnologintext' => 'Diğer kullanıcılara e-posta gönderebilmeniz için [[Special:UserLogin|oturum aç]]malısınız ve [[Special:Preferences|tercihler]] sayfasında geçerli bir e-posta adresiniz olmalı.',
 'emailuser'       => 'Kullanıcıya e-posta gönder',
 'emailpage'       => 'Kullanıcıya e-posta gönder',
 'emailpagetext'   => 'Aşağıdaki form kullanıcı hesabıyla ilişkilendirilmiş geçerli bir e-posta adresi olduğu takdirde ilgili kişiye bir e-posta gönderecek. 
@@ -1247,13 +1241,13 @@
 'nowatchlist'          => 'İzleme listesinde hiçbir madde bulunmuyor.',
 'watchlistanontext'    => 'Lütfen izleme listenizdeki maddeleri görmek yada değiştirmek için $1.',
 'watchnologin'         => 'Oturum açık değil.',
-'watchnologintext'     => 'İzleme listenizi değiştirebilmek için [[Special:Userlogin|oturum açmalısınız]].',
+'watchnologintext'     => 'İzleme listenizi değiştirebilmek için [[Special:UserLogin|oturum açmalısınız]].',
 'addedwatch'           => 'İzleme listesine kaydedildi.',
 'addedwatchtext'       => '"<nowiki>$1</nowiki>" adlı sayfa [[Special:Watchlist|izleme listenize]] kaydedildi.
 
 Gelecekte, bu sayfaya ve ilgili tartışma sayfasına yapılacak değişiklikler burada listelenecektir.
 
-Kolayca seçilebilmeleri için de [[Special:Recentchanges|son değişiklikler listesi]] başlığı altında koyu harflerle listeleneceklerdir.
+Kolayca seçilebilmeleri için de [[Special:RecentChanges|son değişiklikler listesi]] başlığı altında koyu harflerle listeleneceklerdir.
 
 Sayfayı izleme listenizden çıkarmak istediğinizde "sayfayı izlemeyi durdur" bağlantısına tıklayabilirsiniz.',
 'removedwatch'         => 'İzleme listenizden silindi',
@@ -1482,7 +1476,7 @@
 'badipaddress'                => 'Geçersiz IP adresi',
 'blockipsuccesssub'           => 'IP adresi engelleme işlemi başarılı oldu',
 'blockipsuccesstext'          => '"$1" engellendi.
-<br />[[Special:Ipblocklist|IP adresi engellenenler]] listesine bakınız.',
+<br />[[Special:IPBlockList|IP adresi engellenenler]] listesine bakınız.',
 'ipb-edit-dropdown'           => 'Engelleme nedenleri düzenle',
 'ipb-unblock-addr'            => '$1 için engellemeyi kaldır',
 'ipb-unblock'                 => 'Engellemeyi kaldır',
@@ -1509,7 +1503,7 @@
 'autoblocker'                 => 'Otomatik olarak engellendiniz çünkü yakın zamanda IP adresiniz "[[User:$1|$1]]" kullanıcısı tarafından  kullanılmıştır. $1 isimli kullanıcının engellenmesi için verilen sebep: "\'\'\'$2\'\'\'"',
 'blocklogpage'                => 'Erişim engelleme kayıtları',
 'blocklogentry'               => '[[$1]], $2 $3 tarihleri arası süresince engellendi',
-'blocklogtext'                => 'Burada kullanıcı erişimine yönelik engelleme ya da engelleme kaldırma kayıtları listelenmektedir. Otomatik  IP adresi engellemeleri listeye dahil değildir. Şu anda erişimi durdurulmuş kullanıcıları [[Special:Ipblocklist|IP engelleme listesi]] sayfasından görebilirsiniz.',
+'blocklogtext'                => 'Burada kullanıcı erişimine yönelik engelleme ya da engelleme kaldırma kayıtları listelenmektedir. Otomatik  IP adresi engellemeleri listeye dahil değildir. Şu anda erişimi durdurulmuş kullanıcıları [[Special:IPBlockList|IP engelleme listesi]] sayfasından görebilirsiniz.',
 'unblocklogentry'             => '$1 kullanıcının engellemesi kaldırıldı',
 'block-log-flags-anononly'    => 'sadece anonim kullanıcılar',
 'block-log-flags-nocreate'    => 'hesap yaratımı engellendi',
@@ -1558,8 +1552,6 @@
 
 Bu durumlarda sayfayı kendiniz aktarmalısınız.",
 'movearticle'             => 'Eski isim',
-'movenologin'             => 'Sistemde değilsiniz.',
-'movenologintext'         => 'Sayfanın adını değiştirebilmek için kayıtlı ve [[Special:Userlogin|sisteme]] giriş yapmış olmanız gerekmektedir.',
 'newtitle'                => 'Yeni isim',
 'move-watch'              => 'Bu sayfayı izle',
 'movepagebtn'             => 'İsmi değiştir',
@@ -1581,7 +1573,7 @@
 'delete_and_move'         => 'Sil ve taşı',
 'delete_and_move_text'    => '==Silinmesi gerekiyor==
 
-"[[$1]]" isimli bir sayfa zaten mevcut. O sayfayı silerek, isim değişikliğini gerçekleştirmeye devam etmek istiyor musunuz?',
+"[[:$1]]" isimli bir sayfa zaten mevcut. O sayfayı silerek, isim değişikliğini gerçekleştirmeye devam etmek istiyor musunuz?',
 'delete_and_move_confirm' => 'Evet, sayfayı sil',
 'delete_and_move_reason'  => 'İsim değişikliğinin gerçekleşmesi için silindi.',
 'selfmove'                => 'Olmasını istediğiniz isim ile mevcut isim aynı. Değişiklik mümkün değil.',
@@ -1750,10 +1742,10 @@
 'show-big-image'       => 'Tam çözünürlük',
 'show-big-image-thumb' => '<small>Ön izleme boyutu: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Yeni resimler',
 'imagelisttext'         => "Aşağıdaki liste '''$2''' göre dizilmiş '''$1''' adet dosyayı göstermektedir.",
-'newimages-summary'     => 'Bu özel sayfa, en son yüklenen dosyaları göstermektedir',
+'newimages-summary'     => 'Bu özel sayfa, en son yüklenen dosyaları göstermektedir.',
 'showhidebots'          => '(botları $1)',
 'noimages'              => 'Görecek bir şey yok.',
 'ilsubmit'              => 'Ara',
@@ -1949,7 +1941,7 @@
 
 # External editor support
 'edit-externally'      => 'Dosya üzerinde bilgisayarınızda bulunan uygulamalar ile değişiklikler yapın',
-'edit-externally-help' => 'Daha fazla bilgi için metadaki [http://meta.wikimedia.org/wiki/Help:External_editors dış uygulama ayarları] (İngilizce) sayfasına bakabilirsiniz.',
+'edit-externally-help' => 'Daha fazla bilgi için metadaki [http://www.mediawiki.org/wiki/Manual:External_editors dış uygulama ayarları] (İngilizce) sayfasına bakabilirsiniz.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'hepsi',
@@ -2004,8 +1996,10 @@
 Sayfayı baştan açmak isityorsanız, lütfen onaylayın.",
 'recreate'            => 'Canlandır',
 
+'unit-pixel' => 'px',
+
 # HTML dump
-'redirectingto' => 'Yönlendirme [[$1]]...',
+'redirectingto' => 'Yönlendirme [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Sayfa önbelleği temizlensin mi? $1',
@@ -2081,7 +2075,7 @@
 'version-software-product'         => 'Ürün',
 'version-software-version'         => 'Versiyon',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Dosyanın konumu',
 'filepath-page'   => 'Dosya adı:',
 'filepath-submit' => 'Konum',
Index: languages/messages/MessagesAf.php
===================================================================
--- languages/messages/MessagesAf.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAf.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,13 @@
  * @ingroup Language
  * @file
  *
+ * @author Adriaan
+ * @author Anrie
+ * @author Arnobarnard
+ * @author Manie
  * @author Naudefj
- * @author Arnobarnard
  * @author SPQRobin
  * @author Spacebirdy
- * @author Adriaan
- * @author Anrie
- * @author Siebrand
- * @author Manie
  */
 
 $skinNames = array(
@@ -388,7 +387,7 @@
 'protectedpagetext'    => 'Hierdie bladsy is beskerm om redigering te verhoed.',
 'viewsourcetext'       => 'U kan die bronteks van hierdie bladsy bekyk en wysig:',
 'protectedinterface'   => 'Hierdie bladsy verskaf teks vir die koppelvlak van die sagteware, en is beskerm om misbruik te voorkom.',
-'editinginterface'     => "'''Waarskuwing:''' U is besig om 'n bladsy te redigeer wat koppelvlakinligting aan die programmatuur voorsien. Wysigings aan hierdie bladsy sal die voorkoms van die gebruikerskoppelvlak vir ander gebruikers beïnvloed. Vir vertalings, overweeg om [http://translatewiki.net/wiki/Main_Page?setlang=af Betawiki] (die vertalingsprojek vir MediaWiki) te gebruik.",
+'editinginterface'     => "'''Waarskuwing:''' U is besig om 'n bladsy te redigeer wat koppelvlakinligting aan die programmatuur voorsien. Wysigings aan hierdie bladsy sal die voorkoms van die gebruikerskoppelvlak vir ander gebruikers beïnvloed. Vir vertalings, oorweeg om eerder [http://translatewiki.net/wiki/Main_Page?setlang=af Betawiki] (die vertalingsprojek vir MediaWiki) te gebruik.",
 'sqlhidden'            => '(SQL navraag versteek)',
 'cascadeprotected'     => 'Hierdie bladsy is beskerm teen redigering omdat dit ingesluit is in die volgende {{PLURAL:$1|bladsy|bladsye}} wat beskerm is met die "kaskade" opsie aangeskakel: $2',
 'namespaceprotected'   => "U het nie toestemming om bladsye in die '''$1'''-naamruimte te wysig nie.",
@@ -419,7 +418,7 @@
 'loginproblem'               => '<b>Daar was probleme met jou intekening.</b><br />Probeer weer.',
 'login'                      => 'Teken in',
 'nav-login-createaccount'    => 'Teken in',
-'loginprompt'                => 'U blaaier moet koekies toelaat om by {{SITENAME}} aan te teken.',
+'loginprompt'                => 'U blaaier moet koekies toelaat om by [[Special:Userlog|{{SITENAME}} te kan aanteken]].',
 'userlogin'                  => 'Teken in',
 'logout'                     => 'Teken uit',
 'userlogout'                 => 'Teken uit',
@@ -564,22 +563,19 @@
 
 * Aanvang van blok: $8
 * Einde van blok: $6
+* Bedoelde blokkeerder: $7
 
 U kan die blok met $1 of enige van die [[{{MediaWiki:Grouppage-sysop}}|administrateurs]] bespreek.
 
-Neem kennis dat u nie die 'e-pos die gebruiker' funksionaliteit kan gebruik nie, tensy u 'n geldige e-posadres het in u [[Special:Preferences|voorkeure]] en die gebruik daarvan nie ook geblokkeer is nie.
+Neem kennis dat u slegs die 'e-pos die gebruiker' funksionaliteit kan gebruik as u 'n geldige e-posadres het in u [[Special:Preferences|voorkeure]] het, en die gebruik daarvan is nie ook geblokkeer is nie.
 
-U blokkadenommer is $5.
+U huidige IP-adres is $3 en die blokkadenommer is #$5.
 Vermeld asseblief die bovermelde bloknommer as u die saak rapporteer,",
 'blockednoreason'                  => 'geen rede gegeef nie',
 'blockedoriginalsource'            => "Die bronteks van '''$1''' word onder gewys:",
 'blockededitsource'                => "Die teks van '''jou wysigings''' aan '''$1''' word hieronder vertoon:",
-'whitelistedittitle'               => 'Inteken benodig om te redigeer',
+'whitelistedittitle'               => 'U moet [[Special:UserLogin|aanteken]] wees om te kan redigeer.',
 'whitelistedittext'                => 'U moet $1 om bladsye te wysig.',
-'whitelistreadtitle'               => 'Inteken benodig om te bekyk',
-'whitelistreadtext'                => 'U moet [[Special:Userlogin|inteken]] om bladsye te lees.',
-'whitelistacctitle'                => "U kan nie 'n rekening te skep nie",
-'whitelistacctext'                 => 'Om toegelaat te word om rekeninge te skep op {{SITENAME}} moet u [[Special:Userlogin|aanteken]] en regte hê om dit te mag doen.',
 'confirmedittitle'                 => 'E-pos-bevestiging nodig om te redigeer',
 'confirmedittext'                  => 'U moet u e-posadres bevestig voor u bladsye wysig. Verstel en bevestig asseblief u e-posadres by u [[Special:Preferences|voorkeure]].',
 'nosuchsectiontitle'               => 'Afdeling bestaan nie',
@@ -595,7 +591,7 @@
 Om 'n nuwe bladsy te skep, tik in die invoerboks hier onder. Lees die [[{{MediaWiki:Helppage}}|hulpbladsy]]
 vir meer inligting.
 Indien jy per ongeluk hier is, gebruik jou blaaier se '''terug''' knoppie.",
-'anontalkpagetext'                 => "----''Hierdie is die besprekingsblad vir 'n anonieme gebruiker wat nog nie 'n rekening geskep het nie of wat dit nie gebruik nie. Daarom moet ons sy/haar numeriese IP-adres gebruik vir identifikasie. Só 'n adres kan deur verskeie gebruikers gedeel word. Indien jy 'n anonieme gebruiker is wat voel dat ontoepaslike kommentaar teen jou gerig is, [[Special:Userlogin|skep 'n rekening of teken in]] om verwarring met ander anonieme gebruikers te voorkom.''",
+'anontalkpagetext'                 => "----''Hierdie is die besprekingsblad vir 'n anonieme gebruiker wat nog nie 'n rekening geskep het nie of wat dit nie gebruik nie. Daarom moet ons sy/haar numeriese IP-adres gebruik vir identifikasie. Só 'n adres kan deur verskeie gebruikers gedeel word. Indien jy 'n anonieme gebruiker is wat voel dat ontoepaslike kommentaar teen jou gerig is, [[Special:UserLogin|skep 'n rekening of teken in]] om verwarring met ander anonieme gebruikers te voorkom.''",
 'noarticletext'                    => 'Daar is tans geen inligting vir hierdie artikel nie. Jy kan [[Special:Search/{{PAGENAME}}|soek vir hierdie bladsytitel]] in ander bladsye of [{{fullurl:{{FULLPAGENAME}}|action=edit}} wysig hierdie bladsy].',
 'userpage-userdoesnotexist'        => 'U is besig om \'n gebruikersblad wat nie bestaan nie te wysig (gebruiker "$1"). Maak asseblief seker of u die bladsy wil skep/ wysig.',
 'clearyourcache'                   => "'''Let wel''': Na die voorkeure gestoor is, moet u blaaier se kasgeheue verfris word om die veranderinge te sien: '''Mozilla:''' klik ''Reload'' (of ''Ctrl-R''), '''IE / Opera:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-R'', '''Konqueror''' ''Ctrl-R''.",
@@ -651,7 +647,7 @@
 'hiddencategories'                 => "Hierdie bladsy is 'n lid van {{PLURAL:$1|1 versteekte kategorie|$1 versteekte kategorië}}:",
 'nocreatetitle'                    => 'Bladsy skepping beperk',
 'nocreatetext'                     => '{{SITENAME}} het die skep van nuwe bladsye beperk.
-U kan slegs bestaande bladsye wysig, of u kan [[Special:Userlogin|aanteken of registreer]].',
+U kan slegs bestaande bladsye wysig, of u kan [[Special:UserLogin|aanteken of registreer]].',
 'nocreate-loggedin'                => 'U het nie regte om nuwe blaaie op {{SITENAME}} te skep nie.',
 'permissionserrors'                => 'Toestemmings Foute',
 'permissionserrorstext'            => 'U het nie toestemming om hierdie te doen nie, om die volgende {{PLURAL:$1|rede|redes}}:',
@@ -820,7 +816,7 @@
 'mypreferences'            => 'My voorkeure',
 'prefs-edits'              => 'Aantal wysigings:',
 'prefsnologin'             => 'Nie ingeteken nie',
-'prefsnologintext'         => 'Jy moet [[Special:Userlogin|ingeteken wees]]
+'prefsnologintext'         => 'Jy moet [[Special:UserLogin|ingeteken wees]]
 om voorkeure te spesifiseer.',
 'prefsreset'               => 'Voorkeure is herstel.',
 'qbsettings'               => 'Snelbalkvoorkeure',
@@ -918,26 +914,30 @@
 'grouppage-bureaucrat'    => '{{ns:project}}:Burokrate',
 
 # Rights
-'right-read'           => 'Lees bladsye',
-'right-edit'           => 'Wysig bladsye',
-'right-createpage'     => 'Skep bladsye (nie besprekingsblaaie nie)',
-'right-createtalk'     => 'Skep besprekingsbladsye',
-'right-createaccount'  => 'Skep nuwe gebruikersrekeninge',
-'right-minoredit'      => "Merk as 'n klein verandering",
-'right-move'           => 'Skuif bladsye',
-'right-upload'         => 'Laai lêers op',
-'right-reupload'       => "Oorskryf 'n bestaande lêer",
-'right-reupload-own'   => "Oorskryf 'n lêer wat u self opgelaai het",
-'right-delete'         => 'Vee bladsye uit',
-'right-bigdelete'      => 'Skrap bladsye met groot geskiedenisse',
-'right-deleterevision' => 'Skrap en ontskrap spesifieke hersienings van bladsye',
-'right-browsearchive'  => 'Soek uigeveede bladsye',
-'right-undelete'       => "Ontskrap 'n bladsy",
-'right-suppressionlog' => 'Besigtig privaat logboeke',
-'right-editinterface'  => 'Wysig die gebruikerskoppelvlak',
-'right-mergehistory'   => 'Versmelt die geskiedenis van bladsye',
-'right-userrights'     => 'Wysig alle gebruiker regte',
-'right-siteadmin'      => 'Sluit en ontsluit die datbasis',
+'right-read'                 => 'Lees bladsye',
+'right-edit'                 => 'Wysig bladsye',
+'right-createpage'           => 'Skep bladsye (nie besprekingsblaaie nie)',
+'right-createtalk'           => 'Skep besprekingsbladsye',
+'right-createaccount'        => 'Skep nuwe gebruikersrekeninge',
+'right-minoredit'            => "Merk as 'n klein verandering",
+'right-move'                 => 'Skuif bladsye',
+'right-upload'               => 'Laai lêers op',
+'right-reupload'             => "Oorskryf 'n bestaande lêer",
+'right-reupload-own'         => "Oorskryf 'n lêer wat u self opgelaai het",
+'right-delete'               => 'Vee bladsye uit',
+'right-bigdelete'            => 'Skrap bladsye met groot geskiedenisse',
+'right-deleterevision'       => 'Skrap en ontskrap spesifieke hersienings van bladsye',
+'right-browsearchive'        => 'Soek uigeveede bladsye',
+'right-undelete'             => "Ontskrap 'n bladsy",
+'right-suppressionlog'       => 'Besigtig privaat logboeke',
+'right-editinterface'        => 'Wysig die gebruikerskoppelvlak',
+'right-import'               => "Importeer bladsye vanaf ander wiki's",
+'right-importupload'         => "Importeer bladsye vanaf 'n lêer",
+'right-patrol'               => 'Merk ander se wysigings as gepatrolleer',
+'right-mergehistory'         => 'Versmelt die geskiedenis van bladsye',
+'right-userrights'           => 'Wysig alle gebruiker regte',
+'right-userrights-interwiki' => 'Wysig gebruikersregte van gebruikers op ander wikis',
+'right-siteadmin'            => 'Sluit en ontsluit die datbasis',
 
 # User rights log
 'rightslog'      => 'Gebruikersregtelogboek',
@@ -986,7 +986,7 @@
 'reupload'                   => 'Herlaai',
 'reuploaddesc'               => 'Keer terug na die laaivorm.',
 'uploadnologin'              => 'Nie ingeteken nie',
-'uploadnologintext'          => 'Teken eers in [[Special:Userlogin|logged in]]
+'uploadnologintext'          => 'Teken eers in [[Special:UserLogin|logged in]]
 om lêers te laai.',
 'upload_directory_missing'   => 'Die oplaaigids ($1) bestaan nie en kon nie deur die webbediener geskep word nie.',
 'upload_directory_read_only' => 'Die webbediener kan nie na die oplaai gids ($1) skryf nie.',
@@ -995,7 +995,7 @@
 [[{{MediaWiki:Copyrightpage}}|beleid oor prentgebruik]].
 
 Om prente wat voorheen gelaai is te sien of te soek, gaan na die
-[[Special:Imagelist|lys van gelaaide prente]].
+[[Special:ImageList|lys van gelaaide prente]].
 Laai van lêers en skrappings word aangeteken in die
 [[Special:Log/upload|laailog]].
 
@@ -1071,7 +1071,7 @@
 'upload_source_url'  => " ('n geldige, publiek toeganklike URL)",
 'upload_source_file' => " ('n lêer op U rekenaar)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Die spesiale bladsy wys al die opgelaaide lêers.
 Die nuutste lêer word eerste vertoon.
 Klik op die opskrifte om die tabel anders te sorteer.',
@@ -1099,7 +1099,7 @@
 'imagelinks'                     => 'Prentskakels',
 'linkstoimage'                   => 'Die volgende {{PLURAL:$1|bladsy|$1 bladsye}} gebruik hierdie prent:',
 'nolinkstoimage'                 => 'Daar is geen bladsye wat hierdie prent gebruik nie.',
-'morelinkstoimage'               => 'Wys [[Special:Whatlinkshere/$1|meer skakels]] na die lêer.',
+'morelinkstoimage'               => 'Wys [[Special:WhatLinksHere/$1|meer skakels]] na die lêer.',
 'redirectstofile'                => "Die volgende {{PLURAL:$1|lêer is 'n aanstuur|$1 lêers is aansture}} na die lêer:",
 'duplicatesoffile'               => "Die volgende {{PLURAL:$1|lêer is 'n duplikaat|$1 lêers is duplikate}} van die lêer:",
 'sharedupload'                   => 'Die lêer word gedeel en mag moontlik op ander projekte gebruik word.',
@@ -1176,7 +1176,7 @@
 Dit werk uit op gemiddeld '''\$5''' veranderings per bladsy, en bladsye word '''\$6''' keer per verandering aangevra.
 
 Die ''[http://www.mediawiki.org/wiki/Manual:Job_queue job queue]''-lengte is '''\$7'''.",
-'userstatstext'          => "Daar is {{PLURAL:$1|'''1''' geregistreerde [[Special:Listusers|gebruiker]]|'''$1''' geregistreerde [[Special:Listusers|gebruikers]]}}, waarvan '''$2''' (of '''$4%''') $5 regte het.",
+'userstatstext'          => "Daar is {{PLURAL:$1|'''1''' geregistreerde [[Special:ListUsers|gebruiker]]|'''$1''' geregistreerde [[Special:ListUsers|gebruikers]]}}, waarvan '''$2''' (of '''$4%''') $5 regte het.",
 'statistics-mostpopular' => 'Mees bekykte bladsye',
 
 'disambiguations'      => 'Bladsye wat onduidelikhede opklaar',
@@ -1185,9 +1185,10 @@
 Die bladsye moet gewysig word om eerder direk na die regte onderwerpe te skakel.<br />
 'n Bladsy word beskou as 'n dubbelsinnigheidsbladsy as dit 'n sjabloon bevat wat geskakel is vanaf [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Dubbele aansture',
-'doubleredirectstext' => '<b>Let op:</b> Hierdie lys bevat moontlik false positiewe. Dit beteken gewoonlik dat daar nog teks met skakels onder die eerste #REDIRECT is.<br />
-Elke ry bevat skakels na die eerste en die tweede aanstuur, asook die eerste reël van van die tweede aanstuurteks, wat gewoonlik die "regte" teikenbladsy gee waarna die eerste aanstuur behoort te wys.',
+'doubleredirects'       => 'Dubbele aansture',
+'doubleredirectstext'   => '<b>Let op:</b> Hierdie lys bevat moontlik vals positiewes. Dit beteken gewoonlik dat daar nog teks met skakels onder die eerste #REDIRECT/#AANSTUUR is.<br />
+Elke ry bevat skakels na die eerste en die tweede aanstuur, asook die eerste reël van van die tweede aanstuur se teks, wat gewoonlik die "regte" teiken bladsy gee waarna die eerste aanstuur behoort te wys.',
+'double-redirect-fixer' => 'Aanstuur hersteller',
 
 'brokenredirects'        => 'Stukkende aansture',
 'brokenredirectstext'    => "Die volgende aansture skakel na 'n bladsy wat nie bestaan nie.",
@@ -1269,7 +1270,7 @@
 'logempty'             => 'Geen inskrywings in die logboek voldoen aan die kriteria.',
 'log-title-wildcard'   => 'Soek bladsye wat met die naam begin',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle bladsye',
 'alphaindexline'    => '$1 tot $2',
 'nextpage'          => 'Volgende blad ($1)',
@@ -1291,12 +1292,12 @@
 'special-categories-sort-count' => 'sorteer volgens getal',
 'special-categories-sort-abc'   => 'sorteer alfabeties',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Wys gebruikers, beginnende by:',
 'listusers-submit'   => 'Wys',
 'listusers-noresult' => 'Geen gebruiker gevind.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Gebruikersgroepregte',
 'listgrouprights-summary'  => "Hier volg 'n lys van gebruikersgroepe wat op die wiki gedefinieer is met hulle geassosieerde regte. Vir meer inligting oor individuele regte, sien [[{{MediaWiki:Listgrouprights-helppage}}]].",
 'listgrouprights-group'    => 'Groep',
@@ -1306,7 +1307,7 @@
 
 # E-mail user
 'mailnologin'     => 'Geen versendadres beskikbaar',
-'mailnologintext' => "U moet [[Special:Userlogin|ingeteken]] wees en 'n geldige e-posadres in die [[Special:Preferences|voorkeure]] hê om e-pos aan ander gebruikers te stuur.",
+'mailnologintext' => "U moet [[Special:UserLogin|ingeteken]] wees en 'n geldige e-posadres in die [[Special:Preferences|voorkeure]] hê om e-pos aan ander gebruikers te stuur.",
 'emailuser'       => 'Stuur e-pos na hierdie gebruiker',
 'emailpage'       => 'Stuur e-pos na gebruiker',
 'emailpagetext'   => 'As dié gerbuiker \'n geldige e-posadres in sy/haar gebruikersvoorkeure het, sal hierdie vorm \'n enkele boodskap stuur. Die e-posadres in jou gebruikersvoorkeure sal verkyn as die "Van"-adres van die pos. Dus sal die ontvanger kan terug antwoord.',
@@ -1330,11 +1331,11 @@
 'watchlistfor'         => "(vir '''$1''')",
 'nowatchlist'          => 'Jy het geen items in jou dophoulys nie.',
 'watchnologin'         => 'Nie ingeteken nie',
-'watchnologintext'     => 'Jy moet [[Special:Userlogin|ingeteken]]
+'watchnologintext'     => 'Jy moet [[Special:UserLogin|ingeteken]]
 wees om jou dophoulys te verander.',
 'addedwatch'           => 'Bygevoeg tot dophoulys',
 'addedwatchtext'       => 'Die bladsy "$1" is by u [[Special:Watchlist|dophoulys]] gevoeg.
-Die bladsy "$1" is by u [[Special:Watchlist|dophoulys]] gevoeg. Toekomstige veranderinge aan hierdie bladsy en sy verwante besprekingsblad sal daar verskyn en die bladsy sal in \'\'\'vetdruk\'\'\' verskyn in die [[Special:Recentchanges|lys van onlangse wysigings]], sodat u dit makliker kan raaksien.
+Die bladsy "$1" is by u [[Special:Watchlist|dophoulys]] gevoeg. Toekomstige veranderinge aan hierdie bladsy en sy verwante besprekingsblad sal daar verskyn en die bladsy sal in \'\'\'vetdruk\'\'\' verskyn in die [[Special:RecentChanges|lys van onlangse wysigings]], sodat u dit makliker kan raaksien.
 
 As u die bladsy later van u dophoulys wil verwyder, kliek "verwyder van dophoulys" in die kieslys bo-aan die bladsy.',
 'removedwatch'         => 'Afgehaal van dophoulys',
@@ -1365,6 +1366,7 @@
 'watching'   => 'Plaas op dophoulys...',
 'unwatching' => 'Verwyder van dophoulys...',
 
+'enotif_mailer'                => '{{SITENAME}} E-pos kennisgewings',
 'enotif_reset'                 => 'Merk alle bladsye as besoek',
 'enotif_newpagetext'           => "Dis 'n nuwe bladsy.",
 'enotif_impersonal_salutation' => '{{SITENAME}} gebruiker',
@@ -1374,7 +1376,29 @@
 'enotif_lastvisited'           => 'Sien $1 vir alle wysigings sedert U laaste besoek.',
 'enotif_lastdiff'              => 'Sien $1 om hierdie wysiging te bekyk.',
 'enotif_anon_editor'           => 'anonieme gebruiker $1',
+'enotif_body'                  => 'Beste $WATCHINGUSERNAME,
 
+Die bladsy $PAGETITLE op {{SITENAME}} is $CHANGEDORCREATED op $PAGEEDITDATE deur $PAGEEDITOR, sien $PAGETITLE_URL vir die nuutste weergawe.
+
+$NEWPAGE
+
+Samevatting van die wysiging: $PAGESUMMARY $PAGEMINOREDIT
+
+Outeur se kontakdetails:
+E-pos: $PAGEEDITOR_EMAIL
+Wiki: $PAGEEDITOR_WIKI
+
+Tensy u hierdie bladsy besoek, sal u geen verdere kennisgewings ontvang nie. U kan ook die waarskuwingsvlag op u dophoulys verstel.
+
+             Groete van die {{SITENAME}} waarskuwingssisteem.
+
+--
+U kan u dophoulys wysig by:
+{{fullurl:Special:Watchlist/edit}}
+
+Terugvoer en verdere bystand:
+{{fullurl:{{MediaWiki:Helppage}}}}',
+
 # Delete/protect/revert
 'deletepage'                  => 'Skrap bladsy',
 'confirm'                     => 'Bevestig',
@@ -1402,6 +1426,9 @@
 ** Op aanvraag van outeur
 ** Skending van kopieregte
 ** Vandalisme',
+'delete-edit-reasonlist'      => 'Wysig skrap redes',
+'delete-toobig'               => "Die bladsy het 'n lang wysigingsgeskiedenis, meer as $1 {{PLURAL:$1|weergawe|weergawes}}.
+Verwydering van die soort blaaie is beperk om ontwrigting van {{SITENAME}} te voorkom.",
 'rollback'                    => 'Rol veranderinge terug',
 'rollback_short'              => 'Rol terug',
 'rollbacklink'                => 'Rol terug',
@@ -1442,6 +1469,7 @@
 'restriction-edit'   => 'Wysig',
 'restriction-move'   => 'Skuif',
 'restriction-create' => 'Skep',
+'restriction-upload' => 'Oplaai',
 
 # Restriction levels
 'restriction-level-sysop'         => 'volledig beveilig',
@@ -1499,18 +1527,23 @@
 'sp-contributions-submit'      => 'Vertoon',
 
 # What links here
-'whatlinkshere'         => 'Skakels hierheen',
-'whatlinkshere-title'   => 'Bladsye die skakel na $1',
-'whatlinkshere-page'    => 'Bladsy:',
-'linklistsub'           => '(Lys van skakels)',
-'linkshere'             => "Die volgende bladsye skakel na '''[[:$1]]''':",
-'nolinkshere'           => "Geen bladsye skakel na '''[[:$1]]'''.",
-'isredirect'            => 'Stuur bladsy aan',
-'istemplate'            => 'insluiting',
-'whatlinkshere-prev'    => '{{PLURAL:$1|vorige|vorige $1}}',
-'whatlinkshere-next'    => '{{PLURAL:$1|volgende|volgende $1}}',
-'whatlinkshere-links'   => '← skakels',
-'whatlinkshere-filters' => 'Filters',
+'whatlinkshere'            => 'Skakels hierheen',
+'whatlinkshere-title'      => 'Bladsye die skakel na $1',
+'whatlinkshere-page'       => 'Bladsy:',
+'linklistsub'              => '(Lys van skakels)',
+'linkshere'                => "Die volgende bladsye skakel na '''[[:$1]]''':",
+'nolinkshere'              => "Geen bladsye skakel na '''[[:$1]]'''.",
+'nolinkshere-ns'           => "Geen bladsye skakel na '''[[:$1]]''' in die verkose naamruimte nie.",
+'isredirect'               => 'Stuur bladsy aan',
+'istemplate'               => 'insluiting',
+'isimage'                  => 'lêerskakel',
+'whatlinkshere-prev'       => '{{PLURAL:$1|vorige|vorige $1}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|volgende|volgende $1}}',
+'whatlinkshere-links'      => '← skakels',
+'whatlinkshere-hideredirs' => '$1 aansture',
+'whatlinkshere-hidelinks'  => '$1 skakels',
+'whatlinkshere-hideimages' => '$1 beeldskakels',
+'whatlinkshere-filters'    => 'Filters',
 
 # Block/unblock
 'blockip'                  => 'Blok gebruiker',
@@ -1531,6 +1564,8 @@
 ** Intimiderende gedrag (teistering)
 ** Misbruik van veelvuldige rekeninge
 ** Onaanvaarbare gebruikersnaam',
+'ipbanononly'              => 'Blokkeer slegs anonieme gebruikers',
+'ipbcreateaccount'         => 'Blokkeer registrasie van gebruikers',
 'ipbemailban'              => 'Verbied gebruiker om e-pos te stuur',
 'ipbsubmit'                => 'Versper hierdie adres',
 'ipbother'                 => 'Ander tydperk:',
@@ -1541,7 +1576,8 @@
 'badipaddress'             => 'Die IP-adres is nie in die regte formaat nie.',
 'blockipsuccesssub'        => 'Blokkering het geslaag',
 'blockipsuccesstext'       => 'Die IP-adres "$1" is geblokkeer.
-<br />Sien die [[Special:Ipblocklist|IP-bloklys]] vir \'n oorsig van blokkerings.',
+<br />Sien die [[Special:IPBlockList|IP-bloklys]] vir \'n oorsig van blokkerings.',
+'ipb-edit-dropdown'        => 'Werk lys van redes by',
 'ipb-unblock-addr'         => 'Deblokkeer $1',
 'ipb-unblock'              => "Deblokkeer 'n gebruiker of IP-adres",
 'ipb-blocklist-addr'       => 'Wys bestaande blokkades vir $1',
@@ -1558,6 +1594,7 @@
 'blocklistline'            => '$1, $2 het $3 geblok ($4)',
 'infiniteblock'            => 'oneindig',
 'expiringblock'            => 'verval op $1',
+'anononlyblock'            => 'anoniem-alleen',
 'createaccountblock'       => 'skep van gebruikersrekeninge is geblokkeer',
 'emailblock'               => 'e-pos versper',
 'ipblocklist-empty'        => 'Die blokkeerlys is leeg.',
@@ -1568,10 +1605,11 @@
 'blocklogpage'             => 'Blokkeerlogboek',
 'blocklogentry'            => '"[[$1]]" is vir \'n periode van $2 $3 geblok',
 'blocklogtext'             => "Hier is 'n lys van onlangse blokkeer en deblokkeer aksies. Outomaties geblokkeerde IP-adresse word nie vertoon nie. 
-Sien die [[Special:Ipblocklist|IP-bloklys]] vir geblokkeerde adresse.",
+Sien die [[Special:IPBlockList|IP-bloklys]] vir geblokkeerde adresse.",
 'unblocklogentry'          => 'blokkade van $1 is opgehef:',
 'block-log-flags-anononly' => 'anonieme gebruikers alleenlik',
 'block-log-flags-noemail'  => 'e-pos versper',
+'ipb_expiry_invalid'       => 'Ongeldige duur.',
 'ipb_already_blocked'      => '"$1" is reeds geblok',
 'ip_range_invalid'         => 'Ongeldige IP waardegebied.',
 'blockme'                  => 'Versper my',
@@ -1616,9 +1654,6 @@
 
 Indien wel sal u self die blad moet skuif of versmelt (indien nodig).",
 'movearticle'             => 'Skuif bladsy',
-'movenologin'             => 'Nie ingeteken nie',
-'movenologintext'         => "Jy moet 'n geregistreerde gebruiker wees en [[Special:Userlogin|ingeteken]]
-wees om 'n bladsy te skuif.",
 'movenotallowed'          => 'U het nie regte om bladsye op {{SITENAME}} te skuif nie.',
 'newtitle'                => 'Na nuwe titel',
 'move-watch'              => 'Hou hierdie bladsy dop',
@@ -1645,11 +1680,12 @@
 'delete_and_move'         => 'Skrap en skuif',
 'delete_and_move_text'    => '==Skrapping benodig==
 
-Die teikenartikel "[[$1]]" bestaan reeds. Wil u dit skrap om plek te maak vir die skuif?',
+Die teikenartikel "[[:$1]]" bestaan reeds. Wil u dit skrap om plek te maak vir die skuif?',
 'delete_and_move_confirm' => 'Ja, skrap die bladsy',
 'delete_and_move_reason'  => 'Geskrap om plek te maak vir skuif',
 'selfmove'                => 'Bron- en teikentitels is dieselfde; kan nie bladsy oor homself skuif nie.',
 'imageinvalidfilename'    => 'Die nuwe lêernaam is ongeldig',
+'fix-double-redirects'    => 'Opdateer alle aansture wat na die oorspronklike titel wys',
 
 # Export
 'export'            => 'Eksporteer bladsye',
@@ -1829,10 +1865,10 @@
 'show-big-image'       => 'Volle resolusie',
 'show-big-image-thumb' => '<small>Grootte van hierdie voorskou: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Gallery van nuwe beelde',
 'imagelisttext'         => "Hieronder is a lys van '''$1''' {{PLURAL:$1|lêer|lêers}}, $2 gesorteer.",
-'newimages-summary'     => 'Die spesiale bladsy wys die nuutste lêers wat na die wiki opgelaai is',
+'newimages-summary'     => 'Die spesiale bladsy wys die nuutste lêers wat na die wiki opgelaai is.',
 'showhidebots'          => '($1 robotte)',
 'noimages'              => 'Niks te sien nie.',
 'ilsubmit'              => 'Soek',
@@ -1865,8 +1901,11 @@
 'exif-imagewidth'          => 'Wydte',
 'exif-imagelength'         => 'Hoogte',
 'exif-orientation'         => 'Oriëntasie',
+'exif-samplesperpixel'     => 'Aantal komponente',
+'exif-ycbcrpositioning'    => 'Y- en C-posisionering',
 'exif-xresolution'         => 'Horisontale resolusie',
 'exif-yresolution'         => 'Vertikale resolusie',
+'exif-resolutionunit'      => 'Eenheid X en Y resolusie',
 'exif-imagedescription'    => 'Beeldtitel',
 'exif-make'                => 'Kamera vervaardiger:',
 'exif-model'               => 'Kamera model',
@@ -1888,7 +1927,10 @@
 'exif-flashenergy'         => 'Flitssterkte',
 'exif-exposureindex'       => 'Beligtingsindeks',
 'exif-filesource'          => 'Lêerbron',
+'exif-scenetype'           => 'Soort toneel',
 'exif-whitebalance'        => 'Witbalans',
+'exif-scenecapturetype'    => 'Soort opname',
+'exif-gaincontrol'         => 'Toneelbeheer',
 'exif-contrast'            => 'Kontras',
 'exif-saturation'          => 'Versadiging',
 'exif-sharpness'           => 'Skerpte',
@@ -1968,6 +2010,7 @@
 'exif-scenecapturetype-0' => 'Standaard',
 'exif-scenecapturetype-1' => 'Landskap',
 'exif-scenecapturetype-2' => 'Portret',
+'exif-scenecapturetype-3' => 'Nagtoneel',
 
 'exif-gaincontrol-0' => 'Geen',
 
@@ -2011,7 +2054,7 @@
 
 # External editor support
 'edit-externally'      => "Wysig hierdie lêer met 'n eksterne program",
-'edit-externally-help' => 'Sien die [http://meta.wikimedia.org/wiki/Help:External_editors instruksies] (in Engels) vir meer inligting.',
+'edit-externally-help' => 'Sien die [http://www.mediawiki.org/wiki/Manual:External_editors instruksies] (in Engels) vir meer inligting.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alles',
@@ -2061,7 +2104,7 @@
 'recreate'            => 'Herskep',
 
 # HTML dump
-'redirectingto' => 'Stuur aan na [[$1]]...',
+'redirectingto' => 'Stuur aan na [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Verwyder die kas van hierdie blad?
@@ -2112,7 +2155,7 @@
 Probeer normale voorskou.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Veranderinge nuwer as $1 sekondes mag moontlik nie gewys word nie.',
+'lag-warn-normal' => 'Veranderinge nuwer as $1 {{PLURAL:$1|sekonde|sekondes}} mag moontlik nie gewys word nie.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'U dophoulys bevat {{PLURAL:$1|1 bladsy|$1 bladsye}}, besprekingsbladsye uitgesluit.',
@@ -2164,7 +2207,7 @@
 'version-software-product'      => 'Produk',
 'version-software-version'      => 'Weergawe',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Lêerpad',
 'filepath-page'    => 'Lêer:',
 'filepath-submit'  => 'Pad',
@@ -2200,7 +2243,7 @@
 'specialpages-group-redirects'   => 'Aanstuur gewone bladsye',
 'specialpages-group-spam'        => 'Spam-hulpmiddels',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Leë bladsy',
 'intentionallyblankpage' => 'Die bladsy is bewustelik leeg gelaat',
 
Index: languages/messages/MessagesEe.php
===================================================================
--- languages/messages/MessagesEe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,37 @@
  * @ingroup Language
  * @file
  *
- * @author M.M.S.
+ * @author Cbrown1023
  * @author Natsubee
- * @author Cbrown1023
  */
 
 $messages = array(
+# User preference toggles
+'tog-hideminor'            => 'Ɣla tɔtrɔ suewo le tɔtrɔ yeyeawo me',
+'tog-watchcreations'       => 'Tsɔ axa siwo gɔme medze la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
+'tog-watchdefault'         => 'Tsɔ axa siwo ŋu metrɔ asi le la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
+'tog-watchmoves'           => 'Tsɔ axa siwo ƒe nɔƒe meɖɔli la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
+'tog-watchdeletion'        => 'Tsɔ axa siwo metutu la kpe ɖe axa siwo ŋu nyeƒe ŋku le la ŋu',
+'tog-enotifwatchlistpages' => 'Ɖo du nam ne axa aɖe si ŋu nyeƒe ŋku le la trɔ',
+
+'underline-always' => 'Ɣesiaɣi',
+'underline-never'  => 'Gbeɖe',
+
 # Dates
+'sunday'        => 'Kɔsiɖagbe',
+'monday'        => 'Dzoɖagbe',
+'tuesday'       => 'Brãɖagbe',
+'wednesday'     => 'Kuɖagbe',
+'thursday'      => 'Yawoɖagbe',
+'friday'        => 'Fiɖagbe',
+'saturday'      => 'Memleɖagbe',
+'sun'           => 'Dzo',
+'mon'           => 'Dzo',
+'tue'           => 'Brã',
+'wed'           => 'Kuɖ',
+'thu'           => 'Yaw',
+'fri'           => 'Fiɖ',
+'sat'           => 'Mem',
 'january'       => 'Dzove',
 'february'      => 'Dzodze',
 'march'         => 'Tedoxe',
@@ -52,12 +76,15 @@
 'newwindow'      => '(eʋua fesre yeye)',
 'cancel'         => 'Dzudzɔ etɔtrɔ',
 'qbedit'         => 'Trɔ asi le eŋu',
+'qbpageoptions'  => 'Axa sia',
 'qbmyoptions'    => 'Nyeƒe axawo',
 'qbspecialpages' => 'Axa tɔxewo',
+'mypage'         => 'Axa nye',
 'navigation'     => 'Mɔtabiala',
 'and'            => 'kpakple',
 
 'errorpagetitle'   => 'Vodada',
+'returnto'         => 'Gbugbɔ yi $1.',
 'help'             => 'Kpekpeɖeŋu',
 'search'           => 'Dii',
 'searchbutton'     => 'Dii',
@@ -66,7 +93,9 @@
 'history_short'    => 'Xoxoawo',
 'edit'             => 'Trɔ asi le eŋu',
 'delete'           => 'Tutui',
+'newpage'          => 'Axa yeye',
 'talkpagelinktext' => 'Nyamedzroƒe',
+'specialpage'      => 'Axa Tɔxe',
 'talk'             => 'Nyamedzroƒe',
 'toolbox'          => 'Dɔwɔnuɖaka',
 'otherlanguages'   => 'Le gbe bubuwo me',
@@ -82,9 +111,10 @@
 'portal'            => 'Takpekpewɔƒe',
 'portal-url'        => 'Project:Takpekpewɔƒe',
 
-'newmessageslink' => 'du yeyewo',
-'editsection'     => 'trɔ asi le eŋu',
-'editold'         => 'trɔ asi le eŋu',
+'newmessageslink'         => 'du yeyewo',
+'youhavenewmessagesmulti' => 'Du yeyewo le asiwo le $1',
+'editsection'             => 'trɔ asi le eŋu',
+'editold'                 => 'trɔ asi le eŋu',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Axa',
@@ -151,7 +181,7 @@
 # Special:Log
 'specialloguserlabel' => 'Ezãla:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Axawo katã',
 'allpagessubmit' => 'Yi',
 
@@ -187,7 +217,7 @@
 'tooltip-t-specialpages'  => 'Axa tɔxewo ƒe xexlẽme',
 'tooltip-minoredit'       => 'Esia nye tɔtrɔ sue aɖe ko',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Nutata yeyewo',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesZh_hans.php
===================================================================
--- languages/messages/MessagesZh_hans.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh_hans.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,5 +1,5 @@
 <?php
-/** Chinese (Simplified) (‪中文 (简化字)‬)
+/** Simplified Chinese (‪中文(简体)‬)
  *
  * @ingroup Language
  * @file
@@ -360,7 +360,7 @@
 'nosuchspecialpage' => '此特殊页面不存在',
 'nospecialpagetext' => "<big>'''您请求的特殊页面无效。'''</big>
 
-[[Special:Specialpages|{{int:specialpages}}]]中载有所有有效特殊页面的列表。",
+[[Special:SpecialPages|{{int:specialpages}}]]中载有所有有效特殊页面的列表。",
 
 # General errors
 'error'                => '错误',
@@ -391,7 +391,7 @@
 通常这是由于修订历史页上过时的链接到已经被删除的页面所导致的。
 
 如果情况不是这样，您可能找到了软件内的一个错误。
-请记录下 URL 地址，并向管理员报告。',
+请记录下 URL 地址，并向[[Special:ListUsers/sysop|管理员]]报告。',
 'missingarticle-rev'   => '(修订#: $1)',
 'missingarticle-diff'  => '(差异: $1, $2)',
 'readonly_lag'         => '附属数据库服务器正在将缓存更新到主服务器，数据库已被自动锁定',
@@ -440,11 +440,11 @@
 # Login and logout pages
 'logouttitle'                => '退出',
 'logouttext'                 => '<strong>您现在已经退出。</strong><br />
-您可以继续以匿名方式使用{{SITENAME}}，或再次以相同或不同用户身份登录。
+您可以继续以匿名方式使用{{SITENAME}}，或再次以相同或不同用户身份[[Special:UserLogin|登录]]。
 请注意一些页面可能仍然显示您为登录状态，直到您清空您的浏览器缓存为止。',
 'welcomecreation'            => '== 欢迎, $1! ==
 
- 您的账户已经建立，不要忘记设置{{SITENAME}}的个人参数。',
+ 您的账户已经建立，不要忘记设置[[Special:Preferences|{{SITENAME}}的个人参数]]。',
 'loginpagetitle'             => '用户登录',
 'yourname'                   => '用户名:',
 'yourpassword'               => '密码:',
@@ -579,7 +579,7 @@
 你可以联络$1或者其他的[[{{MediaWiki:Grouppage-sysop}}|管理员]]，讨论这次查封。
 除非你已经在你的[[Special:Preferences|帐号参数设置]]中设置了一个有效的电子邮件地址，否则你是不能使用「电邮这位用户」的功能。当设置定了一个有效的电子邮件地址后，这个功能是不会封锁的。
 
-你的IP地址是$3，而该查封ID是 #$5。 请你在所有查询中注明这地址及／或查封ID。",
+你的IP地址是$3，而该查封ID是 #$5。 请在你的查询中注明以上所有的资料。",
 'autoblockedtext'                  => "你的IP地址已经被自动查封，由于先前的另一位用户被$1所查封。
 而查封的原因是：
 
@@ -587,21 +587,18 @@
 
 * 这次查封的开始时间是：$8
 * 这次查封的到期时间是：$6
+* 对于被查封者：$7
 
 你可以联络$1或者其他的[[{{MediaWiki:Grouppage-sysop}}|管理员]]，讨论这次查封。
 
 除非你已经在你的[[Special:Preferences|帐号参数设置]]中设置了一个有效的电子邮件地址，否则你是不能使用「电邮这位用户」的功能。当设置定了一个有效的电子邮件地址后，这个功能是不会封锁的。
 
-您的查封ID是 #$5。 请你在所有查询中注明这个查封ID。",
+您现时正在使用的 IP 地址是 $3，查封ID是 #$5。 請在你的查詢中註明以上所有的資料。",
 'blockednoreason'                  => '无给出原因',
 'blockedoriginalsource'            => "以下是'''$1'''的源码:",
 'blockededitsource'                => "你对'''$1'''进行'''编辑'''的文字如下:",
 'whitelistedittitle'               => '登录后才可编辑',
 'whitelistedittext'                => '您必须先$1才可编辑页面。',
-'whitelistreadtitle'               => '登录后才可阅读',
-'whitelistreadtext'                => '您必须先[[Special:Userlogin|登录]]才可阅读页面。',
-'whitelistacctitle'                => '您被禁止建立账户',
-'whitelistacctext'                 => '在{{SITENAME}}中建立账户您必须先[[Special:Userlogin|登录]]并拥有相关权限。',
 'confirmedittitle'                 => '邮件确认后才可编辑',
 'confirmedittext'                  => '在编辑此页之前您必须确认您的邮箱地址。请通过[[Special:Preferences|参数设置]]设置并验证您的邮箱地址。',
 'nosuchsectiontitle'               => '没有这个段落',
@@ -615,7 +612,7 @@
 'newarticletext'                   => '您进入了一个尚未创建的页面。
 要创建该页面，请在下面的编辑框中输入内容(详情参见[[Help:帮助|帮助]])。
 如果您是不小心来到此页面，直接点击您浏览器中的"返回"按钮返回。',
-'anontalkpagetext'                 => "---- ''这是一个还未建立账户的匿名用户的讨论页, 因此我们只能用IP地址来与他或她联络。该IP地址可能由几名用户共享。如果您是一名匿名用户并认为此页上的评语与您无关，请[[Special:Userlogin|创建新账户或登录]]以避免在未来与其他匿名用户混淆。''",
+'anontalkpagetext'                 => "---- ''这是一个还未建立账户的匿名用户的讨论页, 因此我们只能用IP地址来与他或她联络。该IP地址可能由几名用户共享。如果您是一名匿名用户并认为此页上的评语与您无关，请[[Special:UserLogin/signup|创建新账户]]或[[Special:UserLogin|登录]]以避免在未来与其他匿名用户混淆。''",
 'noarticletext'                    => '此页目前没有内容，您可以在其它页[[Special:Search/{{PAGENAME}}|搜索此页标题]]或[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} 编辑此页]。',
 'userpage-userdoesnotexist'        => '用户账户“$1”未曾创建。请在创建／编辑这个页面前先检查一下。',
 'clearyourcache'                   => "'''注意 - 在保存以後, 您必須清除瀏覽器的緩存才能看到所作出的改變。''' '''Mozilla / Firefox / Safari:''' 按著 ''Shift'' 再點擊''刷新''，或按下''Ctrl-F5''或''Ctrl-R''，(在Macintosh上按下''Command-R'')；'''Konqueror:''' 只需點擊 ''刷新''或按下''F5''；'''Opera:''' 在 ''工具→設定'' 中完整地清除它們的緩存；'''Internet Explorer:''' 按著 ''Ctrl'' 再點擊 ''刷新''，或按下 ''Ctrl-F5''。",
@@ -627,12 +624,12 @@
 'note'                             => '<strong>注意:</strong>',
 'previewnote'                      => '<strong>请记住这只是预览，内容还未保存！</strong>',
 'previewconflict'                  => '这个预览显示了上面文字编辑区中的内容。它将在你选择保存后出现。',
-'session_fail_preview'             => '<strong>抱歉! 我们不能处理你在进程数据丢失时的编辑。请重试！如果再次失败，请登出后重新登陆。</strong>',
+'session_fail_preview'             => '<strong>抱歉! 我们不能处理你在进程数据丢失时的编辑。请重试！如果再次失败，请[[Special:UserLogout|登出]]后重新登陆。</strong>',
 'session_fail_preview_html'        => "<strong>抱歉! 我们不能处理你在进程数据丢失时的编辑。</strong>
 
 ''由于{{SITENAME}}允许使用原始的 HTML，为了防范 JavaScript 攻击，预览已被隐藏。''
 
-<strong>如果这是一次合法的编辑，请重新进行尝试。如果还不行，请退出并重新登录。</strong>",
+<strong>如果这是一次合法的编辑，请重新进行尝试。如果还不行，请[[Special:UserLogout|退出]]并重新登录。</strong>",
 'token_suffix_mismatch'            => '<strong>由于您用户端中的编辑令牌毁损了一些标点符号字元，为防止编辑的文字损坏，您的编辑已经被拒绝。
 这种情况通常出现于使用含有很多臭虫、以网络为主的匿名代理服务的时候。</strong>',
 'editing'                          => '正在编辑$1',
@@ -675,7 +672,7 @@
 'hiddencategories'                 => '这个页面是属于$1个隐藏分类的成员:',
 'edittools'                        => '<!-- 此处的文本将被显示在以下编辑和上传表单中。 -->',
 'nocreatetitle'                    => '创建页面受限',
-'nocreatetext'                     => '{{SITENAME}}限制了创建新页面的功能。你可以返回并编辑已有的页面，或者[[Special:Userlogin|登录或创建新账户]]。',
+'nocreatetext'                     => '{{SITENAME}}限制了创建新页面的功能。你可以返回并编辑已有的页面，或者[[Special:UserLogin|登录或创建新账户]]。',
 'nocreate-loggedin'                => '您在{{SITENAME}}中并无权限去创建新页面。',
 'permissionserrors'                => '权限错误',
 'permissionserrorstext'            => '根据以下的{{PLURAL:$1|原因|原因}}，您并无权限去做以下的动作:',
@@ -792,7 +789,7 @@
 # Suppression log
 'suppressionlog'     => '废止日志',
 'suppressionlogtext' => '以下是删除以及由操作员牵涉到内容封锁的列表。
-参看[[Special:Ipblocklist|IP封锁名单]]去参看现时进行中的禁止以及封锁之名单。',
+参看[[Special:IPBlockList|IP封锁名单]]去参看现时进行中的禁止以及封锁之名单。',
 
 # History merging
 'mergehistory'                     => '合并页面历史',
@@ -832,7 +829,7 @@
 # Search results
 'searchresults'             => '搜索结果',
 'searchresulttext'          => '有关搜索{{SITENAME}}的更多详情,参见[[{{MediaWiki:Helppage}}|{{int:help}}]]。',
-'searchsubtitle'            => "搜索'''[[:$1]]'''",
+'searchsubtitle'            => '搜索\'\'\'[[:$1]]\'\'\'([[Special:Prefixindex/$1|所有以 "$1" 开头的页面]] | [[Special:WhatLinksHere/$1|所有链接到 "$1" 的页面]])',
 'searchsubtitleinvalid'     => "搜索'''$1'''",
 'noexactmatch'              => "'''没找到标题为\"\$1\"的页面。''' 您可以[[:\$1|创建此页面]]。",
 'noexactmatch-nocreate'     => "'''没找到标题为\"\$1\"的页面。'''",
@@ -875,7 +872,7 @@
 'mypreferences'            => '我的参数设置',
 'prefs-edits'              => '编辑数量:',
 'prefsnologin'             => '尚未登录',
-'prefsnologintext'         => '您必须先[[Special:Userlogin|登录]]才能设置个人参数。',
+'prefsnologintext'         => '您必须先[[Special:UserLogin|登录]]才能设置个人参数。',
 'prefsreset'               => '参数已被重新设置。',
 'qbsettings'               => '快速导航条',
 'qbsettings-none'          => '无',
@@ -949,7 +946,7 @@
 'userrights-reason'           => '更改原因:',
 'userrights-no-interwiki'     => '您并没有权限去编辑在其它wiki上的用户权限。',
 'userrights-nodatabase'       => '数据库$1不存在或并非为本地的。',
-'userrights-nologin'          => '您必须要以操作员帐户[[Special:Userlogin|登入]]之后才可以指定用户权限。',
+'userrights-nologin'          => '您必须要以操作员帐户[[Special:UserLogin|登入]]之后才可以指定用户权限。',
 'userrights-notallowed'       => '您的帐户无权限去指定用户权限。',
 'userrights-changeable-col'   => '您可以更改的组群',
 'userrights-unchangeable-col' => '您不可以更改的组群',
@@ -1079,14 +1076,15 @@
 'reupload'                    => '重新上传',
 'reuploaddesc'                => '取消上传并返回上传表单',
 'uploadnologin'               => '未登录',
-'uploadnologintext'           => '您必须先[[Special:Userlogin|登录]]才能上传文件。',
+'uploadnologintext'           => '您必须先[[Special:UserLogin|登录]]才能上传文件。',
 'upload_directory_missing'    => '上传目录($1)遗失，不能由网页服务器建立。',
 'upload_directory_read_only'  => '上传目录($1)不存在或无写权限。',
 'uploaderror'                 => '上载错误',
 'uploadtext'                  => "使用下面的表单来上传用在页面内新的文件。
 要查看或搜索以前上传的文件
-可以进入[[Special:Imagelist|文件上传列表]]，
-上传和删除将在[[Special:Log/upload|上传日志]]中记录。
+可以进入[[Special:ImageList|文件上传列表]]，
+（重新）上传将在[[Special:Log/upload|上传日志]]中记录，
+而删除将在[[Special:Log/delete|删除日志]]中记录。
 
 要在页面中加入文件，使用以下形式的连接:
 '''<nowiki>[[</nowiki>{{ns:image}}</nowiki>:file.jpg]]</nowiki>'''，
@@ -1097,7 +1095,8 @@
 'upload-prohibited'           => '禁止的文件类型: $1。',
 'uploadlog'                   => '上传日志',
 'uploadlogpage'               => '上传日志',
-'uploadlogpagetext'           => '以下是一个最近上传文件的列表。',
+'uploadlogpagetext'           => '以下是一个最近上传文件的列表。
+查看[[Special:NewImages|新文件画廊]]去看更富图像的总览。',
 'filename'                    => '文件名',
 'filedesc'                    => '文件描述',
 'fileuploadsummary'           => '文件描述:',
@@ -1156,9 +1155,9 @@
 'upload-proto-error'      => '协议错误',
 'upload-proto-error-text' => '远程上传要求 URL 以 <code>http://</code> 或 <code>ftp://</code> 开头。',
 'upload-file-error'       => '内部错误',
-'upload-file-error-text'  => '当试图在服务器上创建临时文件时发生内部错误。请与系统管理员联系。',
+'upload-file-error-text'  => '当试图在服务器上创建临时文件时发生内部错误。请与[[Special:ListUsers/sysop|管理员]]联系。',
 'upload-misc-error'       => '未知的上传错误',
-'upload-misc-error-text'  => '在上传时发生未知的错误. 请验证使用了正确并可访问的 URL，然后进行重试。如果问题仍然存在，请与系统管理员联系。',
+'upload-misc-error-text'  => '在上传时发生未知的错误. 请验证使用了正确并可访问的 URL，然后进行重试。如果问题仍然存在，请与[[Speical:ListUsers/sysop|管理员]]联系。',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => '无法访问 URL',
@@ -1172,7 +1171,7 @@
 'upload_source_url'  => ' (一个有效的，可公开访问的 URL)',
 'upload_source_file' => ' (在您计算机上的一个文件)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => '这个特殊页面显示所有上传过的文件。
 预设中最后上传的文件会显示在这个列表中的最顶处。
 点击一栏的标题去改变这个排列。',
@@ -1200,7 +1199,7 @@
 'imagelinks'                     => '链接',
 'linkstoimage'                   => '以下的$1个页面链接到本文件:',
 'nolinkstoimage'                 => '没有页面链接到本文件。',
-'morelinkstoimage'               => '查看连接到这个文件的[[Special:Whatlinkshere/$1|更多连结]]。',
+'morelinkstoimage'               => '查看连接到这个文件的[[Special:WhatLinksHere/$1|更多连结]]。',
 'redirectstofile'                => '以下的$1个文件重新定向到这个文件:',
 'duplicatesoffile'               => '以下的$1个文件是跟这个文件重覆:',
 'sharedupload'                   => '该文件是一个共享上传，它可能在其它项目中被应用。',
@@ -1219,22 +1218,22 @@
 # File reversion
 'filerevert'                => '恢复$1',
 'filerevert-legend'         => '恢复文件',
-'filerevert-intro'          => '<span class="plainlinks">您现正在恢复\'\'\'[[Media:$1|$1]]\'\'\'到[$4 于$2 $3的版本]。</span>',
+'filerevert-intro'          => "您现正在恢复'''[[Media:$1|$1]]'''到[$4 于$2 $3的版本]。",
 'filerevert-comment'        => '注解:',
 'filerevert-defaultcomment' => '已经恢复到于$1 $2的版本',
 'filerevert-submit'         => '恢复',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'已经恢复到[$4 于$2 $3的版本]。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''已经恢复到[$4 于$2 $3的版本]。",
 'filerevert-badversion'     => '这个文件所提供的时间截记并无先前的本地版本。',
 
 # File deletion
 'filedelete'                  => '删除$1',
 'filedelete-legend'           => '删除文件',
 'filedelete-intro'            => "您现正删除'''[[Media:$1|$1]]'''。",
-'filedelete-intro-old'        => '<span class="plainlinks">你现正删除\'\'\'[[Media:$1|$1]]\'\'\'于[$4 $2 $3]的版本。</span>',
+'filedelete-intro-old'        => "你现正删除'''[[Media:$1|$1]]'''于[$4 $2 $3]的版本。",
 'filedelete-comment'          => '删除理由:',
 'filedelete-submit'           => '删除',
 'filedelete-success'          => "'''$1'''已经删除。",
-'filedelete-success-old'      => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'于 $2 $3 的版本已经删除。</span>',
+'filedelete-success-old'      => "'''[[Media:$1|$1]]'''于 $2 $3 的版本已经删除。",
 'filedelete-nofile'           => "'''$1'''在{{SITENAME}}中不存在。",
 'filedelete-nofile-old'       => "在已指定属性的情况下，这里没有'''$1'''于 $2 $3 的版本。",
 'filedelete-iscurrent'        => '您现正尝试删除这个文件的最近版本。请先将个该文件回退成较旧的版本。',
@@ -1285,7 +1284,7 @@
 即每页平均编辑'''\$5'''次，各次编辑后页面的每个版本平均浏览'''\$6'''次。
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue 工作排队]的长度是'''\$7'''。",
-'userstatstext'          => "网站有'''$1'''位注册[[Special:Listusers|用户]]，其中
+'userstatstext'          => "网站有'''$1'''位注册[[Special:ListUsers|用户]]，其中
 '''$2''' (或 '''$4%''') 有$5权限。",
 'statistics-mostpopular' => '浏览最多的页面',
 
@@ -1299,16 +1298,18 @@
 Template:消除歧義',
 'disambiguations-text' => '以下的页面都有到<b>消含糊页</b>的链接, 但它们应该是链到适当的标题。<br />一个页面会被视为消含糊页如果它是链自[[MediaWiki:Disambiguationspage]]。',
 
-'doubleredirects'     => '双重重定向页面',
-'doubleredirectstext' => '这一页列出所有重定向页面重定向到另一个重定向页的页面。每一行都包含到第一和第二个重定向页面的链接，以及第二个重定向页面的目标，通常显示的都会是"真正"的目标页面，也就是第一个重定向页面应该指向的页面。',
+'doubleredirects'            => '双重重定向页面',
+'doubleredirectstext'        => '这一页列出所有重定向页面重定向到另一个重定向页的页面。每一行都包含到第一和第二个重定向页面的链接，以及第二个重定向页面的目标，通常显示的都会是"真正"的目标页面，也就是第一个重定向页面应该指向的页面。',
+'double-redirect-fixed-move' => '[[$1]]已经完成移动，它现在重定向到[[$2]]',
+'double-redirect-fixer'      => '重定向修正器',
 
 'brokenredirects'        => '损坏的重定向页',
-'brokenredirectstext'    => '以下的重定向页面指向的是不存在的页面:',
+'brokenredirectstext'    => '以下的重定向页面指向的是不存在的页面。',
 'brokenredirects-edit'   => '(编辑)',
 'brokenredirects-delete' => '(删除)',
 
 'withoutinterwiki'         => '未有语言链接的页面',
-'withoutinterwiki-summary' => '以下的页面是未有语言链接到其它语言版本:',
+'withoutinterwiki-summary' => '以下的页面是未有语言链接到其它语言版本。',
 'withoutinterwiki-legend'  => '前缀',
 'withoutinterwiki-submit'  => '显示',
 
@@ -1386,7 +1387,7 @@
 'logempty'             => '在日志中不存在匹配项。',
 'log-title-wildcard'   => '搜寻以这个文字开始的标题',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '所有页面',
 'alphaindexline'    => '$1到$2',
 'nextpage'          => '下一页($1)',
@@ -1409,12 +1410,12 @@
 'special-categories-sort-count' => '按数量排列',
 'special-categories-sort-abc'   => '按字母排列',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '给定显示用户条件:',
 'listusers-submit'   => '显示',
 'listusers-noresult' => '找不到用户。',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => '用户群组权限',
 'listgrouprights-summary'  => '以下面是一个在这个wiki中定义出来的用户权限列表，以及它们的访问权。
 更多有关个别权限的细节可以在[[{{MediaWiki:Listgrouprights-helppage}}|这里]]找到。',
@@ -1425,12 +1426,12 @@
 
 # E-mail user
 'mailnologin'     => '无电邮地址',
-'mailnologintext' => '您必须先[[Special:Userlogin|登录]]
+'mailnologintext' => '您必须先[[Special:UserLogin|登录]]
 并在[[Special:Preferences|参数设置]]
 中有一个有效的电子邮箱地址才可以向其他用户发邮件。',
 'emailuser'       => '向该用户发邮件',
 'emailpage'       => '向用户发邮件',
-'emailpagetext'   => '如果该用户已经在他或她的参数设置页中输入了有效的电子邮箱地址，以下的表单将寄一个信息给该用户。您在您参数设置中所输入的电子邮箱地址将出现在邮件"发件人"一栏中，这样该用户就可以回复您。',
+'emailpagetext'   => '如果该用户已经在他或她的参数设置页中输入了有效的电子邮箱地址，以下的表单将寄一个信息给该用户。您在[[Special:Preferences|您参数设置]]中所输入的电子邮箱地址将出现在邮件"发件人"一栏中，这样该用户就可以回复您。',
 'usermailererror' => 'Mail 对象返回错误:',
 'defemailsubject' => '{{SITENAME}}电子邮件',
 'noemailtitle'    => '无电子邮件地址',
@@ -1454,14 +1455,14 @@
 'nowatchlist'          => '您的监视列表为空。',
 'watchlistanontext'    => '请$1以查看或编辑您的监视列表。',
 'watchnologin'         => '未登录',
-'watchnologintext'     => '您必须先[[Special:Userlogin|登录]]才能更改您的监视列表。',
+'watchnologintext'     => '您必须先[[Special:UserLogin|登录]]才能更改您的监视列表。',
 'addedwatch'           => '已添加至监视列表',
 'addedwatchtext'       => "页面\"[[:\$1]]\"已经被加入到您的[[Special:Watchlist|监视列表]]中。
 将来有关此页面及其讨论页的任何修改将会在那里列出，
-而且还会在[[Special:Recentchanges|最近更改]]中
+而且还会在[[Special:RecentChanges|最近更改]]中
 以'''粗体'''形式列出以使起更容易识别。",
 'removedwatch'         => '已停止监视',
-'removedwatchtext'     => '页面"<nowiki>$1</nowiki>"已经从您的监视页面中移除。',
+'removedwatchtext'     => '页面"<nowiki>$1</nowiki>"已经从[[Special:Watchlist|您的监视页面]]中移除。',
 'watch'                => '监视',
 'watchthispage'        => '监视此页',
 'unwatch'              => '取消监视',
@@ -1560,16 +1561,16 @@
 'rollbacklink'                => '恢复',
 'rollbackfailed'              => '恢复失败',
 'cantrollback'                => '无法恢复编辑；最后的贡献者是本文的唯一作者。',
-'alreadyrolled'               => '无法恢复由[[User:$2|$2]] ([[User talk:$2|讨论]])进行的[[$1]]的最后编辑；
+'alreadyrolled'               => '无法恢复由[[User:$2|$2]] ([[User talk:$2|讨论]]  | [[Special:Contributions/$2|{{int:contribslink}}]])进行的[[$1]]的最后编辑；
 其他人已经编辑或是恢复了该页。
 
-最后编辑者: [[User:$3|$3]] ([[User talk:$3|讨论]])。',
+最后对页面编辑的编辑者: [[User:$3|$3]] ([[User talk:$3|讨论]] | [[Special:Contributions/$3|{{int:contribslink}}]])。',
 'editcomment'                 => '编辑说明: "<i>$1</i>"。', # only shown if there is an edit comment
 'revertpage'                  => '恢复由[[Special:Contributions/$2|$2]] ([[User talk:$2|对话]])的编辑至[[User:$1|$1]]的最后一个版本', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '恢复由$1的编辑；更改回$2的最后一个版本。',
 'sessionfailure'              => '似乎在您登录时发生问题，作为一项防范性措施，该动作已经被取消。请单击"后退"再次尝试！',
 'protectlogpage'              => '保护日志',
-'protectlogtext'              => '下面是页面锁定和取消锁定的列表。请参考[[Special:Protectedpages|保护页面列表]]以查看当前进行的页面保护。',
+'protectlogtext'              => '下面是页面锁定和取消锁定的列表。请参考[[Special:ProtectedPages|保护页面列表]]以查看当前进行的页面保护。',
 'protectedarticle'            => '已保护"[[$1]]"',
 'modifiedarticleprotection'   => '已经更改 "[[$1]]" 的保护等级',
 'unprotectedarticle'          => '已取消保护"[[$1]]"',
@@ -1679,7 +1680,7 @@
 
 # What links here
 'whatlinkshere'            => '链入页面',
-'whatlinkshere-title'      => '链接到$1的页面',
+'whatlinkshere-title'      => '链接到“$1”的页面',
 'whatlinkshere-page'       => '页面:',
 'linklistsub'              => '(链接列表)',
 'linkshere'                => '以下页面链接到[[:$1]]：',
@@ -1731,7 +1732,7 @@
 'badipaddress'                    => 'IP地址不正确。',
 'blockipsuccesssub'               => '查封成功',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]]已经被查封。
-<br />参看[[Special:Ipblocklist|被封IP地址列表]]以复审查封。',
+<br />参看[[Special:IPBlockList|被封IP地址列表]]以复审查封。',
 'ipb-edit-dropdown'               => '编辑查封原因',
 'ipb-unblock-addr'                => '解除封禁$1',
 'ipb-unblock'                     => '解除禁封用户名或IP地址',
@@ -1762,7 +1763,7 @@
 'blocklogpage'                    => '查封日志',
 'blocklogentry'                   => '[[$1]]已被查封 $3 ，终止时间为$2',
 'blocklogtext'                    => '这是关于用户查封和解封操作的日志。
-被自动查封的IP地址没有被列出。请参看[[Special:Ipblocklist|被封IP地址列表]]。',
+被自动查封的IP地址没有被列出。请参看[[Special:IPBlockList|被封IP地址列表]]。',
 'unblocklogentry'                 => '[[$1]]已被解封',
 'block-log-flags-anononly'        => '仅限匿名用户',
 'block-log-flags-nocreate'        => '禁止此IP/用户建立新帐户',
@@ -1809,8 +1810,8 @@
 'move-page-legend'        => '移动页面',
 'movepagetext'            => "用下面的表单来重命名一个页面，并将其修订历史同时移动到新页面。
 老的页面将成为新页面的重定向页。
-链接到老页面的链接并不会自动更改；
-请检查双重或损坏重定向链接。
+您可以自动地更新指到原标题的重定向。
+如果您选择不去做的话，请检查[[Special:DoubleRedirects|双重]]或[[Special:BrokenRedirects|损坏重定向]]连结。
 您应当负责确定所有链接依然会链到指定的页面。
 
 注意如果新页面已经有内容的话，页面将'''不会'''被移动，
@@ -1827,9 +1828,6 @@
 
 在这些情况下，您在必要时必须手工移动或合并页面。",
 'movearticle'             => '移动页面:',
-'movenologin'             => '未登录',
-'movenologintext'         => '您必须是一名登记用户并且[[Special:Userlogin|登录]]
-后才可移动一个页面。',
 'movenotallowed'          => '您在{{SITENAME}}中度并没有权限去移动页面。',
 'newtitle'                => '新标题:',
 'move-watch'              => '监视此页',
@@ -1857,7 +1855,7 @@
 'delete_and_move'         => '删除并移动',
 'delete_and_move_text'    => '==需要删除==
 
-目标页面"[[$1]]"已经存在。你确认需要删除原页面并以进行移动吗？',
+目标页面"[[:$1]]"已经存在。你确认需要删除原页面并以进行移动吗？',
 'delete_and_move_confirm' => '是的，删除此页面',
 'delete_and_move_reason'  => '删除以便移动',
 'selfmove'                => '原始标题和目标标题相同，不能移动一个页面到它自身。',
@@ -1865,6 +1863,7 @@
 'imagenocrossnamespace'   => '不可以移动文件到非文件名字空间',
 'imagetypemismatch'       => '该新副档名不匹配它的类型',
 'imageinvalidfilename'    => '目标文件名称是无效的',
+'fix-double-redirects'    => '更新指到原先标题的任何重定向',
 
 # Export
 'export'            => '导出页面',
@@ -1913,7 +1912,8 @@
 'import-interwiki-history'   => '复制此页的所有历史版本',
 'import-interwiki-submit'    => '导入',
 'import-interwiki-namespace' => '将页面转移到名字空间:',
-'importtext'                 => '请使用 Special:Export 功能从源 wiki 导出文件，保存到您的磁盘并上传到这里。',
+'importtext'                 => '请使用[[Special:Export|导出功能]]从源 wiki 导出文件，
+保存到您的磁盘并上传到这里。',
 'importstart'                => '正在导入页面...',
 'import-revision-count'      => '$1个修订',
 'importnopages'              => '没有导入的页面。',
@@ -2077,9 +2077,10 @@
 'markedaspatrollederror-noautopatrol' => '您无法将你自己所作的更改标记为已检查。',
 
 # Patrol log
-'patrol-log-page' => '巡查日志',
-'patrol-log-line' => '$2的版本$1已被标记为已检查的$3',
-'patrol-log-auto' => '(自动)',
+'patrol-log-page'   => '巡查日志',
+'patrol-log-header' => '这个是已经巡查过的日志。',
+'patrol-log-line'   => '$2的版本$1已被标记为已检查的$3',
+'patrol-log-auto'   => '(自动)',
 
 # Image deletion
 'deletedrevision'                 => '已删除旧版本$1',
@@ -2108,10 +2109,10 @@
 'show-big-image'       => '完整分辨率',
 'show-big-image-thumb' => '<small>这幅略缩图的分辨率: $1 × $2 像素</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新建图像画廊',
 'imagelisttext'         => "以下是按$2排列的'''$1'''个文件列表。",
-'newimages-summary'     => '这个特殊页面中显示最后已上传的文件',
+'newimages-summary'     => '这个特殊页面中显示最后已上传的文件。',
 'showhidebots'          => '($1机器人)',
 'noimages'              => '无可查看图像。',
 'ilsubmit'              => '搜索',
@@ -2407,7 +2408,7 @@
 
 # External editor support
 'edit-externally'      => '用外部程序编辑此文件',
-'edit-externally-help' => '请参见[http://meta.wikimedia.org/wiki/Help:External_editors 设置步骤]了解详细信息。',
+'edit-externally-help' => '请参见[http://www.mediawiki.org/wiki/Manual:External_editors 设置步骤]了解详细信息。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全部',
@@ -2434,7 +2435,7 @@
 邮件传送员回应: $1',
 'confirmemail_invalid'     => '无效的确认码，该代码可能已经过期。',
 'confirmemail_needlogin'   => '您需要$1以确认您的邮箱地址。',
-'confirmemail_success'     => '您的邮箱已经被确认。您现在可以登录并使用此网站了。',
+'confirmemail_success'     => '您的邮箱已经被确认。您现在可以[[Special:UserLogin|登录]]并使用此网站了。',
 'confirmemail_loggedin'    => '您的邮箱地址现在已被确认。',
 'confirmemail_error'       => '你的确认过程发生错误。',
 'confirmemail_subject'     => '{{SITENAME}}邮箱地址确认',
@@ -2469,11 +2470,12 @@
 
 # Delete conflict
 'deletedwhileediting' => '警告: 此页在您开始编辑之后已经被删除！',
-'confirmrecreate'     => '在您编辑这个页面后，用户[[User:$1|$1]]([[User talk:$1|对话]])以下列原因删除了这个页面: $2。请在重新创建页面前三思。',
+'confirmrecreate'     => '在您编辑这个页面后，用户[[User:$1|$1]]([[User talk:$1|对话]])以下列原因删除了这个页面: $2。
+请确认在您重新创建页面前三思。',
 'recreate'            => '重建',
 
 # HTML dump
-'redirectingto' => '重定向到[[$1]]...',
+'redirectingto' => '重定向到[[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '要清除此页面的缓存吗?\\n\\n$1',
@@ -2568,7 +2570,7 @@
 'version-software-product'         => '产品',
 'version-software-version'         => '版本',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => '文件路径',
 'filepath-page'    => '文件名:',
 'filepath-submit'  => '查找路径',
@@ -2606,7 +2608,7 @@
 'specialpages-group-redirects'   => '重定向特殊页面',
 'specialpages-group-spam'        => '反垃圾工具',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => '空白页面',
 'intentionallyblankpage' => '这个页面是为空白，以用来作测试速度等用途',
 
Index: languages/messages/MessagesId.php
===================================================================
--- languages/messages/MessagesId.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesId.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author Rex
  * @author Borgx
- * @author Siebrand
  * @author Irwangatot
+ * @author IvanLanin
  * @author Meursault2004
+ * @author Rex
  * @author לערי ריינהארט
- * @author IvanLanin
- * @author SPQRobin
  */
 
 /**
@@ -389,11 +387,11 @@
 'category-empty'                 => "''Kategori ini saat ini tak memiliki artikel atau media.''",
 'hidden-categories'              => '{{PLURAL:$1|Kategori tersembunyi|Kategori tersembunyi}}',
 'hidden-category-category'       => 'Kategori tersembunyi', # Name of the category where hidden categories will be listed
-'category-subcat-count'          => '{{PLURAL:$2|Kategori ini hanya memiliki subkategori berikut.|Ditampilkan {{PLURAL:$1|subkategori|$1 subkategori}} yang termasuk dalam kategori ini dari total $2.}}',
+'category-subcat-count'          => '{{PLURAL:$2|Kategori ini hanya memiliki satu subkategori berikut.|Kategori ini memiliki {{PLURAL:$1|subkategori|$1 subkategori}} berikut, dari total $2.}}',
 'category-subcat-count-limited'  => 'Kategori ini memiliki {{PLURAL:$1|subkategori|$1 subkategori}} berikut.',
-'category-article-count'         => '{{PLURAL:$2|Kategori ini hanya memiliki halaman berikut.|Ditampilkan {{PLURAL:$1|halaman|$1 halaman}} yang termasuk dalam kategori ini dari total $2.}}',
+'category-article-count'         => '{{PLURAL:$2|Kategori ini hanya memiliki satu halaman berikut.|Kategori ini memiliki {{PLURAL:$1|halaman|$1 halaman}}, dari total $2.}}',
 'category-article-count-limited' => 'Kategori ini memiliki {{PLURAL:$1|halaman|$1 halaman}} berikut.',
-'category-file-count'            => '{{PLURAL:$2|Kategori ini hanya memiliki berkas berikut.|Ditampilkan {{PLURAL:$1|berkas|$1 berkas}} yang termasuk dalam kategori ini dari total $2.}}',
+'category-file-count'            => '{{PLURAL:$2|Kategori ini hanya memiliki satu berkas berikut.|Kategori ini memiliki {{PLURAL:$1|berkas|$1 berkas}} berikut, dari total $2.}}',
 'category-file-count-limited'    => 'Kategori ini memiliki {{PLURAL:$1|berkas|$1 berkas}} berikut.',
 'listingcontinuesabbrev'         => 'samb.',
 
@@ -557,8 +555,10 @@
 'nosuchaction'      => 'Tidak ada tindakan tersebut',
 'nosuchactiontext'  => 'Tindakan yang dispesifikasikan oleh URL tersebut tidak dikenal oleh wiki.',
 'nosuchspecialpage' => 'Tidak ada halaman istimewa tersebut',
-'nospecialpagetext' => 'Anda meminta halaman istimewa yang tidak sah. Daftar halaman istimewa yang sah dapat dilihat di [[Special:Specialpages|daftar halaman istimewa]].',
+'nospecialpagetext' => "<big>'''Anda meminta halaman istimewa yang tidak sah.'''</big>
 
+Daftar halaman istimewa yang sah dapat dilihat di [[Special:SpecialPages|{{int:specialpages}}]].",
+
 # General errors
 'error'                => 'Kesalahan',
 'databaseerror'        => 'Kesalahan basis data',
@@ -571,12 +571,12 @@
 'readonly'             => 'Basis data dikunci',
 'enterlockreason'      => 'Masukkan alasan penguncian, termasuk perkiraan kapan kunci akan dibuka',
 'readonlytext'         => 'Basis data sedang dikunci terhadap masukan baru. Pengurus yang melakukan penguncian memberikan penjelasan sebagai berikut: <p>$1',
-'missing-article'      => 'Basis data tidak dapat menemukan teks dari halaman "$1" $2.
+'missing-article'      => 'Basis data tidak dapat menemukan teks dari halaman yang seharusnya ada, yaitu "$1" $2.
 
-Hal ini mungkin disebabkan oleh pranala usang ke versi terdahulu halaman yang telah dihapuskan.
+Hal ini biasanya disebabkan oleh pranala usang ke revisi terdahulu halaman yang telah dihapuskan.
 
-Jika bukan ini penyebabnya, Anda mungkin telah menemukan bug dalam perangkat lunak.
-Silakan laporkan hal ini kepada Pengurus, dengan menyebutkan alamat URL yang dituju.',
+Jika bukan ini penyebabnya, Anda mungkin telah menemukan sebuah bug dalam perangkat lunak.
+Silakan laporkan hal ini kepada salah seorang [[Special:ListUsers/sysop|Pengurus]], dengan menyebutkan alamat URL yang dituju.',
 'missingarticle-rev'   => '(revisi#: $1)',
 'missingarticle-diff'  => '(Beda: $1, $2)',
 'readonly_lag'         => 'Basis data telah dikunci otomatis selagi basis data sekunder melakukan sinkronisasi dengan basis data utama',
@@ -671,8 +671,10 @@
 'noname'                     => 'Nama pengguna yang Anda masukkan tidak sah.',
 'loginsuccesstitle'          => 'Berhasil masuk log',
 'loginsuccess'               => "'''Anda sekarang masuk log di {{SITENAME}} sebagai \"\$1\".'''",
-'nosuchuser'                 => 'Tidak ada pengguna dengan nama "$1". Periksalah ejaan Anda, atau gunakan formulir di bawah ini untuk membuka akun baru.',
-'nosuchusershort'            => 'Tidak ada pengguna dengan nama "<nowiki>$1</nowiki>". Periksalah ejaan Anda.',
+'nosuchuser'                 => 'Tidak ada pengguna dengan nama "$1".
+Silakan periksa kembali ejaan Anda, atau buka akun baru.',
+'nosuchusershort'            => 'Tidak ada pengguna dengan nama "<nowiki>$1</nowiki>".
+Silakan periksa kembali ejaan Anda.',
 'nouserspecified'            => 'Anda harus memasukkan nama pengguna.',
 'wrongpassword'              => 'Kata sandi yang Anda masukkan salah. Silakan coba lagi.',
 'wrongpasswordempty'         => 'Anda tidak memasukkan kata sandi. Silakan coba lagi.',
@@ -754,7 +756,8 @@
 'blockedtitle'                     => 'Pengguna diblokir',
 'blockedtext'                      => "<big>'''Nama pengguna atau alamat IP Anda telah diblokir.'''</big>
 
-Blokir dilakukan oleh $1. Alasan yang diberikan adalah ''$2''.
+Blokir dilakukan oleh $1.
+Alasan yang diberikan adalah ''$2''.
 
 * Diblokir sejak: $8
 * Blokir kadaluwarsa pada: $6
@@ -762,30 +765,29 @@
 
 Anda dapat menghubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pengurus lainnya]] untuk membicarakan hal ini.
 
-Anda tidak dapat menggunakan fitur 'Kirim surat-e pengguna ini' kecuali Anda telah memasukkan alamat surat-e yang sah di [[Special:Preferences|preferensi]] Anda dan Anda telah diblokir untuk menggunakannya.
+Anda tidak dapat menggunakan fitur 'Kirim surat-e pengguna ini' kecuali Anda telah memasukkan alamat surat-e yang sah di [[Special:Preferences|preferensi akun]] dan Anda tidak diblokir untuk menggunakannya.
 
-Alamat IP Anda adalah $3, dan ID pemblokiran adalah $5. Tolong sertakan salah satu atau kedua informasi ini pada setiap pertanyaan yang Anda buat",
-'autoblockedtext'                  => 'Alamat IP Anda telah terblokir secara otomatis karena digunakan oleh pengguna lain. Pemblokiran dilakukan oleh $1 dengan alasan:
+Alamat IP Anda adalah $3, dan ID pemblokiran adalah $5.
+Tolong sertakan salah satu atau kedua informasi ini pada setiap pertanyaan yang Anda buat.",
+'autoblockedtext'                  => 'Alamat IP Anda telah terblokir secara otomatis karena digunakan oleh pengguna lain, yang diblokir oleh $1. Pemblokiran dilakukan atas alasan:
 
 :\'\'$2\'\'
 
 * Diblokir sejak: $8
 * Blokir kadaluwarsa pada: $6
+* Sasaran pemblokiran: $7
 
 Anda dapat menghubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pengurus lainnya]] untuk membicarakan hal ini.
 
-Anda tidak dapat menggunakan fitur "kirim surat-e pengguna ini" kecuali Anda telah memasukkan alamat surat-e yang sah di [[Special:Preferences|preferensi]] Anda dan Anda telah diblokir untuk menggunakannya.
+Anda tidak dapat menggunakan fitur "kirim surat-e pengguna ini" kecuali Anda telah memasukkan alamat surat-e yang sah di [[Special:Preferences|preferensi akun]] Anda dan Anda tidak diblokir untuk menggunakannya.
 
-ID pemblokiran Anda adalah $5. Tolong sertakan ID ini dalam setiap pertanyaan Anda.',
+Alamat IP Anda saat ini adalah $3, dan ID pemblokiran adalah #$5.
+Tolong sertakan informasi-informasi ini dalam setiap pertanyaan Anda.',
 'blockednoreason'                  => 'tidak ada alasan yang diberikan',
 'blockedoriginalsource'            => "Isi sumber '''$1''' ditunjukkan berikut ini:",
 'blockededitsource'                => "Teks '''suntingan Anda''' terhadap '''$1''' ditunjukkan berikut ini:",
 'whitelistedittitle'               => 'Perlu masuk log untuk menyunting',
 'whitelistedittext'                => 'Anda harus $1 untuk dapat menyunting artikel.',
-'whitelistreadtitle'               => 'Perlu masuk log untuk membaca',
-'whitelistreadtext'                => 'Anda harus [[Special:Userlogin|masuk log]] untuk dapat membaca artikel.',
-'whitelistacctitle'                => 'Anda tidak diperbolehkan untuk membuat akun',
-'whitelistacctext'                 => 'Untuk dapat membuat akun dalam wiki ini, Anda harus [[Special:Userlogin|masuk log]] dan mempunyai izin yang tepat.',
 'confirmedittitle'                 => 'Konfirmasi surat-e diperlukan untuk melakukan penyuntingan',
 'confirmedittext'                  => 'Anda harus mengkonfirmasikan dulu alamat surat-e Anda sebelum menyunting halaman.
 Harap masukkan dan validasikan alamat surat-e Anda melalui [[Special:Preferences|halaman preferensi pengguna]] Anda.',
@@ -798,9 +800,10 @@
 'accmailtext'                      => "Kata sandi untuk '$1' telah dikirimkan ke $2.",
 'newarticle'                       => '(Baru)',
 'newarticletext'                   => "Anda mengikuti pranala ke halaman yang belum tersedia. Untuk membuat halaman tersebut, ketiklah isi halaman di kotak di bawah ini (lihat [[{{MediaWiki:Helppage}}|halaman bantuan]] untuk informasi lebih lanjut). Jika Anda tanpa sengaja sampai ke halaman ini, klik tombol '''back''' di penjelajah web anda.",
-'anontalkpagetext'                 => "----''Ini adalah halaman pembicaraan seorang pengguna anonim yang belum membuat akun atau tidak menggunakannya. Karena ia tidak membuat akun, kami terpaksa harus memakai alamat IP-nya untuk mengidentifikasikannya.
+'anontalkpagetext'                 => "----''Ini adalah halaman pembicaraan seorang pengguna anonim yang belum membuat akun atau tidak menggunakannya.
+Dengan demikian, kami terpaksa harus memakai alamat IP yang bersangkutan untuk mengidentifikasikannya.
 Alamat IP seperti ini mungkin dipakai bersama oleh beberapa pengguna yang berbeda.
-Jika Anda adalah seorang pengguna anonim dan merasa mendapatkan komentar-komentar yang tidak relevan yang ditujukan langsung kepada Anda, silakan [[Special:Userlogin|membuat akun atau masuk log]] untuk menghindari kerancuan dengan pengguna anonim lain di lain waktu.''",
+Jika Anda adalah seorang pengguna anonim dan merasa mendapatkan komentar-komentar yang tidak relevan yang ditujukan langsung kepada Anda, silakan [[Special:UserLogin/signup|membuat akun]] atau [[Special:UserLogin|masuk log]] untuk menghindari kerancuan dengan pengguna anonim lainnya di lain waktu.''",
 'noarticletext'                    => 'Saat ini tidak ada teks dalam halaman ini. Anda dapat [[Special:Search/{{PAGENAME}}|melakukan pencarian untuk judul halaman ini]] di halaman-halaman lain atau [{{fullurl:{{FULLPAGENAME}}|action=edit}} sunting halaman ini].',
 'userpage-userdoesnotexist'        => 'Akun pengguna "$1" tidak terdaftar.',
 'clearyourcache'                   => "'''Catatan:''' Setelah menyimpan preferensi, Anda perlu membersihkan <em>cache</em> penjelajah web Anda untuk melihat perubahan. '''Mozilla / Firefox / Safari:''' tekan ''Ctrl-Shift-R'' (''Cmd-Shift-R'' pada Apple Mac); '''IE:''' tekan ''Ctrl-F5''; '''Konqueror:''': tekan ''F5''; '''Opera''' bersihkan <em>cache</em> melalui menu ''Tools→Preferences''.",
@@ -849,7 +852,7 @@
 'edittools'                        => '<!-- Teks di sini akan dimunculkan di bawah isian suntingan dan pemuatan.-->',
 'nocreatetitle'                    => 'Pembuatan halaman baru dibatasi',
 'nocreatetext'                     => '{{SITENAME}} telah membatasi pembuatan halaman-halaman baru.
-Anda dapat kembali dan menyunting halaman yang telah ada, atau silakan [[Special:Userlogin|masuk log atau membuat akun]].',
+Anda dapat kembali dan menyunting halaman yang telah ada, atau silakan [[Special:UserLogin|masuk log atau membuat akun]].',
 'nocreate-loggedin'                => 'Anda tak memiliki hak akses untuk membuat halaman baru pada wiki ini.',
 'permissionserrors'                => 'Kesalahan Hak Akses',
 'permissionserrorstext'            => 'Anda tak memiliki hak untuk melakukan hal itu karena {{PLURAL:$1|alasan|alasan-alasan}} berikut:',
@@ -887,12 +890,12 @@
 'nohistory'           => 'Tidak ada sejarah penyuntingan untuk halaman ini',
 'revnotfound'         => 'Revisi tidak ditemukan',
 'revnotfoundtext'     => 'Revisi lama halaman yang Anda minta tidak dapat ditemukan. Silakan periksa URL yang digunakan untuk mengakses halaman ini.',
-'currentrev'          => 'Revisi sekarang',
+'currentrev'          => 'Revisi terkini',
 'revisionasof'        => 'Revisi per $1',
 'revision-info'       => 'Revisi per $1; $2',
 'previousrevision'    => '←Revisi sebelumnya',
 'nextrevision'        => 'Revisi selanjutnya→',
-'currentrevisionlink' => 'Revisi sekarang',
+'currentrevisionlink' => 'Revisi terkini',
 'cur'                 => 'skr',
 'next'                => 'selanjutnya',
 'last'                => 'akhir',
@@ -958,8 +961,8 @@
 
 # Suppression log
 'suppressionlog'     => 'Log penyembunyian',
-'suppressionlogtext' => 'Berikut adalah daftar penghapusan dan pemblokiran termasuk konten yang disembunyikan dari para opsis.
-Lihat [[Special:Ipblocklist|daftar IP yang diblokir]] untuk daftar pelarangan dan pemblokiran operasional saat ini.',
+'suppressionlogtext' => 'Berikut adalah daftar penghapusan dan pemblokiran, termasuk konten yang disembunyikan dari para opsis.
+Lihat [[Special:IPBlockList|daftar IP yang diblokir]] untuk daftar terkininya.',
 
 # History merging
 'mergehistory'                     => 'Gabung sejarah halaman',
@@ -1042,7 +1045,7 @@
 'mypreferences'            => 'Preferensi saya',
 'prefs-edits'              => 'Jumlah suntingan:',
 'prefsnologin'             => 'Belum masuk log',
-'prefsnologintext'         => 'Anda harus [[Special:Userlogin|masuk log]] untuk menetapkan preferensi Anda.',
+'prefsnologintext'         => 'Anda harus [[Special:UserLogin|masuk log]] untuk menetapkan preferensi Anda.',
 'prefsreset'               => 'Preferensi telah dikembalikan ke konfigurasi baku.',
 'qbsettings'               => 'Pengaturan bar pintas',
 'qbsettings-none'          => 'Tidak ada',
@@ -1116,7 +1119,7 @@
 'userrights-reason'           => 'Alasan pengubahan:',
 'userrights-no-interwiki'     => 'Anda tidak memiliki hak untuk mengubah hak pengguna di wiki yang lain.',
 'userrights-nodatabase'       => 'Basis data $1 tidak ada atau bukan lokal.',
-'userrights-nologin'          => 'Anda harus [[Special:Userlogin|masuk log]] dengan menggunakan akun pengurus untuk dapat mengubah hak pengguna.',
+'userrights-nologin'          => 'Anda harus [[Special:UserLogin|masuk log]] dengan menggunakan akun pengurus untuk dapat mengubah hak pengguna.',
 'userrights-notallowed'       => 'Anda tidak berhak untuk mengubah hak pengguna',
 'userrights-changeable-col'   => 'Kelompok yang dapat Anda ubah',
 'userrights-unchangeable-col' => 'Kelompok yang tidak dapat Anda ubah',
@@ -1210,7 +1213,7 @@
 'recentchangestext'                 => "Temukan perubahan terbaru dalam wiki di halaman ini. Keterangan: (beda) = perubahan, (versi) = sejarah revisi, '''B''' = halaman baru, '''k''' = suntingan kecil, '''b''' = suntingan bot, (± ''bita'') = jumlah penambahan/pengurangan isi, → = suntingan bagian, ← = ringkasan otomatis.
 ----",
 'recentchanges-feed-description'    => 'Temukan perubahan terbaru dalam wiki di umpan ini.',
-'rcnote'                            => "Di bawah ini {{PLURAL:$1|adalah '''1''' perubahan|adalah '''$1''' perubahan terbaru}} dalam {{PLURAL:$2|hari|'''$2''' hari}} terakhir, sampai $5, $4.",
+'rcnote'                            => "Berikut {{PLURAL:$1|adalah '''1''' perubahan terbaru|adalah '''$1''' perubahan terbaru}} dalam {{PLURAL:$2|'''1''' hari|'''$2''' hari}} terakhir, sampai $5, $4.",
 'rcnotefrom'                        => 'Di bawah ini adalah perubahan sejak <strong>$2</strong> (ditampilkan sampai <strong>$1</strong> perubahan).',
 'rclistfrom'                        => 'Perlihatkan perubahan terbaru sejak $1',
 'rcshowhideminor'                   => '$1 suntingan kecil',
@@ -1246,17 +1249,17 @@
 'reupload'                    => 'Muat ulang',
 'reuploaddesc'                => 'Kembali ke formulir pemuatan',
 'uploadnologin'               => 'Belum masuk log',
-'uploadnologintext'           => 'Anda harus [[Special:Userlogin|masuk log]] untuk dapat memuatkan berkas.',
+'uploadnologintext'           => 'Anda harus [[Special:UserLogin|masuk log]] untuk dapat memuatkan berkas.',
 'upload_directory_missing'    => 'Direktori pemuatan ($1) tidak ditemukan dan tidak dapat dibuat oleh server web.',
 'upload_directory_read_only'  => 'Direktori pemuatan ($1) tidak dapat ditulis oleh server web.',
 'uploaderror'                 => 'Kesalahan pemuatan',
 'uploadtext'                  => "Gunakan formulir di bawah untuk memuat berkas.
-Untuk menampilkan atau mencari berkas-berkas yang sebelumnya dimuatkan, gunakan [[Special:Imagelist|daftar pemuatan berkas]], pemuatan dan penghapusan berkas juga dicatat dalam [[Special:Log/upload|log pemuatan]].
+Untuk menampilkan atau mencari berkas-berkas yang sebelumnya dimuatkan, gunakan [[Special:ImageList|daftar pemuatan berkas]]. Pemuatan dan pemuatan kembali juga dicatat dalam [[Special:Log/upload|log pemuatan]]. Penghapusan berkas dicatat dalam [[Special:Log/delete|log penghapusan]].
 
-Untuk menampilkan atau menyertakan berkas/gambar pada suatu halaman, gunakan pranala dengan format
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Berkas.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Berkas.png|teks alternatif]]</nowiki>''', atau
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Berkas.ogg]]</nowiki>''' untuk langsung menuju berkas yang dimaksud.",
+Untuk menampilkan atau menyertakan berkas/gambar pada suatu halaman, gunakan pranala dengan salah satu format di bawah ini:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Berkas.jpg]]</nowiki></tt>''' untuk menampilkan berkas dalam ukuran aslinya
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Berkas.png|200px|thumb|left|teks alternatif]]</nowiki></tt>''' untuk menampilkan berkas dengan lebar 200px dalam sebuah kotak di kiri artikel dengan 'teks alternatif' sebagai keterangan gambar
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Berkas.ogg]]</nowiki></tt>''' sebagai pranala langsung ke berkas yang dimaksud tanpa menampilkan berkas tersebut melalui wiki",
 'upload-permitted'            => 'Jenis berkas yang diijinkan: $1.',
 'upload-preferred'            => 'Jenis berkas yang disarankan: $1.',
 'upload-prohibited'           => 'Jenis berkas yang dilarang: $1.',
@@ -1339,7 +1342,7 @@
 'upload_source_url'  => ' (suatu URL valid yang dapat diakses publik)',
 'upload_source_file' => ' (suatu berkas di komputer Anda)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Halaman istimewa ini menampilkan semua berkas yang telah dimuat.
 Secara baku, berkas yang terakhir dimuat berada pada urutan teratas.
 Klik pada kepala kolom untuk mengubah urutan.',
@@ -1367,7 +1370,7 @@
 'imagelinks'                     => 'Pranala',
 'linkstoimage'                   => 'Halaman berikut memiliki {{PLURAL:$1|pranala|$1 pranala}} ke berkas ini:',
 'nolinkstoimage'                 => 'Tidak ada halaman yang memiliki pranala ke berkas ini.',
-'morelinkstoimage'               => 'Lihat [[Special:Whatlinkshere/$1|pranala lainnya]] ke berkas ini.',
+'morelinkstoimage'               => 'Lihat [[Special:WhatLinksHere/$1|pranala lainnya]] ke berkas ini.',
 'redirectstofile'                => 'Berkas berikut {{PLURAL:$1|dialihkan|$1 dialihkan}} ke berkas ini:',
 'duplicatesoffile'               => 'Berkas berikut {{PLURAL:$1|merupakan duplikat|$1 merupakan duplikat}} dari berkas ini:',
 'sharedupload'                   => 'Berkas ini adalah pemuatan bersama yang mungkin juga dipakai oleh proyek lain.',
@@ -1446,17 +1449,19 @@
 Telah terjadi sejumlah '''$3''' penampilan halaman dan '''$4''' penyuntingan sejak {{SITENAME}} dimulai. Ini berarti rata-rata '''$5''' suntingan per halaman, dan '''$6''' penampilan per penyuntingan.
 
 Telah dimuat sejumlah '''$8''' berkas dan sedang terjadi '''$7''' [http://www.mediawiki.org/wiki/Manual:Job_queue antrian pekerjaan].",
-'userstatstext'          => "Terdapat '''$1''' [[Special:Listusers|{{PLURAL:$1|pengguna|pengguna}}]] terdaftar. '''$2''' (atau '''$4%''') diantaranya memiliki hak akses $5.",
+'userstatstext'          => "Terdapat {{PLURAL:$1|'''1''' [[Special:ListUsers|pengguna terdaftar]]|'''$1''' [[Special:ListUsers|pengguna terdaftar]]}}, dengan '''$2''' (atau '''$4%''') di antaranya memiliki hak akses $5.",
 'statistics-mostpopular' => 'Halaman yang paling banyak ditampilkan',
 
 'disambiguations'      => 'Halaman disambiguasi',
 'disambiguationspage'  => 'Template:Disambig',
-'disambiguations-text' => "Halaman-halaman berikut memiliki pranala ke suatu ''halaman disambiguasi''.
+'disambiguations-text' => "Halaman-halaman berikut memiliki pranala ke suatu '''halaman disambiguasi'''.
 Halaman-halaman tersebut seharusnya berpaut ke topik-topik yang sesuai.<br />
 Suatu halaman dianggap sebagai halaman disambiguasi apabila halaman tersebut menggunakan templat yang terhubung ke [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Pengalihan ganda',
-'doubleredirectstext' => 'Halaman ini memuat daftar halaman yang beralih ke halaman pengalihan yang lain. Setiap baris memuat pranala ke pengalihan pertama dan pengalihan kedua serta target dari pengalihan kedua yang umumnya adalah halaman yang sebenarnya. Halaman peralihan pertama seharusnya dialihkan ke halaman target tersebut.',
+'doubleredirects'            => 'Pengalihan ganda',
+'doubleredirectstext'        => 'Halaman ini memuat daftar halaman yang beralih ke halaman pengalihan yang lain. Setiap baris memuat pranala ke pengalihan pertama dan pengalihan kedua serta target dari pengalihan kedua yang umumnya adalah halaman yang sebenarnya. Halaman peralihan pertama seharusnya dialihkan ke halaman target tersebut.',
+'double-redirect-fixed-move' => '[[$1]] telah dipindahkan, sekarang menjadi halaman peralihan ke [[$2]]',
+'double-redirect-fixer'      => 'Pengguna yang memperbaiki pengalihan',
 
 'brokenredirects'        => 'Pengalihan rusak',
 'brokenredirectstext'    => 'Halaman-halaman berikut dialihkan ke halaman yang tidak ada.',
@@ -1478,7 +1483,7 @@
 'nrevisions'              => '$1 {{PLURAL:$1|revisi|revisi}}',
 'nviews'                  => '$1 {{PLURAL:$1|penampilan|penampilan}}',
 'specialpage-empty'       => 'Tak ada yang perlu dilaporkan.',
-'lonelypages'             => 'Halaman tak bertuan',
+'lonelypages'             => 'Halaman tanpa pranala balik',
 'lonelypagestext'         => 'Halaman-halaman berikut tidak memiliki pranala dari halaman manapun di wiki ini.',
 'uncategorizedpages'      => 'Halaman yang tak terkategori',
 'uncategorizedcategories' => 'Kategori yang tak terkategori',
@@ -1537,11 +1542,12 @@
 'all-logs-page'        => 'Semua log',
 'log-search-legend'    => 'Pencarian log',
 'log-search-submit'    => 'Cari',
-'alllogstext'          => 'Di bawah ini adalah gabungan log impor, pemblokiran, pemindahan, pemuatan, penghapusan, perlindungan, perubahan hak akses, dll. Anda dapat melakukan pembatasan tampilan dengan memilih jenis log, nama pengguna, atau judul halaman yang terpengaruh.',
+'alllogstext'          => 'Berikut adalah gabungan semua log yang tersedia di {{SITENAME}}.
+Anda dapat melakukan pembatasan tampilan dengan memilih jenis log, nama pengguna, atau judul halaman.',
 'logempty'             => 'Tidak ditemukan entri log yang sesuai.',
 'log-title-wildcard'   => 'Cari judul yang diawali dengan teks tersebut',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Daftar halaman',
 'alphaindexline'    => '$1 ke $2',
 'nextpage'          => 'Halaman selanjutnya ($1)',
@@ -1564,14 +1570,14 @@
 'special-categories-sort-count' => 'urutkan menurut jumlah',
 'special-categories-sort-abc'   => 'urutkan menurut abjad',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Tampilkan pengguna diawali dengan:',
 'listusers-submit'   => 'Tampilkan',
 'listusers-noresult' => 'Pengguna tidak ditemukan.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Hak-hak grup pengguna',
-'listgrouprights-summary'  => 'Berikut adalah daftar kelompok pengguna yang terdapat di wiki ini, dengan daftar hak akses mereka. Informasi lebih lanjut mengenai hak individual dapat ditemukan di [[{{MediaWiki:Listgrouprights-helppage}}]].',
+'listgrouprights-summary'  => 'Berikut adalah daftar kelompok pengguna yang terdapat di wiki ini, dengan daftar hak akses mereka masing-masing. Informasi lebih lanjut mengenai hak masing-masing dapat ditemukan di [[{{MediaWiki:Listgrouprights-helppage}}|halaman bantuan hak pengguna]].',
 'listgrouprights-group'    => 'Kelompok',
 'listgrouprights-rights'   => 'Hak',
 'listgrouprights-helppage' => 'Help:Hak kelompok',
@@ -1579,7 +1585,7 @@
 
 # E-mail user
 'mailnologin'     => 'Tidak ada alamat surat-e',
-'mailnologintext' => 'Anda harus [[Special:Userlogin|masuk log]] dan mempunyai alamat surat-e yang sah di dalam [[Special:Preferences|preferensi]] untuk mengirimkan surat-e kepada pengguna lain.',
+'mailnologintext' => 'Anda harus [[Special:UserLogin|masuk log]] dan mempunyai alamat surat-e yang sah di dalam [[Special:Preferences|preferensi]] untuk mengirimkan surat-e kepada pengguna lain.',
 'emailuser'       => 'Surat-e pengguna',
 'emailpage'       => 'Kirimi pengguna ini surat-e',
 'emailpagetext'   => 'Jika pengguna ini memasukkan alamat surat-e yang sah dalam preferensinya, formulir di bawah ini akan mengirimkan sebuah surat-e. Alamat surat-e yg terdapat pada preferensi Anda akan muncul sebagai alamat "Dari" dalam surat-e tersebut, sehingga penerima dapat membalas surat-e tersebut.',
@@ -1605,10 +1611,10 @@
 'nowatchlist'          => 'Daftar pantauan Anda kosong.',
 'watchlistanontext'    => 'Silakan $1 untuk melihat atau menyunting daftar pantauan Anda.',
 'watchnologin'         => 'Belum masuk log',
-'watchnologintext'     => 'Anda harus [[Special:Userlogin|masuk log]] untuk mengubah daftar pantauan.',
+'watchnologintext'     => 'Anda harus [[Special:UserLogin|masuk log]] untuk mengubah daftar pantauan Anda.',
 'addedwatch'           => 'Telah ditambahkan ke daftar pantauan',
 'addedwatchtext'       => "Halaman \"[[:\$1]]\" telah ditambahkan ke [[Special:Watchlist|daftar pantauan]] Anda.
-Perubahan-perubahan berikutnya pada halaman tersebut dan halaman pembicaraan terkaitnya akan tercantum di sini, dan halaman itu akan ditampilkan ''tebal'' pada [[Special:Recentchanges|daftar perubahan terbaru]] agar lebih mudah terlihat.",
+Perubahan-perubahan berikutnya pada halaman tersebut dan halaman pembicaraan terkaitnya akan tercantum di sini, dan halaman itu akan ditampilkan '''tebal''' pada [[Special:RecentChanges|daftar perubahan terbaru]] agar lebih mudah terlihat.",
 'removedwatch'         => 'Telah dihapus dari daftar pantauan',
 'removedwatchtext'     => 'Halaman "<nowiki>$1</nowiki>" telah dihapus dari daftar pantauan.',
 'watch'                => 'Pantau',
@@ -1707,16 +1713,17 @@
 'rollbacklink'                => 'kembalikan',
 'rollbackfailed'              => 'Pengembalian gagal dilakukan',
 'cantrollback'                => 'Tidak dapat mengembalikan suntingan; pengguna terakhir adalah satu-satunya penulis artikel ini.',
-'alreadyrolled'               => 'Tidak dapat melakukan pengembalian ke suntingan terakhir [[:$1]] oleh [[User:$2|$2]] ([[User talk:$2|bicara]]);
-pengguna lain telah menyunting atau melakukan pengembalian terhadap artikel tersebut.
+'alreadyrolled'               => 'Tidak dapat melakukan pengembalian ke revisi terakhir [[:$1]] oleh [[User:$2|$2]] ([[User talk:$2|bicara]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
+pengguna lain telah menyunting atau melakukan pengembalian terhadap revisi tersebut.
 
-Suntingan terakhir dilakukan oleh [[User:$3|$3]] ([[User talk:$3|bicara]]).',
+Suntingan terakhir dilakukan oleh [[User:$3|$3]] ([[User talk:$3|bicara]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Komentar penyuntingan adalah: "<em>$1</em>".', # only shown if there is an edit comment
 'revertpage'                  => 'Suntingan [[Special:Contributions/$2|$2]] ([[User talk:$2|bicara]]) dikembalikan ke versi terakhir oleh [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Pengembalian suntingan oleh $1; dikembalikan ke versi terakhir oleh $2.',
 'sessionfailure'              => 'Sepertinya ada masalah dengan sesi log anda; log anda telah dibatalkan untuk mencegah pembajakan. Silahkan tekan tombol "back" dan muat kembali halaman sebelum anda masuk, lalu coba lagi.',
 'protectlogpage'              => 'Log perlindungan',
-'protectlogtext'              => 'Di bawah ini adalah log perlindungan dan penghilangan perlindungan halaman. Lihat [[Special:Protectedpages|daftar halaman yang dilindungi]] untuk daftar perlindungan halaman yang berlaku sekarang.',
+'protectlogtext'              => 'Berikut adalah log perlindungan halaman dan pembatalannya.
+Lihat [[Special:ProtectedPages|daftar halaman yang dilindungi]] untuk daftar terkini.',
 'protectedarticle'            => 'melindungi "[[$1]]"',
 'modifiedarticleprotection'   => 'mengubah tingkat perlindungan "[[$1]]"',
 'unprotectedarticle'          => 'menghilangkan perlindungan "[[$1]]"',
@@ -1821,12 +1828,12 @@
 
 # What links here
 'whatlinkshere'            => 'Pranala balik',
-'whatlinkshere-title'      => 'Halaman yang memiliki pranala ke $1',
+'whatlinkshere-title'      => 'Halaman yang memiliki pranala ke "$1"',
 'whatlinkshere-page'       => 'Halaman:',
 'linklistsub'              => '(Daftar pranala)',
-'linkshere'                => "Halaman-halaman berikut ini berpaut ke '''[[:$1]]''':",
-'nolinkshere'              => "Tidak ada halaman yang berpaut ke '''[[:$1]]'''.",
-'nolinkshere-ns'           => "Tidak ada halaman yang berpaut ke '''[[:$1]]''' pada ruang nama yang dipilih.",
+'linkshere'                => "Halaman-halaman berikut ini memiliki pranala ke '''[[:$1]]''':",
+'nolinkshere'              => "Tidak ada halaman yang memiliki pranala ke '''[[:$1]]'''.",
+'nolinkshere-ns'           => "Tidak ada halaman yang memiliki pranala ke '''[[:$1]]''' pada ruang nama yang dipilih.",
 'isredirect'               => 'halaman peralihan',
 'istemplate'               => 'dengan templat',
 'isimage'                  => 'pranala berkas',
@@ -1873,7 +1880,7 @@
 'badipaddress'                    => 'Format alamat IP atau nama pengguna salah.',
 'blockipsuccesssub'               => 'Pemblokiran sukses',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] telah diblokir.<br />
-Lihat [[Special:Ipblocklist|Daftar IP]] untuk meninjau kembali pemblokiran.',
+Lihat [[Special:IPBlockList|Daftar IP]] untuk meninjau kembali pemblokiran.',
 'ipb-edit-dropdown'               => 'Sunting alasan pemblokiran',
 'ipb-unblock-addr'                => 'Hilangkan blokir $1',
 'ipb-unblock'                     => 'Hilangkan blokir seorang pengguna atau suatu alamat IP',
@@ -1905,7 +1912,7 @@
 'blocklogentry'                   => 'memblokir [[$1]] dengan waktu kadaluwarsa $2 $3',
 'blocklogtext'                    => 'Di bawah ini adalah log pemblokiran dan pembukaan blokir terhadap pengguna.
 Alamat IP yang diblokir secara otomatis tidak terdapat di dalam daftar ini.
-Lihat [[Special:Ipblocklist|daftar alamat IP yang diblokir]] untuk daftar pemblokiran terkini.',
+Lihat [[Special:IPBlockList|daftar alamat IP yang diblokir]] untuk daftar pemblokiran terkini.',
 'unblocklogentry'                 => 'menghilangkan blokir "$1"',
 'block-log-flags-anononly'        => 'hanya pengguna anonim',
 'block-log-flags-nocreate'        => 'pembuatan akun dimatikan',
@@ -1939,8 +1946,8 @@
 'locknoconfirm'       => 'Anda tidak memberikan tanda cek pada kotak konfirmasi.',
 'lockdbsuccesssub'    => 'Penguncian basis data berhasil',
 'unlockdbsuccesssub'  => 'Pembukaan kunci basis data berhasil',
-'lockdbsuccesstext'   => 'Basis data telah dikunci.
-<br />Pastikan Anda [[Special:Unlockdb|membuka kuncinya]] setelah pemeliharaan selesai.',
+'lockdbsuccesstext'   => 'Basis data telah dikunci.<br />
+Pastikan Anda [[Special:UnlockDB|membuka kuncinya]] setelah pemeliharaan selesai.',
 'unlockdbsuccesstext' => 'Kunci basis data telah dibuka.',
 'lockfilenotwritable' => 'Berkas kunci basis data tidak dapat ditulis. Untuk mengunci atau membuka basis data, berkas ini harus dapat ditulis oleh server web.',
 'databasenotlocked'   => 'Basis data tidak terkunci.',
@@ -1960,8 +1967,6 @@
 
 Dalam kasus tersebut, apabila diinginkan, Anda dapat memindahkan atau menggabungkan halaman secara manual.",
 'movearticle'             => 'Pindahkan halaman:',
-'movenologin'             => 'Belum masuk log',
-'movenologintext'         => 'Anda harus menjadi pengguna terdaftar dan telah [[Special:Userlogin|masuk log]] untuk dapat memindahkan suatu halaman.',
 'movenotallowed'          => 'Anda tak memiliki hak akses untuk memindahkan halaman pada wiki ini.',
 'newtitle'                => 'Ke judul baru:',
 'move-watch'              => 'Pantau halaman ini',
@@ -1988,7 +1993,7 @@
 'delete_and_move'         => 'Hapus dan pindahkan',
 'delete_and_move_text'    => '==Penghapusan diperlukan==
 
-Artikel yang dituju, "[[$1]]", telah mempunyai isi. Apakah Anda hendak menghapusnya untuk memberikan ruang bagi pemindahan?',
+Artikel yang dituju, "[[:$1]]", telah mempunyai isi. Apakah Anda hendak menghapusnya untuk memberikan ruang bagi pemindahan?',
 'delete_and_move_confirm' => 'Ya, hapus halaman tersebut',
 'delete_and_move_reason'  => 'Dihapus untuk mengantisipasikan pemindahan halaman',
 'selfmove'                => 'Pemindahan halaman tidak dapat dilakukan karena judul sumber dan judul tujuan sama.',
@@ -1996,6 +2001,7 @@
 'imagenocrossnamespace'   => 'Tidak dapat memindahkan berkas ke ruang nama non-berkas',
 'imagetypemismatch'       => 'Ekstensi yang diberikan tidak cocok dengan tipe berkas',
 'imageinvalidfilename'    => 'Nama berkas tujuan tidak sah',
+'fix-double-redirects'    => 'Perbaiki semua pengalihan yang merujuk ke artikel aslinya',
 
 # Export
 'export'            => 'Ekspor halaman',
@@ -2042,7 +2048,8 @@
 'import-interwiki-history'   => 'Salin semua versi terdahulu dari halaman ini',
 'import-interwiki-submit'    => 'Impor',
 'import-interwiki-namespace' => 'Transfer halaman ke dalam ruang nama:',
-'importtext'                 => 'Silakan ekspor berkas dari wiki asal dengan menggunakan utilitas Special:Export, simpan ke disk, dan muatkan di sini.',
+'importtext'                 => 'Silakan ekspor berkas dari wiki asal dengan menggunakan [[Special:Export|fasilitas ekspor]].
+Simpan ke komputer Anda lalu muatkan di sini.',
 'importstart'                => 'Mengimpor halaman...',
 'import-revision-count'      => '$1 {{PLURAL:$1|revisi|revisi}}',
 'importnopages'              => 'Tidak ada halaman untuk diimpor.',
@@ -2192,9 +2199,10 @@
 'markedaspatrollederror-noautopatrol' => 'Anda tidak diizinkan menandai suntingan Anda sendiri dipatroli.',
 
 # Patrol log
-'patrol-log-page' => 'Log patroli',
-'patrol-log-line' => 'menandai $1 dari $2 terpatroli $3',
-'patrol-log-auto' => '(otomatis)',
+'patrol-log-page'   => 'Log patroli',
+'patrol-log-header' => 'Ini adalah log revisi terpatroli.',
+'patrol-log-line'   => 'menandai $1 dari $2 terpatroli $3',
+'patrol-log-auto'   => '(otomatis)',
 
 # Image deletion
 'deletedrevision'                 => 'Revisi lama yang dihapus $1',
@@ -2221,7 +2229,7 @@
 'show-big-image'       => 'Resolusi penuh',
 'show-big-image-thumb' => '<small>Ukuran pratayang ini: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Berkas baru',
 'imagelisttext'         => "Di bawah ini adalah daftar '''$1''' {{PLURAL:$1|berkas|berkas}} diurutkan $2.",
 'newimages-summary'     => 'Halaman istimewa berikut menampilkan daftar berkas yang terakhir dimuat',
@@ -2503,7 +2511,7 @@
 
 # External editor support
 'edit-externally'      => 'Sunting berkas ini dengan aplikasi luar',
-'edit-externally-help' => 'Lihat [http://meta.wikimedia.org/wiki/Help:External_editors instruksi pengaturan] untuk informasi lebih lanjut.',
+'edit-externally-help' => 'Lihat [http://www.mediawiki.org/wiki/Manual:External_editors instruksi pengaturan] untuk informasi lebih lanjut.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'semua',
@@ -2564,7 +2572,7 @@
 'recreate'            => 'Buat ulang',
 
 # HTML dump
-'redirectingto' => 'Sedang dialihkan ke [[$1]]...',
+'redirectingto' => 'Sedang dialihkan ke [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Hapus ''cache'' halaman ini?
@@ -2607,12 +2615,12 @@
 'livepreview-ready'   => 'Memuat… Selesai!',
 'livepreview-failed'  => 'Pratayang langsung gagal!
 Coba dengan pratayang normal.',
-'livepreview-error'   => 'Gagal tersambung: $1 "$2"
+'livepreview-error'   => 'Gagal tersambung: $1 "$2".
 Coba dengan pratayang normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Perubahan yang lebih baru dari $1 detik mungkin tidak muncul di daftar ini.',
-'lag-warn-high'   => 'Karenanya besarnya lag basis data server, perubahan yang lebih baru dari $1 detik mungkin tidak muncul di daftar ini.',
+'lag-warn-normal' => 'Perubahan yang lebih baru dari $1 {{PLURAL:$1|detik|detik}} mungkin tidak muncul di daftar ini.',
+'lag-warn-high'   => 'Karenanya besarnya keterlambatan basis data server, perubahan yang lebih baru dari $1 {{PLURAL:$1|detik|detik}} mungkin tidak muncul di daftar ini.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Daftar pantauan Anda berisi {{PLURAL:$1|1 judul|$1 judul}},tidak termasuk halaman pembicaraan.',
@@ -2662,7 +2670,7 @@
 'version-software-product'         => 'Produk',
 'version-software-version'         => 'Versi',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Lokasi berkas',
 'filepath-page'    => 'Berkas:',
 'filepath-submit'  => 'Lokasi',
@@ -2686,8 +2694,9 @@
 # Special:SpecialPages
 'specialpages'                   => 'Halaman istimewa',
 'specialpages-note'              => '----
-* Halaman istimewa normal.
-* <span class="mw-specialpagerestricted">Halaman istimewa terbatas.</span>',
+Keterangan tampilan:
+* Halaman istimewa normal
+* <span class="mw-specialpagerestricted">Halaman istimewa terbatas</span>',
 'specialpages-group-maintenance' => 'Laporan pemeliharaan',
 'specialpages-group-other'       => 'Halaman istimewa lainnya',
 'specialpages-group-login'       => 'Masuk log / mendaftar',
@@ -2701,7 +2710,7 @@
 'specialpages-group-redirects'   => 'Mengalihkan halaman istimewa',
 'specialpages-group-spam'        => 'Peralatan spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Halaman kosong',
 'intentionallyblankpage' => 'Halaman ini sengaja dibiarkan kosong dan digunakan di antaranya untuk pengukuran kinerja, dan lain-lain.',
 
Index: languages/messages/MessagesTet.php
===================================================================
--- languages/messages/MessagesTet.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTet.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author MF-Warburg
- * @author Siebrand
- * @author SPQRobin
  */
 
 $skinNames = array(
@@ -388,7 +386,7 @@
 'uploadbtn'       => 'Tau iha arkivu laran',
 'watchthisupload' => "Hateke pájina ne'e",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Naran',
 'imagelist_user' => "Uza-na'in",
 
@@ -415,15 +413,15 @@
 # Statistics
 'statistics'    => 'Estátistika',
 'sitestats'     => '{{SITENAME}} estátistika',
-'userstatstext' => "Iha ne'e registrar tiha ona '''$1''' [[Special:Listusers|uza-na'in]], '''$2''' (ka '''$4%''') $5.",
+'userstatstext' => "Iha ne'e registrar tiha ona '''$1''' {{PLURAL:$1|[[Special:ListUsers|uza-na'in]]|[[Special:ListUsers|uza-na'in]]}}, '''$2''' (ka '''$4%''') $5.",
 
 'brokenredirects-edit'   => '(edita)',
 'brokenredirects-delete' => '(halakon)',
 
 # Miscellaneous special pages
 'nlinks'            => '$1 ligasaun',
-'nmembers'          => '$1 membru',
-'nrevisions'        => '$1 versaun',
+'nmembers'          => '$1 {{PLURAL:$1|membru|membru}}',
+'nrevisions'        => '$1 {{PLURAL:$1|versaun|versaun}}',
 'shortpages'        => 'Pájina badak',
 'longpages'         => 'Pájina naruk',
 'listusers'         => "Lista uza-na'in",
@@ -440,7 +438,7 @@
 'specialloguserlabel' => "Uza-na'in:",
 'log-search-submit'   => 'Bá',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Pájina hotu',
 'alphaindexline' => "$1 to'o $2",
 'nextpage'       => 'Pájina oinmai ($1)',
@@ -451,10 +449,10 @@
 # Special:Categories
 'categories' => 'Kategoría',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Hatudu',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'  => 'Lubu',
 'listgrouprights-rights' => 'Priviléjiu',
 
@@ -517,7 +515,7 @@
 'undeletelink'           => 'restaurar',
 'undeletecomment'        => 'Komentáriu:',
 'undeletedarticle'       => 'restaurar "[[$1]]"',
-'undeletedrevisions'     => 'restaurar $1 versaun',
+'undeletedrevisions'     => 'restaurar $1 {{PLURAL:$1|versaun|versaun}}',
 'undelete-search-submit' => 'Buka',
 
 # Namespace form on various pages
@@ -580,7 +578,7 @@
 'allmessagescurrent' => 'Testu atuál',
 
 # Import log
-'import-logentry-interwiki-detail' => '$1 versaun husi $2',
+'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|versaun|versaun}} husi $2',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'      => "Ha'u-nia pájina uza-na'in",
@@ -611,7 +609,7 @@
 'previousdiff' => '←Diferensa molok',
 'nextdiff'     => 'Diferensa oinmai→',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 bot sira)',
 'ilsubmit'     => 'Buka',
 
Index: languages/messages/MessagesAn.php
===================================================================
--- languages/messages/MessagesAn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,11 +5,8 @@
  * @file
  *
  * @author Juanpabl
- * @author SPQRobin
- * @author Siebrand
- * @author לערי ריינהארט
- * @author Jon Harald Søby
  * @author Willtron
+ * @author לערי ריינהארט
  */
 
 $fallback = 'es';
@@ -207,8 +204,8 @@
 'mar'           => 'mar',
 'apr'           => 'abr',
 'may'           => 'may',
-'jun'           => 'chn',
-'jul'           => 'chl',
+'jun'           => 'chun',
+'jul'           => 'chul',
 'aug'           => 'ago',
 'sep'           => 'set',
 'oct'           => 'otu',
@@ -393,7 +390,7 @@
 'nosuchspecialpage' => 'No esiste ixa pachina espezial',
 'nospecialpagetext' => "<big>'''A pachina espezial que ha demandato no esiste.'''</big>
 
-Puede trobar una lista de pachinas espezials en [[Special:Specialpages|{{int:specialpages}}]].",
+Puede trobar una lista de pachinas espezials en [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -415,11 +412,11 @@
 'readonlytext'         => "A base de datos de {{SITENAME}} ye bloqueyata temporalment, probablement por mantenimiento rutinario, dimpués d'ixo tornará á la normalidat.
 L'almenistrador que la bloqueyó dió ista esplicazión:
 <p>$1",
-'missing-article'      => "No s'ha trobato en a base de datos o testo d'una pachina que abría d'estar-ie: \$1\" \$2.
+'missing-article'      => "No s'ha trobato en a base de datos o testo d'una pachina que abría d'estar-ie: \"\$1\" \$2.
 
-A razón d'isto puede estar que un diff no autualizato u un binclo ta l'istorial d'una pachina que ya s'ha borrato.
+Cal que a razón d'isto siga que s'ha seguito un diff masiau antigo u un binclo ta l'istorial d'una pachina que ya s'ha borrato.
 
-No no ye iste o caso, puede que aiga trobato un error en o software. Por fabor, informe d'ello á un almenistrador, endicando-le a URL.",
+Si no ye iste o caso, puede que aiga trobato un error en o software. Por fabor, informe d'isto á un [[Special:ListUsers/sysop|almenistrador]], endicando-le a URL.",
 'missingarticle-rev'   => '(bersión#: $1)',
 'missingarticle-diff'  => '(Esf: $1, $2)',
 'readonly_lag'         => 'A base de datos ye bloqueyata temporalment entre que os serbidors se sincronizan.',
@@ -467,11 +464,12 @@
 
 # Login and logout pages
 'logouttitle'                => "Fin d'a sesión",
-'logouttext'                 => "Ha rematato a sesión.
-Puede continar nabegando por {{SITENAME}} anonimament, u puede enzetar una nueba sesión con o mesmo u atro nombre d'usuario. Pare cuenta que, entre que se limpia a caché d'o nabegador, bellas pachinas encara se pueden amostrar como si continase en a sesión anterior.",
+'logouttext'                 => "<strong>Ha rematato a sesión.</strong>
+
+Puede continar nabegando por {{SITENAME}} anonimament, u puede [[Special:UserLogin|enzetar]] una nueba sesión con o mesmo nombre d'usuario u unatro diferent. Pare cuenta que, entre que se limpia a caché d'o nabegador, puet estar que bellas pachinas s'amuestren como si encara continase en a sesión anterior.",
 'welcomecreation'            => "== ¡Bienbeniu(da), $1! ==
 S'ha creyato a suya cuenta.
-No xublide presonalizar as preferenzias.",
+No xublide presonalizar [[Special:Preferences|as suyas preferenzias en {{SITENAME}}]].",
 'loginpagetitle'             => 'Enzetar a sesión',
 'yourname'                   => "Nombre d'usuario:",
 'yourpassword'               => 'Palabra de paso:',
@@ -482,7 +480,7 @@
 'loginproblem'               => '<b>Escaizió un problema con a suya autenticazión.</b><br />¡Prebe unatra begada!',
 'login'                      => 'Enzetar sesión',
 'nav-login-createaccount'    => 'Enzetar una sesión / creyar cuenta',
-'loginprompt'                => 'Ha de autibar as <i>cookies</i> en o nabegador ta rechistrar-se en {{SITENAME}}.',
+'loginprompt'                => "Ta rechistrar-se en {{SITENAME}} ha d'autibar as cookies en o nabegador.",
 'userlogin'                  => 'Enzetar una sesión / creyar cuenta',
 'logout'                     => "Salir d'a sesión",
 'userlogout'                 => 'Salir',
@@ -630,12 +628,8 @@
 'blockednoreason'                  => "No s'ha dato garra causa",
 'blockedoriginalsource'            => "Contino s'amuestra o codigo fuent de  '''$1''':",
 'blockededitsource'                => "Contino s'amuestra o testo d'as suyas '''edizions''' á '''$1''':",
-'whitelistedittitle'               => 'Cal enzetar una sesión ta ta fer edizions.',
+'whitelistedittitle'               => 'Cal enzetar una sesión ta poder editar.',
 'whitelistedittext'                => 'Ha de $1 ta poder editar pachinas.',
-'whitelistreadtitle'               => "Cal que s'identifique y que enzete una sesión ta poder leyer",
-'whitelistreadtext'                => 'Ha de [[Special:Userlogin|identificar-se]] ta leyer as pachinas.',
-'whitelistacctitle'                => 'No tiene premiso ta creyar una cuenta',
-'whitelistacctext'                 => 'Ta poder creyar cuentas en {{SITENAME}} li cal [[Special:Userlogin|enzetar una sesión]] y tener os premisos apropiatos.',
 'confirmedittitle'                 => 'Cal que confirme a suya adreza de correu-e ta poder editar',
 'confirmedittext'                  => "Ha de confirmar a suya adreza de correu-e antis de poder editar pachinas. Por fabor, establa y confirme una adreza de correu-e a trabiés d'as suyas [[Special:Preferences|preferenzias d'usuario]].",
 'nosuchsectiontitle'               => 'No esiste ixa sezión',
@@ -650,7 +644,9 @@
 Ta creyar a pachina, prenzipie á escribir en a caxa d'abaxo
 (mire-se l'[[{{MediaWiki:Helppage}}|aduya]] ta más informazión).
 Si bi ha plegau por error, punche o botón d'o suyo nabegador ta tornar entazaga.",
-'anontalkpagetext'                 => "---- ''Ista ye a pachina de descusión d'un usuario anonimo que encara no ha creyato una cuenta, u no l'ha feito serbir. Por ixo, hemos d'emplegar a suya adreza IP ta identificar-lo/a. Una adreza IP puede estar compartita entre diferens usuarios. Si busté ye un usuario anonimo y creye que s'han endrezato á busté con comentarios no relebants, [[Special:Userlogin|creye una cuenta u identifique-se]] ta pribar esdebenideras confusions con atros usuarios anonimos.''",
+'anontalkpagetext'                 => "----''Ista ye a pachina de descusión d'un usuario anonimo que encara no ha creyato una cuenta, u no l'ha feito serbir. Por ixo, emos d'emplegar a suya adreza IP ta identificar-lo/a. 
+Barios usuarios pueden compartir una mesma adreza IP. 
+Si busté ye un usuario anonimo y creye que l'han escrito comentarios no relebants, [[Special:UserLogin/signup|creye una cuenta]] u [[Special:UserLogin/signup|identifique-se]] ta pribar confusions futuras con atros usuarios anonimos.''",
 'noarticletext'                    => 'Por agora no bi ha testo en ista pachina. Puede [[Special:Search/{{PAGENAME}}|mirar o títol]] en atras pachinas u [{{fullurl:{{FULLPAGENAME}}|action=edit}} prenzipiar á escribir en ista pachina].',
 'userpage-userdoesnotexist'        => 'A cuenta d\'usuario "$1" no ye rechistrada. Piense si quiere creyar u editar ista pachina.',
 'clearyourcache'                   => "'''Pare cuenta: Si quiere beyer os cambeos dimpués d'alzar l'archibo, puede estar que tienga que refrescar a caché d'o suyo nabegador ta beyer os cambeos.''' '''Mozilla / Firefox / Safari:''' prete a tecla de ''Mayusclas'' mientras puncha ''Reload,'' u prete '''Ctrl-Fr''' u '''Ctrl-R''' (''Command-R'' en un Macintosh); '''Konqueror: ''' punche ''Reload'' u prete ''F5;'' '''Opera:''' limpiar a caché en ''Tools → Preferences;'' '''Internet Explorer:''' prete ''Ctrl'' mientres puncha ''Refresh,'' u prete ''Ctrl-F5.''",
@@ -662,12 +658,12 @@
 'note'                             => '<strong>Nota:</strong>',
 'previewnote'                      => "<strong>Pare cuenta que isto sólo ye que l'ambiesta prebia d'a pachina; os cambeos encara no han estato alzatos!</strong>",
 'previewconflict'                  => "L'ambiesta prebia li amostrará l'aparenzia d'o testo dimpués d'alzar os cambeos.",
-'session_fail_preview'             => "<strong>Ya lo sentimos, pero no podiemos alzar a suya edizión por una perda d'os datos de sesion. Por fabor, prebe de fer-lo una atra bez, y si encara no funziona, salga d'a sesión y torne á identificar-se.</strong>",
-'session_fail_preview_html'        => "<strong>Ya lo sentimos, pero no emos puesto prozesar a suya edizión porque os datos de sesión s'han acazegatos.</strong>
+'session_fail_preview'             => "<strong>Ya lo sentimos, pero no emos puesto alzar a suya edizión por una perduga d'os datos de sesion. Por fabor, prebe de fer-lo una atra bez, y si encara no funziona, [[Special:UserLogout|salga d'a sesión]] y torne á identificar-se.</strong>",
+'session_fail_preview_html'        => "<strong>Ya lo sentimos, pero no emos puesto prozesar a suya edizión porque os datos de sesión s'han trafegatos.</strong>
 
-''Como  {{SITENAME}} tiene l'HTML puro autibato, s'ha amagato l'ambiesta prebia ta aprebenir ataques en JavaScript.''
+''Como {{SITENAME}} tiene l'HTML puro autibato, s'ha amagato l'ambiesta prebia ta aprebenir ataques en JavaScript.''
 
-<strong>Si ye mirando d'editar lechitimament, por fabor, prebe una atra bez. Si encara no funzionase alabez, prebe-se de zarrar a sesión y i dentre identificando-se de nuebas.</strong>",
+<strong>Si ye mirando d'editar lechitimament, por fabor, prebe una atra bez. Si encara no funzionase alabez, prebe-se de [[Special:UserLogout|zarrar a sesión]] y dentrar-ie identificando-se de nuebas.</strong>",
 'token_suffix_mismatch'            => "<strong>S'ha refusato a suya edizión porque o suyo client ha esbarafundiato os caráuters de puntuazión en o editor. A edizión s'ha refusata ta pribar a corrompizión d'a pachina de testo. Isto gosa escaizer cuan se fa serbir un serbizio de proxy defeutuoso alazetato en a web.</strong>",
 'editing'                          => 'Editando $1',
 'editingsection'                   => 'Editando $1 (sezión)',
@@ -703,7 +699,7 @@
 'hiddencategories'                 => 'Ista pachina fa parte de {{PLURAL:$1|1 categoría amagata|$1 categorías amagatas}}:',
 'edittools'                        => "<!-- Iste testo amanixerá baxo os formularios d'edizión y carga. -->",
 'nocreatetitle'                    => "S'ha restrinchito a creyazión de pachinas",
-'nocreatetext'                     => '{{SITENAME}} ha restrinchito a creyazión de nuebas pachinas. Puede tornar entazaga y editar una pachina ya esistent, [[Special:Userlogin|identificarse u creyar una cuenta]].',
+'nocreatetext'                     => '{{SITENAME}} ha restrinchito a creyazión de nuebas pachinas. Puede tornar entazaga y editar una pachina ya esistent, [[Special:UserLogin|identificarse u creyar una cuenta]].',
 'nocreate-loggedin'                => 'No tiene premisos ta creyar nuebas pachinas en {{SITENAME}}.',
 'permissionserrors'                => 'Errors de premisos',
 'permissionserrorstext'            => 'No tiene premisos ta fer-lo, por {{PLURAL:$1|ista razón|istas razons}}:',
@@ -728,7 +724,7 @@
 'undo-success' => "A edizión puede esfer-se. Antis d'esfer a edizión, mire-se a siguient comparanza ta comprebar que ye ixo o que quiere fer reyalment. Alabez, puede alzar os cambeos ta esfer a edizión.",
 'undo-failure' => 'No se puede esfer a edizión pues un atro usuario ha feito una edizión intermeya.',
 'undo-norev'   => "No s'ha puesto esfer a edizión porque no esistiba u ya s'eba borrato.",
-'undo-summary' => 'Esfeita la edizión $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|desc.]])',
+'undo-summary' => 'Esfeita a edizión $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|desc.]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'No se puede creyar a cuenta',
@@ -750,7 +746,7 @@
 'currentrevisionlink' => 'Beyer bersión autual',
 'cur'                 => 'aut',
 'next'                => 'siguient',
-'last'                => 'zag',
+'last'                => 'ant',
 'page_first'          => 'primeras',
 'page_last'           => 'zagueras',
 'histlegend'          => 'Leyenda: (aut) = esferenzias con a bersión autual,
@@ -819,7 +815,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Rechistro de supresions',
-'suppressionlogtext' => "En o cobaxo bi ye una lista de borraus y bloqueyos referitos á contenius amagaus ta os almenistradors. Mire-se a [[Special:Ipblocklist|lista d'adrezas IP bloqueyatas]] ta beyer a lista de bloqueyos y bedas bichents.",
+'suppressionlogtext' => "En o cobaxo bi ye una lista de borraus y bloqueyos referitos á contenius amagaus ta os almenistradors. Mire-se a [[Special:IPBlockList|lista d'adrezas IP bloqueyatas]] ta beyer a lista de bloqueyos y bedas bichents.",
 
 # History merging
 'mergehistory'                     => 'Aunir istorials',
@@ -859,7 +855,7 @@
 # Search results
 'searchresults'             => 'Resultau de mirar',
 'searchresulttext'          => "Ta más informazión sobre cómo mirar pachinas en {{SITENAME}}, consulte l'[[{{MediaWiki:Helppage}}|{{int:help}}]].",
-'searchsubtitle'            => "Ha mirato '''[[:$1]]'''",
+'searchsubtitle'            => 'Ha mirato \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|todas as pachinas que prenzipian con "$1"]] | [[Special:WhatLinksHere/$1|todas as pachinas con binclos enta "$1"]])',
 'searchsubtitleinvalid'     => 'Ha mirato "$1"',
 'noexactmatch'              => "'''No esiste garra pachina tetulata \"\$1\".''' Puede aduyar [[:\$1|creyando-la]].",
 'noexactmatch-nocreate'     => "'''No bi ha garra pachina tetulata \"\$1\".'''",
@@ -902,7 +898,7 @@
 'mypreferences'            => 'Preferenzias',
 'prefs-edits'              => "Numero d'edizions:",
 'prefsnologin'             => 'No ye identificato',
-'prefsnologintext'         => "Ha d'estar [[Special:Userlogin|rechistrau]] y aber enzetau una sesión ta cambiar as preferenzias d'usuario.",
+'prefsnologintext'         => "Ha d'estar [[Special:UserLogin|rechistrau]] y aber enzetau una sesión ta cambiar as preferenzias d'usuario.",
 'prefsreset'               => "S'ha tornato as preferenzias t'as suyas baluras almadazenatas.",
 'qbsettings'               => 'Preferenzias de "Quickbar"',
 'qbsettings-none'          => 'Denguna',
@@ -976,7 +972,7 @@
 'userrights-reason'           => 'Razón ta o cambeo:',
 'userrights-no-interwiki'     => "No tiene premiso ta editar os dreitos d'usuario en atras wikis.",
 'userrights-nodatabase'       => 'A base de datos $1 no esiste u no ye local.',
-'userrights-nologin'          => "Ha d'[[Special:Userlogin|enzetar una sesión]] con una cuenta d'almenistrador ta poder dar dreitos d'usuario.",
+'userrights-nologin'          => "Ha d'[[Special:UserLogin|enzetar una sesión]] con una cuenta d'almenistrador ta poder dar dreitos d'usuario.",
 'userrights-notallowed'       => "A suya cuenta no tiene premisos ta dar dreitos d'usuario.",
 'userrights-changeable-col'   => 'Grupos que puede cambiar',
 'userrights-unchangeable-col' => 'Collas que no puede cambiar',
@@ -1105,27 +1101,23 @@
 'reupload'                    => 'Cargar un atra begada',
 'reuploaddesc'                => "Anular a carga y tornar ta o formulario de carga d'archibos.",
 'uploadnologin'               => 'No ha enzetato una sesión',
-'uploadnologintext'           => "Ha d'estar [[Special:Userlogin|rechistrau]] ta cargar archibos.",
+'uploadnologintext'           => "Ha d'estar [[Special:UserLogin|rechistrau]] ta cargar archibos.",
 'upload_directory_missing'    => 'O direutorio de carga ($1) no esiste y no lo puede creyar o serbidor web.',
 'upload_directory_read_only'  => "O serbidor web no puede escribir en o direutorio de carga d'archibos ($1).",
 'uploaderror'                 => "S'ha produzito una error en cargar l'archibo",
 'uploadtext'                  => "Faiga serbir o formulario d'o cobaxo ta cargar archibos.
-Ta beyer u mirar imáchens cargatas denantes baiga t'a [[Special:Imagelist|lista d'archibos cargatos]]. As cargas y borraus d'archibos tamién son rechistratos en o [[Special:Log/upload|rechistro de cargas]].
+Ta beyer u mirar imáchens cargatas denantes baiga t'a [[Special:ImageList|lista d'archibos cargatos]]. As cargas y recargas tamién se rechistran en o [[Special:Log/upload|rechistro de cargas]], y os borraus en o [[Special:Log/delete|rechistro de borraus]].
 
-Ta encluyir un archibo u imachen en una pachina, emplegue un binclo d'una d'istas trazas '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivo.jpg]]</nowiki>''', '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivo.png|testo alternatibo]]</nowiki>''' u
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Archivo.ogg]]</nowiki>''' ta fer o binclo dreitament ta l'archibo.
-
-
-To include a file in a page, use a link in the form
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''' or
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' for directly linking to the file.",
+Ta encluyir un archibo u imachen en una pachina, emplegue un binclo d'una d'istas trazas 
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archibo.jpg]]</nowiki></tt>''' ta usar a bersion completa de l'archibo, 
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archibo.png|200px|thumb|left|testo alternatibo]]</nowiki></tt>''' ta usar una bersión de 200 píxels d'amplaria en una caixa a la marguin cucha con 'testo alternatibo' como descripzión
+*'''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Archibo.ogg]]</nowiki></tt>''' ta fer un binclo dreitament ta l'archibo sin amostrar-lo.",
 'upload-permitted'            => "Tipos d'archibo premititos: $1.",
 'upload-preferred'            => "Tipos d'archibo preferitos: $1.",
 'upload-prohibited'           => "Tipos d'archibo biedatos: $1.",
 'uploadlog'                   => 'rechistro de cargas',
 'uploadlogpage'               => "Rechistro de cargas d'archibos",
-'uploadlogpagetext'           => "Contino ye una lista d'os zaguers archibos cargatos.",
+'uploadlogpagetext'           => "Contino ye una lista d'os zaguers archibos cargatos. Mire-se a [[Special:NewImages|galería d'archibos nuebos]] ta tener una ambiesta más bisual.",
 'filename'                    => "Nombre de l'archibo",
 'filedesc'                    => 'Resumen',
 'fileuploadsummary'           => 'Resumen:',
@@ -1135,13 +1127,13 @@
 'ignorewarning'               => "Inorar l'abiso y alzar l'archibo en cualsiquier caso",
 'ignorewarnings'              => 'Inorar cualsiquier abiso',
 'minlength1'                  => "Os nombres d'archibo han de tener á lo menos una letra.",
-'illegalfilename'             => "O nombre d'archivo «$1» contiene caráuters no premititos en títols de pachinas. Por fabor, cambee o nombre de l'archibo y mire de tornar á cargarlo.",
+'illegalfilename'             => "O nombre d'archibo «$1» tiene caráuters no premititos en títols de pachinas. Por fabor, cambee o nombre de l'archibo y mire de tornar á cargarlo.",
 'badfilename'                 => 'O nombre d\'a imachen s\'ha cambiato por "$1".',
 'filetype-badmime'            => 'No se premite cargar archibos de tipo MIME "$1".',
 'filetype-unwanted-type'      => "Os '''\".\$1\"''' son un tipo d'archibo no deseyato.  Se prefieren os archibos {{PLURAL:\$3|de tipo|d'os tipos}} \$2.",
 'filetype-banned-type'        => "No se premiten os archibos de tipo '''\".\$1\"'''. {{PLURAL:\$3|O tipo premitito ye|Os tipos premititos son}} \$2.",
 'filetype-missing'            => 'L\'archibo no tiene garra estensión (como ".jpg").',
-'large-file'                  => 'Se consella que os archibos no sigan mayors de $1; iste archbo este archivo ocupa $2.',
+'large-file'                  => 'Se consella que os archibos no sigan mayors de $1; iste archibo ocupa $2.',
 'largefileserver'             => "A grandaria d'iste archibo ye mayor d'a que a confegurazión d'iste serbidor premite.",
 'emptyfile'                   => "Parixe que l'archibo que se miraba de cargar ye buedo; por fabor, comprebe que ixe ye reyalment l'archibo que quereba cargar.",
 'fileexists'                  => "Ya bi ha un archibo con ixe nombre. Por fabor, Por favor mire-se l'archibo esistent <strong><tt>$1</tt></strong> si no ye seguro de querer sustituyir-lo.",
@@ -1153,8 +1145,9 @@
 'fileexists-thumb'            => "<center>'''Archibo esistent'''</center>",
 'fileexists-thumbnail-yes'    => "Parixe que l'archibo ye una imachen prou chicota <i>(miniatura)</i>. Comprebe por fabor l'archibo <strong><tt>$1</tt></strong>.<br />
 Si l'archibo comprebato ye a mesma imachen en tamaño orichinal no cal cargar una nueba miniatura.",
-'file-thumbnail-no'           => 'El nombre del archivo comienza con <strong><tt>$1</tt></strong>. Parece ser una imagen de tamaño reducido <i>(thumbnail)</i>.
-Si tienes esta imagen a toda resolución súbela, si no, por favor cambia el nombre del archivo.',
+'file-thumbnail-no'           => "O nombre de l'archibo prenzipia con <strong><tt>$1</tt></strong>. 
+Pareix que estase una imachen no guaire gran <i>(thumbnail)</i>.
+Si tiene ista imachen a toda resoluzión, cargue-la, si no, por fabor, cambee o nombre de l'archibo.",
 'fileexists-forbidden'        => "Ya bi ha un archibo con iste nombre. Por fabor, cambee o nombre de l'archibo y torne á cargar-lo. [[Image:$1|thumb|center|$1]]",
 'fileexists-shared-forbidden' => "Ya bi ha un archibo con ixe nombre en o repositorio compartito; por fabor, torne t'a pachina anterior y cargue o suyo archibo con atro nombre. [[Image:$1|thumb|center|$1]]",
 'file-exists-duplicate'       => "Iste archibo ye un duplicau {{PLURAL:$1|d'o siguient archibo|d'os siguients archibos}}:",
@@ -1168,7 +1161,7 @@
 'uploadscripted'              => 'Iste archibo contiene codigo de script u HTML que puede estar interpretado incorreutament por un nabegador.',
 'uploadcorrupt'               => "Iste archibo ye corrompito u tiene una estensión incorreuta. Por fabor, comprebe l'archibo y cargue-lo una atra begada.",
 'uploadvirus'                 => 'Iste archibo tiene un birus! Detalles: $1',
-'sourcefilename'              => "Nombre de l'archivo d'orichen:",
+'sourcefilename'              => "Nombre de l'archibo d'orichen:",
 'destfilename'                => "Nombre de l'archibo de destín:",
 'upload-maxfilesize'          => "Masima grandaria de l'archibo: $1",
 'watchthisupload'             => 'Cosirar ista pachina',
@@ -1195,9 +1188,9 @@
 'upload-proto-error'      => 'Protocolo incorreuto',
 'upload-proto-error-text' => 'Si quiere cargar archibos dende atra pachina, a URL ha de prenzipiar por <code>http://</code> u <code>ftp://</code>.',
 'upload-file-error'       => 'Error interna',
-'upload-file-error-text'  => "Ha escaizito una error interna entre que se prebaba de creyar un archibo temporal en o serbidor. Por fabor, contaute con un almenistrador d'o sistema.",
+'upload-file-error-text'  => "Ha escaizito una error interna entre que se prebaba de creyar un archibo temporal en o serbidor. Por fabor, contaute con un [[Special:ListUsers/sysop|almenistrador]] d'o sistema.",
 'upload-misc-error'       => 'Error esconoixita en a carga',
-'upload-misc-error-text'  => "Ha escaizito una error mientres a carga de l'archibo. Por fabor, comprebe que a URL ye conforme y aczesible y dimpués prebe de fer-lo una atra begada. Si o problema contina, contaute con un almenistrador d'o sistema.",
+'upload-misc-error-text'  => "Ha escaizito una error entre que se cargaba l'archibo. Por fabor, comprebe que a URL ye conforme y aczesible y dimpués prebe de fer-lo una atra begada. Si o problema contina, contaute con un [[Special:ListUsers/sysop|almenistrador]] d'o sistema.",
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'No se podió aczeder dica la URL',
@@ -1211,7 +1204,7 @@
 'upload_source_url'  => ' (una URL conforme y publicament aczesible)',
 'upload_source_file' => ' (un archibo en o suyo ordenador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Ista pachina espezial amuestra toz os archibos cargatos.
 Por defeuto os zaguers archibos cargatos s'amuestran en o cobalto d'a lista.
 Fendo click en un encabezau de colunna se cambia o criterio d'ordenazión.",
@@ -1239,7 +1232,7 @@
 'imagelinks'                     => 'Binclos ta la imachen',
 'linkstoimage'                   => "{{PLURAL:$1|A pachina siguient tiene|Contino s'amuestran $1 pachinas que tienen}} binclos ta iste archibo:",
 'nolinkstoimage'                 => 'Denguna pachina tiene un binclo ta ista imachen.',
-'morelinkstoimage'               => 'Amostrar [[Special:Whatlinkshere/$1|más binclos]] ta iste archibo.',
+'morelinkstoimage'               => 'Amostrar [[Special:WhatLinksHere/$1|más binclos]] ta iste archibo.',
 'redirectstofile'                => '{{PLURAL:$1|O siguient archibo reendreza|Os siguients $1 archibos reendrezan}} enta iste archibo:',
 'duplicatesoffile'               => "{{PLURAL:$1|O siguient archibo ye un duplicau|Os siguients $1 archibos son duplicaus}} d'iste archibo:",
 'sharedupload'                   => 'Iste archibo ye compartito y puede estar que siga emplegato en atros procheutos.',
@@ -1258,18 +1251,18 @@
 # File reversion
 'filerevert'                => 'Rebertir $1',
 'filerevert-legend'         => 'Rebertir fichero',
-'filerevert-intro'          => '<span class="plainlinks">Ye rebertindo \'\'\'[[Media:$1|$1]]\'\'\' á la [$4 bersion de $3, $2].</span>',
+'filerevert-intro'          => "Ye rebertindo '''[[Media:$1|$1]]''' á la [$4 bersion de $3, $2].",
 'filerevert-comment'        => 'Comentario:',
 'filerevert-defaultcomment' => 'Rebertito á la bersión de $2, $1',
 'filerevert-submit'         => 'Rebertir',
-'filerevert-success'        => '<span class="plainlinks">S\'ha rebertito \'\'\'[[Media:$1|$1]]\'\'\' á la [$4 bersión de $3, $2].</span>',
+'filerevert-success'        => "S'ha rebertito '''[[Media:$1|$1]]''' á la [$4 bersión de $3, $2].",
 'filerevert-badversion'     => "No bi ha garra bersión antiga d'o archibo con ixa calendata y ora.",
 
 # File deletion
 'filedelete'                  => 'Borrar $1',
 'filedelete-legend'           => 'Borrar archibo',
 'filedelete-intro'            => "Ye borrando '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Ye borrando a bersión de \'\'\'[[Media:$1|$1]]\'\'\' de [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Ye borrando a bersión de '''[[Media:$1|$1]]''' de [$4 $3, $2].",
 'filedelete-comment'          => 'Causa:',
 'filedelete-submit'           => 'Borrar',
 'filedelete-success'          => "S'ha borrato '''$1'''.",
@@ -1311,13 +1304,13 @@
 
 # Statistics
 'statistics'             => 'Estadisticas',
-'sitestats'              => "Estadisticas d'a {{SITENAME}}",
+'sitestats'              => 'Estadisticas de {{SITENAME}}',
 'userstats'              => "Estadisticas d'usuario",
 'sitestatstext'          => "Bi ha un total de {{PLURAL:$1|'''1''' pachina|'''$1''' pachinas}} en a base de datos.
 Isto encluye pachinas de descusión, pachinas sobre {{SITENAME}}, borradors menimos, reendrezeras y atras que cal que no puedan estar consideratas pachinas de contenius.
 Sacando ixas pachinas, regular que bi aiga {{PLURAL:$2|1 pachina|'''$2''' pachinas}} de conteniu lechitimo.
 
-Bi ha '''$8''' {{PLURAL:$8|archibo alzato|archivos alzatos}} en o serbidor.
+Bi ha '''$8''' {{PLURAL:$8|archibo alzato|archibos alzatos}} en o serbidor.
 
 Dende a debantadera d'o wiki bi ha abito un total de '''$3''' {{PLURAL:$3|besitas|besitas}} y '''$4''' {{PLURAL:$4|edizión de pachina|edizions de pachinas}}.
 Isto resulta en una meya de '''$5''' {{PLURAL:$5|edizión|edizions}} por pachina y '''$6''' {{PLURAL:$6|besita|besitas}} por edizión.
@@ -1333,8 +1326,10 @@
 Ixos binclos abrían de ir millor t'a pachina espezifica apropiada.<br />
 Una pachina se considera pachina de desambigazión si fa serbir una plantilla probenient de  [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Reendrezeras dobles',
-'doubleredirectstext' => "En ista pachina s'amuestran as pachinas que son reendrezatas enta atras reendrezeras.  Cada ringlera contiene o binclo t'a primer y segunda reendrezeras, y tamién o destino d'a segunda reendrezera, que ye á sobent a pachina \"reyal\" á la que a primer pachina abría d'endrezar.",
+'doubleredirects'            => 'Reendrezeras dobles',
+'doubleredirectstext'        => "En ista pachina s'amuestran as pachinas que son reendrezatas enta atras reendrezeras.  Cada ringlera contiene o binclo t'a primer y segunda reendrezeras, y tamién o destino d'a segunda reendrezera, que ye á sobent a pachina \"reyal\" á la que a primer pachina abría d'endrezar.",
+'double-redirect-fixed-move' => "S'ha tresladau [[$1]], agora ye una endrezera ta [[$2]]",
+'double-redirect-fixer'      => 'Apañador de reendrezeras',
 
 'brokenredirects'        => 'Reendrezeras crebatas',
 'brokenredirectstext'    => 'As siguients reendrezeras leban enta pachinas inesistents.',
@@ -1357,7 +1352,7 @@
 'nviews'                  => '$1 {{PLURAL:$1|besita|besitas}}',
 'specialpage-empty'       => 'Ista pachina ye bueda.',
 'lonelypages'             => 'Pachinas popiellas',
-'lonelypagestext'         => "Garra pachina de {{SITENAME}} wiki tiene binclos t'as pachinas que se listan contino.",
+'lonelypagestext'         => "Garra pachina de {{SITENAME}} tiene binclos t'as pachinas que se listan contino.",
 'uncategorizedpages'      => 'Pachinas sin categorizar',
 'uncategorizedcategories' => 'Categorías sin categorizar',
 'uncategorizedimages'     => 'Archibos sin categorizar',
@@ -1420,7 +1415,7 @@
 'logempty'             => 'No bi ha garra elemento en o rechistro con ixas carauteristicas.',
 'log-title-wildcard'   => 'Mirar títols que prenzipien con iste testo',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Todas as pachinas',
 'alphaindexline'    => '$1 á $2',
 'nextpage'          => 'Siguient pachina ($1)',
@@ -1443,14 +1438,14 @@
 'special-categories-sort-count' => 'ordenar por recuento',
 'special-categories-sort-abc'   => 'ordenar alfabeticament',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Amostrar usuarios que o nombre suyo prenzipie por:',
 'listusers-submit'   => 'Amostrar',
 'listusers-noresult' => "No s'ha trobato ixe usuario.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Dreitos d'a colla d'usuarios",
-'listgrouprights-summary'  => "Contino bi ye una lista de collas d'usuario definitas en iste wiki, con os suyos dreitos d'aczeso asoziatos. [[{{MediaWiki:Listgrouprights-helppage}}|Aquí]] puede trobar informazión adizional sobre os dreitos indibiduals.",
+'listgrouprights-summary'  => "Contino bi ye una lista de collas d'usuario definitas en iste wiki, con os suyos dreitos d'aczeso asoziatos. Tamién puet trobar aquí [[{{MediaWiki:Listgrouprights-helppage}}|informazión adizional]] sobre os dreitos indibiduals.",
 'listgrouprights-group'    => 'Colla',
 'listgrouprights-rights'   => 'Dreitos',
 'listgrouprights-helppage' => "Help:Dreitos d'a colla",
@@ -1458,11 +1453,11 @@
 
 # E-mail user
 'mailnologin'     => "No nimbiar l'adreza",
-'mailnologintext' => "Ha d'aber [[Special:Userlogin|enzetato una sesión]] y tener una adreza de correu-e conforme en as suyas [[Special:Preferences|preferenzias]] ta nimbiar un correu eletronico ta atros usuarios.",
+'mailnologintext' => "Ha d'aber [[Special:UserLogin|enzetato una sesión]] y tener una adreza de correu-e conforme en as suyas [[Special:Preferences|preferenzias]] ta nimbiar un correu eletronico ta atros usuarios.",
 'emailuser'       => 'Nimbiar un correu electronico ta iste usuario',
 'emailpage'       => "Nimbiar correu ta l'usuario",
-'emailpagetext'   => "Si iste usuario ese rechistrato una adreza de correu-e conforme en as suyas preferenzias d'usuario, iste formulario sirbe ta nimbiar-le un mensache.
-L'adreza de correu-e que endicó en as suyas preferenzias d'usuario amanixerá en o campo 'remitent' ta que o destinatario pueda responder-le.",
+'emailpagetext'   => "Si iste usuario ese rechistrato una adreza de correu-e conforme en as suyas preferenzias d'usuario, puede nimbiar-le un mensache con iste formulario.
+L'adreza de correu-e que endicó en as suyas [[Special:Preferences|preferenzias d'usuario]] amaneixerá en o campo 'remitent' ta que o destinatario pueda responder-le.",
 'usermailererror' => "L'ocheto de correu retornó una error:",
 'defemailsubject' => 'Correu de {{SITENAME}}',
 'noemailtitle'    => 'No bi ha garra adreza de correu eletronico',
@@ -1476,7 +1471,7 @@
 'emailccsubject'  => "Copia d'o suyo mensache ta $1: $2",
 'emailsent'       => 'Mensache de correu nimbiato',
 'emailsenttext'   => "S'ha nimbiato o suyo correu.",
-'emailuserfooter' => 'Iste correu-e s\'ha nimbiato por $1 ta $2 fendo serbir a funzion "Email user" de {{SITENAME}}.',
+'emailuserfooter' => 'Iste correu-e s\'ha nimbiato por $1 ta $2 fendo serbir a funzión "Email user" de {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Lista de seguimiento',
@@ -1485,9 +1480,9 @@
 'nowatchlist'          => 'No tiens denguna pachina en a lista de seguimiento.',
 'watchlistanontext'    => "Ha de $1 ta beyer u editar as dentradas d'a suya lista de seguimiento.",
 'watchnologin'         => 'No ha enzetato a sesión',
-'watchnologintext'     => "Ha d'estar [[Special:Userlogin|identificato]] ta poder cambiar a suya lista de seguimiento.",
+'watchnologintext'     => "Ha d'estar [[Special:UserLogin|identificato]] ta poder cambiar a suya lista de seguimiento.",
 'addedwatch'           => 'Adibiu á la suya lista de seguimiento',
-'addedwatchtext'       => "A pachina «[[:\$1]]» s'ha adibito t'a suya [[Special:Watchlist|lista de seguimiento]]. Os cambios esdebenideros en ista pachina y en a suya pachina de descusión asoziata s'endicarán astí, y a pachina amanixerá '''en negreta''' en a [[Special:Recentchanges|lista de cambeos rezients]] ta que se beiga millor. <p>Si nunca quiere borrar a pachina d'a suya lista de seguimiento, punche \"Deixar de cosirar\" en o menú.",
+'addedwatchtext'       => "A pachina «[[:\$1]]» s'ha adibito t'a suya [[Special:Watchlist|lista de seguimiento]]. Os cambios esdebenideros en ista pachina y en a suya pachina de descusión asoziata s'endicarán astí, y a pachina amanixerá '''en negreta''' en a [[Special:RecentChanges|lista de cambeos rezients]] ta que se beiga millor. <p>Si nunca quiere borrar a pachina d'a suya lista de seguimiento, punche \"Deixar de cosirar\" en o menú.",
 'removedwatch'         => "Borrata d'a lista de seguimiento",
 'removedwatchtext'     => 'A pachina "[[:$1]]" ha estato borrata d\'a suya lista de seguimiento.',
 'watch'                => 'Cosirar',
@@ -1583,14 +1578,16 @@
 ** trencadura de copyright
 ** Bandalismo",
 'delete-edit-reasonlist'      => "Editar as razons d'o borrau",
-'delete-toobig'               => "Ista pachina tiene un istorial d'edizión prou largo, con más de $1 {{PLURAL:$1|bersions|bersions}}. S'ha restrinchito o borrau d'ista mena de pachinas ta aprebenir d'a corrompizión azidental de {{SITENAME}}.",
-'delete-warning-toobig'       => "Ista pachina tiene un istorial d'edizión prou largo, con más de $1 {{PLURAL:$1|bersions|bersions}}. Si la borra puede corromper as operazions d'a base de datos de {{SITENAME}}; contine con ficazio.",
+'delete-toobig'               => "Ista pachina tiene un istorial d'edizión prou largo, con más de $1 {{PLURAL:$1|bersión|bersions}}. S'ha restrinchito o borrau d'ista mena de pachinas ta aprebenir d'a corrompizión azidental de {{SITENAME}}.",
+'delete-warning-toobig'       => "Ista pachina tiene un istorial d'edizión prou largo, con más de $1 {{PLURAL:$1|bersión|bersions}}. Si la borra puede corromper as operazions d'a base de datos de {{SITENAME}}; contine con ficazio.",
 'rollback'                    => 'Esfer edizions',
 'rollback_short'              => 'Esfer',
 'rollbacklink'                => 'Esfer',
 'rollbackfailed'              => "No s'ha puesto esfer",
 'cantrollback'                => "No se pueden esfer as edizions; o zaguer colaborador ye o unico autor d'iste articlo.",
-'alreadyrolled'               => 'No se puede esfer a zaguer edizión de [[$1]] por [[User:$2|$2]] ([[User talk:$2|descusión]]); belatro usuario ya ha editato u esfeito una edizión en ixa pachina. A zaguer edizión estió feita por [[User:$3|$3]] ([[User talk:$3|descusión]]).',
+'alreadyrolled'               => 'No se puede esfer a zaguer edizión de [[$1]] por [[User:$2|$2]] ([[User talk:$2|descusión]])|[[Special:Contributions/$2|{{int:contribslink}}]]); belatro usuario ya ha editato u esfeito una edizión en ixa pachina. 
+
+A zaguer edizión la fazió [[User:$3|$3]] ([[User talk:$3|descusión]]).',
 'editcomment'                 => 'O comentario d\'a edizión ye: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => "S'han esfeitas as edizions de [[Special:Contributions/$2|$2]] ([[User talk:$2|Descusión]]); retornando t'a zaguera bersión editada por [[User:$1|$1]]", # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => "Esfeitas as edizions de $1; s'ha retornato á la zaguer bersión de $2.",
@@ -1598,7 +1595,7 @@
 s\'ha anulato ista aizión como mida de precura contra secuestros de sesión.
 Por fabor, prete "Entazaga", recargue a pachina d\'a que benió, y torne á prebar alabez.',
 'protectlogpage'              => 'Protezions de pachinas',
-'protectlogtext'              => 'Contino se i amuestra una lista de protezions y esprotezions de pachinas. Se beiga [[Special:Protectedpages|lista de pachinas protechitas]] ta más informazión.',
+'protectlogtext'              => 'Contino se i amuestra una lista de protezions y esprotezions de pachinas. Se beiga [[Special:ProtectedPages|lista de pachinas protechitas]] ta más informazión.',
 'protectedarticle'            => "s'ha protechito [[$1]]",
 'modifiedarticleprotection'   => 's\'ha cambiato o libel de protezión de "[[$1]]"',
 'unprotectedarticle'          => "s'ha esprotechito [[$1]]",
@@ -1757,7 +1754,7 @@
 'ipbwatchuser'                    => "Cosirar as pachinas d'usuario y de descusión d'iste usuario",
 'badipaddress'                    => "L'adreza IP no ye conforme.",
 'blockipsuccesssub'               => "O bloqueyo s'ha feito correutament",
-'blockipsuccesstext'              => "L'adreza IP [[Special:Contributions/$1|$1]] ye bloqueyata. <br />Ir t'a [[Special:Ipblocklist|lista d'adrezas IP bloqueyatas]] ta beyer os bloqueyos.",
+'blockipsuccesstext'              => "L'adreza IP [[Special:Contributions/$1|$1]] ye bloqueyata. <br />Ir t'a [[Special:IPBlockList|lista d'adrezas IP bloqueyatas]] ta beyer os bloqueyos.",
 'ipb-edit-dropdown'               => "Editar as razons d'o bloqueyo",
 'ipb-unblock-addr'                => 'Esbloqueyar $1',
 'ipb-unblock'                     => 'Esbloqueyar un usuario u una IP',
@@ -1787,7 +1784,7 @@
 'autoblocker'                     => 'Ye bloqueyato automaticament porque a suya adreza IP l\'ha feito serbir rezientement "[[User:$1|$1]]". A razón data ta bloqueyar á "[[User:$1|$1]]" estió "$2".',
 'blocklogpage'                    => 'Rechistro de bloqueyos',
 'blocklogentry'                   => "S'ha bloqueyato á [[$1]] con una durada de $2 $3",
-'blocklogtext'                    => "Isto ye un rechistro de bloqueyos y esbloqueyos d'usuarios. As adrezas bloqueyatas automaticament no amaneixen aquí. Mire-se a [[Special:Ipblocklist|lista d'adrezas IP bloqueyatas]] ta beyer a lista autual de biedas y bloqueyos.",
+'blocklogtext'                    => "Isto ye un rechistro de bloqueyos y esbloqueyos d'usuarios. As adrezas bloqueyatas automaticament no amaneixen aquí. Mire-se a [[Special:IPBlockList|lista d'adrezas IP bloqueyatas]] ta beyer a lista autual de biedas y bloqueyos.",
 'unblocklogentry'                 => 'ha esbloqueyato á "$1"',
 'block-log-flags-anononly'        => 'nomás os usuarios anonimos',
 'block-log-flags-nocreate'        => "s'ha desautibato a creyazión de cuentas",
@@ -1822,7 +1819,7 @@
 'lockdbsuccesssub'    => "A base de datos s'ha trancato correutament",
 'unlockdbsuccesssub'  => "A base de datos s'ha estrancato correutament",
 'lockdbsuccesstext'   => "Ha trancato a base de datos de {{SITENAME}}.
-Alcuerde-se-ne d'[[Special:Unlockdb|estrancar a base de datos]] dimpués de rematar as fayenas de mantenimiento.",
+Alcuerde-se-ne d'[[Special:UnlockDB|estrancar a base de datos]] dimpués de rematar as fayenas de mantenimiento.",
 'unlockdbsuccesstext' => "S'ha estrancato a base de datos de {{SITENAME}}.",
 'lockfilenotwritable' => "O rechistro de trancamientos d'a base de datos no tiene premiso d'escritura. Ta trancar u estrancar a base de datos, iste archibo ha de tener premisos d'escritura en o serbidor web.",
 'databasenotlocked'   => 'A base de datos no ye trancata.',
@@ -1830,10 +1827,10 @@
 # Move page
 'move-page'               => 'Tresladar $1',
 'move-page-legend'        => 'Tresladar pachina',
-'movepagetext'            => "Si fa serbir o formulario siguient se cambiará o nombre á la pachina, tresladando tot o suyo istorial t'o nuebo nombre.
+'movepagetext'            => "Fendo serbir o formulario siguient se cambiará o nombre d'a pachina, tresladando tot o suyo istorial t'o nuebo nombre.
 O títol anterior se tornará en una reendrezera ta o nuebo títol.
-Os binclos ta o títol antigo d'a pachina no se cambiarán.
-Asegure-se de no deixar reendrezeras dobles u crebatas.
+Puede esbiellar automaticament as reendrezeras que plegan ta o títol orichina.
+Si s'estima más de no fer-lo, asegure-se de no deixar [[Special:DoubleRedirects|reendrezeras dobles]] u [[Special:BrokenRedirects|crebatas]].
 Ye a suya responsabilidat d'asegurar-se que os binclos continan endrezando t'an que abrían de fer-lo.
 
 Remere que a pachina '''no''' se renombrará si ya esiste una pachina con o nuebo títol, si no ye que estase una pachina bueda u una ''reendrezera'' sin istorial.
@@ -1849,8 +1846,6 @@
 
 En ixos casos, si lo deseya, abrá de tresladar u combinar manualment o conteniu d'a pachina de descusión.",
 'movearticle'             => 'Tresladar pachina:',
-'movenologin'             => 'No ha enzetato sesión',
-'movenologintext'         => 'Amenista estar un usuario rechistrato y [[Special:Userlogin|aber-se identificato enzetando una sesión]] ta tresladar una pachina.',
 'movenotallowed'          => 'No tiene premisos ta tresladar pachinas en {{SITENAME}}.',
 'newtitle'                => 'Ta o nuebo títol',
 'move-watch'              => 'Cosirar iste articlo',
@@ -1877,7 +1872,7 @@
 'delete_and_move'         => 'Borrar y tresladar',
 'delete_and_move_text'    => '==S\'amenista borrar a pachina==
 
-A pachina de destino ("[[$1]]") ya esiste. Quiere borrar-la ta premitir o treslau?',
+A pachina de destino ("[[:$1]]") ya esiste. Quiere borrar-la ta premitir o treslau?',
 'delete_and_move_confirm' => 'Sí, borrar a pachina',
 'delete_and_move_reason'  => 'Borrata ta premitir o treslau',
 'selfmove'                => "Os títols d'orichen y destino son os mesmos. No se puede tresladar una pachina ta ella mesma.",
@@ -1885,6 +1880,7 @@
 'imagenocrossnamespace'   => "No se puede tresladar un archibo ta un espazio de nombres que no sía t'archibos",
 'imagetypemismatch'       => "A nueba estensión no concuerda con o tipo d'archibo",
 'imageinvalidfilename'    => "O nombre de l'archibo obchetibo no ye conforme",
+'fix-double-redirects'    => 'Esbiellar todas as reendrezeras que plegan ta o títol orichinal',
 
 # Export
 'export'            => 'Esportar as pachinas',
@@ -1931,7 +1927,7 @@
 'import-interwiki-history'   => "Copiar todas as bersions de l'istorial d'ista pachina",
 'import-interwiki-submit'    => 'Importar',
 'import-interwiki-namespace' => "Transferir pachinas t'o espazio de nombres:",
-'importtext'                 => "Por fabor, esporte l'archibo dende o wiki d'orichen fendo serbir a ferramienta Special:Export, alze-lo en o suyo ordenador y cargue-lo aquí.",
+'importtext'                 => "Por fabor, esporte l'archibo dende o wiki d'orichen fendo serbir a [[Special:Export|ferramienta d'esportazión]]. Alze-lo en o suyo ordenador y cargue-lo aquí.",
 'importstart'                => 'Importando pachinas...',
 'import-revision-count'      => '$1 {{PLURAL:$1|bersión|bersions}}',
 'importnopages'              => 'No bi ha garra pachina ta importar.',
@@ -2073,9 +2069,10 @@
 'markedaspatrollederror-noautopatrol' => 'No tiene premisos ta siñalar os suyos propios cambios como controlatos.',
 
 # Patrol log
-'patrol-log-page' => 'Rechistro de control de bersions',
-'patrol-log-line' => "s'ha siñalato a bersión $1 de $2 como controlata $3",
-'patrol-log-auto' => '(automatico)',
+'patrol-log-page'   => 'Rechistro de control de bersions',
+'patrol-log-header' => 'Iste ye un rechistro de rebisions patrullatas.',
+'patrol-log-line'   => "s'ha siñalato a bersión $1 de $2 como controlata $3",
+'patrol-log-auto'   => '(automatico)',
 
 # Image deletion
 'deletedrevision'                 => "S'ha borrato a bersión antiga $1",
@@ -2098,16 +2095,16 @@
 'thumbsize'            => "Midas d'a miniatura:",
 'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|pachina|pachinas}}',
 'file-info'            => "(grandaria de l'archibo: $1; tipo MIME: $2)",
-'file-info-size'       => "($1 × $2 píxels; grandaria de l'archivo: $3; tipo MIME: $4)",
+'file-info-size'       => "($1 × $2 píxels; grandaria de l'archibo: $3; tipo MIME: $4)",
 'file-nohires'         => '<small>No bi ha garra bersión con mayor resoluzión.</small>',
 'svg-long-desc'        => '(archibo SVG, nominalment $1 × $2 píxels, grandaria: $3)',
 'show-big-image'       => 'Imachen en a maisima resoluzión',
 'show-big-image-thumb' => "<small>Grandaria d'ista ambiesta prebia: $1 × $2 píxels</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galería de nuebas imachens',
 'imagelisttext'         => "Contino bi ha una lista de '''$1''' {{PLURAL:$1|imachen ordenata|imachens ordenatas}} $2.",
-'newimages-summary'     => 'Ista pachina espezial amuestra os zaguers archibos cargatos',
+'newimages-summary'     => 'Ista pachina espezial amuestra os zaguers archibos cargatos.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'No bi ha cosa á beyer.',
 'ilsubmit'              => 'Mirar',
@@ -2385,7 +2382,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar iste archibo fendo serbir una aplicazión esterna',
-'edit-externally-help' => 'Leiga as [http://meta.wikimedia.org/wiki/Help:External_editors instruzions de confegurazión] (en anglés) ta más informazión.',
+'edit-externally-help' => 'Leiga as [http://www.mediawiki.org/wiki/Manual:External_editors instruzions de confegurazión] (en anglés) ta más informazión.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'toz',
@@ -2450,7 +2447,7 @@
 'recreate'            => 'Creyar nuebament',
 
 # HTML dump
-'redirectingto' => 'Reendrezando ta [[$1]]...',
+'redirectingto' => 'Reendrezando ta [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Limpiar a caché d'ista pachina?
@@ -2496,8 +2493,8 @@
 'livepreview-error'   => 'No s\'ha puesto coneutar: $1 "$2". Prebe con l\'ambiesta prebia normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => "Talment no s'amuestren en ista lista as edizions feitas en os zaguers $1 segundos.",
-'lag-warn-high'   => "Por o retardo d'o serbido d'a base de datos, talment no s'amuestren en ista lista as edizions feitas en os zaguers $1 segundos.",
+'lag-warn-normal' => "Talment no s'amuestren en ista lista as edizions feitas en {{PLURAL:$1|o zaguer segundo|os zaguers $1 segundos}}.",
+'lag-warn-high'   => "Por o retardo d'o serbidor d'a base de datos, talment no s'amuestren en ista lista as edizions feitas en {{PLURAL:$1|o zaguer segundo|os zaguers $1 segundos}}.",
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'A suya lista de seguimiento tiene {{PLURAL:$1|una pachina |$1 pachinas}}, sin contar-ie as pachinas de descusión.',
@@ -2548,7 +2545,7 @@
 'version-software-product'         => 'Produto',
 'version-software-version'         => 'Bersión',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => "Camín de l'archibo",
 'filepath-page'    => 'Archibo:',
 'filepath-submit'  => 'Camín',
@@ -2587,7 +2584,7 @@
 'specialpages-group-redirects'   => 'Reendrezando as pachinas espezials',
 'specialpages-group-spam'        => 'Ainas de spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pachina en blanco',
 'intentionallyblankpage' => "Esta pachina s'ha deixato en blanco aldredes y se fa serbir ta fer prebatinas, ezt.",
 
Index: languages/messages/MessagesMwl.php
===================================================================
--- languages/messages/MessagesMwl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMwl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author MCruz
- * @author Siebrand
  * @author Malafaya
  */
 
@@ -253,7 +252,7 @@
 'template-protected'     => '(protegida)',
 'template-semiprotected' => '(semi-protegida)',
 'nocreatetext'           => '{{SITENAME}} tem restringida la possibilidade de criar nuobas páginas.
-Pode boltar atrás i editar unha página yá eisistente, o [[Special:Userlogin|autenticar-se o criar unha cuonta]].',
+Pode boltar atrás i editar unha página yá eisistente, o [[Special:UserLogin|autenticar-se o criar unha cuonta]].',
 'recreate-deleted-warn'  => "'''Atenção: Você está a criar uma página já anteriormente eliminada.'''
 
 Certifique-se de que é adequado prosseguir a edição de esta página.
@@ -338,7 +337,7 @@
 'uploadlogpage' => 'Registo de carregamento',
 'uploadedimage' => 'carregou "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Lista de ficheiros',
 
 # Image description page
@@ -423,7 +422,7 @@
 'log'                  => 'Registos',
 'all-logs-page'        => 'Todos os registos',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Todas las páginas',
 'alphaindexline' => '$1 a $2',
 'nextpage'       => 'Próxima página ($1)',
@@ -615,7 +614,7 @@
 'show-big-image'       => 'Resoluçon completa',
 'show-big-image-thumb' => '<small>Tamanho desta previsão: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Galeria de nuobos ficheiros',
 
 # Bad image list
@@ -640,7 +639,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar yeste ficheiro outelizando ua aplicaçon externa',
-'edit-externally-help' => 'Consulte as [http://meta.wikimedia.org/wiki/Help:External_editors instruções de instalação] para mais informação.',
+'edit-externally-help' => 'Consulte as [http://www.mediawiki.org/wiki/Manual:External_editors instruções de instalação] para mais informação.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'todas',
Index: languages/messages/MessagesAr.php
===================================================================
--- languages/messages/MessagesAr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,24 +4,21 @@
  * @ingroup Language
  * @file
  *
+ * @author Agurzil
+ * @author Alnokta
+ * @author Chaos
+ * @author Gharbeia
+ * @author Jak
+ * @author Khaledhosny
  * @author Meno25
  * @author Mido
- * @author Alnokta
+ * @author Mimouni
  * @author OsamaK
- * @author Siebrand
- * @author Gharbeia
- * @author ترجمان05
+ * @author Oxydo
  * @author Tarawneh
- * @author Khaledhosny
- * @author Mimouni
- * @author Agurzil
  * @author לערי ריינהארט
- * @author Jon Harald Søby
- * @author Chaos
- * @author SPQRobin
- * @author Jak
+ * @author ترجمان05
  * @author عصام بايزيدي
- * @author Oxydo
  */
 
 $linkPrefixExtension = true;
@@ -166,7 +163,7 @@
 	'talkspace'           => array( '1', 'نطاق_النقاش', 'نطاق_نقاش', 'TALKSPACE' ),
 	'talkspacee'          => array( '1', 'عنوان_النقاش', 'عنوان_نقاش', 'TALKSPACEE' ),
 	'subjectspace'        => array( '1', 'نطاق_الموضوع', 'نطاق_المقالة', 'SUBJECTSPACE', 'ARTICLESPACE' ),
-	'subjectspacee'       => array( '1', 'عنوان_نطاق_الموضوع', 'عنوان_نطاق_المقالة SUBJECTSPACEE', 'ARTICLESPACEE' ),
+	'subjectspacee'       => array( '1', 'عنوان_نطاق_الموضوع', 'عنوان_نطاق_المقالة', 'SUBJECTSPACEE', 'ARTICLESPACEE' ),
 	'fullpagename'        => array( '1', 'اسم_الصفحة_الكامل', 'اسم_صفحة_كامل', 'اسم_كامل', 'FULLPAGENAME' ),
 	'fullpagenamee'       => array( '1', 'عنوان_الصفحة_الكامل', 'عنوان_صفحة_كامل', 'عنوان_كامل', 'FULLPAGENAMEE' ),
 	'subpagename'         => array( '1', 'اسم_الصفحة_الفرعي', 'اسم_صفحة_فرعي', 'SUBPAGENAME' ),
@@ -176,7 +173,7 @@
 	'talkpagename'        => array( '1', 'اسم_صفحة_النقاش', 'اسم_صفحة_نقاش', 'TALKPAGENAME' ),
 	'talkpagenamee'       => array( '1', 'عنوان_صفحة_النقاش', 'عنوان_صفحة_نقاش', 'TALKPAGENAMEE' ),
 	'subjectpagename'     => array( '1', 'اسم_صفحة_الموضوع', 'اسم_صفحة_المقالة', 'SUBJECTPAGENAME', 'ARTICLEPAGENAME' ),
-	'subjectpagenamee'    => array( '1', 'عنوان_صفحة_الموضوع', 'عنوان_صفحة_المقالة SUBJECTPAGENAMEE', 'ARTICLEPAGENAMEE' ),
+	'subjectpagenamee'    => array( '1', 'عنوان_صفحة_الموضوع', 'عنوان_صفحة_المقالة', 'SUBJECTPAGENAMEE', 'ARTICLEPAGENAMEE' ),
 	'msg'                 => array( '0', 'رسالة:', 'MSG:' ),
 	'subst'               => array( '0', 'نسخ:', 'إحلال:', 'SUBST:' ),
 	'msgnw'               => array( '0', 'مصدر:', 'مصدر_قالب:', 'MSGNW:' ),
@@ -185,7 +182,7 @@
 	'img_right'           => array( '1', 'يمين', 'right' ),
 	'img_left'            => array( '1', 'يسار', 'left' ),
 	'img_none'            => array( '1', 'بدون', 'بلا', 'none' ),
-	'img_width'           => array( '1', '$1بك', '$1px' ),
+	'img_width'           => array( '1', '$1بك', '$1عن', '$1px' ),
 	'img_center'          => array( '1', 'مركز', 'center', 'centre' ),
 	'img_framed'          => array( '1', 'إطار', 'framed', 'enframed', 'frame' ),
 	'img_frameless'       => array( '1', 'لاإطار', 'frameless' ),
@@ -208,7 +205,7 @@
 	'server'              => array( '0', 'خادم', 'SERVER' ),
 	'servername'          => array( '0', 'اسم_الخادم', 'اسم_خادم', 'SERVERNAME' ),
 	'scriptpath'          => array( '0', 'مسار_السكريبت', 'مسار_سكريبت', 'SCRIPTPATH' ),
-	'grammar'             => array( '0', 'قواعد_اللغة:', 'قواعد_لغة: GRAMMAR:' ),
+	'grammar'             => array( '0', 'قواعد_اللغة:', 'قواعد_لغة:', 'GRAMMAR:' ),
 	'notitleconvert'      => array( '0', '__لاتحويل_عنوان__', '__لاتع__', '__NOTITLECONVERT__', '__NOTC__' ),
 	'nocontentconvert'    => array( '0', '__لاتحويل_محتوى__', '__لاتم__', '__NOCONTENTCONVERT__', '__NOCC__' ),
 	'currentweek'         => array( '1', 'أسبوع_حالي', 'أسبوع', 'CURRENTWEEK' ),
@@ -252,6 +249,7 @@
 	'hiddencat'           => array( '1', '__تصنيف_مخفي__', '__HIDDENCAT__' ),
 	'pagesincategory'     => array( '1', 'صفحات في التصنيف', 'PAGESINCATEGORY', 'PAGESINCAT' ),
 	'pagesize'            => array( '1', 'حجم_الصفحة', 'حجم_صفحة', 'PAGESIZE' ),
+	'staticredirect'      => array( '1', '__تحويلة_إستاتيكية__', '__تحويلة_ساكنة__', '__STATICREDIRECT__' ),
 );
 
 $skinNames = array(
@@ -363,6 +361,7 @@
 	'MergeHistory'              => array( 'دمج_التاريخ' ),
 	'Filepath'                  => array( 'مسار_ملف' ),
 	'Invalidateemail'           => array( 'تعطيل_البريد_الإلكتروني' ),
+	'Blankpage'                 => array( 'صفحة_فارغة' ),
 );
 
 $imageFiles = array(
@@ -378,11 +377,11 @@
 'tog-underline'               => 'ضع خطًا تحت الوصلات:',
 'tog-highlightbroken'         => 'أأظهر الوصلات المعطوبة <a href="" class="new">هكذا</a> (البديل: كهذا<a href="" class="internal">؟</a>).',
 'tog-justify'                 => 'ساوِ الفقرات',
-'tog-hideminor'               => 'خبيء التعديلات الطفيفة في أحدث التغييرات',
+'tog-hideminor'               => 'أخف التعديلات الطفيفة في أحدث التغييرات',
 'tog-extendwatchlist'         => 'مدد قائمة المراقبة لعرض كل التغييرات المطبقة',
 'tog-usenewrc'                => 'شكل متقدم من أحدث التغييرات (جافا سكريبت)',
 'tog-numberheadings'          => 'رقم العناوين تلقائيا',
-'tog-showtoolbar'             => 'اظهر شريط التحرير (جافا سكريبت)',
+'tog-showtoolbar'             => 'أظهر شريط التحرير (جافا سكريبت)',
 'tog-editondblclick'          => 'عدل الصفحات عند الضغط المزدوج (جافا سكريبت)',
 'tog-editsection'             => 'فعل تعديل الأقسام عن طريق وصلات [تحرير]',
 'tog-editsectiononrightclick' => 'فعل تعديل الأقسام بواسطة كبسة الفأرة اليمين على عناوين الأقسام (جافاسكريبت)',
@@ -390,10 +389,10 @@
 'tog-rememberpassword'        => 'تذكر دخولي على هذا الحاسوب',
 'tog-editwidth'               => 'صندوق التحرير يأخذ كامل العرض',
 'tog-watchcreations'          => 'أضف الصفحات التي أنشئها إلى قائمة مراقبتي',
-'tog-watchdefault'            => 'أضف الصفحات التي أحررها إلى قائمة مراقبتي',
+'tog-watchdefault'            => 'أضف الصفحات التي أعدلها إلى قائمة مراقبتي',
 'tog-watchmoves'              => 'أضف الصفحات التي أنقلها إلى قائمة مراقبتي',
 'tog-watchdeletion'           => 'أضف الصفحات التي أحذفها إلى قائمة مراقبتي',
-'tog-minordefault'            => 'علم كل التعديلات كطفيفة افتراضيا',
+'tog-minordefault'            => 'علم على كل التعديلات كطفيفة افتراضيا',
 'tog-previewontop'            => 'أظهر العرض المسبق قبل صندوق التحرير',
 'tog-previewonfirst'          => 'أظهر العرض المسبق عند أول تعديل',
 'tog-nocache'                 => 'عطل اختزان الصفحة',
@@ -416,8 +415,8 @@
 'tog-diffonly'                => 'لا تعرض محتوى الصفحة أسفل الفروقات',
 'tog-showhiddencats'          => 'أظهر التصنيفات المخفية',
 
-'underline-always'  => 'دائمًا',
-'underline-never'   => 'أبدًا',
+'underline-always'  => 'دائما',
+'underline-never'   => 'أبدا',
 'underline-default' => 'تبعا لإعدادات المتصفح',
 
 'skinpreview' => '(عرض)',
@@ -478,12 +477,12 @@
 'pagecategories'                 => '{{PLURAL:$1|تصنيف|تصنيفات}}',
 'category_header'                => 'الصفحات في التصنيف "$1"',
 'subcategories'                  => 'التصنيفات الفرعية',
-'category-media-header'          => 'ملفات الميديا في التصنيف "$1"',
-'category-empty'                 => "''هذا التصنيف لا يحتوي حاليا على مقالات أو ملفات ميديا.''",
+'category-media-header'          => 'الميديا في التصنيف "$1"',
+'category-empty'                 => "''هذا التصنيف لا يحتوي حاليا على صفحات أو ميديا.''",
 'hidden-categories'              => '{{PLURAL:$1|تصنيف مخفي|تصنيفات مخفية}}',
 'hidden-category-category'       => 'تصنيفات مخفية', # Name of the category where hidden categories will be listed
 'category-subcat-count'          => '{{PLURAL:$2|هذا التصنيف لديه فقط التصنيف الفرعي التالي.|هذا التصنيف لديه {{PLURAL:$1|تصنيف فرعي|$1 تصنيف فرعي}}، من إجمالي $2.}}',
-'category-subcat-count-limited'  => 'هذا التصنيف لديه {{PLURAL:$1|تصنيف فرعي|$1 تصنيف فرعي}} كما يلي.',
+'category-subcat-count-limited'  => 'هذا التصنيف به {{PLURAL:$1|تصنيف فرعي|$1 تصنيف فرعي}} كما يلي.',
 'category-article-count'         => '{{PLURAL:$2|هذا التصنيف يحتوي فقط على الصفحة التالية.|بالأسفل {{PLURAL:$1|ملف|$1 ملف}} في هذا التصنيف، من إجمالي $2.}}',
 'category-article-count-limited' => 'بالأسفل {{PLURAL:$1|صفحة|$1 صفحة}} في التصنيف الحالي.',
 'category-file-count'            => '{{PLURAL:$2|هذا التصنيف يحتوي فقط على الملف التالي.|بالأسفل {{PLURAL:$1|ملف|$1 ملف}} في هذا التصنيف، من إجمالي $2.}}',
@@ -543,9 +542,9 @@
 'deletethispage'    => 'احذف هذه الصفحة',
 'undelete_short'    => 'استرجاع {{PLURAL:$1|تعديل واحد|تعديلان|$1 تعديلات|$1 تعديل|$1 تعديلا}}',
 'protect'           => 'حماية',
-'protect_change'    => 'غير الحماية',
+'protect_change'    => 'تغيير الحماية',
 'protectthispage'   => 'احم هذه الصفحة',
-'unprotect'         => 'أزل الحماية',
+'unprotect'         => 'إزالة الحماية',
 'unprotectthispage' => 'أزل حماية هذه الصفحة',
 'newpage'           => 'صفحة جديدة',
 'talkpage'          => 'ناقش هذه الصفحة',
@@ -628,9 +627,9 @@
 'feedlinks'               => 'تلقيم:',
 'feed-invalid'            => 'نوع اشتراك التليقم غير صحيح.',
 'feed-unavailable'        => 'التلقيمات غير متوفرة في {{SITENAME}}',
-'site-rss-feed'           => '$1 تلقيم أر‌إس‌إس',
+'site-rss-feed'           => '$1 تلقيم أر إس إس',
 'site-atom-feed'          => '$1 تلقيم أتوم',
-'page-rss-feed'           => '"$1" تلقيم أر‌إس‌إس',
+'page-rss-feed'           => '"$1" تلقيم أر إس إس',
 'page-atom-feed'          => '"$1" تلقيم أتوم',
 'feed-atom'               => 'أتوم',
 'feed-rss'                => 'أر إس إس',
@@ -650,22 +649,22 @@
 
 # Main script and global functions
 'nosuchaction'      => 'لا يوجد فعل كهذا',
-'nosuchactiontext'  => 'الأمر في المسار لم يتم التعرف عليه بواسطة الويكي',
+'nosuchactiontext'  => 'الفعل في المسار لم يتم التعرف عليه بواسطة الويكي',
 'nosuchspecialpage' => 'لا توجد صفحة خاصة بهذا الاسم',
 'nospecialpagetext' => "<big>'''لقد طلبت صفحة خاصة غير صحيحة.'''</big>
 
-قائمة بالصفحات الخاصة الصحيحة يمكن إيجادها في [[Special:Specialpages]].",
+قائمة بالصفحات الخاصة الصحيحة يمكن إيجادها في [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'خطأ',
 'databaseerror'        => 'خطأ في قاعدة البيانات',
-'dberrortext'          => 'حدث خطأ في صيغة الاستعلام.
+'dberrortext'          => 'حدث خطأ في صيغة استعلام قاعدة البيانات.
 ربما يكون هذا عيب بالبرنامج.
 آخر استعلام طُلب من قاعدة البيانات كان:
 <blockquote><tt>$1</tt></blockquote>
 من داخل الدالة "<tt>$2</tt>".
 MySQL أرجعت الخطأ "<tt>$3: $4</tt>".',
-'dberrortextcl'        => 'حدث خطأ في صيغة الاستعلام.
+'dberrortextcl'        => 'حدث خطأ في صيغة استعلام قاعدة البيانات.
 آخر استعلام طُلب من قاعدة البيانات كان:
 "$1"
 من داخل الدالة "$2".
@@ -679,14 +678,13 @@
 'enterlockreason'      => 'أدخل سببا للغلق، متضمنا تقديرا لوقت رفع الغلق',
 'readonlytext'         => 'قاعدة البيانات مغلقة حاليا أمام المدخلات الجديدة والتعديلات الأخرى، السبب غالبا ما يكون الصيانة، وستعود قاعدة البيانات للوضع الطبيعي قريبا.
 
-الإداري الذي أغلق قاعدة البيانات أعطى التفسير التالي:
-$1',
-'missing-article'      => 'قاعدة البيانات لم تجد النص الخاص بصفحة كان يجب أن تجدها و اسمها "$1" $2.
+الإداري الذي أغلق قاعدة البيانات أعطى التفسير التالي: $1',
+'missing-article'      => 'قاعدة البيانات لم تجد النص الخاص بصفحة كان يجب أن تجدها، واسمها "$1" $2.
 
-عادة ما يحدث هذا عند اتباع وصلات قديمة، لفرق التعديل أو التاريخ،  تؤدي الى صفحه تم حذفها.
+عادة ما يحدث هذا عند اتباع فرقا قديما أو وصلة تاريخ تؤدي إلى صفحه تم حذفها.
 
-اذا لم تكن هذه هي الحاله فالمحتمل أنك وجدت خلل في البرامج .
-رجاء أبلغ أحد الاداريين و أعطه وصلة الى عنوان الإنترنت لهذه الصفحة.',
+إذا لم تكن هذه هي الحالة، فالمحتمل أنك وجدت خللا في البرنامج.
+من فضلك أبلغ أحد [[Special:ListUsers/sysop|الإداريين]]، وأعطه وصلة إلى مسار هذه الصفحة.',
 'missingarticle-rev'   => '(رقم المراجعة: $1)',
 'missingarticle-diff'  => '(فرق: $1، $2)',
 'readonly_lag'         => 'تم إغلاق قاعدة البيانات تلقائيا حتى تستطيع الخوادم التابعة ملاحقة الخادم الرئيسي',
@@ -714,31 +712,35 @@
 'viewsource'           => 'عرض المصدر',
 'viewsourcefor'        => 'ل $1',
 'actionthrottled'      => 'لا يمكن عمل المزيد من هذا الفعل',
-'actionthrottledtext'  => 'كإجراء ضد السبام، أنت ممنوع من إجراء هذا الفعل عدد كبير من المرات في فترة زمنية قصيرة، ولقد تجاوزت هذا الحد. من فضلك حاول مرة ثانية خلال عدة دقائق.',
-'protectedpagetext'    => 'تمت حماية هذه الصفحة لمنع التعديل.',
+'actionthrottledtext'  => 'كإجراء ضد السبام، أنت ممنوع من إجراء هذا الفعل عدد كبير من المرات في فترة زمنية قصيرة، ولقد تجاوزت هذا الحد.
+من فضلك حاول مرة ثانية خلال عدة دقائق.',
+'protectedpagetext'    => 'هذه الصفحة تمت حمايتها لمنع التعديل.',
 'viewsourcetext'       => 'يمكنك رؤية ونسخ مصدر هذه الصفحة:',
 'protectedinterface'   => 'هذه الصفحة توفر نص الواجهة للبرنامج، وهي مقفلة لمنع التخريب.',
 'editinginterface'     => "'''تحذير''': أنت تقوم بتحرير صفحة تستخدم في الواجهة النصية للبرنامج. التغييرات لهذه الصفحة سوف تؤثر على مظهر واجهة المستخدم للمستخدمين الآخرين. للترجمات، من فضلك استخدم [http://translatewiki.net/wiki/Main_Page?setlang=ar بيتاويكي]، مشروع ترجمة الميدياويكي.",
-'sqlhidden'            => '(استعلام إس‌كيو‌إل مخفي)',
+'sqlhidden'            => '(استعلام SQL مخفي)',
 'cascadeprotected'     => 'تمت حماية هذه الصفحة من التعديل، بسبب كونها مدمجة في {{PLURAL:$1|صفحة|صفحات}} التالية، والتي تم استعمال خاصية "حماية الصفحات المدمجة" بها:
 $2',
 'namespaceprotected'   => "لا تمتلك الصلاحية لتعديل الصفحات في نطاق '''$1'''.",
 'customcssjsprotected' => 'لا تمتلك الصلاحية لتعديل هذه الصفحة، لأنها تحتوي على الإعدادات الشخصية لمستخدم آخر.',
-'ns-specialprotected'  => 'الصفحات في النطاق {{ns:special}} لا يمكن تعديلها.',
-'titleprotected'       => "هذا العنوان تمت حمايته من الإنشاء بواسطة [[User:$1|$1]]. السبب المعطى هو ''$2''.",
+'ns-specialprotected'  => 'الصفحات الخاصة لا يمكن تعديلها.',
+'titleprotected'       => "هذا العنوان تمت حمايته من الإنشاء بواسطة [[User:$1|$1]]. 
+السبب المعطى هو ''$2''.",
 
 # Virus scanner
 'virus-badscanner'     => 'سيء : ماسح فيروسات غير معروف: <i>$1</i>',
 'virus-scanfailed'     => 'فشل المسح (كود $1)',
-'virus-unknownscanner' => 'مضاد فيرس غير معروف:',
+'virus-unknownscanner' => 'مضاد فيروسات غير معروف:',
 
 # Login and logout pages
 'logouttitle'                => 'خروج المستخدم',
-'logouttext'                 => '<strong>أنت الآن غير مسجل الدخول للنظام.</strong><br />
-تستطيع المتابعة باستعمال {{SITENAME}} كمجهول، أو الدخول مرة أخرى بنفس الاسم أو باسم آخر. من الممكن أن ترى بعض الصفحات كما وأنك مسجل في النظام، وذلك بسبب استعمال الصفحات المختزنة في المتصفح لديك.',
-'welcomecreation'            => '== مرحبا يا $1! ==
+'logouttext'                 => '<strong>أنت الآن غير مسجل الدخول.</strong>
 
-تم إنشاء حسابك. لا تنس أن تغير تفضيلاتك في {{SITENAME}}.',
+تستطيع المتابعة باستعمال {{SITENAME}} كمجهول، أو الدخول مرة أخرى بنفس الاسم أو باسم آخر.
+من الممكن أن ترى بعض الصفحات كما لو أنك مسجل الدخول، وذلك حتى تقوم بإفراغ الصفحات المختزنة في المتصفح لديك.',
+'welcomecreation'            => '== مرحبا، $1! ==
+تم إنشاء حسابك.
+لا تنس أن تغير [[Special:Preferences|تفضيلاتك في {{SITENAME}}]].',
 'loginpagetitle'             => 'دخول المستخدم',
 'yourname'                   => 'اسم المستخدم:',
 'yourpassword'               => 'كلمة السر:',
@@ -749,11 +751,11 @@
 'loginproblem'               => '<b>حدثت مشكلة أثناء الدخول.</b><br />يرجى المحاولة مرى أخرى!',
 'login'                      => 'دخول',
 'nav-login-createaccount'    => 'دخول / إنشاء حساب',
-'loginprompt'                => 'يجب أن تكون الكوكيز لديك مفعلة لتتمكن من الدخول إلى {{SITENAME}}.',
+'loginprompt'                => 'يجب أن تكون الكوكيز لديك مفعلة لتسجل الدخول إلى {{SITENAME}}.',
 'userlogin'                  => 'سجل الدخول / أنشىء حساب',
 'logout'                     => 'خروج',
 'userlogout'                 => 'خروج',
-'notloggedin'                => 'غير مسجّل الدخول',
+'notloggedin'                => 'غير مسجل الدخول',
 'nologin'                    => 'لم تشترك بعد؟ $1.',
 'nologinlink'                => 'قم بإنشاء حساب',
 'createaccount'              => 'أنشئ حسابا',
@@ -761,7 +763,8 @@
 'gotaccountlink'             => 'دخول',
 'createaccountmail'          => 'بواسطة البريد الإلكتروني',
 'badretype'                  => 'كلمات السر التي أدخلتها لا تتطابق.',
-'userexists'                 => 'اسم المستخدم الذي أدخلته مستعمل بالفعل. من فضلك اختر اسما مختلفا.',
+'userexists'                 => 'اسم المستخدم الذي أدخلته مستعمل بالفعل.
+من فضلك اختر اسما مختلفا.',
 'youremail'                  => 'البريد:',
 'username'                   => 'اسم المستخدم:',
 'uid'                        => 'رقم المستخدم:',
@@ -772,29 +775,34 @@
 'yournick'                   => 'التوقيع:',
 'badsig'                     => 'توقيع خام غير صحيح؛ تحقق من وسوم الHTML.',
 'badsiglength'               => 'التوقيع طويل جدا.
-يجب أن يكون تحت $1 {{PLURAL:$1|حرف|حروف}}.',
+يجب أن يكون أقل من $1 {{PLURAL:$1|حرف|حروف}}.',
 'email'                      => 'البريد الإلكتروني',
-'prefs-help-realname'        => 'الاسم الحقيقي اختياري ولو اخترت أن تعرض اسمك هنا فسيستخدم في الإشارة إلى مساهماتك.',
+'prefs-help-realname'        => 'الاسم الحقيقي اختياري.
+لو اخترت أن توفره، فسيستخدم في الإشارة إلى عملك.',
 'loginerror'                 => 'خطأ في الدخول',
 'prefs-help-email'           => 'البريد الإلكتروني هو مدخل اختياري يمكّن الآخرين من الاتصال بك عن طريق صفحتك أو صفحة نقاشك من دون معرفة هويتك.',
 'prefs-help-email-required'  => 'عنوان البريد الإلكتروني مطلوب.',
 'nocookiesnew'               => 'تم إنشاء حساب المستخدم، و لكنك لست مسجل الدخول بعد. يستخدم {{SITENAME}} كوكيز لتسجيل الدخول. لديك الكوكيز معطلة. من فضلك فعلها، ثم أدخل باسم الحساب و كلمة السر الجديدتين.',
-'nocookieslogin'             => '{{SITENAME}} يستخدم الكوكيز لتسجيل الدخول؛ لديك الكوكيز معطلة؛ من فضلك فعلها ثم حاول مرة أخرى.',
+'nocookieslogin'             => '{{SITENAME}} يستخدم الكوكيز لتسجيل الدخول.
+لديك الكوكيز معطلة.
+من فضلك فعلها ثم حاول مرة أخرى.',
 'noname'                     => 'لم تحدد اسم مستخدم صحيح.',
 'loginsuccesstitle'          => 'تم الدخول بشكل صحيح',
 'loginsuccess'               => "'''لقد قمت بتسجيل الدخول ل{{SITENAME}} باسم \"\$1\".'''",
 'nosuchuser'                 => 'لا يوجد مستخدم بالاسم "$1".
 تأكد من إملاء الاسم، أو قم بإنشاء حساب جديد.',
-'nosuchusershort'            => 'لا يوجد مستخدم باسم <nowiki>$1</nowiki>". تأكد من إملاء الاسم.',
+'nosuchusershort'            => 'لا يوجد مستخدم باسم <nowiki>$1</nowiki>".
+تأكد من إملاء الاسم.',
 'nouserspecified'            => 'يجب عليك تحديد اسم مستخدم.',
-'wrongpassword'              => 'كلمة السر التي أدخلتها غير صحيحة. من فضلك حاول مرة أخرى.',
-'wrongpasswordempty'         => 'كلمة السر المدخلة كانت فارغة. من فضلك حاول مرة أخرى.',
+'wrongpassword'              => 'كلمة السر التي أدخلتها غير صحيحة.
+من فضلك حاول مرة أخرى.',
+'wrongpasswordempty'         => 'كلمة السر المدخلة كانت فارغة.
+من فضلك حاول مرة أخرى.',
 'passwordtooshort'           => 'كلمة السر التي اخترتها غير صحيحة أو قصيرة جدا.
 يجب ألا يقل طول الكلمة عن {{PLURAL:$1|1 حرف|$1 حرف}} حرف وأن تكون مختلفة عن اسم المستخدم الخاص بك.',
 'mailmypassword'             => 'أرسل لي كلمة السر عبر البريد الإلكتروني.',
 'passwordremindertitle'      => 'كلمة سر مؤقتة جديدة ل {{SITENAME}}',
 'passwordremindertext'       => 'لقد طلب شخص ما (غالبا أنت، من عنوان الأيبي $1) أن نرسل لك كلمة سر جديدة لـ{{SITENAME}} ($4).
-
 كلمة السر للمستخدم "$2" الآن هي "$3".
 عليك أن تقوم بالدخول إلى الموقع وتغيير كلمة السر خاصتك الآن.
 
@@ -805,33 +813,38 @@
 'blocked-mailpassword'       => 'تم منع عنوان الأيبي الخاص بك من التحرير، ولمنع التخريب لا يمكنك أن تستخدم خاصية استرجاع كلمة السر.',
 'eauthentsent'               => 'تم إرسال رسالة تأكيد إلكترونية إلى العنوان المسمى. حتى ترسل أي رسالة أخرى لذلك الحساب عليك أن تتبع التعليمات الواردة في الرسالة لتأكيد أن هذا الحساب هو لك بالفعل.',
 'throttled-mailpassword'     => 'تم بالفعل إرسال تذكير بكلمة السر، في خلال الـ{{PLURAL:$1|ساعة|$1 ساعة}} الماضية.
-لمنع التخريب، تذكير واحد فقط سيتم إرساله كل
-{{PLURAL:$1|ساعة|$1 ساعة}}.',
+لمنع التخريب، تذكير واحد فقط سيتم إرساله كل {{PLURAL:$1|ساعة|$1 ساعة}}.',
 'mailerror'                  => 'خطأ أثناء إرسال البريد: $1',
-'acct_creation_throttle_hit' => 'عذرا، لقد قمت بإنشاء $1 حساب. لا يمكنك عمل المزيد.',
+'acct_creation_throttle_hit' => 'عذرا، لقد قمت بإنشاء $1 حساب.
+لا يمكنك عمل المزيد.',
 'emailauthenticated'         => 'تم تأكيد بريدك الإلكتروني في $1.',
-'emailnotauthenticated'      => 'لم يتم التحقق من بريدك الإلكتروني. لن يتم إرسال رسائل لأي من الميزات التالية.',
-'noemailprefs'               => 'يجب تحديد عنوان بريد إلكتروني لتفعيل هذه الخصائص.',
+'emailnotauthenticated'      => 'لم يتم التحقق من بريدك الإلكتروني.
+لن يتم إرسال رسائل لأي من الميزات التالية.',
+'noemailprefs'               => 'حدد عنوان بريد إلكتروني لتفعيل هذه الخصائص.',
 'emailconfirmlink'           => 'أكد عنوان بريدك الإلكتروني',
-'invalidemailaddress'        => 'لا يمكن قبول عنوان البريد الإلكتروني الذي زودته حيث يبدو خاطئا. من فضلك ضع عنوانا مضبوطا أو أفرغ هذا الحقل.',
+'invalidemailaddress'        => 'لا يمكن قبول عنوان البريد الإلكتروني الذي زودته حيث يبدو خاطئا.
+من فضلك ضع عنوانا مضبوطا أو أفرغ هذا الحقل.',
 'accountcreated'             => 'تم إنشاء الحساب',
 'accountcreatedtext'         => 'تم إنشاء الحساب الخاص ب$1.',
 'createaccount-title'        => 'إنشاء حساب في {{SITENAME}}',
-'createaccount-text'         => 'شخص ما أنشأ حسابا لعنوان بريدك الإلكتروني في {{SITENAME}} ($4) بالاسم "$2"، كلمة السر "$3". ينبغي عليك تسجيل الدخول وتغيير كلمة السر الخاصة بك الآن.
+'createaccount-text'         => 'شخص ما أنشأ حسابا لعنوان بريدك الإلكتروني في {{SITENAME}} ($4) بالاسم "$2"، كلمة السر "$3".
+ينبغي عليك تسجيل الدخول وتغيير كلمة السر الخاصة بك الآن.
 
 يمكنك تجاهل هذه الرسالة، لو تم إنشاء هذا الحساب بالخطأ.',
 'loginlanguagelabel'         => 'اللغة: $1',
 
 # Password reset dialog
 'resetpass'               => 'أعد ضبط كلمة سر الحساب',
-'resetpass_announce'      => 'تم تسجيل دخولك بكلمة سر مؤقتة. للدخول بشكل نهائي، يجب عليك ضبط كلمة سر جديدة هنا:',
+'resetpass_announce'      => 'تم تسجيل دخولك بكلمة سر مؤقتة.
+للدخول بشكل نهائي، يجب عليك ضبط كلمة سر جديدة هنا:',
 'resetpass_text'          => '<!-- أضف نصا هنا -->',
 'resetpass_header'        => 'أعد ضبط كلمة السر',
 'resetpass_submit'        => 'ضبط كلمة السر والدخول',
 'resetpass_success'       => 'تم تغيير كلمة السر الخاصة بك بنجاح! يتم تسجيل دخولك الآن...',
-'resetpass_bad_temporary' => 'كلمة السر المؤقتة خاطئة. ربما تم تغيير كلمة السر فعليا بنجاح أو ربما قمت بطلب كلمة سر مؤقتة جديدة.',
+'resetpass_bad_temporary' => 'كلمة السر المؤقتة خاطئة.
+ربما تم تغيير كلمة السر فعليا بنجاح أو ربما قمت بطلب كلمة سر مؤقتة جديدة.',
 'resetpass_forbidden'     => 'لا يمكن تغيير كلمات السر في {{SITENAME}}',
-'resetpass_missing'       => 'لم يتم استقبال بيانات.',
+'resetpass_missing'       => 'لا بيانات استمارة.',
 
 # Edit page toolbar
 'bold_sample'     => 'نص عريض',
@@ -841,7 +854,7 @@
 'link_sample'     => 'عنوان وصلة',
 'link_tip'        => 'وصلة داخلية',
 'extlink_sample'  => 'http://www.example.com عنوان الوصلة',
-'extlink_tip'     => 'وصلة خارجية (تذكر إضافة http:// قبل عنوان الوصلة)',
+'extlink_tip'     => 'وصلة خارجية (تذكر بادئة http://)',
 'headline_sample' => 'نص عنوان رئيسي',
 'headline_tip'    => 'عنوان من المستوى الثاني',
 'math_sample'     => 'أدخل الصيغة هنا',
@@ -863,51 +876,55 @@
 'showpreview'                      => 'عرض مسبق',
 'showlivepreview'                  => 'عرض مباشر',
 'showdiff'                         => 'اظهر المقارنة',
-'anoneditwarning'                  => "'''تحذير:''' لم تقم بالدخول؛ سيتم تسجيل عنوان الأيبي الخاص بك في تاريخ هذه الصفحة.",
-'missingsummary'                   => "'''تنبيه:''' لم تقم بكتابة ملخص للتعديل. إذا قمت بضغط حفظ الصفحة مرة أخرى فيتم حفظ تعديلك بدون ملخص.",
+'anoneditwarning'                  => "'''تحذير:''' لم تقم بالدخول.
+سيتم تسجيل عنوان الأيبي الخاص بك في تاريخ هذه الصفحة.",
+'missingsummary'                   => "'''تنبيه:''' لم تقم بكتابة ملخص للتعديل.
+إذا قمت بضغط حفظ الصفحة مرة أخرى، فيتم حفظ تعديلك بدون ملخص.",
 'missingcommenttext'               => 'من فضلك أدخل تعليقا في الأسفل.',
-'missingcommentheader'             => "'''تنبيه:''' لم تقم بوضع موضوع/عنوان لهذا التعليق، إذا قمت بالضغط على حفظ الصفحة مجددا، سيتم حفظ تعليقك بدون عنوان.",
+'missingcommentheader'             => "'''تنبيه:''' لم تقم بوضع موضوع/عنوان لهذا التعليق.
+إذا قمت بالضغط على حفظ الصفحة مجددا، سيتم حفظ تعليقك بدون عنوان.",
 'summary-preview'                  => 'عرض مسبق للملخص',
 'subject-preview'                  => 'عرض مسبق للموضوع/العنوان',
 'blockedtitle'                     => 'المستخدم ممنوع',
 'blockedtext'                      => "<big>'''اسم المستخدم أو عنوان الأيبي الخاص بك تم منعه.'''</big>
 
-سبب المنع هو: ''$2''. وقام بالمنع $1.
+قام بالمنع $1.
+سبب المنع هو: ''$2''.
 
 * بداية المنع: $8
 * انتهاء المنع: $6
 * الممنوع المقصود: $7
 
-من الممكن التواصل مع $1 للنقاش حول المنع، أو مع أحد [[{{MediaWiki:Grouppage-sysop}}|الإداريين]] حول ذلك>
-تذكر أنه لا يمكن لك استعمال خاصية إرسال رسائل إلكترونية للمستخدمين إلا إذا كنت قد وضعت عنوان بريدي صحيح في صفحة [[Special:Preferences|التفضيلات]] الخاصة بك.
-عنوان الأيبي الخاص بك حاليا هو $3 وكود المنع هو #$5. يرجى إضافة أيهما أو كلاهما في أي رسالة للتساؤل حول المنع.",
-'autoblockedtext'                  => 'عنوان الأيبي الخاص بك تم منعه تلقائيا لأنه تم استخدامه بواسطة مستخدم آخر، و الذي تم منعه بواسطة $1.
+يمكنك الاتصال ب$1 أو مع أحد [[{{MediaWiki:Grouppage-sysop}}|الإداريين]] للنقاش حول المنع.
+
+لا يمكنك استخدام خاصية 'مراسلة هذا المستخدم' إلا إذا كنت قد وضعت عنوان بريدي صحيح في [[Special:Preferences|تفضيلات حسابك]] ولم يتم منعك من استخدامها.
+عنوان الأيبي الخاص بك حاليا هو $3، ورقم المنع هو #$5.
+من فضلك اذكر كل التفاصيل بالأعلى في أي استعلامات تقوم بها.",
+'autoblockedtext'                  => 'عنوان الأيبي الخاص بك تم منعه تلقائيا لأنه تم استخدامه بواسطة مستخدم آخر، تم منعه بواسطة $1.
 السبب الممنوح هو التالي:
 
 :\'\'$2\'\'
 
 * بداية المنع: $8
 * انتهاء المنع: $6
+* الممنوع المقصود: $7
 
-يمكنك أن تتصل ب $1 أو أحد
-[[{{MediaWiki:Grouppage-sysop}}|الإداريين]] الآخرين لمناقشة المنع.
+يمكنك أن تتصل ب $1 أو أحد [[{{MediaWiki:Grouppage-sysop}}|الإداريين]] الآخرين لمناقشة المنع.
 
-لاحظ أنه لا يمكنك استخدام خاصية "إرسال رسالة لهذا المستخدم" إلا لو كان لديك عنوان بريد إلكتروني صحيح مسجل في [[Special:Preferences|تفضيلاتك]].
+لاحظ أنه لا يمكنك استخدام خاصية "إرسال رسالة لهذا المستخدم" إلا لو كان لديك عنوان بريد إلكتروني صحيح مسجل في [[Special:Preferences|تفضيلاتك]] ولم يتم منعك من استخدامه.
 
-رقم منعك هو $5. من فضلك اذكر هذا الرقم في أي استفسار.',
+عنوان الأيبي الحالي الخاص بك هو $3، ورقم المنع هو #$5.
+من فضلك اذكر كل التفاصيل بالأعلى في أي استعلامات تقوم بها.',
 'blockednoreason'                  => 'لا سبب معطى',
 'blockedoriginalsource'            => "مصدر '''$1''' معروض بالأسفل:",
 'blockededitsource'                => "نص '''تعديلاتك''' في '''$1''' معروض بالأسفل:",
 'whitelistedittitle'               => 'تسجيل الدخول مطلوب للتحرير',
 'whitelistedittext'                => 'يجب عليك $1 لتتمكن من تعديل الصفحات.',
-'whitelistreadtitle'               => 'تسجيل الدخول مطلوب للقراءة',
-'whitelistreadtext'                => 'يجب عليك [[Special:Userlogin|تسجيل الدخول]] لتقرأ الصفحات.',
-'whitelistacctitle'                => 'لا يسمح لك بإنشاء اشتراك',
-'whitelistacctext'                 => 'حتى يسمح لك بإنشاء حسابات في {{SITENAME}} يجب عليك [[Special:Userlogin|تسجيل الدخول]] وأن تمتلك الصلاحيات المناسبة.',
 'confirmedittitle'                 => 'تأكيد البريد الإلكتروني مطلوب لبدء التعديل',
 'confirmedittext'                  => 'يجب عليك تأكيد بريدك الإلكتروني قبل التعديل. من فضلك اكتب وأكد بريدك الإلكتروني من خلال [[Special:Preferences|تفضيلاتك]]',
 'nosuchsectiontitle'               => 'لا يوجد قسم كهذا',
-'nosuchsectiontext'                => 'لقد حاولت تحرير قسم غير موجود. وحيث أنه لا يوجد القسم $1، فلا يوجد مكان لحفظ تعديلك.',
+'nosuchsectiontext'                => 'لقد حاولت تحرير قسم غير موجود.
+وحيث أنه لا يوجد القسم $1، فلا يوجد مكان لحفظ تعديلك.',
 'loginreqtitle'                    => 'تسجيل الدخول مطلوب',
 'loginreqlink'                     => 'دخول',
 'loginreqpagetext'                 => 'يجب عليك $1 لتشاهد صفحات أخرى.',
@@ -918,24 +935,33 @@
 لإنشاء هذه الصفحة ابدأ الكتابة في الصندوق بالأسفل.
 (انظر في [[{{MediaWiki:Helppage}}|صفحة المساعدة]] للمزيد من المعلومات)
 إذا كانت زيارتك لهذه الصفحة بالخطأ، اضغط على زر ''رجوع'' في متصفح الإنترنت لديك.",
-'anontalkpagetext'                 => "----''هذه صفحة نقاش لمستخدم مجهول لم يقم بإنشاء حساب بعد أو لا يستعمل ذلك الحساب. لذا فيجب علينا استعمال رقم الأيبي للتعرف عليه/عليها. مثل هذا العنوان يمكن أن يشترك فيه عدة مستخدمين. لو كنت مستخدما مجهولا وتشعر بأن تعليقات لا تخصك تم توجيهها إليك، من فضلك [[Special:Userlogin|أنشىء حسابا أو سجل الدخول]] لتجنب الارتباك المستقبلي مع مستخدمين مجهولين آخرين.''",
+'anontalkpagetext'                 => "----''هذه صفحة نقاش لمستخدم مجهول لم يقم بإنشاء حساب بعد أو لا يستعمل ذلك الحساب.
+لذا فيجب علينا استعمال رقم الأيبي للتعرف عليه/عليها.
+مثل هذا العنوان يمكن أن يشترك فيه عدة مستخدمين.
+لو كنت مستخدما مجهولا وتشعر بأن تعليقات لا تخصك تم توجيهها إليك، من فضلك [[Special:UserLogin/signup|أنشئ حسابا]] أو [[Special:UserLogin|سجل الدخول]] لتجنب الارتباك المستقبلي مع مستخدمين مجهولين آخرين.''",
 'noarticletext'                    => 'لا يوجد حاليا أي نص في هذه الصفحة، يمكنك [[Special:Search/{{PAGENAME}}|البحث عن عنوان هذه الصفحة]] في الصفحات الأخرى أو [{{fullurl:{{FULLPAGENAME}}|action=edit}} تعديل هذه الصفحة].',
-'userpage-userdoesnotexist'        => 'حساب المستخدم "$1" غير مسجل. من فضلك تأكد أنك تريد إنشاء/تعديل هذه الصفحة.',
+'userpage-userdoesnotexist'        => 'حساب المستخدم "$1" غير مسجل.
+من فضلك تأكد أنك تريد إنشاء/تعديل هذه الصفحة.',
 'clearyourcache'                   => "'''ملاحظة - بعد الحفظ, ربما ينبغي عليك إفراغ كاش متصفحك لرؤية التغييرات.''' '''موزيللا / فايرفوكس / سافاري:''' اضغط ''Shift'' أثناء ضغط ''Reload,'' أو اضغط أيا من ''Ctrl-F5'' أو ''Ctrl-R'' (''Command-R'' على ماكنتوش); '''كونكرر: '''اضغط ''Reload'' أو اضغط ''F5;'' '''أوبرا:''' أفرغ الكاش في ''Tools → Preferences;'' '''إنترنت إكسبلورر:''' اضغط ''Ctrl'' أثناء ضغط ''Refresh,'' أو اضغط ''Ctrl-F5.''",
 'usercssjsyoucanpreview'           => "<strong>ملاحظة:</strong> استعمل زر 'عرض مسبق' لتجربة النمط (CSS) أو الجافا سكريبت الجديد قبل حفظ الصفحة.",
 'usercsspreview'                   => "'''تذكر أنك تقوم بعرض الأنماط المتراصة (CSS) فقط وأنك لم تقم بحفظها بعد!'''",
 'userjspreview'                    => "'''تذكر أنك فقط تجرب/تعرض الجافا سكريبت الخاص بك، لم يتم الحفظ بعد!'''",
-'userinvalidcssjstitle'            => "'''تحذير:''' لا توجد واجهة  \"\$1\". تذكر أن ملفات ال.css و ال.js تستخدم حروف صغيرة في العنوان ، كمثال {{ns:user}}:Foo/monobook.css و ليس {{ns:user}}:Foo/Monobook.css.",
+'userinvalidcssjstitle'            => "'''تحذير:''' لا توجد واجهة  \"\$1\".
+تذكر أن ملفات ال.css و ال.js تستخدم حروف صغيرة في العنوان ، كمثال {{ns:user}}:Foo/monobook.css و ليس {{ns:user}}:Foo/Monobook.css.",
 'updated'                          => '(محدثة)',
 'note'                             => '<strong>ملاحظة:</strong>',
-'previewnote'                      => '<strong>تذكر، هذا فقط عرض مسبق للصفحة، ولم يتم حفظه بعد</strong>!',
+'previewnote'                      => '<strong>تذكر، هذا فقط عرض مسبق للصفحة؛
+ولم يتم حفظه بعد</strong>!',
 'previewconflict'                  => 'هذا العرض يوضح النص الموجود في صندوق التحرير العلوي والذي سيظهر إذا اخترت الحفظ.',
-'session_fail_preview'             => '<strong>عذرا! لم نتمكن من حفظ التعديلات التي قمت بها نتيجة لضياع بيانات هذه الجلسة. الرجاء المحاولة مرة أخرى. في حال استمرار المشكلة حاول أن تقوم بالخروج ومن ثم الدخول مرة أخرى.</strong>',
+'session_fail_preview'             => '<strong>عذرا! لم نتمكن من حفظ التعديلات التي قمت بها نتيجة لضياع بيانات هذه الجلسة.
+من فضلك حاول مرة أخرى.
+في حال استمرار المشكلة حاول أن تقوم [[Special:UserLogout|بالخروج]] ومن ثم الدخول مرة أخرى.</strong>',
 'session_fail_preview_html'        => "<strong>عذرا! لم نستطع معالجة تعديلك بسبب فقدان بيانات الجلسة.</strong>
 
 ''لأن {{SITENAME}} بها HTML الخام مفعلة، العرض المسبق مخفي كاحتياط ضد هجمات الجافا سكريبت.''
 
-<strong>إذا كانت هذه محاولة تعديل صادقة، من فضلك حاول مرة أخرى. إذا كانت مازالت لا تعمل، حاول تسجيل الخروج ثم تسجيل الدخول مجددا.</strong>",
+<strong>إذا كانت هذه محاولة تعديل صادقة، من فضلك حاول مرة أخرى.
+إذا كانت مازالت لا تعمل، حاول [[Special:UserLogout|تسجيل الخروج]] ثم تسجيل الدخول مجددا.</strong>",
 'token_suffix_mismatch'            => '<strong>تعديلك تم رفضه لأن عميلك أخطأ في علامات الترقيم 
 في نص التعديل. التعديل تم رفضه لمنع فساد نص المقالة.
 هذا يحدث أحيانا عندما تستخدم خدمة بروكسي مجهولة معيبة أساسها الويب.</strong>',
@@ -950,19 +976,26 @@
 '''فقط''' ما هو موجود في الصندوق العلوي هو ما سيتم حفظه عند الضغط على زر \"حفظ الصفحة\".",
 'yourtext'                         => 'نصك',
 'storedversion'                    => 'النسخة المخزنة',
-'nonunicodebrowser'                => '<strong>تحذير: متصفحك لا يتوافق مع الترميز الموحد. تمت معالجة هذا لكي تتمكن من تحرير الصفحات بأمان: الحروف التي ليست ASCII سوف تظهر في صندوق التحرير كأكواد سداسي عشرية.</strong>',
+'nonunicodebrowser'                => '<strong>تحذير: متصفحك لا يتوافق مع الترميز الموحد.
+تمت معالجة هذا لكي تتمكن من تحرير الصفحات بأمان: الحروف التي ليست ASCII سوف تظهر في صندوق التحرير كأكواد سداسي عشرية.</strong>',
 'editingold'                       => '<strong> تحذير: أنت تقوم الآن بتحرير نسخة قديمة من هذه الصفحة.
 إذا قمت بحفظها، ستفقد كافة التغييرات التي حدثت بعد هذه النسخة. </strong>',
 'yourdiff'                         => 'الفروق',
 'copyrightwarning'                 => 'من فضلك لاحظ أن جميع المساهمات ل {{SITENAME}} خاضعة وصادرة تحت ترخيص $2 (انظر في $1 للمزيد من التفاصيل)
-إذا لم ترد أن تخضع كتابتك للتعديل والتوزيع الحر، لا تضعها هنا<br />. كما أنك تتعهد بأنك قمت بكتابة ما هو موجود بنفسك، أو قمت بنسخها من مصدر يخضع ضمن الملكية العامة، أو مصدر حر آخر. <strong>لا ترسل أي عمل ذي حقوق محفوظة بدون الإذن من صاحب الحق</strong>.',
-'copyrightwarning2'                => 'من فضلك لاحظ أن حميع المشاركات في {{SITENAME}} يمكن أن تعدل أو تتغير أو تحذف من قبل المشاركين الآخرين. إذا لم تكن ترغب أن تعدل مشاركاتك بهذا الشكل، لا تضعها هنا.<br />
-انت أيضا تقر أنك كتبت هذا بنفسك، أو نسختها من مصدر لا يخضع لحقوق النشر أو يسمح بالنقل بشكلا ما (انظر $1 للتفاصيل).
+إذا لم ترد أن تخضع كتابتك للتعديل والتوزيع الحر، لا تضعها هنا<br />. 
+كما أنك تتعهد بأنك قمت بكتابة ما هو موجود بنفسك، أو قمت بنسخها من مصدر يخضع ضمن الملكية العامة، أو مصدر حر آخر. 
+<strong>لا ترسل أي عمل ذي حقوق محفوظة بدون الإذن من صاحب الحق</strong>.',
+'copyrightwarning2'                => 'من فضلك لاحظ أن حميع المشاركات في {{SITENAME}} يمكن أن تعدل أو تتغير أو تحذف من قبل المشاركين الآخرين.
+إذا لم تكن ترغب أن تعدل مشاركاتك بهذا الشكل، لا تضعها هنا.<br />
+أنت أيضا تقر أنك كتبت هذا بنفسك، أو نسخته من مصدر يخضع ضمن الملكية العامة، أو مصدر حر آخر (انظر $1 للتفاصيل).
 <strong>لا تضف أي نص ذي حقوق محفوظة!</strong>',
-'longpagewarning'                  => '<strong>تحذير: هذه الصفحة حجمها $1 كيلوبايت، بعض المتصفحات قد تواجه مشاكل عند محاولة تحرير صفحات يزيد حجمها عن 32 كيلوبايت. يرجى تقسيم الصفحة إلى أقسام أصغر حجما  إن أمكن.</strong>',
-'longpageerror'                    => '<strong>خطأ: النص الذي أدخلته حجمه $1 كيلوبايت
-، وهذا أكبر من الحد الأقصى وهو $2 كيلوبايت. لا يمكن حفظه.</strong>',
-'readonlywarning'                  => '<strong>تحذير: لقد أغلقت قاعدة البيانات للصيانة، لذلك لن تتمكن من حفظ التعديلات التي قمت بها حاليا. إذا رغبت بإمكانك أن تنسخ النص الذي تعمل عليه وتحفظه في ملف نصي إلى وقت لاحق.</strong>',
+'longpagewarning'                  => '<strong>تحذير: هذه الصفحة حجمها $1 كيلوبايت؛
+بعض المتصفحات قد تواجه مشاكل عند محاولة تحرير صفحات يزيد حجمها عن 32 كيلوبايت.
+يرجى تقسيم الصفحة إلى أقسام أصغر حجما.</strong>',
+'longpageerror'                    => '<strong>خطأ: النص الذي أدخلته حجمه $1 كيلوبايت، وهذا أكبر من الحد الأقصى وهو $2 كيلوبايت.
+لا يمكن حفظه.</strong>',
+'readonlywarning'                  => '<strong>تحذير: لقد أغلقت قاعدة البيانات للصيانة، لذلك لن تتمكن من حفظ التعديلات التي قمت بها حاليا.
+إذا رغبت بإمكانك أن تنسخ النص الذي تعمل عليه وتحفظه في ملف نصي إلى وقت لاحق.</strong>',
 'protectedpagewarning'             => '<strong>تحذير: تمت حماية هذه الصفحة حتى يمكن للمستخدمين ذوي الصلاحيات الإدارية فقط تعديلها.</strong>',
 'semiprotectedpagewarning'         => "'''ملاحظة:''' تمت حماية هذه الصفحة بحيث يمكن للمستخدمين المسجلين فقط تعديلها.",
 'cascadeprotectedwarning'          => '<strong>تحذير: تمت حماية هذه الصفحة بحيث يستطيع المستخدمون ذوو الصلاحيات الإدارية فقط تعديلها، وذلك لكونها مدمجة في {{PLURAL:$1|الصفحة|الصفحات}} التالية والتي تمت حمايتها بخاصية "حماية الصفحات المدمجة":</strong>',
@@ -976,7 +1009,7 @@
 'edittools'                        => '<!-- النص هنا سيظهر تحت صندوق التحرير واستمارة رفع الصور. -->',
 'nocreatetitle'                    => 'تم تحديد إنشاء الصفحات',
 'nocreatetext'                     => 'قام {{SITENAME}} بتحديد القدرة على إنشاء صفحات جديدة.
-يمكنك العودة وتحرير صفحة موجودة بالفعل، أو [[Special:Userlogin|الدخول أو تسجيل حساب]].',
+يمكنك العودة وتحرير صفحة موجودة بالفعل، أو [[Special:UserLogin|الدخول أو تسجيل حساب]].',
 'nocreate-loggedin'                => 'لا تمتلك الصلاحية لإنشاء صفحات جديدة في {{SITENAME}}.',
 'permissionserrors'                => 'أخطاء السماحات',
 'permissionserrorstext'            => 'لا تمتلك الصلاحية لفعل هذا، {{PLURAL:$1|للسبب التالي|للأسباب التالية}}:',
@@ -987,19 +1020,20 @@
 سجل الحذف لهذه الصفحة معروض هنا:",
 
 # Parser/template warnings
-'expensive-parserfunction-warning'        => 'تحذير: هذه الصفحة تحتوي على استدعاءات دالة بارسر كثيرة مكلفة.
+'expensive-parserfunction-warning'        => 'تحذير: هذه الصفحة تحتوي على استدعاءات دالة محلل كثيرة مكلفة.
 
 ينبغي أن تكون أقل من $2، يوجد الآن $1.',
 'expensive-parserfunction-category'       => 'صفحات يوجد بها استدعاءات دوال محلل كثيرة ومكلفة',
-'post-expand-template-inclusion-warning'  => 'تحذير: يتضمّن القالب حجما كبيرا جدا.
-بعض القوالب لن تضمّن.',
-'post-expand-template-inclusion-category' => 'صفحات حيث القالب يتضمّن حجما متجاوزا',
+'post-expand-template-inclusion-warning'  => 'تحذير: حجم تضمين القالب كبير جدا.
+بعض القوالب لن تضمن.',
+'post-expand-template-inclusion-category' => 'الصفحات حيث تم تجاوز حجم تضمين القالب',
 'post-expand-template-argument-warning'   => 'تحذير: هذه الصفحة تحتوي على عامل قالب واحد على الأقل له حجم تمدد كبير جدا.
 هذه العوامل تم حذفها.',
 'post-expand-template-argument-category'  => 'صفحات تحتوي مدخلات القالب المحذوفة',
 
 # "Undo" feature
-'undo-success' => 'يمكن استرجاع التعديل. من فضلك تحقق من المقارنة بالأسفل للتأكد من أن هذا هو ما تريد أن تفعله، وبعد ذلك احفظ التغييرات بالأسفل للانتهاء من استرجاع التعديل.',
+'undo-success' => 'يمكن استرجاع التعديل.
+من فضلك تحقق من المقارنة بالأسفل للتأكد من أن هذا هو ما تريد أن تفعله، وبعد ذلك احفظ التغييرات بالأسفل للانتهاء من استرجاع التعديل.',
 'undo-failure' => 'لم يمكن استرجاع التعديل بسبب تعديلات متعارضة تمت على الصفحة.',
 'undo-norev'   => 'فشل في الرجوع عن التعديل حيث أنه غير موجود أو تم حذفه.',
 'undo-summary' => 'الرجوع عن التعديل $1 بواسطة [[Special:Contributions/$2|$2]] ([[User talk:$2|نقاش]])',
@@ -1013,8 +1047,9 @@
 # History pages
 'viewpagelogs'        => 'عرض السجلات لهذه الصفحة',
 'nohistory'           => 'لا يوجد تاريخ للتعديلات لهذه الصفحة.',
-'revnotfound'         => 'النسخة غير موجودة',
-'revnotfoundtext'     => 'لم يتم العثور على النسخة القديمة من الصفحة التي طلبتها. من فضلك تأكد من المسار الذي دخلت به إلى هذه الصفحة.',
+'revnotfound'         => 'المراجعة غير موجودة',
+'revnotfoundtext'     => 'لم يتم العثور على النسخة القديمة من الصفحة التي طلبتها.
+من فضلك تأكد من المسار الذي دخلت به إلى هذه الصفحة.',
 'currentrev'          => 'المراجعة الحالية',
 'revisionasof'        => 'مراجعة $1',
 'revision-info'       => 'مراجعة $1 بواسطة $2',
@@ -1037,9 +1072,11 @@
 
 # Revision feed
 'history-feed-title'          => 'تاريخ التعديل',
-'history-feed-description'    => 'تاريخ التعديل على هذه الصفحة في الويكي',
+'history-feed-description'    => 'تاريخ التعديل لهذه الصفحة في الويكي',
 'history-feed-item-nocomment' => '$1 في $2', # user at time
-'history-feed-empty'          => 'الصفحة المطلوبة غير موجودة. من المحتمل أن تكون هذه الصفحة قد حذفت أو نقلت. حاول [[Special:Search|البحث في الويكي]] عن صفحات جديدة ذات صلة.',
+'history-feed-empty'          => 'الصفحة المطلوبة غير موجودة.
+من المحتمل أن تكون هذه الصفحة قد حذفت أو نقلت.
+حاول [[Special:Search|البحث في الويكي]] عن صفحات جديدة ذات صلة.',
 
 # Revision deletion
 'rev-deleted-comment'         => '(أزيل التعليق)',
@@ -1050,35 +1087,35 @@
 ربما تكون هناك تفاصيل في [{{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}} سجل الحذف].
 </div>',
 'rev-deleted-text-view'       => '<div class="mw-warning plainlinks">
-تم مسح هذا التعديل من الأرشيف العام.
-بإمكانك رؤية هذا التعديل لكونك إداريا على هذا الموقع.
+تمت إزالة هذه المراجعة من الأرشيف العام.
+بإمكانك رؤية هذه المراجعة لكونك إداريا على هذا الموقع.
 من الممكن أن يكون هناك تفاصيل حول هذا في [{{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}} سجل الحذف].
 </div>',
 'rev-delundel'                => 'عرض/إخفاء',
-'revisiondelete'              => 'احذف/استرجع المراجعات',
+'revisiondelete'              => 'حذف/استرجاع المراجعات',
 'revdelete-nooldid-title'     => 'مراجعة هدف غير صحيحة',
-'revdelete-nooldid-text'      => 'أنت إما أنك لم تحدد نسخة أو نسخ معينة كهدف لأداء هذا الفعل، المراجعة المحددة غير موجودة، أو أنك تحاول إخفاء النسخة الحالية.',
+'revdelete-nooldid-text'      => 'أنت إما أنك لم تحدد مراجعة (مراجعات) معينة كهدف لأداء هذا الفعل، المراجعة المحددة غير موجودة، أو أنك تحاول إخفاء المراجعة الحالية.',
 'revdelete-selected'          => '{{PLURAL:$2|المراجعة المختارة|المراجعات المختارة}} ل[[:$1]]:',
 'logdelete-selected'          => '{{PLURAL:$1|حدث السجل المختار|أحداث السجل المختارة}}:',
-'revdelete-text'              => 'النسخ والأحداث المحذوفة ستظل تظهر في تاريخ الصفحة والسجلات،
+'revdelete-text'              => 'المراجعات والأحداث المحذوفة ستظل تظهر في تاريخ الصفحة والسجلات،
 لكن أجزاء من محتواهم لن يكون مسموحا للعامة برؤيتها.
 
 الإداريون الآخرون في {{SITENAME}}سيظل بإمكانهم رؤية المحتوى المخفي ويمكنهم استرجاعه مجددا من خلال هذه الواجهة نفسها، مالم يتم وضع قيود إضافية.',
 'revdelete-legend'            => 'وضع ضوابط رؤية',
-'revdelete-hide-text'         => 'إخفاء نص النسخة',
-'revdelete-hide-name'         => 'إخفاء الإجراء والهدف منه',
+'revdelete-hide-text'         => 'إخفاء نص المراجعة',
+'revdelete-hide-name'         => 'إخفاء الفعل والهدف',
 'revdelete-hide-comment'      => 'إخفاء تعليق التعديل',
 'revdelete-hide-user'         => 'إخفاء اسم/عنوان المستخدم',
 'revdelete-hide-restricted'   => 'طبق هذه الضوابط على مديري النظام وأغلق هذه الواجهة',
-'revdelete-suppress'          => 'إخفاء البيانات عن الإداريين بجانب الآخرين',
+'revdelete-suppress'          => 'إخفاء البيانات عن مديري النظام بجانب الآخرين',
 'revdelete-hide-image'        => 'إخفاء محتوى الملف',
-'revdelete-unsuppress'        => 'إزالة الضوابط من النسخ المسترجعة',
+'revdelete-unsuppress'        => 'إزالة الضوابط من المراجعات المسترجعة',
 'revdelete-log'               => 'تعليق السجل:',
-'revdelete-submit'            => 'طبق على النسخة المختارة',
-'revdelete-logentry'          => 'تغيير مرئية تعديلات في [[$1]]',
-'logdelete-logentry'          => 'تغيير مرئية أحداث في [[$1]]',
-'revdelete-success'           => "'''تم ضبط مرئية التعديلات بنجاح.'''",
-'logdelete-success'           => "'''تم ضبط مرئية الأحداث بنجاح.'''",
+'revdelete-submit'            => 'طبق على المراجعة المختارة',
+'revdelete-logentry'          => 'غير رؤية المراجعة ل[[$1]]',
+'logdelete-logentry'          => 'غير رؤية الحدث ل[[$1]]',
+'revdelete-success'           => "'''تم ضبط رؤية المراجعات بنجاح.'''",
+'logdelete-success'           => "'''تم ضبط رؤية السجلات بنجاح.'''",
 'revdel-restore'              => 'تغيير الرؤية',
 'pagehist'                    => 'تاريخ الصفحة',
 'deletedhist'                 => 'التاريخ المحذوف',
@@ -1095,24 +1132,23 @@
 # Suppression log
 'suppressionlog'     => 'سجل الإخفاء',
 'suppressionlogtext' => 'بالأسفل قائمة بعمليات الحذف والمنع التي تتضمن محتوى مخفي من الإداريين.
-انظر [[Special:Ipblocklist|لقائمة المنع]] لترى عمليات المنع القائمة الآن.',
+انظر [[Special:IPBlockList|لقائمة المنع]] لترى عمليات المنع القائمة الآن.',
 
 # History merging
 'mergehistory'                     => 'دمج تواريخ الصفحة',
 'mergehistory-header'              => 'هذه الصفحة تسمح لك بدمج نسخ تاريخ صفحة ما إلى صفحة أخرى.
 تأكد من أن هذا التغيير سيحافظ على استمرار تاريخ الصفحة.',
-'mergehistory-box'                 => 'دمج نسخ الصفحتين:',
+'mergehistory-box'                 => 'دمج مراجعات صفحتين:',
 'mergehistory-from'                => 'الصفحة المصدر:',
 'mergehistory-into'                => 'الصفحة الهدف:',
 'mergehistory-list'                => 'تاريخ التعديل القابل للدمج',
-'mergehistory-merge'               => 'النسخ التالية من [[:$1|$1]] يمكن دمجها إلى [[:$2|$2]].
-استخدم عامود الصناديق لدمج النسخ التي تم إنشاؤها في وقبل الوقت المحدد.
-لاحظ أن استخدام 
-وصلات التصفح سيعيد ضبط هذا العامود.',
+'mergehistory-merge'               => 'المراجعات التالية من [[:$1|$1]] يمكن دمجها إلى [[:$2|$2]].
+استخدم عامود الصناديق لدمج المراجعات التي تم إنشاؤها في وقبل الوقت المحدد.
+لاحظ أن استخدام وصلات التصفح سيعيد ضبط هذا العامود.',
 'mergehistory-go'                  => 'عرض التعديلات القابلة للدمج',
-'mergehistory-submit'              => 'دمج النسخ',
-'mergehistory-empty'               => 'لا نسخ يمكن دمجها.',
-'mergehistory-success'             => '$3 {{PLURAL:$3|نسخة|نسخة}} من [[:$1]] تم دمجها بنجاح في [[:$2]].',
+'mergehistory-submit'              => 'دمج المراجعات',
+'mergehistory-empty'               => 'لا مراجعات يمكن دمجها.',
+'mergehistory-success'             => '$3 {{PLURAL:$3|مراجعة|مراجعة}} من [[:$1]] تم دمجها بنجاح في [[:$2]].',
 'mergehistory-fail'                => 'غير قادر على عمل دمج التاريخ، من فضلك أعد التحقق من محددات الصفحة والزمن.',
 'mergehistory-no-source'           => 'الصفحة المصدر $1 غير موجودة.',
 'mergehistory-no-destination'      => 'الصفحة الهدف $1 غير موجودة.',
@@ -1123,7 +1159,7 @@
 
 # Merge log
 'mergelog'           => 'سجل الدمج',
-'pagemerge-logentry' => 'دمج [[$1]] إلى [[$2]] (النسخ حتى $3)',
+'pagemerge-logentry' => 'دمج [[$1]] إلى [[$2]] (المراجعات حتى $3)',
 'revertmerge'        => 'استرجاع الدمج',
 'mergelogpagetext'   => 'بالأسفل قائمة بأحدث عمليات الدمج لتاريخ صفحة ما إلى أخرى.',
 
@@ -1133,16 +1169,17 @@
 'lineno'                  => 'سطر $1:',
 'compareselectedversions' => 'قارن بين النسختين المختارتين',
 'editundo'                => 'رجوع',
-'diff-multi'              => '({{PLURAL:$1|نسخة واحدة متوسطة|$1 نسخة متوسطة}} غير معروضة.)',
+'diff-multi'              => '({{PLURAL:$1|مراجعة واحدة متوسطة|$1 مراجعة متوسطة}} غير معروضة.)',
 
 # Search results
 'searchresults'             => 'نتائج البحث',
 'searchresulttext'          => 'للمزيد من المعلومات حول البحث في {{SITENAME}}، انظر [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "لصيغة البحث '''[[:$1]]'''",
-'searchsubtitleinvalid'     => "لصيغة البحث '''$1'''",
-'noexactmatch'              => "'''لا توجد صفحة بالاسم \"\$1\"'''. يمكنك [[:\$1|إنشاء هذه الصفحة]].",
+'searchsubtitle'            => 'أنت بحثت عن \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|كل الصفحات التي تبدأ ب"$1"]] | [[Special:WhatLinksHere/$1|كل الصفحات التي تصل إلى "$1"]])',
+'searchsubtitleinvalid'     => "أنت بحثت عن '''$1'''",
+'noexactmatch'              => "'''لا توجد صفحة بالاسم \"\$1\"'''.
+يمكنك [[:\$1|إنشاء هذه الصفحة]].",
 'noexactmatch-nocreate'     => "'''لا توجد صفحة بالاسم \"\$1\".'''",
-'toomanymatches'            => 'وجدت مطابقات كثيرة، جرب استعلام مختلف من فضلك',
+'toomanymatches'            => 'وجدت مطابقات كثيرة، من فضلك جرب استعلام مختلف',
 'titlematches'              => 'عنوان الصفحة يطابق',
 'notitlematches'            => 'لم يتم إيجاد أي عنوان مطابق',
 'textmatches'               => 'نص الصفحة يطابق',
@@ -1167,21 +1204,24 @@
 'showingresults'            => "القائمة التالية تعرض {{PLURAL:$1|'''1''' نتيجة|'''$1''' نتيجة}} بدءا من رقم '''$2'''.",
 'showingresultsnum'         => "معروض بالأسفل {{PLURAL:$3|'''نتيجة واحدة'''|'''$3''' نتيجة}} بدءا من رقم'''$2'''.",
 'showingresultstotal'       => "معروض بالأسفل {{PLURAL:$3|النتيجة '''$1''' من '''$3'''|النتائج '''$1 - $2''' من '''$3'''}}",
-'nonefound'                 => "'''ملاحظة''': فقط بعض النطاقات يتم البحث فيها افتراضيا. حاول بدء استعلامك ب ''all:'' للبحث في كل المحتوى (شاملا صفحات النقاش، القوالب، إلى آخره)، أو استخدم النطاق المطلوب كبادئة.",
+'nonefound'                 => "'''ملاحظة''': فقط بعض النطاقات يتم البحث فيها افتراضيا.
+حاول بدء استعلامك ب ''all:'' للبحث في كل المحتوى (شاملا صفحات النقاش، القوالب، إلى آخره)، أو استخدم النطاق المطلوب كبادئة.",
 'powersearch'               => 'بحث متقدم',
 'powersearch-legend'        => 'بحث متقدم',
 'powersearch-ns'            => 'بحث في النطاقات:',
 'powersearch-redir'         => 'عرض التحويلات',
 'powersearch-field'         => 'بحث عن',
 'search-external'           => 'بحث خارجي',
-'searchdisabled'            => 'البحث في {{SITENAME}} معطل. يمكنك البحث من خلال جوجل في الوقت الحالي. لاحظ أن فهارسه لمحتوى {{SITENAME}} ربما تكون غير محدثة.',
+'searchdisabled'            => 'البحث في {{SITENAME}} معطل.
+يمكنك البحث من خلال جوجل في الوقت الحالي.
+لاحظ أن فهارسه لمحتوى {{SITENAME}} ربما تكون غير محدثة.',
 
 # Preferences page
 'preferences'              => 'تفضيلات',
 'mypreferences'            => 'تفضيلاتي',
 'prefs-edits'              => 'عدد التعديلات:',
 'prefsnologin'             => 'غير مسجل',
-'prefsnologintext'         => 'يجب أن تكون [[Special:Userlogin|مسجلا]] حتى تتمكن من تعديل تفضيلات المستخدم.',
+'prefsnologintext'         => 'يجب أن تكون [[Special:UserLogin|مسجلا]] حتى تتمكن من تعديل تفضيلات المستخدم.',
 'prefsreset'               => 'أعيدت التفضيلات إلى الإعداد الافتراضي المخزن.',
 'qbsettings'               => 'لوح سريع',
 'qbsettings-none'          => 'بلا تحديد',
@@ -1199,11 +1239,13 @@
 'math_unknown_error'       => 'خطأ غير معروف',
 'math_unknown_function'    => 'وظيفة غير معروفة',
 'math_lexing_error'        => 'خطأ في الصيغة',
-'math_syntax_error'        => 'خطأ بالصيغة',
-'math_image_error'         => 'فشل التحويل لPNG ، تحقق من تثبيت كل من Latex و dvips و gs و convert.',
+'math_syntax_error'        => 'خطأ في الصياغة',
+'math_image_error'         => 'فشل التحويل لPNG ؛ 
+تحقق من تثبيت كل من Latex و dvips و gs و convert.',
 'math_bad_tmpdir'          => 'لا يمكن الكتابة إلى أو إنشاء مجلد الرياضيات المؤقت',
-'math_bad_output'          => 'لا يمكن الكتابة إلى أو إنشاء مجلد الخروج للرياضيات',
-'math_notexvc'             => 'مفقود texvc executable؛ من فضلك انظر math/README to configure.',
+'math_bad_output'          => 'لا يمكن الكتابة إلى أو إنشاء مجلد الخرج للرياضيات',
+'math_notexvc'             => 'مفقود texvc executable؛
+من فضلك انظر math/README to configure.',
 'prefs-personal'           => 'ملف المستخدم',
 'prefs-rc'                 => 'أحدث التغييرات',
 'prefs-watchlist'          => 'قائمة المراقبة',
@@ -1255,7 +1297,7 @@
 'userrights-reason'           => 'سبب التغيير:',
 'userrights-no-interwiki'     => 'أنت لا تمتلك الصلاحية لتعديل صلاحيات المستخدمين على الويكيات الأخرى.',
 'userrights-nodatabase'       => 'قاعدة البيانات $1 غير موجودة أو ليست محلية.',
-'userrights-nologin'          => 'يجب عليك [[Special:Userlogin|تسجيل الدخول]] بحساب إداري لتعديل صلاحيات المستخدم.',
+'userrights-nologin'          => 'يجب عليك [[Special:UserLogin|تسجيل الدخول]] بحساب إداري لتعديل صلاحيات المستخدم.',
 'userrights-notallowed'       => 'حسابك لا يمتلك السماح لتعديل صلاحيات المستخدم.',
 'userrights-changeable-col'   => 'المجموعات التي يمكنك تغييرها',
 'userrights-unchangeable-col' => 'المجموعات التي لا يمكنك تغييرها',
@@ -1265,9 +1307,9 @@
 'group-user'          => 'مستخدمون',
 'group-autoconfirmed' => 'مستخدمون مؤكدون تلقائيا',
 'group-bot'           => 'بوتات',
-'group-sysop'         => 'إداريين',
+'group-sysop'         => 'مديرو نظام',
 'group-bureaucrat'    => 'بيروقراطيون',
-'group-suppress'      => 'أوفرسايت',
+'group-suppress'      => 'نظار',
 'group-all'           => '(الكل)',
 
 'group-user-member'          => 'مستخدم',
@@ -1275,7 +1317,7 @@
 'group-bot-member'           => 'بوت',
 'group-sysop-member'         => 'مدير نظام',
 'group-bureaucrat-member'    => 'بيروقراط',
-'group-suppress-member'      => 'أوفرسايت',
+'group-suppress-member'      => 'ناظر',
 
 'grouppage-user'          => '{{ns:project}}:مستخدمون',
 'grouppage-autoconfirmed' => '{{ns:project}}:مستخدمون مؤكدون تلقائيا',
@@ -1299,11 +1341,11 @@
 'right-reupload-own'         => 'الكتابة على ملف موجود تم رفعه بواسطة نفس المستخدم',
 'right-reupload-shared'      => 'الرفع على الملفات في مستودع الملفات المشترك محليا',
 'right-upload_by_url'        => 'رفع ملف من عنوان مسار',
-'right-purge'                => 'تحديث كاش الموقع لصفحة بدون صفحة تأكيد',
+'right-purge'                => 'تحديث كاش الموقع لصفحة بدون تأكيد',
 'right-autoconfirmed'        => 'تعديل الصفحات نصف المحمية',
 'right-bot'                  => 'تعامل كعملية أوتوماتيكية',
 'right-nominornewtalk'       => 'عدم جعل التعديلات الطفيفة لصفحات النقاش تظهر برواز الرسائل الجديدة',
-'right-apihighlimits'        => 'استخدام حدود أعلى في استعلامات إيه بي آي',
+'right-apihighlimits'        => 'استخدام حدود أعلى في استعلامات API',
 'right-writeapi'             => 'استخدام API الكتابة',
 'right-delete'               => 'حذف الصفحات',
 'right-bigdelete'            => 'حذف الصفحات ذات التواريخ الكبيرة',
@@ -1311,7 +1353,7 @@
 'right-deletedhistory'       => 'رؤية مدخلات التاريخ المحذوفة، بدون نصوصها المصاحبة',
 'right-browsearchive'        => 'البحث في الصفحات المحذوفة',
 'right-undelete'             => 'استرجاع صفحة',
-'right-suppressrevision'     => 'مراجعة واسترجاع المراجعات المخفية عن الإداريين',
+'right-suppressrevision'     => 'مراجعة واسترجاع المراجعات المخفية عن مديري النظام',
 'right-suppressionlog'       => 'رؤية السجلات السرية',
 'right-block'                => 'منع المستخدمين الآخرين من التعديل',
 'right-blockemail'           => 'منع مستخدم من إرسال بريد إلكتروني',
@@ -1347,7 +1389,7 @@
 'nchanges'                          => '{{PLURAL:$1|تغيير|تغييران|$1 تغييرات|$1 تغيير|$1 تغييرا}}',
 'recentchanges'                     => 'أحدث التغييرات',
 'recentchangestext'                 => 'تابع آخر التغييرات في الويكي من هذه الصفحة.',
-'recentchanges-feed-description'    => 'تابع أحدث التغييرات لهذه الويكي عبر هذه التلقيمة.',
+'recentchanges-feed-description'    => 'تابع أحدث التغييرات للويكي عبر هذه التلقيمة.',
 'rcnote'                            => "بالأسفل {{PLURAL:$1|'''1''' تغيير|آخر '''$1''' تغيير}} في آخر {{PLURAL:$2|يوم|'''$2''' يوم}}، بدءا من $5، $4.",
 'rcnotefrom'                        => "بالأسفل التغييرات منذ '''$2''' (إلى '''$1''' معروضة).",
 'rclistfrom'                        => 'أظهر التغييرات بدءا من $1',
@@ -1375,9 +1417,10 @@
 'recentchangeslinked'          => 'تغييرات ذات علاقة',
 'recentchangeslinked-title'    => 'التغييرات المرتبطة ب "$1"',
 'recentchangeslinked-noresult' => 'لم تحدث تعديلات في الصفحات التي لها وصلات هنا خلال الفترة المحددة.',
-'recentchangeslinked-summary'  => "هذه قائمة بالتغييرات التي تمت حديثًا للصفحات الموصولة من صفحة معينة (أو إلى الأعضاء ضمن تصنيف معين). الصفحات في [[Special:Watchlist|قائمة مراقبتك]] '''سميكة'''",
+'recentchangeslinked-summary'  => "هذه قائمة بالتغييرات التي تمت حديثا للصفحات الموصولة من صفحة معينة (أو إلى الأعضاء ضمن تصنيف معين).
+الصفحات في [[Special:Watchlist|قائمة مراقبتك]] '''سميكة'''",
 'recentchangeslinked-page'     => 'اسم الصفحة:',
-'recentchangeslinked-to'       => 'اظهر التغييرات للصفحات الموصولة للصفحة المعطاة عوضا عن ذلك',
+'recentchangeslinked-to'       => 'أظهر التغييرات للصفحات الموصولة للصفحة المعطاة عوضا عن ذلك',
 
 # Upload
 'upload'                      => 'رفع ملف',
@@ -1385,33 +1428,35 @@
 'reupload'                    => 'أعد الرفع',
 'reuploaddesc'                => 'إلغاء الرفع والرجوع إلى استمارة الرفع',
 'uploadnologin'               => 'لم تقم بتسجيل الدخول',
-'uploadnologintext'           => 'يجب أن تكون [[Special:Userlogin|مسجلا الدخول]] لتتمكن من رفع الملفات.',
+'uploadnologintext'           => 'يجب أن تكون [[Special:UserLogin|مسجلا الدخول]] لتتمكن من رفع الملفات.',
 'upload_directory_missing'    => 'مجلد الرفع ($1) مفقود ولم يمكن إنشاؤه بواسطة خادم الويب.',
-'upload_directory_read_only'  => 'لا يمكن الكتابة على مجلد الرفع ($1) بواسطة خادم الشبكة.',
+'upload_directory_read_only'  => 'مجلد الرفع ($1) لا يمكن الكتابة عليه بواسطة خادم الويب.',
 'uploaderror'                 => 'خطأ في الرفع',
 'uploadtext'                  => "استخدم الاستمارة بالأسفل لرفع الملفات.
-لعرض أو البحث في الملفات المرفوعة سابقا، راجع [[Special:Imagelist|قائمة الملفات المرفوعة]]، عمليات الرفع والحذف موجودة في [[Special:Log/upload|سجل الرفع]].
+لرؤية أو البحث في الملفات المرفوعة سابقا، راجع [[Special:ImageList|قائمة الملفات المرفوعة]]، عمليات الرفع (وإعادة الرفع) مسجلة في [[Special:Log/upload|سجل الرفع]] وعمليات الحذف في [[Special:Log/delete|سجل الحذف]].
 
 لإدراج صورة في صفحة، استخدم الوصلات في الصيغ التالية:
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>'''،
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|نص بديل]]</nowiki>''' أو
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' للوصل للملف مباشرة.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' لاستخدام النسخة الكاملة لملف
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|نص بديل]]</nowiki></tt>''' لاستخدام صورة عرضها 200 بكسل في صندوق في الجانب الأيسر مع 'نص بديل' كوصف
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' للوصل للملف مباشرة بدون عرض الملف.",
 'upload-permitted'            => 'أنواع الملفات المسموحة: $1.',
 'upload-preferred'            => 'أنواع الملفات المفضلة: $1.',
 'upload-prohibited'           => 'أنواع الملفات الممنوعة: $1.',
 'uploadlog'                   => 'سجل الرفع',
 'uploadlogpage'               => 'سجل الرفع',
-'uploadlogpagetext'           => 'في الأسفل قائمة بأحدث عمليات رفع الملفات.',
+'uploadlogpagetext'           => 'في الأسفل قائمة بأحدث عمليات رفع الملفات.
+انظر [[Special:NewImages|معرض الملفات الجديدة]] لعرض بصري أكثر',
 'filename'                    => 'اسم الملف',
 'filedesc'                    => 'ملخص',
 'fileuploadsummary'           => 'ملخص:',
 'filestatus'                  => 'حالة حقوق النسخ:',
 'filesource'                  => 'مصدر:',
 'uploadedfiles'               => 'الملفات المرفوعة',
-'ignorewarning'               => 'تجاهل هذا التحذير واحفظ الملف على أية حال.',
-'ignorewarnings'              => 'أهمل أية تحذيرات',
+'ignorewarning'               => 'تجاهل التحذير واحفظ الملف على أية حال.',
+'ignorewarnings'              => 'تجاهل أية تحذيرات',
 'minlength1'                  => 'أسماء الملفات يجب أن تتكون من حرف واحد على الأقل.',
-'illegalfilename'             => 'يحتوي اسم الملف $1 على رموز غير مقبولة. أعد تسمية الملف من فضلك و قم برفعه مرة أخرى.',
+'illegalfilename'             => 'اسم الملف "$1" يحتوي على حروف غير مسموح بها في عناوين الصفحات.
+من فضلك أعد تسمية الملف وحاول رفعه مرة أخرى.',
 'badfilename'                 => 'تم تغيير اسم الملف إلى "$1".',
 'filetype-badmime'            => 'من غير المسموح به رفع ملفات من النوع "$1".',
 'filetype-unwanted-type'      => "'''\".\$1\"''' هو نوع ملف غير مرغوب فيه.
@@ -1421,42 +1466,53 @@
 'filetype-missing'            => 'الملف بدون امتداد (مثل ".jpg").',
 'large-file'                  => 'ينصح ألا تكون الملفات أكبر من $1؛ هذا الملف حجمه $2.',
 'largefileserver'             => 'حجم هذا الملف أكبر من المسموح به على هذا الخادم.',
-'emptyfile'                   => 'يبدو أن الملف الذي رفعته فارغ. قد يكون سبب ذلك خطأ في كتابة الاسم. من فضلك تأكد من أنك تريد فعلا رفع هذا الملف.',
+'emptyfile'                   => 'يبدو أن الملف الذي رفعته فارغ.
+قد يكون سبب ذلك خطأ في كتابة الاسم.
+من فضلك تأكد من أنك تريد فعلا رفع هذا الملف.',
 'fileexists'                  => 'هناك ملف موجود يحمل نفس هذا الاسم الرجاء التأكد من هذا الملف باتباع الوصلة التالية <strong><tt>$1</tt></strong> قبل القيام بتغييره.',
-'filepageexists'              => 'صفحة الوصف لهذا الملف تم إنشاؤها بالفعل في <strong><tt>$1</tt></strong>، لكن لا يوجد ملف بهذا الاسم حاليا. الملخص الذي تدخله لن يظهر على صفحة الوصف. لجعل ملخصك يظهر هناك، ستحتاج إلى تعديله يدويا',
+'filepageexists'              => 'صفحة الوصف لهذا الملف تم إنشاؤها بالفعل في <strong><tt>$1</tt></strong>، لكن لا يوجد ملف بهذا الاسم حاليا.
+الملخص الذي تدخله لن يظهر على صفحة الوصف.
+لجعل ملخصك يظهر هناك، ستحتاج إلى تعديله يدويا',
 'fileexists-extension'        => 'يوجد ملف باسم مشابه:<br />
 اسم الملف المراد رفعه: <strong><tt>$1</tt></strong><br />
-اسم الملف الموجود بالفعل: <strong><tt>$2</tt></strong><br />
-الاختلاف الوحيد بينهما هو حالة أحرف الامتداد من حيث الكبر أو الصغر. افحص الملفين من أجل التحقق من عدم تطابقهما من فضلك.',
-'fileexists-thumb'            => "<center>'''الصورة الموجودة'''</center>",
-'fileexists-thumbnail-yes'    => 'يبدو أن الملف مصغرا لحجم أعلى <i>(تصغير)</i>. افحص الملف <strong><tt>$1</tt></strong> من فضلك.<br />
+اسم الملف الموجود: <strong><tt>$2</tt></strong><br />
+من فضلك اختر اسما مختلفا.',
+'fileexists-thumb'            => "<center>'''الملف الموجود'''</center>",
+'fileexists-thumbnail-yes'    => 'يبدو أن الملف مصغرا لحجم أعلى <i>(تصغير)</i>. 
+من فضلك افحص الملف <strong><tt>$1</tt></strong>.<br />
 إن كان هو نفس الملف بالحجم الأصلي فلا داعي لرفع تصغير إضافي.',
-'file-thumbnail-no'           => 'يبدأ الملف بـ <strong><tt>$1</tt></strong>. يبدو أن الملف مصغرا لحجم أعلى <i>(تصغير)</i>.
+'file-thumbnail-no'           => 'يبدأ الملف ب <strong><tt>$1</tt></strong>. 
+يبدو أن الملف مصغرا لحجم أعلى <i>(تصغير)</i>.
 إذا كانت لديك الصورة في درجة دقة كاملة قم برفعها، أو قم بتغيير اسم الملف من فضلك.',
-'fileexists-forbidden'        => 'هناك ملف بنفس الاسم حاليا؛ من فضلك تراجع وأعطه اسما جديدا. [[Image:$1|thumb|center|$1]]',
-'fileexists-shared-forbidden' => 'يوجد ملف بنفس الاسم في مستودع الملفات المشترك، من فضلك ارجع و ارفع هذا الملف تحت اسم جديد. [[Image:$1|thumb|center|$1]]',
+'fileexists-forbidden'        => 'هناك ملف بنفس الاسم حاليا؛
+من فضلك تراجع وأعطه اسما جديدا. [[Image:$1|thumb|center|$1]]',
+'fileexists-shared-forbidden' => 'يوجد ملف بنفس الاسم في مستودع الملفات المشترك؛
+من فضلك ارجع وارفع هذا الملف تحت اسم جديد. [[Image:$1|thumb|center|$1]]',
 'file-exists-duplicate'       => 'هذا الملف مكرر  {{PLURAL:$1|للملف|للملفات}} التالية:',
 'successfulupload'            => 'تم رفع الملف بنجاح',
-'uploadwarning'               => 'تحذير رفع الملفات',
+'uploadwarning'               => 'تحذير الرفع',
 'savefile'                    => 'حفظ الملف',
 'uploadedimage'               => 'رفع "[[$1]]"',
 'overwroteimage'              => 'رفع نسخة جديدة من "[[$1]]"',
-'uploaddisabled'              => 'تم إيقاف خاصية رفع الملفات.',
+'uploaddisabled'              => 'تم تعطيل الرفع',
 'uploaddisabledtext'          => 'رفع الملفات معطل في {{SITENAME}}.',
 'uploadscripted'              => 'هذا الملف  يضم كود HTML أو كود آخر يمكن أن يؤول بطريقة خاطئة بواسطة متصفح ويب.',
-'uploadcorrupt'               => 'هذا الملف فاسد أو له امتداد خاطيء. من فضلك تأكد من الملف وأعد الرفع مرة أخرى.',
+'uploadcorrupt'               => 'هذا الملف فاسد أو له امتداد خاطيء.
+من فضلك تأكد من الملف وأعد الرفع مرة أخرى.',
 'uploadvirus'                 => 'الملف يحتوي على فيروس! التفاصيل: $1',
 'sourcefilename'              => 'اسم ملف المصدر:',
 'destfilename'                => 'اسم الملف المستهدف:',
 'upload-maxfilesize'          => 'حجم الملف الأقصى: $1',
 'watchthisupload'             => 'راقب هذه الصفحة',
-'filewasdeleted'              => 'تم رفع ثم حذف ملف بهذا الاسم من قبل. من الأفضل مراجعة $1 قبل رفعه مرة أخرى.',
+'filewasdeleted'              => 'تم رفع ثم حذف ملف بهذا الاسم من قبل.
+من الأفضل مراجعة $1 قبل رفعه مرة أخرى.',
 'upload-wasdeleted'           => "'''تحذير: أنت تقوم برفع ملف تم حذفه في السابق.'''
 
 يجب عليك التيقن من أن الاستمرار برفع هذا الملف ملائم.
 سجل الحذف لهذا الملف معروض هنا:",
-'filename-bad-prefix'         => 'اسم الملف الذي ترفعه يبدأ ب<strong>"$1"</strong>، وهو اسم غير وصفي عادة يوضع تلقائيا من الكاميرات الرقمية. من فضلك اختر اسما أكثر وصفا لملفك.',
-'filename-prefix-blacklist'   => ' #<!-- leave this line exactly as it is --> <pre>
+'filename-bad-prefix'         => 'اسم الملف الذي ترفعه يبدأ ب<strong>"$1"</strong>، وهو اسم غير وصفي عادة يوضع تلقائيا من الكاميرات الرقمية.
+من فضلك اختر اسما أكثر وصفا لملفك.',
+'filename-prefix-blacklist'   => ' #<!-- اترك هذا السطر تماما كما هو --> <pre>
 # الصيغة كالتالي: 
 #   * كل شيء من علامة "#" إلى آخر السطر هو تعليق
 #   * كل سطر غير فارغ هو بادئة لأسماء الملفات النمطية التي توضع تلقائيا من قبل الكاميرات الرقمية
@@ -1469,31 +1525,37 @@
 JD # Jenoptik
 MGP # Pentax
 PICT # misc.
- #</pre> <!-- leave this line exactly as it is -->',
+ #</pre> <!-- اترك هذا السطر تماما كما هو -->',
 
 'upload-proto-error'      => 'بروتوكول غير صحيح',
 'upload-proto-error-text' => 'الرفع عن بعد يتطلب مسارا يبدأ بـ <code>http://</code> أو <code>ftp://</code>.',
 'upload-file-error'       => 'خطأ داخلي',
-'upload-file-error-text'  => 'حدث خطأ داخلي عند محاولة عمل ملف مؤقت على الخادم. من فضلك اتصل بإداري نظام.',
+'upload-file-error-text'  => 'حدث خطأ داخلي عند محاولة عمل ملف مؤقت على الخادم.
+من فضلك اتصل [[Special:ListUsers/sysop|بإداري]].',
 'upload-misc-error'       => 'خطأ غير معروف في الرفع',
-'upload-misc-error-text'  => 'حدث خطأ غير معروف أثناء عملية الرفع. من فضلك تاكد أن المسار صحيح ومن الممكن الدخول عليه ثم حاول مرة أخرى. إذا استمرت المشكلة في الحدوث، اتصل بإداري نظام.',
+'upload-misc-error-text'  => 'حدث خطأ غير معروف أثناء عملية الرفع.
+من فضلك تاكد أن المسار صحيح ومن الممكن الدخول عليه ثم حاول مرة أخرى.
+إذا استمرت المشكلة في الحدوث، اتصل [[Special:ListUsers/sysop|بإداري]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'لم يتمكن من الوصول للمسار',
-'upload-curl-error6-text'  => 'لم يمكن الوصول إلى المسار الذي حددته. من فضلك راجع صحة المسار مرة أخرى وأن الموقع يعمل.',
+'upload-curl-error6-text'  => 'لم يمكن الوصول إلى المسار الذي حددته.
+من فضلك راجع صحة المسار مرة أخرى وأن الموقع يعمل.',
 'upload-curl-error28'      => 'انتهاء مهلة الرفع',
-'upload-curl-error28-text' => 'أخذ الموقع وقتا طويلا للاستجابة. من فضلك تأكد أن الموقع يعمل، وانتظر فترة قصيرة ثم حاول مرة أخرى. ربما تريد المحاولة في وقت أقل ازدحاما.',
+'upload-curl-error28-text' => 'أخذ الموقع وقتا طويلا للاستجابة.
+من فضلك تأكد أن الموقع يعمل، وانتظر فترة قصيرة ثم حاول مرة أخرى.
+ربما تريد المحاولة في وقت أقل ازدحاما.',
 
 'license'            => 'ترخيص:',
 'nolicense'          => 'غير محدد',
 'license-nopreview'  => '(العرض المسبق غير متوفر)',
-'upload_source_url'  => '(عنوان ويب صحيح، يمكن الوصول إليه)',
+'upload_source_url'  => '  (مسار صحيح، يمكن الوصول إليه)',
 'upload_source_file' => ' (ملف على حاسوبك)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'هذه الصفحة الخاصة تعرض كل الملفات المرفوعة.
 افتراضيا آخر الملفات المرفوعة تعرض أعلى القائمة.
-الضغط على رأس العامود تغير الترتيب.',
+الضغط على رأس العامود يغير الترتيب.',
 'imagelist_search_for'  => 'ابحث عن اسم الميديا:',
 'imgfile'               => 'ملف',
 'imagelist'             => 'قائمة الملفات',
@@ -1518,14 +1580,14 @@
 'imagelinks'                     => 'وصلات',
 'linkstoimage'                   => '{{PLURAL:$1|الصفحة|ال$1 صفحة}} التالية تصل إلى هذا الملف:',
 'nolinkstoimage'                 => 'لا توجد صفحات تصل لهذا الملف.',
-'morelinkstoimage'               => 'عرض [[Special:Whatlinkshere/$1|المزيد من الوصلات]] إلى هذا الملف.',
+'morelinkstoimage'               => 'عرض [[Special:WhatLinksHere/$1|المزيد من الوصلات]] إلى هذا الملف.',
 'redirectstofile'                => '{{PLURAL:$1|الملف|ال$1 ملف}} التالي يحول إلى هذا الملف:',
 'duplicatesoffile'               => '{{PLURAL:$1|الملف|ال$1 ملف التالي}} مكررات لهذا الملف:',
 'sharedupload'                   => 'هذا الملف تم رفعه للتشارك بين المشاريع ويمكن استخدامه في المشاريع الأخرى.',
 'shareduploadwiki'               => 'من فضلك انظر $1 لمزيد من المعلومات.',
 'shareduploadwiki-desc'          => 'الوصف على $1 في المستودع المشترك معروض بالأسفل.',
 'shareduploadwiki-linktext'      => 'صفحة وصف الملف',
-'shareduploadduplicate'          => 'هذا الملف مكرر ل$1 من المستودع المشترك.',
+'shareduploadduplicate'          => 'هذا الملف تكرار ل$1 من المستودع المشترك.',
 'shareduploadduplicate-linktext' => 'ملف آخر',
 'shareduploadconflict'           => 'هذا الملف لديه نفس الاسم مثل $1 من المستودع المشترك.',
 'shareduploadconflict-linktext'  => 'ملف آخر',
@@ -1537,25 +1599,26 @@
 # File reversion
 'filerevert'                => 'استرجع $1',
 'filerevert-legend'         => 'استرجع الملف',
-'filerevert-intro'          => '<span class="plainlinks">أنت تسترجع \'\'\'[[Media:$1|$1]]\'\'\' [$4 لنسخة بتاريخ $2، $3].</span>',
+'filerevert-intro'          => "أنت تسترجع '''[[Media:$1|$1]]''' [$4 لنسخة بتاريخ $2، $3].",
 'filerevert-comment'        => 'تعليق:',
 'filerevert-defaultcomment' => 'استرجع للنسخة بتاريخ $1، $2',
 'filerevert-submit'         => 'استرجع',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' تم استرجاعها [$4 لنسخة بتاريخ $2، $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' تم استرجاعها [$4 لنسخة بتاريخ $2، $3].",
 'filerevert-badversion'     => 'لا توجد نسخة محلية سابقة لهذا الملف بالتاريخ المعطى.',
 
 # File deletion
 'filedelete'                  => 'احذف $1',
 'filedelete-legend'           => 'احذف الملف',
 'filedelete-intro'            => "أنت تحذف '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">أنت تحذف نسخة \'\'\'[[Media:$1|$1]]\'\'\' بتاريخ [$4 $3، $2].</span>',
-'filedelete-comment'          => 'تعليق:',
+'filedelete-intro-old'        => "أنت تحذف نسخة '''[[Media:$1|$1]]''' بتاريخ [$4 $3، $2].",
+'filedelete-comment'          => 'السبب للحذف:',
 'filedelete-submit'           => 'حذف',
 'filedelete-success'          => "'''$1''' تم حذفه.",
 'filedelete-success-old'      => '<span class="plainlinks">نسخة \'\'\'[[Media:$1|$1]]\'\'\' بتاريخ $3، $2 تم حذفها.</span>',
 'filedelete-nofile'           => "'''$1''' غير موجود في {{SITENAME}}.",
 'filedelete-nofile-old'       => "لا توجد نسخة مؤرشفة من '''$1''' بالعناصر المحددة.",
-'filedelete-iscurrent'        => 'أنت تحاول حذف أحدث نسخة من هذا الملف. من فضلك استرجع لنسخة أقدم أولا.',
+'filedelete-iscurrent'        => 'أنت تحاول حذف أحدث نسخة من هذا الملف.
+من فضلك استرجع لنسخة أقدم أولا.',
 'filedelete-otherreason'      => 'سبب إضافي/آخر:',
 'filedelete-reason-otherlist' => 'سبب آخر',
 'filedelete-reason-dropdown'  => '*أسباب الحذف الشائعة
@@ -1565,10 +1628,11 @@
 
 # MIME search
 'mimesearch'         => 'بحث MIME',
-'mimesearch-summary' => 'تعمل هذه الصفحة على عرض وتصفية الملفات بناء على نوعها. المدخل: نوع المحتوى/النوع الفرعي، كمثال
+'mimesearch-summary' => 'تعمل هذه الصفحة على عرض وتصفية الملفات بناء على نوعها.
+المدخل: نوع المحتوى/النوع الفرعي، كمثال
 <tt>image/jpeg</tt>.',
 'mimetype'           => 'نوع الملف:',
-'download'           => 'نزل',
+'download'           => 'تنزيل',
 
 # Unwatched pages
 'unwatchedpages' => 'صفحات غير مراقبة',
@@ -1577,8 +1641,9 @@
 'listredirects' => 'عرض التحويلات',
 
 # Unused templates
-'unusedtemplates'     => 'قوالب غير مستعملة',
-'unusedtemplatestext' => 'تحتوي هذه الصفحة على قائمة بالصفحات من نطاق قالب غير المستعملة في صفحات أخرى. تذكر بأن تتحقق من عدم وجود وصلات أخرى لهذه القوالب قبل حذفها.',
+'unusedtemplates'     => 'قوالب غير مستخدمة',
+'unusedtemplatestext' => 'تحتوي هذه الصفحة على قائمة بالصفحات من نطاق قالب غير المستعملة في صفحات أخرى.
+تذكر بأن تتحقق من عدم وجود وصلات أخرى لهذه القوالب قبل حذفها.',
 'unusedtemplateswlh'  => 'وصلات أخرى',
 
 # Random page
@@ -1606,27 +1671,32 @@
 هذا يعني '''\$5''' تعديل متوسط لكل صفحة، و '''\$6''' عرض لكل تعديل.
 
 طول [http://www.mediawiki.org/wiki/Manual:Job_queue طابور الشغل] هو '''\$7'''.",
-'userstatstext'          => "يوجد {{PLURAL:$1|[[Special:Listusers|مستخدم]] مسجل '''واحد'''|'''$1''' [[Special:Listusers|مستخدم]] مسجل}}، منهم '''$2''' (أو '''$4%''') {{PLURAL:$2|لديه|لديهم}} صلاحيات $5.",
+'userstatstext'          => "يوجد {{PLURAL:$1|[[Special:ListUsers|مستخدم]] مسجل '''واحد'''|'''$1''' [[Special:ListUsers|مستخدم]] مسجل}}، منهم '''$2''' (أو '''$4%''') {{PLURAL:$2|لديه|لديهم}} صلاحيات $5.",
 'statistics-mostpopular' => 'أكثر الصفحات مشاهدة',
 
 'disambiguations'      => 'صفحات التوضيح',
 'disambiguationspage'  => 'Template:توضيح',
-'disambiguations-text' => "الصفحات التالية تصل إلى '''صفحة توضيح'''. ينبغي في المقابل أن تصل إلى الصفحة الملائمة. <br />تعامل الصفحة كصفحة توضيح إذا كان بها قالب موجود في [[MediaWiki:Disambiguationspage]]",
+'disambiguations-text' => "الصفحات التالية تصل إلى '''صفحة توضيح'''.
+ينبغي في المقابل أن تصل إلى الصفحة الملائمة. <br />
+تعامل الصفحة كصفحة توضيح إذا كان بها قالب موجود في [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'تحويلات مزدوجة',
-'doubleredirectstext' => "كل سطر في القائمة التالية يحتوي على وصلات للتحويلة الأولى والثانية بالإضافة إلى أول سطر من نص التحويلة الثانية والذي عادة ما يشير إلى المقالة ''المفترض'' أن يتم التحويل إليها مباشرة من التحويلة الأولى أيضا.",
+'doubleredirects'            => 'تحويلات مزدوجة',
+'doubleredirectstext'        => 'هذه الصفحة تعرض الصفحات التي تحول إلى صفحات تحويل أخرى.
+كل سطر يحتوي على وصلات للتحويلة الأولى والثانية، بالإضافة إلى هدف التحويلة الثانية، والذي عادة ما يشير إلى صفحة الهدف "الحقيقية"، التي من المفترض أن تحول إليها التحويلة الأولى.',
+'double-redirect-fixed-move' => '[[$1]] تم نقلها، هي الآن تحويلة إلى [[$2]]',
+'double-redirect-fixer'      => 'مصلح التحويل',
 
 'brokenredirects'        => 'تحويلات مكسورة',
-'brokenredirectstext'    => 'الوصلات التالية تشير لصفحات غير موجودة:',
+'brokenredirectstext'    => 'التحويلات التالية تصل لصفحات غير موجودة.',
 'brokenredirects-edit'   => '(عدل)',
 'brokenredirects-delete' => '(حذف)',
 
 'withoutinterwiki'         => 'صفحات بدون وصلات لغات أخرى',
-'withoutinterwiki-summary' => 'الصفحات التالية لا تصل إلى نسخ بلغات أخرى:',
+'withoutinterwiki-summary' => 'الصفحات التالية لا تصل إلى نسخ بلغات أخرى.',
 'withoutinterwiki-legend'  => 'بادئة',
 'withoutinterwiki-submit'  => 'عرض',
 
-'fewestrevisions' => 'المقالات ذات أقل تعديل',
+'fewestrevisions' => 'الصفحات ذات أقل تعديل',
 
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|بايت|بايت}}',
@@ -1642,8 +1712,8 @@
 'uncategorizedcategories' => 'تصنيفات غير مصنفة',
 'uncategorizedimages'     => 'ملفات غير مصنفة',
 'uncategorizedtemplates'  => 'قوالب غير مصنفة',
-'unusedcategories'        => 'تصنيفات غير مستعملة',
-'unusedimages'            => 'صور غير مستعملة',
+'unusedcategories'        => 'تصنيفات غير مستخدمة',
+'unusedimages'            => 'ملفات غير مستخدمة',
 'popularpages'            => 'صفحات مشهورة',
 'wantedcategories'        => 'تصنيفات مطلوبة',
 'wantedpages'             => 'صفحات مطلوبة',
@@ -1653,7 +1723,7 @@
 'mostlinkedtemplates'     => 'أكثر القوالب وصلا',
 'mostcategories'          => 'أكثر الصفحات تصنيفا',
 'mostimages'              => 'أكثر الملفات ارتباطا',
-'mostrevisions'           => 'أكثر المقالات تعديلا',
+'mostrevisions'           => 'أكثر الصفحات تعديلا',
 'prefixindex'             => 'فهرس بادئة',
 'shortpages'              => 'صفحات قصيرة',
 'longpages'               => 'صفحات طويلة',
@@ -1673,10 +1743,9 @@
 'move'                    => 'نقل',
 'movethispage'            => 'انقل هذه الصفحة',
 'unusedimagestext'        => 'من فضلك لاحظ أن المواقع الأخرى ربما تصل إلى ملف بالمسار المباشر، ولذا ربما يكون معروضا هنا بالرغم من كونه مستخدما.',
-'unusedcategoriestext'    => 'التصنيفات التالية موجودة على الرغم من أنها لا تحتوي على أية مقالات أو تصنيفات أخرى.',
+'unusedcategoriestext'    => 'التصنيفات التالية موجودة على الرغم من أنها لا تحتوي على أية صفحات أو تصنيفات أخرى.',
 'notargettitle'           => 'لا هدف',
-'notargettext'            => 'لم تحدد الصفحة او المستخدم المستهدف
-لعمل هذه الخاصية.',
+'notargettext'            => 'لم تحدد الصفحة أو المستخدم المستهدف لعمل هذه الخاصية.',
 'nopagetitle'             => 'لا توجد صفحة هدف كهذه',
 'nopagetext'              => 'صفحة الهدف التي حددتها غير موجودة.',
 'pager-newer-n'           => '{{PLURAL:$1|أجدد 1|أجدد $1}}',
@@ -1697,42 +1766,44 @@
 'all-logs-page'        => 'كل السجلات',
 'log-search-legend'    => 'ابحث عن سجلات',
 'log-search-submit'    => 'اذهب',
-'alllogstext'          => 'عرض شامل لكل السجلات المتوفرة في {{SITENAME}}. باستطاعتك جعل القائمة أكثر تحديدا وذلك باختيار نوع العملية، أو اسم المستخدم، أو الصفحات المتأثرة.',
+'alllogstext'          => 'عرض شامل لكل السجلات المتوفرة في {{SITENAME}}. 
+باستطاعتك جعل القائمة أكثر تحديدا وذلك باختيار نوع العملية، أو اسم المستخدم، أو الصفحات المتأثرة.',
 'logempty'             => 'لا توجد مدخلات مطابقة في السجل.',
 'log-title-wildcard'   => 'البحث عن عناوين تبدأ بهذا النص',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'كل الصفحات',
 'alphaindexline'    => '$1 إلى $2',
 'nextpage'          => 'الصفحة التالية ($1)',
 'prevpage'          => 'الصفحة السابقة ($1)',
 'allpagesfrom'      => 'عرض الصفحات بدءا من:',
-'allarticles'       => 'كل المقالات',
+'allarticles'       => 'كل الصفحات',
 'allinnamespace'    => 'كل الصفحات (في نطاق $1)',
 'allnotinnamespace' => 'كل الصفحات (ليست في نطاق $1)',
 'allpagesprev'      => 'السابق',
 'allpagesnext'      => 'التالي',
 'allpagessubmit'    => 'اذهب',
 'allpagesprefix'    => 'عرض الصفحات التي تبدأ بـ:',
-'allpagesbadtitle'  => 'العنوان المقترح للصفحة غير مقبول أو يضم لغات أخرى أو سابقة إنترويكي. يمكن أن يتضمن حروفا لا يمكن استعمالها للعناوين.',
+'allpagesbadtitle'  => 'العنوان المقترح للصفحة غير مقبول أو يضم لغات أخرى أو سابقة إنترويكي.
+يمكن أن يتضمن حروفا لا يمكن استعمالها للعناوين.',
 'allpages-bad-ns'   => '{{SITENAME}} لا يوجد بها نطاق "$1".',
 
 # Special:Categories
 'categories'                    => 'تصنيفات',
-'categoriespagetext'            => 'التصنيفات التالية تحتوي على صفحات أو وسائط.',
-'categoriesfrom'                => 'أظهر التغييرات بدءا من:',
+'categoriespagetext'            => 'التصنيفات التالية تحتوي على صفحات أو ميديا.',
+'categoriesfrom'                => 'أظهر التصنيفات بدءا من:',
 'special-categories-sort-count' => 'رتب بالعدد',
 'special-categories-sort-abc'   => 'رتب هجائيا',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'عرض المستخدمين بدءا من:',
 'listusers-submit'   => 'عرض',
 'listusers-noresult' => 'لم يتم إيجاد مستخدم.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'صلاحيات مجموعات المستخدمين',
 'listgrouprights-summary'  => 'التالي قائمة بمجموعات المستخدمين المعرفة في هذا الويكي، بصلاحياتهم المصاحبة.
-معلومات إضافية حول الصلاحيات المنفردة يمكن العثور عليها [[{{MediaWiki:Listgrouprights-helppage}}|هنا]].',
+ربما تكون هناك [[{{MediaWiki:Listgrouprights-helppage}}|معلومات إضافية]] حول الصلاحيات المنفردة.',
 'listgrouprights-group'    => 'المجموعة',
 'listgrouprights-rights'   => 'الصلاحيات',
 'listgrouprights-helppage' => 'Help:صلاحيات المجموعات',
@@ -1740,18 +1811,15 @@
 
 # E-mail user
 'mailnologin'     => 'لا يوجد عنوان للإرسال',
-'mailnologintext' => 'يجب أن تقوم [[Special:Userlogin|بتسجيل الدخول]] وإدخال بريد إلكتروني صالح في صفحة [[Special:Preferences|التفضيلات]] لتتمكن من إرسال الرسائل لمستخدمين آخرين.',
+'mailnologintext' => 'يجب أن تقوم [[Special:UserLogin|بتسجيل الدخول]] وإدخال بريد إلكتروني صالح في صفحة [[Special:Preferences|التفضيلات]] لتتمكن من إرسال الرسائل لمستخدمين آخرين.',
 'emailuser'       => 'إرسال رسالة لهذا المستخدم',
 'emailpage'       => 'إرسال رسالة للمستخدم',
-'emailpagetext'   => 'لو أن هذا المستخدم قد قام بإدخال عنوان بريدي صحيح في تفضيلاته،
-فسيتم إرسال رسالة واحدة له بالنموذج أدناه.
-العنوان الذي قمت أنت بإدخاله لك في تفضيلات المستخدم،
-سيظهر في مكان المرسل في الرسالة التي سترسل له، ليتمكن من الرد عليك.',
+'emailpagetext'   => 'لو أن هذا المستخدم قد قام بإدخال عنوان بريد إلكتروني صحيح في تفضيلاته، فسيتم إرسال رسالة واحدة له بالنموذج أدناه.
+العنوان الذي قمت أنت بإدخاله لك في [[Special:Preferences|تفضيلات المستخدم]]، سيظهر في مكان المرسل في الرسالة التي سترسل له، ليتمكن من الرد عليك.',
 'usermailererror' => 'جسم البريد أرجع خطأ:',
 'defemailsubject' => 'رسالة من {{SITENAME}}',
 'noemailtitle'    => 'لا يوجد عنوان بريد إلكتروني',
-'noemailtext'     => 'لم يحدد هذا المستخدم عنوان بريد إلكتروني صحيح،
-أو طلب عدم استلام الرسائل من المستخدمين الآخرين.',
+'noemailtext'     => 'لم يحدد هذا المستخدم عنوان بريد إلكتروني صحيح، أو طلب عدم استلام الرسائل من المستخدمين الآخرين.',
 'emailfrom'       => 'من',
 'emailto'         => 'إلى',
 'emailsubject'    => 'الموضوع',
@@ -1766,29 +1834,28 @@
 # Watchlist
 'watchlist'            => 'قائمة مراقبتي',
 'mywatchlist'          => 'قائمة مراقبتي',
-'watchlistfor'         => "(ل '''$1''')",
-'nowatchlist'          => 'لا توجد عناوين في قائمة مراقبتك.',
+'watchlistfor'         => "(ل'''$1''')",
+'nowatchlist'          => 'لا توجد مدخلات في قائمة مراقبتك.',
 'watchlistanontext'    => 'الرجاء $1 لعرض أو تعديل الصفحات في قائمة مراقبتك.',
 'watchnologin'         => 'غير مسجل',
-'watchnologintext'     => 'يجب أن تكون [[Special:Userlogin|مسجلا الدخول]] لتعدل قائمة مراقبتك.',
+'watchnologintext'     => 'يجب أن تكون [[Special:UserLogin|مسجلا الدخول]] لتعدل قائمة مراقبتك.',
 'addedwatch'           => 'تمت الإضافة لقائمة المراقبة',
-'addedwatchtext'       => 'تمت إضافة الصفحة  "$1" إلى [[Special:Watchlist|قائمة المراقبة]] خاصتك. سيتم وضع التغييرات القادمة على هذه الصفحة، وصفحة النقاش الخاصة بها سيتم وضعها هناك. وسيتم اظهار اسم الصفحة بخط <b>عريض</b> في صفحة [[Special:Recentchanges|أحدث التغييرات]] لتسهيل تحديدها واكتشافها.
-
-إذا كنت تريد إزالة الصفحة من قائمة المراقبة لديك، اضغط على "توقف عن المراقبة" بالأعلى.',
+'addedwatchtext'       => "تمت إضافة الصفحة  \"\$1\" إلى [[Special:Watchlist|قائمة المراقبتك]].
+التغييرات القادمة على هذه الصفحة وصفحة النقاش الخاصة بها سيتم وضعها هناك، وسيتم إظهار اسم الصفحة بخط '''عريض''' في صفحة [[Special:RecentChanges|أحدث التغييرات]] لتسهيل تحديدها واكتشافها.",
 'removedwatch'         => 'تمت الإزالة من قائمة المراقبة',
-'removedwatchtext'     => 'تمت إزالة الصفحة "[[:$1]]" من قائمة مراقبتك.',
+'removedwatchtext'     => 'الصفحة "[[:$1]]" تمت إزالتها من [[Special:Watchlist|قائمة مراقبتك]].',
 'watch'                => 'مراقبة',
 'watchthispage'        => 'راقب هذه الصفحة',
 'unwatch'              => 'إيقاف المراقبة',
 'unwatchthispage'      => 'توقف عن المراقبة',
 'notanarticle'         => 'ليست صفحة محتوى',
-'notvisiblerev'        => 'النسخة تم حذفها',
-'watchnochange'        => 'لم يتم تعديل أي صفحة في قائمة مراقبتك خلال الفترة المحددة.',
+'notvisiblerev'        => 'المراجعة تم حذفها',
+'watchnochange'        => 'لم يتم تعديل أي صفحة في قائمة مراقبتك خلال الفترة الزمنية المحددة.',
 'watchlist-details'    => '{{PLURAL:$1|$1 صفحة|$1 صفحة}} مراقبة بدون عد صفحات النقاش.',
-'wlheader-enotif'      => '* خاصية الإعلام بالبريد الإلكتروني مفعلة.',
+'wlheader-enotif'      => '* الإخطار بالبريد الإلكتروني مفعل.',
 'wlheader-showupdated' => "* الصفحات التي تم تحريرها بعد زيارتك لها لآخر مرة معروضة بالخط '''العريض'''",
 'watchmethod-recent'   => 'فحص التعديلات الأخيرة للصفحات المراقبة',
-'watchmethod-list'     => 'إظهار التحريرات في الصفحات المراقبة',
+'watchmethod-list'     => 'فحص الصفحات المراقبة للتعديلات الحديثة',
 'watchlistcontains'    => 'تحتوي قائمة مراقبتك على $1 {{PLURAL:$1|صفحة|صفحات}}.',
 'iteminvalidname'      => "مشكلة في المدخل '$1'، اسم غير صحيح...",
 'wlnote'               => "بالأسفل {{PLURAL:$1|آخر تغيير|آخر '''$1''' تغيير}} في آخر {{PLURAL:$2|ساعة|'''$2''' ساعة}}.",
@@ -1804,34 +1871,34 @@
 'watching'   => 'مراقبة...',
 'unwatching' => 'إزالة المراقبة...',
 
-'enotif_mailer'                => 'نظام {{SITENAME}} البريدي للملاحظات',
-'enotif_reset'                 => 'اعتبر كل الصفحات تم زيارتها',
+'enotif_mailer'                => 'نظام {{SITENAME}} البريدي للإخطارات',
+'enotif_reset'                 => 'التعليم على كل الصفحات كمزارة',
 'enotif_newpagetext'           => 'هذه صفحة جديدة.',
 'enotif_impersonal_salutation' => 'مستخدم {{SITENAME}}',
 'changed'                      => 'تم التغيير',
 'created'                      => 'أنشأ',
 'enotif_subject'               => 'صفحة {{SITENAME}} $PAGETITLE تم $CHANGEDORCREATED بواسطة $PAGEEDITOR',
-'enotif_lastvisited'           => 'انظر $1 لمراجعة كل التغييرات منذ زيارتك الأخيرة.',
+'enotif_lastvisited'           => 'انظر $1 لكل التغييرات منذ زيارتك الأخيرة.',
 'enotif_lastdiff'              => 'انظر $1 لرؤية هذا التغيير.',
 'enotif_anon_editor'           => 'مستخدم مجهول $1',
 'enotif_body'                  => 'عزيزي $WATCHINGUSERNAME،
 
-إن صفحة $PAGETITLE في {{SITENAME}} قد تغيرت إلى $CHANGEDORCREATED من قبل $PAGEEDITOR، لرؤية النسخة الحالية من الصفحة انظر هنا: $PAGETITLE_URL.
+إن صفحة $PAGETITLE في {{SITENAME}} قد تغيرت إلى $CHANGEDORCREATED من قبل $PAGEEDITOR، لرؤية النسخة الحالية من الصفحة انظر: $PAGETITLE_URL.
 
 $NEWPAGE
 
-ملخص التحرير: $PAGESUMMARY $PAGEMINOREDIT
+ملخص تعديل المحرر: $PAGESUMMARY $PAGEMINOREDIT
 
-اتصل بالمستخدم المحرر:
+اتصل بالمحرر:
 بريد إلكتروني: $PAGEEDITOR_EMAIL
 صفحة المستخدم: $PAGEEDITOR_WIKI
 
 لن يكون هنالك أي إخطارات أخرى عن أية تغييرات تتم في المستقبل إلا إذا زرت هذه الصفحة. يمكنك أيضا أن تعيد تصفير عداد الإخطارات لجميع الصفحات التي تراقبها في قائمة مراقبتك.
 
-رسالة إرشادية من {{SITENAME}}
+نظام إخطار {{SITENAME}}
 
 --
-لتغيير قائمة مراقبتك اذهب إلى:
+لتغيير إعدادات قائمة مراقبتك، اذهب إلى:
 {{fullurl:{{ns:special}}:Watchlist/edit}}
 
 للاقتراحات والحصول على مساعدة إضافية:
@@ -1847,7 +1914,8 @@
 'delete-confirm'              => 'حذف "$1"',
 'delete-legend'               => 'حذف',
 'historywarning'              => 'تحذير: الصفحة التي توشك على حذفها لديها تاريخ:',
-'confirmdeletetext'           => 'أنت على وشك أن تقوم بحذف صفحة أو صورة بالإضافة إلى جميع التعديلات عليها بشكل دائم من قاعدة البيانات. الرجاء التأكد من عزمك على الحذف وبأنك مدرك لنتائج هذه العملية. عمليات الحذف يجب أن تتم بناء على [[{{MediaWiki:Policy-url}}|القواعد المتفق عليها]].',
+'confirmdeletetext'           => 'أنت على وشك أن تقوم بحذف صفحة بالإضافة إلى كل تاريخها.
+من فضلك التأكد من عزمك على الحذف، وبأنك مدرك للعواقب، وبأنك تقوم بهذا بالتوافق مع [[{{MediaWiki:Policy-url}}|السياسة]].',
 'actioncomplete'              => 'انتهاء العملية',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" تم حذفها.
 انظر في $2 لسجل آخر عمليات الحذف.',
@@ -1874,40 +1942,47 @@
 'rollback_short'              => 'استرجاع',
 'rollbacklink'                => 'استرجاع',
 'rollbackfailed'              => 'لم ينجح الاسترجاع',
-'cantrollback'                => 'لم يمكن استرجاع التعديل؛ آخر مساهم هو المستخدم الوحيد الذي عدل هذه الصفحة.',
-'alreadyrolled'               => 'لم ينجح استرجاع آخر تعديل لصفحة [[$1]] من قبل [[User:$2|$2]] ([[User talk:$2|نقاش]]) لأن هنالك من قام بتعديل أو استرجاع هذه الصفحة من قبل.
+'cantrollback'                => 'لم يمكن استرجاع التعديل؛
+آخر مساهم هو المؤلف الوحيد لهذه الصفحة.',
+'alreadyrolled'               => 'لم يمكن استرجاع آخر تعديل ل[[$1]] بواسطة [[User:$2|$2]] ([[User talk:$2|نقاش]] | [[Special:Contributions/$2|{{int:contribslink}}]])؛
+شخص آخر عدل أو استرجع الصفحة بالفعل.
 
-آخر تعديل كان بواسطة [[User:$3|$3]] ([[User talk:$3|نقاش]]).',
+آخر تعديل كان بواسطة [[User:$3|$3]] ([[User talk:$3|نقاش]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'تعليق التعديل كان: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'استرجع التعديلات بواسطة [[Special:Contributions/$2|$2]] ([[User talk:$2|نقاش]]) حتى آخر نسخة بواسطة [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'rollback-success'            => 'استرجع تعديلات $1؛ استرجع حتى آخر نسخة بواسطة $2.',
-'sessionfailure'              => 'يبدو أنه هناك مشكلة في هذه الجلسة الخاصة بك؛ لذلك فقد ألغيت هذه العملية كإجراء احترازي ضد الاختراق. الرجاء الضغط على مفتاح "العودة" (Back) للرجوع للصفحة التي جئت منها ثم قم بإعادة تحميلها قبل المحاولة مرة أخرى.',
+'rollback-success'            => 'استرجع تعديلات $1؛
+استرجع حتى آخر نسخة بواسطة $2.',
+'sessionfailure'              => 'يبدو أنه هناك مشكلة في هذه جلسة الدخول الخاصة بك؛
+لذلك فقد ألغيت هذه العملية كإجراء احترازي ضد الاختراق.
+من فضلك اضغط على مفتاح "رجوع" لتحميل الصفحة التي جئت منها، ثم حاول مرة أخرى.',
 'protectlogpage'              => 'سجل الحماية',
-'protectlogtext'              => 'بالأسفل قائمة بالصفحات التي تمت حمايتها أو إزالة الحماية عنها. للمزيد من المعلومات انظر [[Special:Protectedpages|قائمة الصفحات المحمية]].',
+'protectlogtext'              => 'بالأسفل قائمة بالصفحات التي تمت حمايتها أو إزالة الحماية عنها.
+انظر [[Special:ProtectedPages|قائمة الصفحات المحمية]] لقائمة بعمليات حماية الصفحات المفعلة حاليا.',
 'protectedarticle'            => 'حمى "[[$1]]"',
-'modifiedarticleprotection'   => 'غير مستوى الحماية ل‍ "[[$1]]"',
+'modifiedarticleprotection'   => 'غير مستوى الحماية ل"[[$1]]"',
 'unprotectedarticle'          => 'أزال حماية [[$1]]',
-'protect-title'               => 'ضبط مستوى الحماية ل‍ "$1"',
+'protect-title'               => 'ضبط مستوى الحماية ل"$1"',
 'protect-legend'              => 'تأكيد الحماية',
 'protectcomment'              => 'تعليق:',
 'protectexpiry'               => 'تنتهي في:',
 'protect_expiry_invalid'      => 'وقت الانتهاء غير صحيح.',
 'protect_expiry_old'          => 'وقت انتهاء المنع يقع في الماضي.',
 'protect-unchain'             => 'فصل سماح النقل',
-'protect-text'                => 'يمكنك هنا أن تعرض و تغير مستوى الحماية للصفحة <strong><nowiki>$1</nowiki></strong>.',
+'protect-text'                => 'يمكنك هنا أن تعرض وتغير مستوى الحماية للصفحة <strong><nowiki>$1</nowiki></strong>.',
 'protect-locked-blocked'      => 'لا يمكنك تغيير مستويات الحماية وأنت ممنوع.
 الإعدادات الحالية للصفحة <strong>$1</strong> هي:',
 'protect-locked-dblock'       => 'لا يمكن تغيير مستويات الحماية بسبب غلق قاعدة البيانات حاليا.
 الإعدادات الحالية للصفحة <strong>$1</strong> هي:',
 'protect-locked-access'       => 'لا يملك حسابك هذا صلاحية تغيير مستوى حماية الصفحة.
 الإعدادات الحالية للصفحة <strong>$1</strong> هي:',
-'protect-cascadeon'           => 'هذه الصفحة محمية لكونها مضمنة في {{PLURAL:$1|الصفحة|الصفحات}} التالية، والتي بها خيار حماية الصفحات المدمجة فعال. يمكنك تغيير مستوى حماية هذه الصفحة بدون التأثير على حماية الصفحات المدمجة الأخرى.',
+'protect-cascadeon'           => 'هذه الصفحة محمية لكونها مضمنة في {{PLURAL:$1|الصفحة|الصفحات}} التالية، والتي بها خيار حماية الصفحات المدمجة فعال.
+يمكنك تغيير مستوى حماية هذه الصفحة بدون التأثير على حماية الصفحات المدمجة الأخرى.',
 'protect-default'             => '(افتراضي)',
 'protect-fallback'            => 'يتطلب السماح "$1"',
 'protect-level-autoconfirmed' => 'منع المستخدمين غير المسجلين',
 'protect-level-sysop'         => 'مدراء النظام فقط',
 'protect-summary-cascade'     => 'مضمنة',
-'protect-expiring'            => 'تنتهي في $1 (ت‌ع‌م)',
+'protect-expiring'            => 'تنتهي في $1 (UTC)',
 'protect-cascade'             => 'احم الصفحات المضمنة في هذه الصفحة (حماية مضمنة)',
 'protect-cantedit'            => 'لا يمكنك تغيير مستويات الحماية لهذه الصفحة، لأنك لا تمتلك الصلاحية لتعديلها.',
 'restriction-type'            => 'سماح:',
@@ -1930,41 +2005,50 @@
 # Undelete
 'undelete'                     => 'عرض الصفحات المحذوفة',
 'undeletepage'                 => 'عرض واسترجاع الصفحات المحذوفة',
-'undeletepagetitle'            => "'''التالي يتكون من النسخ المحذوفة من [[:$1]]'''.",
+'undeletepagetitle'            => "'''التالي يتكون من المراجعات المحذوفة من [[:$1]]'''.",
 'viewdeletedpage'              => 'عرض الصفحات المحذوفة',
-'undeletepagetext'             => 'تم حذف الصفحات التالية ولكنها مازالت في الأرشيف ويمكن استرجاعها. يمكن تنظيف الأرشيف بشكل دوري.',
-'undelete-fieldset-title'      => 'استرجاع النسخ',
-'undeleteextrahelp'            => "لاسترجاع الصفحة كاملة، اترك جميع الصناديق فارغة
-و اضغط '''''استرجاع'''''. للاسترجاع بشكل انتقائي، ضع علامة في الصناديق أمام التعديلات التي تريد استرجاعها، و اضغط '''''استرجاع'''''. الضغط على '''''إلغاء''''' سيؤدي إلى إفراغ التعليق و حذف جميع العلامات من الصناديق.",
-'undeleterevisions'            => '$1 {{PLURAL:$1|نسخة|نسخة}} تم أرشفتها',
-'undeletehistory'              => 'لو استرجعت الصفحة، كل النسخ سيتم استرجاعها إلى التاريخ.
-لو كان قد تم إنشاء صفحة جديدة بالاسم نفسه بعد الحذف، النسخ المسترجعة ستظهر في التاريخ السابق. أيضا لاحظ أن الضوابط على نسخ الملف ستضيع مع الاسترجاع',
-'undeleterevdel'               => 'الاسترجاع لن يتم إذا كان سينتج عنه أن تكون النسخة أعلى الصفحة أو الملف محذوفة جزئيا. في مثل هذه الحالات، يجب عليك إظهار أحدث النسخ المحذوفة.',
-'undeletehistorynoadmin'       => 'لقد تم حذف هذه الصفحة للأسباب المدرجة في الأسفل. إلى جانب أسباب الحذف يمكن رؤية المستخدمين الذين قاموا بالتعديل على هذه الصفحة قبل حذفها. بإمكان الإداريين فقط رؤية المحتويات الأصلية للمقال والتعديلات عليها.',
-'undelete-revision'            => 'النسخة المحذوفة ل$1 (بتاريخ $2) بواسطة $3:',
-'undeleterevision-missing'     => 'نسخة غير صحيحة أو مفقودة. ربما لديك وصلة سيئة، أو ربما النسخة تم استرجاعها أو إزالتها من الأرشيف.',
-'undelete-nodiff'              => 'لم يتم العثور على نسخة سابقة.',
+'undeletepagetext'             => 'تم حذف الصفحات التالية ولكنها مازالت في الأرشيف ويمكن استرجاعها.
+يمكن تنظيف الأرشيف بشكل دوري.',
+'undelete-fieldset-title'      => 'استرجاع المراجعات',
+'undeleteextrahelp'            => "لاسترجاع الصفحة كاملة، اترك جميع الصناديق فارغة واضغط '''''استرجاع'''''.
+للاسترجاع بشكل انتقائي، ضع علامة في الصناديق أمام التعديلات التي تريد استرجاعها، واضغط '''''استرجاع'''''.
+الضغط على '''''إلغاء''''' سيؤدي إلى إفراغ التعليق ومسح جميع العلامات من الصناديق.",
+'undeleterevisions'            => '$1 {{PLURAL:$1|مراجعة|مراجعة}} تمت أرشفتها',
+'undeletehistory'              => 'لو استرجعت الصفحة، كل المراجعات سيتم استرجاعها إلى التاريخ.
+لو كان قد تم إنشاء صفحة جديدة بالاسم نفسه بعد الحذف، المراجعات المسترجعة ستظهر في التاريخ السابق.
+أيضا لاحظ أن الضوابط على مراجعات الملف ستضيع مع الاسترجاع',
+'undeleterevdel'               => 'الاسترجاع لن يتم إذا كان سينتج عنه أن تكون المراجعة أعلى الصفحة أو الملف محذوفة جزئيا.
+في مثل هذه الحالات، يجب عليك إظهار أحدث المراجعات المحذوفة.',
+'undeletehistorynoadmin'       => 'هذه الصفحة تم حذفها.
+السبب للحذف معروض في الملخص بالأسفل، إلى جانب تفاصيل المستخدمين الذين قاموا بالتعديل على هذه الصفحة قبل حذفها.
+نص المراجعات المحذوفة هذه متوفر فقط للإداريين.',
+'undelete-revision'            => 'المراجعة المحذوفة ل$1 (بتاريخ $2) بواسطة $3:',
+'undeleterevision-missing'     => 'مراجعة غير صحيحة أو مفقودة.
+ربما لديك وصلة سيئة، أو ربما المراجعة تم استرجاعها أو إزالتها من الأرشيف.',
+'undelete-nodiff'              => 'لم يتم العثور على مراجعة سابقة.',
 'undeletebtn'                  => 'استرجاع',
 'undeletelink'                 => 'استرجاع',
 'undeletereset'                => 'إلغاء',
 'undeletecomment'              => 'تعليق:',
 'undeletedarticle'             => 'استرجع "[[$1]]"',
 'undeletedrevisions'           => 'تم استرجاع {{PLURAL:$1|تعديل واحد|تعديلان|$1 تعديلات|$1 تعديل|$1 تعديلا}}',
-'undeletedrevisions-files'     => '{{PLURAL:$1|1 نسخة|$1 نسخة}} و {{PLURAL:$2|1 ملف|$2 ملف}} تم استرجاعها',
+'undeletedrevisions-files'     => '{{PLURAL:$1|1 مراجعة|$1 مراجعة}} و {{PLURAL:$2|1 ملف|$2 ملف}} تم استرجاعها',
 'undeletedfiles'               => '{{PLURAL:$1|ملف|ملفات}} $1 تم استرجاع',
-'cannotundelete'               => 'فشل الاسترجاع؛ ربما قام شخص آخر باسترجاع الصفحة بالفعل.',
+'cannotundelete'               => 'فشل الاسترجاع؛
+ربما قام شخص آخر باسترجاع الصفحة بالفعل.',
 'undeletedpage'                => "<big>'''تم استرجاع $1'''</big>
 
 راجع [[Special:Log/delete|سجل الحدف]] لمعاينة عمليات الحذف و الاسترجاعات الحديثة.",
 'undelete-header'              => 'انظر الصفحات المحذوفة حديثا في [[Special:Log/delete|سجل الحذف]].',
 'undelete-search-box'          => 'ابحث في الصفحات المحذوفة',
 'undelete-search-prefix'       => 'عرض الصفحات التي تبدأ بـ:',
-'undelete-search-submit'       => 'ابحث',
+'undelete-search-submit'       => 'بحث',
 'undelete-no-results'          => 'لم يتم العثور على صفحات مطابقة في أرشيف المحذوفات.',
-'undelete-filename-mismatch'   => 'لم يمكن استرجاع نسخة الملف بتاريخ $1: اسم الملف لا يطابق',
-'undelete-bad-store-key'       => 'لم يمكن استرجاع نسخة الملف بتاريخ $1: الملف كان مفقودا قبل الحذف',
+'undelete-filename-mismatch'   => 'لم يمكن استرجاع مراجعة الملف بتاريخ $1: اسم الملف لا يطابق',
+'undelete-bad-store-key'       => 'لم يمكن استرجاع مراجعة الملف بتاريخ $1: الملف كان مفقودا قبل الحذف',
 'undelete-cleanup-error'       => 'خطأ حذف ملف أرشيف غير مستخدم "$1".',
-'undelete-missing-filearchive' => 'غير قادر على استرجاع ملف الأرشيف رقم $1 لأنه ليس في قاعدة البيانات. ربما يكون قد تم استرجاعه.',
+'undelete-missing-filearchive' => 'غير قادر على استرجاع ملف الأرشيف رقم $1 لأنه ليس في قاعدة البيانات.
+ربما يكون قد تم استرجاعه.',
 'undelete-error-short'         => 'خطأ استرجاع ملف: $1',
 'undelete-error-long'          => 'حدثت أخطاء أثناء استرجاع الملف:
 
@@ -1978,7 +2062,7 @@
 # Contributions
 'contributions' => 'مساهمات المستخدم',
 'mycontris'     => 'مساهماتي',
-'contribsub2'   => 'للمستخدم $1 ($2)',
+'contribsub2'   => 'ل$1 ($2)',
 'nocontribs'    => 'لم يتم العثور على تغييرات تطابق هذه المحددات.',
 'uctop'         => '(أعلى)',
 'month'         => 'من شهر (وأقدم):',
@@ -1993,17 +2077,17 @@
 
 # What links here
 'whatlinkshere'            => 'ماذا يصل هنا',
-'whatlinkshere-title'      => 'الصفحات التي تصل إلى $1',
+'whatlinkshere-title'      => 'الصفحات التي تصل إلى "$1"',
 'whatlinkshere-page'       => 'الصفحة:',
 'linklistsub'              => '(قائمة الوصلات)',
-'linkshere'                => "الصفحات التالية تحتوي على وصلة إلى '''[[:$1]]''':",
+'linkshere'                => "الصفحات التالية تصل إلى '''[[:$1]]''':",
 'nolinkshere'              => "لا توجد صفحات تصل إلى '''[[:$1]]'''.",
 'nolinkshere-ns'           => "لا تصل أي صفحة إلى '''[[:$1]]''' في النطاق المختار.",
 'isredirect'               => 'صفحة تحويل',
 'istemplate'               => 'مضمن',
 'isimage'                  => 'وصلة صورة',
-'whatlinkshere-prev'       => '{{PLURAL:$1|السابق|الـ $1 السابقة}}',
-'whatlinkshere-next'       => '{{PLURAL:$1|القادمة|الـ $1 القادمة}}',
+'whatlinkshere-prev'       => '{{PLURAL:$1|السابق|ال$1 السابقة}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|القادمة|ال$1 القادمة}}',
 'whatlinkshere-links'      => '← وصلات',
 'whatlinkshere-hideredirs' => '$1 التحويلات',
 'whatlinkshere-hidetrans'  => '$1 التضمينات',
@@ -2013,12 +2097,11 @@
 
 # Block/unblock
 'blockip'                         => 'منع مستخدم',
-'blockip-legend'                  => 'امنع المستخدم',
-'blockiptext'                     => 'استخدم الاستمارة أدناه لمنع عنوان أيبي
-أو مستخدم مسجل من الكتابة.
-يجب أن يتم هذا فقط لمنع التخريب ومتوافقا مع
-[[{{MediaWiki:Policy-url}}|السياسة]] المتبعة هنا.
-قم بذكر السبب أدناه (كمثال، اذكر بعض الصفحات التي قام بتخريبها تحديدا).',
+'blockip-legend'                  => 'منع المستخدم',
+'blockiptext'                     => 'استخدم الاستمارة أدناه لمنع عنوان أيبي أو مستخدم مسجل من الكتابة.
+يجب أن يتم هذا فقط لمنع التخريب، وبالتوافق مع
+[[{{MediaWiki:Policy-url}}|السياسة]].
+اذكر سببا محددا أدناه (على سبيل المثال، اذكر بعض الصفحات المعينة التي قام بتخريبها).',
 'ipaddress'                       => 'عنوان الأيبي:',
 'ipadressorusername'              => 'عنوان الأيبي أو اسم المستخدم:',
 'ipbexpiry'                       => 'مدة المنع:',
@@ -2027,43 +2110,42 @@
 'ipbreason-dropdown'              => '*أسباب المنع الشائعة
 ** كتابة معلومات زائفة
 ** إزالة المحتوى من الصفحات
-** سخام وصلات لمواقع خارجية
+** سبام وصلات لمواقع خارجية
 ** كتابة كلام لا معنى له في الصفحات
 ** سلوك عدواني
 ** إساءة استخدام حسابات متعددة
 ** اسم مستخدم غير مقبول',
-'ipbanononly'                     => 'منع المستخدمين المجهولين فقط',
+'ipbanononly'                     => 'امنع المستخدمين المجهولين فقط',
 'ipbcreateaccount'                => 'امنع إنشاء الحسابات',
-'ipbemailban'                     => 'منع المستخدم من إرسال بريد إلكتروني',
+'ipbemailban'                     => 'امنع المستخدم من إرسال بريد إلكتروني',
 'ipbenableautoblock'              => 'تلقائيا امنع آخر عنوان أيبي تم استعماله بواسطة هذا المستخدم، وأي عناوين أيبي أخرى يحاول التحرير من خلالها',
-'ipbsubmit'                       => 'امنع هذا المستخدم',
+'ipbsubmit'                       => 'منع هذا المستخدم',
 'ipbother'                        => 'وقت آخر:',
-'ipboptions'                      => 'ربع ساعة:15 minutes,ساعة واحدة:1 hour,ساعتين:2 hours,يوم:1 day,ثلاثة أيام:3 days,أسبوع:1 week,أسبوعان:2 weeks,شهر:1 month,ثلاثة شهور:3 months,ستة شهور:6 months,عام واحد:1 year,دائم:infinite', # display1:time1,display2:time2,...
+'ipboptions'                      => '2 ساعة:2 hours,1 يوم:1 day,3 يوم:3 days,1 أسبوع:1 week,2 أسبوع:2 weeks,1 شهر:1 month,3 شهر:3 months,6 شهر:6 months,1 سنة:1 year,لا نهائي:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'                  => 'غير ذلك',
 'ipbotherreason'                  => 'سبب إضافي:',
 'ipbhidename'                     => 'أخف اسم المستخدم من سجل المنع، قائمة المنع النشطة وقائمة المستخدمين',
 'ipbwatchuser'                    => 'راقب صفحتي المستخدم والنقاش لهذا المستخدم',
 'badipaddress'                    => 'عنوان أيبي غير صحيح',
 'blockipsuccesssub'               => 'تم المنع بنجاح',
-'blockipsuccesstext'              => 'تم منع [[Special:Contributions/$1|$1]].
-<br />انظر [[Special:Ipblocklist|قائمة منع الأيبي]] لمراجعة حالات المنع.',
-'ipb-edit-dropdown'               => 'تعديل أسباب المنع',
+'blockipsuccesstext'              => 'تم منع [[Special:Contributions/$1|$1]].<br />
+انظر [[Special:IPBlockList|قائمة منع الأيبي]] لمراجعة حالات المنع.',
+'ipb-edit-dropdown'               => 'عدل أسباب المنع',
 'ipb-unblock-addr'                => 'رفع منع $1',
 'ipb-unblock'                     => 'رفع المنع عن مستخدم أو عنوان أيبي',
-'ipb-blocklist-addr'              => 'عرض المنع الحالي لـ $1',
+'ipb-blocklist-addr'              => 'عرض المنع الحالي ل$1',
 'ipb-blocklist'                   => 'عرض حالات المنع الحالية',
 'unblockip'                       => 'رفع منع مستخدم',
-'unblockiptext'                   => 'استخدم الحقل أدناه لاسترجاع صلاحية الكتابة
-الخاصة بعنوان أيبي أو مستخدم تم سحبها منه مسبقا.',
+'unblockiptext'                   => 'استخدم الاستمارة أدناه لاسترجاع صلاحية الكتابة الخاصة بعنوان أيبي أو مستخدم تم سحبها منه مسبقا.',
 'ipusubmit'                       => 'رفع منع هذا العنوان',
 'unblocked'                       => 'تم  رفع منع [[User:$1|$1]]',
 'unblocked-id'                    => 'منع $1 تم رفعه',
-'ipblocklist'                     => 'قائمة عناوين الأيبي وأسماء المستخدمين الممنوعة',
-'ipblocklist-legend'              => 'أوجد مستخدما ممنوعا',
+'ipblocklist'                     => 'عناوين الأيبي وأسماء المستخدمين الممنوعة',
+'ipblocklist-legend'              => 'إيجاد مستخدم ممنوع',
 'ipblocklist-username'            => 'اسم المستخدم أو عنوان الأيبي:',
 'ipblocklist-submit'              => 'بحث',
 'blocklistline'                   => '$1, $2 منع $3 ($4)',
-'infiniteblock'                   => 'غير محدد',
+'infiniteblock'                   => 'لا نهائي',
 'expiringblock'                   => 'ينتهي في $1',
 'anononlyblock'                   => 'مجهول فقط',
 'noautoblockblock'                => 'المنع التلقائي معطل',
@@ -2071,94 +2153,102 @@
 'emailblock'                      => 'البريد الإلكتروني ممنوع',
 'ipblocklist-empty'               => 'قائمة المنع فارغة.',
 'ipblocklist-no-results'          => 'عنوان الأيبي أو اسم المستخدم المطلوب غير ممنوع.',
-'blocklink'                       => 'امنع',
-'unblocklink'                     => 'ارفع المنع',
+'blocklink'                       => 'منع',
+'unblocklink'                     => 'رفع المنع',
 'contribslink'                    => 'مساهمات',
-'autoblocker'                     => 'تم منعك تلقائيا لأن الأيبي الخاص بك تم استخدامه مؤخرا بواسطة "[[User:$1|$1]]". السبب المعطى لمنع $1 هو: "$2"',
+'autoblocker'                     => 'تم منعك تلقائيا لأن الأيبي الخاص بك تم استخدامه مؤخرا بواسطة "[[User:$1|$1]]". 
+السبب المعطى لمنع $1 هو: "$2"',
 'blocklogpage'                    => 'سجل المنع',
 'blocklogentry'                   => 'منع "[[$1]]" لفترة زمنية مدتها $2 $3',
-'blocklogtext'                    => 'هذا سجل بعمليات المنع ورفع المنع. عناوين الأيبي الممنوعة تلقائيا ليست معروضة. انظر [[Special:Ipblocklist|عناوين الأيبي الممنوعة]] لرؤية عمليات المنع المفعلة حاليا.',
+'blocklogtext'                    => 'هذا سجل بعمليات المنع ورفع المنع.
+عناوين الأيبي الممنوعة تلقائيا ليست معروضة.
+انظر [[Special:IPBlockList|عناوين الأيبي الممنوعة]] لرؤية عمليات المنع المفعلة حاليا.',
 'unblocklogentry'                 => 'رفع منع $1',
 'block-log-flags-anononly'        => 'المستخدمون المجهولون فقط',
 'block-log-flags-nocreate'        => 'إنشاء الحسابات ممنوع',
 'block-log-flags-noautoblock'     => 'المنع التلقائي معطل',
 'block-log-flags-noemail'         => 'البريد الإلكتروني ممنوع',
 'block-log-flags-angry-autoblock' => 'المنع التلقائي المتقدم مفعل',
-'range_block_disabled'            => 'إمكانية الإداري لمنع نطاق معطلة.',
+'range_block_disabled'            => 'إمكانية مدير النظام لمنع نطاق معطلة.',
 'ipb_expiry_invalid'              => 'تاريخ الانتهاء غير صحيح.',
-'ipb_expiry_temp'                 => 'عمليات منع أسماء المستخدمين المخفية ينبغي أن تكون دائمة.',
+'ipb_expiry_temp'                 => 'عمليات منع أسماء المستخدمين المخفية يجب أن تكون دائمة.',
 'ipb_already_blocked'             => '"$1" ممنوع بالفعل',
-'ipb_cant_unblock'                => 'خطأ: لم يتم إيجاد الممنوع $1. ربما تم رفع منعه بالفعل.',
-'ipb_blocked_as_range'            => 'خطأ: الأيبي $1 ليس ممنوعا مباشرة ولا يمكن رفع المنع عنه. لكنه، على أية حال، ممنوع كجزء من النطاق $2، والذي يمكن رفع المنع عنه.',
+'ipb_cant_unblock'                => 'خطأ: لم يتم إيجاد الممنوع $1.
+ربما تم رفع منعه بالفعل.',
+'ipb_blocked_as_range'            => 'خطأ: الأيبي $1 ليس ممنوعا مباشرة ولا يمكن رفع المنع عنه.
+لكنه، على أية حال، ممنوع كجزء من النطاق $2، والذي يمكن رفع المنع عنه.',
 'ip_range_invalid'                => 'نطاق عناوين الأيبي المدخل غير صحيح.',
 'blockme'                         => 'منعي',
 'proxyblocker'                    => 'مانع البروكسي',
 'proxyblocker-disabled'           => 'هذه الخاصية معطلة.',
-'proxyblockreason'                => 'تم منع عنوان الأيبي الخاص بك لكونه بروكسي مفتوح. قم بمراسلة مزود خدمة الإنترنت الخاص بك أو الدعم الفني وأعلمهم بهذه المشكلة الأمنية.',
+'proxyblockreason'                => 'تم منع عنوان الأيبي الخاص بك لكونه بروكسي مفتوح.
+من فضلك اتصل بمزود خدمة الإنترنت الخاص بك أو الدعم الفني وأعلمهم بهذه المشكلة الأمنية الخطيرة.',
 'proxyblocksuccess'               => 'تم.',
 'sorbs'                           => 'دي إن إس بي إل',
 'sorbsreason'                     => 'عنوان الأيبي الخاص بك موجود كبروكسي مفتوح في DNSBL المستخدم بواسطة {{SITENAME}}.',
-'sorbs_create_account_reason'     => 'عنوان الأيبي الخاص بك موجود كبروكسي مفتوح في DNSBL المستخدم بواسطة {{SITENAME}}. لا يمكنك إنشاء حساب.',
+'sorbs_create_account_reason'     => 'عنوان الأيبي الخاص بك موجود كبروكسي مفتوح في DNSBL المستخدم بواسطة {{SITENAME}}. 
+لا يمكنك إنشاء حساب.',
 
 # Developer tools
-'lockdb'              => 'أقفل قاعدة البيانات',
-'unlockdb'            => 'افتح قاعدة البيانات',
-'lockdbtext'          => 'إغلاق قاعدة البيانات سوف يمنع جميع المستخدمين من تحرير الصفحات وتغيير التفضيلات الخاصة بهم وتعديل قائمة المراقبة وغير ذلك من الأمور المتطلبة التعديل على قاعدة البيانات. الرجاء التأكد من أن هذا حقا ما ترغب القيام به، ومن أنك سوف تقوم بإزالة الغلق بعد الانتهاء من الصيانة.',
-'unlockdbtext'        => 'فتح قاعدة البيانات سيسترجع قدرة كل المستخدمين على تحرير الصفحات، تغيير تفضيلاتهم
-، تعديل قوائم المراقبة الخاصة بهم، و
-أشياء أخرى تحتاج التغيير في قاعدة البيانات.
+'lockdb'              => 'قفل قاعدة البيانات',
+'unlockdb'            => 'فتح قاعدة البيانات',
+'lockdbtext'          => 'إغلاق قاعدة البيانات سوف يمنع جميع المستخدمين من تحرير الصفحات وتغيير التفضيلات الخاصة بهم وتعديل قائمة المراقبة وغير ذلك من الأمور المتطلبة التعديل على قاعدة البيانات.
+من فضلك تأكد من أن هذا حقا ما ترغب القيام به، ومن أنك سوف تقوم بإزالة الغلق بعد الانتهاء من الصيانة.',
+'unlockdbtext'        => 'فتح قاعدة البيانات سيسترجع قدرة كل المستخدمين على تحرير الصفحات، تغيير تفضيلاتهم، تعديل قوائم المراقبة الخاصة بهم، وأشياء أخرى تحتاج التغيير في قاعدة البيانات.
 من فضلك أكد أن هذا هو ما تريده.',
-'lockconfirm'         => 'نعم، أنا متأكد أني أريد قفل قاعدة البيانات.',
+'lockconfirm'         => 'نعم، أنا أريد فعلا قفل قاعدة البيانات.',
 'unlockconfirm'       => 'نعم، أريد فعلا فتح قاعدة البيانات.',
-'lockbtn'             => 'أقفل قاعدة البيانات',
-'unlockbtn'           => 'افتح قاعدة البيانات',
-'locknoconfirm'       => 'لم تقم باختيار خانة التأكيد.',
+'lockbtn'             => 'قفل قاعدة البيانات',
+'unlockbtn'           => 'فتح قاعدة البيانات',
+'locknoconfirm'       => 'لم تقم بتعليم صندوق التأكيد.',
 'lockdbsuccesssub'    => 'نجح إقفال قاعدة البيانات',
 'unlockdbsuccesssub'  => 'تم إزالة قفل قاعدة البيانات',
-'lockdbsuccesstext'   => 'لقد أغلقت قاعدة البيانات.
-<br />تذكر أن [[Special:Unlockdb|تزيل الغلق]] بعد اكتمال أعمال الصيانة.',
+'lockdbsuccesstext'   => 'لقد أغلقت قاعدة البيانات.<br />
+تذكر أن [[Special:UnlockDB|تزيل الغلق]] بعد اكتمال أعمال الصيانة.',
 'unlockdbsuccesstext' => 'تم إعادة فتح قاعدة البيانات',
-'lockfilenotwritable' => 'ملف غلق قاعدة البيانات لا يمكن الكتابة عليه. لغلق قاعدة البيانات أو إزالة الغلق يجب أن يكون هذا الملف قابلا للكتابة من قبل الخادم.',
+'lockfilenotwritable' => 'ملف غلق قاعدة البيانات لا يمكن الكتابة عليه.
+لغلق قاعدة البيانات أو إزالة الغلق يجب أن يكون هذا الملف قابلا للكتابة من قبل خادم الويب.',
 'databasenotlocked'   => 'قاعدة البيانات ليست مغلقة.',
 
 # Move page
 'move-page'               => 'نقل $1',
 'move-page-legend'        => 'نقل صفحة',
-'movepagetext'            => "باستعمال النموذج أدناه بإمكانك أن تغير اسم الصفحة، وأن تنقل تاريخها للاسم الجديد.
-سيتم إنشاء تحويلة من العنوان القديم للصفحة بالعنوان الجديد.
-لكن، لن يتم تغيير الوصلات في الصفحات التي تتصل بهذه الصفحة؛ لذا عليك التأكد من عدم وجود وصلات مقطوعة، أو وصلات متتالية، للتأكد من أن المقالات تتصل مع بعضها بشكل مناسب.
+'movepagetext'            => "باستخدام  الاستمارة بالأسفل بإمكانك أن تغير اسم الصفحة، وأن تنقل تاريخها للاسم الجديد.
+العنوان القديم سيصبح تحويلة للعنوان الجديد.
+يمكنك تحديث التحويلات التي تشير إلى العنوان الأصلي تلقائيا.
+لو اخترت ألا تفعل، تأكد من عدم وجود تحويلات [[Special:DoubleRedirects|مزدوجة]] أو [[Special:BrokenRedirects|مكسورة]].
+أنت مسؤول عن التأكد من أن الوصلات تتصل مع بعضها بشكل مناسب.
 
-يرجى الملاحظة أنه '''لن يتم''' نقل الصفحة إذا وجدت صفحة بالاسم الجديد، إلا إذا كانت صفحة فارغة، أو صفحة تحويل، ولا تاريخ لها. وهذا يعني أنك لا تستطيع وضع صفحة مكان صفحة، كما أنه من الممكن ارجاع الصفحة لمكانها في حال تم النقل بشكل خاطئ.
+لاحظ أنه '''لن يتم''' نقل الصفحة إذا وجدت صفحة بالعنوان الجديد، إلا إذا كانت فارغة، أو تحويلة ولا تاريخ لها.
+هذا يعني أنك يمكنك استرجاع الصفحة لمكانها لو قمت بخطأ، وأنك لا يمكنك الكتابة على صفحة موجودة.
 
 '''تحذير!'''
-قد يكون لنقل الصفحة آثار كبيرة، وتغييرات غير متوقع بالنسبة للصفحات المشهورة. يرجى فهم وإدارك عواقب نقل الصفحات قبل القيام به.",
-'movepagetalktext'        => 'صفحة النقاش المرفقة بالمقالة سيتم نقلها كذلك، إذا وجدت. ولكن لا يتم نقل صفحة النقاش في الحالات التالية:
-* نقل الصفحة عبر نطاقات  مختلفة.
-* يوجد صفحة نقاش غير فارغة تحت العنوان الجديد للمقالة.
-* قمت بإزالة اختيار نقل صفحة النقاش في الأسفل.
+هذا قد يكون تغييرا كارثيا وغير متوقع لصفحة مشهورة؛
+من فضلك تأكد من فهم عواقب هذا قبل المتابعة.",
+'movepagetalktext'        => "صفحة النقاش المرفقة سيتم نقلها كذلك، '''إلا في حالة''':
+* توجد صفحة نقاش غير فارغة تحت العنوان الجديد، أو
+* قمت بإزالة اختيار الصندوق بالأسفل.
 
-وفي الحالات أعلاه، يجب عليك نقل أو دمج محتويات صفحة النقاش يدويا، إذا رغب في ذلك.',
+وفي هذه الحالات، يجب عليك نقل أو دمج محتويات الصفحة يدويا، إذا رغب في ذلك.",
 'movearticle'             => 'انقل الصفحة:',
-'movenologin'             => 'غير مسجل',
-'movenologintext'         => 'يجب أن تكون مستخدما مسجلا وأن تقوم [[Special:Userlogin|بالدخول]] لكي تنقل صفحة.',
 'movenotallowed'          => 'لا تمتلك الصلاحية لنقل الصفحات في {{SITENAME}}.',
 'newtitle'                => 'إلى العنوان الجديد:',
 'move-watch'              => 'راقب هذه الصفحة',
 'movepagebtn'             => 'نقل الصفحة',
-'pagemovedsub'            => 'نقلت بنجاح',
+'pagemovedsub'            => 'تم النقل بنجاح',
 'movepage-moved'          => '<big>\'\'\'"$1" نقلت إلى "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'articleexists'           => 'توجد صفحة بهذا الاسم،
-أو أن الاسم الذي تم اختياره غير صالح.
-يرجى اختيار اسم آخر.',
-'cantmove-titleprotected' => 'أنت لا يمكنك نقل صفحة إلى هذا الموقع، لأن العنوان الجديد تمت حمايته ضد الإنشاء',
-'talkexists'              => "'''نقلت الصفحة بنجاح، ولكن لم تنقل صفحة النقاش المرافقة لوجود صفحة نقاش مسبقا تحت العنوان الجديد. يرجى نقل محتويات صفحة النقاش يدويا، ودمجها مع المحتويات السابقة.'''",
+'articleexists'           => 'توجد صفحة بهذا الاسم، أو أن الاسم الذي تم اختياره غير صالح.
+من فضلك اختيار اسم آخر.',
+'cantmove-titleprotected' => 'لا يمكنك نقل صفحة إلى هذا الموقع، لأن العنوان الجديد تمت حمايته ضد الإنشاء',
+'talkexists'              => "'''الصفحة نفسها تم نقلها بنجاح، ولكن صفحة النقاش لم يمكن نقلها لوجود صفحة مسبقا تحت العنوان الجديد.
+من فضلك ادمجهما يدويا.'''",
 'movedto'                 => 'تم نقلها إلى',
-'movetalk'                => 'انقل صفحة النقاش.',
-'move-subpages'           => 'نقل كل الصفحات الفرعية، إذا كان هذا ممكنا',
-'move-talk-subpages'      => 'نقل كل الصفحات الفرعية لصفحة النقاش، إذا كان هذا ممكنا',
-'movepage-page-exists'    => 'الصفحة $1 موجودة حاليا ولا يمكن الكتابة فوقها تلقائيا.',
+'movetalk'                => 'انقل صفحة النقاش المرفقة',
+'move-subpages'           => 'انقل كل الصفحات الفرعية، إذا كان هذا ممكنا',
+'move-talk-subpages'      => 'انقل كل الصفحات الفرعية لصفحة النقاش، إذا كان هذا ممكنا',
+'movepage-page-exists'    => 'الصفحة $1 موجودة بالفعل ولا يمكن الكتابة عليها تلقائيا.',
 'movepage-page-moved'     => 'تم نقل الصفحة $1 إلى $2.',
-'movepage-page-unmoved'   => 'لا يمكن نقل الصفحة $1 إلى $2.',
+'movepage-page-unmoved'   => 'لم يمكن نقل الصفحة $1 إلى $2.',
 'movepage-max-pages'      => 'الحد الأقصى $1 {{PLURAL:$1|صفحة|صفحة}} تم نقله ولن يتم نقل المزيد تلقائيا.',
 '1movedto2'               => '[[$1]] تم نقلها إلى [[$2]]',
 '1movedto2_redir'         => '[[$1]] تم نقلها إلى [[$2]] فوق التحويلة',
@@ -2167,31 +2257,34 @@
 'movereason'              => 'السبب:',
 'revertmove'              => 'استرجاع',
 'delete_and_move'         => 'حذف ونقل',
-'delete_and_move_text'    => '==يستلزم الحذف==
-
-هناك صفحة تحت الاسم "[[$1]]" الذي طلبت أن تنقل إليه هذه الصفحة. هل تريد حذفها لإفساح المجال للنقل؟',
+'delete_and_move_text'    => '==الحذف مطلوب==
+الصفحة الهدف "[[:$1]]" موجودة بالفعل.
+هل تريد حذفها لإفساح المجال للنقل؟',
 'delete_and_move_confirm' => 'نعم، احذف الصفحة',
 'delete_and_move_reason'  => 'تم الحذف لإفساح مجال للنقل',
-'selfmove'                => 'لا يوجد اختلاف في عنوان المصدر و الهدف؛ لا يمكن نقل الصفحة على نفسها.',
-'immobile_namespace'      => 'لا يمكن النقل إلى العنوان المراد؛ النطاق غير مسموح بالنقل إليه.',
+'selfmove'                => 'لا يوجد اختلاف في عنوان المصدر والهدف؛
+لا يمكن نقل الصفحة على نفسها.',
+'immobile_namespace'      => 'عنوان المصدر أو الهدف ذو طبيعة خاصة؛
+لا يمكن نقل الصفحات من وإلى هذا النطاق.',
 'imagenocrossnamespace'   => 'لا يمكن نقل الملف إلى نطاق غير نطاق الملفات',
 'imagetypemismatch'       => 'امتداد الملف الجديد لا يطابق نوعه',
-'imageinvalidfilename'    => 'اسم ملف الصورة المستهدف غير صحيح',
+'imageinvalidfilename'    => 'اسم الملف الهدف غير صحيح',
+'fix-double-redirects'    => 'حدث أي تحويلات تشير إلى العنوان الأصلي',
 
 # Export
 'export'            => 'تصدير صفحات',
-'exporttext'        => 'يمكنك تصدير النص وتاريخ تعديلات صفحة أو مجموعة صفحات خاصة في صيغة إكس إم إل. وذلك بقصد استيرادها في ويكي آخر يستعمل ميدياويكي بواسطة الصفحة [[Special:Import|صفحة الاستيراد]].
+'exporttext'        => 'يمكنك تصدير النص وتاريخ تعديلات صفحة أو مجموعة صفحات في صيغة XML. هذا يمكن استيراده في ويكي آخر يستعمل ميدياويكي بواسطة الصفحة [[Special:Import|صفحة الاستيراد]].
 
-لتصدير صفحات، اكتب العناوين في الصندوق أسفله، عنوان واحد في كل السطر، مع اختيار ما إذا كنت ترغب في النسخة الحالية بالإضافة إلى النسخ القديمة كاملة أو مع معلومات تاريخ الصفحة عنها أو فقط النسخة الحالية مع معلومات عن التعديل الأخير.
+لتصدير صفحات، أدخل العناوين في الصندوق أسفله، عنوان واحد في كل سطر، مع اختيار ما إذا كنت ترغب في النسخة الحالية بالإضافة إلى النسخ القديمة كاملة، أو مع معلومات تاريخ الصفحة عنها، أو فقط النسخة الحالية مع معلومات عن التعديل الأخير.
 
-في الحالة الأخيرة يمكنك استخدام وصلة مباشرة، كمثال [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] للصفحة [[{{MediaWiki:Mainpage}}]].',
-'exportcuronly'     => 'ضمن النسخة الحالية فقط، وليس تاريخ الصفحة بأكمله',
+في الحالة الأخيرة يمكنك أيضا استخدام وصلة، على سبيل المثال [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] للصفحة "[[{{MediaWiki:Mainpage}}]]".',
+'exportcuronly'     => 'ضمن المراجعة الحالية فقط، وليس التاريخ الكامل',
 'exportnohistory'   => "----
-ملاحظة:''' تم توقيف التصدير الكامل لتاريخ الصفحة بهذه الترسيمة لأسباب تحسينية'''",
+ملاحظة:''' تصدير التاريخ الكامل للصفحات من خلال هذه الاستمارة تم تعطيله لأسباب تتعلق بالأداء'''",
 'export-submit'     => 'تصدير',
-'export-addcattext' => 'إضافة صفحات من تصنيف:',
+'export-addcattext' => 'أضف صفحات من تصنيف:',
 'export-addcat'     => 'إضافة',
-'export-download'   => 'اعرض الحفظ كملف',
+'export-download'   => 'احفظ كملف',
 'export-templates'  => 'ضمن القوالب',
 
 # Namespace 8 related
@@ -2201,9 +2294,9 @@
 'allmessagescurrent'        => 'النص الحالي',
 'allmessagestext'           => 'هذه قائمة برسائل النظام المتوفرة في نطاق ميدياويكي.
 من فضلك زر [http://www.mediawiki.org/wiki/Localisation ترجمة ميدياويكي] و [http://translatewiki.net بيتاويكي] لو كنت ترغب في المساهمة في ترجمة ميدياويكي الأساسية.',
-'allmessagesnotsupportedDB' => "لا يمكن استخدام '''{{ns:special}}:Allmessages''' لأن المتغير '''\$wgUseDatabaseMessages''' غير مشغل.",
+'allmessagesnotsupportedDB' => "هذه الصفحة لا يمكن استخدامها لأن '''\$wgUseDatabaseMessages''' تم تعطيله.",
 'allmessagesfilter'         => 'بحث باسم الرسالة:',
-'allmessagesmodified'       => 'اعرض المتغير فقط',
+'allmessagesmodified'       => 'عرض المتغير فقط',
 
 # Thumbnails
 'thumbnail-more'           => 'تكبير',
@@ -2217,44 +2310,47 @@
 # Special:Import
 'import'                     => 'استيراد صفحات',
 'importinterwiki'            => 'استيراد ترانسويكي',
-'import-interwiki-text'      => 'اختر الويكي و عنوان الصفحة المطلوب استيرادها.
-تواريخ التعديلات و أسماء المحررين سيتم الحفاظ عليها.
-كل عمليات الاستيراد عبر مواقع الويكي يتم تسجيلها في [[Special:Log/import|سجل الاستيراد]].',
+'import-interwiki-text'      => 'اختر ويكي وعنوان الصفحة للاستيراد.
+تواريخ المراجعات وأسماء المحررين سيتم حفظها.
+كل أفعال الاستيراد عبر الويكي يتم تسجيلها في [[Special:Log/import|سجل الاستيراد]].',
 'import-interwiki-history'   => 'انسخ كل نسخ التاريخ لهذه الصفحة',
 'import-interwiki-submit'    => 'استيراد',
 'import-interwiki-namespace' => 'انقل الصفحات إلى النطاق:',
-'importtext'                 => 'من فضلك صدّر الملف من الويكي المصدر عن طريق Special:Export، احفظها على جهازك ثم ارفعها هنا.',
+'importtext'                 => 'من فضلك صدر الملف من الويكي المصدر باستخدام [[Special:Export|أداة الاستيراد]].
+احفظها على حاسوبك ثم ارفعها هنا.',
 'importstart'                => 'استيراد صفحات...',
-'import-revision-count'      => '{{PLURAL:$1|نسخة واحدة|نسخة}} $1',
+'import-revision-count'      => '{{PLURAL:$1|مراجعة واحدة|مراجعة}} $1',
 'importnopages'              => 'لا صفحات للاستيراد',
-'importfailed'               => 'فشل استيراد: $1',
-'importunknownsource'        => 'نوع مجهول لمصدر الاستيراد',
+'importfailed'               => 'فشل الاستيراد: <nowiki>$1</nowiki>',
+'importunknownsource'        => 'نوع مصدر استيراد مجهول',
 'importcantopen'             => 'لم يمكن فتح ملف الاستيراد',
-'importbadinterwiki'         => 'وصلة إنترويكي خاطئة',
+'importbadinterwiki'         => 'وصلة إنترويكي سيئة',
 'importnotext'               => 'فارغ أو لا نص',
 'importsuccess'              => 'الاستيراد انتهى!',
-'importhistoryconflict'      => 'هناك تاريخ تعديلات يتعارض مع تاريخ هذه الصفحة (ربما تكون قد استوردت الصفحة من قبل)',
-'importnosources'            => 'لم يتم تحديد مصادر للاستيراد الويكي و الاستيراد المباشر عن طريق الرفع غير فعال.',
+'importhistoryconflict'      => 'هناك مراجعة تاريخ متعارضة موجودة (ربما تكون قد استوردت هذه الصفحة من قبل)',
+'importnosources'            => 'لم يتم تعريف مصادر للاستيراد عبر الويكي وعمليات رفع التاريخ المباشرة معطلة.',
 'importnofile'               => 'لم يتم رفع ملف استيراد.',
-'importuploaderrorsize'      => 'رفع ملف الاستيراد فشل. الملف أكبر من حجم الرفع المسموح.',
+'importuploaderrorsize'      => 'رفع ملف الاستيراد فشل.
+الملف أكبر من حجم الرفع المسموح.',
 'importuploaderrorpartial'   => 'رفع ملف الاستيراد فشل. الملف تم رفعه جزئيا.',
-'importuploaderrortemp'      => 'رفع ملف الاستيراد فشل. هناك مجلد مؤقت مفقود.',
-'import-parse-failure'       => 'فشل بارس استيراد XML',
+'importuploaderrortemp'      => 'رفع ملف الاستيراد فشل.
+هناك مجلد مؤقت مفقود.',
+'import-parse-failure'       => 'فشل تحليل استيراد XML',
 'import-noarticle'           => 'لا صفحة للاستيراد!',
-'import-nonewrevisions'      => 'كل النسخ تم استيرادها من قبل.',
+'import-nonewrevisions'      => 'كل المراجعات تم استيرادها من قبل.',
 'xml-error-string'           => '$1 عند السطر $2، العمود $3 (بايت $4): $5',
-'import-upload'              => 'ارفع بيانات إكس‌إم‌إل',
+'import-upload'              => 'رفع بيانات XML',
 
 # Import log
 'importlogpage'                    => 'سجل الاستيراد',
-'importlogpagetext'                => 'استيرادات إدارية (للإداريين فقط) لصفحات من مواقع ويكي أخرى.',
+'importlogpagetext'                => 'عمليات الاستيراد الإدارية للصفحات مع تاريخ التعديل من ويكيات أخرى.',
 'import-logentry-upload'           => 'استورد [[$1]] بواسطة رفع ملف',
-'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|تعديل واحد|تعديل}}',
-'import-logentry-interwiki'        => 'استيراد ويكي $1',
-'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|تعديل واحد|تعديل}} من $2',
+'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|مراجعة واحدة|مراجعة}}',
+'import-logentry-interwiki'        => 'استورد عبر الويكي $1',
+'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|مراجعة واحدة|مراجعة}} من $2',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'             => 'صفحتي الخاصة',
+'tooltip-pt-userpage'             => 'صفحة مستخدمي',
 'tooltip-pt-anonuserpage'         => 'صفحة المستخدم للأيبي الذي تقوم بالتحرير من خلاله',
 'tooltip-pt-mytalk'               => 'صفحة نقاشي',
 'tooltip-pt-anontalk'             => 'نقاش حول التعديلات من عنوان الأيبي هذا',
@@ -2265,13 +2361,15 @@
 'tooltip-pt-anonlogin'            => 'من المفضل أن تقوم بتسجيل الدخول، هذا ليس إلزاميا.',
 'tooltip-pt-logout'               => 'خروج',
 'tooltip-ca-talk'                 => 'نقاش حول صفحة المحتوى',
-'tooltip-ca-edit'                 => 'بإمكانك تعديل هذه الصفحة، برجاء استعمال زر عرض مسبق قبل الحفظ',
-'tooltip-ca-addsection'           => 'علق على هذا النقاش.',
-'tooltip-ca-viewsource'           => 'هذه الصفحة محمية. يمكنك رؤية مصدرها.',
+'tooltip-ca-edit'                 => 'يمكنك تعديل هذه الصفحة.
+من فضلك استخدم زر العرض المسبق قبل الحفظ.',
+'tooltip-ca-addsection'           => 'أضف تعليقا إلى هذا النقاش.',
+'tooltip-ca-viewsource'           => 'هذه الصفحة محمية.
+يمكنك رؤية مصدرها.',
 'tooltip-ca-history'              => 'النسخ السابقة من هذه الصفحة',
 'tooltip-ca-protect'              => 'احم هذه الصفحة',
 'tooltip-ca-delete'               => 'احذف هذه الصفحة',
-'tooltip-ca-undelete'             => 'استرجاع التعديلات التي تمت على هذه الصفحة قبل حذفها',
+'tooltip-ca-undelete'             => 'استرجع التعديلات التي تمت على هذه الصفحة قبل حذفها',
 'tooltip-ca-move'                 => 'انقل هذه الصفحة',
 'tooltip-ca-watch'                => 'أضف هذه الصفحة إلى قائمة مراقبتك',
 'tooltip-ca-unwatch'              => 'أزل هذه الصفحة من قائمة مراقبتك',
@@ -2279,32 +2377,32 @@
 'tooltip-search-go'               => 'اذهب إلى صفحة بنفس هذا الاسم إن وجدت',
 'tooltip-search-fulltext'         => 'ابحث في الصفحات عن هذا النص',
 'tooltip-p-logo'                  => 'الصفحة الرئيسية',
-'tooltip-n-mainpage'              => 'زيارة الصفحة الرئيسية',
+'tooltip-n-mainpage'              => 'زر الصفحة الرئيسية',
 'tooltip-n-portal'                => 'حول المشروع، ماذا يمكن أن تفعل، أين يمكن أن تجد ما تحتاجه',
 'tooltip-n-currentevents'         => 'مطالعة سريعة لأهم الأحداث الجارية',
-'tooltip-n-recentchanges'         => 'قائمة بأحدث التغييرات في الويكي.',
+'tooltip-n-recentchanges'         => 'قائمة أحدث التغييرات في الويكي.',
 'tooltip-n-randompage'            => 'حمل صفحة عشوائية',
 'tooltip-n-help'                  => 'تحتاج مساعدة؟ طالع هذه الصفحة!',
-'tooltip-t-whatlinkshere'         => 'قائمة بكل الصفحات في الويكي التي تصل هنا',
+'tooltip-t-whatlinkshere'         => 'قائمة بكل صفحات الويكي التي تصل هنا',
 'tooltip-t-recentchangeslinked'   => 'أحدث التغييرات في الصفحات الموصولة من هذه الصفحة',
 'tooltip-feed-rss'                => 'تلقيم أر إس إس لهذه الصفحة',
 'tooltip-feed-atom'               => 'تلقيم أتوم لهذه الصفحة',
-'tooltip-t-contributions'         => 'اعرض قائمة مساهمات هذا المستخدم',
+'tooltip-t-contributions'         => 'رؤية قائمة مساهمات هذا المستخدم',
 'tooltip-t-emailuser'             => 'أرسل رسالة لهذا المستخدم',
-'tooltip-t-upload'                => 'رفع ملفات',
+'tooltip-t-upload'                => 'ارفع ملفات',
 'tooltip-t-specialpages'          => 'قائمة بكل الصفحات الخاصة',
 'tooltip-t-print'                 => 'نسخة للطباعة لهذه الصفحة',
 'tooltip-t-permalink'             => 'وصلة دائمة لهذه النسخة من الصفحة',
-'tooltip-ca-nstab-main'           => 'اعرض صفحة المحتوى',
+'tooltip-ca-nstab-main'           => 'رؤية صفحة المحتوى',
 'tooltip-ca-nstab-user'           => 'اعرض صفحة المستخدم',
-'tooltip-ca-nstab-media'          => 'اعرض صفحة ملف الميديا',
+'tooltip-ca-nstab-media'          => 'رؤية صفحة الميديا',
 'tooltip-ca-nstab-special'        => 'هذه صفحة خاصة، لا تستطيع أن تعدل الصفحة نفسها',
-'tooltip-ca-nstab-project'        => 'اعرض صفحة المشروع',
-'tooltip-ca-nstab-image'          => 'اعرض صفحة الملف',
-'tooltip-ca-nstab-mediawiki'      => 'اعرض رسالة النظام',
-'tooltip-ca-nstab-template'       => 'اعرض القالب',
-'tooltip-ca-nstab-help'           => 'اعرض صفحة المساعدة',
-'tooltip-ca-nstab-category'       => 'اعرض صفحة التصنيف',
+'tooltip-ca-nstab-project'        => 'رؤية صفحة المشروع',
+'tooltip-ca-nstab-image'          => 'رؤية صفحة الملف',
+'tooltip-ca-nstab-mediawiki'      => 'رؤية رسالة النظام',
+'tooltip-ca-nstab-template'       => 'رؤية القالب',
+'tooltip-ca-nstab-help'           => 'رؤية صفحة المساعدة',
+'tooltip-ca-nstab-category'       => 'رؤية صفحة التصنيف',
 'tooltip-minoredit'               => 'علم على هذا كتعديل طفيف',
 'tooltip-save'                    => 'احفظ تغييراتك',
 'tooltip-preview'                 => 'اعرض تغييراتك، من فضلك استخدم هذا قبل الحفظ!',
@@ -2319,7 +2417,7 @@
 'standard.css'    => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة ستاندرد */',
 'nostalgia.css'   => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة نوستالشيا */',
 'cologneblue.css' => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة كولون بلو */',
-'monobook.css'    => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة المونوبوك */',
+'monobook.css'    => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة مونوبوك */',
 'myskin.css'      => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة ماي سكين */',
 'chick.css'       => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة تشيك */',
 'simple.css'      => '/* الأنماط المتراصة CSS المعروضة هنا ستؤثر على مستخدمي واجهة سيمبل */',
@@ -2345,17 +2443,18 @@
 'anonymous'        => 'مستخدم مجهول ل{{SITENAME}}',
 'siteuser'         => 'مستخدم {{SITENAME}} $1',
 'lastmodifiedatby' => 'آخر تعديل لهذه الصفحة كان في $2، $1 بواسطة $3.', # $1 date, $2 time, $3 user
-'othercontribs'    => 'بناء على عمل $1.',
+'othercontribs'    => 'بناء على العمل بواسطة $1.',
 'others'           => 'أخرى',
-'siteusers'        => '{{SITENAME}} مستخدم(و) $1',
+'siteusers'        => 'مستخدم(و) {{SITENAME}} $1',
 'creditspage'      => 'حقوق الصفحة',
 'nocredits'        => 'لا توجد معلومات حقوق متوفرة لهذه الصفحة.',
 
 # Spam protection
-'spamprotectiontitle' => 'فلتر الحماية من السخام',
-'spamprotectiontext'  => 'تم منع حفظ الصفحة عن طريق مانع السخام. من المحتمل أن يكون هذا بسبب وصلة خارجية.',
-'spamprotectionmatch' => 'النص التالي هو ما نشط مانع السخام الخاص بنا: $1',
-'spambot_username'    => 'تنظيف سخام ميدياويكي',
+'spamprotectiontitle' => 'فلتر الحماية من السبام',
+'spamprotectiontext'  => 'الصفحة التي أردت حفظها تم منعها بواسطة مانع السبام.
+من المحتمل أن يكون هذا بسبب وصلة إلى موقع خارجي.',
+'spamprotectionmatch' => 'النص التالي هو ما نشط مانع السبام الخاص بنا: $1',
+'spambot_username'    => 'تنظيف سبام ميدياويكي',
 'spam_reverting'      => 'استرجاع آخر نسخة ليس بها وصلات إلى $1',
 'spam_blanking'       => 'كل النسخ احتوت على وصلات ل $1، إفراغ',
 
@@ -2373,33 +2472,34 @@
 'mw_math_html'   => 'اعرض بصيغة HTML إن أمكن، وإلا فاعرض كهيئة PNG',
 'mw_math_source' => 'اعرض على هيئة TeX (للمتصفحات النصية)',
 'mw_math_modern' => 'مستحسن للمتصفحات الحديثة',
-'mw_math_mathml' => 'اعرض بصيغة MathML إن أمكن (تحت التجريب)',
+'mw_math_mathml' => 'اعرض بصيغة MathML إن أمكن (تجريبي)',
 
 # Patrolling
-'markaspatrolleddiff'                 => 'تمت مراجعتها',
-'markaspatrolledtext'                 => 'هذه المقالة تمت مراجعتها',
-'markedaspatrolled'                   => 'تمت مراجعتها',
-'markedaspatrolledtext'               => 'تمت الإشارة إلى النسخة المختارة كمراجعة.',
+'markaspatrolleddiff'                 => 'علم كمراجعة',
+'markaspatrolledtext'                 => 'علم على هذه الصفحة كمراجعة',
+'markedaspatrolled'                   => 'تم التعليم كمراجعة',
+'markedaspatrolledtext'               => 'المراجعة المختارة تم التعليم عليها كمراجعة.',
 'rcpatroldisabled'                    => 'مراجعة أحدث التغييرات معطلة',
 'rcpatroldisabledtext'                => 'خاصية مراجعة أحدث التغييرات معطلة حاليا',
 'markedaspatrollederror'              => 'لا يمكن التعليم بالمراجعة',
-'markedaspatrollederrortext'          => 'يجب عليك اختيار النسخة التي تريد أن تشير أنها مراجعة',
+'markedaspatrollederrortext'          => 'يجب عليك اختيار المراجعة التي تريد أن تشير أنها مراجعة',
 'markedaspatrollederror-noautopatrol' => 'من غير المسموح لك التعليم على تغييراتك الشخصية كمراجعة.',
 
 # Patrol log
-'patrol-log-page' => 'سجل المراجعة',
-'patrol-log-line' => 'علم على $1 من $2 كمراجعة $3',
-'patrol-log-auto' => '(تلقائيا)',
-'patrol-log-diff' => 'ن$1',
+'patrol-log-page'   => 'سجل المراجعة',
+'patrol-log-header' => 'هذا سجل بالمراجعات المراجعة.',
+'patrol-log-line'   => 'علم على $1 من $2 كمراجعة $3',
+'patrol-log-auto'   => '(تلقائيا)',
+'patrol-log-diff'   => 'ن$1',
 
 # Image deletion
-'deletedrevision'                 => 'حذف النسخة القديمة $1',
+'deletedrevision'                 => 'حذف المراجعة القديمة $1',
 'filedeleteerror-short'           => 'خطأ حذف الملف: $1',
 'filedeleteerror-long'            => 'حدثت أخطاء أثناء حذف الملف:
 
 $1',
 'filedelete-missing'              => 'الملف "$1" لم يمكن حذفه، لأنه غير موجود.',
-'filedelete-old-unregistered'     => 'نسخة الملف المحددة "$1" ليست في قاعدة البيانات.',
+'filedelete-old-unregistered'     => 'مراجعة الملف المحددة "$1" ليست في قاعدة البيانات.',
 'filedelete-current-unregistered' => 'الملف المحدد "$1" ليس في قاعدة البيانات.',
 'filedelete-archive-read-only'    => 'مجلد الأرشيف "$1" لا يمكن الكتابة عليه بواسطة خادم الويب.',
 
@@ -2415,14 +2515,14 @@
 'file-info'            => '(حجم الملف: $1، نوع MIME: $2)',
 'file-info-size'       => '($1 × $2 بكسل حجم الملف: $3، نوع MIME: $4)',
 'file-nohires'         => '<small>لا توجد دقة أعلى متوفرة.</small>',
-'svg-long-desc'        => '(ملف إس في جي، أبعاده $1 × $2 بكسل، حجم الملف: $3)',
-'show-big-image'       => 'الصورة بدقة كاملة',
+'svg-long-desc'        => '(ملف SVG، أبعاده $1 × $2 بكسل، حجم الملف: $3)',
+'show-big-image'       => 'دقة كاملة',
 'show-big-image-thumb' => '<small>حجم هذا العرض: $1 × $2 بكسل</small>',
 
-# Special:Newimages
-'newimages'             => 'معرض الصور الجديدة',
+# Special:NewImages
+'newimages'             => 'معرض الملفات الجديدة',
 'imagelisttext'         => 'فيما يلي قائمة تحوي $1 {{PLURAL:$1|ملف|ملفات}} مرتبة $2.',
-'newimages-summary'     => 'هذه الصفحة الخاصة تعرض آخر الملفات المرفوعة',
+'newimages-summary'     => 'هذه الصفحة الخاصة تعرض آخر الملفات المرفوعة.',
 'showhidebots'          => '($1 بوتات)',
 'noimages'              => 'لا شيء للعرض.',
 'ilsubmit'              => 'بحث',
@@ -2438,15 +2538,18 @@
 # Bad image list
 'bad_image_list' => 'الصيغة كالتالي:
 
-فقط عناصر القائمة (السطور التي تبدأ ب *) يتم أخذها في الاعتبار. أول وصلة في السطر يجب أن تكون وصلة لملف سيىء.
+فقط عناصر القائمة (السطور التي تبدأ ب *) يتم أخذها في الاعتبار.
+أول وصلة في السطر يجب أن تكون وصلة لملف سيىء.
 أي وصلات تالية في نفس السطر سيتم اعتبارها استثناءات، بمعنى آخر مقالات حيث الملف يمكن أن يكون موجودا.',
 
 # Metadata
 'metadata'          => 'بيانات ميتا',
-'metadata-help'     => 'هذا الملف يحتوي على معلومات إضافية، غالبا ما تكون أضيفت من قبل الكاميرا الرقمية أو الماسح الضوئي المستخدم في نقل الملف إلى الحاسوب. إذا كان الملف قد عدل عن حالته الأصلية، فبعض التفاصيل قد لا تعبر عن الملف المعدل.',
-'metadata-expand'   => 'اظهر التفاصيل الممتدة',
-'metadata-collapse' => 'أخف التفاصيل الممتدة',
-'metadata-fields'   => 'حقول معطيات الميتا EXIF الموجودة في هذه الرسالة سوف تعرض في صفحة الصورة عندما يكون جدول معطيات الميتا مضغوطا. الحقول الأخرى ستكون مخفية افتراضيا.
+'metadata-help'     => 'هذا الملف يحتوي على معلومات إضافية، غالبا ما تكون أضيفت من قبل الكاميرا الرقمية أو الماسح الضوئي المستخدم في نقل الملف إلى الحاسوب.
+إذا كان الملف قد عدل عن حالته الأصلية، فبعض التفاصيل قد لا تعبر عن الملف المعدل.',
+'metadata-expand'   => 'عرض التفاصيل الممتدة',
+'metadata-collapse' => 'إخفاء التفاصيل الممتدة',
+'metadata-fields'   => 'حقول معطيات الميتا EXIF الموجودة في هذه الرسالة سوف تعرض في صفحة الصورة عندما يكون جدول معطيات الميتا مضغوطا.
+الحقول الأخرى ستكون مخفية افتراضيا.
 * make
 * model
 * datetimeoriginal
@@ -2456,7 +2559,7 @@
 
 # EXIF tags
 'exif-imagewidth'                  => 'العرض',
-'exif-imagelength'                 => 'الطول',
+'exif-imagelength'                 => 'الارتفاع',
 'exif-bitspersample'               => 'بت لكل مكون',
 'exif-compression'                 => 'نظام الضغط',
 'exif-photometricinterpretation'   => 'تركيب البكسل',
@@ -2469,8 +2572,8 @@
 'exif-yresolution'                 => 'الدقة الرأسية',
 'exif-resolutionunit'              => 'وحدة تحليل X و Y',
 'exif-stripoffsets'                => 'موقع بيانات الصورة',
-'exif-rowsperstrip'                => 'عدد الصفوف لكل ستريب',
-'exif-stripbytecounts'             => 'بايت لكل ستريب مضغوط',
+'exif-rowsperstrip'                => 'عدد الصفوف لكل شريحة',
+'exif-stripbytecounts'             => 'بايت لكل شريحة مضغوطة',
 'exif-jpeginterchangeformat'       => 'الحد ل JPEG SOI',
 'exif-jpeginterchangeformatlength' => 'بايت من بيانات JPEG',
 'exif-transferfunction'            => 'وظيفة النقل',
@@ -2478,13 +2581,13 @@
 'exif-primarychromaticities'       => 'ألوان الأساسيات',
 'exif-ycbcrcoefficients'           => 'معاملات مصفوفة تحويل فراغ اللون',
 'exif-referenceblackwhite'         => 'زوج من قيم المرجع السوداء والبيضاء',
-'exif-datetime'                    => 'تاريخ و وقت تغيير الملف',
+'exif-datetime'                    => 'تاريخ ووقت تغيير الملف',
 'exif-imagedescription'            => 'عنوان الصورة',
-'exif-make'                        => 'منتج آلة التصوير',
+'exif-make'                        => 'مصنع آلة التصوير',
 'exif-model'                       => 'نوع آلة التصوير',
 'exif-software'                    => 'البرمجيات المستخدمة',
 'exif-artist'                      => 'المؤلف',
-'exif-copyright'                   => 'مالك الحقوق المحفوظة',
+'exif-copyright'                   => 'مالك الحقوق',
 'exif-exifversion'                 => 'نسخة Exif',
 'exif-flashpixversion'             => 'نسخة فلاش بكس المدعومة',
 'exif-colorspace'                  => 'فرق اللون',
@@ -2492,15 +2595,15 @@
 'exif-compressedbitsperpixel'      => 'طور ضغط الصورة',
 'exif-pixelydimension'             => 'عرض صورة صحيح',
 'exif-pixelxdimension'             => 'ارتفاع صورة صحيح',
-'exif-makernote'                   => 'ملاحظات الصانع',
+'exif-makernote'                   => 'ملاحظات المصنع',
 'exif-usercomment'                 => 'تعليقات المستخدم',
 'exif-relatedsoundfile'            => 'ملف صوتي مرتبط',
-'exif-datetimeoriginal'            => 'تاريخ و وقت الإنتاج',
-'exif-datetimedigitized'           => 'تاريخ و وقت التحويل الرقمي',
+'exif-datetimeoriginal'            => 'تاريخ ووقت توليد البيانات',
+'exif-datetimedigitized'           => 'تاريخ ووقت التحويل الرقمي',
 'exif-subsectime'                  => 'وقت تاريخ ثواني فرعية',
 'exif-subsectimeoriginal'          => 'وقت تاريخ أصلي ثواني فرعية',
 'exif-subsectimedigitized'         => 'وقت تاريخ رقمي ثواني فرعية',
-'exif-exposuretime'                => 'مدة التعرض',
+'exif-exposuretime'                => 'زمن التعرض',
 'exif-exposuretime-format'         => '$1 ثانية ($2)',
 'exif-fnumber'                     => 'العدد البؤري',
 'exif-fnumber-format'              => 'البعد البؤري/$1',
@@ -2530,23 +2633,23 @@
 'exif-sensingmethod'               => 'وسيلة الاستشعار',
 'exif-filesource'                  => 'مصدر الملف',
 'exif-scenetype'                   => 'نوع المشهد',
-'exif-cfapattern'                  => 'نمط سي إف إيه',
+'exif-cfapattern'                  => 'نمط CFA',
 'exif-customrendered'              => 'معالجة الصورة حسب الطلب',
 'exif-exposuremode'                => 'طور التعرض',
 'exif-whitebalance'                => 'توازن الأبيض',
-'exif-digitalzoomratio'            => 'نسبة الزوم الرقمية',
+'exif-digitalzoomratio'            => 'نسبة التقريب الرقمية',
 'exif-focallengthin35mmfilm'       => 'البعد البؤري في فيلم 35 مم',
 'exif-scenecapturetype'            => 'نوع إمساك المشهد',
 'exif-gaincontrol'                 => 'التحكم بالمشهد',
 'exif-contrast'                    => 'التعارض',
 'exif-saturation'                  => 'التشبع',
 'exif-sharpness'                   => 'الحدة',
-'exif-devicesettingdescription'    => 'وصف إعدادات الأداة',
+'exif-devicesettingdescription'    => 'وصف إعدادات الجهاز',
 'exif-subjectdistancerange'        => 'نطاق مسافة الجسم',
 'exif-imageuniqueid'               => 'رقم الصورة الفريد',
 'exif-gpsversionid'                => 'نسخة وسم GPS',
-'exif-gpslatituderef'              => 'شمال أو جنوب خطوط العرض',
-'exif-gpslatitude'                 => 'خط العرض',
+'exif-gpslatituderef'              => 'دائرة العرض الشمالية أو الجنوبية',
+'exif-gpslatitude'                 => 'دائرة العرض',
 'exif-gpslongituderef'             => 'خط الطول الشرقي أو الغربي',
 'exif-gpslongitude'                => 'خط الطول',
 'exif-gpsaltituderef'              => 'مرجع الارتفاع',
@@ -2557,21 +2660,21 @@
 'exif-gpsmeasuremode'              => 'طريقة القياس',
 'exif-gpsdop'                      => 'دقة القياس',
 'exif-gpsspeedref'                 => 'وحدة السرعة',
-'exif-gpsspeed'                    => 'سرعة مستقبل جي بي إس',
+'exif-gpsspeed'                    => 'سرعة مستقبل GPS',
 'exif-gpstrackref'                 => 'المرجع لاتجاه الحركة',
 'exif-gpstrack'                    => 'اتجاه الحركة',
 'exif-gpsimgdirectionref'          => 'المرجع لاتجاه الصورة',
 'exif-gpsimgdirection'             => 'اتجاه الصورة',
 'exif-gpsmapdatum'                 => 'بيانات استطلاع الجيوديسيك المستخدمة',
-'exif-gpsdestlatituderef'          => 'المرجع لخط عرض الوجهة',
-'exif-gpsdestlatitude'             => 'خط عرض الوجهة',
+'exif-gpsdestlatituderef'          => 'المرجع لدائرة عرض الوجهة',
+'exif-gpsdestlatitude'             => 'دائرة عرض الوجهة',
 'exif-gpsdestlongituderef'         => 'المرجع لخط طول الوجهة',
 'exif-gpsdestlongitude'            => 'خط طول الوجهة',
 'exif-gpsdestbearingref'           => 'المرجع لتحمل الوجهة',
 'exif-gpsdestbearing'              => 'تحمل الوجهة',
 'exif-gpsdestdistanceref'          => 'المرجع للمسافة للهدف',
 'exif-gpsdestdistance'             => 'المسافة للهدف',
-'exif-gpsprocessingmethod'         => 'اسم وسيلة معالجة جي بي إس',
+'exif-gpsprocessingmethod'         => 'اسم وسيلة معالجة GPS',
 'exif-gpsareainformation'          => 'اسم مساحة GPS',
 'exif-gpsdatestamp'                => 'تاريخ GPS',
 'exif-gpsdifferential'             => 'تصحيح GPS التفاضلي',
@@ -2585,7 +2688,7 @@
 
 'exif-unknowndate' => 'تاريخ غير معروف',
 
-'exif-orientation-1' => 'وضعية طبيعية', # 0th row: top; 0th column: left
+'exif-orientation-1' => 'عادي', # 0th row: top; 0th column: left
 'exif-orientation-2' => 'دار عرضيا', # 0th row: top; 0th column: right
 'exif-orientation-3' => 'دار 180°', # 0th row: bottom; 0th column: right
 'exif-orientation-4' => 'دار أفقيا', # 0th row: bottom; 0th column: left
@@ -2595,7 +2698,7 @@
 'exif-orientation-8' => 'دار 90° عكس عقارب الساعة', # 0th row: left; 0th column: bottom
 
 'exif-planarconfiguration-1' => 'صيغة تشنكي',
-'exif-planarconfiguration-2' => 'الصيغة المستوية',
+'exif-planarconfiguration-2' => 'صيغة مستوية',
 
 'exif-xyresolution-i' => '$1 نقطة لكل بوصة',
 'exif-xyresolution-c' => '$1 دي بي سي',
@@ -2613,7 +2716,7 @@
 
 'exif-exposureprogram-0' => 'غير معرف',
 'exif-exposureprogram-1' => 'يدوي',
-'exif-exposureprogram-2' => 'برنامج اعتيادي',
+'exif-exposureprogram-2' => 'برنامج عادي',
 'exif-exposureprogram-3' => 'أولوية الغالق',
 'exif-exposureprogram-4' => 'أولوية الإغلاق',
 'exif-exposureprogram-5' => 'برنامج الصنع (يميل تجاه عمق الحقل)',
@@ -2668,7 +2771,7 @@
 
 'exif-scenetype-1' => 'صورة ملتقطة بشكل مباشر',
 
-'exif-customrendered-0' => 'عملية طبيعية',
+'exif-customrendered-0' => 'عملية عادية',
 'exif-customrendered-1' => 'عملية حسب الطلب',
 
 'exif-exposuremode-0' => 'تعرض تلقائي',
@@ -2689,15 +2792,15 @@
 'exif-gaincontrol-3' => 'تحكم أسفل منخفض',
 'exif-gaincontrol-4' => 'تحكم أسفل مرتفع',
 
-'exif-contrast-0' => 'وضعية طبيعية',
+'exif-contrast-0' => 'عادي',
 'exif-contrast-1' => 'ناعم',
 'exif-contrast-2' => 'قاسي',
 
-'exif-saturation-0' => 'وضعية طبيعية',
+'exif-saturation-0' => 'عادي',
 'exif-saturation-1' => 'تشبع قليل',
 'exif-saturation-2' => 'تشبع عالي',
 
-'exif-sharpness-0' => 'وضعية طبيعية',
+'exif-sharpness-0' => 'عادي',
 'exif-sharpness-1' => 'ناعم',
 'exif-sharpness-2' => 'قاسي',
 
@@ -2731,7 +2834,7 @@
 
 # External editor support
 'edit-externally'      => 'عدل هذا الملف باستخدام تطبيق خارجي',
-'edit-externally-help' => 'انظر [http://meta.wikimedia.org/wiki/Help:External_editors تعليمات الإعداد] لمزيد من المعلومات.',
+'edit-externally-help' => 'انظر [http://www.mediawiki.org/wiki/Manual:External_editors تعليمات الإعداد] لمزيد من المعلومات.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'الكل',
@@ -2743,22 +2846,26 @@
 # E-mail address confirmation
 'confirmemail'             => 'أكد عنوان البريد الإلكتروني',
 'confirmemail_noemail'     => 'ليس لديك عنوان بريد إلكتروني صحيح مسجل في [[Special:Preferences|تفضيلاتك]].',
-'confirmemail_text'        => '{{SITENAME}} يتطلب تأكيد عنوانك الإلكتروني قبل استخدام خصائص البريد الإلكتروني. اضغط على زر التفعيل بالأسفل ليتم إرسال رسالة تأكيد لعنوانك. ستتضمن الرسالة رمز تفعيل؛ اضغط على الوصلة التي تحتوي الرمز لتأكيد أن عنوانك الإلكتروني صحيح.',
-'confirmemail_pending'     => "<div class=\"error\">
-'''تم إرسال كود التأكيد بالفعل من قبل إلى بريدك الإلكتروني، إذا كان حسابك قد تم عمله حالا، ربما يجب أن تنتظر بضع دقائق قبل طلبك لكود آخر.'''
-</div>",
-'confirmemail_send'        => 'أرسل رمز التفعيل',
+'confirmemail_text'        => '{{SITENAME}} يتطلب تأكيد عنوانك الإلكتروني قبل استخدام خصائص البريد الإلكتروني.
+اضغط على زر التفعيل بالأسفل ليتم إرسال رسالة تأكيد لعنوانك.
+ستتضمن الرسالة رمز تفعيل؛
+اضغط على الوصلة التي تحتوي الرمز لتأكيد أن عنوانك الإلكتروني صحيح.',
+'confirmemail_pending'     => '<div class="error">تم إرسال كود التأكيد بالفعل من قبل إلى بريدك الإلكتروني؛
+إذا كان حسابك قد تم عمله حالا، ربما يجب أن تنتظر بضع دقائق قبل طلبك لكود آخر.</div>',
+'confirmemail_send'        => 'أرسل كود تأكيد',
 'confirmemail_sent'        => 'تم إرسال رسالة التأكيد، شكرا لك.',
 'confirmemail_oncreate'    => 'تم إرسال كود تأكيد لعنوان بريدك الإلكتروني.
-لا يشترط أن تستخدم الكود للدخول للموسوعة باسمك، ولكن يجب أن تقوم بإدخاله قبل
-استخدامك أيا من خواص البريد الإلكتروني المستخدمة هنا في الويكي.',
-'confirmemail_sendfailed'  => 'لم نستطع إرسال رسالة التأكيد. من فضلك، تأكد من بريدك الإلكتروني.
+لا يشترط أن تستخدم الكود للدخول للموسوعة باسمك، ولكن يجب أن تقوم بإدخاله قبل استخدامك أيا من خواص البريد الإلكتروني المستخدمة هنا في الويكي.',
+'confirmemail_sendfailed'  => 'لم يمكن إرسال رسالة التأكيد.
+راجع العنوان لحروف غير صحيحة.
 
-الخطأ الذي حدث: $1',
-'confirmemail_invalid'     => 'رمز تفعيل خاطئ. ربما انتهت فترة صلاحيته.',
-'confirmemail_needlogin'   => 'يجب عليك $1 لتأكيد البريد الإلكتروني الخاص بك.',
-'confirmemail_success'     => 'تم تأكيد بريدك الإلكتروني، بإمكانك الآن الدخول و التمتع بالويكي.',
-'confirmemail_loggedin'    => 'تم تأكيد بريدك الإلكتروني، شكرا لك.',
+خادم البريد أرجع: $1',
+'confirmemail_invalid'     => 'كود تأكيد غير صحيح.
+ربما انتهت فترة صلاحيته.',
+'confirmemail_needlogin'   => 'يجب عليك $1 لتأكيد بريدك الإلكتروني.',
+'confirmemail_success'     => 'تم تأكيد بريدك الإلكتروني.
+يمكنك الآن الدخول والتمتع بالويكي.',
+'confirmemail_loggedin'    => 'بريدك الإلكتروني تم تأكيده الآن.',
 'confirmemail_error'       => 'ثمة شئ خطأ حدث عند محاولة حفظ تأكيدك.',
 'confirmemail_subject'     => 'رسالة تأكيد البريد من {{SITENAME}}',
 'confirmemail_body'        => 'شخص ما، من المحتمل أن يكون أنت، من عنوان الأيبي $1،
@@ -2773,35 +2880,34 @@
 
 $5
 
-كود التفعيل هذا ينتهي $4.',
+كود التفعيل هذا سينتهي في $4.',
 'confirmemail_invalidated' => 'تأكيد عنوان البريد الإلكتروني تم إلغاؤه',
 'invalidateemail'          => 'إلغاء تأكيد البريد الإلكتروني',
 
 # Scary transclusion
 'scarytranscludedisabled' => '[التضمين بالإنترويكي معطل]',
 'scarytranscludefailed'   => '[البحث عن القالب فشل ل$1؛ عذرا]',
-'scarytranscludetoolong'  => '[عنوان طويل للغاية؛ معذرة]',
+'scarytranscludetoolong'  => '[مسار طويل للغاية؛ عذرا]',
 
 # Trackbacks
-'trackbackbox'      => '<div id="mw_trackbacks">
-المتابعات الخاصة بهذه المقالة:<br />
+'trackbackbox'      => '<div id="mw_trackbacks">المتابعات لهذه الصفحة:<br />
 $1
 </div>',
 'trackbackremove'   => ' ([$1 حذف])',
 'trackbacklink'     => 'متابعة',
-'trackbackdeleteok' => 'حذفت المراجعة بنجاح.',
+'trackbackdeleteok' => 'المتابعة تم حذفها بنجاح.',
 
 # Delete conflict
 'deletedwhileediting' => 'تحذير: هذه الصفحة تم حذفها بعد أن بدأت أنت بتحريرها!',
-'confirmrecreate'     => "لقد قام المستخدم [[User:$1|$1]] ([[User talk:$1|نقاش]]) بحذف هذه المقالة بعد أن بدأت بتحريرها للسبب التالي:
+'confirmrecreate'     => "المستخدم [[User:$1|$1]] ([[User talk:$1|نقاش]]) حذف هذه الصفحة بعد أن بدأت أنت بتحريرها للسبب التالي:
 :''$2''
-الرجاء التأكد من أنك تريد إعادة إنشاء هذه المقالة.",
+الرجاء التأكد من أنك تريد إعادة إنشاء هذه الصفحة.",
 'recreate'            => 'أعد الإنشاء',
 
 'unit-pixel' => 'بك',
 
 # HTML dump
-'redirectingto' => 'جاري التحويل إلى [[$1]]...',
+'redirectingto' => 'جاري التحويل إلى [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'امسح مختزن هذه الصفحة؟
@@ -2811,14 +2917,14 @@
 
 # AJAX search
 'searchcontaining' => "ابحث عن الصفحات المحتوية على ''$1''.",
-'searchnamed'      => "ابحث عن الصفحات المعنونة ''$1''.",
+'searchnamed'      => "ابحث عن الصفحات المسماة ''$1''.",
 'articletitles'    => "الصفحات التي تبدأ ب''$1''",
 'hideresults'      => 'إخفاء النتائج',
 'useajaxsearch'    => 'استخدم بحث أجاكس',
 
 # Separators for various lists, etc.
 'semicolon-separator' => '؛',
-'comma-separator'     => '،',
+'comma-separator'     => '،&#32;',
 
 # Multipage image navigation
 'imgmultipageprev' => '← الصفحة السابقة',
@@ -2833,7 +2939,7 @@
 'table_pager_prev'         => 'الصفحة السابقة',
 'table_pager_first'        => 'الصفحة الأولى',
 'table_pager_last'         => 'الصفحة الأخيرة',
-'table_pager_limit'        => 'اعرض $1 عنصر في الصفحة',
+'table_pager_limit'        => 'اعرض $1 مدخلة في الصفحة',
 'table_pager_limit_submit' => 'اذهب',
 'table_pager_empty'        => 'لا نتائج',
 
@@ -2858,23 +2964,24 @@
 حاول تجربة العرض العادي.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'التغييرات الأحدث من $1 ثانية قد لا تظهر في هذه القائمة.',
-'lag-warn-high'   => 'نتيجة لوجود تأخر كبير في تحديث قاعدة بيانات الخادم، التغييرات أحدث من $1 ثانية
-ربما لا تكون ظاهرة في هذه القائمة.',
+'lag-warn-normal' => 'التغييرات الأحدث من $1 {{PLURAL:$1|ثانية|ثانية}} قد لا تظهر في هذه القائمة.',
+'lag-warn-high'   => 'نتيجة لوجود تأخر كبير في تحديث قاعدة بيانات الخادم، التغييرات الأحدث من $1 {{PLURAL:$1|ثانية|ثانية}} ربما لا تكون ظاهرة في هذه القائمة.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'قائمة مراقبتك تحتوي على {{PLURAL:$1|عنوان واحد|$1 عنوان}}، بدون احتساب صفحات النقاش.',
 'watchlistedit-noitems'        => 'قائمة مراقبتك لا تحتوي على أية عناوين.',
 'watchlistedit-normal-title'   => 'تعديل قائمة المراقبة',
-'watchlistedit-normal-legend'  => 'أزل عناوين من قائمة المراقبة',
-'watchlistedit-normal-explain' => 'العناوين في قائمة مراقبتك معروضة بالأسفل. لإزالة عنوان، اضغط على
-	الصندوق بجواره، واضغط إزالة العناوين. يمكنك أيضا [[Special:Watchlist/raw|تعديل القائمة الخام]].',
-'watchlistedit-normal-submit'  => 'أزل العناوين',
+'watchlistedit-normal-legend'  => 'إزالة عناوين من قائمة المراقبة',
+'watchlistedit-normal-explain' => 'العناوين في قائمة مراقبتك معروضة بالأسفل.
+لإزالة عنوان، اضغط على الصندوق بجواره، واضغط إزالة العناوين.
+يمكنك أيضا [[Special:Watchlist/raw|تعديل القائمة الخام]].',
+'watchlistedit-normal-submit'  => 'إزالة العناوين',
 'watchlistedit-normal-done'    => '{{PLURAL:$1|عنوان واحد|$1 عنوان}} تمت إزالته من قائمة مراقبتك:',
 'watchlistedit-raw-title'      => 'عدل قائمة المراقبة الخام',
-'watchlistedit-raw-legend'     => 'عدل قائمة المراقبة',
-'watchlistedit-raw-explain'    => 'العناوين في قائمة مراقبتك معروضة بالأسفل، ويمكن تعديلها عن طريق الإضافة والإزالة من القائمة؛ عنوان واحد لكل سطر. عند الانتهاء، اضغط تحديث قائمة المراقبة.
-	يمكنك أيضا [[Special:Watchlist/edit|استخدام المحرر القياسي]].',
+'watchlistedit-raw-legend'     => 'عدل قائمة المراقبة الخام',
+'watchlistedit-raw-explain'    => 'العناوين في قائمة مراقبتك معروضة بالأسفل، ويمكن تعديلها عن طريق الإضافة والإزالة من القائمة؛ عنوان واحد لكل سطر.
+عند الانتهاء، اضغط تحديث قائمة المراقبة.
+يمكنك أيضا [[Special:Watchlist/edit|استخدام المحرر القياسي]].',
 'watchlistedit-raw-titles'     => 'العناوين:',
 'watchlistedit-raw-submit'     => 'تحديث قائمة المراقبة',
 'watchlistedit-raw-done'       => 'قائمة مراقبتك تم تحديثها.',
@@ -2971,12 +3078,15 @@
 'version-software-product'         => 'المنتج',
 'version-software-version'         => 'النسخة',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'مسار ملف',
 'filepath-page'    => 'الملف:',
 'filepath-submit'  => 'المسار',
-'filepath-summary' => 'هذه الصفحة الخاصة تعرض المسار الكامل لملف. ستعرض الصور بأقصى دقة، ستعمل أنواع الملفات الأخرى بالبرنامج المخصص لهم مباشرة؛ أدخل اسم الملف بدون البادئة "{{ns:image}}:"',
+'filepath-summary' => 'هذه الصفحة الخاصة تعرض المسار الكامل لملف.
+ستعرض الصور بأقصى دقة، ستعمل أنواع الملفات الأخرى بالبرنامج المخصص لهم مباشرة.
 
+أدخل اسم الملف بدون البادئة "{{ns:image}}:"',
+
 # Special:FileDuplicateSearch
 'fileduplicatesearch'          => 'بحث عن ملفات مكررة',
 'fileduplicatesearch-summary'  => 'ابحث عن الملفات المكررة بناء على قيمة الهاش الخاصة بها.
@@ -3007,7 +3117,7 @@
 'specialpages-group-redirects'   => 'صفحات خاصة تحول',
 'specialpages-group-spam'        => 'أدوات السبام',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'صفحة فارغة',
 'intentionallyblankpage' => 'هذه الصفحة تركت فارغة عن قصد',
 
Index: languages/messages/MessagesMg.php
===================================================================
--- languages/messages/MessagesMg.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMg.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
  * @author Alno
  * @author לערי ריינהארט
  */
@@ -189,7 +187,7 @@
 'nosuchactiontext'  => "
 Ny asa voafaritra tao amin'ny URL dia tsy fantatr'ity wiki ity",
 'nosuchspecialpage' => 'Tsy misy io pejy manokana io',
-'nospecialpagetext' => 'Nangataka pejy manokana tsy misy ianao, azonao jerena eto [[Special:Specialpages|{{int:specialpages}}]] ny lisitry ny pejy manokana.',
+'nospecialpagetext' => 'Nangataka pejy manokana tsy misy ianao, azonao jerena eto [[Special:SpecialPages|{{int:specialpages}}]] ny lisitry ny pejy manokana.',
 
 # General errors
 'error'           => 'Tsy mety',
@@ -349,10 +347,6 @@
 'blockedtitle'           => 'Mpikambana voasakana',
 'whitelistedittitle'     => 'Midira/Misorata anarana',
 'whitelistedittext'      => "Mila $1 aloha ianao vao afaka manova/mamorona pejy eto amin'ity wiki ity.",
-'whitelistreadtitle'     => 'Mila miditra vao mamaky pejy',
-'whitelistreadtext'      => "Mila [[Special:Userlogin|miditra/misoratra anarana]] ianao vao afaka mijery ny votoatin'ny pejy.",
-'whitelistacctitle'      => "Tsy manana alàlana hamorona kaonty eto amin'ity wiki ity ianao",
-'whitelistacctext'       => "Mila [[Special:Userlogin|miditra/misoratra anarana]] aloha ianao ary manana ny fahazoan-dàlana takiana vao afaka mamorona kaonty eto amin'ity wiki ity.",
 'loginreqtitle'          => 'Mila fidirana',
 'loginreqlink'           => 'hiditra',
 'loginreqpagetext'       => 'Tokony $1 ianao raha te hijery pejy hafa.',
@@ -362,7 +356,7 @@
 'newarticletext'         => "Mbola tsy misy ity takelaka ity koa azonao atao ny mamorona azy eto ambany. Jereo ny [[{{MediaWiki:Helppage}}|Fanoroana]] raha misy fanazavana ilainao.
 
 Raha toa moa ka tsy nieritreritra ny hamorona ity takelaka ity ianao dia miverena etsy amin'ny fandraisana.",
-'anontalkpagetext'       => "----''Eto no sehatra iresahana ho an'ny mpikambana tsy mitonona anarana, izany hoe tsy nisoratra anarana na tsy mampiasa ny solonanarany. Voatery noho izany isika mampiasa ny adiresy IP ho marika hanondroana azy. Io adiresy IP io dia mety hikambanana amin'ny olona maro hafa. Raha tsy mitonona anarana ianao ary mahatsapa fa misy fanamarihana tsy miantefa aminao loatra voarainao, dia iangaviana ianao mba [[Special:Userlogin|hisoratra anarana ho mpikambana na hiditra]] mba tsy hifangaroanao amin'ny mpikambana tsy mitonona anarana hafa intsony.''",
+'anontalkpagetext'       => "----''Eto no sehatra iresahana ho an'ny mpikambana tsy mitonona anarana, izany hoe tsy nisoratra anarana na tsy mampiasa ny solonanarany. Voatery noho izany isika mampiasa ny adiresy IP ho marika hanondroana azy. Io adiresy IP io dia mety hikambanana amin'ny olona maro hafa. Raha tsy mitonona anarana ianao ary mahatsapa fa misy fanamarihana tsy miantefa aminao loatra voarainao, dia iangaviana ianao mba [[Special:UserLogin|hisoratra anarana ho mpikambana na hiditra]] mba tsy hifangaroanao amin'ny mpikambana tsy mitonona anarana hafa intsony.''",
 'noarticletext'          => "'''Tsy mbola nisy namorona io lahatsoratra io... azonao atao ny mamorona azy.'''
 * '''[{{SERVER}}{{localurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} Forony eto ny lahatsoratra momba ny {{PAGENAME}}]'''.
 * [[{{ns:special}}:Search/{{PAGENAME}}|Tadiavo ny momba ny {{PAGENAME}}]] ato.",
@@ -407,7 +401,7 @@
 ianao dia tehirizo anaty rakitra ny fanovanao mandra-paha.</strong>',
 'protectedpagewarning'   => '<strong>FAMPITANDREMANA:  Voaaro ity pejy ity ka ny mpikambana manana ny fahazoan-dàlana sysop ihany no afaka manova azy.</strong>',
 'nocreatetitle'          => 'Voafetra ny famoronana pejy',
-'nocreatetext'           => " Voafetra ihany ny fahafahana mamorona pejy eto amin'ity sehatra ity.  Ny pejy efa misy no azonao ovaina, na [[Special:Userlogin|midira na mamoròna kaonty]].",
+'nocreatetext'           => " Voafetra ihany ny fahafahana mamorona pejy eto amin'ity sehatra ity.  Ny pejy efa misy no azonao ovaina, na [[Special:UserLogin|midira na mamoròna kaonty]].",
 
 # History pages
 'nohistory'        => 'Tsy manana tantaram-panovana io pejy io.',
@@ -456,7 +450,7 @@
 # Preferences page
 'preferences'           => 'Ny momba anao',
 'prefsnologin'          => 'Tsy tafiditra',
-'prefsnologintext'      => '[[Special:Userlogin|Midira]] aloha izay vao manova ny mombamomba anao.',
+'prefsnologintext'      => '[[Special:UserLogin|Midira]] aloha izay vao manova ny mombamomba anao.',
 'changepassword'        => 'Hanova tenimiafina',
 'skin'                  => 'Endrika',
 'dateformat'            => 'endriky ny daty',
@@ -525,10 +519,10 @@
 'reupload'                    => 'Alefaso indray',
 'reuploaddesc'                => "Miverena any amin'ny fisy fandefasan-drakitra.",
 'uploadnologin'               => 'Tsy niditra',
-'uploadnologintext'           => 'Mila [[Special:Userlogin|misoratra anarana]] aloha vao afaka mandefa rakitra.',
+'uploadnologintext'           => 'Mila [[Special:UserLogin|misoratra anarana]] aloha vao afaka mandefa rakitra.',
 'upload_directory_read_only'  => "Ny répertoire ($1) handraisana ny rakitra alefan'ny mpikambana dia tsy afaka anoratana.",
 'uploaderror'                 => 'Nisy tsy fetezana ny fandefasana rakitra',
-'uploadtext'                  => "Ampiasao ity fisy ity handefasana rakitra. Jereo eto ny [[Special:Imagelist|lisitry ny rakitra]] nalefan'ny mpikambana, na koa azonao ampiasaina ny [[Special:Log/upload|tantaran'asan'ny fandefasana sy famonoana rakitra]].
+'uploadtext'                  => "Ampiasao ity fisy ity handefasana rakitra. Jereo eto ny [[Special:ImageList|lisitry ny rakitra]] nalefan'ny mpikambana, na koa azonao ampiasaina ny [[Special:Log/upload|tantaran'asan'ny fandefasana sy famonoana rakitra]].
 
 Raha hanisy sary ao anaty pejy, dia mampiasà rohy toy ny iray amin'ireto
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:file.jpg]]</nowiki>''', na
@@ -569,7 +563,7 @@
 
 'nolicense' => 'Tsy misy safidy',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Lisitry ny rakitra',
 
 # Image description page
@@ -645,7 +639,7 @@
 mampihena ny tantaran'asa miseho eto.",
 'logempty'             => 'Tsy nahitana.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Pejy rehetra',
 'alphaindexline'    => "$1 hatramin'ny $2",
 'nextpage'          => 'Pejy manaraka ($1)',
@@ -664,7 +658,7 @@
 
 # E-mail user
 'mailnologin'     => 'Tsy misy adiresy handefasana ny tenimiafina',
-'mailnologintext' => "Mila [[Special:Userlogin|miditra]] ianao sady manana imailaka mandeha sy voamarina ao amin'ny [[Special:Preferences|mombamomba anao]] vao afaka mandefa imailaka amin'ny mpikambana hafa.",
+'mailnologintext' => "Mila [[Special:UserLogin|miditra]] ianao sady manana imailaka mandeha sy voamarina ao amin'ny [[Special:Preferences|mombamomba anao]] vao afaka mandefa imailaka amin'ny mpikambana hafa.",
 'emailuser'       => 'Andefaso imailaka io mpikambana io',
 'emailpage'       => 'Andefaso imailaka io mpikambana io',
 'emailpagetext'   => "
@@ -688,11 +682,11 @@
 'watchlist'            => 'Narahiko maso',
 'nowatchlist'          => "Tsy misy n'inon'inona ao amin'ny lisitry ny pejy arahinao maso.",
 'watchnologin'         => 'Tsy tafiditra',
-'watchnologintext'     => 'Mila [[Special:Userlogin|miditra/misoratra anarana]] aloha ianao vao afaka manova ny lisitry ny pejy arahinao maso.',
+'watchnologintext'     => 'Mila [[Special:UserLogin|miditra/misoratra anarana]] aloha ianao vao afaka manova ny lisitry ny pejy arahinao maso.',
 'addedwatch'           => "Tafiditra amin'ny lisitry ny pejy arahi-maso akaiky",
 'addedwatchtext'       => "Tafiditra anatin'ny lisitry ny [[Special:Watchlist|PejyArahiMaso]]-nao ny pejy \"<nowiki>\$1</nowiki>\".
 Ny fanovana hisy amin'io pejy io sy ny pejin-dresaka miaraka aminy dia hiseho ao,
-ary rehefa miseho ao amin'ny [[Special:Recentchanges|lisitry ny takelaka vao niova]] io pejy io dia hatao ''matavy'' mba
+ary rehefa miseho ao amin'ny [[Special:RecentChanges|lisitry ny takelaka vao niova]] io pejy io dia hatao ''matavy'' mba
 hahamora ny fahitana azy.
 
 Aoriana, raha irinao ny hanaisotra azy ao amin'ny PejyArahiMaso-nao, dia tsindrio ilay hoe \"Unwatch\" etsy amin'ny sisiny esty.",
@@ -771,7 +765,7 @@
 Ny fanovana farany dia nataon'i [[User:$3|$3]] ([[User talk:$3|Dinika]]).",
 'editcomment'                 => 'Toy izao no fanamarihana momba io fanovana io: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => "Voafafa ny fanovana ny [[Special:Contributions/$2|$2]] ([[User talk:$2|Dinika]]); voaverina amin'ny votoatiny teo aloha nataon'i [[User:$1|$1]]", # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'protectlogtext'              => 'Eto ambany ny lisitry ny fiarovana/fanalana hidy ny pejy. Fanazavana fanampiny: jereo [[Special:Protectedpages]].',
+'protectlogtext'              => 'Eto ambany ny lisitry ny fiarovana/fanalana hidy ny pejy. Fanazavana fanampiny: jereo [[Special:ProtectedPages]].',
 'protectedarticle'            => 'voaaro ny pejy "[[$1]]"',
 'unprotectedarticle'          => 'voaala ny fiarovana an\'i "[[$1]]"',
 'protect-title'               => 'Fiarovana an\'i "$1"',
@@ -832,7 +826,7 @@
 'badipaddress'                => 'Tsy mety ny adiresy IP (invalid)',
 'blockipsuccesssub'           => 'Vita soa aman-tsara ny sakana',
 'blockipsuccesstext'          => 'Voasakana i [[Special:Contributions/$1|$1]].
-<br />Jereo ny [[Special:Ipblocklist|lisitry ny IP voasakana]] raha hanala ny sakana efa misy.',
+<br />Jereo ny [[Special:IPBlockList|lisitry ny IP voasakana]] raha hanala ny sakana efa misy.',
 'unblockip'                   => "Esory ny sakana amin'io mpikambana io",
 'unblockiptext'               => "
 Ampiasao ity fisy eto ambany ity hanalana ny sakana 
@@ -849,7 +843,7 @@
 'blocklogentry'               => 'voasakana i "[[$1]]" mandritra ny $2',
 'blocklogtext'                => "
 Eto no ahitana ny tantaran'ny hetsika momba ny fisakanana sy ny fanafoanana fisakanana mpandray anjara. 
-Ireo adiresy IP voasakana ho azy dia tsy miseho eto. Jereo ao amin'ny [[Special:Ipblocklist|lisitry ny IP voasakana]]
+Ireo adiresy IP voasakana ho azy dia tsy miseho eto. Jereo ao amin'ny [[Special:IPBlockList|lisitry ny IP voasakana]]
 ny lisitry ny fisakanana sy fandrar� na tanteraka misy ankehitriny.",
 'unblocklogentry'             => "voaaisotra ny sakana an'i $1",
 'ipb_expiry_invalid'          => "Tsy mety ilay fotoana hahataperan'ny sakana.",
@@ -888,8 +882,6 @@
 # Move page
 'move-page-legend'        => 'Afindrao toerana ny pejy',
 'movearticle'             => 'Afindrao toerana ny pejy',
-'movenologin'             => 'Tsy mbola tafiditra ianao',
-'movenologintext'         => 'Ny mpikambana nisoratra anarana sy [[Special:Userlogin|tafiditra]] ihany no afaka mamindra toerana takelaka.',
 'newtitle'                => 'Lohateny vaovao',
 'movepagebtn'             => 'Afindrao',
 'pagemovedsub'            => 'Voafindra ny pejy',
@@ -911,7 +903,7 @@
 'delete_and_move'         => 'Ovay toerana dia fafao',
 'delete_and_move_text'    => '==Mila fafàna==
 
-Efa misy ny lahatsoratra hoe "[[$1]]". Irinao ve ny hamafana azy mba hahafahana mamindra toerana ity lahatsoratra ity?',
+Efa misy ny lahatsoratra hoe "[[:$1]]". Irinao ve ny hamafana azy mba hahafahana mamindra toerana ity lahatsoratra ity?',
 'delete_and_move_confirm' => 'Eny, fafao io pejy io',
 'delete_and_move_reason'  => 'Fafao mba hamindrana toerana ny anankiray',
 'selfmove'                => 'Mitovy ny anarana taloha sy anarana vaovao; tsy afaka afindra ny pejy.',
@@ -998,7 +990,7 @@
 'imagemaxsize' => "Ferana ny haben'ny sary ao amin'ny pejy famaritana ho:",
 'thumbsize'    => "Haben'ny thumbnail",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Tahala misy ny rakitra vaovao',
 'imagelisttext' => 'Eto ambany ny lisitry ny rakitra $1 milahatra araka ny $2.',
 'showhidebots'  => '(rôbô $1)',
@@ -1013,7 +1005,7 @@
 
 # External editor support
 'edit-externally'      => "Ovao amin'ny alalan'ny fampiasana fitaovana ivelan'ity Wiki ity io rakitra io",
-'edit-externally-help' => 'Fanazavana fanampiny, jereo [http://meta.wikimedia.org/wiki/Help:External_editors ny torolalana].',
+'edit-externally-help' => 'Fanazavana fanampiny, jereo [http://www.mediawiki.org/wiki/Manual:External_editors ny torolalana].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'rehetra',
Index: languages/messages/MessagesTg_cyrl.php
===================================================================
--- languages/messages/MessagesTg_cyrl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTg_cyrl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,17 +1,15 @@
 <?php
-/** Tajik (Cyrillic) (Тоҷикӣ/tojikī (Cyrillic))
+/** Tajik (Cyrillic) (Тоҷикӣ (Cyrillic))
  *
  * @ingroup Language
  * @file
  *
- * @author Ibrahim
- * @author FrancisTyers
- * @author SPQRobin
- * @author Siebrand
- * @author לערי ריינהארט
+ * @author Cbrown1023
  * @author Farrukh
+ * @author FrancisTyers
+ * @author Ibrahim
  * @author Soroush
- * @author Cbrown1023
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -346,7 +344,7 @@
 'nosuchspecialpage' => 'Чунин саҳифаи вижа вуҷуд надорад',
 'nospecialpagetext' => "<big>'''Шумо саҳифаи вижаеро дархост кардаед, ки нодуруст аст.'''</big>
 
-Феҳристи саҳифаҳои вижаи дурустро метавонед дар инҷо [[Special:Specialpages|{{int:specialpages}}]] нигаред.",
+Феҳристи саҳифаҳои вижаи дурустро метавонед дар инҷо [[Special:SpecialPages|{{int:specialpages}}]] нигаред.",
 
 # General errors
 'error'                => 'Иштибоҳ',
@@ -429,7 +427,7 @@
 'loginproblem'               => '<b>Вуруди шумо ба систем бо мушкили рӯ ба рӯ шуд.</b><br />Бори дигар санҷед!',
 'login'                      => 'Вуруд',
 'nav-login-createaccount'    => 'Вуруд / Сохтани ҳисоби ҷадид',
-'loginprompt'                => 'Барои вуруд ба {{SITENAME}} бояд кукиҳоро фаъол кунед.',
+'loginprompt'                => '[[Special:UserLogin|Барои вуруд ба {{SITENAME}}]] бояд кукиҳоро фаъол кунед.',
 'userlogin'                  => 'Вуруд / Сохтани ҳисоби ҷадид',
 'logout'                     => 'Хуруҷ аз систем',
 'userlogout'                 => 'Хуруҷ аз систем',
@@ -574,10 +572,6 @@
 'blockededitsource'         => "Матни '''вироишҳои шумо''' дар '''$1''' дар зер нишон дода шудааст:",
 'whitelistedittitle'        => 'Барои вироиш вуруд бояд кард',
 'whitelistedittext'         => 'Барои вироиши мақола бояд ба систем $1 шавед.',
-'whitelistreadtitle'        => 'Барои хондан бояд вуруд кард',
-'whitelistreadtext'         => 'Барои хонадани мақолаҳо бояд [[Special:Userlogin|ба систем ворид шавед]].',
-'whitelistacctitle'         => 'Ба Шумо барои сохтани номи корбар иҷозат нест.',
-'whitelistacctext'          => 'Барои эчоди ҳисоб дар {{SITENAME}} шумо бояд [[Special:Userlogin|вуруд]] карда, рухсати марбута ба ин корро дошта бошед.',
 'confirmedittitle'          => 'Тасдиқ кардани нишонаи почтаи электронӣ барои вироиш кардан лозим аст',
 'confirmedittext'           => 'Шумо бояд нишонаи почтаи электрониатонро пеш аз вироиш кардани саҳифаҳо, тасдиқ кунед. Лутфан ин корро тариқи [[Special:Preferences|тарҷиҳоти корбар]] сурат диҳед.',
 'nosuchsectiontitle'        => 'Чунин бахше вуҷуд надорад',
@@ -591,7 +585,7 @@
 'newarticletext'            => "Шумо пайвандеро интихоб кардед, ки саҳифа дар он арзи вуҷуд надорад.
 Барои сохтани саҳифа, ба қуттии зерин нависед ([[{{MediaWiki:Helppage}}|саҳифаи роҳнаморо]] барои маълумоти бештар нигаред).
 Агар аз сабаби хатогӣ ва ё иштибоҳ омадед, тугмаи '''Ба оқиб'''-ро дар браузери худ пахш кунед.",
-'anontalkpagetext'          => "----''Ин саҳифае баҳсе барои корбари гумном (аноним) аст, ки ҳануз ҳисоби ҷадид эчод накардааст ва ё аз он истифода намекунад. Бинобар ин барои шиносоиаш маҷбурем аз нишонаи IP истифода кунем. Чунин нишонаи IP мумкин аст аз тарафи чандин корбарон ба шакли муштарак истифода шавад. Агар шумо корбари гумном ҳастед ва ҳис мекунед, изҳори назари номарбуте ба шумо сурат гирифтааст, лутфан барои пешгири аз иштибоҳ гирифта шудан бо корбарони гумноми дигар дар оянда [[Special:Userlogin|ҳисобе эҷод кунед ё вориди систем шавед]].''",
+'anontalkpagetext'          => "----''Ин саҳифае баҳсе барои корбари гумном (аноним) аст, ки ҳануз ҳисоби ҷадид эчод накардааст ва ё аз он истифода намекунад. Бинобар ин барои шиносоиаш маҷбурем аз нишонаи IP истифода кунем. Чунин нишонаи IP мумкин аст аз тарафи чандин корбарон ба шакли муштарак истифода шавад. Агар шумо корбари гумном ҳастед ва ҳис мекунед, изҳори назари номарбуте ба шумо сурат гирифтааст, лутфан барои пешгири аз иштибоҳ гирифта шудан бо корбарони гумноми дигар дар оянда [[Special:UserLogin|ҳисобе эҷод кунед ё вориди систем шавед]].''",
 'noarticletext'             => 'Дар ин саҳифа то кунун, матн вуҷуд надорад, шумо метавонед дар дигар саҳифаҳо [[Special:Search/{{PAGENAME}}|унвони ин саҳифаро ҷустуҷӯ кунед]] ё [{{fullurl:{{FULLPAGENAME}}|action=edit}} ин саҳифаро вироиш кунед].',
 'userpage-userdoesnotexist' => 'Ҳисоби корбар "$1" сабт нашудааст. Итминон ҳосил кунед ки мехоҳед ин саҳифаро эчод ё вироиш кунед.',
 'clearyourcache'            => "'''Эзоҳ:''' Пас аз захирасозӣ мумкин аст барои дидани тағйирот ниёз бошад, ки ҳофизаи ниҳонии мурургари худро холӣ кунед. '''Мозилла / Файерфокс / Сафари:''' калиди ''Shift''-ро нигоҳ доред  ва рӯи тугмаи  ''Reload'' клик кунед, ё калидҳои ''Ctrl-Shift-R'' (''Cmd-Shift-R'' дар Эппл Макинтош) бо ҳам фишор диҳед; '''IE:''' калиди ''Ctrl'' нигоҳ доред ва рӯи тугмаи ''Refresh'' клик кунед, ё калидҳои ''Ctrl-F5'' бо ҳам фишор диҳед; '''Konqueror:''': тугмаи ''Reload''-ро оддӣ клик кунед, ё калиди ''F5'' фишор диҳед; Ба корбарони '''Opera''' мумкин аст лозим бошад, ки ҳофизаи ниҳонии худро комилан дар ''Tools→Preferences'' холӣ кунанд.",
@@ -646,7 +640,7 @@
 'hiddencategories'          => 'Ин саҳифа дар {{PLURAL:$1|1 гурӯҳи пинҳон|$1 гурӯҳҳои пинҳон}} қарор дорад:',
 'nocreatetitle'             => 'Эҷоди саҳифа маҳдуд шудааст',
 'nocreatetext'              => '{{SITENAME}} қобилияти эҷоди саҳифаҳои ҷадидро маҳдуд карда аст.
-Шумо метавонед бозгашта саҳифаи мавҷудбударо вироиш кунед, ё [[Special:Userlogin|ба систем вуруд кунед ё ҳисоби корбарӣ эҷод кунед]].',
+Шумо метавонед бозгашта саҳифаи мавҷудбударо вироиш кунед, ё [[Special:UserLogin|ба систем вуруд кунед ё ҳисоби корбарӣ эҷод кунед]].',
 'nocreate-loggedin'         => 'Шумо иҷозати эҷоди саҳифаи ҷадидро дар {{SITENAME}} надоред.',
 'permissionserrors'         => 'Хатоҳои сатҳи дастрасӣ',
 'permissionserrorstext'     => 'Шумо рухсати анҷоми ин корро ба {{PLURAL:$1|сабаби|сабабҳои}} зерин надоред:',
@@ -747,7 +741,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Гузориши мавқуфсозӣ',
-'suppressionlogtext' => 'Дар зер феҳристе аз охирин ҳазфҳо ва қатъи дастрасиҳоеро мебинед, ки мӯҳтавои онҳо аз мудирон пинҳон шуда мебошад. Барои феҳристи қатъи дастрасиҳои фаъол ман мамнӯъҳо ба [[Special:Ipblocklist|феҳристи қатъи дастрасиҳои IP]] нигаред.',
+'suppressionlogtext' => 'Дар зер феҳристе аз охирин ҳазфҳо ва қатъи дастрасиҳоеро мебинед, ки мӯҳтавои онҳо аз мудирон пинҳон шуда мебошад. Барои феҳристи қатъи дастрасиҳои фаъол ман мамнӯъҳо ба [[Special:IPBlockList|феҳристи қатъи дастрасиҳои IP]] нигаред.',
 
 # History merging
 'mergehistory'                     => 'Идғоми таърихи саҳифаҳо',
@@ -823,7 +817,7 @@
 'mypreferences'            => 'Тарҷиҳоти ман',
 'prefs-edits'              => 'Шумораи вироишҳо:',
 'prefsnologin'             => 'Ба систем ворид нашудаед',
-'prefsnologintext'         => 'Барои танзими тарҷиҳоти корбарӣ бояд [[Special:Userlogin|вуруд ба систем шавед]].',
+'prefsnologintext'         => 'Барои танзими тарҷиҳоти корбарӣ бояд [[Special:UserLogin|вуруд ба систем шавед]].',
 'prefsreset'               => 'Тарҷиҳот аз ҳофиза аз нав шуд.',
 'qbsettings'               => 'Танзимоти тезхат (Quickbar)',
 'qbsettings-none'          => 'Набошад',
@@ -895,7 +889,7 @@
 'userrights-reason'           => 'Иллати тағйир:',
 'userrights-no-interwiki'     => 'Шумо иҷозати тағйири ихтиёроти корбарони дигар викиҳоро надоред.',
 'userrights-nodatabase'       => 'Пойгоҳи дода $1 вуҷуд надорад ё маҳаллӣ нест.',
-'userrights-nologin'          => 'Шумо бояд бо як ҳисоби корбарӣ дорои ихтиёроти мудириятӣ [[Special:Userlogin|ба систем вуруд кунед]], то битавонед ихтиёроти корбаронро таъйид кунед.',
+'userrights-nologin'          => 'Шумо бояд бо як ҳисоби корбарӣ дорои ихтиёроти мудириятӣ [[Special:UserLogin|ба систем вуруд кунед]], то битавонед ихтиёроти корбаронро таъйид кунед.',
 'userrights-notallowed'       => 'Ҳисоби корбарии шумо иҷозати тағйири ихтиёроти корбариро надорад.',
 'userrights-changeable-col'   => 'Гурӯҳҳое, ки шумо метавонед тағйир диҳед',
 'userrights-unchangeable-col' => 'Гурӯҳҳое, ки шумо наметавонед тағйир диҳед',
@@ -947,7 +941,7 @@
 'recentchanges'                     => 'Тағйироти охирин',
 'recentchangestext'                 => 'Назорати тағйиротҳои навтарин дар Википедиа дар ҳамин саҳифа аст.',
 'recentchanges-feed-description'    => 'Радёбии охирин тағйироти ин вики дар ин хурд.',
-'rcnote'                            => "Дар поён  {{PLURAL:$1|'''1''' тағйире аст|'''$1''' тағйирот мебошанд}}, ки дар давоми {{PLURAL:$2|рӯҳ|'''$2''' рӯзҳои}} охир, сар карда аз $3.",
+'rcnote'                            => "Дар поён  {{PLURAL:$1|'''1''' тағйире аст|'''$1''' тағйирот мебошанд}}, ки дар давоми {{PLURAL:$2|рӯҳ|'''$2''' рӯзҳои}} охир, сар карда аз $5, $4.",
 'rcnotefrom'                        => 'Дар зер тағйиротҳои охирин аз <b>$2</b> (то <b>$1</b> нишон дода шудааст).',
 'rclistfrom'                        => 'Нишон додани тағйиротҳои нав сар карда аз $1',
 'rcshowhideminor'                   => '$1 вироишҳои хурд',
@@ -983,10 +977,10 @@
 'reupload'                    => 'Боргузории дубора',
 'reuploaddesc'                => 'Боргузориро лағв кунед ва ба форми боргузорӣ баргардед.',
 'uploadnologin'               => 'Вуруд накарда',
-'uploadnologintext'           => 'Барои фиристодани файлҳо Шумо бояд [[Special:Userlogin|вуруд кунед]].',
+'uploadnologintext'           => 'Барои фиристодани файлҳо Шумо бояд [[Special:UserLogin|вуруд кунед]].',
 'upload_directory_read_only'  => 'Шохаи боргузорӣ ($1) аз тарафи веб коргузор қобили навиштан нест.',
 'uploaderror'                 => 'Иштибоҳи фиристодан',
-'uploadtext'                  => "Аз форми зерин барои богузорӣ кардани парвандаҳои ҷадид истифода кунед. Барои дидани парвандаҳое, ки қаблан боргузори шудаанд ба [[Special:Imagelist|феҳристи парвандаҳои боргузоришуда]], боргузориҳо ва ҳамчунин ҳазфҳо дар [[Special:Log/upload|гузориши боргузорӣ]] сабт мешаванд.
+'uploadtext'                  => "Аз форми зерин барои богузорӣ кардани парвандаҳои ҷадид истифода кунед. Барои дидани парвандаҳое, ки қаблан боргузори шудаанд ба [[Special:ImageList|феҳристи парвандаҳои боргузоришуда]], боргузориҳо ва ҳамчунин ҳазфҳо дар [[Special:Log/upload|гузориши боргузорӣ]] сабт мешаванд.
 
 Баъд аз ин ки парвандаеро богузорӣ кардаед, ба ин се шакл метавонед онро дар саҳифаҳо истифода кунед
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1069,7 +1063,7 @@
 'upload_source_url'  => '(як нишони интернетии мӯътабар ва оммавӣ)',
 'upload_source_file' => ' (парвандае дар компютери шумо)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ин саҳифаи вижа тамоми парвандаҳои боргузоришударо нишон медиҳад.
 Ба таври пешфарз охирин парвандаҳои боргузоришуда дар болои феҳрист нишон дода шудаанд.
 Як клик кардани рӯи унвони сутунҳо боиси тағйири тартиби намоиши парвандаҳо мешавад.',
@@ -1111,18 +1105,18 @@
 # File reversion
 'filerevert'                => 'Вогардонии $1',
 'filerevert-legend'         => 'Вогардонии парванда',
-'filerevert-intro'          => '<span class="plainlinks">Шумо дар ҳоли вогардонии \'\'\'[[Media:$1|$1]]\'\'\' ба [$4 нусхаи аз $3, $2] ҳастед.</span>',
+'filerevert-intro'          => "Шумо дар ҳоли вогардонии '''[[Media:$1|$1]]''' ба [$4 нусхаи аз $3, $2] ҳастед.",
 'filerevert-comment'        => 'Тавзеҳ:',
 'filerevert-defaultcomment' => 'Вогардонӣ ба нусхаи $2, $1',
 'filerevert-submit'         => 'бирав',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' вогардонида шуд ба [нусхаи $4 аз таърихи $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' вогардонида шуд ба [нусхаи $4 аз таърихи $3, $2].",
 'filerevert-badversion'     => 'Нусхаи кӯҳнатаре аз ин парванда вуҷуд надошт.',
 
 # File deletion
 'filedelete'                  => 'Ҳазфи $1',
 'filedelete-legend'           => 'Ҳазфи парванда',
 'filedelete-intro'            => "Шумо дар ҳоли ҳазф кардани '''[[Media:$1|$1]]''' ҳастед.",
-'filedelete-intro-old'        => '<span class="plainlinks">Шумо дар ҳоли ҳазфи нусхаи \'\'\'[[Media:$1|$1]]\'\'\' аз таърихи [$4 $3, $2] ҳастед.</span>',
+'filedelete-intro-old'        => "Шумо дар ҳоли ҳазфи нусхаи '''[[Media:$1|$1]]''' аз таърихи [$4 $3, $2] ҳастед.",
 'filedelete-comment'          => 'Сабаби ҳазф:',
 'filedelete-submit'           => 'Ҳазф',
 'filedelete-success'          => "'''$1''' ҳазф шуд.",
@@ -1176,7 +1170,7 @@
 Ба ин тартиб ҳар саҳифа ба ҳисоби миёна '''\$5''' вироиш шудааст, ва '''\$6''' назарот ба ҳар вироиш сурат гирифта аст.
 
 Тӯли [http://www.mediawiki.org/wiki/Manual:Job_queue саф корҳо] '''\$7''' аст.",
-'userstatstext'          => "Теъдоди {{PLURAL:$1|'''1''' [[Special:Listusers|корбаре]] сабти ном шуда вуҷуд дорад,|'''$1''' [[Special:Listusers|корбароне]] вуҷуд доранд}}, ки аз байни онҳо '''$2''' (ё '''$4%''') нафар $5 дорои дастраси {{PLURAL:$2|аст|ҳастанд}}.",
+'userstatstext'          => "Теъдоди {{PLURAL:$1|'''1''' [[Special:ListUsers|корбаре]] сабти ном шуда вуҷуд дорад,|'''$1''' [[Special:ListUsers|корбароне]] вуҷуд доранд}}, ки аз байни онҳо '''$2''' (ё '''$4%''') нафар $5 дорои дастраси {{PLURAL:$2|аст|ҳастанд}}.",
 'statistics-mostpopular' => 'Саҳифаҳои бисёр назаркардашуда',
 
 'disambiguations'      => 'Саҳифаҳои ибҳомзудоӣ',
@@ -1265,7 +1259,7 @@
 'logempty'             => 'Мавриди мутобиқ ба манзури шумо дар гузориш пайдо нашуд.',
 'log-title-wildcard'   => 'Саҳифаҳоеро ҷустуҷӯ кунед, ки унвонашон бо ин матн оғоз мешаванд',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Ҳамаи саҳифаҳо',
 'alphaindexline'    => '$1 то $2',
 'nextpage'          => 'Саҳифаи баъдина ($1)',
@@ -1287,18 +1281,18 @@
 'special-categories-sort-count' => 'муратаб кардан бар асоси теъдод',
 'special-categories-sort-abc'   => 'муратаб кардани алифбоӣ',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Намоиши корбарон бо шурӯъ аз:',
 'listusers-submit'   => 'Нишон додани',
 'listusers-noresult' => 'Ҳеҷ корбаре ёфт нашуд.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'   => 'Гурӯҳ',
 'listgrouprights-members' => '(феҳристи аъзоён)',
 
 # E-mail user
 'mailnologin'     => 'Нишонае аз фиристанда вуҷуд надорад',
-'mailnologintext' => 'Барои фиристодани почтаи электронӣ барои корбарони дигар бояд [[Special:Userlogin|ба систем ворид шавед]] ва нишонаи почтаи электронии мӯътабар дар [[Special:Preferences|тарҷиҳоти]] худ дошта бошед.',
+'mailnologintext' => 'Барои фиристодани почтаи электронӣ барои корбарони дигар бояд [[Special:UserLogin|ба систем ворид шавед]] ва нишонаи почтаи электронии мӯътабар дар [[Special:Preferences|тарҷиҳоти]] худ дошта бошед.',
 'emailuser'       => 'Фиристодани email ба ин корбар',
 'emailpage'       => 'Почтаи электронӣ ба корбар',
 'emailpagetext'   => 'Агар ин корбар нишонаи почтаи электронии мӯътабаре дар тарҷиҳоти ворид карда бошад, форми зерин як пайғоме мефиристад.
@@ -1324,11 +1318,11 @@
 'nowatchlist'          => 'Дар феҳристи пайгириҳои шумо ҳеҷ мавриде нест.',
 'watchlistanontext'    => 'Лутфан барои мушоҳида ва вироиши феҳристи пайгириҳои худ аз $1 истифода кунед.',
 'watchnologin'         => 'Вуруд нашуда',
-'watchnologintext'     => 'Барои тағйири феҳристи пайгириҳои худ бояд [[Special:Userlogin|ба систем ворид шавед]].',
+'watchnologintext'     => 'Барои тағйири феҳристи пайгириҳои худ бояд [[Special:UserLogin|ба систем ворид шавед]].',
 'addedwatch'           => 'Ба феҳристи пайгириҳо илова карда шуд',
 'addedwatchtext'       => "Ин саҳифа \"[[:\$1]]\" ва [[Special:Watchlist|феҳристи назароти]] Шумо илова шуд.
 Дигаргуниҳои ояндаи ин саҳифа ва саҳифи баҳси алоқаманд дар рӯихати онҷо хоҳад шуд,
-ва саҳифа '''ғафс''' дар [[Special:Recentchanges|рӯихати тағйироти охирин]] барои бо осони дарёфт кардан хоҳад ба назар расид.
+ва саҳифа '''ғафс''' дар [[Special:RecentChanges|рӯихати тағйироти охирин]] барои бо осони дарёфт кардан хоҳад ба назар расид.
 
 Агар шумо дертар аз феҳристи назаротатон ин саҳифаро ҳазв кардан хоҳед, дар меню \"Назар накардан\"-ро пахш кунед.",
 'removedwatch'         => 'Аз феҳристи пайгириҳо бардошта шуд',
@@ -1437,7 +1431,7 @@
 'rollback-success'            => 'Вироишҳои $1 вогардонӣ шуд; саҳифа ба вироиши $2 баргардонида шуд.',
 'sessionfailure'              => 'Ба назар мерасад, мушкилие дар мавриди нишасти корбарии шумо вуҷуд дорад; амали дархостшуда ба унвони иқдоми пешгирона дар баробари рабуда шудани иттилооти нишасти корбарӣ, лағв шуд. Лутфан тугмаи "бозгашт"-ро дар мурургари худ пахш кунед ва саҳифае, ки аз он инҷо расидаед муҷаддадан фарохонӣ кунед, сипас муҷаддадан боз саъй кунед.',
 'protectlogpage'              => 'Гузориши муҳофизат',
-'protectlogtext'              => 'Дар зер феҳристи қуфл карданҳо ва аз қуфл озод шуданҳо омада аст. Барои иттилооти бештар ба [[Special:Protectedpages|феҳристи саҳифаҳои муҳофизатшуда]] нигаред.',
+'protectlogtext'              => 'Дар зер феҳристи қуфл карданҳо ва аз қуфл озод шуданҳо омада аст. Барои иттилооти бештар ба [[Special:ProtectedPages|феҳристи саҳифаҳои муҳофизатшуда]] нигаред.',
 'protectedarticle'            => '"[[$1]]" муҳофизат шуд',
 'modifiedarticleprotection'   => 'сатҳи муҳофизати саҳифаи "[[$1]]" тағйир дода шуд',
 'unprotectedarticle'          => 'аз муҳофизат озод шуда "[[$1]]"',
@@ -1589,7 +1583,7 @@
 'badipaddress'                => 'IP нишонаи номӯътабар',
 'blockipsuccesssub'           => 'Бастан муваффақ щуд',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] баста шудааст.<br />
-Барои баррасӣ ба [[Special:Ipblocklist|феҳристи нишонаҳои IP ва номҳои корбарии баста шуда]] нигаред.',
+Барои баррасӣ ба [[Special:IPBlockList|феҳристи нишонаҳои IP ва номҳои корбарии баста шуда]] нигаред.',
 'ipb-edit-dropdown'           => 'Далели қатъи дастрасӣ',
 'ipb-unblock-addr'            => 'Боз кардани $1',
 'ipb-unblock'                 => 'Боз кардани номи корбарӣ ё нишонаи IP',
@@ -1621,7 +1615,7 @@
 'blocklogentry'               => 'баста шуд [[$1]] бо вақти саромадан $2 $3',
 'blocklogtext'                => 'Ин гузориш аз амали бастан ва боз кардани корбарон аст.
 Нишонаҳои IP-и бо таври худкор баста шуда, феҳрист нашудаанд.
-Барои феҳристи маҳрумиятҳо ва баста шуданҳои амалиёти кунунӣ ба [[Special:Ipblocklist|феҳристи IP-ҳои баста]] муроҷиат кунед.',
+Барои феҳристи маҳрумиятҳо ва баста шуданҳои амалиёти кунунӣ ба [[Special:IPBlockList|феҳристи IP-ҳои баста]] муроҷиат кунед.',
 'unblocklogentry'             => '$1 боз шуд',
 'block-log-flags-anononly'    => 'фақат корбарони гумном',
 'block-log-flags-nocreate'    => 'қобилияти эҷоди ҳисоб ғайрифаъол шуд',
@@ -1656,7 +1650,7 @@
 'lockdbsuccesssub'    => 'Қуфл кардани пойгоҳи дода бо муваффақият анҷом шуд',
 'unlockdbsuccesssub'  => 'Қуфли пойгоҳи дода бардошта шуд',
 'lockdbsuccesstext'   => 'Пойгоҳи дода қуфл шуд.<br />
-Фаромӯш накунед, ки пас аз итмоми нигоҳдорӣ [[Special:Unlockdb|қуфлро бардоред]].',
+Фаромӯш накунед, ки пас аз итмоми нигоҳдорӣ [[Special:UnlockDB|қуфлро бардоред]].',
 'unlockdbsuccesstext' => 'Пойгоҳи дода аз қуфл боз шуд.',
 'lockfilenotwritable' => 'Парвандаи қуфли дода навиштанӣ нест. Барои он ки битавонед, пойгоҳи додаро қуфл ё боз кунед, ин парванда бояд аз тарафи коргузор навиштанӣ бошад.',
 'databasenotlocked'   => 'Пойгоҳи дода қуфл нест.',
@@ -1682,13 +1676,12 @@
 
 Дар он ҳолатҳо, саҳифаро бояд ба таври дастӣ кӯчонид ва ё ду саҳифаро бо вироиш як кунед.",
 'movearticle'             => 'Кӯчонидани саҳифа:',
-'movenologin'             => 'Вуруд нашудаед',
-'movenologintext'         => 'Барои кӯчонидани саҳифа шумо бояд корбари сабтшуда ва [[Special:Userlogin|ба систем вурудшуда]] бошед.',
 'movenotallowed'          => 'Шумо иҷозати кӯчонидани саҳифаҳоро дар Википедиа надоред.',
 'newtitle'                => 'Ба унвони ҷадид:',
 'move-watch'              => 'Назар кардани ин саҳифа',
 'movepagebtn'             => 'Кӯчонидани саҳифа',
 'pagemovedsub'            => 'Кӯчониш бомуваффақият анҷом ёфт',
+'movepage-moved'          => '<big>\'\'\'"$1" ба "$2" кӯчонида шуд\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Саҳифае бо ин ном вуҷуд надорад, ё номе, ки интихоб кардаед мӯътабар нест.
 Лутфан номи дигареро интихоб намоед.',
 'cantmove-titleprotected' => 'Шумо наметавонед ин саҳифаро ба ин нишона кӯчонед, барои он, ки унвони ҷадид аз эҷод кардан муҳофизат шудааст',
@@ -1704,7 +1697,7 @@
 'delete_and_move'         => 'Ҳазф ва кӯчонидан',
 'delete_and_move_text'    => '==Ниёз ба ҳазф==
 
-Мақолаи мақсад "[[$1]]" вуҷуд дорад. Оё мехоҳед онро ҳазф кунед то интиқол мумкин шавад?',
+Мақолаи мақсад "[[:$1]]" вуҷуд дорад. Оё мехоҳед онро ҳазф кунед то интиқол мумкин шавад?',
 'delete_and_move_confirm' => 'Бале, саҳифа ҳазф шавад',
 'delete_and_move_reason'  => 'Ҳазф шуд барои мумкин шудани кӯчонидан',
 'selfmove'                => 'Унвонҳои манбаъ ва мақсад якхела мебошад; кӯчонидани саҳифа ба худаш мумкин нест.',
@@ -1926,10 +1919,10 @@
 'show-big-image'       => 'Акси пурра',
 'show-big-image-thumb' => '<small>Андозаи ин пешнамоиш: $1 × $2 пиксел</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Намоишгоҳи парвандаҳои ҷадид',
 'imagelisttext'         => "Дар зер феҳристи '''$1''' {{PLURAL:$1|парвандаи|парвандаҳои}} ба тартиб оварда шуда, омадааст $2.",
-'newimages-summary'     => 'Ин саҳифаи вижа охирин парвандаҳои боршударо намоиш медиҳад',
+'newimages-summary'     => 'Ин саҳифаи вижа охирин парвандаҳои боршударо намоиш медиҳад.',
 'showhidebots'          => '($1 ботҳо)',
 'noimages'              => 'Чизе барои дидан нест.',
 'ilsubmit'              => 'Ҷустуҷӯи',
@@ -2211,7 +2204,7 @@
 
 # External editor support
 'edit-externally'      => 'Ин файлро бо барномаи беруна таҳрир кунед',
-'edit-externally-help' => 'Барои иттилооти бештар [http://meta.wikimedia.org/wiki/Help:External_editors роҳнамои танзимотро оиди вироишгарони беруна] нигаред.',
+'edit-externally-help' => 'Барои иттилооти бештар [http://www.mediawiki.org/wiki/Manual:External_editors роҳнамои танзимотро оиди вироишгарони беруна] нигаред.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ҳама',
@@ -2288,7 +2281,7 @@
 'recreate'            => 'Аз нав созед',
 
 # HTML dump
-'redirectingto' => 'Дар ҳоли тағйири масир ба [[$1]]...',
+'redirectingto' => 'Дар ҳоли тағйири масир ба [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Пок карадни нусхаи ҳофизаи ниҳонии (Cache) ин саҳифаро таъйид мекунед?
@@ -2398,7 +2391,7 @@
 'version-software-product'         => 'Маҳсул',
 'version-software-version'         => 'Нусха',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Масири парванда',
 'filepath-page'    => 'Парванда:',
 'filepath-submit'  => 'Масир',
Index: languages/messages/MessagesCdo.php
===================================================================
--- languages/messages/MessagesCdo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCdo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  */
 
 $datePreferences = array(
@@ -228,7 +227,7 @@
 'userlogin'                  => 'Láuk-diē / kŭi dióng-hô̤',
 'logout'                     => 'Láuk-chók',
 'userlogout'                 => 'Láuk-chók',
-'notloggedin'                => 'Mò̤ [[Special:Userlogin|láuk-diē]]',
+'notloggedin'                => 'Mò̤ [[Special:UserLogin|láuk-diē]]',
 'nologin'                    => 'Gó muôi kŭi dióng-hô̤? $1.',
 'nologinlink'                => 'Kŭi 1 ciáh sĭng dióng-hô̤',
 'createaccount'              => 'Kŭi dióng-hô̤',
@@ -291,7 +290,7 @@
 'accmailtext'              => '"$1" gì mĭk-mā ī-gĭng gié ké̤ṳk $2 lāu.',
 'newarticle'               => '(Sĭng)',
 'newarticletext'           => "Nṳ̄ téng 1 ciáh lièng-giék lì gáu cī miêng gó muôi còng-câi gì hiĕk. Buóh kī-chiū piĕng-siā ciā hiĕk, chiāng diŏh â-dā̤ gì bēng-bēng diē-sié páh cê (chăng-kō̤ [[Help:Mŭk-liŏh]] liēu-gāi gáing sâ̤ séng-sék). Iŏk-sṳ̄ nṳ̄ huák-hiêng cê-gă giàng dâng gó̤, nâ dĭh áik báuk-lāng-ké (''browser'') gì \"'''duōng kó̤ sèng 1 hiĕk'''\" (''back'') cêu â̤-sāi lāu.",
-'anontalkpagetext'         => "----''Cī tiŏng tō̤-lâung-hiĕk mò̤ gó-dêng gì dióng-hô̤, nâ ô 1 ciáh IP dê-cī. Chiāng cé̤ṳ-é: Kō̤-nèng ng-nié 1 ciáh nè̤ng sāi-ê̤ṳng cī ciáh IP dê-cī. Iŏk-sṳ̄ nṳ̄ gó muôi kŭi 1 ciáh dióng-hô̤ bêng-chiā giéng-gáe̤k ciā làu-uâ sê làu ké̤ṳk nṳ̄ gì, chiāng nṳ̄ [[Special:Userlogin|kŭi 1 ciáh dióng-hô̤ hĕ̤k-ciā láuk-diē]], cêu â̤ piáh-miēng ī-hâiu gái huák-sĕng cūng-kuāng ông-dà̤.''",
+'anontalkpagetext'         => "----''Cī tiŏng tō̤-lâung-hiĕk mò̤ gó-dêng gì dióng-hô̤, nâ ô 1 ciáh IP dê-cī. Chiāng cé̤ṳ-é: Kō̤-nèng ng-nié 1 ciáh nè̤ng sāi-ê̤ṳng cī ciáh IP dê-cī. Iŏk-sṳ̄ nṳ̄ gó muôi kŭi 1 ciáh dióng-hô̤ bêng-chiā giéng-gáe̤k ciā làu-uâ sê làu ké̤ṳk nṳ̄ gì, chiāng nṳ̄ [[Special:UserLogin|kŭi 1 ciáh dióng-hô̤ hĕ̤k-ciā láuk-diē]], cêu â̤ piáh-miēng ī-hâiu gái huák-sĕng cūng-kuāng ông-dà̤.''",
 'noarticletext'            => 'Ciā hiĕk-miêng gà̤-dēng mò̤ ùng-cê. Nṳ̄ â̤-sāi găk gì-tă hiĕk-miêng [[Special:Search̤/{{PAGENAME}}|sìng-tō̤ ĭ gì biĕu-dà̤]] hĕ̤k-ciā [{{fullurl:{{FULLPAGENAME}}|action=edit}} cê-gă siā].',
 'clearyourcache'           => "'''Cé̤ṳ-é:''' Bō̤-còng cĭ hâiu, kō̤-nèng diŏh tĕ̤ng táh báuk-lāng-ké gì ká̤-chṳ̄ ciáh â̤ káng-giéng diŏh gāi-biéng. '''Mozilla / Firefox / Safari:''' áik ''Reload'' sèng-âu áik diâng ''Shift'', hĕ̤k-ciā áik ''Ctrl-Shift-R'' (Apple Mac sê ''Cmd-Shift-R''); '''IE:''' áik ''Refresh'' sèng-âu áik diâng ''Ctrl'', hĕ̤k-ciā áik ''Ctrl-F5''; '''Konqueror:''' nâ sāi áik ''Reload'', hĕ̤k-ciā áik ''F5''; '''Opera''' ê̤ṳng-hô buóh tĕ̤ng táh ká̤-chṳ̄, chiāng sāi gă-sĭ ''Tools→Preferences''.",
 'previewnote'              => '<strong>Cé̤ṳ-é: Cuòi nâ sê ché káng ùng-cê gì iông-sék; nṳ̄ sū có̤ gì siŭ-gāi gó muôi bō̤-còng!</strong>',
@@ -442,7 +441,7 @@
 'reupload'          => 'Dṳ̀ng-sĭng siông-diòng',
 'reuploaddesc'      => 'Duōng kó̤ siông-duòng dăng-dăng.',
 'uploadnologin'     => 'Mò̤ láuk-diē',
-'uploadnologintext' => 'Sĕng [[Special:Userlogin|láuk-diē]] ciáh â̤-sāi siông-duòng ùng-giông.',
+'uploadnologintext' => 'Sĕng [[Special:UserLogin|láuk-diē]] ciáh â̤-sāi siông-duòng ùng-giông.',
 'uploaderror'       => 'Siông-duòng ô dâng',
 'uploadlog'         => 'siông-duòng nĭk-cé',
 'uploadlogpage'     => 'Siông-duòng nĭk-cé',
@@ -464,7 +463,7 @@
 'destfilename'      => 'Mŭk-biĕu ùng-giông-miàng:',
 'watchthisupload'   => 'Gáng-sê ciā hiĕk',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'ùng-giông',
 'imagelist'      => 'Ùng-giông dăng-dăng',
 'imagelist_date' => 'Nĭk-gĭ',
@@ -550,7 +549,7 @@
 'alllogstext'          => "Siông-diòng (''upload''), chēng (''deletion''), bō̤-hô (''protection''), hŭng-sō̤ (''blocking''), gâe̤ng guāng-lī-uòng (''sysop'') nĭk-cé ciòng-buô hiēng-sê diŏh â-dā̤. Nṳ̄ â̤-sāi gēng-sōng nĭk-cé lôi-biék, ê̤ṳng-hô gì miàng, hĕ̤k-ciā 1 tiŏng hiĕk lì gāng-huá giék-guō.",
 'logempty'             => 'Nĭk-cé diē-sié tō̤ mâ̤ diŏh hâung-mŭk.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Sū-iū hiĕk-miêng',
 'alphaindexline'    => '$1 gáu $2',
 'nextpage'          => 'Â 1 hiĕk ($1)',
@@ -588,7 +587,7 @@
 'nowatchlist'          => 'Nṳ̄ gì gáng-sê-dăng gà̤-dēng mò̤ dèu-mĕ̤k.',
 'watchnologin'         => 'Mò̤ láuk diē',
 'addedwatch'           => 'Gă-tiĕng gáu gáng-sê-dăng',
-'addedwatchtext'       => "\"[[:\$1]]\" ī-gĭng gă-tiĕng gáu nṳ̄ gì [[Special:Watchlist|gáng-sê-dăng]] lāu. Â-nĭk, ciā hiĕk gâe̤ng ĭ tō̤-lâung hiĕk gì gāi-biéng cêu â̤ hiēng-sê diŏh hē̤-nē̤; bêng-chiā, nṳ̄ gáng-sê gì hiĕk găk \"[[Special:Recentchanges|Có̤i-gê̤ṳng gì gāi-biéng]]\" dăng-dăng gà̤-dēng gì cê-tā̤ â̤ có̤ '''chŭ-chŭ-nuóh'''.
+'addedwatchtext'       => "\"[[:\$1]]\" ī-gĭng gă-tiĕng gáu nṳ̄ gì [[Special:Watchlist|gáng-sê-dăng]] lāu. Â-nĭk, ciā hiĕk gâe̤ng ĭ tō̤-lâung hiĕk gì gāi-biéng cêu â̤ hiēng-sê diŏh hē̤-nē̤; bêng-chiā, nṳ̄ gáng-sê gì hiĕk găk \"[[Special:RecentChanges|Có̤i-gê̤ṳng gì gāi-biéng]]\" dăng-dăng gà̤-dēng gì cê-tā̤ â̤ có̤ '''chŭ-chŭ-nuóh'''.
 
 Iŏk-sṳ̄ nṳ̄ buóh-siōng téng nṳ̄ gáng-sê-dăng gà̤-dēng dṳ̀ lâi ciā hiĕk, áik kóng-cié-dèu (''sidebar'') siông gì \"ng-sāi gáng-sê\", cêu â̤-sāi lāu.",
 'removedwatch'         => 'Téng gáng-sê-dăng dṳ̀ lâi lāu',
@@ -723,7 +722,7 @@
 'ipbotherreason'           => 'Gì-tă nguòng-ĭng:',
 'blockipsuccesssub'        => 'Hŭng-sō̤ sìng-gŭng',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|$1]] ké̤ṳk hŭng-sō̤ lāu.
-<br />Kó̤ [[Special:Ipblocklist|IP hŭng-sō̤ dăng-dăng]] káng hŭng-sō̤ séng-sék.',
+<br />Kó̤ [[Special:IPBlockList|IP hŭng-sō̤ dăng-dăng]] káng hŭng-sō̤ séng-sék.',
 'ipb-edit-dropdown'        => 'Siŭ-gāi hŭng-sō̤ nguòng-ĭng',
 'ipb-unblock-addr'         => 'Gāi-hŭng $1',
 'ipb-unblock'              => 'Gāi-hŭng siŏh ciáh ê̤ṳng-hô hĕ̤k IP dê-cī',
@@ -770,8 +769,6 @@
 
 Nâ cūng-kuāng, nṳ̄ â̤-sāi cê-gă iè-dông hĕ̤k-ciā sê hăk-biáng hiĕk-miêng.",
 'movearticle'             => 'Iè-dông ùng-ciŏng',
-'movenologin'             => 'Muôi láuk-diē',
-'movenologintext'         => 'Sĕng [[Special:Userlogin|láuk-diē]] ciáh â̤-sāi iè-dông hiĕk-miêng.',
 'newtitle'                => 'Gáu sĭng dà̤-mĕ̤k',
 'move-watch'              => 'Gáng-sê ciā hiĕk',
 'movepagebtn'             => 'Iè-dông hiĕk-miêng',
@@ -816,7 +813,7 @@
 # Media information
 'file-nohires' => '<small>Cuòi sê có̤i duâi chióh-cháung.</small>',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 gĭ-ké-nè̤ng)',
 'ilsubmit'     => 'Sìng-tō̤',
 'bydate'       => 'áng nĭk-gĭ',
@@ -834,7 +831,7 @@
 
 # External editor support
 'edit-externally'      => 'Sāi nguôi-buô tiàng-sê̤ṳ piĕng-cék ciā ùng-giông',
-'edit-externally-help' => 'Chăng-kō̤ [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] liēu-gāi gáing sâ̤ séng-sék.',
+'edit-externally-help' => 'Chăng-kō̤ [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] liēu-gāi gáing sâ̤ séng-sék.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'sū-iū',
@@ -862,7 +859,7 @@
 'recreate'            => 'Dṳ̀ng-sĭng kŭi',
 
 # HTML dump
-'redirectingto' => 'Dṳ̀ng-sĭng dêng-hióng gáu [[$1]]...',
+'redirectingto' => 'Dṳ̀ng-sĭng dêng-hióng gáu [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Hō̤',
@@ -907,7 +904,7 @@
 'watchlisttools-edit' => 'Káng gâe̤ng siŭ-gāi gáng-sê-dăng',
 'watchlisttools-raw'  => 'Siŭ-gāi nguòng-sṳ̄ gáng-sê-dăng',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Ùng-giông:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesAv.php
===================================================================
--- languages/messages/MessagesAv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -94,7 +94,7 @@
 # Special:Log
 'specialloguserlabel' => 'ГIахьалчи:',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'Киналго макъалаби',
 
 # Watchlist
Index: languages/messages/MessagesRmy.php
===================================================================
--- languages/messages/MessagesRmy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRmy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author לערי ריינהארט
  * @author Desiphral
- * @author Siebrand
- * @author Jon Harald Søby
  * @author Niklas Laxström
+ * @author לערי ריינהארט
  */
 
 $fallback = 'ro';
@@ -159,7 +157,7 @@
 'nstab-category'  => 'Shopni',
 
 # Main script and global functions
-'nospecialpagetext' => 'Manglyas ekh [[Special:Specialpages|uzalutni patrin]] so na arakhel pes kai {{SITENAME}}.',
+'nospecialpagetext' => 'Manglyas ekh [[Special:SpecialPages|uzalutni patrin]] so na arakhel pes kai {{SITENAME}}.',
 
 # General errors
 'wrong_wfQuery_params' => 'Doshalo gin le parametrengo ko wfQuery()<br />I function: $1<br />Query: $2',
@@ -229,10 +227,7 @@
 'showlivepreview'    => 'Jivutno angledikhipen',
 'showdiff'           => 'Dikh le paruvimata',
 'whitelistedittitle' => 'Trebul o autentifikaripen kashte editisares',
-'whitelistedittext'  => 'Trebul te [[Special:Userlogin|autentifikisares]] kashte editisares artikolurya.',
-'whitelistreadtitle' => 'Trebul o autentifikaripen kashte drabares',
-'whitelistreadtext'  => 'Trebul te [[Special:Userlogin|autentifikisares]] kashte drabares artikolurya.',
-'whitelistacctitle'  => 'Chi shai (nai tuke xakaya) te keres konturya',
+'whitelistedittext'  => 'Trebul te [[Special:UserLogin|autentifikisares]] kashte editisares artikolurya.',
 'accmailtitle'       => 'O nakhavipnasko lav bićhaldo.',
 'accmailtext'        => "O nakhavipnasko lav andar '$1' bićhaldo ko $2.",
 'newarticle'         => '(Nevo)',
@@ -351,7 +346,7 @@
 'badfilename' => 'O chitrosko anav sas paruvdo; o nevo anav si "$1".',
 'savefile'    => 'Uxtav file',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Patrinipen le chitrengo',
 
 # Image description page
@@ -379,7 +374,7 @@
 'ancientpages' => 'E puraneder lekha',
 'move'         => 'Ingerdipen',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Savore patrya',
 'nextpage'       => 'Anglutni patrin ($1)',
 'allarticles'    => 'Sa le artikolurya',
@@ -396,7 +391,7 @@
 'mywatchlist'      => 'Dikhipnaske lekha',
 'addedwatch'       => 'Thovdi ando patrinipen le patrinyange so arakhav len',
 'addedwatchtext'   => 'I patrin "[[:$1]]" sas thovdi andi tiri lista [[Special:Watchlist|le artikolengi so dikhes len]].
-Le neve paruvimata andar kadale patrya thai andar lenge vakyarimatenge patrya thona kathe, vi dikhena pen le <b>thule semnurenca</b> andi patrin le [[Special:Recentchanges|neve paruvimatenge]].
+Le neve paruvimata andar kadale patrya thai andar lenge vakyarimatenge patrya thona kathe, vi dikhena pen le <b>thule semnurenca</b> andi patrin le [[Special:RecentChanges|neve paruvimatenge]].
 
 Kana kamesa te khoses kadaya patrin andar tiri lista le patryange so arakhes len ker click kai "Na mai arakh" (opre, kana i patrin dikhel pes).',
 'removedwatchtext' => 'I patrin "[[:$1]]" sas khosli katar o patrinipen le dikhipnaske lekhenca (artikolurya).',
@@ -533,7 +528,7 @@
 'previousdiff' => '← Purano ververipen',
 'nextdiff'     => 'Anglutno paruvipen →',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 boturya)',
 'ilsubmit'     => 'Rod',
 
Index: languages/messages/MessagesMk.php
===================================================================
--- languages/messages/MessagesMk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,12 +5,10 @@
  * @file
  *
  * @author FlavrSavr
- * @author Misos
- * @author INkubusse
- * @author Siebrand
  * @author Glupav
+ * @author INkubusse
+ * @author Misos
  * @author לערי ריינהארט
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -354,7 +352,7 @@
 'nosuchaction'      => 'Не постои таква функција',
 'nosuchactiontext'  => 'Функцијата од УРЛ-то не е подржана од Вики',
 'nosuchspecialpage' => 'Не постои таква специјална страница',
-'nospecialpagetext' => 'Баравте невалидна [[Special:Specialpages|специјална страница]].',
+'nospecialpagetext' => 'Баравте невалидна [[Special:SpecialPages|специјална страница]].',
 
 # General errors
 'error'                => 'Грешка',
@@ -470,7 +468,11 @@
 'passwordtooshort'           => 'Вашата лозинка е прекратка. Мора да има најмалку $1 знаци.',
 'mailmypassword'             => 'Испрати ми нова лозинка по е-пошта',
 'passwordremindertitle'      => 'Потсетник за лозинка од {{SITENAME}}',
-'passwordremindertext'       => 'Некој (најверојатно вие, од IP адреса $1) побара да ви испратиме нова {{SITENAME}} лозинка. Лозинката за корисникот "$2" сега е "$4". Треба да се најавите и да ја промените лозинката сега. Сега можете да се логирате со оваа привремена позинка, која е валидна само за едно логирање. Можете да продолжите да ја користите старата лозинка ако ја памтите или да поставите нова. {{fullurl:Special:Userlogin|wpName=$3&wpPassword=$4&returnto=Special:Preferences}}',
+'passwordremindertext'       => 'Некој (најверојатно вие, од IP адреса $1) побара да ви испратиме нова {{SITENAME}} лозинка.
+Лозинката за корисникот "$2" сега е "$4".
+Треба да се најавите и да ја промените лозинката сега.
+Сега можете да се логирате со оваа привремена позинка, која е валидна само за едно логирање.
+Можете да продолжите да ја користите старата лозинка ако ја памтите или да поставите нова.',
 'noemail'                    => 'Не е внесена е-поштенската адреса за корисникот "$1".',
 'passwordsent'               => 'Нова лозинка е испратена на корисникот "$1". Најавете се повторно откако ќе ја примите пораката.',
 'blocked-mailpassword'       => 'Вашата IP адреса е блокирана за уредување, а за да се спречи злоупотреба, можноста за барање нова лозинка е исто така оневозможена.',
@@ -574,10 +576,6 @@
 'blockededitsource'                => "Текстот на '''вашите уредувања''' на '''$1''' е прикажан подолу:",
 'whitelistedittitle'               => 'Мора да сте најавени за менување на статии',
 'whitelistedittext'                => 'Мора да сте $1 за да уредувате страници.',
-'whitelistreadtitle'               => 'Мора да сте најавени за да читате статии',
-'whitelistreadtext'                => 'Мора да сте [[Special:Userlogin|најавени]] за да читате статии.',
-'whitelistacctitle'                => 'Немате дозвола да додавате корисници',
-'whitelistacctext'                 => 'За да можете да додавате корисници во ова Вики мора да се [[Special:Userlogin|најавите]] и да имате соодветна дозвола.',
 'confirmedittitle'                 => 'Потребна е потврда за е-поштенската адреса за уредување',
 'confirmedittext'                  => 'Морате да ја потврдите вашата е-поштенска адреса пред да уредувате страници. Поставете ја и валидирајте ја вашата е-поштенска адреса преку вашите [[Special:Preferences|прилагодувања]].',
 'nosuchsectiontitle'               => 'Нема такваа секција',
@@ -589,7 +587,7 @@
 'accmailtext'                      => "Лозинката за '$1' е испратена на $2.",
 'newarticle'                       => '(нова)',
 'newarticletext'                   => "Следевте врска која води до страница која сеуште не постои. За да ја креирате страницата, почнете со типкање во долното прозорче (видете ја страницата за [[{{MediaWiki:Helppage}}|помош]] за повеќе информации). Ако сте овде по грешка, само притиснете го копчето '''назад''' во вашиот прелистувач.",
-'anontalkpagetext'                 => "---- ''Ова е страница за разговор за анонимен корисник кој сеуште не е регистриран или не ја користи. Затоа мораме да ја користиме неговата нумеричка [[IP адреса]] за идентификација. Една IP адреса може да биде делена од повеќе корисници. Ако сте анонимен корисник и сметате дека кон вас се упатени ирелевантни коментари, ве молиме [[Special:Userlogin|Регистрирајте или најавете се]] за да избегнете забуна со други корисници.''",
+'anontalkpagetext'                 => "---- ''Ова е страница за разговор за анонимен корисник кој сеуште не е регистриран или не ја користи. Затоа мораме да ја користиме неговата нумеричка [[IP адреса]] за идентификација. Една IP адреса може да биде делена од повеќе корисници. Ако сте анонимен корисник и сметате дека кон вас се упатени ирелевантни коментари, ве молиме [[Special:UserLogin|Регистрирајте или најавете се]] за да избегнете забуна со други корисници.''",
 'noarticletext'                    => 'Моментално нема текст на оваа страница, можете да го [[Special:Search/{{PAGENAME}}|побарате овој наслов]] во други страници или да ја [{{fullurl:{{FULLPAGENAME}}|action=edit}} уредите оваа страница].',
 'userpage-userdoesnotexist'        => 'Не е регистриран корисник со име „$1“. Ве молиме размислете дали навистина сакате да ја создадете/уредите оваа страница.',
 'clearyourcache'                   => "'''Забелешка:''' По зачувување морате да го исчистите кешот на вашиот прелистувач за да ги видите промените: '''Mozilla / Firefox:''' ''Ctrl-Shift-R'', '''IE:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-Shift-R'', '''Konqueror''' ''F5''.",
@@ -651,7 +649,7 @@
 'edittools'                        => '<!-- Овој текст ќе се прикаже под формите за уредување и подигнување датотеки. -->',
 'nocreatetitle'                    => 'Креирањето на нови страници е ограничено',
 'nocreatetext'                     => 'На оваа страница е ограничена можноста за креирање нови страници.
-Можете да се вратите назад и да уредите постоечка страница, или [[Special:Userlogin|најавете се или креирајте нова сметка]].',
+Можете да се вратите назад и да уредите постоечка страница, или [[Special:UserLogin|најавете се или креирајте нова сметка]].',
 'nocreate-loggedin'                => 'Немате дозвола да создавате нови страници на {{SITENAME}}.',
 'permissionserrors'                => 'Грешки во правата',
 'permissionserrorstext'            => 'Немате дозвола да го направите тоа, заради {{PLURAL:$1|следнава причина|следниве причини}}:',
@@ -774,7 +772,7 @@
 'preferences'              => 'Прилагодувања',
 'mypreferences'            => 'мои прилагодувања',
 'prefsnologin'             => 'Не сте најавени',
-'prefsnologintext'         => 'Мора да бидете [[Special:Userlogin|најавени]] за промена на прилагодувањата.',
+'prefsnologintext'         => 'Мора да бидете [[Special:UserLogin|најавени]] за промена на прилагодувањата.',
 'prefsreset'               => 'Воспоставени се стандардните прилагодувања.',
 'qbsettings'               => 'Лента за брз избор',
 'qbsettings-none'          => 'Без мени',
@@ -893,10 +891,10 @@
 'reupload'                    => 'Повторно подигни',
 'reuploaddesc'                => 'Врати се во формуларот за подигнување.',
 'uploadnologin'               => 'Не сте најавени',
-'uploadnologintext'           => 'Морате да бидете [[Special:Userlogin|најавени]] за да подигнувате датотеки.',
+'uploadnologintext'           => 'Морате да бидете [[Special:UserLogin|најавени]] за да подигнувате датотеки.',
 'upload_directory_read_only'  => 'Веб серверот не може да запишува во папката за подигнување ($1).',
 'uploaderror'                 => 'Грешка во подигнувањето',
-'uploadtext'                  => "Користете го долниот формулар за да преместите нови датотеки, а за да гледате или пребарувате претходно преместени слики одете на [[Special:Imagelist|листата на преместени датотеки]], преместувањата и бришењата се истотака запишани во [[Special:Log|дневникот на проектот]].
+'uploadtext'                  => "Користете го долниот формулар за да преместите нови датотеки, а за да гледате или пребарувате претходно преместени слики одете на [[Special:ImageList|листата на преместени датотеки]], преместувањата и бришењата се истотака запишани во [[Special:Log|дневникот на проектот]].
 
 За да внесете слика во страница, користете врска во обликот
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>'''
@@ -958,7 +956,7 @@
 'upload_source_url'  => ' (валидна, јавно достапна адреса (URL))',
 'upload_source_file' => ' (датотека на вашиот компјутер)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Побарај име на медија:',
 'imgfile'               => 'датотека',
 'imagelist'             => 'Листа на слики',
@@ -995,11 +993,11 @@
 # File reversion
 'filerevert'                => 'Врати $1',
 'filerevert-legend'         => 'Врати датотека',
-'filerevert-intro'          => '<span class="plainlinks">Ја враќата \'\'\'[[Media:$1|$1]]\'\'\' на [$4 верзија од $3, $2].</span>',
+'filerevert-intro'          => "Ја враќата '''[[Media:$1|$1]]''' на [$4 верзија од $3, $2].",
 'filerevert-comment'        => 'Коментар:',
 'filerevert-defaultcomment' => 'Вратена на верзија од $2, $1',
 'filerevert-submit'         => 'Врати',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' е вратен на [$4 верзија од $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' е вратен на [$4 верзија од $3, $2].",
 'filerevert-badversion'     => 'Нема претходна локална верзија на оваа датотека со даденото време.',
 
 # MIME search
@@ -1040,7 +1038,7 @@
 Со тоа, во просек има '''$5''' уредувања по страница и '''$6''' прегледи по уредување.
 
 Должината на [http://www.mediawiki.org/wiki/Manual:Job_queue редицата за работи] изнесува '''$7'''.",
-'userstatstext'          => "Има вкупно {{PLURAL:$1|'''1''' регистриран [[Special:Listusers|корисник]]|'''$1''' регистрирани [[Special:Listusers|корисници]]}}, од кои '''$2''' (или '''$4%''') {{PLURAL:$2|има|имаат}} кориснички права на „$5“.",
+'userstatstext'          => "Има вкупно {{PLURAL:$1|'''1''' регистриран [[Special:ListUsers|корисник]]|'''$1''' регистрирани [[Special:ListUsers|корисници]]}}, од кои '''$2''' (или '''$4%''') {{PLURAL:$2|има|имаат}} кориснички права на „$5“.",
 'statistics-mostpopular' => 'Најгледани страници',
 
 'disambiguations'      => 'Страници за појаснување',
@@ -1121,7 +1119,7 @@
 'logempty'             => 'Нема одговарачки записи во дневникот.',
 'log-title-wildcard'   => 'Пребарај наслови кои почнуваат со овој текст',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Сите страници',
 'alphaindexline'    => '$1 во $2',
 'nextpage'          => 'Следна страница ($1)',
@@ -1141,14 +1139,14 @@
 'categories'         => 'Категории',
 'categoriespagetext' => 'Следниве категории содржат страници или медија.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Прикажни корисници почнувајќи од:',
 'listusers-submit'   => 'Прикажи',
 'listusers-noresult' => 'Не е пронајден корисник.',
 
 # E-mail user
 'mailnologin'     => 'Нема адреса за праќање',
-'mailnologintext' => 'Мора да бидете [[Special:Userlogin|најавени]] и да имате валидна е-поштенска адреса во вашите [[Special:Preferences|прилагодувања]] за да испратите е-пошта до други корисници.',
+'mailnologintext' => 'Мора да бидете [[Special:UserLogin|најавени]] и да имате валидна е-поштенска адреса во вашите [[Special:Preferences|прилагодувања]] за да испратите е-пошта до други корисници.',
 'emailuser'       => 'Е-пошта до овој корисник',
 'emailpage'       => 'Е-пошта до корисникот',
 'emailpagetext'   => 'Ако овој корисник внесол валидна е-адреса во неговите или нејзините прилагодувања, долниот формулар ќе прати една порака. Е-поштенската адреса што ја внесовте во вашите прилагодувања ќе се прикаже во "Од" полето на пораката, со што примачот ќе може да ви одговори.',
@@ -1173,9 +1171,9 @@
 'nowatchlist'          => 'Немате елементи во вашите набљудувани страници.',
 'watchlistanontext'    => 'Ве молиме $1 за да гледате или менувате елементи во вашата листа на набљудувани страници.',
 'watchnologin'         => 'Не сте најавени',
-'watchnologintext'     => 'Мора да бидете [[Special:Userlogin|најавени]] за да се модифицира вашата листа на набљудувани страници.',
+'watchnologintext'     => 'Мора да бидете [[Special:UserLogin|најавени]] за да се модифицира вашата листа на набљудувани страници.',
 'addedwatch'           => 'Додадено во набљудувани страници',
-'addedwatchtext'       => "Страницата \"<nowiki>\$1</nowiki>\" е додадена во вашите [[Special:Watchlist|набљудувани страници]]. Идните промени на оваа страница и поврзаните со неа Страници за разговор ќе бидат прикажани овде и страницата ќе се прикаже '''задебелена''' во [[Special:Recentchanges|листата на скорешни промени]] за да можете полесно да ја изберете. <p>Ако подоцна сакате да ја отстраните страницата од набљудувани страници, притиснете на \"Престани набљудување\" .",
+'addedwatchtext'       => "Страницата \"<nowiki>\$1</nowiki>\" е додадена во вашите [[Special:Watchlist|набљудувани страници]]. Идните промени на оваа страница и поврзаните со неа Страници за разговор ќе бидат прикажани овде и страницата ќе се прикаже '''задебелена''' во [[Special:RecentChanges|листата на скорешни промени]] за да можете полесно да ја изберете. <p>Ако подоцна сакате да ја отстраните страницата од набљудувани страници, притиснете на \"Престани набљудување\" .",
 'removedwatch'         => 'Отстрани ја страницата од набљудуваните страници',
 'removedwatchtext'     => 'Страницата "<nowiki>$1</nowiki>" е отстранета од набљудуваните страници.',
 'watch'                => 'Набљудувај',
@@ -1378,7 +1376,7 @@
 'badipaddress'                => 'Невалидна IP адреса',
 'blockipsuccesssub'           => 'Успешно блокирање',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] е блокиран.<br />
-Видете ја [[Special:Ipblocklist|листата на блокирани IP адреси]] за преглед на блокирањата.',
+Видете ја [[Special:IPBlockList|листата на блокирани IP адреси]] за преглед на блокирањата.',
 'ipb-edit-dropdown'           => 'Наведи причина за блокирање',
 'ipb-unblock-addr'            => 'Одблокирај го $1',
 'ipb-unblock'                 => 'Одблокирај корисник или  IP адреса',
@@ -1407,7 +1405,7 @@
 'blocklogpage'                => 'Дневник на блокирања',
 'blocklogtext'                => 'Ова е дневник на блокирањата и деблокирањата, извршени од овој корисник.
 Автоматски блокираните IP адреси не се наведени.
-Видете ја [[Special:Ipblocklist|листата на блокирани IP адреси]] за листа на тековни забрани и блокирања.',
+Видете ја [[Special:IPBlockList|листата на блокирани IP адреси]] за листа на тековни забрани и блокирања.',
 'unblocklogentry'             => 'деблокиран "$1"',
 'block-log-flags-anononly'    => 'само анонимни корисници',
 'block-log-flags-nocreate'    => 'оневозможено креирање на кориснички сметки',
@@ -1459,8 +1457,6 @@
 *Непразна страница за разговор веќе постои за новиот наслов, или
 *Не сте го одштиклирале долното поле. Во тие случаи, вие ќе треба да ја преместите или споите страницата рачно, доколку сакате.',
 'movearticle'             => 'Премести ја страницата',
-'movenologin'             => 'Не сте најавени',
-'movenologintext'         => 'Мора да бидете регистриран корисник и [[Special:Userlogin|најавен]] да преместите страница.',
 'movenotallowed'          => 'You do not have permission to move pages on Википедија.',
 'newtitle'                => 'Кон новиот наслов',
 'move-watch'              => 'Набљудувај ја оваа страница',
@@ -1477,7 +1473,7 @@
 'movereason'              => 'Причина',
 'revertmove'              => 'врати',
 'delete_and_move'         => 'Избриши и премести',
-'delete_and_move_text'    => '==Потребно бришење== Целната статија "[[$1]]" веќе постои. Дали сакате да ја избришете за да ослободите место за преместувањето?',
+'delete_and_move_text'    => '==Потребно бришење== Целната статија "[[:$1]]" веќе постои. Дали сакате да ја избришете за да ослободите место за преместувањето?',
 'delete_and_move_confirm' => 'Да, избриши ја страницата',
 'delete_and_move_reason'  => 'Избришано за да се ослободи место за преместувањето',
 'selfmove'                => 'Страницата не може да биде преместена бидејќи целниот наслов се совпаѓа со првобитниот наслов.',
@@ -1675,7 +1671,7 @@
 'show-big-image'       => 'Вистинска големина',
 'show-big-image-thumb' => '<small>Големина на овој приказ: $1 × $2 пиксели</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Галерија на нови слики',
 'imagelisttext'         => 'Подолу е листа на $1 подредени слики $2.',
 'showhidebots'          => '($1 ботови)',
@@ -1942,7 +1938,7 @@
 
 # External editor support
 'edit-externally'      => 'Уредете ја оваа датотека со надворешна апликација',
-'edit-externally-help' => 'Видете [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] за повеќе информации.',
+'edit-externally-help' => 'Видете [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] за повеќе информации.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'сите',
@@ -2012,7 +2008,7 @@
 'unit-pixel' => 'п',
 
 # HTML dump
-'redirectingto' => 'Пренасочувам на [[$1]]...',
+'redirectingto' => 'Пренасочувам на [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Да се исчисти кешот на оваа страница?
@@ -2064,7 +2060,7 @@
 # Special:Version
 'version' => 'Верзија', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'Патека до датотека',
 
 # Special:SpecialPages
Index: languages/messages/MessagesSdc.php
===================================================================
--- languages/messages/MessagesSdc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSdc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Felis
  * @author Antofa
  * @author Cornelia
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
+ * @author Felis
  */
 
 $messages = array(
@@ -282,7 +279,7 @@
 'nosuchaction'      => 'Operazioni no ricuniscidda',
 'nosuchactiontext'  => "L'indirizzu immessu no curripondi a unu cumandu ricunisciddu da lu software MediaWiki",
 'nosuchspecialpage' => 'Pàgina ippiziari no dipunìbiri',
-'nospecialpagetext' => "La pàgina ippiziari dumandadda no è isthadda ricuniscidda da lu software MediaWiki; l'erencu di li pàgini ippiziari vàriddi s'acciappa i'li [[Special:Specialpages|{{int:specialpages}}]].",
+'nospecialpagetext' => "La pàgina ippiziari dumandadda no è isthadda ricuniscidda da lu software MediaWiki; l'erencu di li pàgini ippiziari vàriddi s'acciappa i'li [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Errori',
@@ -521,10 +518,6 @@
 'blockededitsource'         => "Inogghi so musthraddi li '''mudìfigghi arriggaddi''' a la pàgina '''$1''':",
 'whitelistedittitle'        => 'È nezzessàriu intrà pa mudìfiggà li pàgini',
 'whitelistedittext'         => 'Pa mudìfiggà li pàgini è nezzessàriu $1.',
-'whitelistreadtitle'        => 'È nezzessàriu intrà pa liggì li pàgini',
-'whitelistreadtext'         => 'Pa liggì li pàgini è nezzessàriu [[Special:Userlogin|intrà]].',
-'whitelistacctitle'         => "Criazioni d'una noba intradda nò cunsintidda",
-'whitelistacctext'          => "Pa assé abiritaddi a la criazioni di nobi registhrazioni in {{SITENAME}} è nezzessàriu [[Special:Userlogin|intrà]] e abenni l'autorizzazioni.",
 'confirmedittitle'          => "È nezzessàriu cunfèimmà l'indirizzu di postha erettrònica pà mudìfiggà li pàgini",
 'confirmedittext'           => "Pa assé abiritaddi a la mudìfigga di li pàgini è nezzessàriu cunfèimma lu proprio indirizzu di postha erettrònica. Pa impusthà e cunfèimmà l'indirizzu usà li [[Special:Preferences|prifirenzi]].",
 'nosuchsectiontitle'        => 'La sezzioni nò esisthi',
@@ -540,7 +533,7 @@
 Si vói crià la pàgina abà, pói sùbidu ischribì in giossu (abbaidda li [[{{MediaWiki:Helppage}}|pàgini d'aggiuddu]] pà maggiori infuimmazioni).
 
 S'ài sighiddu lu cullegamentu pa un'errori, è suffizenti incalchà lu buttoni '''Indareddu''' i' lu propriu nabiggadori.",
-'anontalkpagetext'          => "----''Chistha è la pàgina di dischussioni di un'utenti anònimu, chi no ha ancora criaddu una registhrazioni o, in dugna modu, no la usa. Pa identifiggallu è dunca nezzessàriu usà lu sóiu nùmaru di l'indirizzu IP. L'indirizzi IP, parò, poni assé cundibisi da più utenti. Si sei un'utenti anònimu e vói chi li cummenti prisenti in chistha pàgina no si rifèrini a te, [[Special:Userlogin|crea una noba registhrazion o intra]] cu' chidda ch'hai già pa evità d'assé confusu cu' althri utenti anònimi in futuru.''",
+'anontalkpagetext'          => "----''Chistha è la pàgina di dischussioni di un'utenti anònimu, chi no ha ancora criaddu una registhrazioni o, in dugna modu, no la usa. Pa identifiggallu è dunca nezzessàriu usà lu sóiu nùmaru di l'indirizzu IP. L'indirizzi IP, parò, poni assé cundibisi da più utenti. Si sei un'utenti anònimu e vói chi li cummenti prisenti in chistha pàgina no si rifèrini a te, [[Special:UserLogin|crea una noba registhrazion o intra]] cu' chidda ch'hai già pa evità d'assé confusu cu' althri utenti anònimi in futuru.''",
 'noarticletext'             => "Abà la pàgina è biodda. È pussìbiri [[Special:Search/{{PAGENAME}}|zirchà chistu innòmu]] i' l'althri pàgini di lu situ oppuru [{{SERVER}}{{localurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} mudifiggà la pàgina].",
 'userpage-userdoesnotexist' => 'La registhrazioni "$1" nò curripundi a un\'utenti rigisthraddu. Verifiggà chi s\'aggia avveru gana di crià o mudìfiggà chistha pàgina.',
 'clearyourcache'            => "'''Nota:''' daboi abé saivaddu è nezzessàriu pulì la mimória cache di lu propriu nabiggadori pà vidé li ciambamenti. Pa '''Mozilla / Firefox / Safari''': fà clic i Ricàrrigga incalchendi lu buttoni di li maiuschuri, oppuru incalchà ''Ctrl-Maiusc-R'' (''Cmd-Maiusc-R'' i Mac); pa '''Internet Explorer:''' mantinì incalchaddu lu tasthu ''Ctrl'' mentri s'incalcha lu buttoni ''Aggiorna'' o incalchà ''Ctrl-F5''; pa '''Konqueror''': incalchà lu buttoni ''Ricarica'' o lu tasthu ''F5''; pa '''Opera''' pò assé nezzessàriu ibbuiddà cumpretamenti la mimória cache da lu menù ''Strumenti → Preferenze''.",
@@ -595,7 +588,7 @@
 'template-semiprotected'    => '(mezu-prutiggiddu)',
 'edittools'                 => '<!-- Testhu chi appari in giossu lu mòdulu di mudìfiga e di carriggamentu. -->',
 'nocreatetitle'             => 'Criazioni di li pàgini limitadda',
-'nocreatetext'              => '{{SITENAME}} à limitaddu la pussibiliddai di crià nobi pagini a li sori utenti registhraddi. È pussìbiri turrà indareddu e mudìfiggà una pàgina esisthenti, oppuru [[Special:Userlogin|intrà o crià una noba registhrazioni]].',
+'nocreatetext'              => '{{SITENAME}} à limitaddu la pussibiliddai di crià nobi pagini a li sori utenti registhraddi. È pussìbiri turrà indareddu e mudìfiggà una pàgina esisthenti, oppuru [[Special:UserLogin|intrà o crià una noba registhrazioni]].',
 'nocreate-loggedin'         => 'No si diponi di li pimmissi nezzessàri pa crià nobi pàgini in {{SITENAME}}.',
 'permissionserrors'         => 'Errori i li pimmissi',
 'permissionserrorstext'     => "Nò si diponi di li pimmissi nezzessàri a eseguì l'azioni dumandadda, pa {{PLURAL:$1|lu sighenti mutibu|li sighenti mutibi}}:",
@@ -744,7 +737,7 @@
 'mypreferences'            => "Li me' prifirenzi",
 'prefs-edits'              => 'Mudìfigghi effettuaddi:',
 'prefsnologin'             => 'Intradda nò effettuadda',
-'prefsnologintext'         => 'Pa mudìfiggà li prifirenzi è nezzessàriu [[Special:Userlogin|intrà]].',
+'prefsnologintext'         => 'Pa mudìfiggà li prifirenzi è nezzessàriu [[Special:UserLogin|intrà]].',
 'prefsreset'               => 'Li prifirenzi so turraddi cumenti a lu prinzìpiu.',
 'qbsettings'               => 'Prifirenzi di lu menù',
 'qbsettings-none'          => 'Nisciunu',
@@ -812,7 +805,7 @@
 'userrights-reason'        => 'Mutibu di la mudìffiga:',
 'userrights-no-interwiki'  => "Nò ài lu primmissu pa mudìfiggà li diritti di l'utenti i' althri siti.",
 'userrights-nodatabase'    => 'La bancadati $1 nò isisthi o nò è in lucari.',
-'userrights-nologin'       => 'Débi [[Special:Userlogin|intrà]] cumenti amministhradori pa assignà li diritti utenti.',
+'userrights-nologin'       => 'Débi [[Special:UserLogin|intrà]] cumenti amministhradori pa assignà li diritti utenti.',
 'userrights-notallowed'    => "La registhrazioni tóia nò à lu primissu d'assignà li diritti utenti.",
 
 # Groups
@@ -883,11 +876,11 @@
 'reupload'                    => 'Carrigga di nobu',
 'reuploaddesc'                => 'Canzella lu carriggamentu e turra a lu mòdulu',
 'uploadnologin'               => 'Intradda nò effettuadda',
-'uploadnologintext'           => 'È nezzessàriu [[Special:Userlogin|intrà]] pa carriggà file.',
+'uploadnologintext'           => 'È nezzessàriu [[Special:UserLogin|intrà]] pa carriggà file.',
 'upload_directory_read_only'  => "L'elaburaddori sivvidori nò è bonu à ischribì i' la carthella di carriggamentu ($1).",
 'uploaderror'                 => "Errori i' lu carriggamentu",
 'uploadtext'                  => "Usà lu mòdulu in giossu pà carriggà file.
-Pà visuarizzà o zirchà li file già carriggaddi, cunsulthà  lu [[Special:Imagelist|rigisthru di li file carriggaddi]]. Carriggamenti e ischarriggamenti di file so registhraddi i' lu  [[Special:Log/upload|rigisthru di li carriggamenti]].
+Pà visuarizzà o zirchà li file già carriggaddi, cunsulthà  lu [[Special:ImageList|rigisthru di li file carriggaddi]]. Carriggamenti e ischarriggamenti di file so registhraddi i' lu  [[Special:Log/upload|rigisthru di li carriggamenti]].
 
 Pa insirì un'immàgina i'na pàgina, fà un cullegamentu cussì:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''' ,
@@ -968,7 +961,7 @@
 'upload_source_url'  => " (un'indirizzu vàriddu e pùbbriggu)",
 'upload_source_file' => " (un file i' lu propriu elaburaddori)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Zercha immàgini pa innòmu:',
 'imgfile'               => 'file',
 'imagelist'             => 'Listha di li file',
@@ -1003,18 +996,18 @@
 # File reversion
 'filerevert'                => 'Turra che primma $1',
 'filerevert-legend'         => 'Ricupara file',
-'filerevert-intro'          => '<span class="plainlinks">N\'isthai pa ricuparà lu file \'\'\'[[Media:$1|$1]]\'\'\' a la [versioni $4 di lu $2, $3].</span>',
+'filerevert-intro'          => "N'isthai pa ricuparà lu file '''[[Media:$1|$1]]''' a la [versioni $4 di lu $2, $3].",
 'filerevert-comment'        => 'Oggettu:',
 'filerevert-defaultcomment' => 'Turradda che primma la versioni di lu $1, $2',
 'filerevert-submit'         => 'Turra che primma',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'Lu file [[Media:$1|$1]]\'\'\' è isthaddu ricuparaddu a la [versioni $4 di lu $2, $3].</span>',
+'filerevert-success'        => "'''Lu file [[Media:$1|$1]]''' è isthaddu ricuparaddu a la [versioni $4 di lu $2, $3].",
 'filerevert-badversion'     => "Nò isisthono versioni lucari prizzidenti di lu file cu' la marchaddura oreria disizadda.",
 
 # File deletion
 'filedelete'             => 'Canzella $1',
 'filedelete-legend'      => 'Canzella lu file',
 'filedelete-intro'       => "N'isthai canzellendi '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'   => '<span class="plainlinks">N\'isthai canzillendi la versioni di \'\'\'[[Media:$1|$1]]\'\'\' di lu [$4 $2, $3].</span>',
+'filedelete-intro-old'   => "N'isthai canzillendi la versioni di '''[[Media:$1|$1]]''' di lu [$4 $2, $3].",
 'filedelete-comment'     => 'Mutibazioni:',
 'filedelete-submit'      => 'Canzella',
 'filedelete-success'     => "Lu file '''$1''' è isthaddu canzilladdu.",
@@ -1060,7 +1053,7 @@
 Da l'isthallazioni di {{SITENAME}} finz'abà  '''\$3''' {{PLURAL:\$3|pàgina è isthadda visitadda|pàgini so isthaddi visitaddi}}, e '''\$4''' {{PLURAL:\$4|mudìfigga è isthadda arriggadda|mudìfigghi so isthaddi arriggaddi}}, pa una mèdia di '''\$5''' mudìfigghi pa pàgina e '''\$6''' litturi pa mudìfigga.
 
 La [http://www.mediawiki.org/wiki/Manual:Job_queue coda di li pruzzessi] è longa '''\$7'''.",
-'userstatstext'          => "Abà {{PLURAL:$1|è registhraddu '''1''' [[Special:Listusers|utenti]]|so registhraddi '''$1''' [[Special:Listusers|utenti]]}}. Lu gruppu $5 è cumposthu da '''$2''' {{PLURAL:$2|utenti|utenti}}, pari a lu '''$4%''' di li registhraddi.",
+'userstatstext'          => "Abà {{PLURAL:$1|è registhraddu '''1''' [[Special:ListUsers|utenti]]|so registhraddi '''$1''' [[Special:ListUsers|utenti]]}}. Lu gruppu $5 è cumposthu da '''$2''' {{PLURAL:$2|utenti|utenti}}, pari a lu '''$4%''' di li registhraddi.",
 'statistics-mostpopular' => 'Pàgini più visitaddi',
 
 'disambiguations'      => 'Pàgini cu lu matessi innòmmu',
@@ -1146,7 +1139,7 @@
 'logempty'             => 'Lu rigisthru nò cunteni erementi curripundenti.',
 'log-title-wildcard'   => "Zercha li tìturi ch'ischuminzani cun",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tutti li pàgini',
 'alphaindexline'    => 'da $1 a $2',
 'nextpage'          => 'Pàgini sighenti ($1)',
@@ -1166,17 +1159,17 @@
 'categories'         => 'Categuri',
 'categoriespagetext' => "Erencu cumpretu di li categuri prisenti i'lu situ.",
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "Musthra l'utenti parthendi da:",
 'listusers-submit'   => 'Musthra',
 'listusers-noresult' => 'Nisciun utenti curripundi a li critéri impusthaddi.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-members' => '(erencu di li membri)',
 
 # E-mail user
 'mailnologin'     => "Nisciun indirizzu a lu quari invià l'imbasciadda.",
-'mailnologintext' => "Pa invià imbasciaddi di postha erettrònica è nezzessàriu [[Special:Userlogin|intrà]] e abé registhraddu un'indirizzu variddu i' li propri [[Special:Preferences|prifirenzi]].",
+'mailnologintext' => "Pa invià imbasciaddi di postha erettrònica è nezzessàriu [[Special:UserLogin|intrà]] e abé registhraddu un'indirizzu variddu i' li propri [[Special:Preferences|prifirenzi]].",
 'emailuser'       => "Ischribì a l'utenti",
 'emailpage'       => "Invia un'imbasciadda di postha erettrònica a l'utenti",
 'emailpagetext'   => "Si l'utenti à registhraddu un'indirizzu di postha erettrònica vàriddu i' li propri prifirenzi, lu mòdulu in giossu cunsenti d'ischribelli una sora imbasciadda. L'indirizzu indicaddu i' li prifirenzi di lu mandanti apparirà i' lu campu \"Da:\" di l'imbasciadda pa cunsintì a  lu disthinatàriu l'eventuari rippostha.",
@@ -1201,10 +1194,10 @@
 'nowatchlist'          => "La listha di l'abbaidaddi ippiziari è biodda.",
 'watchlistanontext'    => "Pa visuarizzà e mudìfiggà l'erencu di l'abbaidaddi ippiziari è nezzessàriu $1.",
 'watchnologin'         => 'Intradda nò effettuadda',
-'watchnologintext'     => "Pa mudìfiggà la listha di l'abbaidaddi ippiziari è nezzessàriu primma [[Special:Userlogin|intrà]].",
+'watchnologintext'     => "Pa mudìfiggà la listha di l'abbaidaddi ippiziari è nezzessàriu primma [[Special:UserLogin|intrà]].",
 'addedwatch'           => "Pàgina aggiunta a la listha di l'abbaidaddi ippiziari",
 'addedwatchtext'       => "La pàgina  \"[[:\$1]]\" è isthadda aggiunta a la propria [[Special:Watchlist|listha di l'abbaidaddi ippiziari]]. D'abà innanzi, tutti li mudìfigghi arriggaddi a la pàgina e a la sóia dischussioni sarani erencaddi in chidda listha; lu tìturu di la pàgina apparirà in '''grasseddu''' i' la pàgina
-di l'[[Special:Recentchanges|ulthimi mudìfigghi]] pa rindiru più visìbiri.
+di l'[[Special:RecentChanges|ulthimi mudìfigghi]] pa rindiru più visìbiri.
 
 Si daboi s'à gana d'eliminà la pàgina da la listha di l'abbaidaddi ippiziarii, fà clic i' \"nò sighì\" i' la barra in althu.",
 'removedwatch'         => "Pàgina eliminadda da la listha di l'abbaidaddi ippiziari",
@@ -1307,7 +1300,7 @@
 'rollback-success'            => 'Annulladdi li mudìfigghi di $1; turradda a la versioni prizzidenti di $2.',
 'sessionfailure'              => "S'è verifigaddu un probrema i' la sissioni ch'identifigga l'intradda; lu sistham nò à eseguiddu lu cumandu imparthiddu pa precauzioni. Turrà a la pàgina prizzidenti cu' lu buttoni \"Indareddu\" di lu proprio nabigaddori, turrà a carriggà la pàgina e riprubà.",
 'protectlogpage'              => 'Prutizioni',
-'protectlogtext'              => "Inogghi v'è la listha di li pàgini broccaddi e ibbruccaddi. Védi la [[Special:Protectedpages|listha di li pàgini prutiggiddi]] pa chiddi chi so attuarmenti prutiggiddi.",
+'protectlogtext'              => "Inogghi v'è la listha di li pàgini broccaddi e ibbruccaddi. Védi la [[Special:ProtectedPages|listha di li pàgini prutiggiddi]] pa chiddi chi so attuarmenti prutiggiddi.",
 'protectedarticle'            => 'à prutiggiddu "[[$1]]"',
 'modifiedarticleprotection'   => 'ha mudìfiggaddu lu libellu di prutizioni di "[[$1]]"',
 'unprotectedarticle'          => 'à ibbruccaddu "[[$1]]"',
@@ -1434,7 +1427,7 @@
 'badipaddress'                => 'Indirizzu IP invàriddu',
 'blockipsuccesssub'           => 'Broccu eseguiddu',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] è isthaddu broccaddu.
-<br />Cunsulthà la [[Special:Ipblocklist|listha di l'IP broccaddi]] pa vidé i brocchi attibi.",
+<br />Cunsulthà la [[Special:IPBlockList|listha di l'IP broccaddi]] pa vidé i brocchi attibi.",
 'ipb-edit-dropdown'           => 'Mutibi pa lu broccu',
 'ipb-unblock-addr'            => 'Ibbrucca $1',
 'ipb-unblock'                 => "Ibbrucca un'utenti o un'indirizzu IP",
@@ -1464,7 +1457,7 @@
 'autoblocker'                 => "Broccaddu automatiggamenti parchí l'indirizzu IP è cundibisu cu' l'utenti \"[[User:\$1|\$1]]\". Lu broccu di l'utenti \$1 è isthaddu impusthaddu pa lu sighenti mutibu: \"'''\$2'''\".",
 'blocklogpage'                => 'Brocchi',
 'blocklogentry'               => "à broccaddu [[$1]] cu' l'ischadènzia $2 $3",
-'blocklogtext'                => "Chisthu è l'erencu di l'azioni di broccu e ibbruccu utenti. Li indirizzi IP broccaddi automatiggamenti nò so erencaddi. Cunsulthà la [[Special:Ipblocklist|listha di l'IP broccaddi]] pa l'erencu di l'indirizzi e innòmmi utenti chi so broccaddi abà.",
+'blocklogtext'                => "Chisthu è l'erencu di l'azioni di broccu e ibbruccu utenti. Li indirizzi IP broccaddi automatiggamenti nò so erencaddi. Cunsulthà la [[Special:IPBlockList|listha di l'IP broccaddi]] pa l'erencu di l'indirizzi e innòmmi utenti chi so broccaddi abà.",
 'unblocklogentry'             => 'à ibbruccaddu $1',
 'block-log-flags-anononly'    => 'soru utenti anònimi',
 'block-log-flags-nocreate'    => 'criazioni registhrazioni broccadda',
@@ -1518,8 +1511,6 @@
 
 In chisthi casi, si lu vói avveru, débi ippusthà o aggiugnì a manu le infuimmazioni cuntinuddi i' la pàgina di dischussioni.",
 'movearticle'             => 'Ippustha la pàgina',
-'movenologin'             => 'Intradda nò effettuadda',
-'movenologintext'         => "L'ippusthamentu di li pàgini è cunsintiddu soru a l'utenti registhraddi chi so [[Special:Userlogin|intraddi]] i' lu situ.",
 'movenotallowed'          => "Nò si diponi di li primmissi nezzessàri a l'ippusthamentu di pàgini i' {{SITENAME}}.",
 'newtitle'                => 'Nobu tìturu:',
 'move-watch'              => "Aggiungi a l'abbaidaddi ippiziari",
@@ -1539,7 +1530,7 @@
 'delete_and_move'         => 'Canzella e ippustha',
 'delete_and_move_text'    => '==Prigonga di canzilladdura==
 
-La pàgina di disthinazioni "[[$1]]" isisthi già. Vói canzillalla pa rindì pussìbiri l\'ippusthamentu?',
+La pàgina di disthinazioni "[[:$1]]" isisthi già. Vói canzillalla pa rindì pussìbiri l\'ippusthamentu?',
 'delete_and_move_confirm' => 'Emmo, sobbraischribì la pàgini',
 'delete_and_move_reason'  => "Canzilladda pa rindì pussìbiri l'ippusthamentu",
 'selfmove'                => "Lu nobu tìturu è uguari a lu vécciu; impussìbiri ippusthà la pàgina cu' lu matessi innòmmu.",
@@ -1757,7 +1748,7 @@
 'show-big-image'       => 'Versioni a altha risoruzioni',
 'show-big-image-thumb' => "<small>Misuri di chisth'antiprimma: $1 × $2 punti</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galleria di li file nobi',
 'imagelisttext'         => "Inogghi una listha di '''$1''' {{PLURAL:$1|file|file}} ordhinaddi pa $2.",
 'showhidebots'          => '($1 li bot)',
@@ -1848,7 +1839,7 @@
 
 # External editor support
 'edit-externally'      => 'Mudìfigga chistu file usendi un prugramma esthernu',
-'edit-externally-help' => "Pa maggiori infuimmazioni cunsultha l'[http://meta.wikimedia.org/wiki/Help:External_editors isthruzioni] (in ingresu).",
+'edit-externally-help' => "Pa maggiori infuimmazioni cunsultha l'[http://www.mediawiki.org/wiki/Manual:External_editors isthruzioni] (in ingresu).",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tutti',
@@ -1911,7 +1902,7 @@
 'recreate'            => 'Ricrea',
 
 # HTML dump
-'redirectingto' => 'Rinviu a [[$1]]...',
+'redirectingto' => 'Rinviu a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Vói pulì la mimória cache di chistha pàgina?
Index: languages/messages/MessagesEu.php
===================================================================
--- languages/messages/MessagesEu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Theklan
  * @author Bengoa
- * @author Siebrand
- * @author לערי ריינהארט
- * @author Malafaya
- * @author Kaustubh
  * @author Helix84
+ * @author Kaustubh
+ * @author Malafaya
+ * @author Theklan
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -320,7 +318,7 @@
 'nosuchspecialpage' => 'Ez da aparteko orrialde hori existitzen',
 'nospecialpagetext' => "<big>'''Baliogabeko aparteko orrialde bat eskatu duzu.'''</big>
 
-Existitzen direnen zerrenda ikus dezakezu  [[Special:Specialpages|{{int:specialpages}}]] orrialdean.",
+Existitzen direnen zerrenda ikus dezakezu  [[Special:SpecialPages|{{int:specialpages}}]] orrialdean.",
 
 # General errors
 'error'                => 'Errorea',
@@ -535,10 +533,6 @@
 'blockededitsource'                => "Jarraian ikus daitezke '''$1'''(e)n egin dituzun aldaketak:",
 'whitelistedittitle'               => 'Saioa hastea beharrezkoa da aldaketak egiteko',
 'whitelistedittext'                => '$1 behar duzu orrialdeak aldatu ahal izateko..',
-'whitelistreadtitle'               => 'Saioa hastea beharrezkoa da irakurtzeko',
-'whitelistreadtext'                => '[[Special:Userlogin|Saioa hasi]] behar duzu orrialdeak irakurtzeko.',
-'whitelistacctitle'                => 'Ez daukazu kontu berri bat sortzeko baimenik',
-'whitelistacctext'                 => 'Wiki honetan kontu berriak sortu ahal izateko [[Special:Userlogin|saioa hasi]] eta baimena izatea beharrezko da.',
 'confirmedittitle'                 => 'E-posta egiaztatzea beharrezkoa da aldaketak egiteko',
 'confirmedittext'                  => 'Orrialdeetan aldaketak egin aurretik zure e-posta helbidea egiaztatu beharra daukazu. Mesedez, zehaztu eta egiaztatu zure e-posta helbidea [[Special:Preferences|hobespenetan]].',
 'nosuchsectiontitle'               => 'Ez da atala existitzen',
@@ -550,7 +544,7 @@
 'accmailtext'                      => '"$1"(r)en pasahitza $2(e)ra bidali da.',
 'newarticle'                       => '(Berria)',
 'newarticletext'                   => "Orrialde hau ez da existitzen oraindik. Orrialde sortu nahi baduzu, beheko koadroan idazten hasi zaitezke (ikus [[{{MediaWiki:Helppage}}|laguntza orrialdea]] informazio gehiagorako). Hona nahi gabe etorri bazara, nabigatzaileko '''atzera''' botoian klik egin.",
-'anontalkpagetext'                 => "----''Honako hau konturik sortu ez edo erabiltzen ez duen erabiltzaile anonimo baten eztabaida orria da. Bere IP helbidea erabili beharko da beraz identifikatzeko. Erabiltzaile batek baino gehiagok IP bera erabil dezakete ordea. Erabiltzaile anonimoa bazara eta zurekin zerikusirik ez duten mezuak jasotzen badituzu, mesedez [[Special:Userlogin|Izena eman edo saioa hasi]] etorkizunean horrelakoak gerta ez daitezen.''",
+'anontalkpagetext'                 => "----''Honako hau konturik sortu ez edo erabiltzen ez duen erabiltzaile anonimo baten eztabaida orria da. Bere IP helbidea erabili beharko da beraz identifikatzeko. Erabiltzaile batek baino gehiagok IP bera erabil dezakete ordea. Erabiltzaile anonimoa bazara eta zurekin zerikusirik ez duten mezuak jasotzen badituzu, mesedez [[Special:UserLogin|Izena eman edo saioa hasi]] etorkizunean horrelakoak gerta ez daitezen.''",
 'noarticletext'                    => 'Oraindik ez dago testurik orrialde honetan; beste orrialde batzuetan [[Special:Search/{{PAGENAME}}|bilatu dezakezu izenburu hau]] edo [{{fullurl:{{FULLPAGENAME}}|action=edit}} berau aldatu ere egin dezakezu].',
 'userpage-userdoesnotexist'        => '"$1" lankidea ez dago erregistatuta. Mesedez, konprobatu orri hau editatu/sortu nahi duzun.',
 'clearyourcache'                   => "'''Oharra - Gorde ondoren zure nabigatzailearen katxea ekidin beharko duzu aldaketak ikusteko.''' '''Mozilla / Firefox / Safari:''' ''Shift'' tekla sakatu birkargatzeko momentuan, edo ''Ctrl-Shift-R'' sakatu (''Cmd-Shift-R'' Apple Mac baten); '''Internet Explorer:''' ''Ctrl'' tekla sakatu birkargatzeko momentuan, edo ''Ctrl-F5'' sakatu; '''Konqueror:''': Birkargatzeko klik egin, edo F5 sakatu, besterik ez; '''Opera''' erabiltzaileek ''Tresnak-Hobespenak'' atalera jo eta katxea garbitzeko aukera hautatu.",
@@ -597,7 +591,7 @@
 'template-semiprotected'           => '(erdi-babestua)',
 'edittools'                        => '<!-- Hemen jarritako testua aldaketa eta igoera formularioen azpian agertuko da. -->',
 'nocreatetitle'                    => 'Orrialdeak sortzea mugatuta',
-'nocreatetext'                     => 'Gune honek orrialde berriak sortzeko gaitasuna mugatu du. Atzera egin dezakezu existitzen den orrialde bat aldatzeko, edo [[Special:Userlogin|saio hasi edo kontua sortu]].',
+'nocreatetext'                     => 'Gune honek orrialde berriak sortzeko gaitasuna mugatu du. Atzera egin dezakezu existitzen den orrialde bat aldatzeko, edo [[Special:UserLogin|saio hasi edo kontua sortu]].',
 'nocreate-loggedin'                => 'Ez daukazu wiki honetan orrialde berriak sortzeko baimenik, administratzaile batek orri hau blokeatu duelako bandalismoak sahiesteko.',
 'permissionserrors'                => 'Baimen erroreak',
 'permissionserrorstext'            => 'Ez duzu hori egiteko baimenik, hurrengo {{PLURAL:$1|arrazoia dela eta|arrazoiak direla eta}}:',
@@ -776,7 +770,7 @@
 'mypreferences'            => 'Nire hobespenak',
 'prefs-edits'              => 'Aldaketa kopurua:',
 'prefsnologin'             => 'Saioa hasi gabe',
-'prefsnologintext'         => '[[Special:Userlogin|Saioa hasi behar duzu]] zure hobespenak ezartzeko.',
+'prefsnologintext'         => '[[Special:UserLogin|Saioa hasi behar duzu]] zure hobespenak ezartzeko.',
 'prefsreset'               => 'Hobespenak hasieratu egin dira.',
 'qbsettings'               => 'Laster-barra',
 'qbsettings-none'          => 'Ezein ere',
@@ -957,10 +951,10 @@
 'reupload'                    => 'Berriz igo',
 'reuploaddesc'                => 'Igotzeko formulariora itzuli.',
 'uploadnologin'               => 'Saioa hasi gabe',
-'uploadnologintext'           => 'Fitxategiak igotzeko [[Special:Userlogin|saioa hasi]] behar duzu.',
+'uploadnologintext'           => 'Fitxategiak igotzeko [[Special:UserLogin|saioa hasi]] behar duzu.',
 'upload_directory_read_only'  => 'Web zerbitzariak ez dauka igoera direktorioan ($1) idazteko baimenik.',
 'uploaderror'                 => 'Errorea igotzerakoan',
-'uploadtext'                  => "Fitxategiak igotzeko beheko formularioa erabil dezakezu. Aurretik igotako irudiak ikusi edo bilatzeko [[Special:Imagelist|igotako fitxategien zerrendara]] jo. Igoerak eta ezabatutakoak [[Special:Log/upload|igoera erregistroan]] zerrendatzen dira.
+'uploadtext'                  => "Fitxategiak igotzeko beheko formularioa erabil dezakezu. Aurretik igotako irudiak ikusi edo bilatzeko [[Special:ImageList|igotako fitxategien zerrendara]] jo. Igoerak eta ezabatutakoak [[Special:Log/upload|igoera erregistroan]] zerrendatzen dira.
 
 Orrialde baten irudi bat txertatzeko, erabili kode hauetako bat:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fitxategia.jpg]]</nowiki>''',
@@ -1040,7 +1034,7 @@
 'upload_source_url'  => ' (baliozko URL publikoa)',
 'upload_source_file' => ' (zure ordenagailuko fitxategi bat)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Irudiaren izenagatik bilatu:',
 'imgfile'               => 'fitxategia',
 'imagelist'             => 'Fitxategien zerrenda',
@@ -1065,7 +1059,7 @@
 'imagelinks'                     => 'Loturak',
 'linkstoimage'                   => 'Hurrengo orrialdeek dute fitxategi honetarako lotura:',
 'nolinkstoimage'                 => 'Ez dago fitxategi honetara lotura egiten duen orrialderik.',
-'morelinkstoimage'               => 'Ikusi fitxategi honen [[Special:Whatlinkshere/$1|lotura gehiago]].',
+'morelinkstoimage'               => 'Ikusi fitxategi honen [[Special:WhatLinksHere/$1|lotura gehiago]].',
 'redirectstofile'                => 'Honako {{PLURAL:$1|artxiboak fitxategi honetara birzuzentzen du:|$1 artxiboek fitxategi honetara birzuzentzen dute:}}',
 'duplicatesoffile'               => 'Hondoren fitxategi {{PLURAL:$1|hau beste honen berdina da|$1 hauek beste honen berdinak dira}}:',
 'sharedupload'                   => 'Fitxategi hau elkarbanatutako igoera bat da eta beste proiektuek ere erabil dezakete.',
@@ -1090,7 +1084,7 @@
 'filedelete'                  => '$1 ezabatu',
 'filedelete-legend'           => 'Fitxategia ezabatu',
 'filedelete-intro'            => "'''[[Media:$1|$1]]''' ezabatzen ari zara.",
-'filedelete-intro-old'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'ren bertsioa ezabatzen ari zara, [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "'''[[Media:$1|$1]]'''ren bertsioa ezabatzen ari zara, [$4 $3, $2].",
 'filedelete-comment'          => 'Iruzkina:',
 'filedelete-submit'           => 'Ezabatu',
 'filedelete-success'          => "'''$1''' ezabatu da.",
@@ -1134,15 +1128,15 @@
 'userstats'              => 'Erabiltzaile estatistikak',
 'sitestatstext'          => "Datu-basean guztira <b>$1</b> orri daude; eztabaidatzeko, wikipedari buruzko orriak, birzuzenketak eta artikulu laburrak barne hartzen.
 
-Horiek baztertzen, <b>$2</b> artikulu dira datu-basean.
+Horiek baztertzen, <b>$2</b> artikulu dauzakagu datu-basean.
 
-'''$8''' files have been uploaded.
+'''$8''' irudi igo dira.
 
 Guztira '''$3''' bisitaturiko orri, eta <b>$4</b> artikulu aldaketa egon dira software-a berritu zenetik (2002.eko uztailaren 20a).
 
 Emaitza hauekin hurrengo arrazoiak atera daitezke: '''$5''' aldaketa egon dira orrialde bakoitzeko, eta '''$6''' bisita aldaketa bakoitzeko.
 
-The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''$7'''.",
+Gure [http://www.mediawiki.org/wiki/Manual:Job_queue Job queue] '''$7'''-koa da.",
 'userstatstext'          => "'''$1''' erabiltzaile daude izen emanda, horietatik '''$2''' (edo '''$4%''') $5ek eskumenak {{PLURAL:$2|dituelarik|dituztelarik}}.",
 'statistics-mostpopular' => 'Orrialde bisitatuenak',
 
@@ -1234,7 +1228,7 @@
 'logempty'             => 'Ez dago emaitzarik erregistroan.',
 'log-title-wildcard'   => 'Testu honekin hasten diren izenburuak bilatu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Orrialde guztiak',
 'alphaindexline'    => '$1(e)tik $2(e)raino',
 'nextpage'          => 'Hurrengo orrialdea ($1)',
@@ -1257,12 +1251,12 @@
 'special-categories-sort-count' => 'kontatetzearen arabera ordenatu',
 'special-categories-sort-abc'   => 'alfabetikoki aldatu',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Hemendik aurrerako erabiltzaileak bistaratu:',
 'listusers-submit'   => 'Erakutsi',
 'listusers-noresult' => 'Ez da erabiltzailerik aurkitu.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Erabiltzaile talde eskumenak',
 'listgrouprights-group'    => 'Taldea',
 'listgrouprights-rights'   => 'Eskumenak',
@@ -1271,7 +1265,7 @@
 
 # E-mail user
 'mailnologin'     => 'Bidalketa helbiderik ez',
-'mailnologintext' => 'Beste erabiltzaileei e-posta mezuak bidaltzeko [[Special:Userlogin|saioa hasi]] eta baliozko e-posta helbidea behar duzu izan zure [[Special:Preferences|hobespenetan]].',
+'mailnologintext' => 'Beste erabiltzaileei e-posta mezuak bidaltzeko [[Special:UserLogin|saioa hasi]] eta baliozko e-posta helbidea behar duzu izan zure [[Special:Preferences|hobespenetan]].',
 'emailuser'       => 'Erabiltzaile honi e-posta bidali',
 'emailpage'       => 'Erabiltzaileari e-posta bidali',
 'emailpagetext'   => 'Erabiltzaile honek baliozko e-posta helbide bat ezarri badu bere hobespenetan, beheko formularioa erabiliz mezu bat bidal dakioke. Hobespenetan daukazun e-posta helbidea azalduko da mezuaren bidaltzaile bezala eta beraz erantzun ahal izango dizu.',
@@ -1296,9 +1290,9 @@
 'nowatchlist'          => 'Zure jarraipen zerrenda hutsik dago.',
 'watchlistanontext'    => 'Mesedez $1 zure jarraipen zerrendako orrialdeak ikusi eta aldatu ahal izateko.',
 'watchnologin'         => 'Saioa hasi gabe',
-'watchnologintext'     => '[[Special:Userlogin|Saioa hasi]] behar duzu zure jarraipen zerrenda aldatzeko.',
+'watchnologintext'     => '[[Special:UserLogin|Saioa hasi]] behar duzu zure jarraipen zerrenda aldatzeko.',
 'addedwatch'           => 'Jarraipen zerrendan gehitu da',
-'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" orrialdea zure [[Special:Watchlist|jarraipen edo zelatatuen zerrendara]] erantsi da. Orrialde honen hurrengo aldaketak zerrenda horretan ageriko dira aurrerantzean, eta gainera [[Special:Recentchanges|aldaketa berrien zerrendan]] beltzez ageriko da, erraztasunez antzeman ahal izateko.
+'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" orrialdea zure [[Special:Watchlist|jarraipen edo zelatatuen zerrendara]] erantsi da. Orrialde honen hurrengo aldaketak zerrenda horretan ageriko dira aurrerantzean, eta gainera [[Special:RecentChanges|aldaketa berrien zerrendan]] beltzez ageriko da, erraztasunez antzeman ahal izateko.
 
 Jarraipen zerrendatik artikulua kentzeko, artikuluan ''ez jarraitu''ri eman.",
 'removedwatch'         => 'Jarraipen zerrendatik ezabatuta',
@@ -1546,7 +1540,7 @@
 'badipaddress'                => 'Baliogabeko IP helbidea',
 'blockipsuccesssub'           => 'Blokeoa burutu da',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] erabiltzaileari blokeoa ezarri zaio.<br />
-Ikus [[Special:Ipblocklist|IP blokeoen zerrenda]] blokeoak aztertzeko.',
+Ikus [[Special:IPBlockList|IP blokeoen zerrenda]] blokeoak aztertzeko.',
 'ipb-edit-dropdown'           => 'Lankide bat blokeatzeko arrazoiak',
 'ipb-unblock-addr'            => '$1 lankide edo IP helbideari blokeoa baliogabetu',
 'ipb-unblock'                 => 'Erabiltzaile izen edo IP helbide bati blokeoa kendu',
@@ -1576,7 +1570,7 @@
 'autoblocker'                 => '"[[User:$1|$1]]"(e)k berriki erabili duen IP helbidea duzulako autoblokeatu zaizu. $1(e)k emandako arrazoia zera da: "\'\'\'$2\'\'\'"',
 'blocklogpage'                => 'Blokeo erregistroa',
 'blocklogentry'               => '"[[$1]]" $2(e)ko iraungipenarekin blokeatu da. $3',
-'blocklogtext'                => 'Erabiltzaileen blokeoen ezarpen eta ezabaketen erregistroa da hau. Ez dira automatikoki blokeatutako IP helbideak zerrendatzen. Ikus [[Special:Ipblocklist|IP blokeoen zerrenda]] aktibo dauden blokeoak aztertzeko.',
+'blocklogtext'                => 'Erabiltzaileen blokeoen ezarpen eta ezabaketen erregistroa da hau. Ez dira automatikoki blokeatutako IP helbideak zerrendatzen. Ikus [[Special:IPBlockList|IP blokeoen zerrenda]] aktibo dauden blokeoak aztertzeko.',
 'unblocklogentry'             => '$1 desblokeatu da',
 'block-log-flags-anononly'    => 'erabiltzaile anonimoak bakarrik',
 'block-log-flags-nocreate'    => 'kontuak sortzea ezgaituta',
@@ -1607,7 +1601,7 @@
 'locknoconfirm'       => 'Ez duzu baieztapen kutxa hautatu.',
 'lockdbsuccesssub'    => 'Datu-basea blokeatu egin da',
 'unlockdbsuccesssub'  => 'Datu-basearen blokeoa kendu da',
-'lockdbsuccesstext'   => 'Datu-basea blokeatu egin da. <br />Ez ahaztu mantenu lanak burutu ondoren [[Special:Unlockdb|blokeoa kentzeaz]].',
+'lockdbsuccesstext'   => 'Datu-basea blokeatu egin da. <br />Ez ahaztu mantenu lanak burutu ondoren [[Special:UnlockDB|blokeoa kentzeaz]].',
 'unlockdbsuccesstext' => 'Datu-basea desblokeatu egin da.',
 'lockfilenotwritable' => 'Ezin da datu-baseko blokeo fitxategian idatzi. Datu-basea blokeatu edo desblokeatzeko, zerbitzariak idazteko aukera izan beharra dauka.',
 'databasenotlocked'   => 'Datu-basea ez dago blokeatuta.',
@@ -1626,8 +1620,6 @@
 
 Kasu horietan orrialdea eskuz mugitu edo bestearekin bateratu beharko duzu.",
 'movearticle'             => 'Orrialdea mugitu',
-'movenologin'             => 'Saioa hasi gabe',
-'movenologintext'         => 'Orrialde bat mugitzeko erregistratutako erabiltzailea izan behar duzu eta [[Special:Userlogin|saioa hasi]].',
 'movenotallowed'          => 'Ez daukazu {{SITENAME}}n orrialdeak mugitzeko baimenik.',
 'newtitle'                => 'Izenburu berria',
 'move-watch'              => 'Orrialde hau jarraitu',
@@ -1653,7 +1645,7 @@
 'delete_and_move'         => 'Ezabatu eta mugitu',
 'delete_and_move_text'    => '== Ezabatzeko beharra ==
 
-"[[$1]]" helburua existitzen da. Lekua egiteko ezabatu nahi al duzu?',
+"[[:$1]]" helburua existitzen da. Lekua egiteko ezabatu nahi al duzu?',
 'delete_and_move_confirm' => 'Bai, orrialdea ezabatu',
 'delete_and_move_reason'  => 'Lekua egiteko ezabatu da',
 'selfmove'                => 'Helburu izenburua berdina da; ezin da orrialde bat bere gainera mugitu.',
@@ -1881,7 +1873,7 @@
 'show-big-image'       => 'Bereizmen handikoa',
 'show-big-image-thumb' => '<small>Aurreikuspen honen neurria: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Fitxategi berrien galeria',
 'imagelisttext'         => "Jarraian duzu $2(e)z ordenatutako {{PLURAL:$1|fitxategi baten|'''$1''' fitxategiren}} zerrenda.",
 'showhidebots'          => '($1 bot-ak)',
@@ -2021,6 +2013,8 @@
 
 'exif-scenecapturetype-2' => 'Erretratua',
 
+'exif-gaincontrol-0' => 'Ezer',
+
 'exif-contrast-0' => 'Arrunta',
 'exif-contrast-1' => 'Leuna',
 'exif-contrast-2' => 'Zakarra',
@@ -2060,7 +2054,7 @@
 
 # External editor support
 'edit-externally'      => 'Fitxategi hau editatu kanpo-aplikazio bat erabiliz',
-'edit-externally-help' => 'Ikus [http://meta.wikimedia.org/wiki/Help:External_editors konfiguraziorako argibideak] informazio gehiagorako.',
+'edit-externally-help' => 'Ikus [http://www.mediawiki.org/wiki/Manual:External_editors konfiguraziorako argibideak] informazio gehiagorako.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'guztiak',
@@ -2115,7 +2109,7 @@
 'recreate'            => 'Birsortu',
 
 # HTML dump
-'redirectingto' => '[[$1]] orrialdera berbideratzen...',
+'redirectingto' => '[[:$1]] orrialdera berbideratzen...',
 
 # action=purge
 'confirm_purge'        => 'Orrialde honen katxea ezabatu?
@@ -2186,7 +2180,7 @@
 'version-software-product' => 'Produktua',
 'version-software-version' => 'Bertsioa',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Fitxategi bidea',
 'filepath-page'   => 'Fitxategia:',
 'filepath-submit' => 'Ibilbidea',
@@ -2206,7 +2200,7 @@
 'specialpages-group-wiki'      => 'Wiki datuak eta tresnak',
 'specialpages-group-spam'      => 'Spam tresnak',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage' => 'Orrialde txuria',
 
 );
Index: languages/messages/MessagesAz.php
===================================================================
--- languages/messages/MessagesAz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -239,7 +238,6 @@
 'showdiff'           => 'Dəyişiklikləri göstər',
 'blockedtitle'       => 'İstifadəçi bloklanıb',
 'whitelistedittitle' => 'Redaktə üçün daxil olmalısınız',
-'whitelistreadtitle' => 'Oxumaq üçün daxil olmalısınız',
 'accmailtitle'       => 'Parol göndərildi.',
 'accmailtext'        => '"$1" üçün parol göndərildi bu ünvana : $2.',
 'newarticle'         => '(Yeni)',
@@ -339,7 +337,7 @@
 'uploadwarning'     => 'Yükləyiş xəbərdarlıqı',
 'savefile'          => 'Faylı qeyd et',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Fayl siyahısı',
 
 # Image description page
@@ -400,7 +398,7 @@
 'log'         => 'Loglar',
 'alllogstext' => "Qarşıya yükləmə, silmə, qoruma, bloklama ve sistem operatoru loqlarının birləşdirilmiş göstərməsi. Log növü, istifadəçi adı veya tə'sir edilən səhifəni seçib görüntünü kiçildə bilərsiniz.",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Bütün səhifələr',
 'nextpage'       => 'Sonrakı səhifə ($1)',
 'allpagesfrom'   => 'Bu mövqedən başlayan səhifeleri göstər:',
@@ -430,7 +428,7 @@
 'mywatchlist'          => 'İzlədiyim səhifələr',
 'watchnologin'         => 'Daxil olmamısınız',
 'addedwatch'           => 'İzləmə siyahısına əlavə edildi.',
-'addedwatchtext'       => '"$1" səhifəsi [[Special:Watchlist|izlədiyiniz səhifələrə]] əlavə edildi. Bu səhifədə və əlaqəli müzakirə səhifəsində olacaq dəyişikliklər orada göstəriləcək və səhifə asanlıqla seçiləbilmək üçün [[Special:Recentchanges|son dəyişikliklər]]-də qalın şriftlərlə görsənəcəkdir.
+'addedwatchtext'       => '"$1" səhifəsi [[Special:Watchlist|izlədiyiniz səhifələrə]] əlavə edildi. Bu səhifədə və əlaqəli müzakirə səhifəsində olacaq dəyişikliklər orada göstəriləcək və səhifə asanlıqla seçiləbilmək üçün [[Special:RecentChanges|son dəyişikliklər]]-də qalın şriftlərlə görsənəcəkdir.
 
 Səhifəni izləmə sıyahınızdan çıxarmaq üçün yan lovhədəki "izləmə" düyməsinə vurun.',
 'removedwatch'         => 'İzləmə siyahısından çıxardılıb',
@@ -482,7 +480,7 @@
 'ipbsubmit'          => 'Bu istifadəçiyi əngəllə',
 'badipaddress'       => 'Yanlış IP',
 'blockipsuccesssub'  => 'bloklandi',
-'blockipsuccesstext' => '[[Special:Contributions/$1| $1]]bloklanıb. <br />See[[Special:Ipblocklist|IP blok siyahisi]] bloklanmış IP lər.',
+'blockipsuccesstext' => '[[Special:Contributions/$1| $1]]bloklanıb. <br />See[[Special:IPBlockList|IP blok siyahisi]] bloklanmış IP lər.',
 'ipblocklist'        => 'Əngəllənmiş istifadəçilər siyahı',
 'blocklink'          => 'blokla',
 'contribslink'       => 'Köməklər',
@@ -556,7 +554,7 @@
 'imagemaxsize' => 'Limit images on image description pages to:',
 'thumbsize'    => 'Kiçik ölçü:',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Yeni faylların siyahısı',
 'bydate'    => 'tarixe görə',
 
Index: languages/messages/MessagesJbo.php
===================================================================
--- languages/messages/MessagesJbo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesJbo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Malafaya
  * @author OldakQuill
- * @author OldakQuill
- * @author Malafaya
  */
 
 $messages = array(
@@ -131,7 +129,7 @@
 # Miscellaneous special pages
 'move' => 'stika lo cmene',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'ro notci',
 
 # Special:Categories
@@ -168,7 +166,7 @@
 # Tooltip help for the actions
 'tooltip-pt-logout' => "co'u se jaspu",
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'se datnyvei zoi',
 
 # Special:SpecialPages
Index: languages/messages/MessagesMo.php
===================================================================
--- languages/messages/MessagesMo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -120,7 +120,7 @@
 # Miscellaneous special pages
 'nbytes' => '{{PLURAL:$1|ун октет|$1 октець}}',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 пынэ ла $2',
 
 # Watchlist
Index: languages/messages/MessagesChr.php
===================================================================
--- languages/messages/MessagesChr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesChr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -64,7 +64,7 @@
 # Block/unblock
 'proxyblocksuccess' => 'ᎠᏍᏆᏛᎯ.',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ᎠᏯᏍᏗ',
 
 # Special:SpecialPages
Index: languages/messages/MessagesBat_smg.php
===================================================================
--- languages/messages/MessagesBat_smg.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBat_smg.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,7 +6,6 @@
  *
  * @author Hugo.arg
  * @author Zordsdavini
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -303,7 +302,7 @@
 # Main script and global functions
 'nosuchaction'      => 'Nier tuokė veiksma',
 'nosuchspecialpage' => 'Nier tuokė specēlėjė poslapė',
-'nospecialpagetext' => 'Tamsta prašiet nelaistėna specēlė̅jė poslapė, laistėnū specēliūju poslapiu sōraša rasėt [[Special:Specialpages|specēliūju poslapiu sārošė]].',
+'nospecialpagetext' => 'Tamsta prašiet nelaistėna specēlė̅jė poslapė, laistėnū specēliūju poslapiu sōraša rasėt [[Special:SpecialPages|specēliūju poslapiu sārošė]].',
 
 # General errors
 'error'                => 'Klaida',
@@ -467,9 +466,6 @@
 'blockedoriginalsource'     => "Žemiau īr ruodoms '''$1''' torėnīs:",
 'blockededitsource'         => "''Tamstas keitimu'' teksts poslapiui '''$1''' īr ruodoms žemiau:",
 'whitelistedittitle'        => 'Nuorėnt redagoutė rēk prisėjongtė',
-'whitelistreadtitle'        => 'Norėnt skaitītė rēk prisėjongtė',
-'whitelistreadtext'         => 'Tamstā rēk [[Special:Userlogin|prisėjongtė]], ka skaitītė poslapius.',
-'whitelistacctitle'         => 'Tamstā nelēdama kortė paskīruos',
 'loginreqlink'              => 'prisėjongtė',
 'accmailtitle'              => 'Slaptažuodis ėšsiūsts īr.',
 'accmailtext'               => "Nauduotuojė '$1' slaptažuodis nusiūsts i $2 īr.",
@@ -520,7 +516,7 @@
 'template-semiprotected'    => '(posiau apsauguots)',
 'nocreatetitle'             => 'Poslapiu kūrims aprėbuots',
 'nocreatetext'              => '{{SITENAME}} aprėbuojė galėmībe kortė naujus poslapius.
-Tamsta galėt grīžtė ė redagoutė nūnā esonti poslapi, a [[Special:Userlogin|prėsėjongtė a sokortė paskīra]].',
+Tamsta galėt grīžtė ė redagoutė nūnā esonti poslapi, a [[Special:UserLogin|prėsėjongtė a sokortė paskīra]].',
 'recreate-deleted-warn'     => "<font color =darkred>'''Diemesė: Tomsta atkoriat poslapi, katros onkstiau bova ėštrints.'''</font>
 Tomsta torėt nosprēst, a pritėnk tuoliau redagoutė šėta poslapi.
 Šėta poslapė šalėnėmu istuorėjė īr pateikta patuogoma vardan:",
@@ -596,7 +592,7 @@
 'preferences'           => 'Nustatīmā',
 'mypreferences'         => 'Mona nustatīmā',
 'prefsnologin'          => 'Naprisėjongis',
-'prefsnologintext'      => 'Tomstā reik būtė [[Special:Userlogin|prisėjongosiam]], kū galietomiet keistė sava nustatīmus.',
+'prefsnologintext'      => 'Tomstā reik būtė [[Special:UserLogin|prisėjongosiam]], kū galietomiet keistė sava nustatīmus.',
 'qbsettings-none'       => 'Neruodītė',
 'changepassword'        => 'Pakeistė slaptažuodė',
 'skin'                  => 'Ėšruoda',
@@ -708,7 +704,7 @@
 'reupload'                   => 'Pakartuotė ikielima',
 'reuploaddesc'               => 'Sogrīžtė i ikielima fuorma.',
 'uploadnologin'              => 'Naprėsėjongis',
-'uploadnologintext'          => 'Nuoriedamė ikeltė faila, torėt būt [[Special:Userlogin|prėsėjongis]].',
+'uploadnologintext'          => 'Nuoriedamė ikeltė faila, torėt būt [[Special:UserLogin|prėsėjongis]].',
 'upload_directory_read_only' => 'Tėnklapė serveris nagal rašītė i ikielima papke ($1).',
 'uploaderror'                => 'Ikielima soklīdims',
 'upload-permitted'           => 'Laistėnė failu tėpā: $1.',
@@ -755,7 +751,7 @@
 'upload_source_url'  => ' (tėkrs, vėišā priėinams URL)',
 'upload_source_file' => ' (fails Tamstas kompioterī)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'fails',
 'imagelist'             => 'Failu sārašos',
 'imagelist_name'        => 'Pavadinėms',
@@ -899,7 +895,7 @@
 'logempty'             => 'Istuorėjuo nier anėjuokiū atitinkontiu atsėtėkimu.',
 'log-title-wildcard'   => 'Ėiškuotė pavadinėmu, katrė prasėded šėtuo teksto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Vėsė straipsnē',
 'alphaindexline'    => 'Nu $1 lėg $2',
 'nextpage'          => 'Kėts poslapis ($1)',
@@ -918,14 +914,14 @@
 'categories'         => 'Kateguorėjės',
 'categoriespagetext' => 'Pruojekte īr šėtuos kateguorėjės.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Ruodītė nauduotuojus pradedont nū:',
 'listusers-submit'   => 'Ruodītė',
 'listusers-noresult' => 'Nerast anėjuokiū nauduotuoju.',
 
 # E-mail user
 'mailnologin'     => 'Nier adresa',
-'mailnologintext' => 'Tamstā reik būtė [[Special:Userlogin|prisėjongosiam]]
+'mailnologintext' => 'Tamstā reik būtė [[Special:UserLogin|prisėjongosiam]]
 ė tor būtė ivests teisings el. pašta adresos Tamstas [[Special:Preferences|nustatīmuos]],
 kū siōstomiet el. gruomatas kėtėm nauduotuojam.',
 'emailuser'       => 'Rašītė gruomata šėtam nauduotuojō',
@@ -948,11 +944,11 @@
 'nowatchlist'          => 'Netorėt anėvėina keravuojama poslapė.',
 'watchlistanontext'    => 'Prašuom $1, ka parveizietomėt a pakeistomiet elementus sava keravuojamu sārašė.',
 'watchnologin'         => 'Neprisėjongės',
-'watchnologintext'     => 'Tamstā rēk būtė [[Special:Userlogin|prisėjongosiam]], ka pakeistomiet sava keravuojamu sāraša.',
+'watchnologintext'     => 'Tamstā rēk būtė [[Special:UserLogin|prisėjongosiam]], ka pakeistomiet sava keravuojamu sāraša.',
 'addedwatch'           => 'Pridieta pri keravuojamu',
 'addedwatchtext'       => "Poslapis \"[[\$1]]\" idiets i [[Special:Watchlist|stebėmū sāraša]].
 Būsėmė poslapė ėr atėtinkama aptarėma poslapė pakeitėmā būs paruoduomė stebėmū poslapiu sārašė,
-tāp pat būs '''parīškintė''' [[Special:Recentchanges|vielībūju pakeitėmu sārašė]], ka ėšsėskėrtom ėš kėtū straipsniu.
+tāp pat būs '''parīškintė''' [[Special:RecentChanges|vielībūju pakeitėmu sārašė]], ka ėšsėskėrtom ėš kėtū straipsniu.
 Jė bikumet ožsėnuorietomiet liautėis stebietė straipsnė, spostelkat \"Nebstebietė\" vėršotėniam meniu.",
 'removedwatch'         => 'Pašalėntė ėš keravuojamu',
 'removedwatchtext'     => 'Poslapis „[[:$1]]“ pašalėnts ėš Tomstas stebėmūju sōraša.',
@@ -1024,10 +1020,10 @@
 'sessionfailure'              => 'Atruod kū īr biedū so Tamstas prėsėjongėma sesėjė; šėts veiksmos bova atšaukts kāp atsargoma prėimonė priš sesėjės vuogėma.
 Prašoum paspaustė „atgal“ ėr parkrautė poslapi ėš katruo atiejot, ė pamieginkėt vielē.',
 'protectlogpage'              => 'Rakinėmu istuorėjė',
-'protectlogtext'              => 'Žemiau īr poslapė ožrakinėmu teipuogi atrakinėmu istuorėjė. Daba veikiantiu poslapiu apsaugū sōraša sorasit [[Special:Protectedpages|apsauguotu poslapiu sōrašuo]].',
-'protectedarticle'            => 'ožrakina „[[$1]]“',
-'modifiedarticleprotection'   => 'pakeists „[[$1]]“ apsauguos līgis',
-'unprotectedarticle'          => 'atrakėna „[[$1]]“',
+'protectlogtext'              => 'Žemiau īr poslapė ožrakinėmu teipuogi atrakinėmu istuorėjė. Daba veikiantiu poslapiu apsaugū sōraša sorasit [[Special:ProtectedPages|apsauguotu poslapiu sōrašuo]].',
+'protectedarticle'            => 'ožrakina „[[:$1]]“',
+'modifiedarticleprotection'   => 'pakeists „[[:$1]]“ apsauguos līgis',
+'unprotectedarticle'          => 'atrakėna „[[:$1]]“',
 'protectcomment'              => 'Kuomentars:',
 'protectexpiry'               => 'Beng galiuotė:',
 'protect_expiry_invalid'      => 'Galiuojėma čiesos īr nateisėngs.',
@@ -1157,7 +1153,7 @@
 'ipbotherreason'              => 'Kėta/papėlduoma prižastis',
 'blockipsuccesssub'           => 'Ožblokavėms pavīka',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] bova ožblokouts.
-<br />Aplonkīkėt [[Special:Ipblocklist|IP blokavėmu istuorėjė]] noriedamė ana parveizėtė.',
+<br />Aplonkīkėt [[Special:IPBlockList|IP blokavėmu istuorėjė]] noriedamė ana parveizėtė.',
 'ipb-unblock-addr'            => 'Atblokoutė $1',
 'ipb-unblock'                 => 'Atblokoutė nauduotuojė varda a IP adresa',
 'ipb-blocklist-addr'          => 'Ruodītė esontius $1 bluokavėmus',
@@ -1182,7 +1178,7 @@
 'autoblocker'                 => 'Autuomatėnis ožbluokavėms, nes dalėnaties IP adreso so nauduotuojo "$1". Prīžastės - "$2".',
 'blocklogpage'                => 'Ožblokavėmu istuorėjė',
 'blocklogentry'               => 'ožblokava „[[$1]]“, blokavėma čiesos - $2 $3',
-'blocklogtext'                => 'Čė īr nauduotuoju blokavėma ėr atblokavėma sārašos. Autuomatėškā blokoutė IP adresā nier ėšvardėntė. Jeigu nuorėt paveizėtė nūnā blokoujamus adresus, veizėkėt [[Special:Ipblocklist|IP ožbluokavėmu istuorėjė]].',
+'blocklogtext'                => 'Čė īr nauduotuoju blokavėma ėr atblokavėma sārašos. Autuomatėškā blokoutė IP adresā nier ėšvardėntė. Jeigu nuorėt paveizėtė nūnā blokoujamus adresus, veizėkėt [[Special:IPBlockList|IP ožbluokavėmu istuorėjė]].',
 'unblocklogentry'             => 'atbluokava $1',
 'block-log-flags-anononly'    => 'vėn anonėmėnē nauduotuojē',
 'block-log-flags-nocreate'    => 'privėlėju kūrėms ėšjungts',
@@ -1217,8 +1213,6 @@
 *Paliksėt žemiau asontė varnale nepažīmieta.
 Šėtās atviejās Tamsta sava nužiūra torėt parkeltė a apjongtė aptarėma poslapi.",
 'movearticle'             => 'Parvadintė poslapi:',
-'movenologin'             => 'Neprisėjongės',
-'movenologintext'         => 'Nuoriedamė parvadintė poslapi, torėt būtė ožsėregėstravės nauduotuos ė teipuogi būtė [[Special:Userlogin|prisėjongės]].',
 'newtitle'                => 'Naus pavadėnėms:',
 'move-watch'              => 'Keravuotė šėta poslapi',
 'movepagebtn'             => 'Parvadintė poslapė',
@@ -1231,7 +1225,7 @@
 Prašuom sojongtė šėtuos poslapios.'''",
 'movedto'                 => 'parvadints i',
 'movetalk'                => 'Parkeltė sosėta aptarėma poslapi.',
-'1movedto2'               => 'Straipsnis [[$1]] parvadints i [[$2]]',
+'1movedto2'               => 'Straipsnis [[:$1]] parvadints i [[:$2]]',
 '1movedto2_redir'         => "'$1' parvadints i '$2' (onkstiau bova nukrēpamāsis)",
 'movelogpage'             => 'Parvardinėmu istuorėjė',
 'movelogpagetext'         => 'Sārašos parvadintu poslapiu.',
@@ -1239,7 +1233,7 @@
 'revertmove'              => 'atmestė',
 'delete_and_move'         => 'Ėštrintė ė parkeltė',
 'delete_and_move_text'    => '==Rēkalings ėštrīnims==
-Paskėrties straipsnis „[[$1]]“ jau īr. A nuorėt ana ėštrintė, kū galietomiet parvadintė?',
+Paskėrties straipsnis „[[:$1]]“ jau īr. A nuorėt ana ėštrintė, kū galietomiet parvadintė?',
 'delete_and_move_confirm' => 'Tēp, trintė poslapi',
 'delete_and_move_reason'  => 'Ėštrinta diel parkielima',
 
@@ -1375,7 +1369,7 @@
 'show-big-image'       => 'Pėlns ėšraiškėms',
 'show-big-image-thumb' => '<small>Šėtuos parvaizos dėdums: $1 × $2 puškiu</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Naujausiu abruozdieliu galerėjė',
 'imagelisttext'         => "Žemiau īr '''$1''' failu sārašos, sorūšiouts $2.",
 'showhidebots'          => '($1 robotos)',
@@ -1433,7 +1427,7 @@
 
 # External editor support
 'edit-externally'      => 'Atdarītė ėšuoriniam redaktuorio',
-'edit-externally-help' => 'Nuoriedamė gautė daugiau infuormacėjės, veiziekėt [http://meta.wikimedia.org/wiki/Help:External_editors kruovėma instrokcėjės].',
+'edit-externally-help' => 'Nuoriedamė gautė daugiau infuormacėjės, veiziekėt [http://www.mediawiki.org/wiki/Manual:External_editors kruovėma instrokcėjės].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'vėsos',
@@ -1453,7 +1447,7 @@
 'recreate'            => 'Atkortė',
 
 # HTML dump
-'redirectingto' => 'Paradresounama i [[$1]]...',
+'redirectingto' => 'Paradresounama i [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Tink',
@@ -1482,7 +1476,7 @@
 # Auto-summaries
 'autosumm-blank'   => 'Šalėnams ciels straipsnė torėnīs',
 'autosumm-replace' => "Poslapis keitams so '$1'",
-'autoredircomment' => 'Nukreipama i [[$1]]',
+'autoredircomment' => 'Nukreipama i [[:$1]]',
 'autosumm-new'     => 'Naus poslapis: $1',
 
 # Live preview
@@ -1519,7 +1513,7 @@
 # Special:Version
 'version' => 'Versėjė', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'Faila maršrots',
 
 # Special:SpecialPages
Index: languages/messages/MessagesIt.php
===================================================================
--- languages/messages/MessagesIt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,28 +4,26 @@
  * @ingroup Language
  * @file
  *
+ * @author .anaconda
+ * @author Broc
  * @author BrokenArrow
+ * @author Candalua
+ * @author Cruccone
+ * @author Cryptex
  * @author Darth Kule
- * @author Cruccone
+ * @author Felis
+ * @author Gianfranco
+ * @author Martorell
  * @author Melos
- * @author Siebrand
- * @author Gianfranco
- * @author Felis
  * @author Nemo bis
- * @author לערי ריינהארט
- * @author Broc
+ * @author Nick1915
+ * @author Pietrodn
  * @author Ramac
- * @author .anaconda
- * @author Xpensive
  * @author S.Örvarr.S
- * @author Nick1915
- * @author SPQRobin
+ * @author SabineCretella
  * @author Tonyfroio
- * @author Pietrodn
- * @author Martorell
- * @author SabineCretella
- * @author Cryptex
- * @author Candalua
+ * @author Xpensive
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -141,10 +139,10 @@
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Sottolinea i collegamenti',
-'tog-highlightbroken'         => 'Formatta <a href="" class="new">così</a> i collegamenti a pagine inesistenti (se disattivato: così<a href="" class="internal">?</a>).',
+'tog-highlightbroken'         => 'Evidenzia <a href="" class="new">così</a> i collegamenti a pagine inesistenti (se disattivato: così<a href="" class="internal">?</a>).',
 'tog-justify'                 => 'Allineamento dei paragrafi giustificato',
 'tog-hideminor'               => 'Nascondi le modifiche minori nelle ultime modifiche',
-'tog-extendwatchlist'         => 'Espandi la funzione osservati speciali mostrando tutte le modifiche applicabili',
+'tog-extendwatchlist'         => "Mostra tutte le modifiche agli osservati speciali, non solo l'ultima",
 'tog-usenewrc'                => 'Ultime modifiche avanzate (richiede JavaScript)',
 'tog-numberheadings'          => 'Numerazione automatica dei titoli di sezione',
 'tog-showtoolbar'             => 'Mostra barra degli strumenti di modifica (richiede JavaScript)',
@@ -152,14 +150,14 @@
 'tog-editsection'             => 'Modifica delle sezioni tramite il collegamento [modifica]',
 'tog-editsectiononrightclick' => 'Modifica delle sezioni tramite clic destro sul titolo (richiede JavaScript)',
 'tog-showtoc'                 => "Mostra l'indice per le pagine con più di 3 sezioni",
-'tog-rememberpassword'        => 'Ricorda la password (richiede di accettare i cookie)',
+'tog-rememberpassword'        => 'Ricorda la password su questo computer (richiede di accettare i cookie)',
 'tog-editwidth'               => 'Aumenta al massimo la larghezza della casella di modifica',
 'tog-watchcreations'          => 'Aggiungi le pagine create agli osservati speciali',
 'tog-watchdefault'            => 'Aggiungi le pagine modificate agli osservati speciali',
 'tog-watchmoves'              => 'Aggiungi le pagine spostate agli osservati speciali',
 'tog-watchdeletion'           => 'Aggiungi le pagine cancellate agli osservati speciali',
-'tog-minordefault'            => "Indica per default tutte le modifiche come 'minori'",
-'tog-previewontop'            => "Mostra l'anteprima sopra la casella di modifica",
+'tog-minordefault'            => 'Indica ogni modifica come minore (solo come predefinito)',
+'tog-previewontop'            => "Mostra l'anteprima sopra la casella di modifica e non sotto",
 'tog-previewonfirst'          => "Mostra l'anteprima per la prima modifica",
 'tog-nocache'                 => "Disattiva la ''cache'' per le pagine",
 'tog-enotifwatchlistpages'    => 'Segnalami via e-mail le modifiche alle pagine osservate',
@@ -170,7 +168,7 @@
 'tog-fancysig'                => 'Non modificare il markup della firma (usare per firme non standard)',
 'tog-externaleditor'          => 'Usa per default un editor di testi esterno (solo per utenti esperti, ha bisogno di impostazioni speciali sul tuo computer)',
 'tog-externaldiff'            => 'Usa per default un programma di diff esterno (solo per utenti esperti, ha bisogno di impostazioni speciali sul tuo computer)',
-'tog-showjumplinks'           => "Attiva i collegamenti accessibili 'vai a'",
+'tog-showjumplinks'           => 'Attiva i collegamenti accessibili "vai a"',
 'tog-uselivepreview'          => "Attiva la funzione ''Live preview'' (richiede JavaScript; sperimentale)",
 'tog-forceeditsummary'        => "Chiedi conferma se l'oggetto della modifica è vuoto",
 'tog-watchlisthideown'        => 'Nascondi le mie modifiche negli osservati speciali',
@@ -278,7 +276,7 @@
 'qbspecialpages' => 'Pagine speciali',
 'moredotdotdot'  => 'Altro...',
 'mypage'         => 'La mia pagina',
-'mytalk'         => 'Le mie discussioni',
+'mytalk'         => 'mie discussioni',
 'anontalk'       => 'Discussioni per questo IP',
 'navigation'     => 'Navigazione',
 'and'            => 'e',
@@ -332,8 +330,8 @@
 'categorypage'      => 'Visualizza la categoria',
 'viewtalkpage'      => 'Visualizza la pagina di discussione',
 'otherlanguages'    => 'Altre lingue',
-'redirectedfrom'    => '(Redirect da $1)',
-'redirectpagesub'   => 'Pagina di redirect',
+'redirectedfrom'    => '(Reindirizzamento da <b>$1</b>)',
+'redirectpagesub'   => 'Pagina di reindirizzamento',
 'lastmodifiedat'    => 'Ultima modifica per la pagina: $2, $1.', # $1 date, $2 time
 'viewcount'         => 'Questa pagina è stata letta {{PLURAL:$1|una volta|$1 volte}}.',
 'protectedpage'     => 'Pagina bloccata',
@@ -405,7 +403,7 @@
 'nstab-user'      => 'Utente',
 'nstab-media'     => 'File multimediale',
 'nstab-special'   => 'Speciale',
-'nstab-project'   => 'Pagina di servizio',
+'nstab-project'   => 'pagina di servizio',
 'nstab-image'     => 'Immagine',
 'nstab-mediawiki' => 'Messaggio',
 'nstab-template'  => 'Template',
@@ -416,7 +414,7 @@
 'nosuchaction'      => 'Operazione non riconosciuta',
 'nosuchactiontext'  => 'La URL immessa non corrisponde a un comando riconosciuto dal software MediaWiki',
 'nosuchspecialpage' => 'Pagina speciale non disponibile',
-'nospecialpagetext' => "La pagina speciale richiesta non è stata riconosciuta dal software MediaWiki; l'elenco delle pagine speciali valide si trova in [[Special:Specialpages|Elenco delle pagine speciali]].",
+'nospecialpagetext' => "La pagina speciale richiesta non è stata riconosciuta dal software MediaWiki; l'elenco delle pagine speciali valide si trova in [[Special:SpecialPages|Elenco delle pagine speciali]].",
 
 # General errors
 'error'                => 'Errore',
@@ -435,9 +433,9 @@
 'noconnect'            => 'Connessione al database non riuscita a causa di un problema tecnico del sito.<br />$1',
 'nodb'                 => 'Selezione del database $1 non riuscita',
 'cachederror'          => "Quella presentata di seguito è una copia ''cache'' della pagina richiesta; potrebbe quindi non essere aggiornata.",
-'laggedslavemode'      => 'Attenzione: La pagina potrebbe non riportare gli aggiornamenti più recenti.',
+'laggedslavemode'      => 'Attenzione: la pagina potrebbe non contenere gli ultimi aggiornamenti.',
 'readonly'             => 'Database bloccato',
-'enterlockreason'      => 'Indica il motivo del blocco, specificando il momento in cui è presumibile che venga rimosso.',
+'enterlockreason'      => 'Indica il motivo del blocco, specificando il momento in cui è presumibile che venga rimosso',
 'readonlytext'         => "In questo momento il database è bloccato e non sono possibili aggiunte o modifiche alle pagine. Il blocco è di solito legato a operazioni di manutenzione ordinaria, al termine delle quali il database è di nuovo accessibile.
 
 L'amministratore di sistema che ha imposto il blocco ha fornito questa spiegazione: $1",
@@ -446,7 +444,7 @@
 Di solito ciò si verifica quando viene richiamato, a partire dalla cronologia o dal confronto tra revisioni, un collegamento a una pagina cancellata, a un confronto tra revisioni inesistenti o a un confronto tra revisioni ripulite dalla cronologia.
 
 In caso contrario, si è probabilmente scoperto un errore del software MediaWiki.
-Si prega di segnalare l\'accaduto a un amministratore specificando la URL in questione.',
+Si prega di segnalare l\'accaduto a un [[Special:ListUsers/sysop|amministratore]] specificando la URL in questione.',
 'missingarticle-rev'   => '(numero della revisione: $1)',
 'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'Il database è stato bloccato automaticamente per consentire ai server con i database slave di sincronizzarsi con il master',
@@ -461,7 +459,7 @@
 'unexpected'           => 'Valore imprevisto: "$1"="$2".',
 'formerror'            => 'Errore: impossibile inviare il modulo',
 'badarticleerror'      => 'Operazione non consentita per questa pagina.',
-'cannotdelete'         => 'Impossibile cancellare la pagina o il file richiesto. (Potrebbe essere stato già cancellato.)',
+'cannotdelete'         => 'Impossibile cancellare la pagina o il file richiesto (potrebbe essere stato già cancellato).',
 'badtitle'             => 'Titolo non corretto',
 'badtitletext'         => 'Il titolo della pagina richiesta è vuoto, errato o con caratteri non ammessi oppure deriva da un errore nei collegamenti tra siti wiki diversi o versioni in lingue diverse dello stesso sito.',
 'perfdisabled'         => 'Siamo spiacenti, questa funzionalità è temporaneamente disabilitata perché il suo uso rallenta il database fino a rendere il sito inutilizzabile per tutti gli utenti.',
@@ -471,14 +469,15 @@
 'wrong_wfQuery_params' => 'Errore nei parametri inviati alla funzione wfQuery()<br />
 Funzione: $1<br />
 Query: $2',
-'viewsource'           => 'Vedi sorgente',
+'viewsource'           => 'Visualizza sorgente',
 'viewsourcefor'        => 'di $1',
 'actionthrottled'      => 'Azione ritardata',
 'actionthrottledtext'  => "Come misura di sicurezza contro lo spam, l'esecuzione di alcune azioni è limitata a un numero massimo di volte in un determinato periodo di tempo, limite che in questo caso è stato superato. Si prega di riprovare tra qualche minuto.",
 'protectedpagetext'    => 'Questa pagina è stata protetta per impedirne la modifica.',
 'viewsourcetext'       => 'È possibile visualizzare e copiare il codice sorgente di questa pagina:',
 'protectedinterface'   => "Questa pagina contiene un elemento che fa parte dell'interfaccia utente del software; è quindi protetta per evitare possibili abusi.",
-'editinginterface'     => "'''Attenzione:''' Il testo di questa pagina fa parte dell'interfaccia utente del sito. Tutte le modifiche apportate a questa pagina si riflettono sui messaggi visualizzati per tutti gli utenti.",
+'editinginterface'     => "'''Attenzione:''' Il testo di questa pagina fa parte dell'interfaccia utente del sito. Tutte le modifiche apportate a questa pagina si riflettono sui messaggi visualizzati per tutti gli utenti.
+Per le traduzioni, considera la possibilità di usare [http://translatewiki.net/wiki/Main_Page?setlang=it Betawiki], il progetto MediaWiki per la localizzazione.",
 'sqlhidden'            => '(la query SQL è stata nascosta)',
 'cascadeprotected'     => 'Su questa pagina non è possibile effettuare modifiche perché è stata inclusa {{PLURAL:$1|nella pagina indicata di seguito, che è stata protetta|nelle pagine indicate di seguito, che sono state protette}} selezionando la protezione "ricorsiva":
 $2',
@@ -506,14 +505,14 @@
 'yourname'                   => 'Nome utente',
 'yourpassword'               => 'Password',
 'yourpasswordagain'          => 'Ripeti la password',
-'remembermypassword'         => 'Ricorda la password',
+'remembermypassword'         => 'Ricorda la password su questo computer',
 'yourdomainname'             => 'Specificare il dominio',
 'externaldberror'            => 'Si è verificato un errore con il server di autenticazione esterno, oppure non si dispone delle autorizzazioni necessarie per aggiornare il proprio accesso esterno.',
 'loginproblem'               => "<b>Si è verificato un errore durante l'accesso.</b><br />Riprovare.",
 'login'                      => 'Entra',
 'nav-login-createaccount'    => 'Entra / Registrati',
 'loginprompt'                => 'Per accedere a {{SITENAME}} è necessario abilitare i cookie.',
-'userlogin'                  => 'Entra o crea un nuovo accesso',
+'userlogin'                  => 'Entra / Registrati',
 'logout'                     => 'Esci',
 'userlogout'                 => 'esci',
 'notloggedin'                => 'Accesso non effettuato',
@@ -526,11 +525,11 @@
 'badretype'                  => 'Le password inserite non coincidono tra loro.',
 'userexists'                 => 'Il nome utente inserito è già utilizzato. Si prega di scegliere un nome utente diverso.',
 'youremail'                  => 'Indirizzo e-mail:',
-'username'                   => 'Nome utente',
+'username'                   => 'Nome utente:',
 'uid'                        => 'ID utente:',
 'prefs-memberingroups'       => 'Membro {{PLURAL:$1|del gruppo|dei gruppi}}:',
 'yourrealname'               => 'Nome vero:',
-'yourlanguage'               => 'Lingua:',
+'yourlanguage'               => "Lingua dell'interfaccia:",
 'yourvariant'                => 'Variante:',
 'yournick'                   => 'Soprannome (nickname):',
 'badsig'                     => 'Errore nella firma non standard, verificare i tag HTML.',
@@ -538,21 +537,21 @@
 'email'                      => 'Indirizzo e-mail',
 'prefs-help-realname'        => "L'indicazione del proprio nome vero è opzionale; se si sceglie di inserirlo, verrà utilizzato per attribuire la paternità dei contenuti inviati.",
 'loginerror'                 => "Errore nell'accesso",
-'prefs-help-email'           => "¹L'inserimento del proprio indirizzo e-mail è opzionale. Se si sceglie di inserirlo, consente di essere contattati attraverso la propria pagina utente o la relativa pagina di discussione, senza dover rivelare la propria identità.",
+'prefs-help-email'           => "L'inserimento del proprio indirizzo e-mail è opzionale. Se si sceglie di inserirlo, consente di essere contattati attraverso la propria pagina utente o la relativa pagina di discussione, senza dover rivelare la propria identità.",
 'prefs-help-email-required'  => 'Indirizzo e-mail necessario.',
-'nocookiesnew'               => "Il nome utente per l'accesso è stato creato, ma non è stato possibile accedere a {{SITENAME}} perché i cookie sono disattivati. Riprovare l'accesso con il nome utente e la password appena creati dopo aver attivato i cookie nel proprio browser.",
+'nocookiesnew'               => "La registrazione è stata completata, ma non è stato possibile accedere a {{SITENAME}} perché i cookie sono disattivati. Riprovare l'accesso con il nome utente e la password appena creati dopo aver attivato i cookie nel proprio browser.",
 'nocookieslogin'             => "L'accesso a {{SITENAME}} richiede l'uso dei cookie, che risultano disattivati. Riprovare l'accesso dopo aver attivato i cookie nel proprio browser.",
-'noname'                     => 'Il nome utente indicato non è valido.',
+'noname'                     => 'Il nome utente indicato non è valido, non è possibile creare un accesso a questo nome.',
 'loginsuccesstitle'          => 'Accesso effettuato',
-'loginsuccess'               => "'''Il collegamento al server di {{SITENAME}} con il nome utente \"\$1\" è attivo.'''",
+'loginsuccess'               => "'''Sei stato connesso al server di {{SITENAME}} con il nome utente di \"\$1\".'''",
 'nosuchuser'                 => 'Non è registrato alcun utente di nome "$1". Verificare il nome inserito o creare un nuovo accesso.',
 'nosuchusershort'            => 'Non è registrato alcun utente di nome "<nowiki>$1</nowiki>". Verificare il nome inserito.',
 'nouserspecified'            => 'È necessario specificare un nome utente.',
 'wrongpassword'              => 'La password inserita non è corretta. Riprovare.',
-'wrongpasswordempty'         => 'La password inserita è vuota. Riprovare.',
+'wrongpasswordempty'         => 'Non è stata inserita alcuna password. Riprovare.',
 'passwordtooshort'           => 'La password inserita non è valida o è troppo breve. 
 Deve contenere almeno {{PLURAL:$1|1 carattere|$1 caratteri}} ed essere diversa dal tuo nome utente.',
-'mailmypassword'             => 'Invia password via e-mail',
+'mailmypassword'             => 'Invia una nuova password al mio indirizzo e-mail',
 'passwordremindertitle'      => 'Servizio Password Reminder di {{SITENAME}}',
 'passwordremindertext'       => 'Qualcuno (probabilmente tu, con indirizzo IP $1) ha richiesto l\'invio di una nuova password di accesso a {{SITENAME}} ($4).
 La password per l\'utente "$2" è stata impostata a "$3".
@@ -568,7 +567,7 @@
 'throttled-mailpassword'     => 'Una nuova password è già stata inviata da meno di {{PLURAL:$1|1 ora|$1 ore}}.
 Per prevenire abusi, la funzione "Invia nuova password" può essere usata solo una volta ogni {{PLURAL:$1|ora|$1 ore}}.',
 'mailerror'                  => "Errore nell'invio del messaggio: $1",
-'acct_creation_throttle_hit' => 'Siamo spiacenti, ma hai già creato $1 account. Non puoi crearne altri.',
+'acct_creation_throttle_hit' => 'Spiacente, hai già creato $1 account. Non puoi crearne altri.',
 'emailauthenticated'         => "L'indirizzo e-mail è stato confermato il $1.",
 'emailnotauthenticated'      => "L'indirizzo e-mail non è stato ancora confermato. Non verranno inviati messaggi e-mail attraverso le funzioni elencate di seguito.",
 'noemailprefs'               => 'Indicare un indirizzo e-mail per attivare queste funzioni.',
@@ -602,7 +601,7 @@
 'link_sample'     => 'Titolo del collegamento',
 'link_tip'        => 'Collegamento interno',
 'extlink_sample'  => 'http://www.example.com titolo del collegamento',
-'extlink_tip'     => 'Collegamento esterno (notare il prefisso http:// )',
+'extlink_tip'     => 'Collegamento esterno (ricorda il prefisso http:// )',
 'headline_sample' => 'Intestazione',
 'headline_tip'    => 'Intestazione di 2° livello',
 'math_sample'     => 'Inserire qui la formula',
@@ -627,7 +626,7 @@
 'showlivepreview'                  => "Funzione ''Live preview''",
 'showdiff'                         => 'Mostra cambiamenti',
 'anoneditwarning'                  => "'''Attenzione:''' Accesso non effettuato. Nella cronologia della pagina verrà registrato l'indirizzo IP.",
-'missingsummary'                   => "'''Attenzione:''' Non è stato specificato l'oggetto della modifica. Premendo di nuovo 'Salva la pagina' la modifica verrà salvata con l'oggetto vuoto.",
+'missingsummary'                   => "'''Attenzione:''' non è stato specificato l'oggetto di questa modifica. Premendo di nuovo '''Salva la pagina''' la modifica verrà salvata con l'oggetto vuoto.",
 'missingcommenttext'               => 'Inserire un commento qui sotto.',
 'missingcommentheader'             => "'''Attenzione:''' Non è stata specificata l'intestazione di questo commento. Premendo di nuovo '''Salva la pagina''' la modifica verrà salvata senza intestazione.",
 'summary-preview'                  => 'Anteprima oggetto',
@@ -643,9 +642,10 @@
 
 Se lo si desidera, è possibile contattare $1 o un altro [[{{MediaWiki:Grouppage-sysop}}|amministratore]] per discutere del blocco.
 
-Si noti che la funzione 'Scrivi all'utente' non è attiva se non è stato registrato un indirizzo e-mail valido nelle proprie [[Special:Preferences|preferenze]].
+Si noti che la funzione 'Scrivi all'utente' non è attiva se non è stato registrato un indirizzo e-mail valido nelle proprie [[Special:Preferences|preferenze]] e se si è stato bloccati dal suo utilizzo.
 
-Si prega di specificare l'indirizzo IP attuale ($3) o il numero del blocco (ID #$5) in qualsiasi richiesta di chiarimenti.",
+L'indirizzo IP attuale è $3, il numero ID del blocco è #$5.
+Si prega di specificare tutti i dettagli precedenti in qualsiasi richiesta di chiarimenti.",
 'autoblockedtext'                  => "Questo indirizzo IP è stato bloccato automaticamente perché condiviso con un altro utente, a sua volta bloccato da $1.
 La motivazione del blocco è la seguente:
 
@@ -653,21 +653,19 @@
 
 * Inizio del blocco: $8
 * Scadenza del blocco: $6
+* Intervallo di blocco: $7
 
 È possibile contattare $1 o un altro [[{{MediaWiki:Grouppage-sysop}}|amministratore]] per discutere del blocco.
 
-Si noti che la funzione 'Scrivi all'utente' non è attiva se non è stato registrato un indirizzo e-mail valido nelle proprie [[Special:Preferences|preferenze]].
+Si noti che la funzione 'Scrivi all'utente' non è attiva se non è stato registrato un indirizzo e-mail valido nelle proprie [[Special:Preferences|preferenze]] e se si è stato bloccati dal suo utilizzo.
 
-Si prega di specificare il numero del blocco (ID #$5) in qualsiasi richiesta di chiarimenti.",
+L'indirizzo IP attuale è $3, il numero ID del blocco è #$5
+Si prega di specificare tutti i dettagli precedenti in qualsiasi richiesta di chiarimenti.",
 'blockednoreason'                  => 'nessuna motivazione indicata',
 'blockedoriginalsource'            => "Di seguito viene mostrato il codice sorgente della pagina '''$1''':",
 'blockededitsource'                => "Di seguito vengono mostrate le '''modifiche apportate''' alla pagina '''$1''':",
 'whitelistedittitle'               => 'Accesso necessario per la modifica delle pagine',
 'whitelistedittext'                => 'Per modificare le pagine è necessario $1.',
-'whitelistreadtitle'               => 'Accesso necessario per la lettura delle pagine',
-'whitelistreadtext'                => "Per essere abilitato alla lettura delle pagine è necessario [[Special:Userlogin|eseguire l'accesso]].",
-'whitelistacctitle'                => 'Creazione di un nuovo accesso non consentita',
-'whitelistacctext'                 => "Per essere abilitati alla creazione di nuovi accessi su questo sito è necessario [[Special:Userlogin|effettuare l'accesso]] ed aver ricevuto le opportune autorizzazioni.",
 'confirmedittitle'                 => 'Conferma della e-mail necessaria per la modifica delle pagine',
 'confirmedittext'                  => "Per essere abilitati alla modifica delle pagine è necessario confermare il proprio indirizzo e-mail. Per impostare e confermare l'indirizzo servirsi delle [[Special:Preferences|preferenze]].",
 'nosuchsectiontitle'               => 'La sezione non esiste',
@@ -682,7 +680,7 @@
 Se si desidera creare la pagina ora, basta cominciare a scrivere il testo nella casella qui sotto
 (fare riferimento alle [[{{MediaWiki:Helppage}}|pagine di aiuto]] per maggiori informazioni).
 Se il collegamento è stato seguito per errore, è sufficiente fare clic sul pulsante '''Indietro''' del proprio browser.",
-'anontalkpagetext'                 => "----''Questa è la pagina di discussione di un utente anonimo, che non ha ancora creato un accesso o comunque non lo usa. Per identificarlo è quindi necessario usare il numero del suo indirizzo IP. Gli indirizzi IP possono però essere condivisi da più utenti. Se sei un utente anonimo e ritieni che i commenti presenti in questa pagina non si riferiscano a te, [[Special:Userlogin|crea un nuovo accesso o entra]] con quello che già hai per evitare di essere confuso con altri utenti anonimi in futuro''",
+'anontalkpagetext'                 => "----''Questa è la pagina di discussione di un utente anonimo, che non ha ancora creato un accesso o comunque non lo usa. Per identificarlo è quindi necessario usare il numero del suo indirizzo IP. Gli indirizzi IP possono però essere condivisi da più utenti. Se sei un utente anonimo e ritieni che i commenti presenti in questa pagina non si riferiscano a te, [[Special:UserLogin|crea un nuovo accesso o entra]] con quello che già hai per evitare di essere confuso con altri utenti anonimi in futuro''",
 'noarticletext'                    => 'In questo momento la pagina richiesta è vuota. È possibile [[Special:Search/{{PAGENAME}}|cercare questo titolo]] nelle altre pagine del sito oppure [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificare la pagina ora].',
 'userpage-userdoesnotexist'        => 'L\'account "$1" non corrisponde a un utente registrato. Verificare che si intenda davvero creare o modificare questa pagina.',
 'clearyourcache'                   => "'''Nota: dopo aver salvato è necessario pulire la cache del proprio browser per vedere i cambiamenti.''' Per '''Mozilla / Firefox / Safari''': fare clic su ''Ricarica'' tenendo premuto il tasto delle maiuscole, oppure premere ''Ctrl-F5'' o ''Ctrl-R'' (''Command-R'' su Mac); per '''Konqueror''': premere il pulsante ''Ricarica'' o il tasto ''F5''; per '''Opera''' può essere necessario svuotare completamente la cache dal menu ''Strumenti → Preferenze''; per '''Internet Explorer:''' mantenere premuto il tasto ''Ctrl'' mentre si preme il pulsante ''Aggiorna'' o premere ''Ctrl-F5''.",
@@ -693,7 +691,7 @@
 'updated'                          => '(Aggiornato)',
 'note'                             => '<strong>NOTA:</strong>',
 'previewnote'                      => '<strong>Questa è solo una anteprima; le modifiche alla pagina NON sono ancora state salvate!</strong>',
-'previewconflict'                  => "L'anteprima corrisponde al testo presente nella casella di modifica superiore e rappresenta la pagina come apparirà se si sceglie di premere 'Salva la pagina' in questo momento.",
+'previewconflict'                  => 'L\'anteprima corrisponde al testo presente nella casella di modifica superiore e rappresenta la pagina come apparirà se si sceglie di premere "Salva la pagina" in questo momento.',
 'session_fail_preview'             => '<strong>Siamo spiacenti, non è stato possibile elaborare la modifica perché sono andati persi i dati relativi alla sessione. Se il problema persiste, si può provare a scollegarsi ed effettuare un nuovo accesso.</strong>',
 'session_fail_preview_html'        => "<strong>Siamo spiacenti, non è stato possibile elaborare la modifica perché sono andati persi i dati relativi alla sessione.</strong>
 
@@ -710,7 +708,7 @@
 Premendo il pulsante 'Salva la pagina', verrà salvato <b>solo</b> il testo contenuto nella casella di modifica superiore.<br />",
 'yourtext'                         => 'Il tuo testo',
 'storedversion'                    => 'La versione memorizzata',
-'nonunicodebrowser'                => '<strong>Attenzione: Si sta utilizzando un browser non compatibile con i caratteri Unicode. Per consentire la modifica delle pagine senza creare inconvenienti, i caratteri non ASCII vengono visualizzati nella casella di modifica sotto forma di codici esadecimali.</strong>',
+'nonunicodebrowser'                => '<strong>Attenzione: si sta utilizzando un browser non compatibile con i caratteri Unicode. Per consentire la modifica delle pagine senza creare inconvenienti, i caratteri non ASCII vengono visualizzati nella casella di modifica sotto forma di codici esadecimali.</strong>',
 'editingold'                       => '<strong>Attenzione: si sta modificando una versione non aggiornata della pagina.<br />
 Se si sceglie di salvarla, tutti i cambiamenti apportati dopo questa revisione andranno perduti.</strong>',
 'yourdiff'                         => 'Differenze',
@@ -735,7 +733,7 @@
 'hiddencategories'                 => 'Questa pagina appartiene a {{PLURAL:$1|una categoria nascosta|$1 categorie nascoste}}:',
 'edittools'                        => '<!-- Testo che appare al di sotto del modulo di modifica e di upload. -->',
 'nocreatetitle'                    => 'Creazione delle pagine limitata',
-'nocreatetext'                     => 'La possibilità di creare nuove pagine su {{SITENAME}} è stata limitata ai soli utenti registrati. È possibile tornare indietro e modificare una pagina esistente, oppure [[Special:Userlogin|entrare o creare un nuovo accesso]].',
+'nocreatetext'                     => 'La possibilità di creare nuove pagine su {{SITENAME}} è stata limitata ai soli utenti registrati. È possibile tornare indietro e modificare una pagina esistente, oppure [[Special:UserLogin|entrare o registrarsi]].',
 'nocreate-loggedin'                => 'Non si dispone dei permessi necessari a creare nuove pagine su {{SITENAME}}.',
 'permissionserrors'                => 'Errore nei permessi',
 'permissionserrorstext'            => "Non si dispone dei permessi necessari ad eseguire l'azione richiesta, per {{PLURAL:$1|il seguente motivo|i seguenti motivi}}:",
@@ -760,7 +758,7 @@
 'undo-success' => 'Questa modifica può essere annullata. Verificare il confronto presentato di seguito per accertarsi che il contenuto corrisponda a quanto desiderato e quindi salvare le modifiche per completare la procedura di annullamento.',
 'undo-failure' => 'Impossibile annullare la modifica a causa di un conflitto con modifiche intermedie.',
 'undo-norev'   => 'La modifica non può essere annullata perché non esiste o è stata cancellata.',
-'undo-summary' => 'Annullata la modifica $1 di [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussione]])',
+'undo-summary' => 'Annullata la modifica $1 di [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussione]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Impossibile registrare un utente',
@@ -852,7 +850,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Log delle soppressioni',
-'suppressionlogtext' => "Di seguito viene presentato un elenco delle cancellazioni e dei blocchi più recenti riguardanti contenuti nascosti agli amministratori. Vedi l'[[Special:Ipblocklist|elenco degli IP bloccati]] per l'elenco dei ban e dei blocchi attivi al momento.",
+'suppressionlogtext' => "Di seguito sono elencate le cancellazioni e i blocchi più recenti riguardanti contenuti nascosti agli amministratori. Vedi l'[[Special:IPBlockList|elenco degli IP bloccati]] per l'elenco dei blocchi attivi al momento.",
 
 # History merging
 'mergehistory'                     => 'Unione cronologie',
@@ -876,10 +874,10 @@
 'mergehistory-comment'             => 'Unione di [[:$1]] in [[:$2]]: $3',
 
 # Merge log
-'mergelog'           => 'Log delle unioni',
+'mergelog'           => 'Unioni',
 'pagemerge-logentry' => 'ha unito [[$1]] a [[$2]] (revisioni fino a $3)',
 'revertmerge'        => 'Annulla unioni',
-'mergelogpagetext'   => "Qui di seguito viene presentata una lista delle ultime operazioni di unione della cronologia di una pagina in un'altra.",
+'mergelogpagetext'   => 'Di seguito sono elencate le ultime operazioni di unione della cronologia di due pagine.',
 
 # Diffs
 'history-title'           => 'Cronologia delle modifiche di "$1"',
@@ -932,10 +930,10 @@
 
 # Preferences page
 'preferences'              => 'Preferenze',
-'mypreferences'            => 'le mie preferenze',
+'mypreferences'            => 'preferenze',
 'prefs-edits'              => 'Modifiche effettuate:',
 'prefsnologin'             => 'Accesso non effettuato',
-'prefsnologintext'         => "Per poter personalizzare le preferenze è necessario effettuare l'[[Special:Userlogin|accesso]].",
+'prefsnologintext'         => "Per poter personalizzare le preferenze è necessario effettuare l'[[Special:UserLogin|accesso]].",
 'prefsreset'               => 'Le preferenze sono state ripristinate ai valori predefiniti.',
 'qbsettings'               => 'Quickbar',
 'qbsettings-none'          => 'Nessuno',
@@ -989,7 +987,7 @@
 'allowemail'               => 'Abilita la ricezione di email da altri utenti¹',
 'prefs-searchoptions'      => 'Opzioni di ricerca',
 'prefs-namespaces'         => 'Namespace',
-'defaultns'                => 'Namespace predefiniti per la ricerca:',
+'defaultns'                => 'Cerca in questi namespace se non diversamente specificato:',
 'default'                  => 'predefinito',
 'files'                    => 'File',
 
@@ -1009,20 +1007,20 @@
 'userrights-reason'           => 'Motivo della modifica:',
 'userrights-no-interwiki'     => 'Non si dispone dei permessi necessari per modificare i diritti degli utenti su altri siti.',
 'userrights-nodatabase'       => 'Il database $1 non esiste o non è un database locale.',
-'userrights-nologin'          => "Per assegnare diritti agli utenti è necessario [[Special:Userlogin|effettuare l'accesso]] come amministratore.",
+'userrights-nologin'          => "Per assegnare diritti agli utenti è necessario [[Special:UserLogin|effettuare l'accesso]] come amministratore.",
 'userrights-notallowed'       => "L'utente non dispone dei permessi necessari per assegnare diritti agli utenti.",
 'userrights-changeable-col'   => 'Gruppi modificabili',
 'userrights-unchangeable-col' => 'Gruppi non modificabili',
 
 # Groups
 'group'               => 'Gruppo:',
-'group-user'          => 'Utenti',
+'group-user'          => 'Utenti registrati',
 'group-autoconfirmed' => 'Utenti autoconvalidati',
 'group-bot'           => 'Bot',
 'group-sysop'         => 'Amministratori',
 'group-bureaucrat'    => 'Burocrati',
 'group-suppress'      => 'Oversight',
-'group-all'           => '(utenti)',
+'group-all'           => 'Utenti',
 
 'group-user-member'          => 'Utente',
 'group-autoconfirmed-member' => 'Utente autoconvalidato',
@@ -1093,7 +1091,7 @@
 
 # User rights log
 'rightslog'      => 'Diritti degli utenti',
-'rightslogtext'  => 'Questo è il log delle modifiche ai diritti assegnati agli utenti.',
+'rightslogtext'  => 'Di seguito sono elencate le modifiche ai diritti assegnati agli utenti.',
 'rightslogentry' => "ha modificato l'appartenenza di $1 dal gruppo $2 al gruppo $3",
 'rightsnone'     => '(nessuno)',
 
@@ -1138,31 +1136,30 @@
 'reupload'                    => 'Carica di nuovo',
 'reuploaddesc'                => 'Torna al modulo per il caricamento.',
 'uploadnologin'               => 'Accesso non effettuato',
-'uploadnologintext'           => "Il caricamento dei file è consentito solo agli utenti registrati che hanno eseguito [[Special:Userlogin|l'accesso]] al sito.",
+'uploadnologintext'           => "Il caricamento dei file è consentito solo agli utenti registrati che hanno eseguito [[Special:UserLogin|l'accesso]] al sito.",
 'upload_directory_missing'    => 'La directory di upload ($1) non esiste e non può essere creata dal webserver.',
 'upload_directory_read_only'  => 'Il server web non è in grado di scrivere nella directory di upload ($1).',
 'uploaderror'                 => 'Errore nel caricamento',
-'uploadtext'                  => "Usare il modulo sottostante per caricare nuovi file. Per visualizzare o ricercare i file già caricati, consultare il [[Special:Imagelist|log dei file caricati]]. Caricamenti e cancellazioni di file sono registrati nel [[Special:Log/upload|log degli upload]].
+'uploadtext'                  => "Usare il modulo sottostante per caricare nuovi file. Per visualizzare o ricercare i file già caricati, consultare il [[Special:ImageList|log dei file caricati]]. Caricamenti di file e di nuove versioni di file sono registrati nel [[Special:Log/upload|log degli upload]], le cancellazioni nell'[[Special:Log/delete|apposito]].
 
 Per inserire un file all'interno di una pagina, fare un collegamento di questo tipo:
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|testo alternativo]]</nowiki>'''
-usare invece
-* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>'''
-per generare un collegamento diretto al file.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' per usare la versione intera del file
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|testo alternativo]]</nowiki></tt>''' per usare una versione larga 200 pixel inserita in un box, allineata a sinistra e con 'testo alternativo' come didascalia
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' per generare un collegamento diretto al file senza visualizzarlo",
 'upload-permitted'            => 'Tipi di file consentiti: $1.',
 'upload-preferred'            => 'Tipi di file consigliati: $1.',
 'upload-prohibited'           => 'Tipi di file non consentiti: $1.',
 'uploadlog'                   => 'File caricati',
-'uploadlogpage'               => 'Log dei file caricati',
-'uploadlogpagetext'           => 'Elenco degli ultimi file caricati sul server di {{SITENAME}}.',
+'uploadlogpage'               => 'File caricati',
+'uploadlogpagetext'           => "Di seguito sono elencati gli ultimi file caricati.
+Guarda la [[Special:NewImages|galleria dei nuovi file]] per una visione d'insieme",
 'filename'                    => 'Nome del file',
 'filedesc'                    => 'Dettagli',
 'fileuploadsummary'           => 'Dettagli del file:',
 'filestatus'                  => 'Informazioni sul copyright:',
 'filesource'                  => 'Fonte:',
 'uploadedfiles'               => 'Elenco dei file caricati',
-'ignorewarning'               => "Ignora l'avvertimento e salva comunque il file.",
+'ignorewarning'               => "Ignora l'avviso e salva comunque il file. La versione esistente verrà sovrascritta.",
 'ignorewarnings'              => 'Ignora i messaggi di avvertimento del sistema',
 'minlength1'                  => "Il nome del file dev'essere composto da almeno un carattere.",
 'illegalfilename'             => 'Il nome "$1" contiene dei caratteri non ammessi nei titoli delle pagine. Dare al file un nome diverso e provare a caricarlo di nuovo.',
@@ -1202,7 +1199,7 @@
 'destfilename'                => 'Nome del file di destinazione:',
 'upload-maxfilesize'          => 'Dimensione massima del file: $1',
 'watchthisupload'             => 'Aggiungi agli osservati speciali',
-'filewasdeleted'              => 'Un file con questo nome è stato già caricato e cancellato in passato. Verificare $1 prima di caricarlo di nuovo.',
+'filewasdeleted'              => 'Un file con questo nome è stato già caricato e cancellato in passato. Verificare il log delle $1 prima di caricarlo di nuovo.',
 'upload-wasdeleted'           => "'''Attenzione: stai caricando un file che in precedenza è stato cancellato.'''
 
 Verifica per favore l'opportunità di continuare con il caricamento di questo file.
@@ -1242,7 +1239,7 @@
 'upload_source_url'  => ' (una URL corretta e accessibile)',
 'upload_source_file' => ' (un file sul proprio computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Questa pagina speciale mostra tutti i file caricati.
 I file caricati più di recente vengono mostrati all'inizio della lista.
 Per modificare l'ordinamento, fare clic sull'intestazione della colonna prescelta.",
@@ -1270,7 +1267,7 @@
 'imagelinks'                     => "Collegamenti all'immagine",
 'linkstoimage'                   => "{{PLURAL:$1|La seguente pagina contiene|Le seguenti $1 pagine contengono}} collegamenti all'immagine:",
 'nolinkstoimage'                 => "Nessuna pagina contiene collegamenti all'immagine.",
-'morelinkstoimage'               => 'Visualizza [[Special:Whatlinkshere/$1|altri link]] a questo file.',
+'morelinkstoimage'               => 'Visualizza [[Special:WhatLinksHere/$1|altri link]] a questo file.',
 'redirectstofile'                => '{{PLURAL:$1|Il seguente|I seguenti $1}} file {{PLURAL:$1|è|sono}} un redirect a questo file:',
 'duplicatesoffile'               => '{{PLURAL:$1|Il seguente|I seguenti $1}} file {{PLURAL:$1|è un duplicato|sono duplicati}} di questo file:',
 'sharedupload'                   => 'Questo file è un upload condiviso; può essere quindi utilizzato da più progetti wiki.',
@@ -1289,19 +1286,19 @@
 # File reversion
 'filerevert'                => 'Ripristina $1',
 'filerevert-legend'         => 'Ripristina file',
-'filerevert-intro'          => '<span class="plainlinks">Si sta per ripristinare il file \'\'\'[[Media:$1|$1]]\'\'\' alla [versione $4 del $2, $3].</span>',
+'filerevert-intro'          => "Si sta per ripristinare il file '''[[Media:$1|$1]]''' alla [$4 versione del $2, $3].",
 'filerevert-comment'        => 'Oggetto:',
 'filerevert-defaultcomment' => 'Ripristinata la versione del $2, $1',
 'filerevert-submit'         => 'Ripristina',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'Il file [[Media:$1|$1]]\'\'\' è stato ripristinato alla [$4 versione del $2, $3].</span>',
+'filerevert-success'        => "'''Il file [[Media:$1|$1]]''' è stato ripristinato alla [$4 versione del $2, $3].",
 'filerevert-badversion'     => 'Non esistono versioni locali precedenti del file con il timestamp richiesto.',
 
 # File deletion
 'filedelete'                  => 'Cancella $1',
 'filedelete-legend'           => 'Cancella il file',
 'filedelete-intro'            => "Stai per cancellare '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Stai cancellando la versione di \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $3, $2].</span>',
-'filedelete-comment'          => 'Motivazione:',
+'filedelete-intro-old'        => "Stai cancellando la versione di '''[[Media:$1|$1]]''' del [$4 $2, $3].",
+'filedelete-comment'          => 'Motivo della cancellazione:',
 'filedelete-submit'           => 'Cancella',
 'filedelete-success'          => "Il file '''$1''' è stato cancellato.",
 'filedelete-success-old'      => '<span class="plainlinks">La versione del $3, $2 del file \'\'\'[[Media:$1|$1]]\'\'\' è stata cancellata.</span>',
@@ -1325,7 +1322,7 @@
 'unwatchedpages' => 'Pagine non osservate',
 
 # List redirects
-'listredirects' => 'Elenco dei redirect',
+'listredirects' => 'Elenco di tutti i redirect',
 
 # Unused templates
 'unusedtemplates'     => 'Template non utilizzati',
@@ -1345,13 +1342,13 @@
 'sitestats'              => 'Statistiche relative a {{SITENAME}}',
 'userstats'              => 'Statistiche relative agli utenti',
 'sitestatstext'          => "Il database contiene complessivamente '''\$1''' {{PLURAL:\$1|pagina|pagine}}.
-Questa cifra comprende anche le pagine di discussione, quelle di servizio di {{SITENAME}}, le voci più esigue (\"stub\"), i redirect e altre pagine che probabilmente non vanno considerate tra i contenuti del sito. Escludendo le pagine sopra descritte, ve ne sono '''\$2''' di contenuti veri e propri.
+Questa cifra comprende anche le pagine di discussione, quelle di servizio di {{SITENAME}}, le voci più esigue (\"stub\"), i redirect e altre pagine che probabilmente non vanno considerate tra i contenuti del sito. Escludendo le pagine sopra descritte, ve ne {{PLURAL:\$2|è '''1'''|sono '''\$2'''}} di contenuti veri e propri.
 
 {{PLURAL:\$8|È stato inoltre caricato|Sono stati inoltre caricati}} '''\$8''' file.
 
 Dall'installazione del sito sino a questo momento {{PLURAL:\$3|è stata visitata '''1''' pagina|sono state visitate '''\$3''' pagine}} ed {{PLURAL:\$4|eseguita '''1''' modifica|eseguite '''\$4''' modifiche}}, pari a una media di '''\$5''' modifiche per pagina e '''\$6''' richieste di lettura per ciascuna modifica.
 
-La coda dei processi da eseguire in background contiene {{PLURAL:\$7|'''1''' elemento|'''\$7''' elementi}}.",
+La [http://www.mediawiki.org/wiki/Manual:Job_queue coda dei processi] da eseguire in background contiene {{PLURAL:\$7|'''1''' elemento|'''\$7''' elementi}}.",
 'userstatstext'          => "In questo momento {{PLURAL:$1|è registrato '''1''' utente|sono registrati '''$1''' utenti}}. Il gruppo $5 è composto da '''$2''' {{PLURAL:$2|utente|utenti}}, pari al '''$4%''' dei registrati.",
 'statistics-mostpopular' => 'Pagine più visitate',
 
@@ -1359,9 +1356,11 @@
 'disambiguationspage'  => 'Template:Disambigua',
 'disambiguations-text' => "Le pagine nella lista che segue contengono dei collegamenti a '''pagine di disambiguazione''' e non all'argomento cui dovrebbero fare riferimento.<br />Vengono considerate pagine di disambiguazione tutte quelle che contengono i template elencati in [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redirect doppi',
-'doubleredirectstext' => '<b>Attenzione:</b> Questa lista può contenere risultati errati, ad esempio nel caso in cui il comando #REDIRECT sia seguito da altro testo o collegamenti.<br />
+'doubleredirects'            => 'Redirect doppi',
+'doubleredirectstext'        => '<b>Attenzione:</b> Questa lista può contenere risultati errati, ad esempio nel caso in cui il comando #REDIRECT sia seguito da altro testo o collegamenti.<br />
 Ciascuna riga contiene i collegamenti al primo ed al secondo redirect, oltre alla prima riga di testo del secondo redirect che di solito contiene la pagina di destinazione "corretta" alla quale dovrebbe puntare anche il primo redirect.',
+'double-redirect-fixed-move' => '[[$1]] è stata spostata automaticamente, ora è un redirect a [[$2]]',
+'double-redirect-fixer'      => 'Correttore di redirect',
 
 'brokenredirects'        => 'Redirect errati',
 'brokenredirectstext'    => 'I seguenti redirect puntano a pagine inesistenti:',
@@ -1382,14 +1381,14 @@
 'nmembers'                => '$1 {{PLURAL:$1|elemento|elementi}}',
 'nrevisions'              => '$1 {{PLURAL:$1|revisione|revisioni}}',
 'nviews'                  => '$1 {{PLURAL:$1|visita|visite}}',
-'specialpage-empty'       => 'Questo rapporto non contiene alcun risultato.',
+'specialpage-empty'       => 'Questa pagina speciale è attualmente vuota.',
 'lonelypages'             => 'Pagine orfane',
 'lonelypagestext'         => 'Le pagine indicate di seguito sono prive di collegamenti che provengono da altre pagine del sito.',
 'uncategorizedpages'      => 'Pagine prive di categorie',
-'uncategorizedcategories' => 'Categorie prive di categorie',
+'uncategorizedcategories' => 'Categorie non categorizzate',
 'uncategorizedimages'     => 'File privi di categorie',
 'uncategorizedtemplates'  => 'Template privi di categorie',
-'unusedcategories'        => 'Categorie non utilizzate',
+'unusedcategories'        => 'Categorie vuote',
 'unusedimages'            => 'File non utilizzati',
 'popularpages'            => 'Pagine più visitate',
 'wantedcategories'        => 'Categorie richieste',
@@ -1419,7 +1418,7 @@
 'ancientpages'            => 'Pagine meno recenti',
 'move'                    => 'Sposta',
 'movethispage'            => 'Sposta questa pagina',
-'unusedimagestext'        => "Si noti che è possibile realizzare collegamenti ai file da altri siti, usando direttamente la URL; questi potrebbero quindi essere utilizzati anche se compaiono nell'elenco.",
+'unusedimagestext'        => 'In questo elenco sono presenti i file caricati e non usati nel sito. Potrebbero essere presenti immagini che sono usate da altri siti con un collegamento diretto.',
 'unusedcategoriestext'    => 'Le pagine delle categorie indicate di seguito sono state create ma non contengono nessuna pagina né sottocategoria.',
 'notargettitle'           => 'Dati mancanti',
 'notargettext'            => "Non è stata indicata una pagina o un utente in relazione al quale eseguire l'operazione richiesta.",
@@ -1437,17 +1436,17 @@
 'booksources-text'          => 'Di seguito viene presentato un elenco di collegamenti verso siti esterni che vendono libri nuovi e usati, attraverso i quali è possibile ottenere maggiori informazioni sul testo cercato.',
 
 # Special:Log
-'specialloguserlabel'  => 'Utente:',
-'speciallogtitlelabel' => 'Titolo:',
+'specialloguserlabel'  => 'Azione effettuata da:',
+'speciallogtitlelabel' => 'Azione effettuata su:',
 'log'                  => 'Log',
 'all-logs-page'        => 'Tutti i registri',
 'log-search-legend'    => 'Ricerca nei registri',
 'log-search-submit'    => 'Vai',
-'alllogstext'          => 'Presentazione unificata dei log relativi alle operazioni di caricamento, cancellazione, protezione, blocco e amministrazione del sito. Riempiendo gli appositi campi si può limitare la visualizzazione a uno specifico log, nome utente o pagina.',
+'alllogstext'          => "Presentazione unificata dei registri relativi alle operazioni di caricamento, cancellazione, protezione, blocco e amministrazione del sito. Puoi restringere i criteri di ricerca selezionando il tipo di registro, l'utente che ha eseguito l'azione, e/o la pagina interessata.",
 'logempty'             => 'Il log non contiene elementi corrispondenti alla ricerca.',
 'log-title-wildcard'   => 'Ricerca dei titoli che iniziano con',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tutte le pagine',
 'alphaindexline'    => 'da $1 a $2',
 'nextpage'          => 'Pagina successiva ($1)',
@@ -1470,15 +1469,15 @@
 'special-categories-sort-count' => 'ordina per numero',
 'special-categories-sort-abc'   => 'ordina alfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostra gli utenti a partire da:',
 'listusers-submit'   => 'Mostra',
 'listusers-noresult' => 'Nessun utente risponde ai criteri impostati.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Diritti del gruppo utente',
 'listgrouprights-summary'  => "Di seguito sono elencati i gruppi utente definiti per questo wiki, con i diritti d'accesso loro associati.
-Ulteriori informazioni sui diritti individuali possono essere trovati in [[{{MediaWiki:Listgrouprights-helppage}}]].",
+Potrebbero esserci [[{{MediaWiki:Listgrouprights-helppage}}|ulteriori informazioni]] sui diritti individuali.",
 'listgrouprights-group'    => 'Gruppo',
 'listgrouprights-rights'   => 'Diritti',
 'listgrouprights-helppage' => 'Help:Diritti del gruppo',
@@ -1486,7 +1485,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nessun indirizzo cui inviare il messaggio',
-'mailnologintext' => 'Per inviare messaggi e-mail ad altri utenti è necessario [[Special:Userlogin|accedere al sito]] e aver registrato un indirizzo valido nelle proprie [[Special:Preferences|preferenze]].',
+'mailnologintext' => 'Per inviare messaggi e-mail ad altri utenti è necessario [[Special:UserLogin|accedere al sito]] e aver registrato un indirizzo valido nelle proprie [[Special:Preferences|preferenze]].',
 'emailuser'       => "Scrivi all'utente",
 'emailpage'       => "Invia un messaggio e-mail all'utente",
 'emailpagetext'   => "Se l'utente ha registrato un indirizzo e-mail valido nelle proprie preferenze, il modulo qui sotto consente di scrivere allo stesso un solo messaggio. L'indirizzo indicato nelle preferenze del mittente apparirà nel campo \"Da:\" del messaggio per consentire al destinatario l'eventuale risposta.",
@@ -1507,16 +1506,18 @@
 
 # Watchlist
 'watchlist'            => 'Osservati speciali',
-'mywatchlist'          => 'Osservati speciali',
-'watchlistfor'         => "(per '''$1''')",
+'mywatchlist'          => 'osservati speciali',
+'watchlistfor'         => "(dell'utente '''$1''')",
 'nowatchlist'          => 'La lista degli osservati speciali è vuota.',
 'watchlistanontext'    => "Per visualizzare e modificare l'elenco degli osservati speciali è necessario $1.",
 'watchnologin'         => 'Accesso non effettuato',
-'watchnologintext'     => "Per modificare la lista degli osservati speciali è necessario prima eseguire l'[[Special:Userlogin|accesso al sito]].",
+'watchnologintext'     => "Per modificare la lista degli osservati speciali è necessario prima eseguire l'[[Special:UserLogin|accesso al sito]].",
 'addedwatch'           => 'Pagina aggiunta alla lista degli osservati speciali',
-'addedwatchtext'       => "La pagina  \"[[:\$1]]\" è stata aggiunta alla propria [[Special:Watchlist|lista degli osservati speciali]].
+'addedwatchtext'       => "La pagina \"[[:\$1]]\" è stata aggiunta alla propria [[Special:Watchlist|lista degli osservati speciali]]. 
 D'ora in poi, le modifiche apportate alla pagina e alla sua discussione verranno elencate in quella sede;
-il titolo della pagina apparirà in '''grassetto''' nella pagina delle [[Special:Recentchanges|ultime modifiche]] per renderlo più visibile.",
+il titolo della pagina apparirà in '''grassetto''' nella pagina delle [[Special:RecentChanges|ultime modifiche]] per renderlo più visibile. 
+
+Se in un secondo tempo si desidera eliminare la pagina dalla lista degli osservati speciali, fare clic su \"non seguire\" nella barra in alto.",
 'removedwatch'         => 'Pagina eliminata dalla lista degli osservati speciali',
 'removedwatchtext'     => 'La pagina  "[[:$1]]" è stata eliminata dalla lista degli osservati speciali.',
 'watch'                => 'Segui',
@@ -1588,50 +1589,51 @@
 'exblank'                     => 'la pagina era vuota',
 'delete-confirm'              => 'Cancella "$1"',
 'delete-legend'               => 'Cancella',
-'historywarning'              => 'Attenzione: La pagina che si sta per cancellare ha una cronologia:',
+'historywarning'              => 'Attenzione! La pagina che si sta per cancellare ha una cronologia:',
 'confirmdeletetext'           => 'Stai per cancellare permanentemente dal database una pagina o una immagine, insieme a tutta la sua cronologia. Per cortesia, conferma che è tua intenzione procedere a tale cancellazione, che hai piena consapevolezza delle conseguenze della tua azione e che essa è conforme alle linee guida stabilite in [[{{MediaWiki:Policy-url}}]].',
 'actioncomplete'              => 'Azione completata',
-'deletedtext'                 => 'La pagina "<nowiki>$1</nowiki>" è stata cancellata. Consultare il $2 per un elenco delle pagine cancellate di recente.',
+'deletedtext'                 => 'La pagina "$1" è stata cancellata. 
+Consultare il log delle $2 per un elenco delle pagine cancellate di recente.',
 'deletedarticle'              => 'ha cancellato "[[$1]]"',
 'suppressedarticle'           => 'soppresso "[[$1]]"',
 'dellogpage'                  => 'Cancellazioni',
 'dellogpagetext'              => 'Di seguito sono elencate le pagine cancellate di recente.',
-'deletionlog'                 => 'Log delle cancellazioni',
+'deletionlog'                 => 'cancellazioni',
 'reverted'                    => 'Ripristinata la versione precedente',
-'deletecomment'               => 'Motivo della cancellazione',
+'deletecomment'               => 'Motivo della cancellazione:',
 'deleteotherreason'           => 'Altra motivazione o motivazione aggiuntiva:',
 'deletereasonotherlist'       => 'Altra motivazione',
 'deletereason-dropdown'       => "*Motivazioni più comuni per la cancellazione
 ** Richiesta dell'autore
 ** Violazione di copyright
 ** Vandalismo",
-'delete-edit-reasonlist'      => 'Modifica le motivazioni per la cancellazione',
+'delete-edit-reasonlist'      => 'Modifica i motivi di cancellazione',
 'delete-toobig'               => 'La cronologia di questa pagina è molto lunga (oltre $1 {{PLURAL:$1|revisione|revisioni}}). La sua cancellazione è stata limitata per evitare di creare accidentalmente dei problemi di funzionamento al database di {{SITENAME}}.',
 'delete-warning-toobig'       => 'La cronologia di questa pagina è molto lunga (oltre $1 {{PLURAL:$1|revisione|revisioni}}). La sua cancellazione può creare dei problemi di funzionamento al database di {{SITENAME}}; procedere con cautela.',
 'rollback'                    => 'Annulla le modifiche',
 'rollback_short'              => 'Rollback',
 'rollbacklink'                => 'rollback',
-'rollbackfailed'              => 'Rollback non riuscito',
+'rollbackfailed'              => 'Rollback fallito',
 'cantrollback'                => "Impossibile annullare le modifiche; l'utente che le ha effettuate è l'unico ad aver contribuito alla pagina.",
 'alreadyrolled'               => 'Non è possibile annullare le modifiche apportate alla pagina [[:$1]] da parte di [[User:$2|$2]] ([[User talk:$2|discussione]]); un altro utente ha già modificato la pagina oppure ha effettuato il rollback.
 
 La modifica più recente alla pagina è stata apportata da [[User:$3|$3]] ([[User talk:$3|discussione]]).',
 'editcomment'                 => 'Il commento alla modifica era: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Annullate le modifiche di [[Special:Contributions/$2|$2]] ([[User talk:$2|discussione]]), riportata alla versione precedente di [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'rollback-success'            => 'Annullate le modifiche di $1; riportata alla versione precedente di $2.',
+'rollback-success'            => "Annullate le modifiche di $1; pagina riportata all'ultima versione di $2.",
 'sessionfailure'              => "Si è verificato un problema nella sessione che identifica l'accesso; il sistema non ha eseguito il comando impartito per precauzione. Tornare alla pagina precedente con il tasto 'Indietro' del proprio browser, ricaricare la pagina e riprovare.",
 'protectlogpage'              => 'Protezioni',
 'protectlogtext'              => 'Di seguito sono elencate le azioni di protezione e sblocco delle pagine.',
 'protectedarticle'            => 'ha protetto "[[$1]]"',
 'modifiedarticleprotection'   => 'ha modificato il livello di protezione di "[[$1]]"',
-'unprotectedarticle'          => 'ha sbloccato "[[$1]]"',
+'unprotectedarticle'          => 'ha sprotetto [[$1]]',
 'protect-title'               => 'Protezione di "$1"',
 'protect-legend'              => 'Conferma la protezione',
 'protectcomment'              => 'Motivo della protezione:',
 'protectexpiry'               => 'Scadenza:',
 'protect_expiry_invalid'      => 'Scadenza non valida.',
 'protect_expiry_old'          => 'Scadenza già trascorsa.',
-'protect-unchain'             => 'Scollega i permessi di spostamento',
+'protect-unchain'             => 'Sblocca lo spostamento',
 'protect-text'                => 'Questo modulo consente di vedere e modificare il livello di protezione per la pagina <strong><nowiki>$1</nowiki></strong>.',
 'protect-locked-blocked'      => 'Non è possibile modificare i livelli di protezione quando è attivo un blocco. Le impostazioni correnti per la pagina sono <strong>$1</strong>:',
 'protect-locked-dblock'       => 'Impossibile modificare i livelli di protezione durante un blocco del database.
@@ -1645,7 +1647,7 @@
 'protect-level-sysop'         => 'Solo amministratori',
 'protect-summary-cascade'     => 'ricorsiva',
 'protect-expiring'            => 'scadenza: $1 (UTC)',
-'protect-cascade'             => 'Protezione ricorsiva (estende la protezione a tutte le pagine incluse in questa).',
+'protect-cascade'             => 'Protezione ricorsiva: protegge tutte le pagine incluse in questa pagina. Abilitare l\'opzione solo dopo aver controllato gli include ed esclusivamente se sei sicuro di cosa stai facendo. La scadenza della protezione, diversa da infinito, si può specificare \'\'\'in lingua inglese\'\'\' usando il formato standard GNU, descritto nel manuale di tar (per esempio: "1 hour", "2 days", "next Wednesday", "1 January 2017"). In alternativa, la scadenza può essere "indefinite" o "infinite" (senza scadenza).',
 'protect-cantedit'            => 'Non è possibile modificare i livelli di protezione per la pagina in quanto non si dispone dei permessi necessari per modificare la pagina stessa.',
 'restriction-type'            => 'Permesso',
 'restriction-level'           => 'Livello di restrizione',
@@ -1675,7 +1677,9 @@
 'undeleterevisions'            => '{{PLURAL:$1|Una revisione|$1 revisioni}} in archivio',
 'undeletehistory'              => 'Recuperando questa pagina, tutte le sue revisioni verranno inserite di nuovo nella relativa cronologia. Se dopo la cancellazione è stata creata una nuova pagina con lo stesso titolo, le revisioni recuperate saranno inserite nella cronologia e la versione attualmente online della pagina non verrà modificata.',
 'undeleterevdel'               => "Il ripristino non verrà effettuato se determina la cancellazione parziale della versione corrente della pagina o del file interessato. In tal caso, è necessario rimuovere il segno di spunta o l'oscuramento dalle revisioni cancellate più recenti.",
-'undeletehistorynoadmin'       => 'La pagina è stata cancellata. Il motivo della cancellazione è indicato di seguito, assieme ai dati degli utenti che avevano modificato la pagina prima della cancellazione. Il testo contenuto nelle revisioni cancellate è disponibile solo agli amministratori.',
+'undeletehistorynoadmin'       => "Questa pagina è stata cancellata. 
+Il motivo della cancellazione è mostrato qui sotto, assieme ai dettagli dell'utente che ha modificato questa pagina prima della cancellazione. 
+Il testo contenuto nelle revisioni cancellate è disponibile solo agli amministratori.",
 'undelete-revision'            => 'Revisione cancellata della pagina $1, inserita il $2 da $3:',
 'undeleterevision-missing'     => "Revisione errata o mancante. Il collegamento è errato oppure la revisione è stata già ripristinata o eliminata dall'archivio.",
 'undelete-nodiff'              => 'Non è stata trovata nessuna revisione precedente.',
@@ -1688,9 +1692,9 @@
 'undeletedrevisions-files'     => '{{PLURAL:$1|Una revisione|$1 revisioni}} e $2 file recuperati',
 'undeletedfiles'               => '{{PLURAL:$1|Un file recuperato|$1 file recuperati}}',
 'cannotundelete'               => 'Ripristino non riuscito; è possibile che la pagina sia già stata recuperata da un altro utente.',
-'undeletedpage'                => "<big>'''$1 è stata recuperata'''</big>
+'undeletedpage'                => "<big>'''La pagina $1 è stata recuperata'''</big>
 
-Consultare il [[Special:Log/delete|log delle cancellazioni]] per vedere le cancellazioni e i recuperi più recenti.",
+Consulta il [[Special:Log/delete|log delle cancellazioni]] per vedere le cancellazioni e i recuperi più recenti.",
 'undelete-header'              => 'Consultare il [[Special:Log/delete|log delle cancellazioni]] per vedere le cancellazioni più recenti.',
 'undelete-search-box'          => 'Ricerca nelle pagine cancellate',
 'undelete-search-prefix'       => 'Mostra le pagine il cui titolo inizia con:',
@@ -1716,19 +1720,19 @@
 'contribsub2'   => 'Per $1 ($2)',
 'nocontribs'    => 'Non sono state trovate modifiche che soddisfino i criteri di ricerca.',
 'uctop'         => ' (ultima per la pagina)',
-'month'         => 'A partire dal mese (e precedenti):',
-'year'          => "A partire dall'anno (e precedenti):",
+'month'         => 'Dal mese (e precedenti):',
+'year'          => "Dall'anno (e precedenti):",
 
 'sp-contributions-newbies'     => 'Mostra solo i contributi dei nuovi utenti',
 'sp-contributions-newbies-sub' => 'Per i nuovi utenti',
-'sp-contributions-blocklog'    => 'Blocchi',
+'sp-contributions-blocklog'    => 'blocchi',
 'sp-contributions-search'      => 'Ricerca contributi',
 'sp-contributions-username'    => 'Indirizzo IP o nome utente:',
 'sp-contributions-submit'      => 'Ricerca',
 
 # What links here
 'whatlinkshere'            => 'Puntano qui',
-'whatlinkshere-title'      => 'Pagine che puntano a $1',
+'whatlinkshere-title'      => 'Pagine che puntano a "$1"',
 'whatlinkshere-page'       => 'Pagina:',
 'linklistsub'              => '(Lista dei collegamenti)',
 'linkshere'                => "Le seguenti pagine contengono dei collegamenti a '''[[:$1]]''':",
@@ -1749,7 +1753,15 @@
 # Block/unblock
 'blockip'                         => 'Blocco utente',
 'blockip-legend'                  => "Blocca l'utente",
-'blockiptext'                     => "Usare il modulo sottostante per bloccare l'accesso in scrittura ad uno specifico utente o indirizzo IP. Il blocco dev'essere operato per prevenire atti di vandalismo e in stretta osservanza della [[{{MediaWiki:Policy-url}}|policy di {{SITENAME}}]]. Specificare in dettaglio il motivo del blocco nel campo seguente (ad es. indicando i titoli delle pagine oggetto di vandalismo).",
+'blockiptext'                     => 'Usa il modulo sottostante per bloccare l\'accesso in scrittura a uno specifico indirizzo IP o un utente registrato. 
+
+Il blocco dev\'essere operato per prevenire atti di vandalismo e in stretta osservanza della [[{{MediaWiki:Policy-url}}|policy di {{SITENAME}}]].
+
+Indica il motivo specifico per il quale procedi al blocco dell\'indirizzo IP o dell\'utente (per esempio, cita i titoli di eventuali pagine che siano state oggetto di vandalismo).
+
+Le durate del blocco diverse da quelle predefinite si possono specificare \'\'\'in lingua inglese\'\'\' usando il formato standard GNU, descritto nel [http://www.gnu.org/software/shishi/manual/html_node/Relative-items-in-date-strings.html manuale di tar] (per esempio: "1 hour", "2 days", "next Wednesday", "1 January 2017"). In alternativa, il blocco può essere "indefinite" o "infinite" (senza scadenza).
+
+Per sbloccare qualcuno utilizza la [[{{ns:Special}}:Ipblocklist|lista degli IP e degli utenti bloccati]]. Ricorda infine che viene mantenuto un [[Special:Log/block|log dei blocchi]].',
 'ipaddress'                       => 'Indirizzo IP:',
 'ipadressorusername'              => 'Indirizzo IP o nome utente:',
 'ipbexpiry'                       => 'Scadenza del blocco:',
@@ -1763,7 +1775,7 @@
 ** Commportamenti intimidatori o molestie
 ** Uso indebito di più account
 ** Nome utente non consono',
-'ipbanononly'                     => 'Blocca solo utenti anonimi',
+'ipbanononly'                     => 'Blocca solo utenti anonimi (gli utenti registrati che condividono lo stesso IP non vengono bloccati)',
 'ipbcreateaccount'                => 'Impedisci la creazione di altri account',
 'ipbemailban'                     => "Impedisci all'utente l'invio di e-mail",
 'ipbenableautoblock'              => "Blocca automaticamente l'ultimo indirizzo IP usato dall'utente e i successivi con cui vengono  tentate modifiche",
@@ -1777,8 +1789,8 @@
 'badipaddress'                    => 'Indirizzo IP non valido.',
 'blockipsuccesssub'               => 'Blocco eseguito',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] è stato bloccato. <br />
-Consultare la [[Special:Ipblocklist|lista degli IP bloccati]] per vedere i blocchi attivi.',
-'ipb-edit-dropdown'               => 'Motivi per il blocco',
+Consultare la [[Special:IPBlockList|lista degli IP bloccati]] per vedere i blocchi attivi.',
+'ipb-edit-dropdown'               => 'Modifica i motivi per il blocco',
 'ipb-unblock-addr'                => 'Sblocca $1',
 'ipb-unblock'                     => 'Sblocca un utente o un indirizzo IP',
 'ipb-blocklist-addr'              => 'Elenca i blocchi attivi per $1',
@@ -1788,15 +1800,15 @@
 'ipusubmit'                       => "Sblocca l'utente",
 'unblocked'                       => "L'utente [[User:$1|$1]] è stato sbloccato",
 'unblocked-id'                    => 'Il blocco $1 è stato rimosso',
-'ipblocklist'                     => 'Lista degli utenti e indirizzi IP bloccati',
+'ipblocklist'                     => 'Utenti e indirizzi IP bloccati',
 'ipblocklist-legend'              => 'Trova un utente bloccato',
 'ipblocklist-username'            => 'Nome utente o indirizzo IP:',
 'ipblocklist-submit'              => 'Ricerca',
 'blocklistline'                   => '$1, $2 ha bloccato $3 ($4)',
 'infiniteblock'                   => 'infinito',
-'expiringblock'                   => 'fino al $1',
+'expiringblock'                   => 'scadenza: $1',
 'anononlyblock'                   => 'solo anonimi',
-'noautoblockblock'                => 'senza blocco automatico',
+'noautoblockblock'                => 'blocco automatico disabilitato',
 'createaccountblock'              => 'creazione account bloccata',
 'emailblock'                      => 'e-mail bloccate',
 'ipblocklist-empty'               => "L'elenco dei blocchi è vuoto.",
@@ -1804,10 +1816,11 @@
 'blocklink'                       => 'blocca',
 'unblocklink'                     => 'sblocca',
 'contribslink'                    => 'contributi',
-'autoblocker'                     => "Bloccato automaticamente perché l'indirizzo IP è condiviso con l'utente \"[[User:\$1|\$1]]\". Il blocco dell'utente \$1 è stato imposto per il seguente motivo: \"'''\$2'''\".",
+'autoblocker'                     => 'Bloccato automaticamente perché l\'indirizzo IP è condiviso con l\'utente "[[User:$1|$1]]".
+Il blocco dell\'utente $1 è stato imposto per il seguente motivo: "$2".',
 'blocklogpage'                    => 'Blocchi',
-'blocklogentry'                   => 'ha bloccato "[[$1]]"; scadenza $2 $3',
-'blocklogtext'                    => "Questo è l'elenco delle azioni di blocco e sblocco utenti. Gli indirizzi IP bloccati automaticamente non sono elencati. Consultare l'[[Special:Ipblocklist|elenco IP bloccati]] per l'elenco degli indirizzi e nomi utente il cui blocco è operativo.",
+'blocklogentry'                   => 'ha bloccato [[$1]] per un periodo di $2 $3',
+'blocklogtext'                    => "Di seguito sono elencate le azioni di blocco e sblocco utenti. Gli indirizzi IP bloccati automaticamente non sono elencati. Consultare l'[[Special:IPBlockList|elenco IP bloccati]] per l'elenco degli indirizzi e nomi utente il cui blocco è operativo.",
 'unblocklogentry'                 => 'ha sbloccato $1',
 'block-log-flags-anononly'        => 'solo utenti anonimi',
 'block-log-flags-nocreate'        => 'creazione account bloccata',
@@ -1815,7 +1828,7 @@
 'block-log-flags-noemail'         => 'e-mail bloccate',
 'block-log-flags-angry-autoblock' => 'blocco automatico avanzato attivo',
 'range_block_disabled'            => 'La possibilità di bloccare intervalli di indirizzi IP non è attiva al momento.',
-'ipb_expiry_invalid'              => 'Durata o scadenza del blocco non valida.',
+'ipb_expiry_invalid'              => 'Durata o scadenza del blocco non valida. Controlla il [http://www.gnu.org/software/shishi/manual/html_node/Relative-items-in-date-strings.html manuale di tar] per la sintassi esatta.',
 'ipb_expiry_temp'                 => 'I blocchi dei nomi utenti nascosti dovrebbero essere infiniti',
 'ipb_already_blocked'             => 'L\'utente "$1" è già bloccato',
 'ipb_cant_unblock'                => 'Errore: Impossibile trovare il blocco con ID $1. Il blocco potrebbe essere già stato rimosso.',
@@ -1850,28 +1863,26 @@
 # Move page
 'move-page'               => 'Spostamento di $1',
 'move-page-legend'        => 'Spostamento di pagina',
-'movepagetext'            => "Questo modulo consente di rinominare una pagina, spostando tutta la sua cronologia al nuovo nome. La pagina attuale diverrà automaticamente un redirect al nuovo titolo. I collegamenti esistenti non saranno aggiornati; verificare che lo spostamento non abbia creato doppi redirect o redirect errati. L'onere di garantire che i collegamenti alla pagina restino corretti spetta a chi la sposta.
+'movepagetext'            => "Questo modulo consente di rinominare una pagina, spostando tutta la sua cronologia al nuovo nome. La pagina attuale diverrà automaticamente un redirect al nuovo titolo. Puoi aggiornare automaticamente i redirect che puntano al titolo originale. Puoi decidere di non farlo, ma ricordati di verificare che lo spostamento non abbia creato [[Special:DoubleRedirects|doppi redirect]] o [[Special:BrokenRedirects|redirect errati]]. L'onere di garantire che i collegamenti alla pagina restino corretti spetta a chi la sposta.
 
 Si noti che la pagina '''non''' sarà spostata se ne esiste già una con il nuovo nome, a meno che non sia vuota o costituita solo da un redirect alla vecchia e sia priva di versioni precedenti. In caso di spostamento errato si può quindi tornare subito al vecchio titolo, e non è possibile sovrascrivere per errore una pagina già esistente.
 
-<b>ATTENZIONE:</b>
+'''ATTENZIONE:'''
 Un cambiamento così drastico può creare contrattempi e problemi, soprattutto per le pagine più visitate. Accertarsi di aver valutato le conseguenze dello spostamento prima di procedere.",
-'movepagetalktext'        => "La corrispondente pagina di discussione sarà spostata automaticamente insieme alla pagina principale, '''tranne che nei seguenti casi:'''
-* Lo spostamento della pagina è tra namespace diversi
-* In corrispondenza del nuovo titolo esiste già una pagina di discussione (non vuota)
-* La casella qui sotto è stata deselezionata.
+'movepagetalktext'        => "La corrispondente pagina di discussione, se esiste, sarà spostata automaticamente insieme alla pagina principale, '''tranne che nei seguenti casi''':
+* lo spostamento della pagina è tra namespace diversi;
+* in corrispondenza del nuovo titolo esiste già una pagina di discussione (non vuota);
+* la casella qui sotto è stata deselezionata.
 
 In questi casi, se lo si ritiene opportuno, occorre spostare o aggiungere manualmente le informazioni contenute nella pagina di discussione.",
 'movearticle'             => 'Sposta la pagina',
-'movenologin'             => 'Accesso non effettuato',
-'movenologintext'         => "Lo spostamento delle pagine è consentito solo agli utenti registrati che hanno eseguito l'[[Special:Userlogin|accesso]] al sito.",
 'movenotallowed'          => 'Non si dispone dei permessi necessari allo spostamento delle pagine su {{SITENAME}}.',
 'newtitle'                => 'Nuovo titolo:',
-'move-watch'              => 'Aggiungi agli osservati speciali',
+'move-watch'              => 'Aggiungi la pagina agli osservati speciali',
 'movepagebtn'             => 'Sposta la pagina',
 'pagemovedsub'            => 'Spostamento effettuato con successo',
 'movepage-moved'          => '<big>\'\'\'"$1" è stata spostata a "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'articleexists'           => 'Una pagina con questo nome esiste già, oppure il nome scelto non è valido. Scegliere un altro titolo.',
+'articleexists'           => 'Una pagina con questo nome esiste già, oppure il nome che hai scelto non è valido.<br /> Scegli, per cortesia, un titolo diverso per la pagina.',
 'cantmove-titleprotected' => 'Lo spostamento della pagina non è possibile in quanto il nuovo titolo è stato protetto per impedirne la creazione',
 'talkexists'              => "'''La pagina è stata spostata correttamente, ma non è stato possibile spostare la pagina di discussione perché ne esiste già un'altra con il nuovo titolo. Integrare manualmente i contenuti delle due pagine.'''",
 'movedto'                 => 'spostata a',
@@ -1885,20 +1896,21 @@
 '1movedto2'               => 'ha spostato [[$1]] a [[$2]]',
 '1movedto2_redir'         => 'ha spostato [[$1]] a [[$2]] tramite redirect',
 'movelogpage'             => 'Spostamenti',
-'movelogpagetext'         => "Questo è l'elenco delle pagine spostate.",
-'movereason'              => 'Motivo',
+'movelogpagetext'         => 'Di seguito sono elencate le pagine spostate di recente.',
+'movereason'              => 'Motivo:',
 'revertmove'              => 'ripristina',
 'delete_and_move'         => 'Cancella e sposta',
-'delete_and_move_text'    => '==Richiesta di cancellazione==
+'delete_and_move_text'    => '==Cancellazione richiesta==
 
-La pagina di destinazione [[$1]] esiste già. Si desidera cancellarla per rendere possibile lo spostamento?',
+La pagina specificata come destinazione "[[:$1]]" esiste già. Vuoi cancellarla per proseguire con lo spostamento?',
 'delete_and_move_confirm' => 'Sì, sovrascrivi la pagina esistente',
 'delete_and_move_reason'  => 'Cancellata per rendere possibile lo spostamento',
-'selfmove'                => 'Il nuovo titolo è uguale al vecchio; impossibile spostare la pagina su se stessa.',
+'selfmove'                => "Il titolo di destinazione inserito è uguale a quello di provenienza: '''attenzione''', leggi i titoli dei campi prima di confermare un comando! Il secondo campo contiene un commento che è necessario per giustificare lo spostamento della pagine e viene memorizzato nel log.",
 'immobile_namespace'      => 'Il nuovo titolo corrisponde a una pagina speciale; impossibile spostare pagine in quel namespace.',
 'imagenocrossnamespace'   => "Non puoi spostare un'immagine fuori del namespace Immagine.",
 'imagetypemismatch'       => 'La nuova estensione del file non corrisponde alla sua reale estensione',
 'imageinvalidfilename'    => "Il nome dell'immagine non è valido",
+'fix-double-redirects'    => 'Aggiorna tutti i redirect che puntano al titolo originale',
 
 # Export
 'export'            => 'Esporta pagine',
@@ -1968,10 +1980,10 @@
 
 # Import log
 'importlogpage'                    => 'Importazioni',
-'importlogpagetext'                => "Registro delle importazioni d'ufficio di pagine provenienti da altre wiki, complete di cronologia.",
+'importlogpagetext'                => 'Di seguito sono elencate le importazioni di pagine provenienti da altre wiki, complete di cronologia.',
 'import-logentry-upload'           => 'ha importato [[$1]] tramite upload',
 'import-logentry-upload-detail'    => '{{PLURAL:$1|una revisione importata|$1 revisioni importate}}',
-'import-logentry-interwiki'        => 'ha trasferito da altra wiki la pagina $1',
+'import-logentry-interwiki'        => 'ha trasferito da altra wiki la pagina [[$1]]',
 'import-logentry-interwiki-detail' => '{{PLURAL:$1|una revisione importata|$1 revisioni importate}} da $2',
 
 # Tooltip help for the actions
@@ -1979,7 +1991,7 @@
 'tooltip-pt-anonuserpage'         => 'La pagina utente di questo indirizzo IP',
 'tooltip-pt-mytalk'               => 'La tua pagina di discussione',
 'tooltip-pt-anontalk'             => 'Discussioni sulle modifiche fatte da questo indirizzo IP',
-'tooltip-pt-preferences'          => 'Le tue preferenze',
+'tooltip-pt-preferences'          => 'Le mie preferenze',
 'tooltip-pt-watchlist'            => 'La lista delle pagine che stai tenendo sotto osservazione',
 'tooltip-pt-mycontris'            => "L'elenco dei tuoi contributi",
 'tooltip-pt-login'                => 'La registrazione è consigliata, anche se non obbligatoria',
@@ -2060,7 +2072,7 @@
 # Metadata
 'nodublincore'      => 'Metadati Dublin Core RDF non attivi su questo server.',
 'nocreativecommons' => 'Metadati Commons RDF non attivi su questo server.',
-'notacceptable'     => 'Il server wiki non è in grado di fornire i dati in un formato leggibile dal client utilizzato.',
+'notacceptable'     => 'Il server wiki non è in grado di fornire i dati in un formato leggibile dal tuo client.',
 
 # Attribution
 'anonymous'        => 'uno o più utenti anonimi di {{SITENAME}}',
@@ -2098,23 +2110,24 @@
 
 # Patrolling
 'markaspatrolleddiff'                 => 'Segna la modifica come verificata',
-'markaspatrolledtext'                 => 'Segna questa voce come verificata',
-'markedaspatrolled'                   => 'Segnato come verificato',
-'markedaspatrolledtext'               => 'La revisione selezionata è stata segnata come verificata.',
+'markaspatrolledtext'                 => 'Segna questa pagina come verificata',
+'markedaspatrolled'                   => 'Modifica verificata',
+'markedaspatrolledtext'               => 'La modifica selezionata è stata segnata come verificata.',
 'rcpatroldisabled'                    => 'La verifica delle ultime modifiche è disattivata',
 'rcpatroldisabledtext'                => 'La funzione di verifica delle ultime modifiche al momento non è attiva.',
 'markedaspatrollederror'              => 'Impossibile contrassegnare la voce come verificata',
-'markedaspatrollederrortext'          => 'Occorre specificare una revisione da contrassegnare come verificata.',
+'markedaspatrollederrortext'          => 'Occorre specificare una modifica da contrassegnare come verificata.',
 'markedaspatrollederror-noautopatrol' => 'Non si dispone dei permessi necessari per segnare le proprie modifiche come verificate.',
 
 # Patrol log
-'patrol-log-page' => 'Modifiche verificate',
-'patrol-log-line' => 'ha segnato la $1 alla pagina $2 come verificata $3',
-'patrol-log-auto' => '(verifica automatica)',
-'patrol-log-diff' => 'modifica $1',
+'patrol-log-page'   => 'Modifiche verificate',
+'patrol-log-header' => 'Di seguito sono elencate le verifiche delle modifiche.',
+'patrol-log-line'   => 'ha segnato la $1 alla pagina $2 come verificata $3',
+'patrol-log-auto'   => '(verifica automatica)',
+'patrol-log-diff'   => 'modifica $1',
 
 # Image deletion
-'deletedrevision'                 => 'Revisione precedente, cancellata: $1',
+'deletedrevision'                 => 'Cancellata la vecchia revisione di $1.',
 'filedeleteerror-short'           => 'Errore nella cancellazione del file: $1',
 'filedeleteerror-long'            => 'Si sono verificati degli errori nel tentativo di cancellare il file:
 
@@ -2140,10 +2153,10 @@
 'show-big-image'       => 'Versione ad alta risoluzione',
 'show-big-image-thumb' => '<small>Dimensioni di questa anteprima: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galleria dei nuovi file',
 'imagelisttext'         => "La lista presentata di seguito, costituita da {{PLURAL:$1|un file|'''$1''' file}}, è ordinata per $2.",
-'newimages-summary'     => 'Questa pagina speciale mostra i file caricati più di recente',
+'newimages-summary'     => 'Questa pagina speciale mostra i file caricati più di recente.',
 'showhidebots'          => '($1 i bot)',
 'noimages'              => "Non c'è nulla da vedere.",
 'ilsubmit'              => 'Ricerca',
@@ -2158,7 +2171,7 @@
 
 # Metadata
 'metadata'          => 'Metadati',
-'metadata-help'     => 'Questo file contiene informazioni aggiuntive, probabilmente aggiunte dalla fotocamera o dallo scanner usati per crearlo o digitalizzarlo. Se il file è stato modificato, alcuni dettagli potrebbero non corrispondere alle modifiche apportate.',
+'metadata-help'     => 'Questo file contiene informazioni aggiuntive, probabilmente aggiunte dalla fotocamera o dallo scanner usati per crearlo o digitalizzarlo. Se il file è stato modificato, alcuni dettagli potrebbero non corrispondere alla realtà.',
 'metadata-expand'   => 'Mostra dettagli',
 'metadata-collapse' => 'Nascondi dettagli',
 'metadata-fields'   => "I campi relativi ai metadati EXIF elencati in questo messaggio verranno mostrati sulla pagina dell'immagine quando la tabella dei metadati è presentata nella forma breve. Per impostazione predefinita, gli altri campi verranno nascosti.
@@ -2431,7 +2444,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifica questo file usando un programma esterno',
-'edit-externally-help' => 'Per maggiori informazioni consultare le [http://meta.wikimedia.org/wiki/Help:External_editors istruzioni] (in inglese)',
+'edit-externally-help' => 'Per maggiori informazioni consultare le [http://www.mediawiki.org/wiki/Manual:External_editors istruzioni] (in inglese)',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tutte',
@@ -2493,18 +2506,27 @@
 'trackbackdeleteok' => 'Informazioni di trackback eliminate correttamente.',
 
 # Delete conflict
-'deletedwhileediting' => 'Attenzione: Questa pagina è stata cancellata dopo che hai iniziato a modificarla.',
+'deletedwhileediting' => 'Attenzione: questa pagina è stata cancellata dopo che hai cominciato a modificarla!',
 'confirmrecreate'     => "L'utente [[User:$1|$1]] ([[User talk:$1|discussioni]]) ha cancellato questa pagina dopo che hai iniziato a modificarla, per il seguente motivo: ''$2''
 Per favore, conferma che desideri veramente ricreare questa pagina.",
 'recreate'            => 'Ricrea',
 
 # HTML dump
-'redirectingto' => 'Reindirizzamento a [[$1]]...',
+'redirectingto' => 'Reindirizzamento a [[:$1]]...',
 
 # action=purge
-'confirm_purge'        => 'Si desidera pulire la cache di questa pagina?
+'confirm_purge'        => "Vuoi pulire la cache di questa pagina?  $1
 
-$1',
+La ''cache'' è un archivio che contiene una copia provvisoria delle pagine web.
+
+Ogni volta che apri una pagina, il software si connette al database e crea al momento la pagina che viene inviata al tuo ''browser'' e visualizzata sul tuo computer. Questo processo impiega tempo e risorse. 
+
+Per le pagine più frequentemente richieste, questo processo risulterebbe troppo oneroso e perciò ingestibile. Per ovviare al problema il software crea automaticamente una copia della pagina che viene conservata per un certo tempo in una ''cache'', una memoria transitoria appositamente dedicata. In questo modo non è necessario effettuare ogni volta il processo di creazione, poichè la pagina è già pronta.
+
+* vantaggi: minor carico di lavoro per il sistema e maggiore velocità
+* svantaggi: è possibile che la pagina caricata non sia la versione più recente; la pagina potrebbe essere stata modificata dopo essere stata copiata nella ''cache''
+
+Pertanto, pulire (o aggiornare) la ''cache'' di una pagina, significa assicurarsi di visualizzare la versione più recente.",
 'confirm_purge_button' => 'Conferma',
 
 # AJAX search
@@ -2549,21 +2571,21 @@
 Usare l\'anteprima standard.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Le modifiche apportate negli ultimi $1 secondi potrebbero non apparire in questa lista.',
-'lag-warn-high'   => "A causa di un eccessivo ritardo nell'aggiornamento del server di database, le modifiche apportate negli ultimi $1 secondi potrebbero non apparire in questa lista.",
+'lag-warn-normal' => "Le modifiche apportate {{PLURAL:$1|nell'ultimo secondo|negli ultimi $1 secondi}} potrebbero non apparire in questa lista.",
+'lag-warn-high'   => "A causa di un eccessivo ritardo nell'aggiornamento del server di database, le modifiche apportate {{PLURAL:$1|nell'ultimo secondo|negli ultimi $1 secondi}} potrebbero non apparire in questa lista.",
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'La lista degli osservati speciali contiene {{PLURAL:$1|una pagina (e la rispettiva pagina di discussione)|$1 pagine (e le rispettive pagine di discussione)}}.',
 'watchlistedit-noitems'        => 'La lista degli osservati speciali è vuota.',
 'watchlistedit-normal-title'   => 'Modifica osservati speciali',
 'watchlistedit-normal-legend'  => 'Eliminazione di pagine dagli osservati speciali',
-'watchlistedit-normal-explain' => "Di seguito sono elencate tutte le pagine osservate. Per rimuovere una o più pagine dalla lista, selezionare le caselle relative e fare clic sul pulsante 'Elimina pagine' in fondo all'elenco. Si noti che è anche possibile [[Special:Watchlist/raw|modificare la lista in formato testuale]].",
+'watchlistedit-normal-explain' => 'Di seguito sono elencate tutte le pagine osservate. Per rimuovere una o più pagine dalla lista, selezionare le caselle relative e fare clic sul pulsante "Elimina pagine" in fondo all\'elenco. Si noti che è anche possibile [[Special:Watchlist/raw|modificare la lista in formato testuale]].',
 'watchlistedit-normal-submit'  => 'Elimina pagine',
 'watchlistedit-normal-done'    => 'Dalla lista degli osservati speciali {{PLURAL:$1|è stata eliminata una pagina|sono state eliminate $1 pagine}}:',
 'watchlistedit-raw-title'      => 'Modifica degli osservati speciali in forma testuale',
 'watchlistedit-raw-legend'     => 'Modifica testuale osservati speciali',
-'watchlistedit-raw-explain'    => "Di seguito sono elencate tutte le pagine osservate. Per modificare la lista aggiungere o rimuovere i rispettivi titoli, uno per riga. Una volta terminato, fare clic su 'Aggiorna la lista' in fondo all'elenco. Si noti che è anche possibile [[Special:Watchlist/edit|modificare la lista con l'interfaccia standard]].",
-'watchlistedit-raw-titles'     => 'Pagine:',
+'watchlistedit-raw-explain'    => 'Di seguito sono elencate tutte le pagine osservate. Per modificare la lista aggiungere o rimuovere i rispettivi titoli, uno per riga. Una volta terminato, fare clic su "Aggiorna la lista" in fondo all\'elenco. Si noti che è anche possibile [[Special:Watchlist/edit|modificare la lista con l\'interfaccia standard]].',
+'watchlistedit-raw-titles'     => 'Titoli delle pagine:',
 'watchlistedit-raw-submit'     => 'Aggiorna la lista',
 'watchlistedit-raw-done'       => 'La lista degli osservati speciali è stata aggiornata.',
 'watchlistedit-raw-added'      => '{{PLURAL:$1|È stata aggiunta una pagina|Sono state aggiunte $1 pagine}}:',
@@ -2571,7 +2593,7 @@
 
 # Watchlist editing tools
 'watchlisttools-view' => 'Visualizza le modifiche pertinenti',
-'watchlisttools-edit' => 'Visualizza e modifica la lista',
+'watchlisttools-edit' => 'Visualizza e modifica la lista degli osservati speciali',
 'watchlisttools-raw'  => 'Modifica la lista in formato testo',
 
 # Core parser functions
@@ -2598,7 +2620,7 @@
 'version-software-product'         => 'Prodotto',
 'version-software-version'         => 'Versione',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Percorso di un file',
 'filepath-page'    => 'Nome del file:',
 'filepath-submit'  => 'Percorso',
@@ -2636,7 +2658,7 @@
 'specialpages-group-redirects'   => 'Pagine speciali di redirect',
 'specialpages-group-spam'        => 'Strumenti contro lo spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pagina vuota',
 'intentionallyblankpage' => 'Questa pagina è lasciata volutamente vuota ed è usata per benchmark, ecc.',
 
Index: languages/messages/MessagesMs.php
===================================================================
--- languages/messages/MessagesMs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Aurora
  * @author Aviator
- * @author Siebrand
- * @author Aurora
+ * @author Kurniasan
+ * @author Putera Luqman Tunku Andre
  * @author לערי ריינהארט
- * @author Kurniasan
  */
 
 /**
@@ -61,84 +61,89 @@
 );
 
 $specialPageAliases = array(
-	'DoubleRedirects'         => array('Pelencongan_berganda'),
-	'BrokenRedirects'         => array('Pelencongan_rosak'),
-	'Disambiguations'         => array('Penyahtaksaan'),
-	'Userlogin'               => array('Log_masuk'),
-	'Userlogout'              => array('Log_keluar'),
-	'CreateAccount'           => array('Buka_akaun'),
-	'Preferences'             => array('Keutamaan'),
-	'Watchlist'               => array('Senarai_pantau'),
-	'Recentchanges'           => array('Perubahan_terkini'),
-	'Upload'                  => array('Muat_naik'),
-	'Imagelist'               => array('Senarai_imej'),
-	'Newimages'               => array('Imej_baru'),
-	'Listusers'               => array('Senarai_pengguna'),
-	'Statistics'              => array('Statistik'),
-	'Randompage'              => array('Laman_rawak'),
-	'Lonelypages'             => array('Laman_yatim'),
-	'Uncategorizedpages'      => array('Laman_tanpa_kategori'),
-	'Uncategorizedcategories' => array('Kategori_tanpa_kategori'),
-	'Uncategorizedimages'     => array('Imej_tanpa_kategori'),
-	'Uncategorizedtemplates'  => array('Templat_tanpa_kategori'),
-	'Unusedcategories'        => array('Kategori_tak_digunakan'),
-	'Unusedimages'            => array('Imej_tak_digunakan'),
-	'Wantedpages'             => array('Laman_dikehendaki'),
-	'Wantedcategories'        => array('Kategori_dikehendaki'),
-	'Mostlinked'              => array('Laman_dipaut_terbanyak'),
-	'Mostlinkedcategories'    => array('Kategori_dipaut_terbanyak'),
-	'Mostlinkedtemplates'     => array('Templat_dipaut_terbanyak'),
-	'Mostcategories'          => array('Kategori_terbanyak'),
-	'Mostimages'              => array('Imej_terbanyak'),
-	'Mostrevisions'           => array('Semakan_terbanyak'),
-	'Fewestrevisions'         => array('Semakan_tersikit'),
-	'Shortpages'              => array('Laman_pendek'),
-	'Longpages'               => array('Laman_panjang'),
-	'Newpages'                => array('Laman_baru'),
-	'Ancientpages'            => array('Laman_lapuk'),
-	'Deadendpages'            => array('Laman_buntu'),
-	'Protectedpages'          => array('Laman_dilindungi'),
-	'Protectedtitles'         => array('Tajuk_dilindungi'),
-	'Allpages'                => array('Semua_laman'),
-	'Prefixindex'             => array('Indeks_awalan'),
-	'Ipblocklist'             => array('Sekatan_IP'),
-	'Specialpages'            => array('Laman_khas'),
-	'Contributions'           => array('Sumbangan'),
-	'Emailuser'               => array('E-mel_pengguna'),
-	'Confirmemail'            => array('Sahkan_e-mel'),
-	'Whatlinkshere'           => array('Pautan_ke'),
-	'Recentchangeslinked'     => array('Perubahan_berkaitan'),
-	'Movepage'                => array('Pindah_laman'),
-	'Blockme'                 => array('Sekat_saya'),
-	'Booksources'             => array('Sumber_buku'),
-	'Categories'              => array('Kategori'),
-	'Export'                  => array('Eksport'),
-	'Version'                 => array('Versi'),
-	'Allmessages'             => array('Semua_mesej'),
-	'Log'                     => array('Log'),
-	'Blockip'                 => array('Sekat_IP'),
-	'Undelete'                => array('Nyahhapus'),
-	'Import'                  => array('Import'),
-	'Lockdb'                  => array('Kunci_pangkalan_data'),
-	'Unlockdb'                => array('Buka_kunci_pangkalan_data'),
-	'Userrights'              => array('Hak_pengguna'),
-	'MIMEsearch'              => array('Gelintar_MIME'),
-	'Unwatchedpages'          => array('Laman_tak_dipantau'),
-	'Listredirects'           => array('Senarai_pelencongan'),
-	'Revisiondelete'          => array('Hapus_semakan'),
-	'Unusedtemplates'         => array('Templat_tak_digunakan'),
-	'Randomredirect'          => array('Pelencongan_rawak'),
-	'Mypage'                  => array('Laman_saya'),
-	'Mytalk'                  => array('Perbincangan_saya'),
-	'Mycontributions'         => array('Sumbangan_saya'),
-	'Listadmins'              => array('Senarai_pentadbir'),
-	'Listbots'                => array('Senarai_bot'),
-	'Popularpages'            => array('Laman_popular'),
-	'Search'                  => array('Gelintar'),
-	'Resetpass'               => array('Lupa_kata_laluan'),
-	'Withoutinterwiki'        => array('Laman_tanpa_pautan_bahasa'),
-	'MergeHistory'            => array('Gabung_sejarah'),
-	'Filepath'                => array('Laluan_fail'),
+	'DoubleRedirects'         => array( 'Lencongan_berganda', 'Pelencongan_berganda' ),
+	'BrokenRedirects'         => array( 'Lencongan_rosak', 'Pelencongan_rosak' ),
+	'Disambiguations'         => array( 'Penyahtaksaan' ),
+	'Userlogin'               => array( 'Log_masuk' ),
+	'Userlogout'              => array( 'Log_keluar' ),
+	'CreateAccount'           => array( 'Buka_akaun' ),
+	'Preferences'             => array( 'Keutamaan' ),
+	'Watchlist'               => array( 'Senarai_pantau' ),
+	'Recentchanges'           => array( 'Perubahan_terkini' ),
+	'Upload'                  => array( 'Muat_naik' ),
+	'Imagelist'               => array( 'Senarai_imej' ),
+	'Newimages'               => array( 'Imej_baru' ),
+	'Listusers'               => array( 'Senarai_pengguna' ),
+	'Listgrouprights'         => array( 'Senarai_hak_kumpulan' ),
+	'Statistics'              => array( 'Statistik' ),
+	'Randompage'              => array( 'Laman_rawak' ),
+	'Lonelypages'             => array( 'Laman_yatim' ),
+	'Uncategorizedpages'      => array( 'Laman_tanpa_kategori' ),
+	'Uncategorizedcategories' => array( 'Kategori_tanpa_kategori' ),
+	'Uncategorizedimages'     => array( 'Imej_tanpa_kategori' ),
+	'Uncategorizedtemplates'  => array( 'Templat_tanpa_kategori' ),
+	'Unusedcategories'        => array( 'Kategori_tak_digunakan' ),
+	'Unusedimages'            => array( 'Imej_tak_digunakan' ),
+	'Wantedpages'             => array( 'Laman_dikehendaki' ),
+	'Wantedcategories'        => array( 'Kategori_dikehendaki' ),
+	'Missingfiles'            => array( 'Laman_hilang' ),
+	'Mostlinked'              => array( 'Laman_dipaut_terbanyak' ),
+	'Mostlinkedcategories'    => array( 'Kategori_dipaut_terbanyak' ),
+	'Mostlinkedtemplates'     => array( 'Templat_dipaut_terbanyak' ),
+	'Mostcategories'          => array( 'Kategori_terbanyak' ),
+	'Mostimages'              => array( 'Imej_terbanyak' ),
+	'Mostrevisions'           => array( 'Semakan_terbanyak' ),
+	'Fewestrevisions'         => array( 'Semakan_tersikit' ),
+	'Shortpages'              => array( 'Laman_pendek' ),
+	'Longpages'               => array( 'Laman_panjang' ),
+	'Newpages'                => array( 'Laman_baru' ),
+	'Ancientpages'            => array( 'Laman_lapuk' ),
+	'Deadendpages'            => array( 'Laman_buntu' ),
+	'Protectedpages'          => array( 'Laman_dilindungi' ),
+	'Protectedtitles'         => array( 'Tajuk_dilindungi' ),
+	'Allpages'                => array( 'Semua_laman' ),
+	'Prefixindex'             => array( 'Indeks_awalan' ),
+	'Ipblocklist'             => array( 'Sekatan_IP' ),
+	'Specialpages'            => array( 'Laman_khas' ),
+	'Contributions'           => array( 'Sumbangan' ),
+	'Emailuser'               => array( 'E-mel_pengguna' ),
+	'Confirmemail'            => array( 'Sahkan_e-mel' ),
+	'Whatlinkshere'           => array( 'Pautan_ke' ),
+	'Recentchangeslinked'     => array( 'Perubahan_berkaitan' ),
+	'Movepage'                => array( 'Pindah_laman' ),
+	'Blockme'                 => array( 'Sekat_saya' ),
+	'Booksources'             => array( 'Sumber_buku' ),
+	'Categories'              => array( 'Kategori' ),
+	'Export'                  => array( 'Eksport' ),
+	'Version'                 => array( 'Versi' ),
+	'Allmessages'             => array( 'Semua_pesanan', 'Semua_mesej' ),
+	'Log'                     => array( 'Log' ),
+	'Blockip'                 => array( 'Sekat_IP' ),
+	'Undelete'                => array( 'Nyahhapus' ),
+	'Import'                  => array( 'Import' ),
+	'Lockdb'                  => array( 'Kunci_pangkalan_data' ),
+	'Unlockdb'                => array( 'Buka_kunci_pangkalan_data' ),
+	'Userrights'              => array( 'Hak_pengguna' ),
+	'MIMEsearch'              => array( 'Gelintar_MIME' ),
+	'FileDuplicateSearch'     => array( 'Cari_fail_berganda' ),
+	'Unwatchedpages'          => array( 'Laman_tak_dipantau' ),
+	'Listredirects'           => array( 'Senarai_lencongan', 'Senarai_pelencongan' ),
+	'Revisiondelete'          => array( 'Hapus_semakan' ),
+	'Unusedtemplates'         => array( 'Templat_tak_digunakan' ),
+	'Randomredirect'          => array( 'Lencongan_rawak', 'Pelencongan_rawak' ),
+	'Mypage'                  => array( 'Laman_saya' ),
+	'Mytalk'                  => array( 'Perbincangan_saya' ),
+	'Mycontributions'         => array( 'Sumbangan_saya' ),
+	'Listadmins'              => array( 'Senarai_pentadbir' ),
+	'Listbots'                => array( 'Senarai_bot' ),
+	'Popularpages'            => array( 'Laman_popular' ),
+	'Search'                  => array( 'Gelintar' ),
+	'Resetpass'               => array( 'Lupa_kata_laluan' ),
+	'Withoutinterwiki'        => array( 'Laman_tanpa_pautan_bahasa' ),
+	'MergeHistory'            => array( 'Gabung_sejarah' ),
+	'Filepath'                => array( 'Laluan_fail' ),
+	'Invalidateemail'         => array( 'Alamat_surat_elektronik_tidak_sah' ),
+	'Blankpage'               => array( 'Laman_kosong' ),
 );
 
 $messages = array(
@@ -317,7 +322,7 @@
 'unprotectthispage' => 'Nyahlindung laman ini',
 'newpage'           => 'Laman baru',
 'talkpage'          => 'Bincangkan laman ini',
-'talkpagelinktext'  => 'bincang',
+'talkpagelinktext'  => 'Perbincangan',
 'specialpage'       => 'Laman Khas',
 'personaltools'     => 'Alatan peribadi',
 'postcomment'       => 'Kirim komen',
@@ -421,7 +426,7 @@
 'nosuchspecialpage' => 'Laman khas tidak wujud',
 'nospecialpagetext' => "<big>'''Anda telah meminta laman khas yang tidak sah.'''</big>
 
-Senarai laman khas yang sah boleh dilihat di [[Special:Specialpages]].",
+Senarai laman khas yang sah boleh dilihat di [[Special:SpecialPages]].",
 
 # General errors
 'error'                => 'Ralat',
@@ -448,7 +453,7 @@
 Perkara ini biasanya disebabkan oleh perbuatan mengikuti pautan perbezaan yang lama atau pautan ke laman yang telah dihapuskan.
 
 Jika bukan ini sebabnya, anda mungkin telah menjumpai pepijat dalam perisian ini.
-Sila catat URL bagi laman ini dan laporkan perkara ini kepada seorang pentadbir.',
+Sila catat URL bagi laman ini dan laporkan perkara ini kepada seorang [[Special:ListUsers/sysop|pentadbir]].',
 'missingarticle-rev'   => '(semakan $1)',
 'missingarticle-diff'  => '(perbezaan $1-$2)',
 'readonly_lag'         => 'Pangkalan data telah dikunci secara automatik sementara semua pelayan pangkalan data diselaraskan.',
@@ -497,7 +502,7 @@
 'logouttitle'                => 'Log keluar',
 'logouttext'                 => "<strong>Anda telah log keluar.</strong>
 
-Anda boleh terus menggunakan {{SITENAME}} sebagai pengguna tanpa nama, atau anda boleh log masuk sekali lagi sebagai pengguna lain. Sila ambil perhatian bahawa sesetengah laman mungkin dipaparkan seolah-olah anda masih log masuk. Anda boleh menyelesaikan masalah ini dengan mengosongkan data simpanan (''cache'') pelayar anda.",
+Anda boleh terus menggunakan {{SITENAME}} sebagai pengguna tanpa nama, atau anda boleh [[Special:UserLogin|log masuk sekali lagi]] sebagai pengguna lain. Sila ambil perhatian bahawa sesetengah laman mungkin dipaparkan seolah-olah anda masih log masuk. Anda boleh menyelesaikan masalah tersebut dengan hanya mengosongkan data simpanan (''cache'') pelayar anda.",
 'welcomecreation'            => '== Selamat datang, $1! ==
 
 Akaun anda telah dibuka. Jangan lupa untuk mengubah keutamaan {{SITENAME}} anda.',
@@ -605,7 +610,7 @@
 'extlink_tip'     => 'Pautan luar (ingat awalan http://)',
 'headline_sample' => 'Teks tajuk',
 'headline_tip'    => 'Tajuk peringkat 2',
-'math_sample'     => 'Masukkan formula di sini',
+'math_sample'     => 'Masukkan rumus di sini',
 'math_tip'        => 'Formula matematik (LaTeX)',
 'nowiki_sample'   => 'Masukkan teks tak berformat di sini',
 'nowiki_tip'      => 'Abaikan pemformatan wiki',
@@ -639,12 +644,13 @@
 
 * Mula: $8
 * Tamat: $6
-* Pengguna yang disekat: $7
+* Pengguna sasaran: $7
 
-Sila hubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pentadbir]] yang lain untuk untuk berbincang
-mengenai sekatan ini. Anda tidak boleh menggunakan ciri "e-melkan pengguna ini" kecuali
-sekiranya anda telah menetapkan alamat e-mel yang sah dalam [[Special:Preferences|keutamaan]] anda dan anda tidak disekat daripada menggunakannya.
-Alamat IP semasa anda ialah $3, dan ID sekatan ialah #$5. Sila sertakan salah satu atau kedua-duanya sekali dalam pertanyaan nanti.',
+Sila hubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pentadbir]] yang lain untuk untuk berunding mengenai sekatan ini.
+
+Anda tidak boleh menggunakan ciri "e-melkan pengguna ini" kecuali sekiranya anda telah menetapkan alamat e-mel yang sah dalam [[Special:Preferences|keutamaan]] anda dan anda tidak disekat daripada menggunakannya.
+
+Alamat IP semasa anda ialah $3, dan ID sekatan ialah #$5. Sila sertakan maklumat-maklumat ini dalam pertanyaan nanti.',
 'autoblockedtext'                  => 'Alamat IP anda telah disekat secara automatik kerana ia digunakan oleh pengguna lain yang disekat oleh $1.
 Berikut ialah sebab yang dinyatakan:
 
@@ -652,24 +658,19 @@
 
 * Mula: $8
 * Tamat: $6
+* Pengguna sasaran: $7
 
-Anda boleh menghubungi $1 atau
-[[{{MediaWiki:Grouppage-sysop}}|pentadbir]] lain untuk membincangkan sekatan ini.
+Anda boleh menghubungi $1 atau [[{{MediaWiki:Grouppage-sysop}}|pentadbir]] lain untuk berunding mengenai sekatan ini.
 
-Sila ambil perhatian bahawa anda tidak boleh menggunakan ciri "e-melkan pengguna ini" melainkan anda mempunyai alamat e-mel yang sah
-dalam [[Special:Preferences|laman keutamaan]] dan anda tidak disekat daripada menggunakannya.
+Sila ambil perhatian bahawa anda tidak boleh menggunakan ciri "e-melkan pengguna ini" kecuali sekiranya anda telah menetapkan alamat e-mel yang sah dalam [[Special:Preferences|laman keutamaan]] anda dan anda tidak disekat daripada menggunakannya.
 
-ID sekatan anda ialah $5. Sila sertakan ID ini dalam pertanyaan anda.',
+Alamat IP semasa anda ialah $3, dan ID sekatan ialah #$5. Sila sertakan maklumat-maklumat ini dalam pertanyaan nanti.',
 'blockednoreason'                  => 'tiada sebab diberikan',
 'blockedoriginalsource'            => "Sumber bagi '''$1'''
 ditunjukkan di bawah:",
 'blockededitsource'                => "Teks bagi '''suntingan anda''' terhadap '''$1''' ditunjukkan di bawah:",
 'whitelistedittitle'               => 'Log masuk dahulu untuk menyunting',
 'whitelistedittext'                => 'Anda hendaklah $1 terlebih dahulu untuk menyunting laman.',
-'whitelistreadtitle'               => 'Log masuk dahulu untuk membaca',
-'whitelistreadtext'                => 'Anda perlu [[Special:Userlogin|log masuk]] terlebih dahulu untuk membaca laman.',
-'whitelistacctitle'                => 'Anda tidak dibenarkan membuka akaun.',
-'whitelistacctext'                 => 'Supaya dibenarkan membuka akaun di {{SITENAME}}, anda perlu [[Special:Userlogin|log masuk]] dan mempunyai keizinan yang berkaitan.',
 'confirmedittitle'                 => 'Pengesahan e-mel diperlukan untuk menyunting',
 'confirmedittext'                  => 'Anda perlu mengesahkan alamat e-mel anda terlebih dahulu untuk menyunting mana-mana laman. Sila tetapkan dan sahkan alamat e-mel anda melalui [[Special:Preferences|laman keutamaan]].',
 'nosuchsectiontitle'               => 'Bahagian tidak wujud',
@@ -684,7 +685,7 @@
 Untuk mencipta laman ini, sila taip dalam kotak di bawah
 (lihat [[{{MediaWiki:Helppage}}|laman bantuan]] untuk maklumat lanjut).
 Jika anda tiba di sini secara tak sengaja, hanya klik butang '''back''' pada pelayar anda.",
-'anontalkpagetext'                 => "----''Ini ialah laman perbincangan bagi pengguna tanpa nama yang belum membuka akaun atau tidak log masuk. Kami terpaksa menggunakan alamat IP untuk mengenal pasti pengguna tersebut. Alamat IP ini boleh dikongsi oleh ramai pengguna. Sekiranya anda adalah seorang pengguna tanpa nama dan berasa bahawa komen yang tidak kena mengena telah ditujui kepada anda, sila [[Special:Userlogin|buka akaun baru atau log masuk]] untuk mengelakkan sebarang kekeliruan dengan pengguna tanpa nama yang lain.''",
+'anontalkpagetext'                 => "----''Ini ialah laman perbincangan bagi pengguna tanpa nama yang belum membuka akaun atau tidak log masuk. Kami terpaksa menggunakan alamat IP untuk mengenal pasti pengguna tersebut. Alamat IP ini boleh dikongsi oleh ramai pengguna. Sekiranya anda adalah seorang pengguna tanpa nama dan berasa bahawa komen yang tidak kena mengena telah ditujui kepada anda, sila [[Special:UserLogin|buka akaun baru atau log masuk]] untuk mengelakkan sebarang kekeliruan dengan pengguna tanpa nama yang lain.''",
 'noarticletext'                    => 'Tiada teks dalam laman ini pada masa sekarang. Anda boleh [[Special:Search/{{PAGENAME}}|mencari tajuk bagi laman ini]] dalam laman-laman lain atau [{{fullurl:{{FULLPAGENAME}}|action=edit}} menyunting laman ini].',
 'userpage-userdoesnotexist'        => 'Akaun pengguna "$1" tidak berdaftar. Sila pastikan sama ada anda mahu mencipta/menyunting laman ini.',
 'clearyourcache'                   => "'''Nota:''' Selepas menyimpan, anda mungkin perlu mengosongkan fail simpanan (''cache'') pelayar anda terlebih dahulu untuk melihat perubahan. '''Mozilla /Firefox/Safari:''' tahan kekunci ''Shift'' ketika mengklik ''Reload'', atau tekan ''Ctrl-Shift-R'' (''Cmd-Shift-R'' pada Apple Mac); '''IE:''' tahan kekunci ''Ctrl'' ketika mengklik ''Refresh'', atau tekan ''Ctrl-F5''; '''Konqueror:''' klik butang ''Reload'', atau tekan ''F5''; pengguna '''Opera''' perlu mengosongkan fail simpanan melalui ''Tools→Preferences''.",
@@ -750,7 +751,7 @@
 'hiddencategories'                 => 'Laman ini terdapat dalam $1 kategori tersembunyi:',
 'nocreatetitle'                    => 'Penciptaan laman dihadkan',
 'nocreatetext'                     => 'Penciptaan laman baru dihadkan pada {{SITENAME}}.
-Anda boleh berundur dan menyunting laman yang sedia ada, atau [[Special:Userlogin|log masuk]].',
+Anda boleh berundur dan menyunting laman yang sedia ada, atau [[Special:UserLogin|log masuk]].',
 'nocreate-loggedin'                => 'Anda tidak mempunyai keizinan untuk mencipta laman baru dalam {{SITENAME}}.',
 'permissionserrors'                => 'Tidak Dibenarkan',
 'permissionserrorstext'            => 'Anda tidak mempunyai keizinan untuk berbuat demikian atas {{PLURAL:$1|sebab|sebab-sebab}} berikut:',
@@ -835,7 +836,7 @@
 'revdelete-nooldid-title'     => 'Tiada semakan sasaran',
 'revdelete-nooldid-text'      => 'Anda tidak menyatakan semakan sasaran.',
 'revdelete-selected'          => "{{PLURAL:$2|Versi|Versi-versi}} '''$1''' yang dipilih:",
-'logdelete-selected'          => '{{PLURAL:$1|Peristiwa log terpilih|Peristiwa-peristiwa log terpilih}}:',
+'logdelete-selected'          => '{{PLURAL:$1|Peristiwa|Peristiwa-peristiwa}} log yang dipilih:',
 'revdelete-text'              => 'Semakan dan peristiwa yang dihapuskan masih muncul dalam sejarah laman dan log,
 akan tetapi kandungannya tidak boleh dilihat oleh orang awam.
 
@@ -872,7 +873,7 @@
 # Suppression log
 'suppressionlog'     => 'Log penahanan',
 'suppressionlogtext' => 'Berikut ialah senarai penghapusan dan sekatan yang membabitkan kandungan yang terselindung daripada penyelia.
-Sila lihat [[Special:Ipblocklist|senarai sekatan IP]] untuk senarai sekatan yang sedang dijalankan.',
+Sila lihat [[Special:IPBlockList|senarai sekatan IP]] untuk senarai sekatan yang sedang dijalankan.',
 
 # History merging
 'mergehistory'                     => 'Gabungkan sejarah laman',
@@ -940,8 +941,8 @@
 'mwsuggest-disable'         => 'Matikan ciri cadangan AJAX',
 'searchrelated'             => 'berkaitan',
 'searchall'                 => 'semua',
-'showingresults'            => 'Terpapar di bawah adalah hasil pencarian dari <b>$1</b> hingga <b>$2</b>.',
-'showingresultsnum'         => 'Terpapar di bawah <b>$3</b> adalah hasil pencarian yang bermula dengan #<b>$2</b>.',
+'showingresults'            => "Berikut ialah '''$1''' hasil bermula daripada yang {{PLURAL:$2|pertama|ke-'''$2'''}}.",
+'showingresultsnum'         => "Berikut ialah '''$3''' hasil bermula daripada yang {{PLURAL:$2|pertama|ke-'''$2'''}}.",
 'showingresultstotal'       => "Berikut ialah {{PLURAL:$3|hasil '''$1'''|hasil '''$1 - $2'''}} daripada '''$3'''",
 'nonefound'                 => "'''Catatan''': Kegagalan pencarian biasanya
 disebabkan oleh pencarian perkataan-perkataan yang terlalu umum, seperti \"ada\"
@@ -960,7 +961,7 @@
 'mypreferences'            => 'Keutamaan saya',
 'prefs-edits'              => 'Jumlah suntingan:',
 'prefsnologin'             => 'Belum log masuk',
-'prefsnologintext'         => 'Anda mesti [[Special:Userlogin|log masuk]] terlebih dahulu untuk menetapkan keutamaan.',
+'prefsnologintext'         => 'Anda mesti [[Special:UserLogin|log masuk]] terlebih dahulu untuk menetapkan keutamaan.',
 'prefsreset'               => 'Keutamaan anda telah diset semula dari storan.',
 'qbsettings'               => 'Bar pantas',
 'qbsettings-none'          => 'Tiada',
@@ -1034,7 +1035,7 @@
 'userrights-reason'           => 'Sebab perubahan:',
 'userrights-no-interwiki'     => 'Anda tidak mempunyai keizinan untuk mengubah hak-hak pengguna di wiki lain.',
 'userrights-nodatabase'       => 'Pangkalan data $1 tiada atau bukan tempatan.',
-'userrights-nologin'          => 'Anda mesti [[Special:Userlogin|log masuk]] dengan akaun pentadbir terlebih dahulu untuk memperuntukkan hak-hak pengguna.',
+'userrights-nologin'          => 'Anda mesti [[Special:UserLogin|log masuk]] dengan akaun pentadbir terlebih dahulu untuk memperuntukkan hak-hak pengguna.',
 'userrights-notallowed'       => 'Anda tidak mempunyai keizinan untuk memperuntukkan hak-hak pengguna.',
 'userrights-changeable-col'   => 'Kumpulan yang anda boleh ubah',
 'userrights-unchangeable-col' => 'Kumpulan yang anda tak boleh ubah',
@@ -1163,12 +1164,12 @@
 'reupload'                    => 'Muat naik sekali lagi',
 'reuploaddesc'                => 'Kembali ke borang muat naik',
 'uploadnologin'               => 'Belum log masuk',
-'uploadnologintext'           => 'Anda perlu [[Special:Userlogin|log masuk]]
+'uploadnologintext'           => 'Anda perlu [[Special:UserLogin|log masuk]]
 terlebih dahulu untuk memuat naik fail.',
 'upload_directory_missing'    => 'Direktori muat naik ($1) hilang dan tidak dapat dicipta oleh pelayan web.',
 'upload_directory_read_only'  => 'Direktori muat naik ($1) tidak boleh ditulis oleh pelayan web.',
 'uploaderror'                 => 'Ralat muat naik',
-'uploadtext'                  => "Gunakan borang di bawah untuk memuat naik fail. Untuk melihat atau mencari imej yang sudah dimuat naik, sila ke [[Special:Imagelist|senarai fail yang dimuat naik]]. Muat naik dan penghapusan akan direkodkan dalam [[Special:Log/upload|log muat naik]].
+'uploadtext'                  => "Gunakan borang di bawah untuk memuat naik fail. Untuk melihat atau mencari imej yang sudah dimuat naik, sila ke [[Special:ImageList|senarai fail yang dimuat naik]]. Muat naik dan penghapusan akan direkodkan dalam [[Special:Log/upload|log muat naik]].
 
 Untuk menyertakan imej tersebut dalam sesebuah laman, sila masukkan teks
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fail.jpg]]</nowiki>''' atau
@@ -1252,7 +1253,7 @@
 'upload_source_url'  => ' (URL yang boleh diakses oleh orang awam)',
 'upload_source_file' => ' (fail dalam komputer anda)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Laman khas ini memaparkan senarai fail yang telah dimuat naik.
 Klik di atas mana-mana lajur yang berkenaan untuk menukar tertib susunan.',
 'imagelist_search_for'  => 'Cari nama imej:',
@@ -1279,13 +1280,13 @@
 'imagelinks'                     => 'Pautan',
 'linkstoimage'                   => '{{PLURAL:$1|Laman|$1 buah laman}} berikut mengandungi pautan ke fail ini:',
 'nolinkstoimage'                 => 'Tiada laman yang mengandungi pautan ke fail ini.',
-'morelinkstoimage'               => 'Lihat [[Special:Whatlinkshere/$1|semua pautan]] ke fail ini.',
+'morelinkstoimage'               => 'Lihat [[Special:WhatLinksHere/$1|semua pautan]] ke fail ini.',
 'redirectstofile'                => '{{PLURAL:$1|Fail|$1 buah fail}} berikut melencong ke fail ini:',
 'duplicatesoffile'               => '{{PLURAL:$1|Fail|$1 buah fail}} berikut adalah salinan bagi fail ini:',
 'sharedupload'                   => 'Fail ini adalah fail muat naik kongsi dan boleh digunakan oleh projek lain.',
 'shareduploadwiki'               => 'Sila lihat $1 untuk maklumat lanjut.',
-'shareduploadwiki-desc'          => 'Berikut ialah keterangan bagi $1nya di gedung kongsi.',
-'shareduploadwiki-linktext'      => 'laman huraian fail',
+'shareduploadwiki-desc'          => 'Berikut ialah keterangan yang diambil daripada $1nya di gedung kongsi.',
+'shareduploadwiki-linktext'      => 'laman keterangan fail',
 'shareduploadduplicate'          => 'Fail ini adalah salinan bagi $1 di gedung kongsi.',
 'shareduploadduplicate-linktext' => 'fail lain',
 'shareduploadconflict'           => 'Fail ini mempunyai nama yang sama dengan $1 di gedung kongsi.',
@@ -1355,11 +1356,11 @@
 'sitestats'              => 'Statistik {{SITENAME}}',
 'userstats'              => 'Statistik pengguna',
 'sitestatstext'          => "Terdapat sejumlah '''\$1''' laman dalam pangkalan data kami. Jumlah ini termasuklah laman \"perbincangan\", laman mengenai {{SITENAME}}, laman ringkas,
-lencongan, dan lain-lain yang tidak layak menjadi laman kandungan. Dengan mengecualikan laman-laman ini, terdapat sejumlah '''\$2''' laman yang barangkali dianggap sah.
+lencongan, dan lain-lain yang tidak dikira sebagai laman kandungan. Dengan mengecualikan laman-laman ini, terdapat sejumlah '''\$2''' laman yang barangkali dianggap sah.
 
 '''\$8''' buah fail telah dimuat naik.
 
-Terdapat sejumlah '''\$3''' paparan laman dan '''\$4''' penyuntingan dilakukan sejak {{SITENAME}} dimulakan. Secara purata, terdapat '''\$5''' suntingan bagi setiap laman, dan '''\$6''' paparan bagi setiap suntingan.
+Terdapat sejumlah '''\$3''' paparan laman dan '''\$4''' penyuntingan dilakukan sejak {{SITENAME}} dibuka. Secara purata, terdapat '''\$5''' suntingan bagi setiap laman, dan '''\$6''' paparan bagi setiap suntingan.
 
 Jumlah [http://www.mediawiki.org/wiki/Manual:Job_queue tugas yang tertunggak] ialah '''\$7'''.",
 'userstatstext'          => "Terdapat '''$1''' pengguna berdaftar. '''$2''' (atau '''$4''') daripadanya mempunyai hak $5.",
@@ -1369,8 +1370,10 @@
 'disambiguationspage'  => 'Template:disambig',
 'disambiguations-text' => "Laman-laman berikut mengandungi pautan ke '''laman penyahtaksaan'''. Pautan ini sepatutnya ditujukan kepada topik yang sepatutnya.<br />Sesebuah laman dianggap sebagai laman penyahtaksaan jika ia menggunakan templat yang dipaut dari [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Lencongan berganda',
-'doubleredirectstext' => 'Berikut ialah sebarai laman yang melencong ke laman lencongan yang lain. Setiap baris mengandungi pautan ke laman lencongan pertama dan kedua, serta baris pertama bagi teks lencongan kedua, lazimnya merupakan laman sasaran "sebenar", yang sepatutnya ditujui oleh lencongan pertama.',
+'doubleredirects'            => 'Lencongan berganda',
+'doubleredirectstext'        => 'Berikut ialah sebarai laman yang melencong ke laman lencongan yang lain. Setiap baris mengandungi pautan ke laman lencongan pertama dan kedua, serta baris pertama bagi teks lencongan kedua, lazimnya merupakan laman sasaran "sebenar", yang sepatutnya ditujui oleh lencongan pertama.',
+'double-redirect-fixed-move' => '[[$1]] dilencongkan ke [[$2]]',
+'double-redirect-fixer'      => 'Pembaiki lencongan',
 
 'brokenredirects'        => 'Lencongan rosak',
 'brokenredirectstext'    => 'Lencongan-lencongan berikut menuju ke laman yang tidak wujud:',
@@ -1459,7 +1462,7 @@
 'logempty'             => 'Tiada item yang sepadan dalam log.',
 'log-title-wildcard'   => 'Cari semua tajuk yang bermula dengan teks ini',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Semua laman',
 'alphaindexline'    => '$1 hingga $2',
 'nextpage'          => 'Halaman berikutnya ($1)',
@@ -1482,15 +1485,15 @@
 'special-categories-sort-count' => 'susun mengikut tertib bilangan',
 'special-categories-sort-abc'   => 'susun mengikut tertib abjad',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Tunjukkan pengguna bermula pada:',
 'listusers-submit'   => 'Tunjuk',
 'listusers-noresult' => 'Tiada pengguna dijumpai.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Hak kumpulan pengguna',
-'listgrouprights-summary'  => 'Beriku ialah senarai kumpulan pengguna yang ditubuhkan di wiki ini dengan berserta hak-hak yang berkaitan.
-Maklumat tambahan mengenai sesebuah hak boleh dijumpai di [[{{MediaWiki:Listgrouprights-helppage}}]].',
+'listgrouprights-summary'  => 'Berikut ialah senarai kumpulan pengguna yang ditubuhkan di wiki ini dengan hak-hak masing-masing.
+Anda boleh mengetahui [[{{MediaWiki:Listgrouprights-helppage}}|maklumat tambahan]] mengenai setiap hak.',
 'listgrouprights-group'    => 'Kumpulan',
 'listgrouprights-rights'   => 'Hak',
 'listgrouprights-helppage' => 'Help:Hak kumpulan',
@@ -1498,7 +1501,7 @@
 
 # E-mail user
 'mailnologin'     => 'Tiada alamat e-mel',
-'mailnologintext' => 'Anda perlu [[Special:Userlogin|log masuk]]
+'mailnologintext' => 'Anda perlu [[Special:UserLogin|log masuk]]
 terlebih dahulu dan mempunyai alamat e-mel yang sah dalam
 [[Special:Preferences|laman keutamaan]] untuk mengirim e-mel kepada pengguna lain.',
 'emailuser'       => 'Kirim e-mel kepada pengguna ini',
@@ -1531,11 +1534,11 @@
 'nowatchlist'          => 'Tiada item dalam senarai pantau anda.',
 'watchlistanontext'    => 'Sila $1 terlebih dahulu untuk melihat atau menyunting senarai pantau anda.',
 'watchnologin'         => 'Belum log masuk',
-'watchnologintext'     => 'Anda mesti [[Special:Userlogin|log masuk]] terlebih dahulu untuk mengubah senarai pantau.',
+'watchnologintext'     => 'Anda mesti [[Special:UserLogin|log masuk]] terlebih dahulu untuk mengubah senarai pantau.',
 'addedwatch'           => 'Senarai pantau dikemaskinikan',
 'addedwatchtext'       => "Laman \"[[:\$1]]\" telah ditambahkan ke dalam [[Special:Watchlist|senarai pantau]] anda.
 Semua perubahan bagi laman tersebut dan laman perbincangannya akan disenaraikan di sana,
-dan tajuk laman tersebut juga akan ditonjolkan dalam '''teks tebal''' di [[Special:Recentchanges|senarai perubahan terkini]]
+dan tajuk laman tersebut juga akan ditonjolkan dalam '''teks tebal''' di [[Special:RecentChanges|senarai perubahan terkini]]
 untuk memudahkan anda.
 
 Jika anda mahu membuang laman tersebut daripada senarai pantau, klik \"Nyahpantau\" pada bar sisi.",
@@ -1651,7 +1654,7 @@
 Tindakan ini telah dibatalkan untuk mencegah perampasan sesi.
 Sila tekan butang "back" dan muatkan semula laman yang telah anda kunjungi sebelum ini, kemudian cuba lagi.',
 'protectlogpage'              => 'Log perlindungan',
-'protectlogtext'              => 'Berikut ialah senarai bagi tindakan penguncian/pembukaan laman. Sila lihat [[Special:Protectedpages|senarai laman dilindungi]] untuk rujukan lanjut.',
+'protectlogtext'              => 'Berikut ialah senarai bagi tindakan penguncian/pembukaan laman. Sila lihat [[Special:ProtectedPages|senarai laman dilindungi]] untuk rujukan lanjut.',
 'protectedarticle'            => 'melindungi "[[$1]]"',
 'modifiedarticleprotection'   => 'menukar peringkat perlindungan bagi "[[$1]]"',
 'unprotectedarticle'          => 'menyahlindung "[[$1]]"',
@@ -1697,7 +1700,7 @@
 
 # Undelete
 'undelete'                     => 'Lihat laman-laman yang dihapuskan',
-'undeletepage'                 => 'Lihat dan pulihkan laman yang dihapuskan.',
+'undeletepage'                 => 'Lihat dan pulihkan laman yang dihapuskan',
 'undeletepagetitle'            => "'''Berikut ialah semakan-semakan [[:$1|$1]] yang telah dihapuskan'''.",
 'viewdeletedpage'              => 'Lihat laman-laman yang dihapuskan',
 'undeletepagetext'             => 'Laman-laman berikut telah dihapuskan tetapi masih disimpan dalam arkib dan
@@ -1754,9 +1757,9 @@
 'blanknamespace' => '(Utama)',
 
 # Contributions
-'contributions' => 'Sumbangan pengguna',
+'contributions' => 'Sumbangan',
 'mycontris'     => 'Sumbangan saya',
-'contribsub2'   => 'Bagi $1 ($2)',
+'contribsub2'   => 'Oleh $1 ($2)',
 'nocontribs'    => 'Tiada sebarang perubahan yang sepadan dengan kriteria-kriteria ini.',
 'uctop'         => ' (puncak)',
 'month'         => 'Sebelum bulan:',
@@ -1771,7 +1774,7 @@
 
 # What links here
 'whatlinkshere'            => 'Pautan ke laman ini',
-'whatlinkshere-title'      => 'Laman yang mengandungi pautan ke $1',
+'whatlinkshere-title'      => 'Laman yang mengandungi pautan ke "$1"',
 'whatlinkshere-page'       => 'Laman:',
 'linklistsub'              => '(Senarai pautan masuk)',
 'linkshere'                => "Laman-laman berikut mengandungi pautan ke '''[[:$1]]''':",
@@ -1787,7 +1790,7 @@
 'whatlinkshere-hidetrans'  => '$1 kemasukan',
 'whatlinkshere-hidelinks'  => '$1 pautan',
 'whatlinkshere-hideimages' => '$1 pautan imej',
-'whatlinkshere-filters'    => 'Penapis',
+'whatlinkshere-filters'    => 'Tapis',
 
 # Block/unblock
 'blockip'                         => 'Sekat pengguna',
@@ -1813,8 +1816,8 @@
 ** Menyalahgunakan berbilang akaun
 ** Nama pengguna yang tidak sesuai',
 'ipbanononly'                     => 'Sekat pengguna tanpa nama sahaja',
-'ipbcreateaccount'                => 'Halang pembukaan akaun baru',
-'ipbemailban'                     => 'Menghalang pengguna daripada mengirim e-mel',
+'ipbcreateaccount'                => 'Halang pengguna tersebut daripada membuka akaun baru',
+'ipbemailban'                     => 'Halang pengguna tersebut daripada mengirim e-mel',
 'ipbenableautoblock'              => 'Sekat alamat IP terakhir dan mana-mana alamat berikutnya yang digunakan oleh pengguna ini secara automatik',
 'ipbsubmit'                       => 'Sekat pengguna ini',
 'ipbother'                        => 'Waktu lain:',
@@ -1826,7 +1829,7 @@
 'badipaddress'                    => 'Alamat IP tidak sah',
 'blockipsuccesssub'               => 'Sekatan berjaya',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] telah disekat.
-<br />Sila lihat [[Special:Ipblocklist|senarai sekatan IP]] untuk maklumat lanjut.',
+<br />Sila lihat [[Special:IPBlockList|senarai sekatan IP]] untuk maklumat lanjut.',
 'ipb-edit-dropdown'               => 'Sunting sebab sekatan',
 'ipb-unblock-addr'                => 'Nyahsekat $1',
 'ipb-unblock'                     => 'Nyahsekat nama pengguna atau alamat IP',
@@ -1837,7 +1840,7 @@
 'ipusubmit'                       => 'Nyahsekat alamat ini.',
 'unblocked'                       => '[[User:$1|$1]] telah dinyahsekat',
 'unblocked-id'                    => 'Sekatan $1 telah dibuang',
-'ipblocklist'                     => 'Nama pengguna dan alamat IP yang disekat',
+'ipblocklist'                     => 'Alamat IP dan nama pengguna yang disekat',
 'ipblocklist-legend'              => 'Cari pengguna yang disekat',
 'ipblocklist-username'            => 'Nama pengguna atau alamat IP:',
 'ipblocklist-submit'              => 'Cari',
@@ -1858,7 +1861,7 @@
 'blocklogentry'                   => 'menyekat [[$1]] sehingga $2 $3',
 'blocklogtext'                    => 'Ini adalah log bagi sekatan dan penyahsekatan.
 Alamat IP yang disekat secara automatik tidak disenaraikan di sini. Sila lihat
-[[Special:Ipblocklist|senarai sekatan IP]] untuk mengetahui sekatan-sekatan yang sedang dijalankan.',
+[[Special:IPBlockList|senarai sekatan IP]] untuk mengetahui sekatan-sekatan yang sedang dijalankan.',
 'unblocklogentry'                 => 'menyahsekat $1',
 'block-log-flags-anononly'        => 'pengguna tanpa nama sahaja',
 'block-log-flags-nocreate'        => 'pembukaan akaun dimatikan',
@@ -1900,7 +1903,7 @@
 'lockdbsuccesssub'    => 'Pangkalan data dikunci.',
 'unlockdbsuccesssub'  => 'Kunci pangkalan data dibuka.',
 'lockdbsuccesstext'   => 'Pangkalan data telah dikunci.
-<br />Pastikan anda [[Special:Unlockdb|membukanya semula]] selepas penyelenggaraan selesai.',
+<br />Pastikan anda [[Special:UnlockDB|membukanya semula]] selepas penyelenggaraan selesai.',
 'unlockdbsuccesstext' => 'Kunci pangkalan data {{SITENAME}} telah dibuka.',
 'lockfilenotwritable' => 'Fail kunci pangkalan data tidak boleh ditulis. Untuk mengunci atau membuka kunci pangkalan data, fail ini perlu diubah suai supaya boleh ditulis oleh pelayan web ini.',
 'databasenotlocked'   => 'Pangkalan data tidak dikunci.',
@@ -1908,21 +1911,19 @@
 # Move page
 'move-page'               => 'Pindah $1',
 'move-page-legend'        => 'Pindah laman',
-'movepagetext'            => "Gunakan borang di bawah untuk menukar nama laman dan memindahkan semua maklumat sejarahnya kepada nama baru. Tajuk yang lama akan dijadikan lencongan ke tajuk yang baru. Pautan ke tajuk yang lama tidak akan diubah, oleh itu sila semak sekiranya terdapat lencongan berganda atau lencongan rosak. Anda bertanggungjawab memastikan semua pautan bersambung ke laman yang sepatutnya.
+'movepagetext'            => "Gunakan borang di bawah untuk menukar nama laman dan memindahkan semua maklumat sejarahnya ke nama baru. Tajuk yang lama akan dijadikan lencongan ke tajuk yang baru. Anda juga boleh mengemaskinikan semua lencongan yang menuju ke tajuk asal supaya menuju ke tajuk baru. Sebaliknya, anda boleh menyemak sekiranya terdapat [[Special:DoubleRedirects|lencongan berganda]] atau [[Special:BrokenRedirects|lencongan rosak]]. Anda bertanggungjawab memastikan semua pautan bersambung ke laman yang sepatutnya.
 
 Sila ambil perhatian bahawa laman tersebut '''tidak''' akan dipindahkan sekiranya laman dengan tajuk yang baru tadi telah wujud, melainkan apabila
 laman tersebut kosong atau merupakan laman lencongan dan tidak mempunyai sejarah penyuntingan. Ini bermakna anda boleh menukar semula nama sesebuah
 laman kepada nama yang asal jika anda telah melakukan kesilapan, dan anda tidak boleh menulis ganti laman yang telah wujud.
 
-<b>AMARAN!</b> Tindakan ini boleh menjadi perubahan yang tidak dijangka dan drastik bagi laman popular; sila pastikan anda faham akibat yang mungkin timbul sebelum meneruskannya.",
+'''AMARAN!''' Tindakan ini boleh menjadi perubahan yang tidak dijangka dan drastik bagi laman popular. Oleh itu, sila pastikan anda faham akibat yang mungkin timbul sebelum meneruskannya.",
 'movepagetalktext'        => "Laman perbincangan yang berkaitan, jika ada, akan dipindahkan bersama-sama laman ini secara automatik '''kecuali''':
 * Sebuah laman perbincangan dengan nama baru telah pun wujud, atau
 * Anda membuang tanda kotak di bawah.
 
 Dalam kes tersebut, anda terpaksa melencongkan atau menggabungkan laman secara manual, jika perlu.",
 'movearticle'             => 'Pindah laman:',
-'movenologin'             => 'Belum log masuk.',
-'movenologintext'         => 'Anda mesti [[Special:Userlogin|log masuk]] terlebih dahulu untuk memindahkan laman.',
 'movenotallowed'          => 'Anda tidak mempunyai keizinan untuk memindahkan laman dalam {{SITENAME}}.',
 'newtitle'                => 'Kepada tajuk baru:',
 'move-watch'              => 'Pantau laman ini',
@@ -1951,7 +1952,7 @@
 'delete_and_move'         => 'Hapus dan pindah',
 'delete_and_move_text'    => '==Penghapusan diperlukan==
 
-Laman destinasi "[[$1]]" telah pun wujud. Adakah anda mahu menghapuskannya supaya laman ini dapat dipindahkan?',
+Laman destinasi "[[:$1]]" telah pun wujud. Adakah anda mahu menghapuskannya supaya laman ini dapat dipindahkan?',
 'delete_and_move_confirm' => 'Ya, hapuskan laman ini',
 'delete_and_move_reason'  => 'Dihapuskan supaya laman lain dapat dipindahkan',
 'selfmove'                => 'Tajuk sumber dan tajuk destinasi tidak boleh sama.',
@@ -1959,6 +1960,7 @@
 'imagenocrossnamespace'   => 'Tidak boleh memindah fail ke ruang nama lain',
 'imagetypemismatch'       => 'Sambungan baru fail tersebut tidak sepadan dengan jenisnya',
 'imageinvalidfilename'    => 'Nama fail imej sasaran tidak sah',
+'fix-double-redirects'    => 'Kemas kinikan semua lencongan yang menuju ke tajuk asal',
 
 # Export
 'export'            => 'Eksport laman',
@@ -2148,10 +2150,11 @@
 'markedaspatrollederror-noautopatrol' => 'Anda tidak dibenarkan menandakan perubahan anda sendiri sebagai telah diperiksa.',
 
 # Patrol log
-'patrol-log-page' => 'Log pemeriksaan',
-'patrol-log-line' => 'menandakan $1 bagi $2 sebagai telah diperiksa $3',
-'patrol-log-auto' => '(automatik)',
-'patrol-log-diff' => 's$1',
+'patrol-log-page'   => 'Log pemeriksaan',
+'patrol-log-header' => 'Berikut ialah log rondaan bagi semakan.',
+'patrol-log-line'   => 'menandakan $1 bagi $2 sebagai telah diperiksa $3',
+'patrol-log-auto'   => '(automatik)',
+'patrol-log-diff'   => 's$1',
 
 # Image deletion
 'deletedrevision'                 => 'Menghapuskan semakan lama $1.',
@@ -2170,7 +2173,7 @@
 
 # Media information
 'mediawarning'         => "'''Amaran''': Fail ini boleh mengandungi kod yang berbahaya dan merosakkan komputer anda.<hr />",
-'imagemaxsize'         => 'Hadkan saiz imej pada laman huraian imej kepada:',
+'imagemaxsize'         => 'Had saiz imej di laman keterangannya:',
 'thumbsize'            => 'Saiz imej ringkas:',
 'widthheightpage'      => '$1×$2, $3 halaman',
 'file-info'            => '(saiz file: $1, jenis MIME: $2)',
@@ -2180,10 +2183,10 @@
 'show-big-image'       => 'Leraian penuh',
 'show-big-image-thumb' => '<small>Saiz pratonton ini: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeri fail baru',
 'imagelisttext'         => "Berikut ialah senarai bagi '''$1''' fail yang disusun secara $2.",
-'newimages-summary'     => 'Laman khas ini memaparkan senarai fail muat naik terakhir',
+'newimages-summary'     => 'Laman khas ini memaparkan senarai fail muat naik terakhir.',
 'showhidebots'          => '($1 bot)',
 'noimages'              => 'Tiada imej.',
 'ilsubmit'              => 'Cari',
@@ -2467,7 +2470,7 @@
 
 # External editor support
 'edit-externally'      => 'Sunting fail ini menggunakan perisian luar',
-'edit-externally-help' => 'Lihat [http://meta.wikimedia.org/wiki/Help:External_editors arahan pemasangan] untuk maklumat lanjut.',
+'edit-externally-help' => 'Lihat [http://www.mediawiki.org/wiki/Manual:External_editors arahan pemasangan] untuk maklumat lanjut.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'semua',
@@ -2539,7 +2542,7 @@
 'recreate'            => 'Cipta semula',
 
 # HTML dump
-'redirectingto' => 'Melencong ke [[$1]]...',
+'redirectingto' => 'Melencong ke [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Kosongkan fail simpanan bagi laman ini?
@@ -2636,7 +2639,7 @@
 'version-software-product'         => 'Produk',
 'version-software-version'         => 'Versi',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Laluan fail',
 'filepath-page'    => 'Fail:',
 'filepath-submit'  => 'Laluan',
@@ -2675,7 +2678,7 @@
 'specialpages-group-redirects'   => 'Laman khas yang melencong',
 'specialpages-group-spam'        => 'Alatan spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Laman kosong',
 'intentionallyblankpage' => 'Laman ini sengaja dibiarkan kosong dan digunakan untuk kerja-kerja ujian dan sebagainya.',
 
Index: languages/messages/MessagesBa.php
===================================================================
--- languages/messages/MessagesBa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Рустам Нурыев
- * @author Siebrand
  */
 
 $fallback = 'ru';
@@ -226,7 +225,7 @@
 # Recent changes linked
 'recentchangeslinked' => 'Бәйле үҙгәртеүҙәр',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_user' => 'Ҡатнашыусы',
 
 # MIME search
@@ -250,7 +249,7 @@
 # Special:Log
 'specialloguserlabel' => 'Ҡатнашыусы:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Бөтә биттәр',
 'alphaindexline'    => '$1 алып $2 тиклем',
 'allpagesfrom'      => 'Ошондай хәрефтәрҙән башланған биттәрҙе күрһәтергә:',
Index: languages/messages/MessagesBe.php
===================================================================
--- languages/messages/MessagesBe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Mienski
  * @author Yury Tarasievich
- * @author Mienski
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -343,7 +342,7 @@
 'nosuchspecialpage' => 'Няма такой адмысловай старонкі',
 'nospecialpagetext' => "<big>'''Вы звярнуліся па няправільную адмысловую старонку.'''</big>
 
-Пералік правільных адмысловых старонак ёсць на [[Special:Specialpages|{{int:specialpages}}]].",
+Пералік правільных адмысловых старонак ёсць на [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Памылка',
@@ -375,8 +374,8 @@
 
 Звычайна так бывае, калі адкрываюць састарэлую розніцу (diff) або спасылку з гісторыі сцёртай старонкі.
 
-Калі гэта не так, магчыма, гэта памылка ў праграмах.
-Паведамце пра гэта адміністратару, разам з URL.',
+Калі гэта не так, то, магчыма, гэта памылка ў праграмах.
+Паведамце пра гэта, разам з праблемным URL, аднаму з [[{{ns:Special}}:ListUsers/sysop|адміністратараў]].',
 'missingarticle-rev'   => '(версія #: $1)',
 'missingarticle-diff'  => '(розн.: $1, $2)',
 'readonly_lag'         => 'База даных была аўтаматычна зачынена, каб з ёй маглі ўзгадніцца яе базы-паслядоўнікі',
@@ -426,8 +425,9 @@
 
 # Login and logout pages
 'logouttitle'                => 'Выхад з сістэмы',
-'logouttext'                 => '<strong>Вы выйшлі з сістэмы.</strong><br />
-Можна працягваць працу ананімна, або можна ўвайсці ізноў, пад тым самым, ці пад іншым удзельніцкім імем. Заўважце, што некаторыя старонкі могуць паказвацца так, быццам вы яшчэ не выйшлі; у такім разе трэба ачысціць кэш вашага браўзера.',
+'logouttext'                 => '<strong>Вы выйшлі з сістэмы.</strong>
+
+Можна працягваць працу на {{SITENAME}} ананімна, або можна [[{{ns:Special}}:Userlogin|ўвайсці ў сістэму ізноў]], пад тым самым або пад іншым удзельніцкім імем. Заўважце, што некаторыя старонкі могуць паказвацца так, быццам вы яшчэ не выйшлі; у такім разе трэба ачысціць кэш вашага браўзера.',
 'welcomecreation'            => '== Вітаем, $1! == Ваш  рахунак быў створаны. Не забудзьцеся дапасаваць свае настаўленні ў {{SITENAME}}.',
 'loginpagetitle'             => 'Уваход у сістэму',
 'yourname'                   => 'Імя ўдзельніка',
@@ -439,7 +439,7 @@
 'loginproblem'               => '<b>Праблема пры спробе ўваходу ў сістэму.</b><br />Паспрабуйце ізноў!',
 'login'                      => 'Увайсці ў сістэму',
 'nav-login-createaccount'    => 'Увайсці ў сістэму / стварыць рахунак',
-'loginprompt'                => 'Каб уваходзіць у сістэму {{SITENAME}}, трэба дазволіць у браўзеры квіткі (кукі).',
+'loginprompt'                => 'Каб [[{{ns:Special}}:Userlogin|уваходзіць у сістэму {{SITENAME}}]], трэба дазволіць у браўзеры квіткі (кукі).',
 'userlogin'                  => 'Увайсці ў сістэму / стварыць рахунак',
 'logout'                     => 'Выйсці з сістэмы',
 'userlogout'                 => 'Выйсці з сістэмы',
@@ -567,8 +567,8 @@
 * Атрымальнік блока: $7
 
 Вы можаце звярнуцца да $1 або да аднаго з іншых [[{{MediaWiki:Grouppage-sysop}}|адміністратараў]], каб паразмаўляць пра гэты блок.
-Дзеля гэтага вы не зможаце карыстацца функцыяй ''{{:{{ns:mediawiki}}:emailuser/be}}'', калі гэта вам забаронена, або калі вы не наставілі правільнага пацверджанага адрасу эл.пошты ў [[Special:Preferences|настаўленнях]].
-Ваш адрас IP: $3, нумар блоку: #$5. Вы павінны дадаваць хоць адно з гэтых двух палёў да кожнага свайго звароту, датычнага гэтага блоку.",
+Вы не зможаце дзеля гэтага карыстацца функцыяй ''{{:{{ns:mediawiki}}:emailuser/be}}'', калі гэта вам забаронена, або калі вы не наставілі правільнага пацверджанага адрасу эл.пошты ў сваіх [[Special:Preferences|настаўленнях]].
+Ваш адрас IP: $3, нумар блоку: #$5. Падавайце ўсе гэтыя звесткі ў кожным сваім звароце адносна гэтага блоку.",
 'autoblockedtext'                  => "Ваш адрас IP быў аўтаматычна заблакаваны, таму што ім карыстаўся ўдзельнік, заблакаваны адміністратарам $1.
 Пададзеная прычына блоку:
 
@@ -576,21 +576,18 @@
 
 * Блок пастаўлены: $8
 * Блок канчаецца: $6
+* Атрымальнік блоку: $7
 
 Вы можаце звярнуцца да $1 або да аднаго з іншых [[{{MediaWiki:Grouppage-sysop}}|адміністратараў]], каб паразмаўляць пра гэты блок.
 
-Дзеля гэтага вы не зможаце карыстацца функцыяй ''Эл.пошта ўдзельніка'', калі гэта вам забаронена, або калі вы не наставілі правільнага пацверджанага адрасу эл.пошты ў [[Special:Preferences|настаўленнях]].
+Вы не зможаце дзеля гэтага карыстацца функцыяй ''{{:{{ns:mediawiki}}:emailuser/be}}'', калі гэта вам забаронена, або калі вы не наставілі правільнага пацверджанага адрасу эл.пошты ў сваіх [[{{ns:Special}}:Preferences|настаўленнях]].
 
-Ваш нумар блоку: $5. Вы павінны дадаваць гэты нумар да кожнага свайго звароту, датычнага гэтага блоку.",
+Ваш адрас IP: $3. Ваш нумар блоку: $5. Падавайце ўсе гэтыя звесткі ў кожным сваім звароце адносна гэтага блоку.",
 'blockednoreason'                  => 'прычына не вызначана',
 'blockedoriginalsource'            => "Крынічны тэкст '''$1''' паказаны ніжэй:",
 'blockededitsource'                => "Тэкст '''вашых правак''' у '''$1''' паказаны ніжэй:",
-'whitelistedittitle'               => 'Каб правіць старонку, трэба ўвайсці ў сістэму',
+'whitelistedittitle'               => 'Каб правіць старонкі, трэба ўвайсці ў сістэму',
 'whitelistedittext'                => 'Належыць $1 каб правіць старонкі.',
-'whitelistreadtitle'               => 'Каб чытаць, патрэбны ўваход у сістэму',
-'whitelistreadtext'                => 'Трэба [[Special:Userlogin|ўвайсці ў сістэму]] каб адкрываць старонкі.',
-'whitelistacctitle'                => 'Вам не дазволена ствараць рахункаў',
-'whitelistacctext'                 => 'Каб магчы ствараць рахункі на пляцоўцы {{SITENAME}}, вам трэба [[Special:Userlogin|ўвайсці ў сістэму]] і мець неабходныя паўнамоцтвы.',
 'confirmedittitle'                 => 'Для рэдагавання патрабуецца пацверджаны адрас эл.пошты',
 'confirmedittext'                  => 'Вам трэба пацвердзіць свой адрас эл.пошты перад тым, як правіць старонкі.
 Вызначце і пацвердзіце адрас ў сваіх [[Special:Preferences|настáўленнях]].',
@@ -603,7 +600,7 @@
 'accmailtext'                      => 'Пароль для "$1" быў адасланы на $2.',
 'newarticle'                       => '(Новы)',
 'newarticletext'                   => 'Вы перайшлі да старонкі, якой яшчэ няма, і таму трапілі сюды. Каб пачаць новую старонку, пішыце яе тэкст у ніжэйпаказаным акне рэдагавання (падрабязнасці бач у [[{{MediaWiki:Helppage}}|даведцы]]). Калі вы тут выпадкова, проста націсніце "назад" у браўзеры.',
-'anontalkpagetext'                 => "----''Гэта старонка размовы з ананімным удзельнікам, які або не мае свайго рахунку, або ім не карыстаўся. Таму дзеля яго ці яе ідэнтыфікацыі мы мусім выкарыстаць лічбавы Адрас IP. Такі адрас IP могуць дзяліць між сабою некалькі асоб. Калі вы ананімны ўдзельнік, і лічыце, што атрымліваеце няслушныя заўвагі,[[Special:Userlogin|завядзіце сабе рахунак або ўвайдзіце ў сістэму]], каб вас больш не блыталі з іншымі ананімнымі ўдзельнікамі.''",
+'anontalkpagetext'                 => "----''Гэта старонка размовы з ананімным удзельнікам, які або не мае свайго рахунку, або ім не карыстаўся. Таму дзеля яго ці яе ідэнтыфікацыі мы мусім выкарыстаць лічбавы Адрас IP. Такі адрас IP могуць дзяліць між сабою некалькі асоб. Калі вы ананімны ўдзельнік, і лічыце, што атрымліваеце няслушныя заўвагі,[[Special:UserLogin|завядзіце сабе рахунак або ўвайдзіце ў сістэму]], каб вас больш не блыталі з іншымі ананімнымі ўдзельнікамі.''",
 'noarticletext'                    => 'Такая старонка яшчэ не існуе. Вы можаце [[Special:Search/{{PAGENAME}}|пашукаць такога тэксту]] ў іншых артыкулах, або [{{fullurl:{{FULLPAGENAME}}|action=edit}} стварыць новы артыкул].',
 'userpage-userdoesnotexist'        => 'Рахунак удзельніка "$1" не зарэгістраваны. Праверце, ці вы жадаеце стварыць або паправіць гэтую старонку.',
 'clearyourcache'                   => "'''Заўвага:''' Пасля замацоўвання, вам можа спатрэбіцца ачыстка кэшу браўзера, каб пабачыць унесеныя змяненні. '''Mozilla / Firefox / Safari:''' націсніце '''Reload''', утрымліваючы ''Shift'', або націсніце ''Ctrl-F5'' ці ''Ctrl-R'' (''Cmd-R'' на Макінтошах); '''Konqueror:''': націсніце ''Reload'' або ''F5''; '''Opera''': увайдзіце ў настаўленні карыстальніка (меню ''Tools'', падпункт ''Preferences''), там ачысціце кэш; '''Internet Explorer:''' націсніце ''Refresh'', утрымліваючы ''Ctrl'', або націсніце ''Ctrl-F5''.",
@@ -616,12 +613,12 @@
 'previewnote'                      => '<strong>Гэта папярэдні паказ; праўкі яшчэ не замацаваныя!</strong>',
 'previewconflict'                  => 'Гэта папярэдні паказ магчымага выніку замацоўвання актуальнага стану крынічнага тэксту ў верхнім тэкставым полі.',
 'session_fail_preview'             => '<strong>Прабачце! Не ўдалося апрацаваць вашую праўку, таму што сервер не атрымаў поўных звестак аб вашым сеансе.
-Паспрабуйце, калі ласка, ізноў. Калі памылка не знікае, паспрабуйце выйсці з сістэмы і зайсці ізноў.</strong>',
+Паспрабуйце, калі ласка, ізноў. Калі памылка не знікае, паспрабуйце [[{{ns:Special}}:UserLogout|выйсці з сістэмы]] і зайсці ізноў.</strong>',
 'session_fail_preview_html'        => "<strong>Не ўдалося апрацаваць вашую праўку з-за таго, што згубіліся даныя аб сеансе.</strong>
 
-''Перадпаказ не зроблены, каб засцерагчыся ад атак праз Яваскрыпт, бо на пляцоўцы {{SITENAME}} дазволены сыры код HTML.''
+''Перадпаказ не зроблены, бо на пляцоўцы {{SITENAME}} дазволены сыры код HTML, што робіць магчымымі атакі праз Яваскрыпт.''
 
-<strong>Калі гэта спроба легітымнай праўкі, паспрабуйце паўтарыць запіс ізноў. Калі і гэта не будзе працаваць, паспрабуйце выйсці з сістэмы і ўвайсці ізноў.</strong>",
+<strong>Калі гэта нармальная спроба праўкі, паспрабуйце паўтарыць запісванне. Калі і гэта не дапаможа, паспрабуйце [[{{ns:Special}}:UserLogout|выйсці з сістэмы]] і ўвайсці ізноў.</strong>",
 'token_suffix_mismatch'            => '<strong>Ваша праўка была адхілена, каб пазбегнуць сапсавання тэксту старонкі, таму што ваш браўзер папсаваў знакі прыпынку ў квітку праўкі.
 Магчыма, прычына ў выкарыстанні вамі ананімнага проксі-сервера, праграмы якога працуюць некарэктна.</strong>',
 'editing'                          => 'Правім: $1',
@@ -661,7 +658,7 @@
 'hiddencategories'                 => 'Старонка належыць да {{PLURAL:$1|1 схаванай катэгорыі|$1 схаваных катэгорый}}:',
 'nocreatetitle'                    => 'Стварэнне старонак абмежавана',
 'nocreatetext'                     => 'На пляцоўцы {{SITENAME}} магчымасці стварэння новых старонак абмежаваныя.
-Вы можаце папрацаваць з існуючай старонкай, або [[Special:Userlogin|увайсці ў сістэму, або завесці сабе рахунак]].',
+Вы можаце папрацаваць з існуючай старонкай, або [[Special:UserLogin|увайсці ў сістэму, або завесці сабе рахунак]].',
 'nocreate-loggedin'                => 'На пляцоўцы {{SITENAME}} Вам не дазволена ствараць новых старонак.',
 'permissionserrors'                => 'Памылкі дазволаў',
 'permissionserrorstext'            => 'Вам не дазволена гэтага рабіць, з наступн{{PLURAL:$1|ай прычыны|ых прычын}}:',
@@ -687,7 +684,7 @@
 'undo-success' => 'Праўку можна адкаціць, але праверце папярэдні паказ, што ніжэй, каб упэўніцца ў адпаведнасці будучых змяненняў, і толькі тады запішыце іх, каб завершыць адкат праўкі.',
 'undo-failure' => 'Немагчыма адкаціць праўку, таму што перашкаджаюць праўкі, што былі перад ёй.',
 'undo-norev'   => 'Не ўдалося адкаціць праўку, таму што яна не існуе або была сцёрта.',
-'undo-summary' => 'Адкат версіі $1 аўтарства [[Special:Contributions/$2|$2]] ([[User talk:$2|размова]])',
+'undo-summary' => 'Адкат версіі $1 аўтарства [[{{ns:Special}}:Contributions/$2|$2]] ([[{{ns:User talk}}:$2|размова]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Немагчыма стварыць рахунак',
@@ -780,7 +777,7 @@
 # Suppression log
 'suppressionlog'     => 'Журнал падаўленняў',
 'suppressionlogtext' => 'Ніжэй пералічаныя сціранні і блокі, якія датычаць зместу, скрытага ад адміністратараў.
-Бач актуальныя забароны і блокі ў [[Special:Ipblocklist|спісе блокаў IP]].',
+Бач актуальныя забароны і блокі ў [[Special:IPBlockList|спісе блокаў IP]].',
 
 # History merging
 'mergehistory'                     => "Аб'яднаць гісторыі старонак",
@@ -820,7 +817,7 @@
 # Search results
 'searchresults'             => 'Вынікі пошуку',
 'searchresulttext'          => 'Больш падрабязна пра пошук на {{SITENAME}}: [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "Вы шукалі '''[[:$1]]'''",
+'searchsubtitle'            => 'Вы шукалі \'\'\'[[:$1]]\'\'\' ([[{{ns:Special}}:Prefixindex/$1|усе назвы, што пачынаюцца з "$1"]] | [[{{ns:Special}}:WhatLinksHere/$1|усе назвы, што спасылаюцца на "$1"]])',
 'searchsubtitleinvalid'     => "Вы шукалі '''$1'''",
 'noexactmatch'              => "'''Няма старонкі з назвай \"\$1\".''' Вы можаце яе [[:\$1|стварыць]].",
 'noexactmatch-nocreate'     => "'''Няма старонкі з назвай \"\$1\".'''",
@@ -863,7 +860,7 @@
 'mypreferences'            => 'Настáўленні',
 'prefs-edits'              => 'Колькасць правак:',
 'prefsnologin'             => 'Не ўвайшлі',
-'prefsnologintext'         => 'Каб правіць асабістыя настаўленні, трэба [[Special:Userlogin|ўвайсці ў сістэму]].',
+'prefsnologintext'         => 'Каб правіць асабістыя настаўленні, трэба [[Special:UserLogin|ўвайсці ў сістэму]].',
 'prefsreset'               => 'Настаўленні вернуты да пачатковых з архіву.',
 'qbsettings'               => 'Хуткая стужка',
 'qbsettings-none'          => 'Няма',
@@ -937,7 +934,7 @@
 'userrights-reason'           => 'Тлумачэнне змянення:',
 'userrights-no-interwiki'     => 'Вам не дазволена мяняць дазволаў карыстальнікам на іншых Вікі-ах.',
 'userrights-nodatabase'       => 'Не знойдзена тут, або не існуе база даных $1.',
-'userrights-nologin'          => 'Належыць [[Special:Userlogin|увайсці ў сістэму]] на рахунак адміністратара, каб прызначаць дазволы ўдзельнікам.',
+'userrights-nologin'          => 'Належыць [[Special:UserLogin|увайсці ў сістэму]] на рахунак адміністратара, каб прызначаць дазволы ўдзельнікам.',
 'userrights-notallowed'       => 'Ваш рахунак не мае дазволаў, каб мяняць дазволы ўдзельнікаў.',
 'userrights-changeable-col'   => 'Групы, якія вам дазволена мяняць',
 'userrights-unchangeable-col' => 'Групы, якія вам не дазволена мяняць',
@@ -1067,22 +1064,22 @@
 'reupload'                    => 'Укласці нанова',
 'reuploaddesc'                => 'Спыніць укладанне і вярнуцца да пачатковага фармуляра.',
 'uploadnologin'               => 'Не ў сістэме',
-'uploadnologintext'           => 'Каб укладваць файлы, трэба [[Special:Userlogin|ўвайсці ў сістэму]].',
+'uploadnologintext'           => 'Каб укладваць файлы, трэба [[Special:UserLogin|ўвайсці ў сістэму]].',
 'upload_directory_missing'    => 'Няма каталога для ўкладаў ($1), і серверу не ўдалося яго стварыць.',
 'upload_directory_read_only'  => 'Немагчыма для веб-сервера запісаць у каталог укладаў ($1).',
 'uploaderror'                 => 'Памылка пры ўкладанні',
-'uploadtext'                  => "З дапамогай ніжэй паказанай формы можна ўкладаць файлы. Каб паказаць або знайсці раней укладзенае, трэба перайсці да [[Special:Imagelist|спісу ўкладзеных файлаў]], укладанні і сціранні таксама адзначаюцца ў [[Special:Log/upload|журнале укладанняў]].
+'uploadtext'                  => "З дапамогай формы, паказанай ніжэй, можна ўкладваць файлы. Каб паказаць або каб знайсці ўкладзенае раней, трэба перайсці да [[{{ns:Special}}:ImageList|спісу ўкладзеных файлаў]]; таксама ўкладанні, паўторныя ўкладанні і сціранні адзначаюцца ў [[{{ns:Special}}:Log/upload|журнале укладанняў]].
 
-Каб улучыць файл ў старонку, ужываецца спасылка ў выглядзе
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|альтэрн. тэкст]]</nowiki>''' or
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''', каб спаслацца адразу на файл.",
+Каб уставіць файл ў старонку, ужываецца спасылка, зробленая адным з наступных спосабаў:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' паказвае поўную версію файла
+*  '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|тлумачальны тэкст]]</nowiki></tt>''' паказвае файл, маштабаваны да шырыні 200 кропак, у рамцы, змешчанай злева, і з 'тлумачальным тэкстам' у якасці подпісу
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' не паказвае файла, а толькі спасылку на яго",
 'upload-permitted'            => 'Дазволеныя тыпы файлаў: $1.',
 'upload-preferred'            => 'Больш прыймальныя тыпы файлаў: $1.',
 'upload-prohibited'           => 'Забароненыя тыпы файлаў: $1.',
 'uploadlog'                   => 'журнал укладанняў',
 'uploadlogpage'               => 'Журнал укладанняў',
-'uploadlogpagetext'           => 'Ніжэй паказаны спіс нядаўна ўкладзеных файлаў.',
+'uploadlogpagetext'           => 'Ніжэй паказаны спіс [[{{ns:Special}}:NewImages|нядаўна ўкладзеных]] файлаў.',
 'filename'                    => 'Назва файла',
 'filedesc'                    => 'Тлумачэнне',
 'fileuploadsummary'           => 'Тлумачэнне:',
@@ -1139,9 +1136,9 @@
 'upload-proto-error'      => 'Няправільны пратакол',
 'upload-proto-error-text' => 'Укладанне файла зводдаль патрабуе URL, які пачынаецца з <code>http://</code> або <code>ftp://</code>.',
 'upload-file-error'       => 'Унутраная памылка',
-'upload-file-error-text'  => 'Унутраная памылка пры спробе стварыць на серверы тымчасовы файл. Звярніцеся да сістэмнага адміністратара.',
+'upload-file-error-text'  => 'Унутраная памылка пры спробе стварыць на серверы тымчасовы файл. Звярніцеся да аднаго з [[{{ns:Special}}:ListUsers/sysop|сістэмных адміністратараў]].',
 'upload-misc-error'       => 'Нявызначаная памылка пры ўкладанні',
-'upload-misc-error-text'  => 'Нявызначаная памылка пры ўкладанні. Праверце правільнасць і даступнасць URL і паспрабуйце ізноў. Калі праблема трывалая, звярніцеся да сістэмнага адміністратара.',
+'upload-misc-error-text'  => 'Нявызначаная памылка пры ўкладанні. Праверце правільнасць і даступнасць URL і паспрабуйце ізноў. Калі праблема трывалая, звярніцеся да аднаго з [[{{ns:Special}}:ListUsers/sysop|сістэмных адміністратараў]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Не ўдалося адкрыць URL',
@@ -1155,7 +1152,7 @@
 'upload_source_url'  => ' (сапраўдны, публічна дасягальны URL)',
 'upload_source_file' => ' (файл на вашай машыне)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Тут паказаныя ўсе ўкладзеныя файлы.
 Прадвызначаны парадак такі, што апошнія файлы паказваюцца ўверсе.
 Клік на загалоўку калонкі мяняе парадак.',
@@ -1183,7 +1180,7 @@
 'imagelinks'                     => 'Спасылкі',
 'linkstoimage'                   => 'Наступн{{PLURAL:$1|ая старонка спасылаецца|ыя $1 старонкі спасылаюцца}} на гэты файл:',
 'nolinkstoimage'                 => 'Няма старонак, якія б спасылаліся на файл.',
-'morelinkstoimage'               => 'Паказаць [[Special:Whatlinkshere/$1|больш спасылак]] на гэты файл.',
+'morelinkstoimage'               => 'Паказаць [[Special:WhatLinksHere/$1|больш спасылак]] на гэты файл.',
 'redirectstofile'                => "Наступны{{PLURAL:$1| файл з'яўляецца перасылкай|я $1 файлы з'яўляюцца перасылкамі}} да гэтага файла:",
 'duplicatesoffile'               => "Наступн{{PLURAL:$1|ы файл з'яўляецца дублікатам|ыя $1 файлы з'яўляюцца дублікатамі}} гэтага файла:",
 'sharedupload'                   => 'Гэты файл паданы для супольнага карыстання, і можа быць выкарыстаны ў іншых праектах.',
@@ -1202,18 +1199,18 @@
 # File reversion
 'filerevert'                => 'Адкаціць $1',
 'filerevert-legend'         => 'Адкат файла',
-'filerevert-intro'          => '<span class="plainlinks">Вы адкочваеце \'\'\'[[Media:$1|$1]]\'\'\' да [$4 версіі з $3, $2].</span>',
+'filerevert-intro'          => "Вы адкочваеце '''[[Media:$1|$1]]''' да [$4 версіі з $3, $2].",
 'filerevert-comment'        => 'Каментарый:',
 'filerevert-defaultcomment' => 'Адкочана да версіі з $2, $1',
 'filerevert-submit'         => 'Адкаціць',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' быў адкочаны да [$4 версіі з $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' быў адкочаны да [$4 версіі з $3, $2].",
 'filerevert-badversion'     => 'Няма старэйшай тутэйшай версіі гэтага файла з прапанаванай часавай меткай.',
 
 # File deletion
 'filedelete'                  => 'Выдаліць $1',
 'filedelete-legend'           => 'Выдаліць файл',
 'filedelete-intro'            => "Вы сціраеце '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Вы сціраеце версію \'\'\'[[Media:$1|$1]]\'\'\' з [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Вы сціраеце версію '''[[Media:$1|$1]]''' з [$4 $3, $2].",
 'filedelete-comment'          => 'Каментарый:',
 'filedelete-submit'           => 'Выдаліць',
 'filedelete-success'          => "'''$1''' быў выдалены.",
@@ -1268,7 +1265,7 @@
 Гэта дае, у сярэднім, '''\$5''' правак на старонку і '''\$6''' праглядаў на змяненне.
 
 Аб'ём [http://www.mediawiki.org/wiki/Manual:Job_queue чаргі апрацоўкі задач] складае '''\$7'''.",
-'userstatstext'          => "Тут {{PLURAL:$1|'''1''' рэгістраваны [[Special:Listusers|ўдзельнік]]|'''$1''' рэгістраваных [[Special:Listusers|удзельнікаў]]}}, з якіх '''$2''' ('''$4%''') {{PLURAL:$2|мае|маюць}} правы ''$5''.",
+'userstatstext'          => "Тут {{PLURAL:$1|'''1''' рэгістраваны [[Special:ListUsers|ўдзельнік]]|'''$1''' рэгістраваных [[Special:ListUsers|удзельнікаў]]}}, з якіх '''$2''' ('''$4%''') {{PLURAL:$2|мае|маюць}} правы ''$5''.",
 'statistics-mostpopular' => 'Самыя папулярныя старонкі',
 
 'disambiguations'      => 'Неадназначнасці',
@@ -1277,8 +1274,10 @@
 Лепей, каб яны спасылаліся на канкрэтныя тэматычныя старонкі.<br />
 Старонка лічыцца старонкай развязкі, калі ў яе ўлучаецца такі шаблон, на які спасылаецца [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Падвойныя перасылкі',
-'doubleredirectstext' => 'Кожны радок утрымлівае спасылкі на першую і другую перасылкі, а таксама мэту другой перасылкі, якая звычайна і ёсць "сапраўдная" мэтавая старонка, на якую павінна была паказваць першая перасылка.',
+'doubleredirects'            => 'Падвойныя перасылкі',
+'doubleredirectstext'        => 'Кожны радок утрымлівае спасылкі на першую і другую перасылкі, а таксама мэту другой перасылкі, якая звычайна і ёсць "сапраўдная" мэтавая старонка, на якую павінна была паказваць першая перасылка.',
+'double-redirect-fixed-move' => 'Назва [[$1]] была перанесена, і зараз перасылае да [[$2]]',
+'double-redirect-fixer'      => 'Выпраўляльнік перасылак',
 
 'brokenredirects'        => 'Паламаныя перасылкі',
 'brokenredirectstext'    => 'Наступныя перасылкі спасылаюцца на неіснуючыя старонкі:',
@@ -1364,7 +1363,7 @@
 'logempty'             => 'Нічога адпаведнага ў журнале не знойдзена.',
 'log-title-wildcard'   => 'Знайсці назвы, якія пачынаюцца з гэтага тэксту',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Усе старонкі',
 'alphaindexline'    => '$1 да $2',
 'nextpage'          => 'Наступная старонка ($1)',
@@ -1387,12 +1386,12 @@
 'special-categories-sort-count' => 'пд. колькасці',
 'special-categories-sort-abc'   => 'пд. алфавіту',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Паказаць удзельнікаў, пачаўшы з:',
 'listusers-submit'   => 'Паказаць',
 'listusers-noresult' => 'Удзельнікі не знойдзеныя.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Дазволы для груп удзельнікаў',
 'listgrouprights-summary'  => 'Гэты пералік вызначаных у гэтай вікі груп удзельнікаў, разам з прыпісанымі ім дазволамі.
 Даведацца больш пра асабістыя дазволы можна на старонцы [[{{MediaWiki:Listgrouprights-helppage}}]].',
@@ -1403,11 +1402,11 @@
 
 # E-mail user
 'mailnologin'     => 'Няма эл.адрасу',
-'mailnologintext' => 'Трэба [[Special:Userlogin|ўвайсці ў сістэму]] і мець пацверджаны адрас эл.пошты ў сваіх [[Special:Preferences|настáўленнях]], каб слаць эл.пошту іншым удзельнікам.',
+'mailnologintext' => 'Трэба [[Special:UserLogin|ўвайсці ў сістэму]] і мець пацверджаны адрас эл.пошты ў сваіх [[Special:Preferences|настáўленнях]], каб слаць эл.пошту іншым удзельнікам.',
 'emailuser'       => 'Эл.пошта ўдзельніка',
 'emailpage'       => 'Зварот да ўдзельніка праз эл.пошту',
 'emailpagetext'   => 'Калі ўдзельнік упісаў правільны адрас эл.пошты ў сваіх настаўленнях, то форма, што ніжэй, адашле туды адно паведамленне.
-Адрас эл.пошты, уведзены вамі ў сваіх настаўленнях, з\'явіцца ў полі "From" вашага ліста, і атрымальнік зможа адказаць на ваш ліст.',
+Адрас эл.пошты, уведзены вамі ў [[{{ns:Special}}:Preferences|сваіх настаўленнях]], з\'явіцца ў полі "From" вашага ліста, і атрымальнік зможа адказаць на ваш ліст.',
 'usermailererror' => "Паштовы аб'ект паведамляе пра памылку:",
 'defemailsubject' => 'эл.пошта {{SITENAME}}',
 'noemailtitle'    => 'Няма адраса электроннай пошты',
@@ -1430,10 +1429,10 @@
 'nowatchlist'          => 'Ваш спіс назіранага зараз пусты.',
 'watchlistanontext'    => 'Каб бачыць або правіць складнікі назіранага, трэба $1.',
 'watchnologin'         => 'Без прадстаўлення',
-'watchnologintext'     => 'Каб правіць свой спіс назіранага, трэба [[Special:Userlogin|ўвайсці ў сістэму]].',
+'watchnologintext'     => 'Каб правіць свой спіс назіранага, трэба [[Special:UserLogin|ўвайсці ў сістэму]].',
 'addedwatch'           => 'Дапісана да назіранага',
 'addedwatchtext'       => "Старонка \"[[:\$1]]\" была дададзена да [[Special:Watchlist|назіраных]] вамі.
-Змяненні, якія адбудуцца з гэтай старонкай і з Размовай пра яе, будуць паказвацца там, і старонка будзе '''вылучацца шрыфтам''' у [[Special:Recentchanges|спісе нядаўніх змяненняў]], каб лягчэй пазнаваць яе.
+Змяненні, якія адбудуцца з гэтай старонкай і з Размовай пра яе, будуць паказвацца там, і старонка будзе '''вылучацца шрыфтам''' у [[Special:RecentChanges|спісе нядаўніх змяненняў]], каб лягчэй пазнаваць яе.
 
 Калі вы не пажадаеце больш назіраць за гэтай старонкай, націсніце \"Не назіраць\" у бакоўцы.",
 'removedwatch'         => 'Вынята са спісу назіранага',
@@ -1543,7 +1542,7 @@
 'rollback-success'            => 'Адкочаны праўкі $1; вернута апошняя версія $2.',
 'sessionfailure'              => 'Магчыма, ёсць праблемы з вашым сеансам працы ў сістэме. Таму вам было адмоўлена ў выкананні дзеяння, каб засцерагчыся ад захопу сеанса. Націсніце "Назад", і перачытайце старонку, з якой вы сюды прыйшлі, тады паспрабуйце нанова.',
 'protectlogpage'              => 'Журнал аховы',
-'protectlogtext'              => 'Ніжэй паказаная хроніка пастаноўкі старонак пад ахову і здымання з іх аховы. Гл. [[Special:Protectedpages|пералік старонак пад аховай]], каб бачыць актуальную ахову старонак.',
+'protectlogtext'              => 'Ніжэй паказаная хроніка пастаноўкі старонак пад ахову і здымання з іх аховы. Гл. [[Special:ProtectedPages|пералік старонак пад аховай]], каб бачыць актуальную ахову старонак.',
 'protectedarticle'            => 'пад аховай «[[$1]]»',
 'modifiedarticleprotection'   => 'зменены ўзровень аховы "[[$1]]"',
 'unprotectedarticle'          => 'знятая ахова з "[[$1]]"',
@@ -1643,7 +1642,7 @@
 'year'          => 'Ад году (і раней):',
 
 'sp-contributions-newbies'     => 'Паказваць толькі ўклады з новых рахункаў',
-'sp-contributions-newbies-sub' => 'Для новых рахункаў',
+'sp-contributions-newbies-sub' => 'З новых рахункаў',
 'sp-contributions-blocklog'    => 'Журнал забаронаў',
 'sp-contributions-search'      => 'Знайсці ўклад',
 'sp-contributions-username'    => 'Адрас IP або імя ўдзельніка:',
@@ -1651,7 +1650,7 @@
 
 # What links here
 'whatlinkshere'            => 'Сюды спасылаюцца',
-'whatlinkshere-title'      => 'Старонкі, якія спасылаюцца на $1',
+'whatlinkshere-title'      => 'Старонкі, якія спасылаюцца на "$1"',
 'whatlinkshere-page'       => 'Старонка:',
 'linklistsub'              => '(спіс спасылак)',
 'linkshere'                => "Старонкі, якія спасылаюцца на '''[[:$1]]''':",
@@ -1702,7 +1701,7 @@
 'badipaddress'                    => 'Недапушчальны адрас IP',
 'blockipsuccesssub'               => 'Паспяховае блакаванне',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] быў заблакаваны.<br />
-Блокі пералічаныя ў [[Special:Ipblocklist|спісе IP-блокаў]].',
+Блокі пералічаныя ў [[Special:IPBlockList|спісе IP-блокаў]].',
 'ipb-edit-dropdown'               => 'Прычыны пастаноўкі блока',
 'ipb-unblock-addr'                => 'Зняць блок з $1',
 'ipb-unblock'                     => 'Зняць блок з імя ўдзельніка або адрасу IP',
@@ -1732,7 +1731,7 @@
 'autoblocker'                     => 'Аўтаматычны блок таму што вашым адрасам IP нядаўна карыстаўся "[[User:$1|$1]]". Блакаванне $1\'s патлумачана так: "\'\'\'$2\'\'\'"',
 'blocklogpage'                    => 'Журнал блокаў',
 'blocklogentry'                   => 'пастаўлены блок на "[[$1]]", з часам трывання $2 $3',
-'blocklogtext'                    => 'Журнал пастаноўкі і здымання блокаў. Аўтаматычна блакаваныя адрасы IP тут не паказваюцца. Спіс актуальных забарон і блокаў бач у [[Special:Ipblocklist|спісе блокаў IP]].',
+'blocklogtext'                    => 'Журнал пастаноўкі і здымання блокаў. Аўтаматычна блакаваныя адрасы IP тут не паказваюцца. Спіс актуальных забарон і блокаў бач у [[Special:IPBlockList|спісе блокаў IP]].',
 'unblocklogentry'                 => 'зняты блок з $1',
 'block-log-flags-anononly'        => 'толькі ананімныя ўдзельнікі',
 'block-log-flags-nocreate'        => 'стварэнне рахунку не дазволена',
@@ -1771,7 +1770,7 @@
 'lockdbsuccesssub'    => 'Паспяховае зачыненне базы',
 'unlockdbsuccesssub'  => 'Быў зняты замок з базы дадзеных',
 'lockdbsuccesstext'   => 'База даных была зачынена.
-<br />Памятайце, каб [[Special:Unlockdb|сцерці файл-замок]] пасля завяршэння абслугоўвання.',
+<br />Памятайце, каб [[Special:UnlockDB|сцерці файл-замок]] пасля завяршэння абслугоўвання.',
 'unlockdbsuccesstext' => 'База дадзеных была адмыкнутая.',
 'lockfilenotwritable' => 'Немагчыма запісаць у файл-замок базы даных. Каб зачыняць базу, трэба, каб веб-сервер мог запісваць у гэты файл.',
 'databasenotlocked'   => 'База дадзеных не замкнутая.',
@@ -1781,10 +1780,11 @@
 'move-page-legend'        => 'Перанесці старонку',
 'movepagetext'            => "Форма, што ніжэй, перанясе старонку пад новую назву, і таксама перанясе пад новую назву ўсю гісторыю старонкі.
 Старая назва ператворыцца ў перасылку да новай.
-Спасылкі на старую назву не зменяцца, таму трэба праверыць наяўнасць падвойных ці зламаных перасылак.
+Перасылкі, што вялі да старой назвы, можна ўдакладніць аўтаматычна.
+Калі такое аўта-удакладненне не рабілася, трэба праверыць наяўнасць [[{{ns:Special}}:DoubleRedirects|падвойных]] ці [[{{ns:Special}}:BrokenRedirects|зламаных]] перасылак.
 Адказнасць за правільную працу спасылак ляжыць на тым, хто пераносіць.
 
-Заўважце, што старонка '''не будзе''' перанесена, калі пад новай назвай ужо існуе старонка, калі пры гэтым яна не пустая, не перасылка і не мае гісторыі правак. Такім чынам, запісваць паўзверх наяўных старонак нельга, а зрабіўшы пры пераносе памылку, можна адразу ж яе паправіць, пераносячы старонку ў адваротным кірунку.
+Заўважце, што старонка '''не будзе''' перанесена, калі пад новай назвай ужо існуе старонка, не пустая і не перасылка і без гісторыі правак. Такім чынам, пры пераносе нельга перапісаць наяўную старонку, а магчымую памылку можна адразу выправіць, пераносячы старонку ў адваротным кірунку.
 
 '''УВАГА!'''
 Для папулярнай старонкі гэта можа стацца рэзкай і нечаканай менай;
@@ -1795,8 +1795,6 @@
 
 У такіх выпадках, калі гэта неабходна, трэба пераносіць або аб'ядноўваць старонку размовы самастойна.",
 'movearticle'             => 'Перанесці старонку',
-'movenologin'             => 'Не зроблены ўваход у сістэму',
-'movenologintext'         => 'Вы павінны быць зарэгістраваным удзельнікам, і [[Special:Userlogin|ўвайсці ў сістэму]], каб пераносіць старонкі.',
 'movenotallowed'          => 'На пляцоўцы {{SITENAME}} Вам не дазволена пераносіць старонак.',
 'newtitle'                => 'Пад новую назву:',
 'move-watch'              => 'Назіраць за старонкай',
@@ -1825,7 +1823,7 @@
 'delete_and_move'         => 'Выдаліць і перанесці',
 'delete_and_move_text'    => '==Патрабуецца сціранне==
 
-Ужо існуе артыкул з мэтавай назвай "[[$1]]". Дык ці жадаеце сцерці яго, каб зрабіць месца для пераносу?',
+Ужо існуе артыкул з мэтавай назвай "[[:$1]]". Дык ці жадаеце сцерці яго, каб зрабіць месца для пераносу?',
 'delete_and_move_confirm' => 'Так, сцерці старонку',
 'delete_and_move_reason'  => 'Сцёрта, каб зрабіць месца для пераносу',
 'selfmove'                => 'Назвы вытока і мэты такія самыя; нельга пераносіць старонку саму на сябе.',
@@ -1833,6 +1831,7 @@
 'imagenocrossnamespace'   => 'Нельга пераносіць у не-файлавую прастору назваў',
 'imagetypemismatch'       => 'Новы канчатак назвы файла не адпавядае яго тыпу',
 'imageinvalidfilename'    => 'Недапушчальная назва мэтавага файла',
+'fix-double-redirects'    => 'Абнавіць усе перасылкі, якія вядуць да пачатковай назвы',
 
 # Export
 'export'            => 'Экспартаваць старонкі',
@@ -1878,7 +1877,7 @@
 'import-interwiki-history'   => 'Капіраваць усе гістарычныя версіі гэтай старонкі',
 'import-interwiki-submit'    => 'Імпартаваць',
 'import-interwiki-namespace' => 'Перанесці старонкі ў прастору назваў:',
-'importtext'                 => 'Экспартуйце файл з вікі-крыніцу праз старонку Special:Export, запішыце на дыск, а тады ўкладзіце сюды.',
+'importtext'                 => 'Экспартуйце файл з вытокавай вікі з дапамогай [[{{ns:Special}}:Export|прылады экспарту]], запішыце на дыск і ўкладзіце сюды.',
 'importstart'                => 'Імпартаванне старонак...',
 'import-revision-count'      => '$1 {{PLURAL:$1|версія|версій}}',
 'importnopages'              => 'Няма старонак для імпартавання.',
@@ -2028,9 +2027,10 @@
 'markedaspatrollederror-noautopatrol' => 'Вам не дазволена значыць уласныя праўкі як ухваленыя.',
 
 # Patrol log
-'patrol-log-page' => 'Журнал ухваленых',
-'patrol-log-line' => 'пазначаны $1 з ліку $2 ухваленых $3',
-'patrol-log-auto' => '(аўтаматычна)',
+'patrol-log-page'   => 'Журнал ухваленых',
+'patrol-log-header' => 'Журнал ухваленых версій',
+'patrol-log-line'   => 'пазначаны $1 з ліку $2 ухваленых $3',
+'patrol-log-auto'   => '(аўтаматычна)',
 
 # Image deletion
 'deletedrevision'                 => 'Сцёрта старая версія $1',
@@ -2059,10 +2059,10 @@
 'show-big-image'       => 'Найлепшае разрозненне',
 'show-big-image-thumb' => '<small>Памеры гэтага перадпаказу: $1 × $2 кропак</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Новыя файлы',
 'imagelisttext'         => "Ніжэй даецца спіс з '''$1''' {{PLURAL:$1|файла|файлаў}} у парадку $2.",
-'newimages-summary'     => 'Тут паказаныя нядаўна ўкладзеныя файлы',
+'newimages-summary'     => 'Тут паказаныя нядаўна ўкладзеныя файлы.',
 'showhidebots'          => '($1 робатаў)',
 'noimages'              => 'Тут нічога няма.',
 'ilsubmit'              => 'Знайсці',
@@ -2180,6 +2180,7 @@
 'exif-gpstrack'                    => 'Кірунак руху',
 'exif-gpsimgdirectionref'          => 'Пункт адліку для кірунку выявы',
 'exif-gpsimgdirection'             => 'Кірунак выявы',
+'exif-gpsmapdatum'                 => 'Скарыстаныя геадэзічныя даныя',
 'exif-gpsdestlatituderef'          => 'Пункт адліку для шыраты мэты',
 'exif-gpsdestlatitude'             => 'Шырата мэты',
 'exif-gpsdestlongituderef'         => 'Пункт адліку для даўгаты мэты',
@@ -2319,7 +2320,7 @@
 
 # External editor support
 'edit-externally'      => 'Правіць файл у вонкавай праграме',
-'edit-externally-help' => 'Глядзіце [http://meta.wikimedia.org/wiki/Help:External_editors інструкцыі па настаўлянню (англ.)] па больш падрабязнасцяў.',
+'edit-externally-help' => 'Глядзіце [http://www.mediawiki.org/wiki/Manual:External_editors інструкцыі па настаўлянню (англ.)] па больш падрабязнасцяў.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'усе',
@@ -2386,7 +2387,7 @@
 'unit-pixel' => 'крпк',
 
 # HTML dump
-'redirectingto' => 'Перасылаемся да [[$1]]...',
+'redirectingto' => 'Перасылаемся да [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Ці ачысціць кэш для гэтай старонкі?
@@ -2431,8 +2432,8 @@
 'livepreview-error'   => 'Не ўдалося далучыцца: $1 "$2". Паспрабуйце звычайны перадпаказ.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Мены, навейшыя за $1 секунд, могуць тут не паказвацца.',
-'lag-warn-high'   => 'З прычыны моцных затрымак на серверы баз даных, мены, навейшыя за $1 секунд, могуць тут не паказвацца.',
+'lag-warn-normal' => 'Мены, навейшыя за $1 {{PLURAL:$1|сек.|сек.}}, могуць не трапіць у гэты паказ.',
+'lag-warn-high'   => 'З прычыны моцных затрымак на серверы баз даных, мены, навейшыя за $1 {{PLURAL:$1|сек.|сек.}}, могуць не трапіць у гэты паказ.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'У назіраным {{PLURAL:$1|1 складнік|$1 складнікаў}}, без уліку размоўных старонак.',
@@ -2480,7 +2481,7 @@
 'version-software-product'         => 'Прадукт',
 'version-software-version'         => 'Версія',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Шлях да файла',
 'filepath-page'    => 'Файл:',
 'filepath-submit'  => 'Шлях',
@@ -2519,7 +2520,7 @@
 'specialpages-group-redirects'   => 'Адмысловыя старонкі-перасылкі',
 'specialpages-group-spam'        => 'Прылады супраць спама',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Пустая старонка',
 'intentionallyblankpage' => 'Старонка наўмысна пакінута пустой, і ўжываецца для вымярэння хуткасці і падобнага.',
 
Index: languages/messages/MessagesCeb.php
===================================================================
--- languages/messages/MessagesCeb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCeb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,9 +6,7 @@
  *
  * @author Abastillas
  * @author Jordz
- * @author SPQRobin
  * @author Palang hernan
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -75,7 +73,10 @@
 'october-gen'   => 'Oktubre',
 'november-gen'  => 'Nobyembre',
 'december-gen'  => 'Disyembre',
+'jan'           => 'Ene',
 'may'           => 'Mayo',
+'jun'           => 'Hun',
+'dec'           => 'Dis',
 
 # Categories related messages
 'pagecategories'                => '{{PLURAL:$1|Kategoriya|Mga kategoriya}}',
@@ -195,7 +196,7 @@
 'youhavenewmessagesmulti' => 'Adunay kay bag-ong mensahe sa $1',
 'editsection'             => 'usba',
 'editold'                 => 'usba',
-'viewsourceold'           => 'tan-awa ang sulod',
+'viewsourceold'           => 'tan-awa ang ginikanan',
 'editsectionhint'         => 'Usba ang seksyong: $1',
 'showtoc'                 => 'ipakita',
 'hidetoc'                 => 'tagoa',
@@ -221,7 +222,7 @@
 'nosuchspecialpage' => 'Walay maong espesyal nga panid',
 'nospecialpagetext' => "<big>'''Mihangyo ikaw sa inbalidong espesyal nga panid.'''</big>
 
-Ang lista sa mga balidong espesyal nga mga panid makita sa [[Special:Specialpages|{{int:specialpages}}]].",
+Ang lista sa mga balidong espesyal nga mga panid makita sa [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'               => 'Sayop',
@@ -240,18 +241,18 @@
 'badtitletext'        => 'Ang gihangyong titulo sa panid mahimong inbalido, walay sulod, o nasayop og sumpay nga inter-pinulongan o inter-wiki nga titulo.
 Basin aduna kini usa o daghan pang mga karakter nga dili magamit isip titulo.',
 'perfdisabled'        => "Pasayloa, ang kini nga  ''feature'' temporaryong gihunong tungod kay gipahinay niini ang ''database'' sa punto nga dili na magamit ang wiki.",
-'viewsource'          => 'Tan-awa ang sulod',
+'viewsource'          => 'Tan-awa ang ginikanan',
 'ns-specialprotected' => 'Ang mga espesyal nga panid dili mausban.',
 
 # Login and logout pages
 'logouttitle'             => 'Pagbiya sa tiggamit',
 'welcomecreation'         => '== Maayong pag-abot, $1! ==
 Nahimo na ang imong akawnt.
-Ayaw kalimot sa pag-usab sa imong {{SITENAME}} mga preperensya.',
+Ayaw kalimot sa pag-usab sa imong [[Special:Preferences|{{SITENAME}} mga preperensiya]].',
 'loginpagetitle'          => 'Pagdayon sa tiggamit',
 'yourname'                => 'Ngalan sa tiggamit:',
-'remembermypassword'      => 'Hinumdomi akong pagsulod niini nga kompyuter',
-'loginproblem'            => '<b>Naay kakulian sa imong pagsulod.</b><br />Sulayi pag-usab!',
+'remembermypassword'      => 'Hinumdomi ako niini nga kompyuter',
+'loginproblem'            => "<b>Naay kakulian sa imong pagpaila.</b><br />Sulayi'g usab!",
 'login'                   => 'Sulod',
 'nav-login-createaccount' => 'Rehistro / Dayon',
 'userlogin'               => 'Rehistro / Dayon',
@@ -262,9 +263,18 @@
 'userexists'              => 'Ang ngalan sa tiggamit nga imong gisulat nagamit na.
 Palihug pagpili og lain nga ngalan.',
 'loginerror'              => 'Sayop sa pagdayon',
-'loginsuccesstitle'       => 'Malamposong pagsulod',
+'loginsuccesstitle'       => 'Malamposon ang pagpaila',
 'loginlanguagelabel'      => 'Pinulongan: $1',
 
+# Edit page toolbar
+'bold_tip'      => 'Gilugom nga teksto',
+'italic_sample' => 'Gitakilid nga teksto',
+'italic_tip'    => 'Gitakilid nga teksto',
+'nowiki_sample' => 'Dinhi ang dili-pormaton nga teksto',
+'nowiki_tip'    => 'Dili i-wikipormat',
+'sig_tip'       => 'Ang imong pirma uban ang takna',
+'hr_tip'        => 'Pahigda nga linya (palihog usahay ra gamita)',
+
 # Edit pages
 'summary'                   => 'Mubong sugid',
 'minoredit'                 => 'Ginagmay lang nga kausaban',
@@ -273,27 +283,30 @@
 'preview'                   => 'Paunang tan-aw',
 'showpreview'               => 'Paunang tan-aw',
 'showdiff'                  => 'Ipakita ang kalainan',
-'whitelistacctitle'         => 'Gidid-an ka sa paghimo og akawnt',
+'anoneditwarning'           => "'''Pahibalo:''' Wala ikaw maka-login.
+Ang imong ''IP address'' maoy itala sa kaagi niini nga panid.",
 'newarticle'                => '(Bag-o)',
-'userpage-userdoesnotexist' => 'Ang akawnt sa tiggamit nga "$1" wala mareshistro. Palihug tan-awa kon buot nimong himuon/usbon kini nga panid.',
-'previewnote'               => 'Usa ra kini ka paunang tan-aw;
-
-<strong>Usa ra kini ka paunang tan-aw;
-wala pa matipigi ang mga pag-usab!</strong>',
+'userpage-userdoesnotexist' => 'Ang akawnt sa tiggamit nga "$1" wala marehistro. Palihug tan-awa kon buot nimong himoon/usbon ang kining panid.',
+'previewnote'               => '<strong>Hinumdomi nga kini usa lang ka paunang tan-aw; wala pa matipigi ang imong giusab!</strong>',
 'editing'                   => 'Nagausab sa $1',
 'yourtext'                  => 'Imong gisulat',
 'yourdiff'                  => 'Mga kalainan',
-'copyrightwarning'          => 'Palihog hinumdomi nga ang tanang kontribusyon sa {{SITENAME}} giisip nga ubos sa $2 (basaha ang $1 alang sa dugang hisgot). Kon dili nimo buot nga ang imong mga sinulat mausab ni bisan kinsa ug maapud-apod bisan dili ka pangayoan og pagtugot, ayaw sila ibutang dinhi.<br />
-Nagatimaan ka usab nga ikaw mismo ang nagsulat niini, o gisuno nimo kini gikan sa usa ka publikong rekursos.
-<strong>AYAW PAGBUTANG DINHI OG MGA SINULAT NGA MAY NANAG-IYA SA KATUNGOD SA PAGPATIK!</strong>',
+'copyrightwarning'          => 'Palihog hinumdomi nga ang tanang kontribusyon sa {{SITENAME}} giisip nga ubos sa $2 (basaha ang $1 alang sa dugang detalye). Kon dili nimo buot nga ang imong mga sinulat mausab ni bisan kinsa ug maapud-apod bisan dili ka pangayoan og pagtugot, ayaw sila ibutang dinhi.<br />
+Nagatimaan ka usab nga ikaw mismo ang nagsulat niini, o gikopya nimo kini gikan sa usa ka publikong rekursos o susamang libreng rekursos.
+<strong>AYAW PAGBUTANG DINHI OG MGA BINUHAT NGA MAY NANAG-IYA SA KATUNGOD SA PAGPATIK NGA WA KAY PERMISO!</strong>',
 'templatesused'             => 'Ang mga plantilyang gigamit niini nga panid:',
+'template-protected'        => '(giprotektahan)',
 
 # History pages
-'previousrevision' => '←Daang pag-usab',
+'previousrevision' => '←Mas daang pag-usab',
+'last'             => 'kataposan',
 'histfirst'        => 'Kinaunahan',
 
 # Search results
-'powersearch' => 'Abansadong pagpangita',
+'noexactmatch' => "'''Walay panid nga ginganla'g \"\$1\".'''
+Mahimo mong [[:\$1|isulat kini nga panid]].",
+'viewprevnext' => 'Tan-awa sa ($1) ($2) ($3)',
+'powersearch'  => 'Abansadong pagpangita',
 
 # Preferences page
 'mypreferences' => 'Akong preperensiya',
@@ -304,18 +317,27 @@
 'recentchanges' => 'Mga bag-ong giusab',
 'diff'          => 'kalainan',
 'hist'          => 'kaagi',
+'hide'          => 'Tagoi',
 
 # Recent changes linked
-'recentchangeslinked' => 'Mga may kalabotang kausaban',
+'recentchangeslinked'       => 'Mga may kalabotang kausaban',
+'recentchangeslinked-title' => 'Mga pag-usab nga may kalabotan sa "$1"',
 
 # Upload
 'upload' => 'Pagsumiter og payl',
 
+# Image description page
+'filehist-datetime' => 'Petsa/Takna',
+
 # Random page
 'randompage' => 'Bisan unsang panid',
 
-# Special:Allpages
+# Miscellaneous special pages
+'move' => 'Ibalhin',
+
+# Special:AllPages
 'alphaindexline' => '$1 hangtod $2',
+'allpagessubmit' => 'Sige',
 
 # Special:Categories
 'categories'                  => 'Mga kategoriya',
@@ -338,19 +360,27 @@
 'contribslink' => 'mga tampo',
 
 # Tooltip help for the actions
-'tooltip-pt-login'        => "Gihangyo ka namo sa pag-''log-in'', apan wala kini kinahanglana aron makausab ka sa mga panid.",
+'tooltip-pt-mytalk'       => 'Akong hisgot',
+'tooltip-pt-preferences'  => 'Akong mga preperensiya',
+'tooltip-pt-mycontris'    => 'Akong mga tampo',
+'tooltip-pt-login'        => "Gihangyo ka namo sa pag-''log-in'', apan wala kini gikinahanglan aron makausab ka sa mga panid.",
+'tooltip-pt-logout'       => 'Biya',
 'tooltip-ca-talk'         => 'Panaghisgot kabahin sa panid',
-'tooltip-ca-edit'         => "Mahimo mo kining usbon ang maong panid. Palihog gamita ang ''preview'' nga tuplokanan sa dili mo pa tipigan ang panid.",
-'tooltip-n-mainpage'      => 'Dalikyati ang Unang Panid',
+'tooltip-ca-edit'         => "Mahimo mong usbon ang kining panid. Palihog gamita ang ''Paunang tan-aw'' nga tuplokanan bag-o nimotipigan ang panid.",
+'tooltip-ca-move'         => 'Ibalhin kini nga panid',
+'tooltip-n-mainpage'      => 'Bisitaha ang Unang Panid',
 'tooltip-n-portal'        => 'Kabahin sa proyekto, unsay imong mahimo, asa mangita sa mga impormasyon',
 'tooltip-n-currentevents' => 'Pangita og nahaunang impormasyon sa mga bag-ong panghitabo',
-'tooltip-n-recentchanges' => 'Ang listahan sa mga bag-ong gi-usab dinhi sa wiki.',
+'tooltip-n-recentchanges' => 'Ang talaan sa mga bag-ong giusab sa wiki.',
 'tooltip-n-randompage'    => 'Pag-abli og bisan unsang panid',
 'tooltip-n-help'          => 'Ang dapit nga angay mong pangitaan.',
 'tooltip-t-whatlinkshere' => 'Talaan sa mga wiki nga panid nga misumpay dinhi',
 'tooltip-t-upload'        => 'Pagsumiter og mga payl',
 'tooltip-t-specialpages'  => 'Talaan sa mga espesyal nga panid',
 
+# 'all' in various places, this might be different for inflected languages
+'namespacesall' => 'tanan',
+
 # Special:SpecialPages
 'specialpages' => 'Espesyal nga mga panid',
 
Index: languages/messages/MessagesBi.php
===================================================================
--- languages/messages/MessagesBi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -89,7 +89,7 @@
 # Preferences page
 'servertime' => 'Taem blong server',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Nem',
 
 # Miscellaneous special pages
@@ -97,7 +97,7 @@
 'longpages'  => 'Ol big pej',
 'newpages'   => 'Ol niu pej',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'Olgeta atikel',
 
 # E-mail user
@@ -123,7 +123,7 @@
 'tooltip-n-mainpage' => 'Go long Nambawan Pej',
 'tooltip-minoredit'  => 'Em i stap wan smol jenis',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1 bot)',
 
 # EXIF tags
Index: languages/messages/MessagesBm.php
===================================================================
--- languages/messages/MessagesBm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -97,7 +97,7 @@
 'move'         => 'telun',
 'movethispage' => 'Nyɛ telun',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Nyɛw bɛɛ',
 
 # Special:Categories
@@ -121,7 +121,7 @@
 # Attribution
 'others' => 'wɛrɛ',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Nyini',
 
 # Special:SpecialPages
Index: languages/messages/MessagesCrh_cyrl.php
===================================================================
--- languages/messages/MessagesCrh_cyrl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCrh_cyrl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Alessandro
- * @author Siebrand
  * @author AlefZet
+ * @author Alessandro
  */
 
 $fallback = 'ru';
@@ -387,7 +386,7 @@
 'nosuchspecialpage' => 'Бу исимде бир махсус саифе ёкъ',
 'nospecialpagetext' => "'''<big>Тапылмагъан бир махсус саифеге кирдинъиз.</big>'''
 
-Бар олгъан бутюн махсус саифелерни [[Special:Specialpages|{{int:specialpages}}]] саифесинде корип олурсынъыз.",
+Бар олгъан бутюн махсус саифелерни [[Special:SpecialPages|{{int:specialpages}}]] саифесинде корип олурсынъыз.",
 
 # General errors
 'error'                => 'Хата',
@@ -612,10 +611,6 @@
 'blockededitsource'         => "Ашагъыда «$1» саифесиндеки '''япкъан денъиштирмелеринъизнинъ''' метини булуна.",
 'whitelistedittitle'        => 'Денъиштирмек ичюн отурым ачмалысынъыз',
 'whitelistedittext'         => 'Саифени денъиштирмек ичюн $1 керексинъиз.',
-'whitelistreadtitle'        => 'Окъумакъ ичюн отурым ачмакъ керек',
-'whitelistreadtext'         => 'Бу саифелерни окъумакъ ичюн [[Special:Userlogin|къайд олунмалысынъыз]].',
-'whitelistacctitle'         => 'Эсап ачма изининъиз ёкъ',
-'whitelistacctext'          => 'Бу викиде эсап ачмагъа чаре саиби олмакъ ичюн [[Special:Userlogin|къайд олунмакъ]] ве келишикли акълар саиби олмакъ керексинъиз.',
 'confirmedittitle'          => 'E-mail адресини тасдыкъламакъ лязимдир',
 'confirmedittext'           => 'Саифени денъиштирмеден эвель e-mail адресинъизни тасдыкъламалысынъыз. Лютфен, [[Special:Preferences|аярлар саифесинде]] e-mail адресинъизни экленъиз ве тасдыкъланъыз.',
 'nosuchsectiontitle'        => 'Ойле болюм ёкъ',
@@ -627,7 +622,7 @@
 'accmailtext'               => '$1 ичюн пароль мында ёлланды: $2.',
 'newarticle'                => '(Янъы)',
 'newarticletext'            => "Сиз бу багълантынен шимдилик ёкъ олгъан саифеге авуштынъыз. Янъы бир саифе яратмакъ ичюн ашагъыда булунгъан пенджереге метин язынъыз (тафсилятлы малюмат алмакъ ичюн [[{{MediaWiki:Helppage}}|ярдым саифесине]] бакъынъыз). Бу саифеге тесадюфен авушкъан олсанъыз, браузеринъиздеки '''кери''' дёгмесине басынъыз.",
-'anontalkpagetext'          => "----''Бу музакере саифеси шимдилик къайд олунмагъан я да отурымыны ачмагъан адсыз (аноним) къулланыджыгъа менсюптир. Идентификация ичюн IP адрес ишлетиле. Эгер сиз аноним къулланыджы олсанъыз ве сизге кельген беянатларны янълыштан кельгенини беллесенъиз (бир IP адресинден бир къач къулланыджы файдаланып олалар), лютфен, артыкъ бунынъ киби къарышыкълыкъ олмасын деп [[Special:Userlogin|отурым ачынъыз]].''",
+'anontalkpagetext'          => "----''Бу музакере саифеси шимдилик къайд олунмагъан я да отурымыны ачмагъан адсыз (аноним) къулланыджыгъа менсюптир. Идентификация ичюн IP адрес ишлетиле. Эгер сиз аноним къулланыджы олсанъыз ве сизге кельген беянатларны янълыштан кельгенини беллесенъиз (бир IP адресинден бир къач къулланыджы файдаланып олалар), лютфен, артыкъ бунынъ киби къарышыкълыкъ олмасын деп [[Special:UserLogin|отурым ачынъыз]].''",
 'noarticletext'             => 'Бу саифе боштыр. Бу серлеваны башкъа саифелерде [[Special:Search/{{PAGENAME}}|къыдырып оласынъыз]] я да бу саифени озюнъиз [{{fullurl:{{FULLPAGENAME}}|action=edit}} язып оласынъыз].',
 'userpage-userdoesnotexist' => '"$1" адлы къулланыджы ёкътыр. Тамам бу саифени денъиштирмеге истегенинъизни тешкеринъиз.',
 'clearyourcache'            => "'''Ихтар:''' Аярларынъызны сакълагъандан сонъ, браузеринъизнинъ кэшини де темизлемек керексинъиз: '''Mozilla / Firefox / Safari:''' ''Shift'' басылы экенде саифени янъыдан юклеп я да ''Ctrl-Shift-R'' япып (Apple Mac ичюн ''Cmd-Shift-R'');, '''Internet Explorer:''' ''Ctrl-F5'', '''Konqueror:''' Тек саифени янъыдан юкле дёгмесине басып.",
@@ -682,7 +677,7 @@
 'hiddencategories'          => 'Бу саифе $1 гизли категориягъа менсюптир:',
 'nocreatetitle'             => 'Саифе яратув сынъырлыдыр',
 'nocreatetext'              => '{{SITENAME}} сайтында янъы саифе яратув сынъырлыдыр.
-Кери къайтып мевджут олгъан саифени денъиштире, [[Special:Userlogin|отурым ача я да янъы бир эсап яратып оласынъыз]].',
+Кери къайтып мевджут олгъан саифени денъиштире, [[Special:UserLogin|отурым ача я да янъы бир эсап яратып оласынъыз]].',
 'nocreate-loggedin'         => '{{SITENAME}} сайтында янъы саифелер яратмагъа изининъиз ёкътыр.',
 'permissionserrors'         => 'Иришим акъларынынъ хаталары',
 'permissionserrorstext'     => 'Буны япмагъа изининъиз ёкътыр. {{PLURAL:$1|Себеп|Себеплер}}:',
@@ -777,7 +772,7 @@
 'mypreferences'         => 'Аярларым',
 'prefs-edits'           => 'Япкъан денъишиклик сайысы:',
 'prefsnologin'          => 'Отурым ачмадынъыз',
-'prefsnologintext'      => 'Шахсий аярларынъызны денъиштирмек ичюн [[Special:Userlogin|отурым ачмакъ]] керексинъиз.',
+'prefsnologintext'      => 'Шахсий аярларынъызны денъиштирмек ичюн [[Special:UserLogin|отурым ачмакъ]] керексинъиз.',
 'prefsreset'            => 'Аярлар ильк алына кетирильди.',
 'qbsettings'            => 'Вызлы иришим сутун аярлары',
 'changepassword'        => 'Пароль денъиштир',
@@ -886,10 +881,10 @@
 'reupload'                    => 'Янъыдан юкле',
 'reuploaddesc'                => 'Юклеме формасына кери къайт.',
 'uploadnologin'               => 'Отурым ачмадынъыз',
-'uploadnologintext'           => 'Файл юклеп олмакъ ичюн [[Special:Userlogin|отурым ачмакъ]] керексинъиз.',
+'uploadnologintext'           => 'Файл юклеп олмакъ ичюн [[Special:UserLogin|отурым ачмакъ]] керексинъиз.',
 'upload_directory_read_only'  => 'Web серверининъ ($1) джузьданына файллар сакъламагъа акълары ёкътыр.',
 'uploaderror'                 => 'Юклеме хатасы',
-'uploadtext'                  => "Файллар юклемек ичюн ашагъыдаки форманы къулланынъыз. Эвельдже юкленген ресим тапмакъ я да бакъмакъ ичюн [[Special:Imagelist|юкленген файллар джедвелине]] кечинъиз, бундан гъайры файл юкленюв ве ёкъ этилюв къайдларыны [[Special:Log/upload|юкленюв журналында]] тапып оласынъыз.
+'uploadtext'                  => "Файллар юклемек ичюн ашагъыдаки форманы къулланынъыз. Эвельдже юкленген ресим тапмакъ я да бакъмакъ ичюн [[Special:ImageList|юкленген файллар джедвелине]] кечинъиз, бундан гъайры файл юкленюв ве ёкъ этилюв къайдларыны [[Special:Log/upload|юкленюв журналында]] тапып оласынъыз.
 
 Саифеде ресим къулланмакъ ичюн бойле шекилли багълантылар къулланынъыз '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''', '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|ресим тарифи]]</nowiki>''' я да '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' файлгъа вастасыз багъланты ичюн.",
 'upload-permitted'            => 'Изинли файл чешитлери: $1.',
@@ -974,7 +969,7 @@
 'upload_source_url'  => ' (догъру, публик тарзда кирмеге мусаадели интернет адрес)',
 'upload_source_file' => ' (компьютеринъиздеки файл)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Файл ады къыдырув:',
 'imgfile'               => 'файл',
 'imagelist'             => 'Ресим джедвели',
@@ -1129,7 +1124,7 @@
 'logempty'             => 'Журналда бир кельген малюмат ёкъ.',
 'log-title-wildcard'   => 'Бу символлардан башлангъан серлеваларны къыдыр',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Бутюн саифелер',
 'alphaindexline'    => '$1-ден $2-ге',
 'nextpage'          => 'Сонъраки саифе ($1)',
@@ -1151,13 +1146,13 @@
 'special-categories-sort-count' => 'сайыларына коре сырала',
 'special-categories-sort-abc'   => 'элифбе сырасынен сырала',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Косьтер',
 'listusers-noresult' => 'Ич бир къулланыджы тапылмады.',
 
 # E-mail user
 'mailnologin'     => 'Мектюп ёлланаджакъ адреси ёкътыр',
-'mailnologintext' => 'Дигер къулланыджыларгъа электрон мектюплер ёллап олмакъ ичюн [[Special:Userlogin|отурым ачмалысынъыз]] ве [[Special:Preferences|аярларынъызда]] мевджут олгъан e-mail адресининъ саиби олмалысынъыз.',
+'mailnologintext' => 'Дигер къулланыджыларгъа электрон мектюплер ёллап олмакъ ичюн [[Special:UserLogin|отурым ачмалысынъыз]] ве [[Special:Preferences|аярларынъызда]] мевджут олгъан e-mail адресининъ саиби олмалысынъыз.',
 'emailuser'       => 'Къулланыджыгъа мектюп',
 'emailpage'       => 'Къулланыджыгъа электрон мектюп ёлла',
 'emailpagetext'   => 'Ишбу къулланыджы озь аярларында мевджут олгъан электрон почта адресини язгъан олса, ашагъыдаки форманы толдурып онъа беянат ёллап олурсынъыз.
@@ -1183,10 +1178,10 @@
 'nowatchlist'          => 'Сизинъ козетюв джедвелинъиз боштыр.',
 'watchlistanontext'    => 'Козетюв джедвелини бакъмакъ я да денъиштирмек ичюн $1 борджлусынъыз.',
 'watchnologin'         => 'Отурым ачмакъ керек',
-'watchnologintext'     => 'Озь козетюв джедвелинъизни денъиштирмек ичюн [[Special:Userlogin|отурым ачынъыз]]',
+'watchnologintext'     => 'Озь козетюв джедвелинъизни денъиштирмек ичюн [[Special:UserLogin|отурым ачынъыз]]',
 'addedwatch'           => 'Козетюв джедвелине кирсетмек',
 'addedwatchtext'       => '"[[:$1]]" саифеси [[Special:Watchlist|козетюв джевделинъизге]] кирсетильди.
-Бу саифедеки ве онынънен багълы саифелердеки оладжакъ денъишикликлер бу джедвельде бельгиленеджек, эм де олар козьге чарпмасы ичюн [[Special:Recentchanges|янъы денъишиклик джедвели]] булунгъан саифеде къалын оларакъ косьтерилир.
+Бу саифедеки ве онынънен багълы саифелердеки оладжакъ денъишикликлер бу джедвельде бельгиленеджек, эм де олар козьге чарпмасы ичюн [[Special:RecentChanges|янъы денъишиклик джедвели]] булунгъан саифеде къалын оларакъ косьтерилир.
 Бираздан сонъ козетюв джедвелинъизден бир де бир саифени ёкъ этмеге истесенъиз де, саифенинъ юкъарысындаки сол тарафта "козетме" дёгмесине басынъыз.',
 'removedwatch'         => 'Козетюв джедвелинден ёкъ эт',
 'removedwatchtext'     => '"[[:$1]]" саифеси козетюв джедвелинъизден ёкъ этильди.',
@@ -1258,7 +1253,7 @@
 'exblank'                     => 'саифе метини бош',
 'historywarning'              => 'Тенби: Сиз ёкъ этмек узьре олгъан саифенинъ кечмиши бардыр:',
 'confirmdeletetext'           => 'Бир саифени я да ресимни бутюн кечмиши иле бирликте малюмат базасындан къалыджы оларакъ ёкъ этмек узьресинъиз.
-Лютфен, нетиджелерини анълагъанынъызны, [[Special:Whatlinkshere/{{FULLPAGENAME}}|саифеге багълантыларыны]] тешкергенден сонъ ве [[{{MediaWiki:Policy-url}}|ёкъ этюв политикасына]] уйгъунлыгъыны дикъкъаткъа алып, буны япмагъа истегенинъизни тасдыкъланъыз.',
+Лютфен, нетиджелерини анълагъанынъызны, [[Special:WhatLinksHere/{{FULLPAGENAME}}|саифеге багълантыларыны]] тешкергенден сонъ ве [[{{MediaWiki:Policy-url}}|ёкъ этюв политикасына]] уйгъунлыгъыны дикъкъаткъа алып, буны япмагъа истегенинъизни тасдыкъланъыз.',
 'actioncomplete'              => 'Ишлем тамамланды.',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" ёкъ этильди.
 якъын заманда ёкъ этильгенлерни корьмек ичюн: $2.',
@@ -1279,7 +1274,7 @@
 'revertpage'                  => '[[Special:Contributions/$2|$2]] ([[User talk:$2|музакере]]) тарафындан япылгъан денъишикликлер кери алынып, [[User:$1|$1]] тарафындан денъиштирильген эвельки версия кери кетирильди.', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'protectlogpage'              => 'Къорчалав журналы',
 'protectlogtext'              => 'Къорчалавгъа алув/чыкъарув иле багълы денъишикликлер журналыны корьмектесинъиз.
-Къорчалав алтына алынгъан саифелер там джедвели [[Special:Protectedpages|бу саифеде]] корип оласынъыз.',
+Къорчалав алтына алынгъан саифелер там джедвели [[Special:ProtectedPages|бу саифеде]] корип оласынъыз.',
 'protectedarticle'            => '"[[$1]]" къорчалав алтына алынды',
 'unprotectedarticle'          => 'къорчалав чыкъарлыды: "[[$1]]"',
 'protect-legend'              => 'Къорчалавны тасдыкъла',
@@ -1374,7 +1369,7 @@
 'badipaddress'            => 'Кечерсиз IP адреси',
 'blockipsuccesssub'       => 'IP адресни бан этюв ишлеви мувафакъиетли олды',
 'blockipsuccesstext'      => '"$1" бан этильди.
-<br />[[Special:Ipblocklist|IP адреси бан этильгенлер]] джедвелине бакъынъыз .',
+<br />[[Special:IPBlockList|IP адреси бан этильгенлер]] джедвелине бакъынъыз .',
 'unblockip'               => 'Къулланыджынынъ бан этювини чыкъар',
 'ipusubmit'               => 'Бу адреснинъ бан этювини чыкъар',
 'ipblocklist'             => 'Блок этильген къулланыджылар ве IP адреслери джедвели',
@@ -1387,7 +1382,7 @@
 'autoblocker'             => 'Автоматик оларакъ бан эттинъиз чюнки якъын заманда IP адресинъиз "[[User:$1|$1]]" къулланыджысы тарафындан къулланылды. $1 адлы къулланыджынынъ бан этилюви ичюн берильген себеп: "\'\'\'$2\'\'\'"',
 'blocklogpage'            => 'Иришим бан этюв журналы',
 'blocklogentry'           => '"[[$1]]" иришими $2 $3 токътатылды. Себеп',
-'blocklogtext'            => 'Мында къулланыджы иришимине ёнелик бан этюв ве бан чыкъарув журналы джедвеллене. Автоматик IP адреси бан этювлери джедвельге кирсетильмеди. Ал-азырда иришими токътатылгъан къулланыджыларны [[Special:Ipblocklist|IP бан этюв джедвели]] саифесинден корип оласынъыз.',
+'blocklogtext'            => 'Мында къулланыджы иришимине ёнелик бан этюв ве бан чыкъарув журналы джедвеллене. Автоматик IP адреси бан этювлери джедвельге кирсетильмеди. Ал-азырда иришими токътатылгъан къулланыджыларны [[Special:IPBlockList|IP бан этюв джедвели]] саифесинден корип оласынъыз.',
 'unblocklogentry'         => '$1 къулланыджынынъ бан этюви чыкъарылды',
 'block-log-flags-noemail' => 'e-mail блок этильди',
 'ipb_expiry_invalid'      => 'Кечерсиз битиш заманы.',
@@ -1415,8 +1410,6 @@
 
 Бойле алларда, керек олса, саифелерни къолнен ташымагъа я да бирлештирмеге меджбур олурсынъыз.",
 'movearticle'             => 'Эски ад',
-'movenologin'             => 'Отурым ачмадынъыз',
-'movenologintext'         => 'Саифенинъ адыны денъиштирип олмакъ ичюн [[Special:Userlogin|отурым ачынъыз]].',
 'movenotallowed'          => '{{SITENAME}} сайтында саифелер адларыны денъиштирмеге изининъиз ёкъ.',
 'newtitle'                => 'Янъы ад',
 'move-watch'              => 'Бу саифени козет',
@@ -1437,7 +1430,7 @@
 'delete_and_move'         => 'Ёкъ эт ве адыны денъиштир',
 'delete_and_move_text'    => '==Ёкъ этмек лязимдир==
 
-«[[$1]]» саифеси энди мевджут. Адыны денъиштирип олмакъ ичюн оны ёкъ этмеге истейсинъизми?',
+«[[:$1]]» саифеси энди мевджут. Адыны денъиштирип олмакъ ичюн оны ёкъ этмеге истейсинъизми?',
 'delete_and_move_confirm' => 'Эбет, бу саифени ёкъ эт',
 'delete_and_move_reason'  => 'Исим денъиштирип олмакъ ичюн ёкъ этильди',
 'selfmove'                => 'Бу саифенинъ адыны денъиштирмеге имкян ёкътыр, чюнки асыл иле янъы адлары бир келе.',
@@ -1593,7 +1586,7 @@
 'show-big-image'       => 'Там чезинирлик',
 'show-big-image-thumb' => '<small>Ог бакъувда ресим буюклиги: $1 × $2 пиксель</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Янъы ресимлер',
 'imagelisttext'         => "Ашагъыдаки джедвельде $2 коре тизильген {{PLURAL:$1|'''1''' файлдыр|'''$1''' файлдыр}}.",
 'showhidebots'          => '(ботларны $1)',
@@ -1683,7 +1676,7 @@
 
 # External editor support
 'edit-externally'      => 'Файл узеринде компьютеринъизде булунгъан программалар иле денъишикликлер япынъыз',
-'edit-externally-help' => 'Даа фазла малюмат ичюн [http://meta.wikimedia.org/wiki/Help:External_editors бу саифеге] (Инглиздже) бакъып оласынъыз.',
+'edit-externally-help' => 'Даа фазла малюмат ичюн [http://www.mediawiki.org/wiki/Manual:External_editors бу саифеге] (Инглиздже) бакъып оласынъыз.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'эписини',
@@ -1750,7 +1743,7 @@
 'recreate'            => 'Саифени янъыдан ярат',
 
 # HTML dump
-'redirectingto' => 'Ёллама [[$1]]...',
+'redirectingto' => 'Ёллама [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Саифе кэшини темизлесинми?
Index: languages/messages/MessagesCbk_zam.php
===================================================================
--- languages/messages/MessagesCbk_zam.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCbk_zam.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -42,7 +42,7 @@
 # Random page
 'randompage' => 'Pagina Escujido Automatico',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'Todo maga articulo',
 
 # Watchlist
Index: languages/messages/MessagesNn.php
===================================================================
--- languages/messages/MessagesNn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,22 +4,19 @@
  * @ingroup Language
  * @file
  *
+ * @author Boivie
+ * @author Dittaeva
  * @author Eirik
- * @author Jon Harald Søby
- * @author Jorunn
- * @author Siebrand
- * @author M.M.S.
- * @author לערי ריינהארט
- * @author Ranveig
  * @author Finnrind
- * @author Dittaeva
+ * @author Guttorm Flatabø
  * @author H92
- * @author Boivie
- * @author SPQRobin
+ * @author Jon Harald Søby
+ * @author Jorunn
+ * @author Max sonnelid
  * @author Olve Utne
- * @author Guttorm Flatabø
+ * @author Ranveig
  * @author Shauni
- * @author Max sonnelid
+ * @author לערי ריינהארט
  */
 
 /**
@@ -531,7 +528,7 @@
 'nosuchaction'      => 'Funksjonen finst ikkje',
 'nosuchactiontext'  => 'Wikiprogramvaren kjenner ikkje att funksjonen som er spesifisert i nettadressa',
 'nosuchspecialpage' => 'Ei slik spesialside finst ikkje',
-'nospecialpagetext' => 'Du har bede om ei spesialside som ikkje finst, liste over spesialsider er [[Special:Specialpages|her]].',
+'nospecialpagetext' => 'Du har bede om ei spesialside som ikkje finst, liste over spesialsider er [[Special:SpecialPages|her]].',
 
 # General errors
 'error'                => 'Feil',
@@ -589,11 +586,13 @@
 
 # Login and logout pages
 'logouttitle'                => 'Logg ut',
-'logouttext'                 => '<strong>Du er no utlogga.</strong><br />
-Avhengig av innstillingane på tenaren kan nettlesaren no brukast anonymt på {{SITENAME}}, du kan logge inn att med same kontoen eller ein annan brukar kan logge inn. Ver merksam på at nokre sider kan halde fram med å verte viste som om du er innlogga fram til du slettar mellomlageret til nettlesaren din.',
+'logouttext'                 => '<strong>Du er no utlogga.</strong>
+
+Du kan no halde fram og bruke {{SITENAME}} anonymt, eller du kan [[Special:UserLogin|logge inn att]]  med same kontoen eller ein annan brukar kan logge inn. 
+Ver merksam på at nokre sider kan halde fram med å verte viste som om du er innlogga fram til du slettar mellomlageret til nettlesaren din.',
 'welcomecreation'            => '== Hjarteleg velkommen til {{SITENAME}}, $1! ==
 Brukarkontoen din har vorte oppretta.
-Det er tilrådd at du skriv litt om ser gjennom brukarinnstillingane dine.',
+Ikkje gløym å endre på [[Special:Preferences|innstillingane]] dine.',
 'loginpagetitle'             => 'Logg inn',
 'yourname'                   => 'Brukarnamn:',
 'yourpassword'               => 'Passord:',
@@ -725,15 +724,19 @@
 'summary-preview'                  => 'Førehandsvising av endringssamandraget',
 'subject-preview'                  => 'Førehandsvising av emne/overskrift',
 'blockedtitle'                     => 'Brukaren er blokkert',
-'blockedtext'                      => "<big>'''Brukarnamnet ditt eller IP-adressa di er blokkert frå endring.'''</big>
+'blockedtext'                      => "<big>'''Brukarnamnet ditt eller IP-adressa di er blokkert frå endring'''</big>
 
-Blokkeringa vart gjort av $1. Denne grunnen vart gjeven: ''$2''.
+Blokkeringa vart gjort av $1. 
+Denne grunnen vart gjeven: ''$2''.
 
 * Blokkeringa byrja: $8
 * Blokkeringa utgår: $6
 * Blokkeringa var meint på: $7
 
-Du kan kontakte $1 eller ein annan [[{{MediaWiki:Grouppage-sysop}}|administrator]] for å diskutere blokkeringa. Ver merksam på at du ikkje kan bruke «send e-post til brukar»-funksjonen så lenge du ikkje har ei gyldig e-postadresse registrert i [[Special:Preferences|innstillingane dine]]. Du kan heller ikkje bruke funksjonen dersom du er blokkert frå å sende e-post. IP-adressa di er $3, og blokkeringsnummeret er $5. Ver venleg og opplys om dette ved eventuelle førespurnader.",
+Du kan kontakte $1 eller ein annan [[{{MediaWiki:Grouppage-sysop}}|administrator]] for å diskutere blokkeringa. 
+Ver merksam på at du ikkje kan bruke «send e-post til brukar»-funksjonen så lenge du ikkje har ei gyldig e-postadresse registrert i [[Special:Preferences|innstillingane dine]]. Du kan heller ikkje bruke funksjonen dersom du er blokkert frå å sende e-post. 
+IP-adressa di er $3, og blokkeringsnummeret er $5. 
+Ver venleg og opplys om dette ved eventuelle førespurnader.",
 'autoblockedtext'                  => "IP-adressa di er automatisk blokkert frå endring fordi ho vart brukt av ein annan brukar som vart blokkert av $1. Denne grunnen vart gjeven: ''$2''.
 
 * Blokkeringa byrja: $8
@@ -745,10 +748,6 @@
 'blockededitsource'                => "Teksten i '''endringane dine''' på '''$1''' er vist nedanfor:",
 'whitelistedittitle'               => 'Du lyt logge inn for å gjera endringar',
 'whitelistedittext'                => 'Du lyt $1 for å endre sider.',
-'whitelistreadtitle'               => 'Du lyt logge inn for å lesa',
-'whitelistreadtext'                => 'Du lyt [[Special:Userlogin|logge inn]] for å lesa sider.',
-'whitelistacctitle'                => 'Du har ikkje løyve til å laga brukarkonto',
-'whitelistacctext'                 => 'For å lage brukarkonto her på {{SITENAME}} må du [[Special:Userlogin|logge inn]] og ha rett type tilgang.',
 'confirmedittitle'                 => 'Du må stadfeste e-postadressa di før du kan endre noko',
 'confirmedittext'                  => 'Du må stadfeste e-postadressa di før du kan endre sidene. Ver venleg og legg inn og stadfest e-postadressa di i [[Special:Preferences|innstillingane dine]].',
 'nosuchsectiontitle'               => 'Ingen slik bolk',
@@ -764,7 +763,7 @@
 * Om du er ny her er det tilrådd å sjå på [[{{MediaWiki:Helppage}}|hjelpesida]] først.
 * Om du lagrar ei testside, vil du ikkje kunne slette henne sjølv.
 * Dersom du ikkje ønskjer å endre sida, kan du utan risiko klikke på '''attende'''-knappen i nettlesaren din.",
-'anontalkpagetext'                 => "---- ''Dette er ei diskusjonsside for ein anonym brukar som ikkje har logga inn på eigen brukarkonto. Vi er difor nøydde til å bruke den numeriske IP-adressa knytt til internettoppkoplinga åt brukaren. Same IP-adressa kan vera knytt til fleire brukarar. Om du er ein anonym brukar og meiner at du har fått irrelevante kommentarar på ei slik side, [[Special:Userlogin|logg inn]] slik at vi unngår framtidige forvekslingar med andre anonyme brukarar.''",
+'anontalkpagetext'                 => "---- ''Dette er ei diskusjonsside for ein anonym brukar som ikkje har logga inn på eigen brukarkonto. Vi er difor nøydde til å bruke den numeriske IP-adressa knytt til internettoppkoplinga åt brukaren. Same IP-adressa kan vera knytt til fleire brukarar. Om du er ein anonym brukar og meiner at du har fått irrelevante kommentarar på ei slik side, [[Special:UserLogin|logg inn]] slik at vi unngår framtidige forvekslingar med andre anonyme brukarar.''",
 'noarticletext'                    => "Det er ikkje noko tekst på denne sida. Du kan [[Special:Search/{{PAGENAME}}|søke etter henne]] i andre sider, eller klikke på '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} endre]''' for å opprette sida.",
 'userpage-userdoesnotexist'        => 'Brukarkontoen «$1» finst ikkje. Vil du verkeleg opprette/endre denne sida?',
 'clearyourcache'                   => "'''Merk: Etter lagring vil det kanskje vera naudsynt at nettlesaren slettar mellomlageret sitt for at endringane skal tre i kraft.''' '''Firefox og Safari:''' Hald ''Shift'' nede medan du trykkjer anten ''Ctrl-F5'' eller ''Ctrl-R'' (''Command-R'' på Mac). '''Konqueror:''' Trykk ''Oppdater'' eller på ''F5''. '''Opera:''' Tøm mellomlageret i ''Verktøy → Innstillingar''. '''Internet Explorer:''' Hald nede ''Ctrl'' medan du trykkjer ''Oppdater'', eler trykk ''Ctrl-F5.''",
@@ -819,7 +818,7 @@
 'edittools'                        => '<!-- Teksten her vert synt mellom tekstboksen og «Lagre»-knappen når ein endrar ei side. -->',
 'nocreatetitle'                    => 'Avgrensa sideoppretting',
 'nocreatetext'                     => '{{SITENAME}} har avgrensa tilgang til å opprette nye sider.
-Du kan gå attende og endre ei eksisterande side, [[Special:Userlogin|logge inn eller opprette ein brukarkonto]].',
+Du kan gå attende og endre ei eksisterande side, [[Special:UserLogin|logge inn eller opprette ein brukarkonto]].',
 'nocreate-loggedin'                => 'Du har ikkje tilgang til å opprette nye sider på {{SITENAME}}.',
 'permissionserrors'                => 'Tilgangsfeil',
 'permissionserrorstext'            => 'Du har ikkje tilgang til å gjere dette, {{PLURAL:$1|grunnen|grunnane}} til det finn du her:',
@@ -928,7 +927,7 @@
 # Suppression log
 'suppressionlog'     => 'Logg over historikkfjerningar',
 'suppressionlogtext' => 'Under er ei liste over slettingar og blokkeringar som er gøymde frå administratorane.
-Sjå [[Special:Ipblocklist|blokkeringslista]] for oversikta over gjeldande blokkeringar.',
+Sjå [[Special:IPBlockList|blokkeringslista]] for oversikta over gjeldande blokkeringar.',
 
 # History merging
 'mergehistory'                     => 'Flett sidehistorikkar',
@@ -1015,7 +1014,7 @@
 'mypreferences'            => 'Innstillingane mine',
 'prefs-edits'              => 'Tal på endringar:',
 'prefsnologin'             => 'Ikkje innlogga',
-'prefsnologintext'         => 'Du lyt vere [[Special:Userlogin|innlogga]] for å endre brukarinnstillingane dine.',
+'prefsnologintext'         => 'Du lyt vere [[Special:UserLogin|innlogga]] for å endre brukarinnstillingane dine.',
 'prefsreset'               => 'Innstillingane er tilbakestilte til siste lagra versjon.',
 'qbsettings'               => 'Snøggmeny',
 'qbsettings-none'          => 'Ingen',
@@ -1089,7 +1088,7 @@
 'userrights-reason'           => 'Grunn til endring:',
 'userrights-no-interwiki'     => 'Du har ikkje tilgang til å endre brukartilgangar på andre wikiar.',
 'userrights-nodatabase'       => 'Databasen $1 finst ikkje eller er ikkje lokal.',
-'userrights-nologin'          => 'Du må [[Special:Userlogin|logge inn]] med ein administrator- og/eller byråkratkonto for å endre brukartilgangar.',
+'userrights-nologin'          => 'Du må [[Special:UserLogin|logge inn]] med ein administrator- og/eller byråkratkonto for å endre brukartilgangar.',
 'userrights-notallowed'       => 'Kontoen din har ikkje tilgang til å endre brukartilgangar.',
 'userrights-changeable-col'   => 'Grupper du kan endre',
 'userrights-unchangeable-col' => 'Grupper du ikkje kan endre',
@@ -1191,10 +1190,10 @@
 'reupload'                    => 'Nytt forsøk',
 'reuploaddesc'                => 'Attende til opplastingsskjemaet.',
 'uploadnologin'               => 'Ikkje innlogga',
-'uploadnologintext'           => 'Du lyt vera [[Special:Userlogin|innlogga]] for å kunna laste opp filer.',
+'uploadnologintext'           => 'Du lyt vera [[Special:UserLogin|innlogga]] for å kunna laste opp filer.',
 'upload_directory_read_only'  => 'Opplastingsmappa ($1) er skriveverna.',
 'uploaderror'                 => 'Feil under opplasting av fil',
-'uploadtext'                  => "Bruk skjemaet under for å laste opp filer. For å sjå eller søke i tidlegare opplasta filer, gå til [[Special:Imagelist|fillista]]. Opplastingane vert også lagra i [[Special:Log/upload|opplastingsloggen]].
+'uploadtext'                  => "Bruk skjemaet under for å laste opp filer. For å sjå eller søke i tidlegare opplasta filer, gå til [[Special:ImageList|fillista]]. Opplastingane vert også lagra i [[Special:Log/upload|opplastingsloggen]].
 
 For å bruke ei fil på ei side, bruk ei slik lenkje:
 *'''<nowiki>[[</nowiki>{{ns:image}}:Filnamn.jpg<nowiki>]]</nowiki>'''
@@ -1280,7 +1279,7 @@
 'upload_source_url'  => ' (ei gyldig, offentleg tilgjengeleg nettadresse)',
 'upload_source_file' => ' (ei fil på datamaskina di)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Denne spesialsida viser alle opplasta filer. Dei sist opplasta filene vert viste på toppen som standard. Klikk på ei kolonneoverskrift for å byte sorteringsmetode.',
 'imagelist_search_for'  => 'Søk etter filnamn:',
 'imgfile'               => 'fil',
@@ -1306,7 +1305,7 @@
 'imagelinks'                     => 'Fillenkjer',
 'linkstoimage'                   => '{{PLURAL:$1|Den følgjande sida|Dei følgjande $1 sidene}} har lenkjer til denne fila:',
 'nolinkstoimage'                 => 'Det finst ikkje noka side med lenkje til denne fila.',
-'morelinkstoimage'               => 'Vis [[Special:Whatlinkshere/$1|fleire lenkjer]] til denne fila.',
+'morelinkstoimage'               => 'Vis [[Special:WhatLinksHere/$1|fleire lenkjer]] til denne fila.',
 'sharedupload'                   => 'Denne fila er ei delt opplasting og kan brukast av andre prosjekt.',
 'shareduploadwiki'               => 'Sjå $1 for meir informasjon.',
 'shareduploadwiki-desc'          => 'Skildringa til $1 i det delte lageret er vist nedanfor.',
@@ -1322,18 +1321,18 @@
 # File reversion
 'filerevert'                => 'Rull attende $1',
 'filerevert-legend'         => 'Rull attende fila',
-'filerevert-intro'          => '<span class="plainlinks">Du rullar attende \'\'\'[[Media:$1|$1]]\'\'\' til [$4 versjonen frå $3, $2].</span>',
+'filerevert-intro'          => "Du rullar attende '''[[Media:$1|$1]]''' til [$4 versjonen frå $3, $2].",
 'filerevert-comment'        => 'Kommentar:',
 'filerevert-defaultcomment' => 'Rulla attende til versjonen frå $2, $1',
 'filerevert-submit'         => 'Rull attende',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' er rulla attende til [$4 versjonen frå $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' er rulla attende til [$4 versjonen frå $3, $2].",
 'filerevert-badversion'     => 'Det finst ingen tidlegare lokal versjon av denne fila frå det oppgjevne tidspunktet.',
 
 # File deletion
 'filedelete'                  => 'Slett $1',
 'filedelete-legend'           => 'Slett fil',
 'filedelete-intro'            => "Du slettar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Du slettar versjonen av \'\'\'[[Media:$1|$1]]\'\'\' frå [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Du slettar versjonen av '''[[Media:$1|$1]]''' frå [$4 $3, $2].",
 'filedelete-comment'          => 'Slettingsårsak:',
 'filedelete-submit'           => 'Slett',
 'filedelete-success'          => "'''$1''' er sletta.",
@@ -1475,7 +1474,7 @@
 'logempty'             => 'Ingen treff i loggane.',
 'log-title-wildcard'   => 'Søk i titlar som byrjar med denne teksten',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle sider',
 'alphaindexline'    => '$1 til $2',
 'nextpage'          => 'Neste side ($1)',
@@ -1498,12 +1497,12 @@
 'special-categories-sort-count' => 'sorter etter storleik',
 'special-categories-sort-abc'   => 'sorter alfabetisk',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Vis brukarnamna frå og med:',
 'listusers-submit'   => 'Vis',
 'listusers-noresult' => 'Ingen brukarnamn vart funne.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Tilgangar for brukargrupper',
 'listgrouprights-summary'  => 'Lista nedanfor viser brukargruppene på denne wikien, med dei tilhøyrande tilgangane. Meir informasjon om dei ulike typane tilgang kan ein finne [[{{MediaWiki:Listgrouprights-helppage}}|her]].',
 'listgrouprights-group'    => 'Gruppe',
@@ -1513,7 +1512,7 @@
 
 # E-mail user
 'mailnologin'     => 'Inga avsendaradresse',
-'mailnologintext' => 'Du lyt vera [[Special:Userlogin|innlogga]] og ha ei gyldig e-postadresse sett i [[Special:Preferences|brukarinnstillingane]] for å sende e-post åt andre brukarar.',
+'mailnologintext' => 'Du lyt vera [[Special:UserLogin|innlogga]] og ha ei gyldig e-postadresse sett i [[Special:Preferences|brukarinnstillingane]] for å sende e-post åt andre brukarar.',
 'emailuser'       => 'Send e-post åt denne brukaren',
 'emailpage'       => 'Send e-post åt brukar',
 'emailpagetext'   => 'Om denne brukaren har gjeve ei gyldig e-postadresse i brukarinnstillingane sine, vil dette skjemaet sende ei enkel melding. E-postadressa di frå brukarinnstillingane dine vil vera synleg i «Frå»-feltet i denne e-posten, slik at mottakaren kan svara deg.',
@@ -1538,9 +1537,9 @@
 'nowatchlist'          => 'Du har ikkje noko i overvakingslista di.',
 'watchlistanontext'    => 'Ver venleg og $1 for å vise eller endre sider på overvakingslista di.',
 'watchnologin'         => 'Ikkje innlogga',
-'watchnologintext'     => 'Du lyt vera [[Special:Userlogin|innlogga]] for å kunna endre overvakingslista.',
+'watchnologintext'     => 'Du lyt vera [[Special:UserLogin|innlogga]] for å kunna endre overvakingslista.',
 'addedwatch'           => 'Lagt til overvakingslista',
-'addedwatchtext'       => "Sida «<nowiki>$1</nowiki>» er lagt til [[Special:Watchlist|overvakingslista]] di. Framtidige endringar av denne sida og den tilhøyrande diskusjonssida vil bli oppførde her, og sida vil vera '''utheva''' på «[[Special:Recentchanges|siste endringar]]» for å gjera deg merksam på henne.
+'addedwatchtext'       => "Sida «[[:$1]]» er lagt til [[Special:Watchlist|overvakingslista]] di. Framtidige endringar av denne sida og den tilhøyrande diskusjonssida vil bli oppførde her, og sida vil vera '''utheva''' på «[[Special:RecentChanges|siste endringar]]» for å gjera deg merksam på henne.
 
 Om du seinere vil fjerne sida frå overvakingslista, klikk på «Fjern overvaking» på den aktuelle sida.",
 'removedwatch'         => 'Fjerna frå overvakingslista',
@@ -1647,7 +1646,7 @@
 'rollback-success'            => 'Rulla attende endringane av $1, tilbake til siste versjon av $2.',
 'sessionfailure'              => 'Det ser ut til å vera eit problem med innloggingsøkta di. Handlinga er vorten avbroten for å vera føre var mot kidnapping av økta. Bruk attendeknappen i nettlesaren din og prøv om att.',
 'protectlogpage'              => 'Vernelogg',
-'protectlogtext'              => 'Dette er ei liste over sider som er vortne verna eller har fått fjerna vern. [[Special:Protectedpages|Verna side]] for meir info.',
+'protectlogtext'              => 'Dette er ei liste over sider som er vortne verna eller har fått fjerna vern. [[Special:ProtectedPages|Verna side]] for meir info.',
 'protectedarticle'            => 'verna «[[$1]]»',
 'modifiedarticleprotection'   => 'endra nivået på vernet av «[[$1]]»',
 'unprotectedarticle'          => 'fjerna vern av «[[$1]]»',
@@ -1751,7 +1750,7 @@
 
 # What links here
 'whatlinkshere'            => 'Lenkjer hit',
-'whatlinkshere-title'      => 'Sider som har lenkje til $1',
+'whatlinkshere-title'      => 'Sider som har lenkje til «$1»',
 'whatlinkshere-page'       => 'Side:',
 'linklistsub'              => '(Liste over lenkjer)',
 'linkshere'                => "Desse sidene har lenkjer til '''[[:$1]]''':",
@@ -1799,7 +1798,7 @@
 'badipaddress'                => 'IP-adressa er ugyldig eller blokkering av brukarar er slått av på tenaren.',
 'blockipsuccesssub'           => 'Blokkering utført',
 'blockipsuccesstext'          => '«[[Special:Contributions/$1|$1]]» er blokkert.<br />
-Sjå [[Special:Ipblocklist|blokkeringslista]] for alle blokkeringar.',
+Sjå [[Special:IPBlockList|blokkeringslista]] for alle blokkeringar.',
 'ipb-edit-dropdown'           => 'Endre grunnane for blokkering',
 'ipb-unblock-addr'            => 'Opphev blokkeringa av $1',
 'ipb-unblock'                 => 'Opphev blokkeringa av eit brukarnamn eller ei IP-adresse',
@@ -1830,7 +1829,7 @@
 'blocklogpage'                => 'Blokkeringslogg',
 'blocklogentry'               => 'Blokkerte «[[$1]]» med opphøyrstid $2 $3',
 'blocklogtext'                => 'Dette er ein logg over blokkeringar og oppheving av blokkeringar gjorde.
-IP-adresser som blir automatisk blokkerte er ikkje lista her. Sjå [[Special:Ipblocklist|blokkeringslista]] for alle aktive blokkeringar.',
+IP-adresser som blir automatisk blokkerte er ikkje lista her. Sjå [[Special:IPBlockList|blokkeringslista]] for alle aktive blokkeringar.',
 'unblocklogentry'             => 'oppheva blokkering av «$1»',
 'block-log-flags-anononly'    => 'berre anonyme brukarar',
 'block-log-flags-nocreate'    => 'kontooppretting slått av',
@@ -1861,7 +1860,7 @@
 'locknoconfirm'       => 'Du har ikkje stadfest handlinga.',
 'lockdbsuccesssub'    => 'Databasen er no skriveverna',
 'unlockdbsuccesssub'  => 'Skrivevernet på databasen er no oppheva',
-'lockdbsuccesstext'   => 'Databasen er no skriveverna. <br />Hugs å [[Special:Unlockdb|oppheve skrivevernet]] når du er ferdig med vedlikehaldet.',
+'lockdbsuccesstext'   => 'Databasen er no skriveverna. <br />Hugs å [[Special:UnlockDB|oppheve skrivevernet]] når du er ferdig med vedlikehaldet.',
 'unlockdbsuccesstext' => 'Skrivevernet er oppheva.',
 'databasenotlocked'   => 'Databasen er ikkje låst.',
 
@@ -1879,16 +1878,15 @@
 
 I desse falla lyt du flytte eller flette saman sida manuelt.",
 'movearticle'             => 'Flytt side:',
-'movenologin'             => 'Ikkje innlogga',
-'movenologintext'         => 'Du lyt vera registrert brukar og vera [[Special:Userlogin|innlogga]] for å flytte ei side.',
 'movenotallowed'          => 'Du har ikkje tilgang til å flytte sider på {{SITENAME}}.',
 'newtitle'                => 'Til ny tittel',
 'move-watch'              => 'Overvak denne sida',
 'movepagebtn'             => 'Flytt side',
 'pagemovedsub'            => 'Flyttinga er gjennomført',
+'movepage-moved'          => "<big>'''«$1» er flytt til «$2»'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Ei side med det namnet finst allereie, eller det namnet du har valt er ikkje gyldig. Vel eit anna namn.',
 'cantmove-titleprotected' => 'Du kan ikkje flytte sida hit, fordi det nye sidenamnet er verna mot oppretting.',
-'talkexists'              => "'''Innhaldssida vart flytt, men diskusjonssida som høyrer til kunne ikkje flyttast fordi det allereie finst ei side med den nye tittelen. Du lyt flette dei saman manuelt. Dersom det ikkje er mogleg for deg å gjera dette kan du kontakte ein <a href=\"{{localurl:Project:Administratorar}}\">administrator</a> &#8212; men <b>ikkje</b> bruk klipp-og-lim metoden sidan dette ikkje tek vare på endringshistorikken.'''",
+'talkexists'              => "'''Innhaldssida vart flytt, men diskusjonssida som høyrer til kunne ikkje flyttast fordi det allereie finst ei side med den nye tittelen. Du lyt difor flette dei saman manuelt.'''",
 'movedto'                 => 'er flytt til',
 'movetalk'                => 'Flytt diskusjonssida òg om ho finst.',
 '1movedto2'               => '«[[$1]]» flytt til «[[$2]]»',
@@ -1900,7 +1898,7 @@
 'delete_and_move'         => 'Slett og flytt',
 'delete_and_move_text'    => '== Sletting påkrevd ==
 
-Målsida «[[$1]]» finst allereie. Vil du slette ho for å gje rom for flytting?',
+Målsida «[[:$1]]» finst allereie. Vil du slette ho for å gje rom for flytting?',
 'delete_and_move_confirm' => 'Ja, slett sida',
 'delete_and_move_reason'  => 'Sletta for å gje rom for flytting',
 'selfmove'                => 'Kjelde- og måltitlane er like; kan ikkje flytte sida over seg sjølv.',
@@ -1936,6 +1934,8 @@
 'thumbnail-more'  => 'Forstørr',
 'filemissing'     => 'Fila manglar',
 'thumbnail_error' => 'Feil ved oppretting av miniatyrbilete: $1',
+'djvu_page_error' => 'DjVu-sida er utanfor rekkjevidd',
+'djvu_no_xml'     => 'Klarte ikkje hente inn XML for DjVu-fila',
 
 # Special:Import
 'import'                     => 'Importer sider',
@@ -1943,8 +1943,7 @@
 'import-interwiki-history'   => 'Kopier all historikken for denne sida',
 'import-interwiki-submit'    => 'Importer',
 'import-interwiki-namespace' => 'Flytt sidene til namnerommet:',
-'importtext'                 => 'Du må først eksportere sida du vil importere til ei fil som du lagrar på maskina di, deretter kan du laste ho inn her.
-For å eksportere bruker du [[Special:Export|eksportsida]] på kjeldewikien; hugs at kjelda òg må bruke MediaWiki-programvaren.',
+'importtext'                 => 'Eksporter fila frå kjeldewikien med [[Special:Export|eksporteringsverktøyet]], lagre ho på di eiga datamaskin, og last henne opp her.',
 'importstart'                => 'Importerer sidene…',
 'import-revision-count'      => '$1 {{PLURAL:$1|versjon|versjonar}}',
 'importnopages'              => 'Ingen sider å importere.',
@@ -2111,7 +2110,7 @@
 'show-big-image'       => 'Full oppløysing',
 'show-big-image-thumb' => '<small>Storleiken på denne førehandsvisinga: $1 × $2 pikslar</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Filgalleri',
 'imagelisttext'         => 'Her er ei liste med {{PLURAL:$1|éi fil sortert|$1 filer sorterte}} $2.',
 'newimages-summary'     => 'Denne spesialsida syner dei sist opplasta filene.',
@@ -2396,7 +2395,7 @@
 
 # External editor support
 'edit-externally'      => 'Endre denne fila med eit eksternt program',
-'edit-externally-help' => 'Sjå [http://meta.wikimedia.org/wiki/Help:External_editors eksterne program instruksjonane] for meir informasjon.',
+'edit-externally-help' => 'Sjå [http://www.mediawiki.org/wiki/Manual:External_editors eksterne program instruksjonane] for meir informasjon.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alle',
@@ -2463,7 +2462,7 @@
 'recreate'            => 'Nyopprett',
 
 # HTML dump
-'redirectingto' => 'Omdirigerer til [[$1]]...',
+'redirectingto' => 'Omdirigerer til [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Vil du slette tenarane sin mellomlagra versjon av denne sida?
@@ -2559,7 +2558,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Versjon',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Filsti',
 'filepath-page'   => 'Fil:',
 'filepath-submit' => 'Sti',
Index: languages/messages/MessagesRm.php
===================================================================
--- languages/messages/MessagesRm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author לערי ריינהארט
  * @author Gion-andri
- * @author SPQRobin
- * @author Siebrand
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -251,10 +249,6 @@
 'anoneditwarning'      => "Vus essas betg annunziads. Empè dal num d'utilisader vign l'adressa dad IP registrada en la historia da las versiuns.",
 'blockedtitle'         => 'Utilisader è bloccà',
 'whitelistedittitle'   => "t'annunzia per editar",
-'whitelistreadtitle'   => "per leger stos ti t'annunziar",
-'whitelistreadtext'    => "Ti stos [[Special:Userlogin|t'annunziar]] per leger las paginas.",
-'whitelistacctitle'    => 'Ti na dastgas betg crear in nov conto',
-'whitelistacctext'     => "Per dastgar crear contos en questa wiki stos ti [[Special:Userlogin|t'annunziar]] ed avair ils dretgs correspundents.",
 'confirmedittitle'     => 'Per editar è la confermaziun da la adressa dad email necessaria',
 'confirmedittext'      => 'Ti stos confermar tia adressa dad email avant che editar paginas. Inditgescha e conferma per plaschair tia adressa dad email en tias [[Special:Preferences|preferenzas]].',
 'loginreqtitle'        => 'Annunzia necessari',
@@ -279,6 +273,7 @@
 'longpageerror'        => "<strong>ERRUR: Il text che ti has tramess è $1 kilobytes gronds. Quei ei pli grond ch'il maximum da $2 kilobytes. Il text na sa betg vegnir arcunà. </strong>",
 'protectedpagewarning' => '<strong>ATTENZIUN: Questa pagina è vegnida bloccada, uschè che be utilisaders cun dretgs dad administraturs pon editar ella. </strong>',
 'templatesused'        => 'Templates utilisads sin questa pagina:',
+'edittools'            => '<!-- Text here will be shown below edit and upload forms. -->',
 
 # Account creation failure
 'cantcreateaccounttitle' => "Betg pussaivel da crear l'account",
@@ -319,7 +314,7 @@
 'preferences'           => 'Preferenzas',
 'mypreferences'         => 'Mias preferenzas',
 'prefsnologin'          => 'betg annunzià',
-'prefsnologintext'      => 'Vus stuais esser [[Special:Userlogin|annunziads]] per midar vossas preferenzas.',
+'prefsnologintext'      => 'Vus stuais esser [[Special:UserLogin|annunziads]] per midar vossas preferenzas.',
 'prefsreset'            => 'Preferenzas da standard ein vegnì reconstruidas.',
 'changepassword'        => 'Midar pled-clav',
 'dateformat'            => 'format da las datas',
@@ -371,8 +366,8 @@
 'uploadbtn'         => 'Chargiar si il file',
 'reupload'          => 'chargiar si danovamain',
 'reuploaddesc'      => 'Anavos tar la pagina da chargiar si.',
-'uploadnologintext' => "Ti stos [[Special:Userlogin|t'annunziar]] per chargiar si files.",
-'uploadtext'        => "Cun il formular sutvart pos ti chargiar si files, per vesair u tschertgar maletgs gia chargiads si, dovra [[Special:Imagelist|quest link]]. I dat er ina [[Special:Log/upload|glista dals files chargiads si u stidads]].
+'uploadnologintext' => "Ti stos [[Special:UserLogin|t'annunziar]] per chargiar si files.",
+'uploadtext'        => "Cun il formular sutvart pos ti chargiar si files, per vesair u tschertgar maletgs gia chargiads si, dovra [[Special:ImageList|quest link]]. I dat er ina [[Special:Log/upload|glista dals files chargiads si u stidads]].
 
 Per integrar il maletg/purtret en tes artitgel sas ti per exempel duvrar in dals suandants cumonds: 
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:file.png]]</nowiki>'''
@@ -386,7 +381,7 @@
 'sourcefilename'    => 'file sin tes computer:',
 'destfilename'      => 'num dal file sin il server:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Glista dals maletgs',
 
 # MIME search
@@ -416,7 +411,7 @@
 That comes to '''\$5''' average edits per page, and '''\$6''' views per edit.
 
 La lunghezza da la [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]: '''\$7'''.",
-'userstatstext' => "There {{PLURAL:$1|is '''1''' registered [[Special:Listusers|user]]|are '''$1''' registered [[Special:Listusers|users]]}}, of which
+'userstatstext' => "There {{PLURAL:$1|is '''1''' registered [[Special:ListUsers|user]]|are '''$1''' registered [[Special:ListUsers|users]]}}, of which
 '''$2''' (or '''$4%''') {{PLURAL:$2|has|have}} $5 rights.",
 
 'disambiguations' => 'pagina per la decleraziun da noziuns',
@@ -447,7 +442,7 @@
 'speciallogtitlelabel' => 'Titel:',
 'log'                  => 'logs / cudesch da navigaziun',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'tut ils *** artitgels',
 'alphaindexline'    => '$1 enfin $2',
 'nextpage'          => 'proxima pagina ($1)',
@@ -464,7 +459,7 @@
 'categories' => 'Categorias',
 
 # E-mail user
-'mailnologintext' => "Ti stos [[Special:Userlogin|t'annunziar]] ed avair ina adressa d'email valaivla en tias [[Special:Preferences|preferenzas]] per trametter emails ad auters utilisaders.",
+'mailnologintext' => "Ti stos [[Special:UserLogin|t'annunziar]] ed avair ina adressa d'email valaivla en tias [[Special:Preferences|preferenzas]] per trametter emails ad auters utilisaders.",
 'emailuser'       => 'Trametter in email a quest utilisader',
 'emailpage'       => 'Utilisader dad email',
 'emailpagetext'   => "Sche quest utilisader ha inditgà ina adressa da mail valaivla, pudais vus al trametter cun il formular cheusut in email. Sco speditur (Absender) vegn menziunà l'adressa che vus avais inditga en vossas preferenzas, per che l'utilisader as po rispunder.",
@@ -481,10 +476,10 @@
 'watchlist'            => "mia glista d'observaziun",
 'watchlistfor'         => "(per '''$1''')",
 'watchnologin'         => "Ti n'es betg s'annunzià!",
-'watchnologintext'     => "Ti stos [[Special:Userlogin|t'annunziar]] per midar tia glista d'observaziun.",
+'watchnologintext'     => "Ti stos [[Special:UserLogin|t'annunziar]] per midar tia glista d'observaziun.",
 'addedwatch'           => 'Agiuntà a la glista dad observaziun',
 'addedwatchtext'       => "L'artitgel \"[[:\$1]]\" è vegnì agiuntà a vossa [[Special:Watchlist|glista dad observaziun]]. 
-Midadas futuras vid quai artitgel e la pagina da discussiun appertegnenta vegnan enumeradas là e l'artitgel vegn marcà '''grass''' en la [[Special:Recentchanges|glista da las ultimas midadas]].",
+Midadas futuras vid quai artitgel e la pagina da discussiun appertegnenta vegnan enumeradas là e l'artitgel vegn marcà '''grass''' en la [[Special:RecentChanges|glista da las ultimas midadas]].",
 'watch'                => 'observar',
 'watchthispage'        => 'Guarda questa pagina!',
 'unwatch'              => 'betg pli observar',
@@ -550,7 +545,6 @@
 'databasenotlocked' => 'Questa banca da datas è betg bloccada.',
 
 # Move page
-'movenologintext'         => "Ti stos [[Special:Userlogin|t'annunziar]] per spustar in artitgel.",
 'pagemovedsub'            => 'Spustà cun success',
 'articleexists'           => 'I exista gia in artitgel cun quai num. Tscherni per plaschair in auter.',
 '1movedto2'               => 'Spustà [[$1]] tar [[$2]]',
@@ -558,7 +552,7 @@
 'delete_and_move'         => 'Stidar e spustar',
 'delete_and_move_text'    => '==Stidar necessari==
 
-L\'artitgel da destinaziun "[[$1]]" exista gia. Vul ti stidar el per far plaz per spustar?',
+L\'artitgel da destinaziun "[[:$1]]" exista gia. Vul ti stidar el per far plaz per spustar?',
 'delete_and_move_confirm' => 'Gea, stidar il artitgel da destinaziun per spustar',
 'delete_and_move_reason'  => 'Stidà per far plaz per spustar',
 
@@ -615,7 +609,7 @@
 'imagemaxsize' => 'Grondezza maximala per maletgs sin paginas da descripziun',
 'thumbsize'    => 'grondezza dals maletgs da prevista (thumbnails):',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Novs maletgs',
 'ilsubmit'  => 'Tschertgar',
 'bydate'    => 'tenor data',
Index: languages/messages/MessagesRu.php
===================================================================
--- languages/messages/MessagesRu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,23 +4,21 @@
  * @ingroup Language
  * @file
  *
- * @author Александр Сигачёв
- * @author לערי ריינהארט
  * @author Ahonc
- * @author Siebrand
- * @author Illusion
- * @author VasilievVV
- * @author Putnik
- * @author Kalan
- * @author SPQRobin
+ * @author AlexSm
+ * @author Alexander Sigachov (alexander.sigachov@gmail.com)
  * @author EugeneZelenko
- * @author Innv
  * @author Flrn
  * @author HalanTul
- * @author AlexSm
+ * @author Illusion
+ * @author Innv
+ * @author Kaganer
+ * @author Kalan
  * @author MaxSem
- * @author Kaganer
- * @author Alexander Sigachov (alexander.sigachov@gmail.com)
+ * @author Putnik
+ * @author VasilievVV
+ * @author Александр Сигачёв
+ * @author לערי ריינהארט
  */
 
 /*
@@ -515,7 +513,7 @@
 'nosuchspecialpage' => 'Такой специальной страницы нет',
 'nospecialpagetext' => "<big>'''Запрошенной вами служебной страницы не существует.'''</big>
 
-См. [[Special:Specialpages|список служебных страниц]].",
+См. [[Special:SpecialPages|список служебных страниц]].",
 
 # General errors
 'error'                => 'Ошибка',
@@ -540,12 +538,12 @@
 'readonlytext'         => 'Добавление новых статей и другие изменения базы данных сейчас заблокированы: вероятно, в связи с плановым обслуживанием.
 Заблокировавший оператор оставил следующее разъяснение:
 $1',
-'missing-article'      => 'В базе данных не найдено запрашиваемого текста страницы «$1» $2.
+'missing-article'      => 'В базе данных не найдено запрашиваемого текста страницы, которая должна была быть найдена, «$1» $2.
 
 Подобная ситуация обычно возникает при попытке перехода по устаревшей ссылке на историю изменения страницы, которая была удалена.
 
 Если дело не в этом, то скорее всего, вы обнаружили ошибку в программном обеспечении.
-Пожалуйста, сообщите об этом администратору, указав URL.',
+Пожалуйста, сообщите об этом [[Special:ListUsers/sysop|администратору]], указав URL.',
 'missingarticle-rev'   => '(версия № $1)',
 'missingarticle-diff'  => '(разность: $1, $2)',
 'readonly_lag'         => 'База данных автоматически заблокирована от изменений на время, пока вторичный сервер БД не синхронизируется с первичным.',
@@ -597,8 +595,8 @@
 'logouttext'                 => 'Вы работаете в том же режиме, который был до вашего представления системе. Вы идентифицируетесь не по имени, а по IP-адресу.
 Вы можете продолжить участие в проекте анонимно или начать новый сеанс как тот же самый или другой пользователь. Некоторые страницы могут отображаться, как будто вы ещё представлены системе под именем, для борьбы с этим явлением обновите кеш браузера.',
 'welcomecreation'            => '== Добро пожаловать, $1! ==
-Вы были зарегистрированы.
-Не забудьте провести персональную настройку сайта.',
+Ваша учётная запись создана.
+Не забудьте провести [[Special:Preferences|персональную настройку]] сайта.',
 'loginpagetitle'             => 'Представиться системе',
 'yourname'                   => 'Имя участника:',
 'yourpassword'               => 'Пароль:',
@@ -734,38 +732,36 @@
 'blockedtitle'                     => 'Участник заблокирован',
 'blockedtext'                      => "<big>'''Ваша учётная запись или IP-адрес заблокированы.'''</big>
 
-Блокировка произведена администратором $1. Указана следующая причина: ''«$2»''.
+Блокировка произведена администратором $1.
+Указана следующая причина: ''«$2»''.
 
 * Начало блокировки: $8
 * Окончание блокировки: $6
 * Был заблокирован: $7
 
 Вы можете отправить письмо участнику $1 или любому другому [[{{MediaWiki:Grouppage-sysop}}|администратору]], чтобы обсудить блокировку.
-
 Обратите внимание, что вы не сможете отправить письмо администратору, если вы не зарегистрированы и не подтвердили свой адрес электронной почты в [[Special:Preferences|личных настройках]], а также если вам было запрещено отправлять письма при блокировке.
-
-Ваш IP-адрес — $3, идентификатор блокировки — #$5. Пожалуйста, указывайте эти данные в своих запросах.",
+Ваш IP-адрес — $3, идентификатор блокировки — #$5.
+Пожалуйста, указывайте эти данные в ваших обращениях.",
 'autoblockedtext'                  => 'Ваш IP-адрес автоматически заблокирован в связи с тем, что он ранее использовался кем-то из заблокированных участников. Заблокировавший его администратор ($1) указал следующую причину блокировки:
 
 :«$2»
 
 * Начало блокировки: $8
 * Окончание блокировки: $6
+* Был заблокирован: $7
 
 Вы можете отправить письмо участнику $1 или любому другому [[{{MediaWiki:Grouppage-sysop}}|администратору]], чтобы обсудить блокировку.
 
 Обратите внимание, что вы не сможете отправить письмо администратору, если вы не зарегистрированы в проекте и не подтвердили свой адрес электронной почты в [[Special:Preferences|личных настройках]], а также если вам было запрещено отправлять письма при блокировке.
 
-Ваш идентификатор блокировки — #$5. Пожалуйста, указывайте его в своих запросах.',
+Ваш IP-адрес — $3, идентификатор блокировки — #$5.
+Пожалуйста, указывайте эти данные в ваших обращениях.',
 'blockednoreason'                  => 'причина не указана',
 'blockedoriginalsource'            => 'Ниже показан текст страницы «$1».',
 'blockededitsource'                => "Ниже показан текст '''ваших изменений''' страницы «$1».",
 'whitelistedittitle'               => 'Для изменения требуется авторизация',
 'whitelistedittext'                => 'Вы должны $1 для изменения страниц.',
-'whitelistreadtitle'               => 'Для чтения требуется авторизация',
-'whitelistreadtext'                => 'Вы должны [[Special:Userlogin|зарегистрироваться]] для чтения этих страниц.',
-'whitelistacctitle'                => 'У вас нет прав, чтобы создать учётную запись',
-'whitelistacctext'                 => 'Для того чтобы иметь возможность создавать учётные записи в этой вики, вы должны [[Special:Userlogin|зарегистрироваться]] и иметь соответствующие права.',
 'confirmedittitle'                 => 'Требуется подтверждение адреса электронной почты',
 'confirmedittext'                  => 'Вы должны подтвердить ваш адрес электронной почты перед правкой страниц.
 Пожалуйста, введите и подтвердите ваш адрес эл. почты на [[Special:Preferences|странице настроек]].',
@@ -781,9 +777,10 @@
 Чтобы создать новую страницу, наберите текст в окне, расположенном ниже
 (см. [[{{MediaWiki:Helppage}}|справочную страницу]], чтобы получить больше информации).
 Если вы оказались здесь по ошибке, просто нажмите кнопку '''назад''' вашего браузера.",
-'anontalkpagetext'                 => "----''Эта страница обсуждения принадлежит анонимному участнику, который ещё не зарегистрировался или который не представился регистрированным именем.
+'anontalkpagetext'                 => "----''Эта страница обсуждения принадлежит анонимному участнику, который ещё не зарегистрировался или который не представился регистрационным именем.
 Для идентификации используется цифровой IP-адрес.
-Если вы анонимный участник и полагаете, что получили сообщения, адресованные не вам (один IP-адрес может использоваться несколькими пользователями), пожалуйста, [[Special:Userlogin|представьтесь системе]], чтобы впредь избежать возможной путаницы с другими участниками.''",
+Этот же адрес может соответствовать нескольким другим участникам.
+Если вы анонимный участник и полагаете, что получили сообщения, адресованные не вам, пожалуйста, [[Special:UserLogin|представьтесь системе]], чтобы впредь избежать возможной путаницы с другими участниками.''",
 'noarticletext'                    => "В настоящий момент текст на данной странице отсутствует. Вы можете [[Special:Search/{{PAGENAME}}|найти упоминание данного названия]] в других статьях или '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} создать страницу с таким названием]'''.",
 'userpage-userdoesnotexist'        => 'Учётной записи «$1» не существует. Убедитесь, что вы действительно желаете создать или изменить эту страницу.',
 'clearyourcache'                   => "'''Замечание:''' Чтобы после сохранения увидеть сделанные изменения, очистите кеш своего браузера: '''Mozilla / Firefox''': ''Ctrl+Shift+R'', '''IE:''' ''Ctrl+F5'', '''Safari''': ''Cmd+Shift+R'', '''Konqueror''': ''F5'', '''Opera''': через меню ''Tools→Preferences''.",
@@ -843,7 +840,7 @@
 'edittools'                        => '<!-- Расположенный здесь текст будет показываться под формой редактирования и формой загрузки. -->',
 'nocreatetitle'                    => 'Создание страниц ограничено',
 'nocreatetext'                     => 'На этом сайте ограничена возможность создания новых страниц.
-Вы можете вернуться назад и отредактировать существующую страницу, [[Special:Userlogin|представиться системе или создать новую учётную запись]].',
+Вы можете вернуться назад и отредактировать существующую страницу, [[Special:UserLogin|представиться системе или создать новую учётную запись]].',
 'nocreate-loggedin'                => 'У вас нет разрешения создавать новые страницы в этой вики.',
 'permissionserrors'                => 'Ошибки прав доступа',
 'permissionserrorstext'            => 'У вас нет прав на выполнение этой операции по {{PLURAL:$1|следующей причине|следующим причинам}}:',
@@ -868,7 +865,7 @@
 'undo-success' => 'Правка может быть отменена. Пожалуйста, просмотрите сравнение версий, чтобы убедиться, что это именно те изменения, которые вас интересуют, и нажмите «Записать страницу», чтобы изменения вступили в силу.',
 'undo-failure' => 'Правка не может быть отменена из-за несовместимости промежуточных изменений.',
 'undo-norev'   => 'Правка не может быть отменена, так как её не существует или она была удалена.',
-'undo-summary' => 'Отмена правки № $1 участника [[Special:Contributions/$2|$2]] ([[User talk:$2|обсуждение]])',
+'undo-summary' => 'Отмена правки $1 участника [[Special:Contributions/$2|$2]] ([[User talk:$2|обсуждение]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Невозможно создать учётную запись',
@@ -961,8 +958,8 @@
 
 # Suppression log
 'suppressionlog'     => 'Журнал сокрытий',
-'suppressionlogtext' => 'Ниже представлен список недавних удалений и блокировок, включающих скрытые от админисраторов материалы.
-См. [[Special:Ipblocklist|список IP-блокировок]], чтобы просмотреть список текущих блокировок.',
+'suppressionlogtext' => 'Ниже представлен список недавних удалений и блокировок, включающих скрытые от администраторов материалы.
+См. [[Special:IPBlockList|список IP-блокировок]], чтобы просмотреть список текущих блокировок.',
 
 # History merging
 'mergehistory'                     => 'Объединение историй правок',
@@ -1045,7 +1042,7 @@
 'mypreferences'            => 'Настройки',
 'prefs-edits'              => 'Количество правок:',
 'prefsnologin'             => 'Вы не представились системе',
-'prefsnologintext'         => 'Вы должны [[Special:Userlogin|представиться системе]], чтобы изменять настройки участника.',
+'prefsnologintext'         => 'Вы должны [[Special:UserLogin|представиться системе]], чтобы изменять настройки участника.',
 'prefsreset'               => 'Восстановлены настройки по умолчанию.',
 'qbsettings'               => 'Панель навигации',
 'qbsettings-none'          => 'Не показывать',
@@ -1120,7 +1117,7 @@
 'userrights-reason'           => 'Причина изменения:',
 'userrights-no-interwiki'     => 'У вас нет разрешения изменять права участников на других вики.',
 'userrights-nodatabase'       => 'База данных $1 не существует или не является локальной.',
-'userrights-nologin'          => 'Вы должны [[Special:Userlogin|представиться системе]] с учётной записи администратора, чтобы назначать права пользователям.',
+'userrights-nologin'          => 'Вы должны [[Special:UserLogin|представиться системе]] с учётной записи администратора, чтобы назначать права пользователям.',
 'userrights-notallowed'       => 'С вашей учётной записи не разрешено назначать права пользователям.',
 'userrights-changeable-col'   => 'Группы, которые вы можете изменять',
 'userrights-unchangeable-col' => 'Группы, которые вы не можете изменять',
@@ -1250,24 +1247,25 @@
 'reupload'                    => 'Изменить загрузку',
 'reuploaddesc'                => 'Вернуться к форме загрузки',
 'uploadnologin'               => 'Вы не представились системе',
-'uploadnologintext'           => 'Вы должны [[Special:Userlogin|представиться системе]],
+'uploadnologintext'           => 'Вы должны [[Special:UserLogin|представиться системе]],
 чтобы загружать файлы на сервер.',
 'upload_directory_missing'    => 'Директория для загрузок ($1) отсутствует и не может быть создана веб-сервером.',
 'upload_directory_read_only'  => 'Веб-сервер не имеет прав записи в папку ($1), в которой предполагается хранить загружаемые файлы.',
 'uploaderror'                 => 'Ошибка загрузки файла',
-'uploadtext'                  => "Используя эту форму вы можете загрузить на сервер файлы. Чтобы просмотреть ранее загруженные файлы,
-перейдите сюда: [[Special:Imagelist|список загруженных изображений]]. Загрузка и удаление файлов отражаются в [[Special:Log/upload|журнале загрузки файлов]].
+'uploadtext'                  => "Используя эту форму вы можете загрузить на сервер файлы.
+Чтобы просмотреть ранее загруженные файлы, обратитесь к [[Special:ImageList|списку загруженных файлов]]. Загрузка файлов также записывается в [[Special:Log/upload|журнал загрузок]], удаления файлов записываются в [[Special:Log/delete|журнал удалений]].
 
-Для включения изображения в статью вы можете использовать строки вида:
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|комментарий]]</nowiki>''' или
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' для непосредственной ссылки на файл.",
+Для включения файла в статью вы можете использовать строки вида:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' для вставки полной версии файла;
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|описание]]</nowiki></tt>''' для вставки уменьшенной до 200 пикселей по ширине версии файла слева от текста с выводом под ним указанного описания;
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' для вставки ссылки на файл, без отображения его содержимого на странице.",
 'upload-permitted'            => 'Разрешённые типы файлов: $1.',
 'upload-preferred'            => 'Предпочтительные типы файлов: $1.',
 'upload-prohibited'           => 'Запрещённые типы файлов: $1.',
 'uploadlog'                   => 'журнал загрузок',
 'uploadlogpage'               => 'Журнал загрузок',
-'uploadlogpagetext'           => 'Ниже представлен список последних загрузок файлов.',
+'uploadlogpagetext'           => 'Ниже представлен список последних загрузок файлов.
+См. также [[Special:NewImages|галерею новых файлов]], где сведения о новых загрузках представлены в более наглядном виде.',
 'filename'                    => 'Имя файла',
 'filedesc'                    => 'Краткое описание',
 'fileuploadsummary'           => 'Краткое описание:',
@@ -1356,7 +1354,7 @@
 'upload_source_url'  => ' (правильный, публично доступный интернет-адрес)',
 'upload_source_file' => ' (файл на вашем компьютере)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Эта служебная страница показывает все загруженные файлы.
 Недавно загруженные файлы по умолчанию показываются в верху списка.
 Щелчок на заголовке колонки изменяет порядок сортировки.',
@@ -1384,7 +1382,7 @@
 'imagelinks'                     => 'Ссылки',
 'linkstoimage'                   => '{{PLURAL:$1|Следующая $1 страница ссылается|Следующие $1 страницы ссылаются|Следующие $1 страниц ссылаются}} на данный файл:',
 'nolinkstoimage'                 => 'Нет страниц, ссылающихся на данный файл.',
-'morelinkstoimage'               => 'Просмотреть [[Special:Whatlinkshere/$1|остальные ссылки]] на этот файл.',
+'morelinkstoimage'               => 'Просмотреть [[Special:WhatLinksHere/$1|остальные ссылки]] на этот файл.',
 'redirectstofile'                => 'Со {{PLURAL:$1|следующего $1 файла установлено перенаправление|следующих $1 файлов установлены перенаправления|следующих $1 файлов установлены перенаправления}} на этот файл:',
 'duplicatesoffile'               => '{{PLURAL:$1|Следующий $1 файл является дубликатом|Следующие $1 файла являются дубликатами|Следующие $1 файлов являются дубликатами}} этого файла:',
 'sharedupload'                   => 'Этот файл загружен в общее для нескольких проектов хранилище.',
@@ -1407,7 +1405,7 @@
 'filerevert-comment'        => 'Примечание:',
 'filerevert-defaultcomment' => 'Возврат к версии от $2, $1',
 'filerevert-submit'         => 'Возвратить',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' был возвращён к [$4 версии от $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' был возвращён к [$4 версии от $3, $2].",
 'filerevert-badversion'     => 'Не существует предыдущей локальной версии этого файла с указанной отметкой даты и времени.',
 
 # File deletion
@@ -1476,8 +1474,10 @@
 Вместо этого они, вероятно, должны указывать на соответствующую конкретную статью.<br />
 Страница считается многозначной, если на ней размещён шаблон, имя которого указано на странице [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Двойные перенаправления',
-'doubleredirectstext' => 'На этой странице представлен список перенаправлений на другие перенаправления. Каждая строка содержит ссылки на первое и второе перенаправления, а также первую строчку страницы второго перенаправления, в которой обычно указывается название страницы, куда должно ссылаться первое перенаправление.',
+'doubleredirects'            => 'Двойные перенаправления',
+'doubleredirectstext'        => 'На этой странице представлен список перенаправлений на другие перенаправления. Каждая строка содержит ссылки на первое и второе перенаправления, а также первую строчку страницы второго перенаправления, в которой обычно указывается название страницы, куда должно ссылаться первое перенаправление.',
+'double-redirect-fixed-move' => 'Страница [[$1]] была переименована, сейчас она перенаправляет на [[$2]]',
+'double-redirect-fixer'      => 'Исправитель перенаправлений',
 
 'brokenredirects'        => 'Разорванные перенаправления',
 'brokenredirectstext'    => 'Следующие перенаправления указывают на несуществующие статьи:',
@@ -1563,7 +1563,7 @@
 'logempty'             => 'Подходящие записи в журнале отсутствуют.',
 'log-title-wildcard'   => 'Найти заголовки, начинающиеся на с данных символов',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Все страницы',
 'alphaindexline'    => 'от $1 до $2',
 'nextpage'          => 'Следующая страница ($1)',
@@ -1586,15 +1586,15 @@
 'special-categories-sort-count' => 'упорядочить по количеству',
 'special-categories-sort-abc'   => 'упорядочить по алфавиту',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Показать участников, начиная с:',
 'listusers-submit'   => 'Показать',
 'listusers-noresult' => 'Не найдено участников.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Права групп участников',
 'listgrouprights-summary'  => 'Ниже представлен список определённых в этой вики групп участников, указаны соответствующие им права доступа.
-Дополнительную информацию об индивидуальных правах можно найти на странице [[{{MediaWiki:Listgrouprights-helppage}}]].',
+Возможно, существует [[{{MediaWiki:Listgrouprights-helppage}}|дополнительная информация]] об индивидуальных правах.',
 'listgrouprights-group'    => 'Группа',
 'listgrouprights-rights'   => 'Права',
 'listgrouprights-helppage' => 'Help:Права групп',
@@ -1602,7 +1602,7 @@
 
 # E-mail user
 'mailnologin'     => 'Адрес для отправки отсутствует',
-'mailnologintext' => 'Вы должны [[Special:Userlogin|представиться системе]] и иметь действительный адрес электронной почты в ваших [[Special:Preferences|настройках]], чтобы иметь возможность отправлять электронную почту другим участникам.',
+'mailnologintext' => 'Вы должны [[Special:UserLogin|представиться системе]] и иметь действительный адрес электронной почты в ваших [[Special:Preferences|настройках]], чтобы иметь возможность отправлять электронную почту другим участникам.',
 'emailuser'       => 'Письмо участнику',
 'emailpage'       => 'Письмо участнику',
 'emailpagetext'   => 'Если этот участник указал действительный адрес электронной почты в своих настройках, то, заполнив форму ниже, можно отправить ему сообщение.
@@ -1629,10 +1629,10 @@
 'nowatchlist'          => 'Ваш список наблюдения пуст.',
 'watchlistanontext'    => 'Вы должны $1, чтобы просмотреть или отредактировать список наблюдения.',
 'watchnologin'         => 'Нужно представиться системе',
-'watchnologintext'     => 'Вы должны [[Special:Userlogin|представиться системе]], чтобы иметь возможность изменять свой список наблюдения',
+'watchnologintext'     => 'Вы должны [[Special:UserLogin|представиться системе]], чтобы иметь возможность изменять свой список наблюдения',
 'addedwatch'           => 'Добавлена в список наблюдения',
 'addedwatchtext'       => 'Страница «[[:$1]]» была добавлена в ваш [[Special:Watchlist|список наблюдения]].
-Последующие изменения этой страницы и связанной с ней страницы обсуждения будут отмечаться в этом списке, а также будут выделены жирным шрифтом на странице со [[Special:Recentchanges|списком свежих изменений]], чтобы их было легче заметить.',
+Последующие изменения этой страницы и связанной с ней страницы обсуждения будут отмечаться в этом списке, а также будут выделены жирным шрифтом на странице со [[Special:RecentChanges|списком свежих изменений]], чтобы их было легче заметить.',
 'removedwatch'         => 'Удалена из списка наблюдения',
 'removedwatchtext'     => 'Страница «[[:$1]]» была удалена из вашего списка наблюдения.',
 'watch'                => 'Следить',
@@ -1735,10 +1735,10 @@
 'rollbacklink'                => 'откатить',
 'rollbackfailed'              => 'Ошибка при совершении отката',
 'cantrollback'                => 'Невозможно откатить изменения; последний, кто вносил изменения, является единственным автором этой статьи.',
-'alreadyrolled'               => 'Невозможно откатить последние изменения [[:$1]],сделанные [[User:$2|$2]] ([[User talk:$2|Обсуждение]]);
+'alreadyrolled'               => 'Невозможно откатить последние изменения [[:$1]], сделанные [[User:$2|$2]] ([[User talk:$2|Обсуждение]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
 кто-то другой уже отредактировал или откатил эту страницу.
 
-Последние изменения внёс [[User:$3|$3]] ([[User talk:$3|Обсуждение]]).',
+Последние изменения внёс [[User:$3|$3]] ([[User talk:$3|Обсуждение]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Изменение было пояснено так: <i>«$1»</i>.', # only shown if there is an edit comment
 'revertpage'                  => 'Правки [[Special:Contributions/$2|$2]] ([[User talk:$2|обсуждение]]) откачены к версии [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Откачены правки $1; возврат к версии $2.',
@@ -1746,7 +1746,7 @@
 это действие было отменено в целях предотвращения «захвата сеанса».
 Пожалуйста, нажмите кнопку «Назад» и перезагрузите страницу, с которой вы пришли.',
 'protectlogpage'              => 'Журнал защиты',
-'protectlogtext'              => 'Ниже приведён журнал установок и снятий защиты со статей. Вы можете также просмотреть [[Special:Protectedpages|список страниц, которые в данный момент защищены]].',
+'protectlogtext'              => 'Ниже приведён журнал установок и снятий защиты со статей. Вы можете также просмотреть [[Special:ProtectedPages|список страниц, которые в данный момент защищены]].',
 'protectedarticle'            => 'защищена страница «[[$1]]»',
 'modifiedarticleprotection'   => 'изменён уровень защиты страницы «[[$1]]»',
 'unprotectedarticle'          => 'снята защита со страницы «[[$1]]»',
@@ -1856,7 +1856,7 @@
 
 # What links here
 'whatlinkshere'            => 'Ссылки сюда',
-'whatlinkshere-title'      => 'Страницы, ссылающиеся на $1',
+'whatlinkshere-title'      => 'Страницы, ссылающиеся на «$1»',
 'whatlinkshere-page'       => 'Страница:',
 'linklistsub'              => '(Список ссылок)',
 'linkshere'                => "Следующие страницы ссылаются на '''[[:$1]]''':",
@@ -1909,7 +1909,7 @@
 'badipaddress'                    => 'IP-адрес записан в неправильном формате, или участника с таким именем не существует.',
 'blockipsuccesssub'               => 'Блокировка произведена',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|«$1»]] заблокирован.<br />
-См. [[Special:Ipblocklist|список заблокированных IP-адресов]].',
+См. [[Special:IPBlockList|список заблокированных IP-адресов]].',
 'ipb-edit-dropdown'               => 'Редактировать список причин блокировки',
 'ipb-unblock-addr'                => 'Разблокировать $1',
 'ipb-unblock'                     => 'Разблокировать участника или IP-адрес',
@@ -1921,7 +1921,7 @@
 'ipusubmit'                       => 'Разблокировать этот адрес',
 'unblocked'                       => '[[User:$1|$1]] разблокирован.',
 'unblocked-id'                    => 'Блокировка $1 была снята',
-'ipblocklist'                     => 'Список заблокированных IP-адресов и имён участников',
+'ipblocklist'                     => 'Заблокированные IP-адреса и учётные записи',
 'ipblocklist-legend'              => 'Поиск заблокированного участника',
 'ipblocklist-username'            => 'Имя участника или IP-адрес:',
 'ipblocklist-submit'              => 'Найти',
@@ -1942,7 +1942,7 @@
 'blocklogentry'                   => 'заблокировал [[$1]] на период $2 $3',
 'blocklogtext'                    => 'Журнал блокирования и разблокирования участников.
 Автоматически блокируемые IP-адреса здесь не указываются.
-См. [[Special:Ipblocklist|Список текущих запретов и блокировок]].',
+См. [[Special:IPBlockList|Список текущих запретов и блокировок]].',
 'unblocklogentry'                 => 'разблокировал $1',
 'block-log-flags-anononly'        => 'только анонимные пользователи',
 'block-log-flags-nocreate'        => 'запрещена регистрация учётных записей',
@@ -1983,7 +1983,7 @@
 'lockdbsuccesssub'    => 'База данных заблокирована',
 'unlockdbsuccesssub'  => 'База данных разблокирована',
 'lockdbsuccesstext'   => 'База данных проекта была заблокирована.<br />
-Не забудьте [[Special:Unlockdb|убрать блокировку]] после завершения процедуры обслуживания.',
+Не забудьте [[Special:UnlockDB|убрать блокировку]] после завершения процедуры обслуживания.',
 'unlockdbsuccesstext' => 'База данных проекта была разблокирована.',
 'lockfilenotwritable' => 'Нет права на запись в файл блокировки базы данных. Чтобы заблокировать или разблокировать БД, веб-сервер должен иметь разрешение на запись в этот файл.',
 'databasenotlocked'   => 'База данных не была заблокирована.',
@@ -1993,14 +1993,16 @@
 'move-page-legend'        => 'Переименование страницы',
 'movepagetext'            => "Воспользовавшись формой ниже, вы переименуете страницу, одновременно переместив на новое место её журнал изменений.
 Старое название станет перенаправлением на новое название.
-Ссылки на старое название не будут изменены (пожалуйста, проверьте наличие двойных и разорванных перенаправлений).
-Вы обязаны убедиться в том, что ссылки и далее указывают туда, куда предполагалось.
+Вы можете автоматически обновить перенаправления, которые вели на старое название.
+Если вы этого не сделаете, пожалуйста, проверьте наличие [[Special:DoubleRedirects|двойных]] и [[Special:BrokenRedirects|разорванных перенаправлений]].
+Вы отвечаете за то, что бы ссылки продолжали и далее указывают туда, куда предполагалось.
 
-Обратите внимание, что страница '''не будет''' переименована, если страница с новым названием уже существует (кроме случаев, если она является перенаправлением или пуста и не имеет истории правок).
+Обратите внимание, что страница '''не будет''' переименована, если страница с новым названием уже существует, кроме случаев, если она является перенаправлением или пуста и не имеет истории правок.
 Это означает, что вы можете переименовать страницу обратно в то название, которое у него только что было, если вы переименовали по ошибке, но вы не можете случайно затереть существующую страницу.
 
 '''ПРЕДУПРЕЖДЕНИЕ!'''
-Переименование может привести к масштабным и неожиданным изменениям для ''популярных'' страниц. Пожалуйста, прежде чем вы продолжите, убедитесь, что вы понимаете все возможные последствия.",
+Переименование может привести к масштабным и неожиданным изменениям для ''популярных'' страниц.
+Пожалуйста, прежде чем вы продолжите, убедитесь, что вы понимаете все возможные последствия.",
 'movepagetalktext'        => "Присоединённая страница обсуждения, если таковая есть,
 будет также автоматически переименована, '''кроме случаев, когда:'''
 
@@ -2010,9 +2012,6 @@
 В этих случаях, вы будете вынуждены переместить или объединить страницы вручную,
 если это нужно.",
 'movearticle'             => 'Переименовать страницу',
-'movenologin'             => 'Вы не представились системе',
-'movenologintext'         => 'Вы должны [[Special:Userlogin|представиться системе]],
-чтобы иметь возможность переименовать страницы.',
 'movenotallowed'          => 'У вас нет разрешения переименовывать страницы в {{GRAMMAR:genitive|{{SITENAME}}}}.',
 'newtitle'                => 'Новое название',
 'move-watch'              => 'Включить эту страницу в список наблюдения',
@@ -2040,7 +2039,7 @@
 'delete_and_move'         => 'Удалить и переименовать',
 'delete_and_move_text'    => '==Требуется удаление==
 
-Страница с именем [[$1|«$1»]] уже существует. Вы хотите её удалить, чтобы сделать возможным переименование?',
+Страница с именем [[:$1|«$1»]] уже существует. Вы хотите её удалить, чтобы сделать возможным переименование?',
 'delete_and_move_confirm' => 'Да, удалить эту страницу',
 'delete_and_move_reason'  => 'Удалено для возможности переименования',
 'selfmove'                => 'Невозможно переименовать страницу: исходное и новое имя страницы совпадают.',
@@ -2048,6 +2047,7 @@
 'imagenocrossnamespace'   => 'Невозможно дать изображению имя из другого пространства имён',
 'imagetypemismatch'       => 'Новое расширение файла не соответствует его типу',
 'imageinvalidfilename'    => 'Целевое имя файла ошибочно',
+'fix-double-redirects'    => 'Автоматически исправить перенаправления, указывающие на прежнее название',
 
 # Export
 'export'            => 'Экспортирование статей',
@@ -2094,7 +2094,7 @@
 'import-interwiki-history'   => 'Копировать всю историю изменений этой страницы',
 'import-interwiki-submit'    => 'Импортировать',
 'import-interwiki-namespace' => 'Помещать страницы в пространство имён:',
-'importtext'                 => 'Пожалуйста, экспортируйте страницу из исходной вики, используя инструмент Special:Export, сохраните файл на диск, а затем загрузите его сюда.',
+'importtext'                 => 'Пожалуйста, экспортируйте страницу из исходной вики, используя [[Special:Export|соответствующий инструмент]]. Сохраните файл на диск, а затем загрузите его сюда.',
 'importstart'                => 'Импортирование страниц…',
 'import-revision-count'      => '$1 {{PLURAL:$1|версия|версии|версий}}',
 'importnopages'              => 'Нет страниц для импортирования.',
@@ -2257,9 +2257,10 @@
 'markedaspatrollederror-noautopatrol' => 'Вам не разрешено отмечать собственные правки как проверенные.',
 
 # Patrol log
-'patrol-log-page' => 'Журнал патрулирования',
-'patrol-log-line' => 'проверена $1 из $2 $3',
-'patrol-log-auto' => '(автоматически)',
+'patrol-log-page'   => 'Журнал патрулирования',
+'patrol-log-header' => 'Это журнал патрулированных версий.',
+'patrol-log-line'   => 'проверена $1 из $2 $3',
+'patrol-log-auto'   => '(автоматически)',
 
 # Image deletion
 'deletedrevision'                 => 'Удалена старая версия $1',
@@ -2289,10 +2290,10 @@
 'show-big-image'       => 'Изображение в более высоком разрешении',
 'show-big-image-thumb' => '<small>Размер при предпросмотре: $1 × $2 пикселов</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Галерея новых файлов',
 'imagelisttext'         => "Ниже представлен список из '''$1''' {{PLURAL:$1|файла|файлов|файлов}}, отсортированных $2.",
-'newimages-summary'     => 'Эта служебная страница показывает недавно загруженные файлы',
+'newimages-summary'     => 'Эта служебная страница показывает недавно загруженные файлы.',
 'showhidebots'          => '($1 ботов)',
 'noimages'              => 'Изображения отсутствуют.',
 'ilsubmit'              => 'Найти',
@@ -2584,7 +2585,7 @@
 
 # External editor support
 'edit-externally'      => 'Редактировать этот файл, используя внешнюю программу',
-'edit-externally-help' => 'Подробности см. на странице [http://meta.wikimedia.org/wiki/Help:External_editors Meta:Help:External_editors].',
+'edit-externally-help' => 'Подробности см. на странице [http://www.mediawiki.org/wiki/Manual:External_editors Meta:Help:External_editors].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'все',
@@ -2660,7 +2661,7 @@
 'unit-pixel' => ' пикс.',
 
 # HTML dump
-'redirectingto' => 'Перенаправление на страницу [[$1]]…',
+'redirectingto' => 'Перенаправление на страницу [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Очистить кеш этой страницы?
@@ -2805,7 +2806,7 @@
 'version-software-product'         => 'Продукт',
 'version-software-version'         => 'Версия',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Путь к файлу',
 'filepath-page'    => 'Файл:',
 'filepath-submit'  => 'Путь',
@@ -2843,7 +2844,7 @@
 'specialpages-group-redirects'   => 'Перенаправляющие служебные страницы',
 'specialpages-group-spam'        => 'Инструменты против спама',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Пустая страница',
 'intentionallyblankpage' => 'Эта страница намеренно оставлена пустой',
 
Index: languages/messages/MessagesCrh_latn.php
===================================================================
--- languages/messages/MessagesCrh_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCrh_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Alessandro
- * @author Siebrand
  * @author AlefZet
+ * @author Alessandro
  */
 
 $fallback8bitEncoding = 'windows-1254';
@@ -385,7 +384,7 @@
 'nosuchspecialpage' => 'Bu isimde bir mahsus saife yoq',
 'nospecialpagetext' => "<big>'''Tapılmağan bir mahsus saifege kirdiñiz.'''</big>
 
-Bar olğan bütün mahsus saifelerni [[Special:Specialpages|{{int:specialpages}}]] saifesinde körip olursıñız.",
+Bar olğan bütün mahsus saifelerni [[Special:SpecialPages|{{int:specialpages}}]] saifesinde körip olursıñız.",
 
 # General errors
 'error'                => 'Hata',
@@ -612,10 +611,6 @@
 'blockededitsource'         => "Aşağıda \"\$1\" saifesindeki '''yapqan deñiştirmeleriñizniñ''' metini buluna.",
 'whitelistedittitle'        => 'Deñiştirmek içün oturım açmalısıñız',
 'whitelistedittext'         => 'Saifeni deñiştirmek içün $1 kereksiñiz.',
-'whitelistreadtitle'        => 'Oqumaq içün oturım açmaq kerek',
-'whitelistreadtext'         => 'Bu saifelerni oqumaq içün [[Special:Userlogin|qayd olunmalısıñız]].',
-'whitelistacctitle'         => 'Esap açma iziniñiz yoq',
-'whitelistacctext'          => 'Bu vikide esap açmağa çare saibi olmaq içün [[Special:Userlogin|qayd olunmaq]] ve kelişikli aqlar saibi olmaq kereksiñiz.',
 'confirmedittitle'          => 'E-mail adresini tasdıqlamaq lâzimdir',
 'confirmedittext'           => 'Saifeni deñiştirmeden evel e-mail adresiñizni tasdıqlamalısıñız. Lütfen, [[Special:Preferences|ayarlar saifesinde]] e-mail adresiñizni ekleñiz ve tasdıqlañız.',
 'nosuchsectiontitle'        => 'Öyle bölüm yoq',
@@ -627,7 +622,7 @@
 'accmailtext'               => '$1 içün parol mında yollandı: $2.',
 'newarticle'                => '(Yañı)',
 'newarticletext'            => "Siz bu bağlantınen şimdilik yoq olğan saifege avuştıñız. Yañı bir saife yaratmaq içün aşağıda bulunğan pencerege metin yazıñız (tafsilâtlı malümat almaq içün [[{{MediaWiki:Helppage}}|yardım saifesine]] baqıñız). Bu saifege tesadüfen avuşqan olsañız, brauzeriñizdeki '''keri''' dögmesine basıñız.",
-'anontalkpagetext'          => "----''Bu muzakere saifesi şimdilik qayd olunmağan ya da oturımını açmağan adsız (anonim) qullanıcığa mensüptir. İdentifikatsiya içün IP adres işletile. Eger siz anonim qullanıcı olsañız ve sizge kelgen beyanatlarnı yañlıştan kelgenini belleseñiz (bir IP adresinden bir qaç qullanıcı faydalanıp ola), lütfen, artıq bunıñ kibi qarışıqlıq olmasın dep [[Special:Userlogin|oturım açıñız]].''",
+'anontalkpagetext'          => "----''Bu muzakere saifesi şimdilik qayd olunmağan ya da oturımını açmağan adsız (anonim) qullanıcığa mensüptir. İdentifikatsiya içün IP adres işletile. Eger siz anonim qullanıcı olsañız ve sizge kelgen beyanatlarnı yañlıştan kelgenini belleseñiz (bir IP adresinden bir qaç qullanıcı faydalanıp ola), lütfen, artıq bunıñ kibi qarışıqlıq olmasın dep [[Special:UserLogin|oturım açıñız]].''",
 'noarticletext'             => 'Bu saife boştır. Bu serlevanı başqa saifelerde [[Special:Search/{{PAGENAME}}|qıdırıp olasıñız]] ya da bu saifeni özüñiz [{{fullurl:{{FULLPAGENAME}}|action=edit}} yazıp olasıñız].',
 'userpage-userdoesnotexist' => '"$1" adlı qullanıcı yoqtır. Tamam bu saifeni deñiştirmege istegeniñizni teşkeriñiz.',
 'clearyourcache'            => "'''İhtar:''' Ayarlarıñıznı saqlağandan soñ, brauzeriñizniñ keşini de temizlemek kereksiñiz: '''Mozilla / Firefox / Safari:''' ''Shift'' basılı ekende saifeni yañıdan yüklep ya da ''Ctrl-Shift-R'' yapıp (Apple Mac içün ''Cmd-Shift-R'');, '''Internet Explorer:''' ''Ctrl-F5'', '''Konqueror:''' Tek saifeni yañıdan yükle dögmesine basıp.",
@@ -682,7 +677,7 @@
 'hiddencategories'          => 'Bu saife $1 gizli kategoriyağa mensüptir:',
 'nocreatetitle'             => 'Saife yaratuv sıñırlıdır',
 'nocreatetext'              => '{{SITENAME}} saytında yañı saife yaratuv sıñırlıdır.
-Keri qaytıp mevcüt olğan saifeni deñiştire, [[Special:Userlogin|oturım aça ya da yañı bir esap yaratıp olasıñız]].',
+Keri qaytıp mevcüt olğan saifeni deñiştire, [[Special:UserLogin|oturım aça ya da yañı bir esap yaratıp olasıñız]].',
 'nocreate-loggedin'         => '{{SITENAME}} saytında yañı saifeler yaratmağa iziniñiz yoqtır.',
 'permissionserrors'         => 'İrişim aqlarınıñ hataları',
 'permissionserrorstext'     => 'Bunı yapmağa iziniñiz yoqtır. {{PLURAL:$1|Sebep|Sebepler}}:',
@@ -777,7 +772,7 @@
 'mypreferences'         => 'Ayarlarım',
 'prefs-edits'           => 'Yapqan deñişiklik sayısı:',
 'prefsnologin'          => 'Oturım açmadıñız',
-'prefsnologintext'      => 'Şahsiy ayarlarıñıznı deñiştirmek içün [[Special:Userlogin|oturım açmaq]] kereksiñiz.',
+'prefsnologintext'      => 'Şahsiy ayarlarıñıznı deñiştirmek içün [[Special:UserLogin|oturım açmaq]] kereksiñiz.',
 'prefsreset'            => 'Ayarlar ilk alına ketirildi.',
 'qbsettings'            => 'Vızlı irişim sutun ayarları',
 'changepassword'        => 'Parol deñiştir',
@@ -886,10 +881,10 @@
 'reupload'                    => 'Yañıdan yükle',
 'reuploaddesc'                => 'Yükleme formasına keri qayt.',
 'uploadnologin'               => 'Oturım açmadıñız',
-'uploadnologintext'           => 'Fayl yüklep olmaq içün [[Special:Userlogin|oturım açmaq]] kereksiñiz.',
+'uploadnologintext'           => 'Fayl yüklep olmaq içün [[Special:UserLogin|oturım açmaq]] kereksiñiz.',
 'upload_directory_read_only'  => 'Web serverniñ ($1) cüzdanına fayllar saqlamağa aqları yoqtır.',
 'uploaderror'                 => 'Yükleme hatası',
-'uploadtext'                  => "Fayllar yüklemek içün aşağıdaki formanı qullanıñız. Evelce yüklengen resim tapmaq ya da baqmaq içün [[Special:Imagelist|yüklengen fayllar cedveline]] keçiñiz, bundan ğayrı fayl yüklenüv ve yoq etilüv qaydlarını [[Special:Log/upload|yüklenüv jurnalında]] tapıp olasıñız.
+'uploadtext'                  => "Fayllar yüklemek içün aşağıdaki formanı qullanıñız. Evelce yüklengen resim tapmaq ya da baqmaq içün [[Special:ImageList|yüklengen fayllar cedveline]] keçiñiz, bundan ğayrı fayl yüklenüv ve yoq etilüv qaydlarını [[Special:Log/upload|yüklenüv jurnalında]] tapıp olasıñız.
 
 Saifede resim qullanmaq içün böyle şekilli bağlantılar qullanıñız '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''', '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|resim tarifi]]</nowiki>''' ya da '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' faylğa vastasız bağlantı içün.",
 'upload-permitted'            => 'İzinli fayl çeşitleri: $1.',
@@ -971,7 +966,7 @@
 'upload_source_url'  => ' (doğru, püblik tarzda kirmege musaadeli internet adres)',
 'upload_source_file' => ' (kompyuteriñizdeki fayl)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Fayl adı qıdıruv:',
 'imgfile'               => 'fayl',
 'imagelist'             => 'Resim cedveli',
@@ -1126,7 +1121,7 @@
 'logempty'             => 'Jurnalda bir kelgen malümat yoq.',
 'log-title-wildcard'   => 'Bu simvollardan başlanğan serlevalarnı qıdır',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Bütün saifeler',
 'alphaindexline'    => '$1-den $2-ge',
 'nextpage'          => 'Soñraki saife ($1)',
@@ -1148,13 +1143,13 @@
 'special-categories-sort-count' => 'sayılarına köre sırala',
 'special-categories-sort-abc'   => 'elifbe sırasınen sırala',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Köster',
 'listusers-noresult' => 'İç bir qullanıcı tapılmadı.',
 
 # E-mail user
 'mailnologin'     => 'Mektüp yollanacaq adresi yoqtır',
-'mailnologintext' => 'Diger qullanıcılarğa elektron mektüpler yollap olmaq içün [[Special:Userlogin|oturım açmalısıñız]] ve [[Special:Preferences|ayarlarıñızda]] mevcüt olğan e-mail adresiniñ saibi olmalısıñız.',
+'mailnologintext' => 'Diger qullanıcılarğa elektron mektüpler yollap olmaq içün [[Special:UserLogin|oturım açmalısıñız]] ve [[Special:Preferences|ayarlarıñızda]] mevcüt olğan e-mail adresiniñ saibi olmalısıñız.',
 'emailuser'       => 'Qullanıcığa mektüp',
 'emailpage'       => 'Qullanıcığa elektron mektüp yolla',
 'emailpagetext'   => 'İşbu qullanıcı öz ayarlarında mevcüt olğan elektron poçta adresini yazğan olsa, aşağıdaki formanı toldurıp oña beyanat yollap olursıñız.
@@ -1180,9 +1175,9 @@
 'nowatchlist'          => 'Siziñ közetüv cedveliñiz boştır.',
 'watchlistanontext'    => 'Közetüv cedvelini baqmaq ya da deñiştirmek içün $1 borclusıñız.',
 'watchnologin'         => 'Oturım açmaq kerek',
-'watchnologintext'     => 'Öz közetüv cedveliñizni deñiştirmek içün [[Special:Userlogin|oturım açıñız]]',
+'watchnologintext'     => 'Öz közetüv cedveliñizni deñiştirmek içün [[Special:UserLogin|oturım açıñız]]',
 'addedwatch'           => 'Közetüv cedveline kirsetmek',
-'addedwatchtext'       => '"[[:$1]]" saifesi [[Special:Watchlist|kozetüv cevdeliñizge]] kirsetildi. Bu saifedeki ve onıñnen bağlı saifelerdeki olacaq deñişiklikler bu cedvelde belgilenecek, em de olar közge çarpması içün [[Special:Recentchanges|yañı deñişiklik cedveli]] bulunğan saifede qalın olaraq kösterilir.
+'addedwatchtext'       => '"[[:$1]]" saifesi [[Special:Watchlist|kozetüv cevdeliñizge]] kirsetildi. Bu saifedeki ve onıñnen bağlı saifelerdeki olacaq deñişiklikler bu cedvelde belgilenecek, em de olar közge çarpması içün [[Special:RecentChanges|yañı deñişiklik cedveli]] bulunğan saifede qalın olaraq kösterilir.
 Birazdan soñ közetüv cedveliñizden bir de bir saifeni yoq etmege isteseñiz de, saifeniñ yuqarısındaki sol tarafta "közetme" dögmesine basıñız.',
 'removedwatch'         => 'Közetüv cedvelinden yoq et',
 'removedwatchtext'     => '"[[:$1]]" saifesi közetüv cedveliñizden yoq etildi.',
@@ -1254,7 +1249,7 @@
 'exblank'                     => 'saife metini boş',
 'historywarning'              => 'Tenbi: Siz yoq etmek üzre olğan saifeniñ keçmişi bardır:',
 'confirmdeletetext'           => 'Bir saifeni ya da resimni bütün keçmişi ile birlikte malümat bazasından qalıcı olaraq yoq etmek üzresiñiz.
-Lütfen, neticelerini añlağanıñıznı, [[Special:Whatlinkshere/{{FULLPAGENAME}}|saifege bağlantılarını]] teşkergenden soñ ve [[{{MediaWiki:Policy-url}}|yoq etüv politikasına]] uyğunlığını diqqatqa alıp, bunı yapmağa istegeniñizni tasdıqlañız.',
+Lütfen, neticelerini añlağanıñıznı, [[Special:WhatLinksHere/{{FULLPAGENAME}}|saifege bağlantılarını]] teşkergenden soñ ve [[{{MediaWiki:Policy-url}}|yoq etüv politikasına]] uyğunlığını diqqatqa alıp, bunı yapmağa istegeniñizni tasdıqlañız.',
 'actioncomplete'              => 'İşlem tamamlandı.',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" yoq etildi.
 yaqın zamanda yoq etilgenlerni körmek içün: $2.',
@@ -1275,7 +1270,7 @@
 'revertpage'                  => '[[Special:Contributions/$2|$2]] ([[User talk:$2|muzakere]]) tarafından yapılğan deñişiklikler keri alınıp, [[User:$1|$1]] tarafından deñiştirilgen evelki versiya keri ketirildi.', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'protectlogpage'              => 'Qorçalav jurnalı',
 'protectlogtext'              => 'Qorçalavğa aluv/çıqaruv ile bağlı deñişiklikler jurnalını körmektesiñiz.
-Qorçalav altına alınğan saifeler tam cedveli [[Special:Protectedpages|bu saifede]] körip olasıñız.',
+Qorçalav altına alınğan saifeler tam cedveli [[Special:ProtectedPages|bu saifede]] körip olasıñız.',
 'protectedarticle'            => '"[[$1]]" qorçalav altına alındı',
 'unprotectedarticle'          => 'qorçalav çıqarlıdı: "[[$1]]"',
 'protect-legend'              => 'Qorçalavnı tasdıqla',
@@ -1370,7 +1365,7 @@
 'badipaddress'            => 'Keçersiz IP adresi',
 'blockipsuccesssub'       => 'IP adresni ban etüv işlevi muvafaqiyetli oldı',
 'blockipsuccesstext'      => '"$1" ban etildi.
-<br />[[Special:Ipblocklist|IP adresi ban etilgenler]] cedveline baqıñız .',
+<br />[[Special:IPBlockList|IP adresi ban etilgenler]] cedveline baqıñız .',
 'unblockip'               => 'Qullanıcınıñ ban etüvini çıqar',
 'ipusubmit'               => 'Bu adresniñ ban etüvini çıqar',
 'ipblocklist'             => 'Blok etilgen qullanıcılar ve IP adresleri cedveli',
@@ -1383,7 +1378,7 @@
 'autoblocker'             => 'Avtomatik olaraq ban ettiñiz çünki yaqın zamanda IP adresiñiz "[[User:$1|$1]]" qullanıcısı tarafından qullanıldı. $1 adlı qullanıcınıñ ban etilüvi içün berilgen sebep: "\'\'\'$2\'\'\'"',
 'blocklogpage'            => 'İrişim ban etüv jurnalı',
 'blocklogentry'           => '"[[$1]]" irişimi $2 $3 toqtatıldı. Sebep',
-'blocklogtext'            => 'Mında qullanıcı irişimine yönelik ban etüv ve ban çıqaruv jurnalı cedvellene. Avtomatik IP adresi ban etüvleri cedvelge kirsetilmedi. Al-azırda irişimi toqtatılğan qullanıcılarnı [[Special:Ipblocklist|IP ban etüv cedveli]] saifesinden körip olasıñız.',
+'blocklogtext'            => 'Mında qullanıcı irişimine yönelik ban etüv ve ban çıqaruv jurnalı cedvellene. Avtomatik IP adresi ban etüvleri cedvelge kirsetilmedi. Al-azırda irişimi toqtatılğan qullanıcılarnı [[Special:IPBlockList|IP ban etüv cedveli]] saifesinden körip olasıñız.',
 'unblocklogentry'         => '$1 qullanıcınıñ ban etüvi çıqarıldı',
 'block-log-flags-noemail' => 'e-mail blok etildi',
 'ipb_expiry_invalid'      => 'Keçersiz bitiş zamanı.',
@@ -1415,8 +1410,6 @@
 
 Böyle allarda, kerek olsa, saifelerni qolnen taşımağa ya da birleştirmege mecbur olursıñız.",
 'movearticle'             => 'Eski ad',
-'movenologin'             => 'Oturım açmadıñız',
-'movenologintext'         => 'Saifeniñ adını deñiştirip olmaq içün [[Special:Userlogin|oturım açıñız]].',
 'movenotallowed'          => '{{SITENAME}} saytında saifeler adlarını deñiştirmege iziniñiz yoq.',
 'newtitle'                => 'Yañı ad',
 'move-watch'              => 'Bu saifeni közet',
@@ -1437,7 +1430,7 @@
 'delete_and_move'         => 'Yoq et ve adını deñiştir',
 'delete_and_move_text'    => '==Yoq etmek lâzimdir==
 
-"[[$1]]" saifesi endi mevcüt. Adını deñiştirip olmaq içün onı yoq etmege isteysiñizmi?',
+"[[:$1]]" saifesi endi mevcüt. Adını deñiştirip olmaq içün onı yoq etmege isteysiñizmi?',
 'delete_and_move_confirm' => 'Ebet, bu saifeni yoq et',
 'delete_and_move_reason'  => 'İsim deñiştirip olmaq içün yoq etildi',
 'selfmove'                => 'Bu saifeniñ adını deñiştirmege imkân yoqtır, çünki asıl ile yañı adları bir kele.',
@@ -1593,7 +1586,7 @@
 'show-big-image'       => 'Tam çezinirlik',
 'show-big-image-thumb' => '<small>Ög baquvda resim büyükligi: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Yañı resimler',
 'imagelisttext'         => "Aşağıdaki cedvelde $2 köre tizilgen {{PLURAL:$1|'''1''' fayldır|'''$1''' fayldır}}.",
 'showhidebots'          => '(botlarnı $1)',
@@ -1683,7 +1676,7 @@
 
 # External editor support
 'edit-externally'      => 'Fayl üzerinde kompyuteriñizde bulunğan programmalar ile deñişiklikler yapıñız',
-'edit-externally-help' => 'Daa fazla malümat içün [http://meta.wikimedia.org/wiki/Help:External_editors bu saifege] (İnglizce)  baqıp olasıñız.',
+'edit-externally-help' => 'Daa fazla malümat içün [http://www.mediawiki.org/wiki/Manual:External_editors bu saifege] (İnglizce)  baqıp olasıñız.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'episini',
@@ -1751,7 +1744,7 @@
 'recreate'            => 'Saifeni yañıdan yarat',
 
 # HTML dump
-'redirectingto' => 'Yollama [[$1]]...',
+'redirectingto' => 'Yollama [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Saife keşini temizlesinmi?
Index: languages/messages/MessagesCh.php
===================================================================
--- languages/messages/MessagesCh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,7 +6,6 @@
  *
  * @author Gadao01
  * @author Jatrobat
- * @author Siebrand
  * @author Magalahi
  */
 
@@ -445,10 +444,6 @@
 'blockededitsource'                => "Ma'a'annok gi papa' i tinige' '''tinilaika-mu''' gi '''$1''':",
 'whitelistedittitle'               => 'Nesesario malogin para tumulaika',
 'whitelistedittext'                => 'Un nesisita ma$1 para tumulaika påhina.',
-'whitelistreadtitle'               => 'Nesisario malogin para manaitai',
-'whitelistreadtext'                => 'Un nesisita [[Special:Userlogin|lumogin]] para manaitai.',
-'whitelistacctitle'                => "Ti masedi hao mama'tinas kuenta",
-'whitelistacctext'                 => "Ti masedi hao mama'tinas kuenta gi {{SITENAME}}, un nesita [[Special:Userlogin|lumogin]] yan un nesita i petmisu propiu siha.",
 'confirmedittitle'                 => 'Manesita i konfitmasion e-mail para tumulaika',
 'confirmedittext'                  => "Un nesisita un konfotme iyo-mu email åntes di tumulaika påhina.
 Pot fabot po'lo yan konfotme iyo-mu e-mail gi [[Special:Preferences|prifirensia muna'sesetbi]].",
@@ -466,7 +461,7 @@
 Anggen lachi finatto-mu mågi, yemme' i batunes '''back''' ni iyo-mu browser.",
 'anontalkpagetext'                 => "----''Este na påhinan kombetsasion muna'sesetbi taina'an ni ti ha fa'tinas kuenta-ña pat ti ha u'usa i kuenta. Entonses na in i'isa i numiron IP para in aidentifika gue'.
 Buente ha' na guåha unos kuantos na muna'sesetbi ni ma u'usa i enao na IP.
-An un muna'sesetbi taina'an hao ya manñiente hao na guåha na kommentu ti prisisu ni manadirihiyi hao, pot fabot [[Special:Userlogin|fa'tinas kuenta-mu pat log in]] para mansuhayi yinaoyao yan i otru na muna'sesetbi siha.''",
+An un muna'sesetbi taina'an hao ya manñiente hao na guåha na kommentu ti prisisu ni manadirihiyi hao, pot fabot [[Special:UserLogin|fa'tinas kuenta-mu pat log in]] para mansuhayi yinaoyao yan i otru na muna'sesetbi siha.''",
 'noarticletext'                    => "Tåya' tinige'-ña i påhina este, siña un [[Special:Search/{{PAGENAME}}|aligao i titulon påhina]] gi halom otru na påhina siha pat [{{fullurl:{{FULLPAGENAME}}|action=edit}} tulaika i påhina].",
 'userpage-userdoesnotexist'        => 'Ti marehistra i kuenata muna\'sesetbi "$1". Pot fabot chek kao malago\' hao un fa\'tinas/tulaika este na påhina.',
 'usercsspreview'                   => "'''Hasso fan na un ripapasa iyo-mu CSS muna'sesetbi, trabiha ti masåtba ha'!'''",
@@ -505,7 +500,7 @@
 'template-protected'               => '(maprotehi)',
 'hiddencategories'                 => "Miembron {{PLURAL:$1|1 manå'na' na kategoria|$1 na mannå'na' na kategoria}} este na påhina:",
 'nocreatetext'                     => "I nina'siña mama'tinas mannuebu na påhina machomma' gi {{SITENAME}}.
-Siña hao humanao tåtte ya tumulaika påhina ni guinaha, pat [[Special:Userlogin|log in pat un fa'tinas kuenta-mu]].",
+Siña hao humanao tåtte ya tumulaika påhina ni guinaha, pat [[Special:UserLogin|log in pat un fa'tinas kuenta-mu]].",
 'nocreate-loggedin'                => "Ti nahon i nibet-mu petmisu mama'tinas nuebu na påhina gi {{SITENAME}}.",
 'permissionserrors'                => 'Linache siha gi Petmisu',
 'permissionserrorstext'            => "Ti nahong nibet-mu petmisu chumo'gue enao, pot i sigiente {{PLURAL:$1|na rason|na rason siha}}:",
@@ -690,7 +685,7 @@
 'mypreferences'            => "I ga'ña-hu",
 'prefs-edits'              => 'Numirun tinilaika:',
 'prefsnologin'             => "Ti ma'log in",
-'prefsnologintext'         => "Un nesisita [[Special:Userlogin|muna'log in]] para un tulaika i ga'ña-mu muna'sesetbi.",
+'prefsnologintext'         => "Un nesisita [[Special:UserLogin|muna'log in]] para un tulaika i ga'ña-mu muna'sesetbi.",
 'prefsreset'               => "Manmamo'lo ta'lo i prifirensia siha ginen i dipusita.",
 'qbsettings-none'          => "Tåya'",
 'qbsettings-fixedleft'     => 'Maplanta gi akague',
@@ -787,7 +782,7 @@
 'uploadlogpage' => "Na'kåtga i log",
 'uploadedimage' => 'mana\'kåtga hulu\' "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Listan atkibu',
 
 # Image description page
@@ -887,7 +882,7 @@
 'all-logs-page'        => 'Todu i logs siha',
 'log-search-submit'    => 'Hånao',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Todu i påhina siha',
 'alphaindexline' => '$1 para $2',
 'nextpage'       => "Mamaila' na påhina ($1)",
@@ -912,7 +907,7 @@
 'watchlistfor'         => "(para '''$1''')",
 'addedwatch'           => "Mapo'lo gi listan pinilan",
 'addedwatchtext'       => "Mana'suha i påhina \"[[:\$1]]\" para iyo-mu [[Special:Watchlist|Listan pinilan]].
-I tinilaika siha mo'na gi tiempo kontodu i påhinan kombetsasion siha para u fana'lista guihi, yan para u '''na'potpot''' i påhina gi halom [[Special:Recentchanges|i listan tinilaika gi halacha]] para un ayek ha' mas libianu.",
+I tinilaika siha mo'na gi tiempo kontodu i påhinan kombetsasion siha para u fana'lista guihi, yan para u '''na'potpot''' i påhina gi halom [[Special:RecentChanges|i listan tinilaika gi halacha]] para un ayek ha' mas libianu.",
 'removedwatch'         => "Mana'suha gi listan pinilan",
 'removedwatchtext'     => 'Mana\'suha i påhina "[[:$1]]" gi listan pinilan-mu.',
 'watch'                => 'Pulan',
@@ -1104,7 +1099,7 @@
 'show-big-image'       => 'Magåhet mineddong-ña',
 'show-big-image-thumb' => '<small>Mineddong i ripasu: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Galarian atkibu mannuebu siha',
 'ilsubmit'  => 'Aligao',
 
@@ -1122,7 +1117,7 @@
 
 # External editor support
 'edit-externally'      => 'Tulaika i atkibu yan un aplikasion sanhiyong',
-'edit-externally-help' => 'Hånao para [http://meta.wikimedia.org/wiki/Help:External_editors i plantan chinachalani] para mas infotmasion.',
+'edit-externally-help' => 'Hånao para [http://www.mediawiki.org/wiki/Manual:External_editors i plantan chinachalani] para mas infotmasion.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'todu',
Index: languages/messages/MessagesBe_tarask.php
===================================================================
--- languages/messages/MessagesBe_tarask.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBe_tarask.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,10 @@
  * @ingroup Language
  * @file
  *
+ * @author Cesco
  * @author EugeneZelenko
+ * @author Jim-by
  * @author Red Winged Duck
- * @author Jim-by
- * @author Cesco
  */
 
 $skinNames = array(
@@ -518,7 +518,7 @@
 'nosuchspecialpage' => 'Такой спэцыяльнай старонкі не існуе',
 'nospecialpagetext' => "<big>'''Вы зьвярнуліся на няслушную спэцыяльную старонку.'''</big>
 
-Сьпіс дзейных спэцыяльных старонак ёсьць на [[Special:Specialpages|{{int:specialpages}}]].",
+Сьпіс дзейных спэцыяльных старонак ёсьць на [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Памылка',
@@ -549,7 +549,7 @@
 Звычайна гэта адбываецца ў выпадку пераходу па састарэлай розьніцы альбо спасылцы гісторыі старонкі, якая была выдаленая.
 
 Калі справа ня ў гэтым, верагодна Вы знайшлі памылку ў праграмным забесьпячэньні.
-Калі ласка, паведаміце пра гэта адміністратару, пазначыўшы URL.',
+Калі ласка, паведаміце пра гэта [[Special:ListUsers/sysop|адміністратару]], пазначыўшы URL.',
 'missingarticle-rev'   => '(вэрсія № $1)',
 'missingarticle-diff'  => '(Розьніца: $1, $2)',
 'readonly_lag'         => 'База зьвестак была аўтаматычна заблякаваная да выкананьня сынхранізацыі паміж першасным і другаснымі базамі зьвестак',
@@ -602,11 +602,11 @@
 'logouttitle'                => 'Выхад з сыстэмы',
 'logouttext'                 => '<strong>Вы выйшлі з сыстэмы.</strong>
 
-Вы можаце працягваць працу ў {{GRAMMAR:месны|{{SITENAME}}}} ананімна, альбо можаце ўвайсьці ў сыстэму як той жа альбо іншы ўдзельнік.
+Вы можаце працягваць працу ў {{GRAMMAR:месны|{{SITENAME}}}} ананімна, альбо можаце [[Special:UserLogin|ўвайсьці ў сыстэму]] як той жа альбо іншы ўдзельнік.
 Але некаторыя старонкі могуць адлюстроўвацца як быццам Вы ўсё яшчэ ў сыстэме. Каб гэтага пазьбегнуць трэба ачысьціць кэш браўзэра.',
 'welcomecreation'            => '== Вітаем, $1! ==
 Ваш рахунак быў створаны.
-Не забудзьце зьмяніць Вашыя ўстаноўкі ў {{GRAMMAR:месны|{{SITENAME}}}}.',
+Не забудзьце зьмяніць Вашыя [[Special:Preferences|ўстаноўкі ў {{GRAMMAR:месны|{{SITENAME}}}}]].',
 'loginpagetitle'             => 'Уваход у сыстэму',
 'yourname'                   => 'Імя ўдзельніка/ўдзельніцы:',
 'yourpassword'               => 'Пароль:',
@@ -750,33 +750,38 @@
 'summary-preview'                  => 'Папярэдні прагляд апісаньня',
 'subject-preview'                  => 'Папярэдні прагляд загалоўку',
 'blockedtitle'                     => 'Удзельнік заблякаваны',
-'blockedtext'                      => "<big>'''Ваш рахунак ўдзельніка ці IP-адрас быў заблякаваны $1.'''</big>
+'blockedtext'                      => "<big>'''Ваш рахунак ўдзельніка ці IP-адрас быў заблякаваны.'''</big>
 
+Блякаваньне выканаў $1.
 Прычына гэтага: ''$2''.
 
-Блякіроўка пачалася $8 і дзейнічае да $6 і выкарыстоўваецца супраць дзеяньняў $7.
+* Пачатак блякаваньня: $8
+* Сканчэньне блякаваньня: $6
+* Быў заблякаваны: $7
 
-Вы можаце скантактавацца з $1 ці адным зь іншых [[{{MediaWiki:Grouppage-sysop}}|адміністратараў]], каб абмеркаваць блякаваньне. Заўважце, што Вы ня зможаце ўжыць мажлівасьць «даслаць ліст па электроннай пошце», пакуль не пазначыце сапраўдны адрас электроннай пошты ў Вашых [[Special:Preferences|устаноўках]], што Вам не забаронена. Ваш IP-адрас — $3, ідэнтыфікатар блякіроўкі — #$5. Калі ласка, улучайце гэтую інфармацыю ва ўсе запыты, што Вы будзеце рабіць.",
+Вы можаце скантактавацца з $1 ці адным зь іншых [[{{MediaWiki:Grouppage-sysop}}|адміністратараў]], каб абмеркаваць блякаваньне. Заўважце, што Вы ня зможаце ўжыць мажлівасьць «даслаць ліст па электроннай пошце», пакуль не пазначыце сапраўдны адрас электроннай пошты ў Вашых [[Special:Preferences|устаноўках]], і калі гэта Вам не было забаронена.
+Ваш IP-адрас — $3, ідэнтыфікатар блякаваньня — #$5.
+Калі ласка, улучайце ўсю вышэйпададзеную інфармацыю ва ўсе запыты, што Вы будзеце рабіць.",
 'autoblockedtext'                  => "Ваш IP-адрас быў аўтаматычна заблякаваны, таму што ён ужываўся іншым удзельнікам, які быў заблякаваны $1.
+Прычына гэтага:
 
-Прычына гэтага: ''$2''.
+:''$2''
 
-Блякіроўка пачалася $8 і дзейнічае да $6.
+* Блякаваньне пачалося: $8
+* Блякаваньне скончыцца: $6
+* Быў заблякаваны: $7
 
 Вы можаце скантактавацца з $1 ці з адным зь іншых [[{{MediaWiki:Grouppage-sysop}}|адміністратараў]], каб абмеркаваць блякаваньне.
 
-Заўважце, што Вы ня зможаце ужываць мажлівасьць «даслаць ліст праз электронную пошту», пакуль ня будзе пазначаны дзейны адрас электроннай пошты ў вашых [[Special:Preferences|устаноўках удзельніка]], што Вам не забаронена.
+Заўважце, што Вы ня зможаце ужываць мажлівасьць «даслаць ліст праз электронную пошту», пакуль ня будзе пазначаны дзейны адрас электроннай пошты ў Вашых [[Special:Preferences|устаноўках удзельніка]], і калі гэта Вам не было забаронена.
 
-ID вашага блякаваньня — #$5. Калі ласка, улучайце гэты ID ва ўсе запыты, якія Вы робіце.",
+Ваш цяперашні IP-адрас — $3, ідэнтыфікатар блякаваньня — #$5.
+Калі ласка, улучайце ўсю вышэйпададзеную інфармацыю ва ўсе запыты, што Вы будзеце рабіць.",
 'blockednoreason'                  => 'прычына не пададзена',
 'blockedoriginalsource'            => "Крыніца '''$1''' паказана ніжэй:",
 'blockededitsource'                => "Тэкст '''Вашых зьменаў''' у '''$1''' паказаны ніжэй:",
 'whitelistedittitle'               => 'Для рэдагаваньня патрабуецца ўваход у сыстэму',
 'whitelistedittext'                => 'Вам трэба $1, каб рэдагаваць старонкі.',
-'whitelistreadtitle'               => 'Для прагляду патрабуецца ўваход у сыстэму',
-'whitelistreadtext'                => 'Вы павінны [[Special:Userlogin|ўвайсьці ў сыстэму]] для прагляду старонак.',
-'whitelistacctitle'                => 'Вам не дазволена ствараць рахунак',
-'whitelistacctext'                 => 'Для стварэньня рахунку ў {{GRAMMAR:месны|{{SITENAME}}}} Вам трэба [[Special:Userlogin|зарэгістравацца]] і мець адпаведныя правы.',
 'confirmedittitle'                 => 'Для рэдагаваньня патрэбнае пацьверджаньне адрасу электроннай пошты',
 'confirmedittext'                  => 'Вы мусіце пацьвердзіць Ваш адрас электроннай пошты перад рэдагаваньнем старонак. Калі ласка, пазначце і пацьвердзіце адрас электроннай пошты праз Вашы [[Special:Preferences|ўстаноўкі]].',
 'nosuchsectiontitle'               => 'Такой сэкцыі не існуе',
@@ -791,9 +796,9 @@
 'newarticletext'                   => "Вы прыйшлі па спасылцы на старонку, якая яшчэ не існуе.
 Каб стварыць яе, напішыце тэкст у полі ніжэй (глядзіце [[{{MediaWiki:Helppage}}|старонку дапамогі]] дзеля дадатковай інфармацыі).
 Калі Вы трапілі сюды памылкова, націсьніце '''назад''' у вашым браўзэры.",
-'anontalkpagetext'                 => "----''Гэта старонка гутарак ананімнага ўдзельніка, які яшчэ не стварыў сабе рахунак ці не ўжывае яго. Таму мы вымушаныя ўжываць лічбавы IP-адрас дзеля ягонай ідэнтыфікацыі. Адзін IP-адрас можа выкарыстоўвацца некалькімі ўдзельнікамі. Калі Вы — ананімны ўдзельнік і лічыце, што атрымалі не прызначаныя Вам камэнтары, калі ласка, [[Special:Userlogin|зарэгіструйцеся ці ўвайдзіце ў сыстэму]], каб у будучыні пазьбегнуць магчымай блытаніны зь іншымі ананімнымі ўдзельнікамі.''
+'anontalkpagetext'                 => "----''Гэта старонка гутарак ананімнага ўдзельніка, які яшчэ не стварыў сабе рахунак ці не ўжывае яго. Таму мы вымушаныя ўжываць лічбавы IP-адрас дзеля ягонай ідэнтыфікацыі. Адзін IP-адрас можа выкарыстоўвацца некалькімі ўдзельнікамі. Калі Вы — ананімны ўдзельнік і лічыце, што атрымалі не прызначаныя Вам камэнтары, калі ласка, [[Special:UserLogin|зарэгіструйцеся ці ўвайдзіце ў сыстэму]], каб у будучыні пазьбегнуць магчымай блытаніны зь іншымі ананімнымі ўдзельнікамі.''
 
-''This is the discussion page for an anonymous user who has not created an account yet or who does not use it. We therefore have to use the numerical IP address to identify him/her. Such an IP address can be shared by several users. If you are an anonymous user and feel that irrelevant comments have been directed at you, please [[Special:Userlogin|create an account or log in]] to avoid future confusion with other anonymous users.''",
+''This is the discussion page for an anonymous user who has not created an account yet or who does not use it. We therefore have to use the numerical IP address to identify him/her. Such an IP address can be shared by several users. If you are an anonymous user and feel that irrelevant comments have been directed at you, please [[Special:UserLogin|create an account or log in]] to avoid future confusion with other anonymous users.''",
 'noarticletext'                    => 'Зараз тэкст на гэтай старонцы адсутнічае. Вы можаце [[Special:Search/{{PAGENAME}}|пашукаць гэтую назву]] ў іншых старонках альбо [{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} рэдагаваць гэтую старонку].',
 'userpage-userdoesnotexist'        => 'Рахунак удзельніка «$1» не зарэгістраваны. Калі ласка, удакладніце, ці жадаеце Вы стварыць/рэдагаваць гэтую старонку.',
 'clearyourcache'                   => "'''Заўвага:''' Каб пабачыць зьмены пасьля захаваньня, Вам можа спатрэбіцца ацысьціць кэш Вашага браўзэра. '''Mozilla / Firefox / Safari:''' трымайце ''Shift'' і націсьніце ''Reload'', ці націсьніце ''Ctrl-Shift-R'' (''Cmd-Shift-R'' на Apple Mac); '''IE:''' трымайце ''Ctrl'' і націсьніце ''Refresh'', ці націсьніце ''Ctrl-F5''; '''Konqueror:''': проста націсьніце кнопку ''Reload'', ці націсьніце ''F5''; карыстальнікам '''Opera''' можа спатрэбіцца цалкам ачысьціць кэш праз ''Tools→Preferences''.",
@@ -807,12 +812,12 @@
 'previewnote'                      => '<strong>Гэта толькі папярэдні прагляд і зьмены яшчэ не былі захаваныя!</strong>',
 'previewconflict'                  => 'Гэта папярэдні прагляд тэксту зь верхняга вакна рэдагаваньня, так ён будзе выглядаць, калі Вы вырашыце яго захаваць.',
 'session_fail_preview'             => '<strong>Выбачайце! Не атрымалася захаваць Вашую праўку праз тое, што былі страчаныя зьвесткі пра сэсію.
-Калі ласка, паспрабуйце яшчэ раз. Калі памылка ня зьнікне, паспрабуйце выйсьці з сыстэмы і ўвайсьці ізноў.</strong>',
+Калі ласка, паспрабуйце яшчэ раз. Калі памылка ня зьнікне, паспрабуйце [[Special:UserLogout|выйсьці з сыстэмы]] і ўвайсьці ізноў.</strong>',
 'session_fail_preview_html'        => "<strong>Выбачайце! Не атрымалася захаваць Вашую праўку праз тое, што былі страчаныя зьвесткі пра сэсію.</strong>
 
 ''Таму што ў {{GRAMMAR:месны|{{SITENAME}}}} дазволена выкарыстоўваць чысты HTML, папярэдні прагляд быў адключаны для засьцярогі ад атакаў праз JavaScript.''
 
-<strong>Калі гэта сапраўдная спроба рэдагаваньня, калі ласка, паспрабуйце яшчэ раз. Калі гэта не дапамагае, паспрабуйце выйсьці з сыстэмы і ўвайсьці ізноў.</strong>",
+<strong>Калі гэта сапраўдная спроба рэдагаваньня, калі ласка, паспрабуйце яшчэ раз. Калі гэта не дапамагае, паспрабуйце [[Special:UserLogout|выйсьці з сыстэмы]] і ўвайсьці ізноў.</strong>",
 'token_suffix_mismatch'            => '<strong>Вашае рэдагаваньне было адхіленае, таму што Ваш кліент ня можа апрацоўваць знакі пунктуацыі ў акне рэдагаваньня.
 Рэдагаваньне было скасаванае для таго, каб пазьбегнуць зьнішчэньня тэксту старонкі.
 Такія памылкі здараюцца, калі Вы выкарыстоўваеце ананімны проксі-сэрвэр, які ўтрымлівае памылкі.</strong>',
@@ -840,7 +845,7 @@
 Разьмяшчэньнем тут тэкстаў, Вы дэкляруеце, што Вы зьяўляецеся іх аўтарам, ці Вы скапіявалі іх з крыніцы, якая дазваляе вольнае выкарыстаньне сваіх тэкстаў (дзеля падрабязнасьцяў глядзіце $1).
 
 <strong>КАЛІ ЛАСКА, НЕ ЗЬМЯШЧАЙЦЕ ТУТ БЕЗ ДАЗВОЛУ МАТЭРЫЯЛЫ, ЯКІЯ АХОЎВАЮЦЦА АЎТАРСКІМ ПРАВАМ!</strong>',
-'longpagewarning'                  => "<strong>ПАПЯРЭДЖАНЬНЕ: Гэтая старонка утрымлівае $1 {{PLURAL:$1|кілябайт|кілябайты|кілябайтаў}}; некаторыя браўзэры могуць мець праблемы пры адлюстраваньні старонак аб'ёмам болей 32кб.
+'longpagewarning'                  => "<strong>ПАПЯРЭДЖАНЬНЕ: Гэтая старонка ўтрымлівае $1 {{PLURAL:$1|кілябайт|кілябайты|кілябайтаў}}; некаторыя браўзэры могуць мець праблемы пры адлюстраваньні старонак аб'ёмам болей за 32кб.
 Калі гэта магчыма, паспрабуйце падзяліць зьмест старонкі на больш дробныя часткі.</strong>",
 'longpageerror'                    => "<strong>ПАМЫЛКА: Аб'ём тэксту, які Вы спрабуеце запісаць складае $1 {{PLURAL:$1|кілябайт|кілябайты|кілябайтаў}}. Аб'ём старонкі ня можа перавышаць $2 {{PLURAL:$2|кілябайт|кілябайты|кілябайтаў}}. Старонка ня можа быць захаваная.</strong>",
 'readonlywarning'                  => '<strong>ПАПЯРЭДЖАНЬНЕ: База зьвестак была заблякаваная для тэхнічнага абслугоўваньня, таму немагчыма зараз захаваць Вашыя зьмены.
@@ -858,7 +863,7 @@
 'hiddencategories'                 => 'Гэтая старонка належыць $1 {{PLURAL:$1|схаванай катэгорыі|схаваным катэгорыям|схаваным катэгорыям}}:',
 'nocreatetitle'                    => 'Стварэньне старонак абмежаванае',
 'nocreatetext'                     => 'У {{GRAMMAR:месны|{{SITENAME}}}} абмежаванае стварэньне новых старонак.
-Вы можаце вярнуцца і рэдагаваць існуючую старонку, альбо [[Special:Userlogin|ўвайсьці ў сыстэму ці стварыць рахунак]].',
+Вы можаце вярнуцца і рэдагаваць існуючую старонку, альбо [[Special:UserLogin|ўвайсьці ў сыстэму ці стварыць рахунак]].',
 'nocreate-loggedin'                => 'Вы ня маеце дазволу ствараць новыя старонкі ў {{GRAMMAR:месны|{{SITENAME}}}}.',
 'permissionserrors'                => 'Памылкі дазволаў',
 'permissionserrorstext'            => 'Вы ня маеце дазволу на гэтае дзеяньне па {{PLURAL:$1|наступнай прычыне|наступных прычынах}}:',
@@ -975,7 +980,7 @@
 # Suppression log
 'suppressionlog'     => 'Журнал схаваньняў',
 'suppressionlogtext' => 'Ніжэй знаходзіцца сьпіс выдаленьняў і блякаваньняў, схаваных нават ад адміністратараў.
-Глядзіце [[Special:Ipblocklist|сьпіс блякаваньняў IP]], каб паглядзець сьпіс цяперашніх блякаваньняў.',
+Глядзіце [[Special:IPBlockList|сьпіс блякаваньняў IP]], каб паглядзець сьпіс цяперашніх блякаваньняў.',
 
 # History merging
 'mergehistory'                     => "Аб'яднаць гісторыі старонак",
@@ -1017,7 +1022,7 @@
 # Search results
 'searchresults'             => 'Вынікі пошуку',
 'searchresulttext'          => 'Для атрыманьня больш падрабязнай інфармацыі пра пошук у {{GRAMMAR:месны|{{SITENAME}}}}, глядзіце [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "Па запыце '''[[:$1]]'''",
+'searchsubtitle'            => "Па запыце '''[[:$1]]''' ([[Special:Prefixindex/$1|усе старонкі, якія пачынаюцца з «$1»]] | [[Special:WhatLinksHere/$1|усе старонкі, якія спасылаюцца на «$1»]])",
 'searchsubtitleinvalid'     => "Па запыце '''$1'''",
 'noexactmatch'              => "'''Старонкі з гэткай назвай не існуе.''' Вы можаце '''[[:$1|стварыць гэтую старонку]]'''.",
 'noexactmatch-nocreate'     => "'''Не існуе старонкі з назвай «$1».'''",
@@ -1061,7 +1066,7 @@
 'mypreferences'            => 'Мае ўстаноўкі',
 'prefs-edits'              => 'Колькасьць рэдагаваньняў:',
 'prefsnologin'             => 'Вы не ўвайшлі ў сыстэму',
-'prefsnologintext'         => 'Вам трэба [[Special:Userlogin|ўвайсьці ў сыстэму]], каб зьмяняць свае ўстаноўкі.',
+'prefsnologintext'         => 'Вам трэба [[Special:UserLogin|ўвайсьці ў сыстэму]], каб зьмяняць свае ўстаноўкі.',
 'prefsreset'               => 'Адноўленыя ўстаноўкі па змоўчаньні.',
 'qbsettings'               => 'Панэль хуткага доступу',
 'qbsettings-none'          => 'Не паказваць',
@@ -1137,7 +1142,7 @@
 'userrights-reason'           => 'Прычына зьмены:',
 'userrights-no-interwiki'     => 'Вы ня маеце дазволу зьмяняць правы ўдзельнікаў іншых вікаў.',
 'userrights-nodatabase'       => 'Базы зьвестак $1 не існуе альбо яна не зьяўляецца лякальнай.',
-'userrights-nologin'          => 'Вы павінны [[Special:Userlogin|ўвайсьці ў сыстэму]] як адміністратар, каб прызначаць правы ўдзельнікам.',
+'userrights-nologin'          => 'Вы павінны [[Special:UserLogin|ўвайсьці ў сыстэму]] як адміністратар, каб прызначаць правы ўдзельнікам.',
 'userrights-notallowed'       => 'Вы ня можаце прызначаць правы ўдзельнікам.',
 'userrights-changeable-col'   => 'Групы, якія Вы можаце мяняць',
 'userrights-unchangeable-col' => 'Групы, якія Вы ня можаце мяняць',
@@ -1152,12 +1157,12 @@
 'group-suppress'      => 'Рэвізоры',
 'group-all'           => '(усе)',
 
-'group-user-member'          => 'Удзельнік',
-'group-autoconfirmed-member' => 'Аўтаматычна пацьверджаны ўдзельнік',
-'group-bot-member'           => 'Робат',
-'group-sysop-member'         => 'Адміністратар/Адміністратарка',
-'group-bureaucrat-member'    => 'Бюракрат',
-'group-suppress-member'      => 'Рэвізор',
+'group-user-member'          => 'удзельнік',
+'group-autoconfirmed-member' => 'аўтаматычна пацьверджаны ўдзельнік',
+'group-bot-member'           => 'робат',
+'group-sysop-member'         => 'адміністратар',
+'group-bureaucrat-member'    => 'бюракрат',
+'group-suppress-member'      => 'рэвізор',
 
 'grouppage-user'          => '{{ns:project}}:Удзельнікі',
 'grouppage-autoconfirmed' => '{{ns:project}}:Аўтаматычна пацьверджаныя ўдзельнікі',
@@ -1185,7 +1190,7 @@
 'right-autoconfirmed'        => 'рэдагаваньне часткова абароненых старонак',
 'right-bot'                  => 'лічыцца аўтаматычным працэсам',
 'right-nominornewtalk'       => 'не паведамляць удзельнікам пра новыя паведамленьні на іх старонках размоваў, калі зробленыя там праўкі былі дробнымі',
-'right-apihighlimits'        => 'менш абмежаваньняў на выкананьне API-запытаў',
+'right-apihighlimits'        => 'Менш абмежаваньняў на выкананьне API-запытаў',
 'right-writeapi'             => 'выкарыстаньне API для запісаў',
 'right-delete'               => 'выдаленьне старонак',
 'right-bigdelete'            => 'Выдаленьне старонак зь вялікімі гісторыямі',
@@ -1267,17 +1272,17 @@
 'reupload'                    => 'Загрузіць зноў',
 'reuploaddesc'                => 'Адмяніць загрузку і вярнуцца да формы загрузкі',
 'uploadnologin'               => 'Вы не ўвайшлі ў сыстэму',
-'uploadnologintext'           => 'Вам трэба [[Special:Userlogin|ўвайсьці ў сыстэму]] для загрузкі файлаў.',
+'uploadnologintext'           => 'Вам трэба [[Special:UserLogin|ўвайсьці ў сыстэму]] для загрузкі файлаў.',
 'upload_directory_missing'    => 'Загрузачная дырэкторыя ($1) адсутнічае і ня можа быць створаная сэрвэрам.',
 'upload_directory_read_only'  => 'Сэрвэр ня мае правоў на запіс у дырэкторыю загружаных файлаў ($1).',
 'uploaderror'                 => 'Памылка загрузкі',
 'uploadtext'                  => "Ужывайце форму ніжэй для загрузкі файлаў.
-Каб паглядзець ці адшукаць раней загружаныя файлы, глядзіце [[Special:Imagelist|сьпіс загружаных файлаў]], загрузкі і выдаленьні таксама запісваюцца ў [[Special:Log/upload|журнал загрузак]].
+Каб паглядзець ці адшукаць раней загружаныя файлы, глядзіце [[Special:ImageList|сьпіс загружаных файлаў]], загрузкі таксама запісваюцца ў [[Special:Log/upload|журнал загрузак]], а выдаленьні — у [[Special:Log/delete|журнал выдаленьняў]].
 
-Каб улучыць файл у старонку, ужывайце спасылку ў выглядзе
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|Подпіс да выявы]]</nowiki>''' альбо
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' дзеля простай спасылкі на файл.",
+Каб улучыць файл у старонку, ужывайце адзін з наступных варыянтаў:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' для поўнай вэрсіі файла
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|Подпіс да выявы]]</nowiki></tt>''' для выявы шырынёй 200 піксэляў у рамцы і тэкстам «Подпіс да выявы» ў якасьці подпісу
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' для простай спасылкі на файл безь яго адлюстраваньня.",
 'upload-permitted'            => 'Дазволеныя тыпы файлаў: $1.',
 'upload-preferred'            => 'Пажаданыя тыпы файлаў: $1.',
 'upload-prohibited'           => 'Забароненыя тыпы файлаў: $1.',
@@ -1352,11 +1357,11 @@
 'upload-proto-error-text' => 'Аддаленая загрузка файлаў патрабуе URL-адрас, які пачынаецца з <code>http://</code> альбо <code>ftp://</code>.',
 'upload-file-error'       => 'Унутраная памылка',
 'upload-file-error-text'  => 'Адбылася ўнутраная памылка пад час спробы стварыць часовы файл на сэрвэры.
-Калі ласка, зьвярніцеся да сыстэмнага адміністратара.',
+Калі ласка, зьвярніцеся да [[Special:ListUsers/sysop|сыстэмнага адміністратара]].',
 'upload-misc-error'       => 'Невядомая памылка загрузкі',
 'upload-misc-error-text'  => 'Адбылася невядомая памылка пад час загрузкі.
 Калі ласка, ўпэўніцеся, што URL-адрас слушны, і паспрабуйце ізноў.
-Калі памылка паўтарыцца, зьвярніцеся да сыстэмнага адміністратара.',
+Калі памылка паўтарыцца, зьвярніцеся да [[Special:ListUsers/sysop|сыстэмнага адміністратара]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Немагчыма дасягнуць URL-адрас',
@@ -1373,7 +1378,7 @@
 'upload_source_url'  => ' (слушны, агульнадаступны URL-адрас)',
 'upload_source_file' => ' (файл на Вашым кампутары)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'На гэтай спэцыяльнай старонцы паказаныя ўсе загружаныя файлы.
 Па змоўчваньні апошнія загружаныя файлы адлюстраваныя зьверху сьпісу.
 Націсьніце на назву слупка, каб зьмяніць парадак сартаваньня.',
@@ -1401,7 +1406,7 @@
 'imagelinks'                     => 'Спасылкі',
 'linkstoimage'                   => '{{PLURAL:$1|Наступная старонка спасылаецца|Наступныя старонкі спасылаюцца}} на гэты файл:',
 'nolinkstoimage'                 => 'Ніводная старонка не спасылаецца на гэты файл.',
-'morelinkstoimage'               => 'Паказаць [[Special:Whatlinkshere/$1|болей спасылак]] на гэты файл.',
+'morelinkstoimage'               => 'Паказаць [[Special:WhatLinksHere/$1|болей спасылак]] на гэты файл.',
 'redirectstofile'                => '{{PLURAL:$1|Наступны файл перанакіроўвае|Наступныя файлы перанакіроўваюць}} на гэты файл:',
 'duplicatesoffile'               => '{{PLURAL:$1|Наступны файл дублюе|Наступныя файлы дублююць}} гэты файл:',
 'sharedupload'                   => 'Гэты файл зьяўляецца агульным і можа выкарыстоўвацца іншымі праектамі.',
@@ -1420,18 +1425,18 @@
 # File reversion
 'filerevert'                => 'Вярнуць $1',
 'filerevert-legend'         => 'Вярнуць папярэднюю вэрсію файла',
-'filerevert-intro'          => '<span class="plainlinks">Вы вяртаеце \'\'\'[[Media:$1|$1]]\'\'\' да [вэрсіі $4 ад $3, $2].</span>',
+'filerevert-intro'          => "Вы вяртаеце '''[[Media:$1|$1]]''' да [вэрсіі $4 ад $3, $2].",
 'filerevert-comment'        => 'Камэнтар:',
 'filerevert-defaultcomment' => 'Вернутая вэрсія ад $2, $1',
 'filerevert-submit'         => 'Вярнуць',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' быў вернуты да [вэрсіі $4 ад $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' быў вернуты да [вэрсіі $4 ад $3, $2].",
 'filerevert-badversion'     => 'Не існуе папярэдняй лякальнай вэрсіі гэтага файла з пазначанай датай.',
 
 # File deletion
 'filedelete'                  => 'Выдаліць $1',
 'filedelete-legend'           => 'Выдаліць файл',
 'filedelete-intro'            => "Вы выдаляеце '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Вы выдаляеце вэрсію \'\'\'[[Media:$1|$1]]\'\'\' ад [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Вы выдаляеце вэрсію '''[[Media:$1|$1]]''' ад [$4 $3, $2].",
 'filedelete-comment'          => 'Прычына выдаленьня:',
 'filedelete-submit'           => 'Выдаліць',
 'filedelete-success'          => "'''$1''' выдалены.",
@@ -1488,7 +1493,7 @@
 Такім чынам, у сярэднім прыходзіцца '''$5''' рэдагаваньне на адну старонку, і '''$6''' праглядаў на адно рэдагаваньне.
 
 Даўжыня [http://www.mediawiki.org/wiki/Manual:Job_queue чаргі заданьняў] складае '''$7'''.",
-'userstatstext'          => "Тут {{PLURAL:$1|зарэгістраваны|зарэгістраваныя|зарэгістраваныя}} '''$1''' [[Special:Listusers|{{PLURAL:$1|удзельнік|удзельнікі|удзельнікаў}}]], зь якіх '''$2''' (ці '''$4%''') {{PLURAL:$2|мае|маюць|маюць}} правы $5.",
+'userstatstext'          => "Тут {{PLURAL:$1|зарэгістраваны|зарэгістраваныя|зарэгістраваныя}} '''$1''' [[Special:ListUsers|{{PLURAL:$1|удзельнік|удзельнікі|удзельнікаў}}]], зь якіх '''$2''' (ці '''$4%''') {{PLURAL:$2|мае|маюць|маюць}} правы $5.",
 'statistics-mostpopular' => 'Найпапулярнейшыя старонкі',
 
 'disambiguations'      => 'Старонкі-неадназначнасьці',
@@ -1497,8 +1502,10 @@
 Замест гэтага, яны павінны спасылацца на пэўныя старонкі.<br />
 Старонка лічыцца шматзначнай, калі яна ўтрымлівае шаблён назва якога знаходзіцца на старонцы [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Двайныя перанакіраваньні',
-'doubleredirectstext' => 'На гэтай старонцы знаходзіцца сьпіс перанакіраваньняў на іншыя перанакіраваньні. Кожны радок утрымлівае спасылкі на першае і другое перанакіраваньне, а таксама першы радок старонкі другога перанакіраваньня, у якім звычайна знаходзіцца назва старонкі, куды павіннае спасылацца першае перанакіраваньне.',
+'doubleredirects'            => 'Двайныя перанакіраваньні',
+'doubleredirectstext'        => 'На гэтай старонцы знаходзіцца сьпіс перанакіраваньняў на іншыя перанакіраваньні. Кожны радок утрымлівае спасылкі на першае і другое перанакіраваньне, а таксама першы радок старонкі другога перанакіраваньня, у якім звычайна знаходзіцца назва старонкі, куды павіннае спасылацца першае перанакіраваньне.',
+'double-redirect-fixed-move' => '[[$1]] была перанесеная, яна цяпер перанакіроўвае на [[$2]]',
+'double-redirect-fixer'      => 'Выпраўленьне перанакіраваньняў',
 
 'brokenredirects'        => 'Некарэктныя перанакіраваньні',
 'brokenredirectstext'    => 'Наступныя перанакіраваньні спасылаюцца на неіснуючыя старонкі:',
@@ -1584,7 +1591,7 @@
 'logempty'             => 'Падобных запісаў у журнале няма.',
 'log-title-wildcard'   => 'Шукаць назвы, якія пачынаюцца з гэтага тэксту',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Усе старонкі',
 'alphaindexline'    => 'ад $1 да $2',
 'nextpage'          => 'Наступная старонка ($1)',
@@ -1607,15 +1614,15 @@
 'special-categories-sort-count' => 'сартаваць паводле колькасьці',
 'special-categories-sort-abc'   => 'сартаваць паводле альфабэту',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Паказаць удзельнікаў, пачынаючы з:',
 'listusers-submit'   => 'Паказаць',
 'listusers-noresult' => 'Удзельнікі ня знойдзеныя.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Правы групаў удзельнікаў',
 'listgrouprights-summary'  => 'Ніжэй пададзены сьпіс групаў удзельнікаў {{GRAMMAR:родны|{{SITENAME}}}}, разам зь іх правамі.
-Дадатковую інфармацыю пра асабістыя правы можна знайсьці [[{{MediaWiki:Listgrouprights-helppage}}|тут]].',
+Таксама можна паглядзець [[{{MediaWiki:Listgrouprights-helppage}}|дадатковую інфармацыю]] пра асабістыя правы.',
 'listgrouprights-group'    => 'Група',
 'listgrouprights-rights'   => 'Правы',
 'listgrouprights-helppage' => 'Help:Правы групаў удзельнікаў',
@@ -1623,11 +1630,11 @@
 
 # E-mail user
 'mailnologin'     => 'Няма адрасу атрымальніка',
-'mailnologintext' => 'Вам неабходна [[Special:Userlogin|ўвайсьці ў сыстэму]] і мець пацьверджаны адрас электроннай пошты ў Вашых [[Special:Preferences|устаноўках]], каб дасылаць лісты іншым удзельнікам.',
+'mailnologintext' => 'Вам неабходна [[Special:UserLogin|ўвайсьці ў сыстэму]] і мець пацьверджаны адрас электроннай пошты ў Вашых [[Special:Preferences|устаноўках]], каб дасылаць лісты іншым удзельнікам.',
 'emailuser'       => 'Даслаць ліст',
 'emailpage'       => 'Даслаць ліст ўдзельніку ці ўдзельніцы па электроннай пошце',
 'emailpagetext'   => 'Калі гэты ўдзельнік пазначыў слушны адрас электроннай пошты ў сваіх устаноўках, то з дапамогай формы ніжэй можна даслаць яму ліст.
-Адрас электроннай пошты, які Вы пазначалі ў сваіх устаноўках, будзе пазначаны ў полі ліста «Ад», і ўдзельнік зможа даслаць на гэты адрас адказ.',
+Адрас электроннай пошты, які Вы пазначалі ў [[Special:Preferences|сваіх устаноўках]], будзе пазначаны ў полі ліста «Ад», і ўдзельнік зможа даслаць на гэты адрас адказ.',
 'usermailererror' => 'Пры адсыланьні пошты адбылася памылка:',
 'defemailsubject' => 'Электронная пошта {{GRAMMAR:родны|{{SITENAME}}}}',
 'noemailtitle'    => 'Адрас электроннай пошты адсутнічае',
@@ -1650,10 +1657,10 @@
 'nowatchlist'          => 'Ваш сьпіс назіраньня — пусты.',
 'watchlistanontext'    => 'Калі ласка, $1, каб праглядаць альбо рэдагаваць сьпіс назіраньня.',
 'watchnologin'         => 'Вы не ўвайшлі ў сыстэму',
-'watchnologintext'     => 'Вам неабходна [[Special:Userlogin|ўвайсьці ў сыстэму]], каб зьмяніць Ваш сьпіс назіраньня.',
+'watchnologintext'     => 'Вам неабходна [[Special:UserLogin|ўвайсьці ў сыстэму]], каб зьмяніць Ваш сьпіс назіраньня.',
 'addedwatch'           => 'Дададзеная ў сьпіс назіраньня',
 'addedwatchtext'       => "Артыкул «$1» быў дададзены да Вашага [[Special:Watchlist|сьпісу назіраньня]].
-Наступныя зьмены ў гэтым артыкуле і зьвязанай зь ім старонцы абмеркаваньняў будуць бачныя там, і старонка будзе выглядаць '''тлустай''' на [[Special:Recentchanges|старонцы са сьпісам апошніх зьменаў]], каб зьмены было лягчэй заўважыць.
+Наступныя зьмены ў гэтым артыкуле і зьвязанай зь ім старонцы абмеркаваньняў будуць бачныя там, і старонка будзе выглядаць '''тлустай''' на [[Special:RecentChanges|старонцы са сьпісам апошніх зьменаў]], каб зьмены было лягчэй заўважыць.
 
 Калі Вы захочаце выдаліць артыкул са сьпісу назіраньня, націсьніце «не назіраць» у спэцыяльным радку зьверху артыкула.",
 'removedwatch'         => 'Выдаленая са сьпісу назіраньня',
@@ -1731,7 +1738,7 @@
 'delete-legend'               => 'Выдаліць',
 'historywarning'              => 'Папярэджаньне: у старонкі, якую Вы зьбіраецеся выдаліць, ёсьць гісторыя:',
 'confirmdeletetext'           => 'Зараз Вы выдаліце старонку разам з усёй гісторыяй зьменаў.
-Калі ласка, пацьвердзіце, што Вы зьбіраецеся гэта зрабіць і што Вы разумееце ўсе наступствы, а таксама робіце гэта ў адпаведнасьці з [[{{MediaWiki:policy-url}}|правіламі]].',
+Калі ласка, пацьвердзіце, што Вы зьбіраецеся гэта зрабіць і што Вы разумееце ўсе наступствы, а таксама робіце гэта ў адпаведнасьці з [[{{MediaWiki:Policy-url}}|правіламі]].',
 'actioncomplete'              => 'Дзеяньне завершанае',
 'deletedtext'                 => '«<nowiki>$1</nowiki>» была выдаленая.
 Глядзіце журнал выдаленьняў у $2.',
@@ -1770,7 +1777,7 @@
 Калі ласка, націсьніце «назад» і перазагрузіце старонку зь якой Вы прыйшлі і паспрабуйце ізноў.',
 'protectlogpage'              => 'Журнал абаронаў',
 'protectlogtext'              => 'Ніжэй знаходзіцца сьпіс абаронаў і зьняцьцяў абаронаў.
-Глядзіце [[Special:Protectedpages|сьпіс абароненых старонак на цяперашні момант]].',
+Глядзіце [[Special:ProtectedPages|сьпіс абароненых старонак на цяперашні момант]].',
 'protectedarticle'            => 'абароненая «[[$1]]»',
 'modifiedarticleprotection'   => 'зьменены ўзровень абароны старонкі «[[$1]]»',
 'unprotectedarticle'          => 'зьнятая абарона са старонкі «[[$1]]»',
@@ -1937,7 +1944,7 @@
 'badipaddress'                    => 'Некарэктны IP-адрас',
 'blockipsuccesssub'               => 'Блякаваньне пасьпяховае',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] быў заблякаваны/была заблякаваная.
-<br />Глядзіце [[Special:Ipblocklist|сьпіс заблякаваных IP-адрасоў]] дзеля перагляду блякаваньняў.',
+<br />Глядзіце [[Special:IPBlockList|сьпіс заблякаваных IP-адрасоў]] дзеля перагляду блякаваньняў.',
 'ipb-edit-dropdown'               => 'Рэдагаваць прычыны блякіровак',
 'ipb-unblock-addr'                => 'Разблякаваць $1',
 'ipb-unblock'                     => 'Разблякаваць рахунак ўдзельніка ці IP-адрас',
@@ -1948,7 +1955,7 @@
 'ipusubmit'                       => 'Разблякаваць гэты IP-адрас',
 'unblocked'                       => '[[User:$1|$1]] быў разблякаваны.',
 'unblocked-id'                    => 'Блякаваньне $1 зьнятае',
-'ipblocklist'                     => 'Сьпіс заблякаваных IP-адрасоў і імёнаў удзельнікаў',
+'ipblocklist'                     => 'Заблякаваныя IP-адрасы і імёны удзельнікаў',
 'ipblocklist-legend'              => 'Пошук заблякаванага ўдзельніка',
 'ipblocklist-username'            => 'Імя ўдзельніка/ўдзельніцы альбо IP-адрас:',
 'ipblocklist-submit'              => 'Шукаць',
@@ -1967,7 +1974,7 @@
 'autoblocker'                     => "Вы аўтаматычна заблякаваныя, таму што Ваш IP-адрас нядаўна ўжываўся «[[User:$1|$1]]». Прычына блякаваньня $1 наступная: «'''$2'''»",
 'blocklogpage'                    => 'Журнал блякаваньняў',
 'blocklogentry'                   => 'заблякаваны [[$1]] на тэрмін: $2 $3',
-'blocklogtext'                    => 'Гэта журнал уліку блякаваньняў і разблякаваньняў удзельнікаў. Аўтаматычна заблякаваныя IP-адрасы не пазначаныя. Глядзіце [[Special:Ipblocklist|сьпіс заблякаваных IP-адрасоў]], каб пабачыць дзейныя ў гэты момант блякаваньні.',
+'blocklogtext'                    => 'Гэта журнал уліку блякаваньняў і разблякаваньняў удзельнікаў. Аўтаматычна заблякаваныя IP-адрасы не пазначаныя. Глядзіце [[Special:IPBlockList|сьпіс заблякаваных IP-адрасоў]], каб пабачыць дзейныя ў гэты момант блякаваньні.',
 'unblocklogentry'                 => 'разблякаваны $1',
 'block-log-flags-anononly'        => 'толькі ананімныя ўдзельнікі',
 'block-log-flags-nocreate'        => 'стварэньне рахункаў забароненае',
@@ -2007,7 +2014,7 @@
 'lockdbsuccesssub'    => 'База зьвестак заблякаваная',
 'unlockdbsuccesssub'  => 'База зьвестак разблякаваная',
 'lockdbsuccesstext'   => 'База зьвестак была заблякаваная.<br />
-Не забудзьцеся [[Special:Unlockdb|зьняць блякаваньне]] пасьля сканчэньня абслугоўваньня.',
+Не забудзьцеся [[Special:UnlockDB|зьняць блякаваньне]] пасьля сканчэньня абслугоўваньня.',
 'unlockdbsuccesstext' => 'База зьвестак была разблякаваная.',
 'lockfilenotwritable' => 'Немагчыма запісаць у файл блякаваньняў базы зьвестак.
 Блякаваньне ці разблякаваньне базы зьвестак патрабуе, каб вэб-сэрвэр меў дазвол на запіс у гэты файл.',
@@ -2018,11 +2025,11 @@
 'move-page-legend'        => 'Перанесьці старонку',
 'movepagetext'            => "З дапамогай гэтай формы Вы можаце зьмяніць назву і гісторыю старонкі.
 Старая назва будзе перанакіроўваць на новую.
-Спасылкі на старую назву ня будуць зьмененыя;
-упэўніцеся ў адсутнасьці падвойных ці няслушных перанакіраваньняў.
+Вы можаце аўтаматычна абнавіць перанакіраваньні на першапачатковую назву.
+Калі вы адмовіцеся, упэўніцеся ў адсутнасьці [[Special:DoubleRedirects|падвойных]] ці [[Special:BrokenRedirects|няслушных перанакіраваньняў]].
 Адказнасьць за дакладнасьць спасылак ляжыць на тым, хто перанёс старонку.
 
-Заўважце, што старонка '''ня будзе''' перанесеная, калі пад новай назвай ужо існуе іншая старонка, за выключэньнем выпадкаў, калі яна пустая альбо зьяўляецца перанакіраваньнем і ня мае гісторыі рэдагаваньняў. Гэта азначае, што існуе магчымасьць адмяніць зьмену назвы, калі Вы памыліліся, але не магчыма выдаліць існуючую старонку.
+Заўважце, што старонка '''ня будзе''' перанесеная, калі пад новай назвай ужо існуе іншая старонка, за выключэньнем выпадкаў, калі яна пустая альбо зьяўляецца перанакіраваньнем і ня мае гісторыі рэдагаваньняў. Гэта азначае, што існуе магчымасьць адмяніць зьмену назвы, калі Вы памыліліся, але не магчыма выдаліць існую старонку.
 
 '''ПАПЯРЭДЖАНЬНЕ!'''
 Зьмена назвы можа прывесьці да нечаканых зьменаў папулярных старонак;
@@ -2033,8 +2040,6 @@
 
 У такіх выпадках, Вы можаце перанесьці ці аб'яднаць старонку абмеркаваньня самастойна.",
 'movearticle'             => 'Перанесьці старонку:',
-'movenologin'             => 'Вы не ўвайшлі ў сыстэму',
-'movenologintext'         => 'Вам неабходна [[Special:Userlogin|ўвайсьці ў сыстэму]], каб перанесьці старонкі.',
 'movenotallowed'          => 'Вы ня маеце правоў на перанос старонак у {{GRAMMAR:месны|{{SITENAME}}}}.',
 'newtitle'                => 'Новая назва:',
 'move-watch'              => 'Назіраць за гэтай старонкай',
@@ -2060,7 +2065,7 @@
 'revertmove'              => 'адкат',
 'delete_and_move'         => 'Выдаліць і перанесьці',
 'delete_and_move_text'    => '==Патрабуецца выдаленьне==
-Мэтавая старонка «[[$1]]» ужо існуе.
+Мэтавая старонка «[[:$1]]» ужо існуе.
 Ці жадаеце Вы яе выдаліць, каб вызваліць месца для пераносу?',
 'delete_and_move_confirm' => 'Так, выдаліць старонку',
 'delete_and_move_reason'  => 'Выдаленая, каб вызваліць месца для пераносу',
@@ -2071,6 +2076,7 @@
 'imagenocrossnamespace'   => 'Нельга перанесьці файл у ня-файлавую прастору назваў',
 'imagetypemismatch'       => 'Новае пашырэньне файла не адпавядае яго тыпу',
 'imageinvalidfilename'    => 'Няслушная назва мэтавага файла',
+'fix-double-redirects'    => 'Абнавіць усе перанакіраваньні на першапачатковую назву',
 
 # Export
 'export'            => 'Экспартаваць старонкі',
@@ -2103,42 +2109,73 @@
 'thumbnail-more'           => 'Павялічыць',
 'filemissing'              => 'Файл адсутны',
 'thumbnail_error'          => 'Памылка стварэньня мініятуры: $1',
+'djvu_page_error'          => 'Старонка DjVu па-за прамежкам',
+'djvu_no_xml'              => 'Немагчыма атрымаць XML для DjVu-файла',
+'thumbnail_invalid_params' => 'Няслушныя парамэтры мініятуры',
 'thumbnail_dest_directory' => 'Немагчыма стварыць мэтавую дырэкторыю',
 
 # Special:Import
 'import'                     => 'Імпартаваць старонкі',
+'importinterwiki'            => 'Імпартаваньне зь іншых вікі',
+'import-interwiki-text'      => 'Абярыце вікі і назву старонкі для імпартаваньня.
+Даты зьменаў і імёны аўтараў будуць захаваныя.
+Усе дзеяньні імпартаваньня паміж вікі запісваюцца ў [[Special:Log/import|журнал імпартаваньняў]].',
 'import-interwiki-history'   => 'Капіяваць гісторыю старонкі цалкам',
 'import-interwiki-submit'    => 'Імпартаваць',
 'import-interwiki-namespace' => 'Перанесьці старонкі ў прастору назваў:',
+'importtext'                 => 'Калі ласка, экспартуйце файл з крынічнай вікі з дапамогай [[Special:Export|прылады экспарту]].
+Захавайце яго на свой дыск, а потым загрузіце сюды.',
 'importstart'                => 'Імпартаваньне старонак…',
 'import-revision-count'      => '$1 {{PLURAL:$1|вэрсія|вэрсіі|вэрсій}}',
 'importnopages'              => 'Няма старонак для імпартаваньня.',
 'importfailed'               => 'Немагчыма імпартаваць: $1',
+'importunknownsource'        => 'Невядомы тып крыніцы імпарту',
+'importcantopen'             => 'Немагчыма адкрыць файл імпарту',
 'importbadinterwiki'         => 'Няслушная спасылка на іншую моўную вэрсію',
 'importnotext'               => 'Тэкст адсутнічае',
 'importsuccess'              => 'Імпартаваньне скончанае!',
+'importhistoryconflict'      => 'Канфлікт вэрсіяў у гісторыі рэдагаваньняў (магчыма, гэтую старонку імпартавалі раней)',
+'importnosources'            => 'Крыніцы імпарту паміж вікі не былі вызначаныя і наўпроставая загрузка гісторыі адключаная.',
+'importnofile'               => 'Файл для імпартаваньня ня быў загружаны.',
+'importuploaderrorsize'      => 'Не атрымалася загрузіць файл імпартаваньня.
+Памер файла болей за дазволены для загрузкі.',
+'importuploaderrorpartial'   => 'Не атрымалася загрузіць файл імпартаваньня.
+Ён быў загружаны толькі часткова.',
+'importuploaderrortemp'      => 'Не атрымалася загрузіць файл імпартаваньня.
+Не стае часовай дырэкторыі.',
+'import-parse-failure'       => 'Памылка разбору XML пры імпартаваньні',
 'import-noarticle'           => 'Няма старонкі для імпартаваньня!',
+'import-nonewrevisions'      => 'Усе вэрсіі былі імпартаваныя раней.',
+'xml-error-string'           => '$1 у радку $2, пазыцыі $3 (байт $4): $5',
 'import-upload'              => 'Загрузіць XML-зьвесткі',
 
 # Import log
 'importlogpage'                    => 'Журнал імпартаваньняў',
+'importlogpagetext'                => 'Імпартаваньне адміністратарамі старонак з гісторыяй зьменаў зь іншых вікі.',
+'import-logentry-upload'           => 'імпартавана [[$1]] праз загрузку файла',
 'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|вэрсія|вэрсіі|вэрсій}}',
+'import-logentry-interwiki'        => 'імпартавана зь іншай вікі $1',
 'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|вэрсія|вэрсіі|вэрсій}} з $2',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Мая старонка ўдзельніка',
+'tooltip-pt-anonuserpage'         => 'Старонка ўдзельніка для IP-адрасу, зь якога Вы рэдагуеце',
 'tooltip-pt-mytalk'               => 'Мая старонка размоваў',
+'tooltip-pt-anontalk'             => 'Старонка гутарак пра рэдагаваньні, зробленыя з гэтага IP-адрасу',
 'tooltip-pt-preferences'          => 'Мае ўстаноўкі',
 'tooltip-pt-watchlist'            => 'Сьпіс старонак, за зьменамі якіх Вы назіраеце',
 'tooltip-pt-mycontris'            => 'Мой унёсак',
 'tooltip-pt-login'                => 'Вас запрашаюць увайсьці, хаця гэта і неабавязкова.',
+'tooltip-pt-anonlogin'            => 'Уваход у сыстэму вітаецца, хаця ён не абавязковы.',
 'tooltip-pt-logout'               => 'Выйсьці',
 'tooltip-ca-talk'                 => 'Абмеркаваньне зьместу старонкі',
 'tooltip-ca-edit'                 => 'Вы можаце рэдагаваць гэтую старонку. Калі ласка, ужывайце кнопку прагляду перад захаваньнем.',
 'tooltip-ca-addsection'           => 'Дадаць камэнтар да гэтага абмеркаваньня.',
 'tooltip-ca-viewsource'           => 'Гэтая старонка абароненая. Але можна паглядзець яе крынічны тэкст.',
+'tooltip-ca-history'              => 'Мінулыя вэрсіі гэтай старонкі.',
 'tooltip-ca-protect'              => 'Абараніць гэтую старонку',
 'tooltip-ca-delete'               => 'Выдаліць гэтую старонку',
+'tooltip-ca-undelete'             => 'Аднавіць рэдагаваньні, зробленыя да выдаленьня гэтай старонкі',
 'tooltip-ca-move'                 => 'Перанесьці гэтую старонку',
 'tooltip-ca-watch'                => 'Дадаць гэтую старонку ў Ваш сьпіс назіраньня',
 'tooltip-ca-unwatch'              => 'Выдаліць гэтую старонку з Вашага сьпісу назіраньня',
@@ -2153,6 +2190,7 @@
 'tooltip-n-randompage'            => 'Паказаць выпадковую старонку',
 'tooltip-n-help'                  => 'Месца, каб пра ўсё даведацца.',
 'tooltip-t-whatlinkshere'         => 'Сьпіс усіх старонак, якія спасылаюцца на гэтую',
+'tooltip-t-recentchangeslinked'   => 'Апошнія зьмены ў старонках, на якія спасылаецца гэтая старонка',
 'tooltip-feed-rss'                => 'RSS-стужка для гэтай старонкі',
 'tooltip-feed-atom'               => 'Atom-стужка для гэтай старонкі',
 'tooltip-t-contributions'         => 'Паказаць унёсак гэтага удзельніка/гэтай удзельніцы',
@@ -2161,10 +2199,13 @@
 'tooltip-t-specialpages'          => 'Сьпіс усіх спэцыяльных старонак',
 'tooltip-t-print'                 => 'Вэрсія гэтай старонкі для друку',
 'tooltip-t-permalink'             => 'Сталая спасылка на гэтую вэрсію старонкі',
+'tooltip-ca-nstab-main'           => 'Паказаць зьмест старонкі',
 'tooltip-ca-nstab-user'           => 'Паказаць старонку ўдзельніка',
+'tooltip-ca-nstab-media'          => 'Паказаць старонку мэдыя-файла',
 'tooltip-ca-nstab-special'        => 'Гэта спэцыяльная старонка, і Вы ня можаце яе рэдагаваць',
 'tooltip-ca-nstab-project'        => 'Паказаць старонку праекту',
 'tooltip-ca-nstab-image'          => 'Паказаць старонку файла',
+'tooltip-ca-nstab-mediawiki'      => 'Паказаць сыстэмнае паведамленьне',
 'tooltip-ca-nstab-template'       => 'Паказаць шаблён',
 'tooltip-ca-nstab-help'           => 'Паказаць старонку дапамогі',
 'tooltip-ca-nstab-category'       => 'Паказаць старонку катэгорыі',
@@ -2174,8 +2215,14 @@
 'tooltip-diff'                    => 'Паказаць зробленыя Вамі зьмены ў тэксьце.',
 'tooltip-compareselectedversions' => 'Пабачыць розьніцу паміж дзьвюма абранымі вэрсіямі гэтай старонкі.',
 'tooltip-watch'                   => 'Дадаць гэтую старонку ў Ваш сьпіс назіраньня',
+'tooltip-recreate'                => 'Аднавіць старонку, ня гледзячы на тое, што яна была выдаленая',
 'tooltip-upload'                  => 'Пачаць загрузку',
 
+# Metadata
+'nodublincore'      => 'Мэтазьвесткі Dublin Core RDF забароненыя на гэтым сэрвэры.',
+'nocreativecommons' => 'Мэтазьвесткі Creative Commons RDF забароненыя на гэтым сэрвэры.',
+'notacceptable'     => 'Вікі-сэрвэр ня можа адлюстраваць зьвесткі ў выглядзе, які здольны прачытаць Ваш браўзэр.',
+
 # Attribution
 'anonymous'        => 'Ананімныя ўдзельнікі і ўдзельніцы {{GRAMMAR:родны|{{SITENAME}}}}',
 'siteuser'         => 'Удзельнік/удзельніца {{GRAMMAR:родны|{{SITENAME}}}} $1',
@@ -2184,9 +2231,16 @@
 'others'           => 'іншыя',
 'siteusers'        => 'Удзельнік(і) {{grammar:родны|{{SITENAME}}}} $1',
 'creditspage'      => 'Падзякі',
+'nocredits'        => 'Няма інфармацыі пра аўтараў гэтай старонкі.',
 
 # Spam protection
 'spamprotectiontitle' => 'Фільтар для абароны ад спаму',
+'spamprotectiontext'  => 'Старонка, якую Вы жадаеце захаваць, была заблякаваная спам-фільтрам.
+Верагодна яна ўтрымлівае спасылку на вонкавы сайт.',
+'spamprotectionmatch' => 'Спам-фільтар даслаў наступнае паведамленьне: $1',
+'spambot_username'    => 'Чыстка спаму MediaWiki',
+'spam_reverting'      => 'Адкат да апошняй вэрсіі без спасылак на $1',
+'spam_blanking'       => 'Усе вэрсіі ўтрымліваюць спасылкі на $1, чыстка',
 
 # Info page
 'infosubtitle'   => 'Інфармацыя пра старонку',
@@ -2204,20 +2258,42 @@
 'mw_math_modern' => 'Рэкамэндуецца для сучасных браўзэраў',
 'mw_math_mathml' => 'MathML калі магчыма (экспэрымэнтальна)',
 
+# Patrolling
+'markaspatrolleddiff'                 => 'Пазначыць як «патруляваную»',
+'markaspatrolledtext'                 => 'Пазначыць гэтую старонку як «патруляваную»',
+'markedaspatrolled'                   => 'Пазначаная як «патруляваная»',
+'markedaspatrolledtext'               => 'Абраная вэрсія пазначаная як «патруляваная»',
+'rcpatroldisabled'                    => 'Патруляваньне апошніх зьменаў адключанае',
+'rcpatroldisabledtext'                => 'Магчымасьць патруляваньня апошніх зьменаў цяпер адключаная.',
+'markedaspatrollederror'              => 'Немагчыма пазначыць як «патруляваную»',
+'markedaspatrollederrortext'          => 'Вы мусіце абраць вэрсію, каб пазначыць яе «патруляванай».',
+'markedaspatrollederror-noautopatrol' => 'Вам не дазволена пазначаць Вашыя ўласныя зьмены як «патруляваныя».',
+
 # Patrol log
-'patrol-log-page' => 'Журнал патруляваньняў',
-'patrol-log-auto' => '(аўтаматычна)',
+'patrol-log-page'   => 'Журнал патруляваньняў',
+'patrol-log-header' => 'Гэта журнал патруляваных вэрсіяў.',
+'patrol-log-line'   => 'пазначана $1 з $2 патруляваных $3',
+'patrol-log-auto'   => '(аўтаматычна)',
 
 # Image deletion
-'deletedrevision'       => 'Выдаленая старая вэрсія $1',
-'filedeleteerror-short' => 'Памылка выдаленьня файла: $1',
-'filedelete-missing'    => 'Немагчыма выдаліць файл «$1», таму што ён не існуе.',
+'deletedrevision'                 => 'Выдаленая старая вэрсія $1',
+'filedeleteerror-short'           => 'Памылка выдаленьня файла: $1',
+'filedeleteerror-long'            => 'У часе выдаленьня файла ўзьніклі наступныя памылкі:
 
+$1',
+'filedelete-missing'              => 'Немагчыма выдаліць файл «$1», таму што ён не існуе.',
+'filedelete-old-unregistered'     => 'Пазначанай вэрсіі файла «$1» няма ў базе зьвестак.',
+'filedelete-current-unregistered' => 'Пазначанага файла «$1» няма ў базе зьвестак.',
+'filedelete-archive-read-only'    => 'Архіўная дырэкторыя «$1» не даступная для запісу вэб-сэрвэра.',
+
 # Browsing diffs
 'previousdiff' => '← Перайсьці да папярэдняй зьмены',
 'nextdiff'     => 'Перайсьці да наступнай зьмены →',
 
 # Media information
+'mediawarning'         => "'''Папярэджаньне''': гэты файл можа ўтрымліваць зламысны код, выкананьне якога можа нашкодзіць вашай сыстэме.<hr />",
+'imagemaxsize'         => 'Абмяжоўваць памер выяваў на старонках апісаньня да:',
+'thumbsize'            => 'Памер паменшанай вэрсіі выявы:',
 'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|старонка|старонкі|старонак}}',
 'file-info'            => '(памер файла: $1, тып MIME: $2)',
 'file-info-size'       => '($1 × $2 {{PLURAL:$2|піксэль|піксэлі|піксэляў}}, памер файла: $3, тып MIME: $4)',
@@ -2226,13 +2302,15 @@
 'show-big-image'       => 'Найлепшае разрозьненьне',
 'show-big-image-thumb' => '<small>Памер пры папярэднім праглядзе: $1 × $2 {{PLURAL:$2|піксэль|піксэлі|піксэляў}}</small>',
 
-# Special:Newimages
-'newimages'     => 'Галерэя новых файлаў',
-'imagelisttext' => "Ніжэй пададзены сьпіс з '''$1''' {{PLURAL:$1|файла|файлаў|файлаў}}, адсартаваных $2.",
-'showhidebots'  => '($1 робатаў)',
-'noimages'      => 'Выявы адсутнічаюць.',
-'ilsubmit'      => 'Шукаць',
-'bydate'        => 'па даце',
+# Special:NewImages
+'newimages'             => 'Галерэя новых файлаў',
+'imagelisttext'         => "Ніжэй пададзены сьпіс з '''$1''' {{PLURAL:$1|файла|файлаў|файлаў}}, адсартаваных $2.",
+'newimages-summary'     => 'Гэтая спэцыяльная старонка паказвае нядаўна загружаныя файлы.',
+'showhidebots'          => '($1 робатаў)',
+'noimages'              => 'Выявы адсутнічаюць.',
+'ilsubmit'              => 'Шукаць',
+'bydate'                => 'па даце',
+'sp-newimages-showfrom' => 'Паказаць новыя файлы, загружаныя пазьней за $2, $1',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
 'seconds-abbrev' => 'с',
@@ -2263,8 +2341,25 @@
 'exif-imagelength'                 => 'Вышыня',
 'exif-bitspersample'               => 'Глыбіня колеру',
 'exif-compression'                 => 'Мэтад сьцісканьня',
+'exif-photometricinterpretation'   => 'Колеравая мадэль',
 'exif-orientation'                 => 'Арыентацыя кадра',
+'exif-samplesperpixel'             => 'Колькасьць колеравых кампанэнтаў',
+'exif-planarconfiguration'         => 'Прынцып арганізацыі зьвестак',
+'exif-ycbcrsubsampling'            => 'Суадносіны памераў кампанэнтаў Y і C',
+'exif-ycbcrpositioning'            => 'Парадак разьмяшчэньня кампанэнтаў Y і C',
+'exif-xresolution'                 => 'Гарызантальнае разрозьненьне',
+'exif-yresolution'                 => 'Вэртыкальнае разрозьненьне',
+'exif-resolutionunit'              => 'Адзінка вымярэньня разрозьненьняў X і Y',
+'exif-stripoffsets'                => 'Разьмяшчэньне блёку зьвестак',
+'exif-rowsperstrip'                => 'Колькасьць радкоў у блёку',
+'exif-stripbytecounts'             => 'Памер сьціснутага блёку',
+'exif-jpeginterchangeformat'       => 'Разьмяшчэньне пачатку блёку JPEG SOI',
 'exif-jpeginterchangeformatlength' => 'Байты JPEG-зьвестак',
+'exif-transferfunction'            => 'Функцыя пераўтварэньня колеравай прасторы',
+'exif-whitepoint'                  => 'Колернасьць белага пункту',
+'exif-primarychromaticities'       => 'Колернасьць асноўных колераў',
+'exif-ycbcrcoefficients'           => 'Каэфіцыенты пераўтварэньня колеравай прасторы',
+'exif-referenceblackwhite'         => 'Становішча белага і чорнага пунктаў',
 'exif-datetime'                    => 'Дата і час зьмены файла',
 'exif-imagedescription'            => 'Назва выявы',
 'exif-make'                        => 'Вытворца фотаапарата',
@@ -2275,11 +2370,15 @@
 'exif-colorspace'                  => 'Колеравая прастора',
 'exif-usercomment'                 => 'Камэнтары карыстальніка',
 'exif-exposuretime-format'         => '$1 сэк ($2)',
+'exif-aperturevalue'               => 'Дыяфрагма',
+'exif-brightnessvalue'             => 'Яркасьць',
 'exif-lightsource'                 => 'Крыніца сьвятла',
 'exif-flash'                       => 'Успышка',
 'exif-focallength-format'          => '$1 мм',
+'exif-saturation'                  => 'Насычанасьць',
 'exif-gpslatitude'                 => 'Шырата',
 'exif-gpslongitude'                => 'Даўгата',
+'exif-gpsaltitude'                 => 'Вышыня',
 
 'exif-lightsource-0' => 'Невядомая',
 'exif-lightsource-4' => 'Успышка',
@@ -2294,7 +2393,7 @@
 
 # External editor support
 'edit-externally'      => 'Рэдагаваць гэты файл з выкарыстаньнем вонкавай праграмы',
-'edit-externally-help' => 'Глядзіце падрабязнасьці ў [http://meta.wikimedia.org/wiki/Help:External_editors інструкцыі па наладцы] (па-ангельску).',
+'edit-externally-help' => 'Глядзіце падрабязнасьці ў [http://www.mediawiki.org/wiki/Manual:External_editors інструкцыі па наладцы] (па-ангельску).',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'усе',
@@ -2399,7 +2498,7 @@
 'version-license'          => 'Ліцэнзія',
 'version-software-version' => 'Вэрсія',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Шлях да файла',
 'filepath-page'   => 'Файл:',
 'filepath-submit' => 'Шлях',
@@ -2421,7 +2520,7 @@
 'specialpages-group-pagetools' => 'Інструмэнты для старонак',
 'specialpages-group-spam'      => 'Інструмэнты для барацьбы са спамам',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Пустая старонка',
 'intentionallyblankpage' => 'Гэтая старонка наўмысна пакінутая пустой',
 
Index: languages/messages/MessagesYue.php
===================================================================
--- languages/messages/MessagesYue.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesYue.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,5 +1,5 @@
 <?php
-/** Cantonese (粵語/廣東話)
+/** Yue (粵語)
  *
  * @ingroup Language
  * @file
@@ -415,7 +415,7 @@
 'nosuchspecialpage' => '冇呢頁特別頁',
 'nospecialpagetext' => "<big>'''無你所要求嘅特別頁。'''</big>
 
-喺[[Special:Specialpages|{{int:specialpages}}]]有全部用得嘅特別頁。",
+喺[[Special:SpecialPages|{{int:specialpages}}]]有全部用得嘅特別頁。",
 
 # General errors
 'error'                => '錯誤',
@@ -445,7 +445,7 @@
 通常係因為修訂歷史頁上面，由過時嘅連結去到刪除咗嘅版所引起嘅。
 
 如果唔係，你可能係搵到軟件裏面嘅臭蟲。
-請記低 URL 地址，向管理員報告。',
+請記低 URL 地址，向[[Special:ListUsers/sysop|管理員]]報告。',
 'missingarticle-rev'   => '(修訂#: $1)',
 'missingarticle-diff'  => '(差異: $1, $2)',
 'readonly_lag'         => '當從伺服器追緊主伺服器時，資料庫會自動被鎖',
@@ -494,10 +494,10 @@
 'logouttitle'                => '用戶登出',
 'logouttext'                 => "'''你而家已經登出咗。'''
 
-你仍然可以用匿名身份用{{SITENAME}}，又或者重新登入。但係留意某啲頁面可能會繼續話你登入咗，除非等你清除瀏覽器嘅快取儲存。",
+你仍然可以用匿名身份用{{SITENAME}}，又或者[[Special:UserLogin|重新登入]]。但係留意某啲頁面可能會繼續話你登入咗，除非等你清除瀏覽器嘅快取儲存。",
 'welcomecreation'            => '== 歡迎， $1！ ==
 
-你個戶口已經起好。唔好唔記得去改改你嘅{{SITENAME}}喜好設定喎。',
+你個戶口已經起好。唔好唔記得去改改你嘅[[Special:Preferences|{{SITENAME}}喜好設定]]喎。',
 'loginpagetitle'             => '用戶登入',
 'yourname'                   => '用戶名:',
 'yourpassword'               => '密碼:',
@@ -638,7 +638,7 @@
 你可以聯絡 $1 或者其他嘅[[{{MediaWiki:Grouppage-sysop}}|管理員]]，討論呢次封鎖。
 除非你已經響你嘅[[Special:Preferences|戶口喜好設定]]入面設定咗有效嘅電郵地址，否則你係唔可以用「電郵呢個用戶」嘅功能。當設定咗一個有效嘅電郵地址之後，呢個功能係唔會封鎖嘅。
 
-你現時嘅 IP 位址係 $3 ，而個封鎖 ID 係 #$5。 請你喺所有查詢都註明呢個位址同埋／或者個封鎖 ID 。",
+你現時嘅 IP 位址係 $3 ，而個封鎖 ID 係 #$5。 請你喺你嘅查詢都註明以上封鎖嘅資料。",
 'autoblockedtext'                  => "你嘅IP地址已經被自動封鎖，由於之前嘅另一位用戶係畀$1封咗。
 而封鎖嘅原因係：
 
@@ -646,21 +646,18 @@
 
 * 呢次封鎖嘅開始時間係：$8
 * 呢次封鎖嘅到期時間係：$6
+* 對於被封鎖者：$7
 
 你可以聯絡 $1 或者其他嘅[[{{MediaWiki:Grouppage-sysop}}|管理員]]，討論呢次封鎖。
 
 除非你已經響你嘅[[Special:Preferences|戶口喜好設定]]入面設定咗有效嘅電郵地址，否則你係唔可以用「電郵呢個用戶」嘅功能。當設定咗一個有效嘅電郵地址之後，呢個功能係唔會封鎖嘅。
 
-你個封鎖 ID 係 #$5。 請你喺所有查詢都註明呢個封鎖 ID 。",
+你現時用緊嘅 IP 地址係 $3，個封鎖 ID 係 #$5。 請喺你嘅查詢都註明呢個封鎖上面嘅資料。",
 'blockednoreason'                  => '無原因畀低',
 'blockedoriginalsource'            => "有關'''$1'''嘅原始碼響下面列示：",
 'blockededitsource'                => "有關'''你'''對'''$1'''嘅'''編輯'''文字響下面列示：",
 'whitelistedittitle'               => '需要登入之後先至可以編輯',
 'whitelistedittext'                => '你需要$1去編輯呢頁。',
-'whitelistreadtitle'               => '登入咗至睇到',
-'whitelistreadtext'                => '你需要[[Special:Userlogin|登入]]先可以去睇呢頁。',
-'whitelistacctitle'                => '你唔可以開一個新戶口',
-'whitelistacctext'                 => '要喺{{SITENAME}}開戶口，你要[[Special:Userlogin|登入]]同提供適當嘅許可。',
 'confirmedittitle'                 => '要用電郵確定咗先可以改',
 'confirmedittext'                  => '你個電郵地址要確定咗先可以編輯。唔該先去[[Special:Preferences|喜好設定]]填咗電郵地址，並做埋確認手續。',
 'nosuchsectiontitle'               => '無呢個小節',
@@ -674,7 +671,7 @@
 'newarticletext'                   => "你連連過嚟嘅頁面重未存在。
 要起版新嘅，請你喺下面嗰格度輸入。(睇睇[[{{MediaWiki:Helppage}}|自助版]]拎多啲資料。)
 如果你係唔覺意嚟到呢度，撳一次你個瀏覽器'''返轉頭'''個掣。",
-'anontalkpagetext'                 => "----''呢度係匿名用戶嘅討論頁，佢可能係重未開戶口，或者佢重唔識開戶口。我哋會用數字表示嘅IP地址嚟代表佢。一個IP地址係可以由幾個用戶夾來用。如果你係匿名用戶，同覺得呢啲留言係同你冇關係嘅話，唔該去[[Special:Userlogin|開一個新戶口或登入]]，避免喺以後嘅留言會同埋其它用戶混淆。''",
+'anontalkpagetext'                 => "----''呢度係匿名用戶嘅討論頁，佢可能係重未開戶口，或者佢重唔識開戶口。我哋會用數字表示嘅IP地址嚟代表佢。一個IP地址係可以由幾個用戶夾來用。如果你係匿名用戶，同覺得呢啲留言係同你冇關係嘅話，唔該去[[Special:UserLogin/signup|開一個新戶口]]或[[Special:UserLogin|登入]]，避免喺以後嘅留言會同埋其它用戶混淆。''",
 'noarticletext'                    => '喺呢一頁而家並冇任何嘅文字，你可以喺其它嘅頁面中[[Special:Search/{{PAGENAME}}|搵呢一頁嘅標題]]或者[{{fullurl:{{FULLPAGENAME}}|action=edit}} 編輯呢一頁]。',
 'userpage-userdoesnotexist'        => '用戶戶口"$1"重未開。請響䦒／編輯呢版之前先檢查一下。',
 'clearyourcache'                   => "'''注意 - 喺儲存之後，你可能要先略過你嘅瀏覽器快取去睇到更改。''' '''Mozilla / Firefox / Safari:''' 㩒住''Shift''掣再撳''重新載入''，又或者㩒''Ctrl-F5''或者''Ctrl-R''（喺Macintosh㩒''Command-R''掣）； '''Konqueror:''' 就咁以撳個''重載''掣，又或者㩒''F5''； '''Opera:'''喺''工具→喜好設定''之中清佢哋嘅快取； '''Internet Explorer:''' 㩒住''Ctrl''掣再撳''重新整理''，又或者㩒''Ctrl-F5''掣。",
@@ -687,12 +684,12 @@
 'previewnote'                      => '<strong>請記住呢個只係預覽；更改嘅内容重未儲存！</strong>',
 'previewconflict'                  => '呢個預覽係反映如果你選擇儲存嘅話，嘅上面嘅文字編輯區裏面嘅字會儲存落嚟。',
 'session_fail_preview'             => "'''對唔住！由於小節嘅資料唔見咗，我哋唔能夠處理你嘅編輯。
-請再試過喇。如果仍然唔得嘅話，試下登出，然後重新登入。'''",
+請再試過喇。如果仍然唔得嘅話，試下[[Special:UserLogout|登出]]，然後重新登入。'''",
 'session_fail_preview_html'        => "'''對唔住！有關嘅程序資料已經遺失，我哋唔能夠處理你嘅編輯。'''
 
 ''由於{{SITENAME}}已經開放咗原 HTML 碼，預覽已經隱藏落嚟以預防 JavaScript 嘅攻擊。''
 
-'''如果呢個係正當嘅編輯嘗試，請再試過。如果重係唔得嘅話，請先登出然後再登入。'''",
+'''如果呢個係正當嘅編輯嘗試，請再試過。如果重係唔得嘅話，請先[[Special:UserLogout|登出]]然後再登入。'''",
 'token_suffix_mismatch'            => "'''因為你嘅用戶端度嘅編輯幣整壞咗一啲標點符號字元，你嘅編輯已經拒絕咗。個編輯已經拒絕，以防止嗰版嘅文字損毀。
 當你響度用緊一啲好多臭蟲，以網絡為主嘅匿名代理服務。'''",
 'editing'                          => '而家喺度編輯$1',
@@ -734,7 +731,7 @@
 'edittools'                        => '<!-- 喺呢度嘅文字會喺編輯框下面同埋上載表格中顯示。 -->',
 'nocreatetitle'                    => '頁面建立被限制',
 'nocreatetext'                     => '{{SITENAME}}已經限制咗起新版嘅能力。
-你可以番轉頭去編輯一啲已經存在嘅頁面，或者[[Special:Userlogin|登入或開個新戶口]]。',
+你可以番轉頭去編輯一啲已經存在嘅頁面，或者[[Special:UserLogin|登入或開個新戶口]]。',
 'nocreate-loggedin'                => '你響{{SITENAME}}度並無許可權去開新版。',
 'permissionserrors'                => '權限錯誤',
 'permissionserrorstext'            => '根據下面嘅{{PLURAL:$1|原因|原因}}，你並無權限去做呢樣嘢:',
@@ -853,7 +850,7 @@
 # Suppression log
 'suppressionlog'     => '廢止日誌',
 'suppressionlogtext' => '下面係刪除同埋由操作員牽涉到內容封鎖嘅一覽。
-睇吓[[Special:Ipblocklist|IP封鎖一覽]]去睇現時進行緊嘅禁止同埋封鎖表。',
+睇吓[[Special:IPBlockList|IP封鎖一覽]]去睇現時進行緊嘅禁止同埋封鎖表。',
 
 # History merging
 'mergehistory'                     => '合併頁歷史',
@@ -893,7 +890,7 @@
 # Search results
 'searchresults'             => '搵嘢結果',
 'searchresulttext'          => '有關搵{{SITENAME}}嘅更多資料請參考[[{{MediaWiki:Helppage}}|{{int:help}}]]。',
-'searchsubtitle'            => "你利用'''[[:$1]]'''搵",
+'searchsubtitle'            => '你利用\'\'\'[[:$1]]\'\'\'搵  ([[Special:Prefixindex/$1|全部由 "$1" 開始嘅頁]] | [[Special:WhatLinksHere/$1|全部連去 "$1" 嘅頁]])',
 'searchsubtitleinvalid'     => "你利用'''$1'''搵",
 'noexactmatch'              => "'''搵唔到到標題為\"\$1\"嘅頁面。''' 你可以而家[[:\$1|開呢個新頁]]。",
 'noexactmatch-nocreate'     => "'''搵唔到到標題為\"\$1\"嘅頁面。'''",
@@ -936,7 +933,7 @@
 'mypreferences'            => '我嘅喜好設定',
 'prefs-edits'              => '編輯數:',
 'prefsnologin'             => '重未登入',
-'prefsnologintext'         => '你一定要去[[Special:Userlogin|登入]]設定好用戶喜好值先。',
+'prefsnologintext'         => '你一定要去[[Special:UserLogin|登入]]設定好用戶喜好值先。',
 'prefsreset'               => '喜好設定已經從儲存空間中重設。',
 'qbsettings'               => '快捷列',
 'qbsettings-none'          => '無',
@@ -1010,7 +1007,7 @@
 'userrights-reason'           => '更改嘅原因:',
 'userrights-no-interwiki'     => '你並無權限去編輯響其它wiki嘅用戶權限。',
 'userrights-nodatabase'       => '資料庫$1唔存在或者唔係本地嘅。',
-'userrights-nologin'          => '你一定要以操作員戶口[[Special:Userlogin|登入]]咗之後先可以指定用戶權限。',
+'userrights-nologin'          => '你一定要以操作員戶口[[Special:UserLogin|登入]]咗之後先可以指定用戶權限。',
 'userrights-notallowed'       => '你嘅戶口無權限去指定用戶權限。',
 'userrights-changeable-col'   => '你可以改嘅組',
 'userrights-unchangeable-col' => '你唔可以改嘅組',
@@ -1140,23 +1137,24 @@
 'reupload'                    => '再上載',
 'reuploaddesc'                => '取消上載再返到去上載表格',
 'uploadnologin'               => '重未登入',
-'uploadnologintext'           => '你必須先[[Special:Userlogin|登入]]去上載檔案。',
+'uploadnologintext'           => '你必須先[[Special:UserLogin|登入]]去上載檔案。',
 'upload_directory_missing'    => '嗰個上載嘅目錄 ($1) 唔見咗，唔可以由網頁伺服器建立。',
 'upload_directory_read_only'  => '嗰個上載嘅目錄 ($1) 而家唔能夠被網頁伺服器寫入。',
 'uploaderror'                 => '上載錯誤',
 'uploadtext'                  => "用下面嘅表格嚟上載檔案。
-要睇或者搵嘢之前上載嘅圖像請去[[Special:Imagelist|已上載檔案一覽]]，上載同刪除嘅動作會喺[[Special:Log/upload|上載日誌]]裏面記錄落嚟。
+要睇或者搵嘢之前上載嘅圖像請去[[Special:ImageList|已上載檔案一覽]]，（再）上載嘅動作會喺[[Special:Log/upload|上載日誌]]裏面記錄落嚟，而刪除嘅動作會喺[[Special:Log/delete|刪除日誌]]裏面記錄落嚟。
 
-如果要喺頁面度引入呢張圖像，可以使用以下方式嘅連結：
-'''<nowiki>[[</nowiki>{{ns:image}}:file.jpg<nowiki>]]</nowiki>'''，
-'''<nowiki>[[</nowiki>{{ns:image}}:file.png|替代文字<nowiki>]]</nowiki>''' 或者用
-'''<nowiki>[[</nowiki>{{ns:media}}:file.ogg<nowiki>]]</nowiki>''' 直接連結到檔案。",
+如果要喺頁面度引入呢張圖像，可以使用以下其中一種方式嘅連結：
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:file.jpg<nowiki>]]</nowiki></tt>'''去用檔案嘅完整版
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:file.png|200px|thumb|left|替代文字<nowiki>]]</nowiki></tt>'''去用200像素比例闊，靠左邊加盒，響描述度加'替代文字'
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}:file.ogg<nowiki>]]</nowiki></tt>''' 直接連結到檔案而唔顯示個檔案。",
 'upload-permitted'            => '准許嘅檔案類型: $1。',
 'upload-preferred'            => '建議嘅檔案類型: $1。',
 'upload-prohibited'           => '禁止嘅檔案類型: $1。',
 'uploadlog'                   => '上載日誌',
 'uploadlogpage'               => '上載日誌',
-'uploadlogpagetext'           => '以下係最近檔案上載嘅一覽表。',
+'uploadlogpagetext'           => '以下係最近檔案上載嘅一覽表。
+睇[[Special:NewImages|新圖像畫廊]]去睇更詳細嘅總覽。',
 'filename'                    => '檔名',
 'filedesc'                    => '摘要',
 'fileuploadsummary'           => '摘要：',
@@ -1219,9 +1217,9 @@
 'upload-proto-error'      => '唔正確嘅協議',
 'upload-proto-error-text' => '遙遠上載需要一個以 <code>http://</code> 或者 <code>ftp://</code> 作為開頭嘅URL。',
 'upload-file-error'       => '內部錯誤',
-'upload-file-error-text'  => '當響伺服器度建立一個暫存檔時發生咗一個內部錯誤。請聯絡一位系統管理員。',
+'upload-file-error-text'  => '當響伺服器度建立一個暫存檔時發生咗一個內部錯誤。請聯絡一位[[Special:ListUsers/sysop|管理員]]。',
 'upload-misc-error'       => '未知嘅上載錯誤',
-'upload-misc-error-text'  => '響上載時發生咗未知嘅錯誤。請確認輸入咗嘅URL係可以訪問嘅，之後再試多一次。如果重有問題嘅話，請聯絡一位系統管理員。',
+'upload-misc-error-text'  => '響上載時發生咗未知嘅錯誤。請確認輸入咗嘅URL係可以訪問嘅，之後再試多一次。如果重有問題嘅話，請聯絡一位[[Special:ListUsers/sysop|管理員]]。',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => '唔可以到嗰個URL',
@@ -1235,7 +1233,7 @@
 'upload_source_url'  => ' （啱嘅，公開嘅網址）',
 'upload_source_file' => ' （你部電腦裏面嘅一個檔案）',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => '呢個特別版顯示全部上載過嘅檔案。
 響預設最後上載嘅檔案會顯示響呢個表嘅最頂。
 撳一欄嘅標題去改個排列。',
@@ -1263,7 +1261,7 @@
 'imagelinks'                     => '連結',
 'linkstoimage'                   => '以下嘅$1個頁面連結到呢個檔案：',
 'nolinkstoimage'                 => '冇個頁面連結到呢個檔案。',
-'morelinkstoimage'               => '去睇連到呢個檔案嘅[[Special:Whatlinkshere/$1|更多連結]]。',
+'morelinkstoimage'               => '去睇連到呢個檔案嘅[[Special:WhatLinksHere/$1|更多連結]]。',
 'redirectstofile'                => '下面嘅$1個檔案跳轉到呢個檔案:',
 'duplicatesoffile'               => '下面嘅$1個檔案係同呢個檔案重覆:',
 'sharedupload'                   => '呢個檔案係共用嘅上載，可以喺其他計劃中使用。“',
@@ -1282,22 +1280,22 @@
 # File reversion
 'filerevert'                => '回復$1',
 'filerevert-legend'         => '回復檔案',
-'filerevert-intro'          => '<span class="plainlinks">你而家回復緊\'\'\'[[Media:$1|$1]]\'\'\'到[$4 響$2 $3嘅版本]。</span>',
+'filerevert-intro'          => "你而家回復緊'''[[Media:$1|$1]]'''到[$4 響$2 $3嘅版本]。",
 'filerevert-comment'        => '註解:',
 'filerevert-defaultcomment' => '已經回復到響$1 $2嘅版本',
 'filerevert-submit'         => '回復',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'已經回復到[$4 響$2 $3嘅版本]。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''已經回復到[$4 響$2 $3嘅版本]。",
 'filerevert-badversion'     => '呢個檔案所提供嘅時間截記並無之前嘅本地版本。',
 
 # File deletion
 'filedelete'                  => '刪除$1',
 'filedelete-legend'           => '刪除檔案',
 'filedelete-intro'            => "你而家刪除緊'''[[Media:$1|$1]]'''。",
-'filedelete-intro-old'        => '<span class="plainlinks">你而家刪除緊\'\'\'[[Media:$1|$1]]\'\'\'響[$4 $2 $3]嘅版本。</span>',
+'filedelete-intro-old'        => "你而家刪除緊'''[[Media:$1|$1]]'''響[$4 $2 $3]嘅版本。",
 'filedelete-comment'          => '刪除原因:',
 'filedelete-submit'           => '刪除',
 'filedelete-success'          => "'''$1'''已經刪除咗。",
-'filedelete-success-old'      => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'響 $2 $3 嘅版本已經刪除咗。</span>',
+'filedelete-success-old'      => "'''[[Media:$1|$1]]'''響 $2 $3 嘅版本已經刪除咗。",
 'filedelete-nofile'           => "'''$1'''響{{SITENAME}}度唔存在。",
 'filedelete-nofile-old'       => "用指定嘅屬性，呢度係無'''$1'''響 $2 $3 嘅歸檔版本。",
 'filedelete-iscurrent'        => '你而家嘗試刪除呢個檔案嘅最近版本。請先將個檔打回頭做舊啲嘅版本先。',
@@ -1347,7 +1345,7 @@
 平均每個頁面有'''$5'''次瀏覽，同埋'''$6'''次編輯。
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]嘅長度係'''$7'''。",
-'userstatstext'          => "目前有'''$1'''個註冊[[Special:Listusers|用戶]]，其中有'''$2'''人（即'''$4%'''）有$5權限。",
+'userstatstext'          => "目前有'''$1'''個註冊[[Special:ListUsers|用戶]]，其中有'''$2'''人（即'''$4%'''）有$5權限。",
 'statistics-mostpopular' => '最多人睇嘅頁',
 
 'disambiguations'      => '搞清楚頁',
@@ -1355,16 +1353,18 @@
 Template:搞清楚',
 'disambiguations-text' => "以下呢啲頁面連結去一個'''搞清楚頁'''。佢哋先至應該指去正確嘅主題。<br />如果一個頁面連結自[[MediaWiki:Disambiguationspage]]，噉就會當佢係搞清楚頁。",
 
-'doubleredirects'     => '雙重跳轉',
-'doubleredirectstext' => '呢一版列出咗全部跳轉頁跳轉到另一版跳轉頁嘅版。每一行包括指去第一個同第二個跳轉嘅連結，以及第二個跳轉嘅目標。呢行文字通常畀出咗第一個跳轉應該指去嘅嗰個「真正」嘅目標頁面。',
+'doubleredirects'            => '雙重跳轉',
+'doubleredirectstext'        => '呢一版列出咗全部跳轉頁跳轉到另一版跳轉頁嘅版。每一行包括指去第一個同第二個跳轉嘅連結，以及第二個跳轉嘅目標。呢行文字通常畀出咗第一個跳轉應該指去嘅嗰個「真正」嘅目標頁面。',
+'double-redirect-fixed-move' => '[[$1]]已經搬好咗，佢而家跳轉過去[[$2]]',
+'double-redirect-fixer'      => '跳轉修正器',
 
 'brokenredirects'        => '破碎嘅跳轉',
-'brokenredirectstext'    => '以下嘅跳轉係指向唔存在嘅頁面：',
+'brokenredirectstext'    => '以下嘅跳轉係指向唔存在嘅頁面。',
 'brokenredirects-edit'   => '(編輯)',
 'brokenredirects-delete' => '(刪除)',
 
 'withoutinterwiki'         => '無語言連結嘅頁',
-'withoutinterwiki-summary' => '以下嘅頁面係重未有連結到其它嘅語言版本：',
+'withoutinterwiki-summary' => '以下嘅頁面係重未有連結到其它嘅語言版本。',
 'withoutinterwiki-legend'  => '前綴',
 'withoutinterwiki-submit'  => '顯示',
 
@@ -1441,7 +1441,7 @@
 'logempty'             => '日誌中冇符合嘅項目。',
 'log-title-wildcard'   => '搵以呢個文字開始嘅標題',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '所有頁面',
 'alphaindexline'    => '$1到$2',
 'nextpage'          => '下一頁 ($1)',
@@ -1464,15 +1464,15 @@
 'special-categories-sort-count' => '跟數量排',
 'special-categories-sort-abc'   => '跟字母排',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '顯示由呢個字開始嘅用戶：',
 'listusers-submit'   => '顯示',
 'listusers-noresult' => '搵唔到用戶。',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => '用戶組權限',
 'listgrouprights-summary'  => '下面係一個響呢個wiki定義咗嘅用戶權限一覽，同埋佢哋嘅存取權。
-更多有關個別權限嘅細節可以響[[{{MediaWiki:Listgrouprights-helppage}}|呢度]]搵到。',
+更多有關個別權限嘅[[{{MediaWiki:Listgrouprights-helppage}}|更多細節]]可以響嗰度搵到。',
 'listgrouprights-group'    => '組',
 'listgrouprights-rights'   => '權',
 'listgrouprights-helppage' => 'Help:組權限',
@@ -1480,10 +1480,10 @@
 
 # E-mail user
 'mailnologin'     => '冇傳送地址',
-'mailnologintext' => '你一定要[[Special:Userlogin|登入咗]]同埋喺你嘅[[Special:Preferences|喜好設定]]度有個有效嘅電郵地址先可以傳送電郵畀其他用戶。',
+'mailnologintext' => '你一定要[[Special:UserLogin|登入咗]]同埋喺你嘅[[Special:Preferences|喜好設定]]度有個有效嘅電郵地址先可以傳送電郵畀其他用戶。',
 'emailuser'       => '發電郵畀呢位用戶',
 'emailpage'       => '發電郵畀用戶',
-'emailpagetext'   => '如果呢位用戶已經喺佢嘅用戶使用偏好入邊填咗個合法嘅電郵地址，以下表格會發送單單一條信息。你喺你嘅用戶喜好設定入面填寫嘅電郵地址會出現喺呢封電郵「由」嘅地址度，以便收件人可以回覆到。',
+'emailpagetext'   => '如果呢位用戶已經喺佢嘅用戶使用偏好入邊填咗個有效嘅電郵地址，以下表格會發送單單一條信息。你喺[[Special:Preferences|你嘅用戶喜好設定]]入面填寫嘅電郵地址會出現喺呢封電郵「由」嘅地址度，以便收件人可以回覆到。',
 'usermailererror' => '目標郵件地址返回錯誤：',
 'defemailsubject' => '{{SITENAME}} 電郵',
 'noemailtitle'    => '無電郵地址',
@@ -1506,12 +1506,12 @@
 'nowatchlist'          => '你嘅監視清單度並冇任何項目。',
 'watchlistanontext'    => '請先$1去睇或者改響你監視清單度嘅項目。',
 'watchnologin'         => '未登入',
-'watchnologintext'     => '你必須先[[Special:Userlogin|登入]]至可以更改你嘅監視清單。',
+'watchnologintext'     => '你必須先[[Special:UserLogin|登入]]至可以更改你嘅監視清單。',
 'addedwatch'           => '加到監視清單度',
 'addedwatchtext'       => "頁面「[[:$1]]」已加入到你嘅[[Special:Watchlist|監視清單]]度。
-呢個頁面以及佢個討論頁以後嘅修改都會列喺嗰度，佢喺[[Special:Recentchanges|最近更改清單]]度會以'''粗體'''顯示，等你可以容易啲睇到佢。",
+呢個頁面以及佢個討論頁以後嘅修改都會列喺嗰度，佢喺[[Special:RecentChanges|最近更改清單]]度會以'''粗體'''顯示，等你可以容易啲睇到佢。",
 'removedwatch'         => '已經由監視清單中刪除',
-'removedwatchtext'     => '頁面「[[:$1]]」已經喺你嘅監視清單中刪除。',
+'removedwatchtext'     => '頁面「[[:$1]]」已經喺[[Special:Watchlist|你嘅監視清單]]度刪除。',
 'watch'                => '監視',
 'watchthispage'        => '監視呢頁',
 'unwatch'              => '唔使監視',
@@ -1609,15 +1609,15 @@
 'rollbacklink'                => '反轉',
 'rollbackfailed'              => '反轉唔到',
 'cantrollback'                => '反轉唔到；上一位貢獻者係唯一修改過呢版嘅人。',
-'alreadyrolled'               => '無法反轉[[User:$2|$2]]（[[User talk:$2|留言]]）對[[:$1]]嘅最後編輯；有人已經修改過或者反轉咗呢個頁面。
+'alreadyrolled'               => '無法反轉[[User:$2|$2]]（[[User talk:$2|留言]] | [[Special:Contributions/$2|{{int:contribslink}}]]）對[[:$1]]嘅最後編輯；有人已經修改過或者反轉咗呢個頁面。
 
-上次編輯係由[[User:$3|$3]]（[[User talk:$3|留言]]）做嘅。',
+上次對呢版嘅編輯係由[[User:$3|$3]]（[[User talk:$3|留言]] | [[Special:Contributions/$3|{{int:contribslink}}]]）做嘅。',
 'editcomment'                 => "編輯摘要係：\"''\$1''\"。", # only shown if there is an edit comment
 'revertpage'                  => '已經反轉由[[Special:Contributions/$2|$2]]（[[User talk:$2|對話]]）所寫嘅編輯到[[User:$1|$1]]嘅最後版本。', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '已經反轉由$1所寫嘅編輯；恢復到$2嘅最後版本。',
 'sessionfailure'              => '你嘅登入會話 (session) 好似有啲問題；為咗防止會話劫持，呢個操作已經取消。請撳「返轉頭」然後重新載入你嚟自嘅頁面，然後再試吓啦。',
 'protectlogpage'              => '保護日誌',
-'protectlogtext'              => '下面係一個保護同埋解除保護頁面嘅一覽表。睇吓[[Special:Protectedpages|保護頁面一覽]]去拎現時進行緊嘅頁面保護一覽。',
+'protectlogtext'              => '下面係一個保護同埋解除保護頁面嘅一覽表。睇吓[[Special:ProtectedPages|保護頁面一覽]]去拎現時進行緊嘅頁面保護一覽。',
 'protectedarticle'            => '已經保護 "[[$1]]"',
 'modifiedarticleprotection'   => '已經改咗 "[[$1]]" 嘅保護等級',
 'unprotectedarticle'          => '已經唔再保護 "[[$1]]"',
@@ -1725,7 +1725,7 @@
 
 # What links here
 'whatlinkshere'            => '有乜嘢連結來呢度',
-'whatlinkshere-title'      => '連到$1嘅頁',
+'whatlinkshere-title'      => '連到「$1」嘅頁',
 'whatlinkshere-page'       => '頁:',
 'linklistsub'              => '（連結一覽）',
 'linkshere'                => "呢啲頁連結到'''[[:$1]]'''：",
@@ -1777,7 +1777,7 @@
 'badipaddress'                    => '無效嘅IP地址',
 'blockipsuccesssub'               => '封鎖成功',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]]已經封鎖。<br />
-去[[Special:Ipblocklist|IP封鎖清單]]睇返封鎖名單。',
+去[[Special:IPBlockList|IP封鎖清單]]睇返封鎖名單。',
 'ipb-edit-dropdown'               => '改封鎖原因',
 'ipb-unblock-addr'                => '解封$1',
 'ipb-unblock'                     => '解封一個用戶名或IP地址',
@@ -1807,7 +1807,7 @@
 'autoblocker'                     => '已經自動封鎖，因為你嘅IP地址冇幾耐之前"[[User:$1|$1]]"使用過。$1\\嘅封鎖原因係: 「$2」',
 'blocklogpage'                    => '封鎖日誌',
 'blocklogentry'                   => '已封鎖[[$1]]，到期時間為$2 $3',
-'blocklogtext'                    => '呢個係封鎖同埋解封動作嘅日誌。自動封鎖IP地址嘅動作冇列出嚟。去[[Special:Ipblocklist|IP封鎖名單]]睇現時生效嘅封鎖名單',
+'blocklogtext'                    => '呢個係封鎖同埋解封動作嘅日誌。自動封鎖IP地址嘅動作冇列出嚟。去[[Special:IPBlockList|IP封鎖名單]]睇現時生效嘅封鎖名單',
 'unblocklogentry'                 => '已經解封$1',
 'block-log-flags-anononly'        => '只限匿名用戶',
 'block-log-flags-nocreate'        => '停用開新戶口',
@@ -1844,7 +1844,7 @@
 'lockdbsuccesssub'    => '資料庫鎖定已經成功',
 'unlockdbsuccesssub'  => '資料庫鎖定已成功移除',
 'lockdbsuccesstext'   => '資料庫現已鎖定。<br />
-請一定要記得喺完成系統維護工作之後[[Special:Unlockdb|解除資料庫嘅鎖定]]。',
+請一定要記得喺完成系統維護工作之後[[Special:UnlockDB|解除資料庫嘅鎖定]]。',
 'unlockdbsuccesstext' => '資料庫鎖定現已解除。',
 'lockfilenotwritable' => '資料庫封鎖檔案係唔可以寫入嘅。要鎖定或解鎖資料庫，係需要由網頁伺服器中寫入。',
 'databasenotlocked'   => '資料庫而家冇鎖到。',
@@ -1854,7 +1854,8 @@
 'move-page-legend'        => '搬頁',
 'movepagetext'            => "使用以下表格會將頁面改名，兼且連同搬埋佢嘅歷史過去。
 舊標題會變成指去新標題嘅跳轉頁。
-指去舊標題嘅連結唔會修改到；請務必要檢查吓有冇雙重跳轉或者死跳轉（嘅情況發生）。
+你可以自動噉更新指到原先標題嘅跳轉。
+如果你揀咗唔去做嘅話，請務必要檢查吓有冇[[Special:Doubledirects|雙重跳轉]]或者[[Special:BrokenRedirects|死跳轉]]（嘅情況發生）。
 你有責任確保啲連結依然指去佢哋應該指去嘅地方。
 
 注意如果已經有一個同個新名同名嘅頁面，噉呢個頁面係搬'''唔到'''嘅，除非嗰個同名嘅頁面係空嘅或者佢係一個跳轉頁，兼且要之前冇編輯過（冇編輯歷史）先得。噉即係講萬一你搞錯咗，你可以將呢個頁面改返去佢改之前噉，你唔可以覆蓋一個現有嘅頁面。
@@ -1867,8 +1868,6 @@
 
 喺呢啲情況下，需要嘅話你唯有手動搬同合併個頁面。",
 'movearticle'             => '搬頁:',
-'movenologin'             => '未登入',
-'movenologintext'         => '你要係註冊用戶而且要[[Special:Userlogin|登入]]咗先可以搬頁',
 'movenotallowed'          => '你響{{SITENAME}}度並無權限去搬版。',
 'newtitle'                => '到新標題:',
 'move-watch'              => '睇實呢一版',
@@ -1895,7 +1894,7 @@
 'delete_and_move'         => '刪除並移動',
 'delete_and_move_text'    => '==需要刪除==
 
-目標頁「[[$1]]」已經存在。你要唔要刪咗佢空個位出嚟畀個搬文動作？',
+目標頁「[[:$1]]」已經存在。你要唔要刪咗佢空個位出嚟畀個搬文動作？',
 'delete_and_move_confirm' => '好，刪咗嗰個頁面',
 'delete_and_move_reason'  => '已經刪咗嚟畀位畀個搬文動作',
 'selfmove'                => '原始標題同目的標題一樣；唔可以將個頁面搬返去自己度。',
@@ -1903,6 +1902,7 @@
 'imagenocrossnamespace'   => '唔可以搬檔案到非檔案空間名',
 'imagetypemismatch'       => '個新副檔名唔配佢嘅類型',
 'imageinvalidfilename'    => '個目標檔名係無效嘅',
+'fix-double-redirects'    => '更新指到原先標題嘅任何跳轉',
 
 # Export
 'export'            => '倒出/導出/匯出（Export）頁面',
@@ -1949,7 +1949,8 @@
 'import-interwiki-history'   => '複製呢一頁所有嘅歷史版本',
 'import-interwiki-submit'    => '倒入',
 'import-interwiki-namespace' => '轉移頁面到空間名：',
-'importtext'                 => '請由原 wiki 嘅 Special:Export 工具匯出成檔案，儲存喺你個磁碟度，然後再上載到呢度。',
+'importtext'                 => '請由原 wiki 嘅[[Special:Export|匯出工具]]匯出成檔案。
+儲存喺你個磁碟度，然後再上載到呢度。',
 'importstart'                => '倒入緊...',
 'import-revision-count'      => '$1次修訂',
 'importnopages'              => '冇頁面去倒入。',
@@ -2113,9 +2114,10 @@
 'markedaspatrollederror-noautopatrol' => '你係唔准去標示你自己嘅更改做已巡查嘅。',
 
 # Patrol log
-'patrol-log-page' => '巡查日誌',
-'patrol-log-line' => '已經標示咗$1/$2版做已經巡查嘅$3',
-'patrol-log-auto' => '(自動)',
+'patrol-log-page'   => '巡查日誌',
+'patrol-log-header' => '呢個係已經巡查過嘅日誌。',
+'patrol-log-line'   => '已經標示咗$1/$2版做已經巡查嘅$3',
+'patrol-log-auto'   => '(自動)',
 
 # Image deletion
 'deletedrevision'                 => '刪除咗$1嘅舊有修訂',
@@ -2144,10 +2146,10 @@
 'show-big-image'       => '完整解像度',
 'show-big-image-thumb' => '<small>呢個預覽嘅大細： $1 × $2 像素</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新檔案畫廊',
 'imagelisttext'         => "以下係'''$1'''個檔案$2排序嘅清單。",
-'newimages-summary'     => '呢個特別頁顯示最後上載咗嘅檔案',
+'newimages-summary'     => '呢個特別頁顯示最後上載咗嘅檔案。',
 'showhidebots'          => '($1 機械人)',
 'noimages'              => '冇嘢去睇。',
 'ilsubmit'              => '搵嘢',
@@ -2456,7 +2458,7 @@
 
 # External editor support
 'edit-externally'      => '用外面程式來改呢個檔案',
-'edit-externally-help' => '去[http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] 睇多啲資料',
+'edit-externally-help' => '去[http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] 睇多啲資料',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全部',
@@ -2479,7 +2481,7 @@
 郵件遞送員回應咗：$1',
 'confirmemail_invalid'     => '無效嘅確認碼。個代碼可能已經過咗期。',
 'confirmemail_needlogin'   => '你需要先$1去確認你嘅電郵地址。',
-'confirmemail_success'     => '你嘅電郵地址已經得到確認。你而家可以登入同盡情享受wiki啦。',
+'confirmemail_success'     => '你嘅電郵地址已經得到確認。你而家可以[[Special:UserLogin|登入]]同盡情享受wiki啦。',
 'confirmemail_loggedin'    => '你嘅電郵地址現已得到確認。',
 'confirmemail_error'       => '儲存你嘅確認資料嘅時候有小小嘢發生咗意外。',
 'confirmemail_subject'     => '{{SITENAME}}電郵地址確認',
@@ -2515,11 +2517,11 @@
 'deletedwhileediting' => '警告：你寫緊文嗰陣，有用戶洗咗呢版！',
 'confirmrecreate'     => "你寫緊文嗰陣，阿用戶 [[User:$1|$1]] ([[User talk:$1|talk]]) 洗咗呢一頁。以下係佢個理由：
 : ''$2''
-你係咪真係想重新整過呢版？",
+請確認你係咪真係想重新整過呢版。",
 'recreate'            => '重新整過',
 
 # HTML dump
-'redirectingto' => '跳轉去[[$1]]...',
+'redirectingto' => '跳轉去[[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '肯定要洗咗呢版個快取版本？
@@ -2613,7 +2615,7 @@
 'version-software-product'         => '產品',
 'version-software-version'         => '版本',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => '檔案路徑',
 'filepath-page'    => '檔名:',
 'filepath-submit'  => '搵路徑',
@@ -2651,7 +2653,7 @@
 'specialpages-group-redirects'   => '跳轉特別頁',
 'specialpages-group-spam'        => '反垃圾工具',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => '空白頁',
 'intentionallyblankpage' => '呢一版係留空咗嘅，用來作測速等用嘅',
 
Index: languages/messages/MessagesSd.php
===================================================================
--- languages/messages/MessagesSd.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSd.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,6 @@
  * @file
  *
  * @author Aursani
- * @author SPQRobin
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $rtl = true;
@@ -339,7 +336,7 @@
 'template-protected'     => '(تحفظيل)',
 'template-semiprotected' => '(نيم تحفظيل)',
 'nocreatetext'           => '{{SITENAME}} نوان صفحا سرجڻ جي روڪَ ڪئي آهي.
-توهان اڳي ئي موجود صفحن کي سنواري سگھو ٿا، يا [[Special:Userlogin|لاگ اِن ٿي يا نئون کاتو کولي سگھو ٿا]].',
+توهان اڳي ئي موجود صفحن کي سنواري سگھو ٿا، يا [[Special:UserLogin|لاگ اِن ٿي يا نئون کاتو کولي سگھو ٿا]].',
 'recreate-deleted-warn'  => "'''خبردار: توهان اهڙو صفحو نئين سر سرجي رهيا آهيو جيڪو اڳي ڊاٺو ويو آهي.'''
 
 بهتر ٿيندو ته توهان سوچي وٺو ته ڇا ان صفحي کي سنوارڻ بهتر ٿيندو.
@@ -441,7 +438,7 @@
 'uploadlogpage' => 'چاڙهه لاگ',
 'uploadedimage' => '"[[$1]]" چاڙهيو ويو',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'فائيل فهرست',
 
 # Image description page
@@ -531,7 +528,7 @@
 'log'                  => 'لاگس',
 'all-logs-page'        => 'سڀئي لاگس',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'سڀ صفحا',
 'alphaindexline' => '$1 کان $2',
 'nextpage'       => 'اڳيون صفحو ($1)',
@@ -553,7 +550,7 @@
 'mywatchlist'          => 'منهنجي ٽيٽ فهرست',
 'watchlistfor'         => "(براءِ '''$1''')",
 'addedwatch'           => 'ٽيٽ فھرست ۾ شامل ڪيو ويو.',
-'addedwatchtext'       => "صفحو بعنوان \"[[:\$1]]\" اوهان جي [[Special:Watchlist|ٽيٽ فهرست]] ۾ شامل ٿي ويو. استقبالي تبديليون هتي درج ٿينديون وينديون. اهو صفحو [[Special:Recentchanges|تازين تبديلين]] واري صفحي تي '''گهرن''' اکرن ۾ نمايان ڪري ڏيکاريو ويندو. جيڪڏهن اوهان اهو سڀ نه ٿا چاهيو ته '''اڻ ٽيٽيو''' تي ڪلڪ ڪريو.",
+'addedwatchtext'       => "صفحو بعنوان \"[[:\$1]]\" اوهان جي [[Special:Watchlist|ٽيٽ فهرست]] ۾ شامل ٿي ويو. استقبالي تبديليون هتي درج ٿينديون وينديون. اهو صفحو [[Special:RecentChanges|تازين تبديلين]] واري صفحي تي '''گهرن''' اکرن ۾ نمايان ڪري ڏيکاريو ويندو. جيڪڏهن اوهان اهو سڀ نه ٿا چاهيو ته '''اڻ ٽيٽيو''' تي ڪلڪ ڪريو.",
 'removedwatch'         => 'ٽيٽ فهرست مان هٽايو ويو',
 'removedwatchtext'     => 'صفحو بعنوان "[[:$1]]" توهان جي ٽيٽ فهرست مان هٽي چڪو آهي.',
 'watch'                => 'ٽيٽيو',
@@ -760,7 +757,7 @@
 'show-big-image'       => 'سنهو ترين تحلل',
 'show-big-image-thumb' => '<small>هن پيش نگاهه جي ماپ: $1 × $2 عڪسلون</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'نون فائيلن جي گيلري',
 'noimages'  => 'ڏسڻ لاءِ ڪجھه ناهي.',
 'bydate'    => 'تاريخوار',
@@ -817,7 +814,7 @@
 
 # External editor support
 'edit-externally'      => 'هيءُ فائيل ڪنهن خارجي منتقڪريءَ سان سنواريو',
-'edit-externally-help' => 'وڌيڪ معلومات لاءِ [http://meta.wikimedia.org/wiki/Help:External_editors هدايتون براءِ تنصيبڪاري] ڏسندا.',
+'edit-externally-help' => 'وڌيڪ معلومات لاءِ [http://www.mediawiki.org/wiki/Manual:External_editors هدايتون براءِ تنصيبڪاري] ڏسندا.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'سڀ',
Index: languages/messages/MessagesKn.php
===================================================================
--- languages/messages/MessagesKn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author Shushruth
- * @author Mana
- * @author לערי ריינהארט
- * @author Siebrand
+ * @author Ashwath Mattur <ashwatham@gmail.com> http://en.wikipedia.org/wiki/User:Ashwatham
  * @author HPN
- * @author Jon Harald Søby
  * @author Hari Prasad Nadig <hpnadig@gmail.com> http://en.wikipedia.org/wiki/User:Hpnadig
- * @author Ashwath Mattur <ashwatham@gmail.com> http://en.wikipedia.org/wiki/User:Ashwatham
- * @author SPQRobin
+ * @author Mana
+ * @author Shushruth
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -326,7 +323,7 @@
 'nosuchspecialpage' => 'ಆ ಹೆಸರಿನ ವಿಶೇಷ ಪುಟ ಇಲ್ಲ',
 'nospecialpagetext' => "<big>'''ನೀವು ಅಸ್ಥಿತ್ವದಲ್ಲಿರದ ವಿಶೇಷ ಪುಟವನ್ನು ಕೋರಿರುವಿರಿ.'''</big>
 
-ಅಸ್ಥಿತ್ವದಲ್ಲಿರುವ ವಿಶೇಷ ಪುಟಗಳ ಪಟ್ಟಿ [[Special:Specialpages|{{int:specialpages}}]] ಅಲ್ಲಿದೆ.",
+ಅಸ್ಥಿತ್ವದಲ್ಲಿರುವ ವಿಶೇಷ ಪುಟಗಳ ಪಟ್ಟಿ [[Special:SpecialPages|{{int:specialpages}}]] ಅಲ್ಲಿದೆ.",
 
 # General errors
 'error'                => 'ದೋಷ',
@@ -557,10 +554,6 @@
 'blockededitsource'         => "'''$1''' ಪುಟದಲ್ಲಿನ '''ನಿಮ್ಮ ಸಂಪಾದನೆಗಳ''' ಪಠ್ಯವನ್ನು ಕೆಳಗೆ ತೋರಲಾಗಿದೆ:",
 'whitelistedittitle'        => 'ಸಂಪಾದನೆ ಮಾಡಲು ಲಾಗ್ ಇನ್ ಆಗಿರಬೇಕು',
 'whitelistedittext'         => 'ಪುಟಗಳನ್ನು ಸಂಪಾದಿಸಲು ನೀವು $1 ಆಗಬೇಕು.',
-'whitelistreadtitle'        => 'ಓದಲು ಲಾಗ್ ಇನ್ ಆಗಿರಬೇಕು',
-'whitelistreadtext'         => 'ಪುಟಗಳನ್ನು ಓದಲು ನೀವು [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಬೇಕು.',
-'whitelistacctitle'         => 'ನಿಮಗೆ ಖಾತೆಯನ್ನು ತಗೆಯಲು ಅನುಮತಿ ಇಲ್ಲ',
-'whitelistacctext'          => '{{SITENAME}} ಅಲ್ಲಿ ಖಾತೆಗಳನ್ನು ಸೃಷ್ಟಿಸಲು ನೀವು [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಿರಬೇಕು ಮತ್ತು ಪ್ರಾಪ್ತ ಅನುಮತಿಗಳನ್ನು ಹೊಂದಿರಬೇಕು.',
 'confirmedittitle'          => 'ಸಂಪಾದನೆ ಮಾಡಲು ಇ-ಅಂಚೆ ಧೃಡೀಕರಣ ಬೇಕು',
 'confirmedittext'           => 'ಪುಟಗಳನ್ನು ಸಂಪಾದಿಸುವ ಮುನ್ನ ನೀವು ನಿಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸವನ್ನು ಧೃಡೀಕರಿಸಬೇಕು.
 ದಯವಿಟ್ಟು [[Special:Preferences|ಬಳಕೆದಾರ ಆಯ್ಕೆಗಳು]] ಪುಟದಲ್ಲಿ ತಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸವನ್ನು ನಮೂದಿಸಿ ಮತ್ತು ಧೃಡೀಕರಿಸಿ.',
@@ -579,7 +572,7 @@
 ಈ ಪುಟಕ್ಕೆ ನೀವು ತಪ್ಪಾಗಿ ಬಂದಿದ್ದಲ್ಲಿ ನಿಮ್ಮ ಬ್ರೌಸರ್‍ನ '''back''' ಬಟನ್ ಅನ್ನು ಒತ್ತಿ.",
 'anontalkpagetext'          => "----''ಇದು ಖಾತೆಯೊಂದನ್ನು ಹೊಂದಿರದ ಅನಾಮಧೇಯ ಬಳಕೆದಾರರೊಬ್ಬರ ಚರ್ಚೆ ಪುಟ. ಖಾತೆಯಿಲ್ಲದಿರುವುದರಿಂದ ಅವರನ್ನು ಗುರುತಿಸಲು ಅವರ IP ವಿಳಾಸವನ್ನು ಉಪಯೋಗಿಸುತ್ತಿದ್ದೇವೆ.
 ಈ ರೀತಿಯ IP ವಿಳಾಸವು ಅನೇಕ ಬಳಕೆದಾರರಿಂದ ಉಪಯೋಗದಲ್ಲಿರಬಹುದು.
-ನೀವು ಅನಾಮಧೇಯ ಬಳಕೆದಾರರಾಗಿದ್ದಲ್ಲಿ, ಹಾಗು ನಿಮಗೆ ಸಂಬಂಧವಿಲ್ಲದಂತ ಸಂದೇಶಗಳು ಬರುತ್ತಿವೆ ಎಂದು ಅನಿಸಿದರೆ, ಮುಂದೆ ಬೇರೆ ಅನಾಮಧೇಯ ಬಳಕೆದಾರರೊಂದಿಗೆ ತಪ್ಪಾಗಿ ಗುರುತಿಸಬಾರದೆಂದಿದ್ದರೆ ದಯವಿಟ್ಟು [[Special:Userlogin|ಸದಸ್ಯರಾಗಿ ಅಥವ ಲಾಗ್ ಇನ್ ಆಗಿ]].''",
+ನೀವು ಅನಾಮಧೇಯ ಬಳಕೆದಾರರಾಗಿದ್ದಲ್ಲಿ, ಹಾಗು ನಿಮಗೆ ಸಂಬಂಧವಿಲ್ಲದಂತ ಸಂದೇಶಗಳು ಬರುತ್ತಿವೆ ಎಂದು ಅನಿಸಿದರೆ, ಮುಂದೆ ಬೇರೆ ಅನಾಮಧೇಯ ಬಳಕೆದಾರರೊಂದಿಗೆ ತಪ್ಪಾಗಿ ಗುರುತಿಸಬಾರದೆಂದಿದ್ದರೆ ದಯವಿಟ್ಟು [[Special:UserLogin|ಸದಸ್ಯರಾಗಿ ಅಥವ ಲಾಗ್ ಇನ್ ಆಗಿ]].''",
 'noarticletext'             => 'ಈ ಪುಟದಲ್ಲಿ ಸದ್ಯಕ್ಕೆ ಏನೂ ಇಲ್ಲ, ನೀವು ಇತರ ಪುಟಗಳಲ್ಲಿ [[Special:Search/{{PAGENAME}}|ಈ ಹೆಸರನ್ನು ಹುಡುಕಬಹುದು]] ಅಥವ [{{fullurl:{{FULLPAGENAME}}|action=edit}} ಈ ಪುಟವನ್ನು ಸಂಪಾದಿಸಬಹುದು].',
 'userpage-userdoesnotexist' => 'ಬಳಕೆದಾರ ಖಾತೆ "$1" ದಾಖಲಾಗಿಲ್ಲ. ನೀವು ಇದೇ ಪುಟವನ್ನು ಸೃಷ್ಟಿ/ಸಂಪಾದನೆ ಮಾಡಬೇಕೆಂದಿರುವಿರಿ ಎಂದು ಖಾತ್ರಿ ಮಾಡಿಕೊಳ್ಳಿ.',
 'usercssjsyoucanpreview'    => "<strong>ಗಮನಿಸಿ:</strong> ಉಳಿಸುವ ಮುನ್ನ 'ಮುನ್ನೋಟ' ಗುಂಡಿಯನ್ನು ಉಪಯೋಗಿಸಿ ನಿಮ್ಮ ಹೊಸ CSS/JS ಅನ್ನು ಪ್ರಯೋಗ ಮಾಡಿ.",
@@ -623,7 +616,7 @@
 'hiddencategories'          => 'ಈ ಪುಟವು {{PLURAL:$1|೧ ಗುಪ್ತ ವರ್ಗಕ್ಕೆ|$1 ಗುಪ್ತ ವರ್ಗಗಳಿಗೆ}} ಸೇರಿದೆ:',
 'nocreatetitle'             => 'ಪುಟವನ್ನು ಸೃಷ್ಟಿಸುವುದನ್ನು ನಿಯಮಿಸಲಾಗಿದೆ',
 'nocreatetext'              => '{{SITENAME}} ಅಲ್ಲಿ ಹೊಸ ಪುಟಗಳನ್ನು ಸೃಷ್ಟಿಸಲು ಕೆಲವು ನಿಬಂಧನೆಗಳಿವೆ.
-ನೀವು ಹಿಂದಿರುಗಿ ಆಗಲೇ ಅಸ್ಥಿತ್ವದಲ್ಲಿರುವ ಪುಟವೊಂದನ್ನು ಸಂಪಾದಿಸಿ, ಅಥವ [[Special:Userlogin|ಲಾಗ್ ಇನ್ ಆಗಿ ಅಥವ ಹೊಸ ಸದಸ್ಯರಾಗಿ]].',
+ನೀವು ಹಿಂದಿರುಗಿ ಆಗಲೇ ಅಸ್ಥಿತ್ವದಲ್ಲಿರುವ ಪುಟವೊಂದನ್ನು ಸಂಪಾದಿಸಿ, ಅಥವ [[Special:UserLogin|ಲಾಗ್ ಇನ್ ಆಗಿ ಅಥವ ಹೊಸ ಸದಸ್ಯರಾಗಿ]].',
 'nocreate-loggedin'         => '{{SITENAME}} ಅಲ್ಲಿ ಹೊಸ ಪುಟಗಳನ್ನು ಸೃಷ್ಟಿಸಲು ನಿಮಗೆ ಅನುಮತಿ ಇಲ್ಲ.',
 'permissionserrors'         => 'ಅನುಮತಿಗಳ ದೋಷಗಳು',
 'permissionserrorstext'     => 'ನಿಮಗೆ ಅದನ್ನು ಮಾಡಲು ಅನುಮತಿ ಇಲ್ಲ, ಅದಕ್ಕೆ {{PLURAL:$1|ಕಾರಣ|ಕಾರಣಗಳು}}:',
@@ -784,7 +777,7 @@
 'mypreferences'            => 'ನನ್ನ ಪ್ರಾಶಸ್ತ್ಯಗಳು',
 'prefs-edits'              => 'ಸಂಪಾದನೆಗಳ ಸಂಖ್ಯೆ:',
 'prefsnologin'             => 'ಲಾಗಿನ್ ಆಗಿಲ್ಲ',
-'prefsnologintext'         => 'ಬಳಕೆದಾರ ಪ್ರಾಶಸ್ತ್ಯಗಳನ್ನು ಬದಲಾಯಿಸಲು ನೀವು [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಿರಬೇಕು.',
+'prefsnologintext'         => 'ಬಳಕೆದಾರ ಪ್ರಾಶಸ್ತ್ಯಗಳನ್ನು ಬದಲಾಯಿಸಲು ನೀವು [[Special:UserLogin|ಲಾಗ್ ಇನ್]] ಆಗಿರಬೇಕು.',
 'prefsreset'               => 'ಮುಂಚೆ ಉಳಿಸಲ್ಪಟ್ಟ ಮಾಹಿತಿಯಿಂದ ಪ್ರಾಶಸ್ತ್ಯಗಳನ್ನು reset ಮಾಡಲಾಯಿತು.',
 'qbsettings-none'          => 'ಯಾವುದೂ ಇಲ್ಲ',
 'qbsettings-floatingleft'  => 'ಎಡಕ್ಕ ತೇಲುತ್ತಿದೆ',
@@ -843,7 +836,7 @@
 'userrights-reason'           => 'ಬದಲಾವಣೆಗೆ ಕಾರಣ:',
 'userrights-no-interwiki'     => 'ಇತರ ವಿಕಿಗಳಲ್ಲಿ ನಿಮಗೆ ಬಳಕೆದಾರ ಹಕ್ಕುಗಳನ್ನು ಬದಲಾಯಿಸುವ ಅನುಮತಿಯಿಲ್ಲ.',
 'userrights-nodatabase'       => 'ಡೇಟಾಬೇಸ್ $1 ಅಸ್ಥಿತ್ವದಲ್ಲಿಲ್ಲ ಅಥವ ಸ್ಥಳೀಯವಾದುದಲ್ಲ.',
-'userrights-nologin'          => 'ಬಳಕೆದಾರ ಹಕ್ಕುಗಳನ್ನು ನೇಮಿಸಲು ನೀವು ನಿರ್ವಾಹಕ ಖಾತೆಯೊಂದಕ್ಕೆ [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಬೇಕು.',
+'userrights-nologin'          => 'ಬಳಕೆದಾರ ಹಕ್ಕುಗಳನ್ನು ನೇಮಿಸಲು ನೀವು ನಿರ್ವಾಹಕ ಖಾತೆಯೊಂದಕ್ಕೆ [[Special:UserLogin|ಲಾಗ್ ಇನ್]] ಆಗಬೇಕು.',
 'userrights-notallowed'       => 'ಬಳಕೆದಾರ ಹಕ್ಕುಗಳನ್ನು ನೇಮಿಸಲು ನಿಮ್ಮ ಖಾತೆಗೆ ಅನುಮತಿಯಿಲ್ಲ.',
 'userrights-changeable-col'   => 'ನೀವು ಬದಲಾಯಿಸಬಲ್ಲ ಗುಂಪುಗಳು',
 'userrights-unchangeable-col' => 'ನೀವು ಬದಲಾಯಿಸಲಾಗದಂತಹ ಗುಂಪುಗಳು',
@@ -920,7 +913,7 @@
 'reupload'                    => 'ಮರು-ಅಪ್ಲೋಡ್',
 'reuploaddesc'                => 'ಅಪ್ಲೋಡ್ ಅನ್ನು ನಿಲ್ಲಿಸಿ ಮತ್ತೆ ಅಪ್ಲೋಡ್ ವಕ್ಕಣೆಗೆ ಹಿಂದಿರುಗಿ',
 'uploadnologin'               => 'ಲಾಗಿನ್ ಆಗಿಲ್ಲ',
-'uploadnologintext'           => 'ಫೈಲುಗಳನ್ನು ಅಪ್ಲೋಡ್ ಮಾಡಲು ನೀವು [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಬೇಕು.',
+'uploadnologintext'           => 'ಫೈಲುಗಳನ್ನು ಅಪ್ಲೋಡ್ ಮಾಡಲು ನೀವು [[Special:UserLogin|ಲಾಗ್ ಇನ್]] ಆಗಬೇಕು.',
 'uploaderror'                 => 'ಅಪ್ಲೋಡ್ ದೋಷ',
 'upload-permitted'            => 'ಅಂಗೀಕೃತ ಫೈಲು ಮಾದರಿಗಳು: $1.',
 'upload-preferred'            => 'ಐಚ್ಛಿಕ ಫೈಲು ಮಾದರಿಗಳು: $1.',
@@ -1002,7 +995,7 @@
 'upload_source_url'  => ' (ಒಂದು ಮನ್ನಿತ, ಸಾರ್ವಜನಿಕವಾಗಿ ಎಟಕುವ URL)',
 'upload_source_file' => ' (ನಿಮ್ಮ ಗಣಕಯಂತ್ರದಲ್ಲಿರುವ ಒಂದು ಫೈಲು)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'ಈ ವಿಶೇಷ ಪುಟವು ಎಲ್ಲಾ ಅಪ್ಲೋಡ್ ಆಗಿರುವ ಫೈಲುಗಳನ್ನು ತೋರುತ್ತದೆ.
 ವಸ್ತುಸ್ಥಿತಿಯಲ್ಲಿ, ಕೊನೆಯದಾಗಿ ಅಪ್ಲೋಡ್ ಆಗಿರುವ ಫೈಲುಗಳು ಪಟ್ಟಿಯ ಪ್ರಾರಂಭದಲ್ಲಿ ಕಾಣುತ್ತವೆ.
 ಪಟ್ಟಿಯ ವಿಭಾಗದ ತಲೆಬರಹವನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿದರೆ ಪಟ್ಟಿಯ ರಚನೆ ಬದಲಾಗುತ್ತದೆ.',
@@ -1040,7 +1033,7 @@
 'filedelete'                  => '$1 ಅನ್ನು ಅಳಿಸು',
 'filedelete-legend'           => 'ಫೈಲನ್ನು ಅಳಿಸು',
 'filedelete-intro'            => "'''[[Media:$1|$1]]''' ಅನ್ನು ಅಳಿಸುತ್ತಿರುವಿರಿ.",
-'filedelete-intro-old'        => '<span class="plainlinks">ನೀವು \'\'\'[[Media:$1|$1]]\'\'\' ಮೀಡಿಯಾದ [$4 $3, $2] ಅಂದಿನಂತಹ ಆವೃತ್ತಿಯನ್ನು ಅಳಿಸುತ್ತಿರುವಿರಿ.</span>',
+'filedelete-intro-old'        => "ನೀವು '''[[Media:$1|$1]]''' ಮೀಡಿಯಾದ [$4 $3, $2] ಅಂದಿನಂತಹ ಆವೃತ್ತಿಯನ್ನು ಅಳಿಸುತ್ತಿರುವಿರಿ.",
 'filedelete-comment'          => 'ಅಳಿಸುವಿಕೆಗೆ ಕಾರಣ:',
 'filedelete-submit'           => 'ಅಳಿಸು',
 'filedelete-success'          => "'''$1''' ಅಳಿಸಲಾಗಿದೆ.",
@@ -1091,7 +1084,7 @@
 ಆ ಲೆಕ್ಕದಲ್ಲಿ ಸರಸರಿ ಪುಟಕ್ಕೆ '''\$5''' ಸಂಪಾದನೆಗಳು, ಮತ್ತು '''\$6''' ವೀಕ್ಷಣೆಗಳು ಆಗಿವೆ.
 
 ಈಗಿನ [http://www.mediawiki.org/wiki/Manual:Job_queue ಕೆಲಸದ ಸಾಲಿನ] ಉದ್ದ '''\$7'''.",
-'userstatstext'          => "ಇಲ್ಲಿ ಒಟ್ಟು {{PLURAL:$1|'''೧''' ನೊಂದಾಯಿತ [[Special:Listusers|ಬಳಕೆದಾರ]]|'''$1''' ನೊಂದಾಯಿತ [[Special:Listusers|ಬಳಕೆದಾರರು]]}} ಇದ್ದಾರೆ, ಮತ್ತು ಅವರಲ್ಲಿ {{PLURAL:$2|ಒಬ್ಬರಿಗೆ|'''$2''' ಬಳಕೆದಾರರಿಗೆ}} (ಅಂದರೆ '''$4%''') $5 ಹಕ್ಕುಗಳಿವೆ.",
+'userstatstext'          => "ಇಲ್ಲಿ ಒಟ್ಟು {{PLURAL:$1|'''೧''' ನೊಂದಾಯಿತ [[Special:ListUsers|ಬಳಕೆದಾರ]]|'''$1''' ನೊಂದಾಯಿತ [[Special:ListUsers|ಬಳಕೆದಾರರು]]}} ಇದ್ದಾರೆ, ಮತ್ತು ಅವರಲ್ಲಿ {{PLURAL:$2|ಒಬ್ಬರಿಗೆ|'''$2''' ಬಳಕೆದಾರರಿಗೆ}} (ಅಂದರೆ '''$4%''') $5 ಹಕ್ಕುಗಳಿವೆ.",
 'statistics-mostpopular' => 'ಅತ್ಯಂತ ಹೆಚ್ಚು ವೀಕ್ಷಿತ ಪುಟಗಳು',
 
 'disambiguations'     => 'ದ್ವಂದ್ವನಿವಾರಣಾ ಪುಟಗಳು',
@@ -1171,7 +1164,7 @@
 'logempty'             => 'ದಾಖಲೆಗಳಲ್ಲಿ ಇದಕ್ಕೆ ಹೋಲುವ ಯಾವ ವಸ್ತುವೂ ಇಲ್ಲ.',
 'log-title-wildcard'   => 'ಈ ಪದಗಳಿಂದ ಪ್ರಾರಂಭವಾಗುವ ಶೀರ್ಷಿಕೆಗಳನ್ನು ಹುಡುಕು',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'ಎಲ್ಲ ಪುಟಗಳು',
 'alphaindexline'    => '$1 ಇಂದ $2',
 'nextpage'          => 'ಮುಂದಿನ ಪುಟ ($1)',
@@ -1192,12 +1185,12 @@
 'special-categories-sort-count' => 'ಎಣಿಕೆಯ ಪ್ರಕಾರ ಜೋಡಿಸು',
 'special-categories-sort-abc'   => 'ಅಕ್ಷರಮಾಲೆಯ ಪ್ರಕಾರ ಜೋಡಿಸು',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'ಇದರಿಂದ ಪ್ರಾರಂಭವಾಗುವ ಬಳಕೆದಾರರನ್ನು ತೋರಿಸು:',
 'listusers-submit'   => 'ತೋರು',
 'listusers-noresult' => 'ಯಾವ ಬಳಕೆದಾರರೂ ಸಿಗಲಿಲ್ಲ.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'ಬಳಕೆದಾರ ಗುಂಪು ಹಕ್ಕುಗಳು',
 'listgrouprights-summary'  => 'ಈ ವಿಕಿಯಲ್ಲಿ ಪ್ರಚಲಿತವಾಗಿರುವ ಬಳಕೆದಾರ ಗುಂಪುಗಳು ಮತ್ತು ಆ ಗುಂಪುಗಳಿಗೆ ಅನ್ವಯಿಸುವ ಹಕ್ಕುಗಳು ಈ ಕೆಳಗಿನಂತಿದೆ.',
 'listgrouprights-group'    => 'ಗುಂಪು',
@@ -1206,7 +1199,7 @@
 
 # E-mail user
 'mailnologin'     => 'ಕಳುಹಿಸುವ ವಿಳಾಸ ಇಲ್ಲ',
-'mailnologintext' => 'ಇತರ ಬಳಕೆದಾರರಿಗೆ ಇ-ಅಂಚೆ ಕಳುಹಿಸಲು ನೀವು [[Special:Userlogin|ಲಾಗ್ ಇನ್]] ಆಗಿರಬೇಕು ಮತ್ತು ನಿಮ್ಮ [[Special:Preferences|ಪ್ರಾಶಸ್ತ್ಯಗಳ ಪುಟದಲ್ಲಿ]] ಒಂದು ಧೃಡೀಕೃತ ಇ-ಅಂಚೆ ವಿಳಾಸ ನೀಡಿರಬೇಕು.',
+'mailnologintext' => 'ಇತರ ಬಳಕೆದಾರರಿಗೆ ಇ-ಅಂಚೆ ಕಳುಹಿಸಲು ನೀವು [[Special:UserLogin|ಲಾಗ್ ಇನ್]] ಆಗಿರಬೇಕು ಮತ್ತು ನಿಮ್ಮ [[Special:Preferences|ಪ್ರಾಶಸ್ತ್ಯಗಳ ಪುಟದಲ್ಲಿ]] ಒಂದು ಧೃಡೀಕೃತ ಇ-ಅಂಚೆ ವಿಳಾಸ ನೀಡಿರಬೇಕು.',
 'emailuser'       => 'ಈ ಸದಸ್ಯರಿಗೆ ಇ-ಅಂಚೆ ಕಳಿಸಿ',
 'emailpage'       => 'ಸದಸ್ಯರಿಗೆ ವಿ-ಅ೦ಚೆ ಕಳಿಸಿ',
 'defemailsubject' => 'ವಿಕಿಪೀಡಿಯ ವಿ-ಅ೦ಚೆ',
@@ -1229,9 +1222,9 @@
 'nowatchlist'          => 'ನಿಮ್ಮ ವೀಕ್ಷಣಾಪಟ್ಟಿಯಲ್ಲಿ ಯಾವುದೇ ಪುಟಗಳಿಲ್ಲ',
 'watchlistanontext'    => 'ನಿಮ್ಮ ವೀಕ್ಷಣಾಪಟ್ಟಿಯನ್ನು ನೋಡಲು ಅಥವ ಸಂಪಾದಿಸಲು ದಯವಿಟ್ಟು $1 ಮಾಡಿ.',
 'watchnologin'         => 'ಲಾಗಿನ್ ಆಗಿಲ್ಲ',
-'watchnologintext'     => 'ನಿಮ್ಮ ವೀಕ್ಷಣಾಪಟ್ಟಿಯನ್ನು ಬದಲಾಯಿಸಲು ನೀವು [[Special:Userlogin|ಲಾಗಿನ್]] ಆಗಿರಬೇಕು.',
+'watchnologintext'     => 'ನಿಮ್ಮ ವೀಕ್ಷಣಾಪಟ್ಟಿಯನ್ನು ಬದಲಾಯಿಸಲು ನೀವು [[Special:UserLogin|ಲಾಗಿನ್]] ಆಗಿರಬೇಕು.',
 'addedwatch'           => 'ವೀಕ್ಷಣಾ ಪಟ್ಟಿಗೆ ಸೇರಿಸಲಾಯಿತು',
-'addedwatchtext'       => '"<nowiki>$1</nowiki>" ಪುಟವನ್ನು ನಿಮ್ಮ [[Special:Watchlist|ವೀಕ್ಷಣಾಪಟ್ಟಿಗೆ]] ಸೇರಿಸಲಾಗಿದೆ. ಈ ಪುಟದ ಮತ್ತು ಇದರ ಚರ್ಚಾ ಪುಟದ ಮುಂದಿನ ಬದಲಾವಣೆಗಳು ವೀಕ್ಷಣಾ ಪಟ್ಟಿಯಲ್ಲಿ ಕಾಣಸಿಗುತ್ತವೆ, ಮತ್ತು [[Special:Recentchanges|ಇತ್ತೀಚೆಗಿನ ಬದಲಾವಣೆಗಳ]] ಪಟ್ಟಿಯಲ್ಲಿ ಈ ಪುಟಗಳನ್ನು ದಪ್ಪಕ್ಷರಗಳಲ್ಲಿ ಕಾಣಿಸಲಾಗುವುದು.
+'addedwatchtext'       => '"<nowiki>$1</nowiki>" ಪುಟವನ್ನು ನಿಮ್ಮ [[Special:Watchlist|ವೀಕ್ಷಣಾಪಟ್ಟಿಗೆ]] ಸೇರಿಸಲಾಗಿದೆ. ಈ ಪುಟದ ಮತ್ತು ಇದರ ಚರ್ಚಾ ಪುಟದ ಮುಂದಿನ ಬದಲಾವಣೆಗಳು ವೀಕ್ಷಣಾ ಪಟ್ಟಿಯಲ್ಲಿ ಕಾಣಸಿಗುತ್ತವೆ, ಮತ್ತು [[Special:RecentChanges|ಇತ್ತೀಚೆಗಿನ ಬದಲಾವಣೆಗಳ]] ಪಟ್ಟಿಯಲ್ಲಿ ಈ ಪುಟಗಳನ್ನು ದಪ್ಪಕ್ಷರಗಳಲ್ಲಿ ಕಾಣಿಸಲಾಗುವುದು.
 
 <p>ಈ ಪುಟವನ್ನು ವೀಕ್ಷಣಾ ಪಟ್ಟಿಯಿಂದ ತೆಗೆಯಬಯಸಿದಲ್ಲಿ, ಮೇಲ್ಪಟ್ಟಿಯಲ್ಲಿ ಕಾಣಿಸಿರುವ "ವೀಕ್ಷಣಾ ಪುಟದಿಂದ ತೆಗೆ" ಅನ್ನು ಕ್ಲಿಕ್ಕಿಸಿ.',
 'removedwatch'         => 'ವೀಕ್ಷಣಾಪಟ್ಟಿಯಿಂದ ತೆಗೆಯಲಾಗಿದೆ',
@@ -1407,7 +1400,7 @@
 'ipbotherreason'           => 'ಇತರ/ಹೆಚ್ಚುವರಿ ಕಾರಣ:',
 'badipaddress'             => 'ಸರಿಯಿಲ್ಲದ IP ವಿಳಾಸ',
 'blockipsuccesssub'        => 'ತಡೆಹಿಡಿಯುವಿಕೆ ಯಶಸ್ವಿಯಾಯಿತು.',
-'blockipsuccesstext'       => '"$1" ಐಪಿ ಸಂಖ್ಯೆಯನ್ನು ತಡೆ ಹಿಡಿಯಲಾಗಿದೆ. <br /> ತಡೆಗಳನ್ನು ಪರಿಶೀಲಿಸಲು [[Special:Ipblocklist|ತಡೆ ಹಿಡಿಯಲಾಗಿರುವ ಐಪಿ ಸಂಖ್ಯೆಗಳ ಪಟ್ಟಿ]] ನೋಡಿ.',
+'blockipsuccesstext'       => '"$1" ಐಪಿ ಸಂಖ್ಯೆಯನ್ನು ತಡೆ ಹಿಡಿಯಲಾಗಿದೆ. <br /> ತಡೆಗಳನ್ನು ಪರಿಶೀಲಿಸಲು [[Special:IPBlockList|ತಡೆ ಹಿಡಿಯಲಾಗಿರುವ ಐಪಿ ಸಂಖ್ಯೆಗಳ ಪಟ್ಟಿ]] ನೋಡಿ.',
 'ipb-edit-dropdown'        => 'ತಡೆಹಿಡಿಯುವಿಕೆ ಕಾರಣಗಳನ್ನು ಸಂಪಾದಿಸು',
 'ipb-unblock-addr'         => '$1 ಖಾತೆಯ ತಡೆಯನ್ನು ತೆಗೆ',
 'ipb-unblock'              => 'ಬಳಕೆದಾರರ ಅಥವ IP ವಿಳಾಸದ ತಡೆಯನ್ನು ತೆಗೆ',
@@ -1475,8 +1468,6 @@
 
 ಈ ಪ್ರಸಂಗಗಳಲ್ಲಿ ನೀವು ಸ್ವತಃ ಚರ್ಚೆ ಪುಟವನ್ನು ಸ್ಥಳಾಂತರಿಸಬೇಕು ಅಥವ ಒಂದುಗೂಡಿಸಬೇಕು.",
 'movearticle'             => 'ಪುಟವನ್ನು ಸ್ಥಳಾಂತರಿಸಿ',
-'movenologin'             => 'ಲಾಗಿನ್ ಆಗಿಲ್ಲ',
-'movenologintext'         => 'ಪುಟವನ್ನು ಸ್ಥಳಾಂತರಿಸಲು ನೀವು ನೋಂದಾಯಿತ ಸದಸ್ಯರಾಗಿದ್ದು [[Special:Userlogin|ಲಾಗಿನ್]] ಆಗಿರಬೇಕು.',
 'movenotallowed'          => 'ನಿಮಗೆ {{SITENAME}} ಅಲ್ಲಿ ಪುಟಗಳನ್ನು ಸ್ಥಳಾಂತರಿಸುವ ಅನುಮತಿ ಇಲ್ಲ.',
 'newtitle'                => 'ಈ ಹೊಸ ಶೀರ್ಷಿಕೆಗೆ:',
 'move-watch'              => 'ಈ ಪುಟವನ್ನು ವೀಕ್ಷಿಸು',
@@ -1497,7 +1488,7 @@
 'revertmove'              => 'ಹಿಂದಿನಂತಾಗಿಸು',
 'delete_and_move'         => 'ಅಳಿಸು ಮತ್ತು ಸ್ಥಳಾಂತರಿಸು',
 'delete_and_move_text'    => '==ಅಳಿಸುವಿಕೆ ಬೇಕಾಗಿದೆ==
-ಸ್ಥಳಾಂತರಿಬೇಕೆಂದಿರುವ ಪುಟ "[[$1]]" ಆಗಲೆ ಅಸ್ಥಿತ್ವದಲ್ಲಿ ಇದೆ.
+ಸ್ಥಳಾಂತರಿಬೇಕೆಂದಿರುವ ಪುಟ "[[:$1]]" ಆಗಲೆ ಅಸ್ಥಿತ್ವದಲ್ಲಿ ಇದೆ.
 ಸ್ಥಳಾಂತರಿಕೆಗೆ ಜಾಗ ಮಾಡಲು ಆ ಪುಟವನ್ನು ಅಳಿಸಬೇಕೆ?',
 'delete_and_move_confirm' => 'ಹೌದು, ಪುಟವನ್ನು ಅಳಿಸಿ',
 'delete_and_move_reason'  => 'ಸ್ಥಳಾಂತರಿಕೆಗೆ ಜಾಗ ಮಾಡಲು ಪುಟವನ್ನು ಅಳಿಸಲಾಯಿತು',
@@ -1641,7 +1632,7 @@
 'show-big-image'       => 'ಅತಿ ಹೆಚ್ಚು ವಿವರವಾದ ನೋಟ',
 'show-big-image-thumb' => '<small>ಈ ಮುನ್ನೋಟದ ಅಳತೆ: $1 × $2 ಚಿತ್ರಬಿಂದುಗಳು</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'ಹೊಸ ಫೈಲುಗಳ ಪ್ರದರ್ಶನ',
 'imagelisttext'         => "ಕೆಳಗೆ ಇರುವುದು '''$1''' {{PLURAL:$1|ಫೈಲಿನ|ಫೈಲುಗಳ}} ಪಟ್ಟಿ, $2 ಏರ್ಪಾಟಾಗಿದೆ.",
 'newimages-summary'     => 'ಈ ವಿಶೇಷ ಪುಟವು ಕೊನೆಯದಾಗಿ ಅಪ್ಲೋಡ್ ಆಗಿರುವ ಫೈಲುಗಳನ್ನು ತೋರುತ್ತದೆ',
@@ -1748,7 +1739,7 @@
 
 # External editor support
 'edit-externally'      => 'ಬಾಹ್ಯ ತಂತ್ರಾಂಶವನ್ನು ಉಪಯೋಗಿಸಿ ಇದನ್ನು ಸಂಪಾದಿಸಿ',
-'edit-externally-help' => 'ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗೆ [http://meta.wikimedia.org/wiki/Help:External_editors ಸ್ಥಾಪನೆಯ ನಿರ್ದೇಶಗಳನ್ನು] ನೋಡಿ.',
+'edit-externally-help' => 'ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗೆ [http://www.mediawiki.org/wiki/Manual:External_editors ಸ್ಥಾಪನೆಯ ನಿರ್ದೇಶಗಳನ್ನು] ನೋಡಿ.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ಎಲ್ಲಾ',
@@ -1808,7 +1799,7 @@
 'recreate'            => 'ಪುನಃ ಸೃಷ್ಟಿಸು',
 
 # HTML dump
-'redirectingto' => '[[$1]] ಪುಟಕ್ಕೆ ಪುನರ್ನಿರ್ದೇಶಿತವಾಗುತ್ತಿದೆ...',
+'redirectingto' => '[[:$1]] ಪುಟಕ್ಕೆ ಪುನರ್ನಿರ್ದೇಶಿತವಾಗುತ್ತಿದೆ...',
 
 # AJAX search
 'searchcontaining' => "''$1'' ಅನ್ನು ಹೊಂದಿರುವ ಪುಟಗಳನ್ನು ಹುಡುಕು.",
@@ -1871,7 +1862,7 @@
 'version-software'         => 'ಸಂಸ್ಥಾಪಿಸಲಾಗಿರುವ ತಂತ್ರಾಂಶ',
 'version-software-version' => 'ಆವೃತ್ತಿ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'      => 'ಫೈಲಿನ ಮಾರ್ಗ',
 'filepath-page' => 'ಫೈಲು:',
 
Index: languages/messages/MessagesMyv.php
===================================================================
--- languages/messages/MessagesMyv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMyv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,13 @@
  * @ingroup Language
  * @file
  *
+ * @author Amdf
  * @author Botuzhaleny-sodamo
  * @author Erzianj jurnalist
- * @author Amdf
- * @author Siebrand
  * @author MF-Warburg
- * @author Tupikovs
+ * @author Spacebirdy
  * @author Sura
- * @author M.M.S.
- * @author Jon Harald Søby
+ * @author Tupikovs
  */
 
 $messages = array(
@@ -285,7 +283,9 @@
 'error'                => 'Ильведькс',
 'databaseerror'        => 'Датабазань ильведькс',
 'nodb'                 => '$1 датабазась эзь кочкаво',
+'laggedslavemode'      => 'Ванок: Кизды, лопасонть материалось таштомсь.',
 'readonly'             => 'Датабазась панжома экшсэ',
+'enterlockreason'      => 'Сёрмадт мейс сёлгамс эряви, ды ёвтак, зярдо таго арьсят панжови',
 'missingarticle-rev'   => '(лиякстомтома#: $1)',
 'internalerror'        => 'Потмонь ильведькс',
 'internalerror_info'   => 'Потмонь ильведькс: $1',
@@ -435,9 +435,6 @@
 'blockedoriginalsource'            => "'''$1''' -нть лисьмапрясь ало неяви:",
 'whitelistedittitle'               => 'Витнемань-петнемань кисэ эряви совамо лем',
 'whitelistedittext'                => 'Лопанть витнемс - петнемс эряви $1.',
-'whitelistreadtitle'               => 'Ловномань кисэ эряви совамо лем',
-'whitelistreadtext'                => 'Лопань ловномга сави тенть [[Special:Userlogin|совамс]].',
-'whitelistacctitle'                => 'Тонеть а мерить теемс-шкамс совамо тарка',
 'nosuchsectiontitle'               => 'Истямо явкс арась',
 'loginreqtitle'                    => 'Совамс эряви',
 'loginreqlink'                     => 'совамс',
@@ -470,7 +467,7 @@
 'template-protected'               => '(ванстозь)',
 'template-semiprotected'           => '(пельс ванстозь)',
 'nocreatetitle'                    => 'Лопань теемась аволь певтеме',
-'nocreatetext'                     => 'Те {{SITENAME}} лопасонть пирязь од лопань теемась. Тонь ули мелеть велявтомс удалов ды  питнемензе-витнемензе улиця лопанть, али [[Special:Userlogin|совамс али теемс од совама]].',
+'nocreatetext'                     => 'Те {{SITENAME}} лопасонть пирязь од лопань теемась. Тонь ули мелеть велявтомс удалов ды  питнемензе-витнемензе улиця лопанть, али [[Special:UserLogin|совамс али теемс од совама]].',
 'nocreate-loggedin'                => 'Тонеть а мерить теемс-шкамс од лопат "{{SITENAME}}" сайтасонть.',
 'permissionserrorstext'            => 'Тонеть а мерить теемс тень, вана {{PLURAL:$1|тувталось|тувталтнэ}}:',
 'permissionserrorstext-withaction' => 'Тонеть а мерить теемс $2, {{PLURAL:$1|тувталось|тувталтнэ}} вана:',
@@ -525,6 +522,7 @@
 'revdelete-hide-user'    => 'Кекшемс витницянть-петницянть теиця лемензэ/IP-нзэ',
 'revdelete-hide-image'   => 'Кекшемс мезе файлатнесэ',
 'revdelete-log'          => 'Логто ёвтнема:',
+'revdelete-logentry'     => '[[$1]]-нть лиякстомтоманть неявомазо полавтовсь',
 'revdel-restore'         => 'Полавтомс неявомачынзэ',
 'pagehist'               => 'Лопанть икелькс умазо',
 'deletedhist'            => 'Нардань икелькс умазо',
@@ -756,7 +754,7 @@
 'nolicense'          => 'Лицензия арась',
 'upload_source_file' => ' (арси машинасот файла)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'файл',
 'imagelist'      => 'Файлат-мезть',
 'imagelist_date' => 'Чи',
@@ -904,7 +902,7 @@
 'all-logs-page'        => 'Веси совамотне-кемекстамотьне',
 'log-search-submit'    => 'Адя',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Весе лопат',
 'alphaindexline' => '$1-сто  $2-нтень',
 'nextpage'       => 'Сы лопа ($1)',
@@ -923,11 +921,11 @@
 'special-categories-sort-count' => 'аравтомс цётонь коряс',
 'special-categories-sort-abc'   => 'аравтомс альфавитэнь коряс',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Невтемс',
 'listusers-noresult' => 'Совицязо а муеви',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'   => 'Куро',
 'listgrouprights-rights'  => 'Видечытне',
 'listgrouprights-members' => '(куронь ломаньть)',
@@ -952,7 +950,7 @@
 'watchnologin'         => 'Апак сова',
 'addedwatch'           => 'Топавтозь ванома потмоксоньте',
 'addedwatchtext'       => 'Лопась «[[:$1]]» совавтозь [[Special:Watchlist|ванома потмозот]].
-Седе тов те лопасонть ды мартонзо сюлмавозь кортнема лопасонть теезь витьнематне тешкставтовить те потмонтень, истяжо кармить кикстазь те лопасонть[[Special:Recentchanges|потмо од витнематне]], истя седе шождасто сынь неявить.',
+Седе тов те лопасонть ды мартонзо сюлмавозь кортнема лопасонть теезь витьнематне тешкставтовить те потмонтень, истяжо кармить кикстазь те лопасонть[[Special:RecentChanges|потмо од витнематне]], истя седе шождасто сынь неявить.',
 'removedwatch'         => 'Нардазь ванома потмокстонть',
 'removedwatchtext'     => 'Лопась «[[:$1]]» ульнесь нардазь тынк ванома потмокстонть.',
 'watch'                => 'Ванстнемс',
@@ -1101,7 +1099,7 @@
 'ipbreasonotherlist'      => 'Лия тувтал',
 'ipbsubmit'               => 'Озавтомс те теицянть саймес',
 'ipbother'                => 'Лия шка:',
-'ipboptions'              => '2 hours:2 част,1 day:1 чи,3 days:3 чить,1 week:1 тарго,2 weeks:2 таргот,1 month:1 ков,3 months:3 ковт,6 months:6 ковт,1 year:1 ие,infinite:певтеме', # display1:time1,display2:time2,...
+'ipboptions'              => '2 част:2 hours,1 чи:1 day,3 чить:3 days,1 тарго:1 week,2 таргот:2 weeks,1 ков:1 month,3 ковт:3 months,6 ковт:6 months,1 ие:1 year,певтеме:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'          => 'лия',
 'ipbotherreason'          => 'Лия/поладкс тувтал:',
 'badipaddress'            => 'Амаштовикс IP адрес',
@@ -1156,7 +1154,6 @@
 
 Зярдо истят тевтне, сави тонстеть лопатнень кучомс-сюлмамс, кедьсэ.",
 'movearticle'             => 'Одов лемдемс лопанть:',
-'movenologin'             => 'Апак сова',
 'newtitle'                => 'Од леменьтэ:',
 'move-watch'              => 'Ваномс лопанть',
 'movepagebtn'             => 'Печтевтемс лопанть',
@@ -1292,7 +1289,7 @@
 'show-big-image'       => 'Пешксе теевксесь',
 'show-big-image-thumb' => '<small>Покшолма икелев ваноманть: $1 × $2 пиксэлт</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'    => 'Од файлатьнень галлереясь',
 'showhidebots' => '($1 ботт)',
 'noimages'     => 'Арась мезе ваномс.',
@@ -1408,7 +1405,7 @@
 
 # External editor support
 'edit-externally'      => 'Витнемс-петнемс те файланть, тевс нолдазь ушо ёнксонь программанть',
-'edit-externally-help' => 'Вант [http://meta.wikimedia.org/wiki/Help:External_editors аравтома инструкциятнень ] седе ламо информациянть кис.',
+'edit-externally-help' => 'Вант [http://www.mediawiki.org/wiki/Manual:External_editors аравтома инструкциятнень ] седе ламо информациянть кис.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'весе',
@@ -1467,7 +1464,7 @@
 'version-license'          => 'Лицензия',
 'version-software-version' => 'Верзия',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Файлас яннэ',
 'filepath-page'   => 'Файл:',
 'filepath-submit' => 'Яннэ',
Index: languages/messages/MessagesSl.php
===================================================================
--- languages/messages/MessagesSl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author XJamRastafire
  * @author romanm
  */
@@ -285,7 +284,7 @@
 'nosuchaction'      => 'Tako dejanje ne obstaja',
 'nosuchactiontext'  => 'Dejanja, ki ga je označil spletni naslov, wiki ne prepozna.',
 'nosuchspecialpage' => 'Posebna stran, ki ste jo zahtevali, ne obstaja',
-'nospecialpagetext' => 'Posebne strani, ki ste jo zahtevali, programje {{GRAMMAR:rodilnik|{{SITENAME}}}} ne prepozna ali pa nimate dostopa do nje. Seznam vseh prepoznanih posebnih strani je na razpolago na strani [[Special:Specialpages]].',
+'nospecialpagetext' => 'Posebne strani, ki ste jo zahtevali, programje {{GRAMMAR:rodilnik|{{SITENAME}}}} ne prepozna ali pa nimate dostopa do nje. Seznam vseh prepoznanih posebnih strani je na razpolago na strani [[Special:SpecialPages]].',
 
 # General errors
 'error'                => 'Napaka',
@@ -361,7 +360,7 @@
 'yourrealname'               => 'Vaše pravo ime*',
 'yourlanguage'               => 'Jezik vmesnika:',
 'yourvariant'                => 'Jezikovna različica',
-'yournick'                   => 'Podpis (uporabite ~~~~):',
+'yournick'                   => 'Podpis',
 'badsig'                     => 'Neveljaven surovi podpis; preverite oznake HTML.',
 'email'                      => 'E-pošta',
 'prefs-help-realname'        => '<!-- ¹ Pravo ime (neobvezno): če se odločite, da ga boste navedli, bo uporabljeno za priznavanje vašega dela. -->',
@@ -452,10 +451,6 @@
 'blockededitsource'         => "Besedilo '''vaših urejanj''' strani '''$1''' je prikazano spodaj:",
 'whitelistedittitle'        => 'Za urejanje se morate prijaviti',
 'whitelistedittext'         => 'Za urejanje strani se $1.',
-'whitelistreadtitle'        => 'Za ogled se je treba prijaviti',
-'whitelistreadtext'         => 'Za ogled strani se morate [[Special:Userlogin|prijaviti]]',
-'whitelistacctitle'         => 'Za izdelavo uporabniškega računa nimate dovoljenja.',
-'whitelistacctext'          => 'V tem wikiju lahko račune odpirajo le [[Special:Userlogin|prijavljeni]] uporabniki z ustreznimi uporabniškimi pravicami.',
 'confirmedittitle'          => 'Za urejanje je potrebna e-poštna potrditev',
 'confirmedittext'           => 'Pred urejanjem strani morate potrditi svoj e-poštni naslov. Prosimo, da ga z uporabo [[Special:Preferences|uporabniških nastavitev]] vpišete in potrdite.',
 'loginreqtitle'             => 'Treba se je prijaviti',
@@ -468,7 +463,7 @@
 Da bi stran ustvarili, vnesite v spodnji obrazec besedilo
 (za več informacij glej [[{{MediaWiki:Helppage}}|pomoč]]).
 Če ste sem prišli po pomoti, v svojem brskalniku kliknite gumb ''Nazaj''.",
-'anontalkpagetext'          => "---- ''To je pogovorna stran za nepodpisanega uporabnika, ki še ni ustvaril računa ali, ki ga ne uporablja. Zaradi tega moramo uporabiti števčen IP address za njegovo/njeno ugotavljanje istovetnosti. Takšen IP naslov si lahko deli več uporabnikov. Če ste nepodpisan uporabnik in če menite, da so nepomembne pripombe namenjene vam, prosimo [[Special:Userlogin|ustvarite račun ali pa se vpišite]], da preprečite naslednje zmede z drugimi nepodpisanimi uporabniki.''",
+'anontalkpagetext'          => "---- ''To je pogovorna stran za nepodpisanega uporabnika, ki še ni ustvaril računa ali, ki ga ne uporablja. Zaradi tega moramo uporabiti števčen IP address za njegovo/njeno ugotavljanje istovetnosti. Takšen IP naslov si lahko deli več uporabnikov. Če ste nepodpisan uporabnik in če menite, da so nepomembne pripombe namenjene vam, prosimo [[Special:UserLogin|ustvarite račun ali pa se vpišite]], da preprečite naslednje zmede z drugimi nepodpisanimi uporabniki.''",
 'noarticletext'             => 'Na tej strani ni trenutno nobenega besedila. Naslov strani lahko poskusite [[Special:Search/{{PAGENAME}}|poiskati]] na drugih straneh ali pa [{{fullurl:{{FULLPAGENAME}}|action=edit}} stran uredite].',
 'clearyourcache'            => "'''Opomba:''' Da bodo spremembe prišle do veljave, po shranitvi izpraznite predpomnilnik svojega brskalnika: '''Mozilla/Safari:''' držite ''Shift'' in kliknite ''Reload'' (ali pritisnite ''Ctrl-Shift-R''), '''Internet Explorer:''' ''Ctrl-F5'', '''Opera/Konqueror:''' ''F5''.",
 'usercssjsyoucanpreview'    => "<strong>Nasvet:</strong> Za preizkušanje svojega novega CSS/JS pred shranjevanjem uporabite gumb ''Prikaži predogled''.",
@@ -512,7 +507,7 @@
 'templatesused'             => 'Na strani uporabljene predloge:',
 'edittools'                 => '<!-- To besedilo bo prikazano pod urejevalnim poljem in poljem za nalaganje. -->',
 'nocreatetitle'             => 'Članka nisem našel',
-'nocreatetext'              => "Članka s tem naslovom - '''{{PAGENAME}}''' - še nimamo, lahko pa ga [[Special:Search/{{PAGENAME}}|poskusite poiskati]] ali pa se [[Special:Userlogin|prijavite]] in ga ustvarite.",
+'nocreatetext'              => "Članka s tem naslovom - '''{{PAGENAME}}''' - še nimamo, lahko pa ga [[Special:Search/{{PAGENAME}}|poskusite poiskati]] ali pa se [[Special:UserLogin|prijavite]] in ga ustvarite.",
 
 # History pages
 'nohistory'           => 'Stran nima zgodovine urejanja.',
@@ -591,7 +586,7 @@
 # Preferences page
 'preferences'              => 'Nastavitve',
 'prefsnologin'             => 'Niste prijavljeni',
-'prefsnologintext'         => 'Za spreminjanje uporabniških nastavitev se [[Special:Userlogin|prijavite]].',
+'prefsnologintext'         => 'Za spreminjanje uporabniških nastavitev se [[Special:UserLogin|prijavite]].',
 'prefsreset'               => 'Nastavitve so ponastavljene.',
 'qbsettings'               => 'Nastavitve hitre vrstice',
 'qbsettings-none'          => 'Brez',
@@ -705,11 +700,11 @@
 'reupload'                    => 'Naloži drugo',
 'reuploaddesc'                => 'Vrnitev na obrazec za nalaganje.',
 'uploadnologin'               => 'Niste prijavljeni',
-'uploadnologintext'           => 'Za nalaganje datotek se [[Special:Userlogin|prijavite]].',
+'uploadnologintext'           => 'Za nalaganje datotek se [[Special:UserLogin|prijavite]].',
 'upload_directory_read_only'  => 'V mapo za nalaganje datotek ($1) spletni strežnik ne more pisati.',
 'uploaderror'                 => 'Napaka',
 'uploadtext'                  => "Spodnji obrazec lahko uporabite za nalaganje datotek;
-za ogled ali iskanje že naloženih pojdite na [[Special:Imagelist|seznam naloženih datotek]].
+za ogled ali iskanje že naloženih pojdite na [[Special:ImageList|seznam naloženih datotek]].
 Naložitve in izbrisi so zapisani tudi v [[Special:Log/upload|dnevniku nalaganja]].
 
 Datoteko lahko na želeno stran vključite z naslednjo skladnjo
@@ -752,7 +747,7 @@
 'license'   => 'Dovoljenje:',
 'nolicense' => 'Nobeno (opomba: datoteka bo morda izbrisana)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Seznam datotek',
 
 # Image description page
@@ -858,7 +853,7 @@
 'alllogstext'          => 'Združeno so prikazani dnevniki sprememb uporabniških pravic, preimenovanj uporabnikov, nalaganja predstavnostnih datotek, prestavljanja in zaščite strani, brisanja, registracij uporabnikov, sprememb položaja botov ter blokiranja in deblokiranja uporabnikov. Pogled lahko zožite z izbiro dnevnika, uporabniškega imena ali strani. Vedite, da polje »Uporabnik« razlikuje med malimi in velikimi črkami.',
 'logempty'             => 'O tej strani ni v dnevniku ničesar.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Vse strani',
 'alphaindexline'    => '$1 do $2',
 'nextpage'          => 'Naslednja stran ($1)',
@@ -877,7 +872,7 @@
 
 # E-mail user
 'mailnologin'     => 'Manjka naslov pošiljatelja',
-'mailnologintext' => "Za pošiljanje pošte se [[Special:Userlogin|prijavite]] in v [[Special:Preferences|nastavitvah]] vpišite veljaven '''overjen''' e-poštni naslov.",
+'mailnologintext' => "Za pošiljanje pošte se [[Special:UserLogin|prijavite]] in v [[Special:Preferences|nastavitvah]] vpišite veljaven '''overjen''' e-poštni naslov.",
 'emailuser'       => 'Pošlji uporabniku e-pismo',
 'emailpage'       => 'Pošlji uporabniku e-pismo',
 'emailpagetext'   => "S spodnjim obrazcem lahko uporabniku pošljete e-poštno sporočilo.
@@ -899,9 +894,9 @@
 'mywatchlist'          => 'Spisek nadzorov',
 'nowatchlist'          => 'Vaš spisek nadzorov je prazen.',
 'watchnologin'         => 'Niste prijavljeni',
-'watchnologintext'     => 'Za urejanje spiska nadzorov se [[Special:Userlogin|prijavite]].',
+'watchnologintext'     => 'Za urejanje spiska nadzorov se [[Special:UserLogin|prijavite]].',
 'addedwatch'           => 'Dodano na spisek nadzorov',
-'addedwatchtext'       => "Stran »'''<nowiki>$1</nowiki>'''« je bila dodana na vaš [[Special:Watchlist|spisek nadzorov]], kjer bodo odslej navedene njene morebitne spremembe in spremembe pripadajoče pogovorne strani. Za lažjo izbiro bodo tudi v [[Special:Recentchanges|seznamu zadnjih sprememb]] prikazane <b>krepko</b>. Če jo želite odstraniti s spiska, kliknite zavihek »Prenehaj opazovati«.",
+'addedwatchtext'       => "Stran »'''<nowiki>$1</nowiki>'''« je bila dodana na vaš [[Special:Watchlist|spisek nadzorov]], kjer bodo odslej navedene njene morebitne spremembe in spremembe pripadajoče pogovorne strani. Za lažjo izbiro bodo tudi v [[Special:RecentChanges|seznamu zadnjih sprememb]] prikazane <b>krepko</b>. Če jo želite odstraniti s spiska, kliknite zavihek »Prenehaj opazovati«.",
 'removedwatch'         => 'Odstranjena s spiska nadzorov',
 'removedwatchtext'     => 'Stran »<nowiki>$1</nowiki>« je odstranjena z vašega spiska nadzorov.',
 'watch'                => 'Opazuj',
@@ -1059,7 +1054,7 @@
 'badipaddress'                => 'Neveljaven IP-naslov ali uporabniško ime.',
 'blockipsuccesssub'           => 'Blokiranje je uspelo',
 'blockipsuccesstext'          => 'IP-naslov ali uporabniški račun »[[Special:Contributions/$1|$1]]« je blokiran.<br />
-Preglejte [[Special:Ipblocklist|seznam blokiranih IP-naslovov]].',
+Preglejte [[Special:IPBlockList|seznam blokiranih IP-naslovov]].',
 'unblockip'                   => 'Omogočite urejanje IP-naslovu',
 'unblockiptext'               => 'Z naslednjim obrazcem lahko obnovite možnost urejanja z blokiranega IP-naslova ali uporabniškega računa.',
 'ipusubmit'                   => 'Deblokiraj naslov',
@@ -1073,7 +1068,7 @@
 'autoblocker'                 => 'Ker si delite IP-naslov z »$1«, vam je urejanje samodejno onemogočeno. Razlog: »$2«.',
 'blocklogpage'                => 'Dnevnik blokiranja',
 'blocklogentry'               => 'uporabnika »$1« sem blokiral(-a) za $2',
-'blocklogtext'                => 'Prikazan je dnevnik blokiranja in deblokiranja uporabnikov. Samodejno blokirani IP-naslovi niso navedeni. Trenutno veljavna blokiranja so navedena na [[Special:Ipblocklist|seznamu blokiranih IP-naslovov]].',
+'blocklogtext'                => 'Prikazan je dnevnik blokiranja in deblokiranja uporabnikov. Samodejno blokirani IP-naslovi niso navedeni. Trenutno veljavna blokiranja so navedena na [[Special:IPBlockList|seznamu blokiranih IP-naslovov]].',
 'unblocklogentry'             => 'je deblokiral(-a) »$1«',
 'range_block_disabled'        => 'Možnost administratorjev za blokiranje urejanja IP-razponom je onemogočena.',
 'ipb_expiry_invalid'          => 'Neveljaven čas preteka',
@@ -1117,8 +1112,6 @@
 
 Če je tako, boste morali pogovorno stran, če želite, prestaviti ali povezati ročno. Če tega ne morete storiti, predlagajte prestavitev na strani [[Project:Želene prestavitve]], vsekakor pa tega '''''ne''''' počnite s preprostim izrezanjem in prilepljenjem vsebine, saj bi tako pokvarili zgodovino urejanja strani.",
 'movearticle'             => 'Prestavi stran',
-'movenologin'             => 'Niste prijavljeni',
-'movenologintext'         => 'Za prestavljanje strani morate biti registrirani in [[Special:Userlogin|prijavljeni]].',
 'newtitle'                => 'Na naslov',
 'movepagebtn'             => 'Prestavi stran',
 'pagemovedsub'            => 'Uspešno prestavljeno',
@@ -1135,7 +1128,7 @@
 'delete_and_move'         => 'Briši in prestavi',
 'delete_and_move_text'    => '==Treba bi bilo brisati==
 
-Ciljna stran »[[$1]]« že obstaja. Ali jo želite, da bi pripravili prostor za prestavitev, izbrisati?',
+Ciljna stran »[[:$1]]« že obstaja. Ali jo želite, da bi pripravili prostor za prestavitev, izbrisati?',
 'delete_and_move_confirm' => 'Da, izbriši stran',
 'delete_and_move_reason'  => 'Izbrisano z namenom pripraviti prostor za prestavitev.',
 'selfmove'                => "'''Naslova vira in cilja sta enaka; stran ni mogoče prestaviti samo vase.''' Prosimo, preverite, ali niste naslova cilja namesto v polje »Na naslov« vpisali v polje »Razlog«.",
@@ -1297,7 +1290,7 @@
 'imagemaxsize' => 'Slike na opisnih straneh omeji na:',
 'thumbsize'    => 'Velikost sličice (thumbnail):',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerija novih datotek',
 'imagelisttext'         => 'Prikazujem $1 $2 {{PLURAL:$1|razvrščeno datoteko|razvrščeni datoteki|razvrščene datoteke|razvrščenih datotek|razvrščenih datotek}}.',
 'showhidebots'          => '($1 bote)',
@@ -1563,7 +1556,7 @@
 
 # External editor support
 'edit-externally'      => 'Uredite datoteko z uporabo zunanjega orodja',
-'edit-externally-help' => 'Za več informacij glej [http://meta.wikimedia.org/wiki/Help:External_editors navodila za namestitev].',
+'edit-externally-help' => 'Za več informacij glej [http://www.mediawiki.org/wiki/Manual:External_editors navodila za namestitev].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'vse',
@@ -1615,7 +1608,7 @@
 'unit-pixel' => ' točk',
 
 # HTML dump
-'redirectingto' => 'Preusmerjam na »[[$1]]« ...',
+'redirectingto' => 'Preusmerjam na »[[:$1]]« ...',
 
 # action=purge
 'confirm_purge'        => 'Osvežim predpomnjenje strani? 
Index: languages/messages/MessagesKv.php
===================================================================
--- languages/messages/MessagesKv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,7 +3,75 @@
  *
  * @ingroup Language
  * @file
+ *
+ * @author Yufereff
+ * @author ОйЛ
  */
 
 $fallback = 'ru';
 
+$messages = array(
+# Dates
+'sunday'        => 'вежалун',
+'monday'        => 'выльлун',
+'tuesday'       => 'воторник',
+'wednesday'     => 'середа',
+'thursday'      => 'четверг',
+'friday'        => 'пекнича',
+'saturday'      => 'субöта',
+'january'       => 'тӧв шӧр',
+'february'      => 'урасьӧм',
+'march'         => 'рака',
+'april'         => 'кос му',
+'may_long'      => 'ода кора',
+'june'          => 'лӧддза-номъя',
+'july'          => 'сора',
+'august'        => 'моз',
+'september'     => 'кӧч',
+'october'       => 'йирым',
+'november'      => 'вӧльгым',
+'december'      => 'ӧшым',
+'january-gen'   => 'тӧв шӧр',
+'february-gen'  => 'урасьӧм',
+'march-gen'     => 'рака',
+'april-gen'     => 'кос му',
+'may-gen'       => 'ода кора',
+'june-gen'      => 'лӧддза-номъя',
+'july-gen'      => 'сора',
+'august-gen'    => 'моз',
+'september-gen' => 'кӧч',
+'october-gen'   => 'йирым',
+'november-gen'  => 'вӧльгым',
+'december-gen'  => 'ӧшым',
+
+'qbedit' => 'Веськӧдны',
+
+'search'        => 'Корсьысьӧм',
+'searchbutton'  => 'Аддзыны',
+'searcharticle' => 'Вуджны',
+'history_short' => 'Важвылӧм',
+'edit'          => 'Веськӧдны',
+'newpage'       => 'Выль лист бок',
+'talk'          => 'Сёрнитӧм',
+'jumptosearch'  => 'корсьысьӧм',
+
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'currentevents'        => 'Быд лунся лоӧмтор',
+'mainpage'             => 'Медшӧр лист бок',
+'mainpage-description' => 'Медшӧр лист бок',
+
+'editsection' => 'веськӧдны',
+
+# Short words for each namespace, by default used in the namespace tab in monobook
+'nstab-main' => 'Гижӧд',
+
+# Login and logout pages
+'login'                   => 'Висьтасьны',
+'nav-login-createaccount' => 'Висьтасьны / гижсьыны',
+'userlogin'               => 'Висьтасьны али гижсьыны',
+
+# Upload
+'upload'    => 'Файл сӧвтны',
+'uploadbtn' => 'Файл сӧвтны',
+
+);
Index: languages/messages/MessagesNds.php
===================================================================
--- languages/messages/MessagesNds.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNds.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,7 @@
  * @file
  *
  * @author Slomox
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Jon Harald Søby
  */
 
 $fallback = 'de';
@@ -474,7 +472,7 @@
 
 Dat kann vörkamen, wenn een op en olen Lenk op den Ünnerscheed twischen twee Versionen oder to en ole Version klickt hett un de Sied al wegsmeten is.
 
-Wenn dat nich de Fall is, denn hest du villicht en Fehler in de Software funnen. Mell dat an en Administrater vun {{SITENAME}} un segg em ok de URL.',
+Wenn dat nich de Fall is, denn hest du villicht en Fehler in de Software funnen. Mell dat an en [[Special:ListUsers/sysop|Administrater]] un segg em ok de URL.',
 'missingarticle-rev'   => '(Versionsnr.: $1)',
 'missingarticle-diff'  => '(Ünnerscheed: $1, $2)',
 'readonly_lag'         => 'De Datenbank is automaatsch sperrt worrn, dat sik de opdeelten Datenbankservers mit den Hööft-Datenbankserver afglieken köönt.',
@@ -525,10 +523,13 @@
 
 # Login and logout pages
 'logouttitle'                => 'Bruker-Afmellen',
-'logouttext'                 => 'Du büst nu afmellt. Du kannst {{SITENAME}} nu anonym wiederbruken oder di ünner en annern Brukernaam wedder anmellen.',
-'welcomecreation'            => '== Willkomen, $1! ==
+'logouttext'                 => '<strong>Du büst nu afmellt.</strong>
+
+Du kannst {{SITENAME}} nu anonym wiederbruken oder di ünner dissen oder en annern Brukernaam wedder [[Special:UserLogin|anmellen]].
+Denk dor an, dat welk Sieden ünner Ümstänn noch jümmer so wiest warrn köönt, as wenn du anmellt weerst. Dat ännert sik, wenn du den Cache vun dien Browser leddig maakst.',
+'welcomecreation'            => '== Willkamen, $1! ==
 Dien Brukerkonto is nu inricht.
-Vergeet nich, dien Instellen antopassen.',
+Vergeet nich, de Sied för di persönlich [[Special:Preferences|intostellen]].',
 'loginpagetitle'             => 'Bruker-Anmellen',
 'yourname'                   => 'Dien Brukernaam',
 'yourpassword'               => 'Dien Passwoort',
@@ -539,7 +540,7 @@
 'loginproblem'               => '<b>Dor weer en Problem mit dien Anmellen.</b><br />Versöök dat noch eenmal!',
 'login'                      => 'Anmellen',
 'nav-login-createaccount'    => 'Nee Konto anleggen oder anmellen',
-'loginprompt'                => 'Üm di bi {{SITENAME}} antomellen, musst du Cookies anstellt hebben.',
+'loginprompt'                => 'Dat du di bi {{SITENAME}} anmellen kannst, musst du Cookies anstellt hebben.',
 'userlogin'                  => 'Nee Konto anleggen oder anmellen',
 'logout'                     => 'Afmellen',
 'userlogout'                 => 'Afmellen',
@@ -657,38 +658,36 @@
 'subject-preview'                  => "Vörschau vun de Reeg ''Tosamenfaten''",
 'blockedtitle'                     => 'Bruker is blockt',
 'blockedtext'                      => 'Dien Brukernaam oder diene IP-Adress is vun $1 blockt worrn.
-As Grund is angeven: \'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}$5 Logbookindrag]</span>, de Block-ID is $5).
+As Grund is angeven: \'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}$5 Logbookindrag]</span>, de Block-ID is $5).
 
 Du dröffst aver jümmer noch lesen. Blot dat Schrieven geiht nich. Wenn du gor nix schrieven wullst, denn hest du villicht op en roden Lenk klickt, to en Artikel den dat noch nich gifft. blot blaue Lenken gaht na vörhannene Artikels.
 
-Wenn du glöövst, dat Sparren weer unrecht, denn mell di bi een vun de [[{{MediaWiki:Grouppage-sysop}}|Administraters]]. Geev bi Fragen jümmer ok dien IP-Adress ($3) oder de ID vun dien Block (#$5) mit an.
+Wenn du glöövst, dat Sparren weer unrecht, denn mell di bi een vun de [[{{MediaWiki:Grouppage-sysop}}|Administraters]]. Geev bi Fragen jümmer ok all disse Infos mit an:
 
 * Anfang vun’n Block: $8
 * Enn vun’n Block: $6
 * Block vun: $7
 * IP-Adress: $3
 * Block-ID: #$5
+* Grund för’n Block: #$2
 * Wokeen hett blockt: $1',
 'autoblockedtext'                  => "Diene IP-Adress is blockt, denn en annern Bruker hett ehr vördem bruukt un is dör $1 blockt worrn.
 As Grund is angeven: ''$2'' (de Block-ID is $5).
 
 Du dröffst aver jümmer noch lesen. Blot dat Schrieven geiht nich.
 
-Wenn du över de Sperr snacken wist, denn mell di bi $1 oder een vun de [[{{MediaWiki:Grouppage-sysop}}|Administraters]]. Geev bi Fragen jümmer ok dien IP-Adress oder de ID vun den Block (#$5) mit an.
+Wenn du över de Sperr snacken wist, denn mell di bi $1 oder een vun de [[{{MediaWiki:Grouppage-sysop}}|Administraters]]. Geev bi Fragen jümmer ok all disse Infos mit an:
 
 * Anfang vun’n Block: $8
 * Enn vun’n Block: $6
 * Block-ID: #$5
+* Grund för’n Block: $2
 * Wokeen hett blockt: $1",
 'blockednoreason'                  => 'keen Grund angeven',
 'blockedoriginalsource'            => "De Borntext vun '''$1''' warrt hier wiest:",
 'blockededitsource'                => "De Text vun '''diene Ännern''' an '''$1''':",
-'whitelistedittitle'               => 'de Siet to ännern is dat nödig anmellt to wesen',
+'whitelistedittitle'               => 'de Sied to ännern is dat nödig, anmellt to wesen',
 'whitelistedittext'                => 'Du musst di $1, dat du Sieden ännern kannst.',
-'whitelistreadtitle'               => 'üm to Lesen is dat neudig anmellt to ween',
-'whitelistreadtext'                => 'Du musst di [[Special:Userlogin|hier anmellen]], dat du Sieden lesen kannst.',
-'whitelistacctitle'                => 'Du hest nich de Rechten en Konto antoleggen',
-'whitelistacctext'                 => 'Dat du op {{SITENAME}} Brukerkontos anleggen kannst, musst du di [[Special:Userlogin|hier anmellen]] un de nödigen Rechten hebben.',
 'confirmedittitle'                 => 'E-Mail-Adress mutt bestätigt wesen, dat du wat ännern kannst',
 'confirmedittext'                  => 'Du musst dien E-Mail-Adress bestätigen, dat du wat ännern kannst. Stell dien E-Mail-Adress in de [[Special:Preferences|{{int:preferences}}]] in un bestätig ehr.',
 'nosuchsectiontitle'               => 'Dissen Afsnitt gifft dat nich',
@@ -700,10 +699,10 @@
 'accmailtext'                      => 'Dat Passwoort vun $1 is an $2 schickt worrn.',
 'newarticle'                       => '(Nee)',
 'newarticletext'                   => 'Hier den Text vun de ne’e Siet indregen. Jümmer in ganze Sätz schrieven un kene Texten vun Annern, de en Oorheverrecht ünnerliggt, hierher kopeern.',
-'anontalkpagetext'                 => "---- ''Dit is de Diskuschoonssiet vun en nich anmellt Bruker.
+'anontalkpagetext'                 => "---- ''Dit is de Diskuschoonssiet vun en nich anmellt Bruker, de noch keen Brukerkonto anleggt hett oder dat jüst nich bruukt.
 Wi mööt hier de numerische IP-Adress verwennen, üm den Bruker to identifizeern.
 So en Adress kann vun verscheden Brukern bruukt warrn.
-Wenn du en anonymen Bruker büst un meenst, dat disse Kommentaren nich an di richt sünd, denn [[Special:Userlogin|mell di doch an]], dormit dat Problem nich mehr besteiht.''",
+Wenn du en anonymen Bruker büst un meenst, dat disse Kommentaren nich an di richt sünd, denn [[Special:UserLogin/signup|legg di en Brukerkonto an]] oder [[Special:UserLogin|mell di an]], dat dat Problem nich mehr dor is.''",
 'noarticletext'                    => 'Dor is opstunns keen Text op disse Siet. Du kannst [[Special:Search/{{PAGENAME}}|na dissen Utdruck in annere Sieden söken]] oder [{{fullurl:{{FULLPAGENAME}}|action=edit}} disse Siet ännern].',
 'userpage-userdoesnotexist'        => 'Dat Brukerkonto „$1“ gifft dat noch nich. Överlegg, wat du disse Siet würklich nee opstellen/ännern wullt.',
 'clearyourcache'                   => "'''Denk doran:''' No den Spiekern muttst du dien Browser noch seggen, de niege Version to laden: '''Mozilla/Firefox:''' ''Strg-Shift-R'', '''IE:''' ''Strg-F5'', '''Safari:''' ''Cmd-Shift-R'', '''Konqueror:''' ''F5''.",
@@ -716,12 +715,12 @@
 'previewnote'                      => '<strong>Dit is blots en Vörschau, de Siet is noch nich spiekert!</strong>',
 'previewconflict'                  => 'Disse Vörschau wiest den Inholt vun dat Textfeld baven; so warrt de Siet utseihn, wenn du nu spiekerst.',
 'session_fail_preview'             => '<strong>Deit uns leed! Wi kunnen dien Ännern nich spiekern. Diene Sitzungsdaten weren weg.
-Versöök dat noch wedder. Wenn dat noch jümmer nich geiht, denn versöch di af- un denn wedder antomellen.</strong>',
-'session_fail_preview_html'        => "<strong>Wi kunn dien Ännern nich spiekern, de Sitzungsdaten sünd verloren gahn.</strong>
+Versöök dat noch wedder. Wenn dat noch jümmer nich geiht, denn versöök di [[Special:UserLogout|aftomellen]] un denn wedder antomellen.</strong>',
+'session_fail_preview_html'        => "<strong>Deit uns leed! Wi kunnen dien Ännern nich spiekern, de Sitzungsdaten sünd verloren gahn.</strong>
 
 ''In {{SITENAME}} is dat Spiekern vun rein HTML verlöövt, dorvun is de Vörschau utblennt, dat JavaScript-Angrepen nich mööglich sünd.''
 
-<strong>Versöök dat noch wedder un klick noch wedder op „Siet spiekern“. Wenn dat Problem noch jümmer dor is, mell di af un denn wedder an.</strong>",
+<strong>Versöök dat noch wedder un klick noch wedder op „Siet spiekern“. Wenn dat Problem noch jümmer dor is, [[Special:UserLogout|mell di af]] un denn wedder an.</strong>",
 'token_suffix_mismatch'            => '<strong>Dien Ännern sünd afwiest worrn. Dien Browser hett welk Teken in de Kuntrull-Tekenreeg kaputt maakt.
 Wenn dat so spiekert warrt, kann dat angahn, dat noch mehr Teken in de Sied kaputt gaht.
 Dat kann to’n Bispeel dor vun kamen, dat du en anonymen Proxy-Deenst bruukst, de wat verkehrt maakt.</strong>',
@@ -767,7 +766,7 @@
 'hiddencategories'                 => 'Disse Siet steiht in {{PLURAL:$1|ene verstekene Kategorie|$1 verstekene Kategorien}}:',
 'edittools'                        => '<!-- Disse Text warrt ünner de Finstern för dat Ännern un Hoochladen wiest. -->',
 'nocreatetitle'                    => 'Opstellen vun ne’e Sieden is inschränkt.',
-'nocreatetext'                     => '{{SITENAME}} verlööft di dat Opstellen vun ne’e Sieden nich. Du kannst blot Sieden ännern, de al dor sünd, oder du musst di [[Special:Userlogin|anmellen]].',
+'nocreatetext'                     => '{{SITENAME}} verlööft di dat Opstellen vun ne’e Sieden nich. Du kannst blot Sieden ännern, de al dor sünd, oder du musst di [[Special:UserLogin|anmellen]].',
 'nocreate-loggedin'                => 'Du hest keen Verlööf, op {{SITENAME}} ne’e Sieden antoleggen.',
 'permissionserrors'                => 'Fehlers mit de Rechten',
 'permissionserrorstext'            => 'Du hest keen Verlööf, dat to doon. De {{PLURAL:$1|Grund is|Grünn sünd}}:',
@@ -888,7 +887,7 @@
 # Suppression log
 'suppressionlog'     => 'Oversight-Logbook',
 'suppressionlogtext' => 'Dit is dat Logbook vun de Oversight-Akschonen mit Sieden un Sperren, de ok för Administraters nich mehr to sehn sünd.
-Kiek in de [[Special:Ipblocklist|IP-Sperrnlist]] för en Översicht över de opstunns aktiven Sperrn.',
+Kiek in de [[Special:IPBlockList|IP-Sperrnlist]] för en Översicht över de opstunns aktiven Sperrn.',
 
 # History merging
 'mergehistory'                     => 'Versionshistorien tohoopföhren',
@@ -973,7 +972,7 @@
 'mypreferences'            => 'För mi Instellen',
 'prefs-edits'              => 'Wo faken du in dit Wiki Sieden ännert hest:',
 'prefsnologin'             => 'Nich anmellt',
-'prefsnologintext'         => 'Du musst [[Special:Userlogin|anmellt]] wesen, üm dien Instellen to ännern.',
+'prefsnologintext'         => 'Du musst [[Special:UserLogin|anmellt]] wesen, üm dien Instellen to ännern.',
 'prefsreset'               => 'Instellen sünd op Standard trüchsett.',
 'qbsettings'               => 'Siedenliest',
 'qbsettings-none'          => 'Keen',
@@ -1046,7 +1045,7 @@
 'userrights-reason'           => 'Grund:',
 'userrights-no-interwiki'     => 'Du hest nich de Rechten, Brukerrechten in annere Wikis to setten.',
 'userrights-nodatabase'       => 'Datenbank $1 gifft dat nich oder is nich lokal.',
-'userrights-nologin'          => 'Du musst mit en Administrater-Brukerkonto [[Special:Userlogin|anmellt]] wesen, dat du Brukerrechten ännern kannst.',
+'userrights-nologin'          => 'Du musst mit en Administrater-Brukerkonto [[Special:UserLogin|anmellt]] wesen, dat du Brukerrechten ännern kannst.',
 'userrights-notallowed'       => 'Du hest nich de Rechten, Brukerrechten to setten.',
 'userrights-changeable-col'   => 'Gruppen, de du ännern kannst',
 'userrights-unchangeable-col' => 'Gruppen, de du nich ännern kannst',
@@ -1094,7 +1093,7 @@
 'right-autoconfirmed'        => 'Halfschuulte Sieden ännern',
 'right-bot'                  => 'Lieks as en automaatschen Prozess behannelt warrn',
 'right-nominornewtalk'       => 'Lüttje Ännern an Diskuschoonssieden wiest keen „Ne’e Narichten“',
-'right-apihighlimits'        => 'Högere Limits in API-Affragen',
+'right-apihighlimits'        => 'Bruuk högere Limits in API-Affragen',
 'right-writeapi'             => 'Ännern över de Schriev-API',
 'right-delete'               => 'Sieden wegsmieten',
 'right-bigdelete'            => 'Sieden mit grote Versionsgeschichten wegsmieten',
@@ -1176,29 +1175,24 @@
 'reupload'                    => 'Nee hoochladen',
 'reuploaddesc'                => 'Trüch to de Hoochladen-Siet.',
 'uploadnologin'               => 'Nich anmellt',
-'uploadnologintext'           => 'Du musst [[Special:Userlogin|anmellt wesen]], dat du Datein hoochladen kannst.',
+'uploadnologintext'           => 'Du musst [[Special:UserLogin|anmellt wesen]], dat du Datein hoochladen kannst.',
 'upload_directory_missing'    => 'De Dateimapp för hoochladene Datein ($1) fehlt un de Webserver kunn ehr ok nich nee opstellen.',
 'upload_directory_read_only'  => 'De Server kann nich in’n Orner för dat Hoochladen vun Datein ($1) schrieven.',
 'uploaderror'                 => 'Fehler bi dat Hoochladen',
-'uploadtext'                  => "Bruuk dat Formular, üm niege Biller hoochtoladen un disse in Sieten to bruken.
-Üm hoochladene Biller to söken un antokieken, geih to de [[Special:Imagelist|List vun hoochladene Biller]].
+'uploadtext'                  => "Bruuk dit Formular, ne’e Datein hoochtoladen.
+Dat du hoochladene Datein söken un ankieken kannst, gah na de [[Special:ImageList|List vun hoochladene Datein]]. Dat Hoochladen un nee Hoochladen vun Datein warrt ok in dat [[Special:Log/upload|Hoochlade-Logbook]] fasthollen. Dat Wegsmieten in dat [[Special:Log/delete|Wegsmiet-Logbook]].
 
-In de mehrsten Browser warrt en „Durchsuchen“-Feld wiest, dat en Standard-Dateidialog apent.
-Wähl de Datei ut, de du hoochladen wullst. De Dateinaam warrt denn in dat Textfeld wiest.
-Bestätig dann den Copyright-Henwies.
-Toletzt muttst du den „Hoochladen“-Knopp klicken.
-Dat kann en Stoot duern, sünnerlich bi en langsamen Internet-Verbinnen.
-
-För Fotos is dat JPEG-Format, för Grafiken un Symbolen dat PNG-Format best.
-Üm en Bild in en Siet to bruken, schriev an Stell vun dat Bild
-'''[[Image:datei.jpg]]''' oder
-'''[[Image:datei.jpg|Beschrieven]]'''.",
+Üm en Datei in en Sied to bruken, schriev dat hier in de Sied rin:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:datei.jpg]]</nowiki></tt>''' för de Datei in vulle Grött
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:datei.jpg|200px|thumb|left|Beschrieven]]</nowiki></tt>''' för dat Bild in en Breed vun 200 Pixels in en lütt Kassen op de linke Sied mit ''Beschrieven'' as Text ünner dat Bild
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' för en direkten Lenk op de Datei, ahn dat se wiest warrt.",
 'upload-permitted'            => 'Verlöövte Dateitypen: $1.',
 'upload-preferred'            => 'Vörtagene Dateitypen: $1.',
 'upload-prohibited'           => 'Verbadene Dateitypen: $1.',
 'uploadlog'                   => 'Hoochlade-Logbook',
 'uploadlogpage'               => 'Hoochlade-Logbook',
-'uploadlogpagetext'           => 'Ünnen steiht de List vun de ne’esten hoochladenen Datein.',
+'uploadlogpagetext'           => 'Ünnen steiht de List vun de ne’esten hoochladenen Datein.
+Kiek bi de [[Special:NewImages|Galerie vun ne’e Datein]] för en Översicht mit Duumnagel-Biller.',
 'filename'                    => 'Dateinaam',
 'filedesc'                    => 'Beschrieven',
 'fileuploadsummary'           => 'Tosamenfaten:',
@@ -1255,10 +1249,9 @@
 'upload-proto-error'      => 'Verkehrt Protokoll',
 'upload-proto-error-text' => 'De URL mutt mit <code>http://</code> oder <code>ftp://</code> anfangen.',
 'upload-file-error'       => 'Internen Fehler',
-'upload-file-error-text'  => 'An internal error occurred when attempting to create a temporary file on the server.  Please contact a system administrator.
-Dat geev en internen Fehler bi dat Anleggen vun en temporäre Datei op’n Server. Segg man en System-Administrater bescheed.',
+'upload-file-error-text'  => 'Dat geev en internen Fehler bi dat Anleggen vun en temporäre Datei op’n Server. Segg man en [[Special:ListUsers/sysop|Administrater]] bescheed.',
 'upload-misc-error'       => 'Unbekannt Fehler bi dat Hoochladen',
-'upload-misc-error-text'  => 'Bi dat Hoochladen geev dat en unbekannten Fehler. Kiek na, wat dor en Fehler in de URL is, wat de Websteed ok löppt un versöök dat denn noch wedder. Wenn dat Problem denn noch jümmer dor is, denn vertell dat en System-Administrater.',
+'upload-misc-error-text'  => 'Bi dat Hoochladen geev dat en unbekannten Fehler. Kiek na, wat dor en Fehler in de URL is, wat de Websteed ok löppt un versöök dat denn noch wedder. Wenn dat Problem denn noch jümmer dor is, denn vertell dat en [[Special:ListUsers/sysop|System-Administrater]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Kunn de URL nich kriegen',
@@ -1274,7 +1267,7 @@
 'upload_source_url'  => ' (gellen, apen togängliche URL)',
 'upload_source_file' => ' (en Datei op dien Reekner)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Disse Spezialsied wiest all Datein. As Standard warrt de ne’esten Datein toeerst wiest. Wenn du op de enkelten Överschriften klickst, kannst du de Sortreeg ümdreihn oder na en anner Kriterium sorteren.',
 'imagelist_search_for'  => 'Söök na Datei:',
 'imgfile'               => 'Datei',
@@ -1300,7 +1293,7 @@
 'imagelinks'                     => 'Bildverwiesen',
 'linkstoimage'                   => 'Disse {{PLURAL:$1|Sied|Sieden}} bruukt dit Bild:',
 'nolinkstoimage'                 => 'Kene Siet bruukt dat Bild.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Mehr Verwiesen]] för disse Datei.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Mehr Verwiesen]] för disse Datei.',
 'redirectstofile'                => 'Disse {{PLURAL:$1|Datei is|Datein sünd}} en Redirect op disse Datei:',
 'duplicatesoffile'               => 'Disse {{PLURAL:$1|Datei is|Datein sünd}} jüst de {{PLURAL:$1|glieke|glieken}} as disse Datei:',
 'sharedupload'                   => 'Disse Datei is as gemeensam bruukte Datei hoochlaadt un warrt mööglicherwies ok vun annere Wikis bruukt.',
@@ -1319,18 +1312,18 @@
 # File reversion
 'filerevert'                => '„$1“ Trüchsetten',
 'filerevert-legend'         => 'Datei trüchsetten',
-'filerevert-intro'          => '<span class="plainlinks">Du settst de Datei \'\'\'[[Media:$1|$1]]\'\'\' op de [$4 Version vun $2, $3] trüch.</span>',
+'filerevert-intro'          => "Du settst de Datei '''[[Media:$1|$1]]''' op de [$4 Version vun $2, $3] trüch.",
 'filerevert-comment'        => 'Kommentar:',
 'filerevert-defaultcomment' => 'trüchsett op de Version vun’n $1, $2',
 'filerevert-submit'         => 'Trüchsetten',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' is op de [$4 Version vun $2, $3] trüchsett worrn.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' is op de [$4 Version vun $2, $3] trüchsett worrn.",
 'filerevert-badversion'     => 'Gifft keen vörige lokale Version vun de Datei to disse Tied.',
 
 # File deletion
 'filedelete'                  => '$1 wegsmieten',
 'filedelete-legend'           => 'Datei wegsmieten',
 'filedelete-intro'            => "Du smittst '''[[Media:$1|$1]]''' weg.",
-'filedelete-intro-old'        => '<span class="plainlinks">Du smittst vun de Datei \'\'\'„[[Media:$1|$1]]“\'\'\' de [$4 Version vun $2, $3] weg.</span>',
+'filedelete-intro-old'        => "Du smittst vun de Datei '''„[[Media:$1|$1]]“''' de [$4 Version vun $2, $3] weg.",
 'filedelete-comment'          => 'Kommentar:',
 'filedelete-submit'           => 'Wegsmieten',
 'filedelete-success'          => "'''$1''' wegsmeten.",
@@ -1393,11 +1386,13 @@
 'disambiguationspage'  => 'Template:Mehrdüdig_Begreep',
 'disambiguations-text' => 'Disse Sieden wist na Sieden för mehrdüdige Begrepen. Se schöölt lever op de Sieden wiesen, de egentlich meent sünd.<br />Ene Siet warrt as Siet för en mehrdüdigen Begreep ansehn, wenn [[MediaWiki:Disambiguationspage]] na ehr wiest.<br />Lenken ut annere Naamrüüm sünd nich mit in de List.',
 
-'doubleredirects'     => 'Dubbelte Wiederleiden',
-'doubleredirectstext' => '<b>Wohrscho:</b> Disse List kann „falsche Positive“ bargen.
+'doubleredirects'            => 'Dubbelte Wiederleiden',
+'doubleredirectstext'        => '<b>Wohrscho:</b> Disse List kann „falsche Positive“ bargen.
 Dat passeert denn, wenn en Wiederleiden blangen de Wiederleiden-Verwies noch mehr Text mit annere Verwiesen hett.
 De schallen denn löscht warrn. Elk Reeg wiest de eerste un tweete Wiederleiden un de eerste Reeg Text ut de Siet,
 to den vun den tweeten Wiederleiden wiest warrt, un to den de eerste Wiederleiden mehrst wiesen schall.',
+'double-redirect-fixed-move' => '[[$1]] is schaven worrn un wiest nu na [[$2]]',
+'double-redirect-fixer'      => 'Redirect-Utbeterer',
 
 'brokenredirects'        => 'Kaputte Wiederleiden',
 'brokenredirectstext'    => 'Disse Wiederleiden wiest na en Siet, de dat nich gifft.',
@@ -1483,7 +1478,7 @@
 'logempty'             => 'In’e Logböker nix funnen, wat passt.',
 'log-title-wildcard'   => 'Titel fangt an mit …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle Sieden',
 'alphaindexline'    => '$1 bet $2',
 'nextpage'          => 'tokamen Siet ($1)',
@@ -1506,12 +1501,12 @@
 'special-categories-sort-count' => 'na Tall sorteren',
 'special-categories-sort-abc'   => 'alphabeetsch sorteren',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Wies de Brukers, de anfangt mit:',
 'listusers-submit'   => 'Wiesen',
 'listusers-noresult' => 'Keen Bruker funnen.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Brukergruppen-Rechten',
 'listgrouprights-summary'  => 'Dit is en List vun de Brukergruppen, de in dit Wiki defineert sünd, un de Rechten, de dor mit verbunnen sünd.
 Mehr Informatschonen över enkelte Rechten staht ünner [[{{MediaWiki:Listgrouprights-helppage}}]].',
@@ -1522,7 +1517,7 @@
 
 # E-mail user
 'mailnologin'     => 'Du büst nich anmellt.',
-'mailnologintext' => 'Du musst [[Special:Userlogin|anmellt wesen]] un in diene [[Special:Preferences|Instellungen]] en güllige E-Mail-Adress hebben, dat du annere Brukers E-Mails schicken kannst.',
+'mailnologintext' => 'Du musst [[Special:UserLogin|anmellt wesen]] un in diene [[Special:Preferences|Instellungen]] en güllige E-Mail-Adress hebben, dat du annere Brukers E-Mails schicken kannst.',
 'emailuser'       => 'E-Mail an dissen Bruker',
 'emailpage'       => 'E-Mail an Bruker',
 'emailpagetext'   => 'Wenn disse Bruker en güllige E-Mail-Adress angeven hett, kannst du em mit den nerrn stahn Formular en E-Mail sennen. As Afsenner warrt de E-Mail-Adress ut dien Instellen indregen, dormit de Bruker di antern kann.',
@@ -1548,10 +1543,10 @@
 'nowatchlist'          => 'Du hest kene Indreeg op dien Oppasslist.',
 'watchlistanontext'    => '$1, dat du dien Oppasslist ankieken oder ännern kannst.',
 'watchnologin'         => 'Du büst nich anmellt',
-'watchnologintext'     => 'Du must [[Special:Userlogin|anmellt]] wesen, wenn du dien Oppasslist ännern willst.',
+'watchnologintext'     => 'Du must [[Special:UserLogin|anmellt]] wesen, wenn du dien Oppasslist ännern willst.',
 'addedwatch'           => 'To de Oppasslist toföögt',
 'addedwatchtext'       => 'De Siet „<nowiki>$1</nowiki>“ is to diene [[Special:Watchlist|Oppasslist]] toföögt worrn.
-Ännern, de in Tokumst an disse Siet un an de tohörige Diskuschoonssiet maakt warrt, sünd dor op oplist un de Siet is op de [[Special:Recentchanges|List vun de letzten Ännern]] fett markt. Wenn du de Siet nich mehr op diene Oppasslist hebben willst, klick op „Nich mehr oppassen“.',
+Ännern, de in Tokumst an disse Siet un an de tohörige Diskuschoonssiet maakt warrt, sünd dor op oplist un de Siet is op de [[Special:RecentChanges|List vun de letzten Ännern]] fett markt. Wenn du de Siet nich mehr op diene Oppasslist hebben willst, klick op „Nich mehr oppassen“.',
 'removedwatch'         => 'De Siet is nich mehr op de Oppasslist',
 'removedwatchtext'     => 'De Siet „<nowiki>$1</nowiki>“ is nich mehr op de Oppasslist.',
 'watch'                => 'Oppassen',
@@ -1647,9 +1642,9 @@
 'rollbacklink'                => 'Trüchnehmen',
 'rollbackfailed'              => 'Trüchnahm hett kenen Spood',
 'cantrollback'                => 'De Ännern kann nich trüchnahmen warrn; de letzte Autor is de eenzige.',
-'alreadyrolled'               => 'Dat Trüchnehmen vun de Ännern an de Siet [[:$1]] vun [[User:$2|$2]] ([[User talk:$2|Diskuschoonssiet]]) is nich mööglich, vun wegen dat dor en annere Ännern oder Trüchnahm ween is.
+'alreadyrolled'               => 'Dat Trüchnehmen vun de Ännern an de Siet [[:$1]] vun [[User:$2|$2]] ([[User talk:$2|Diskuschoonssiet]] | [[Special:Contributions/$2|Bidrääg]]) is nich mööglich, vun wegen dat dor en annere Ännern oder Trüchnahm wesen is.
 
-De letzte Ännern is vun [[User:$3|$3]] ([[User talk:$3|Diskuschoon]]).',
+De letzte Ännern is vun [[User:$3|$3]] ([[User talk:$3|Diskuschoon]] | [[Special:Contributions/$3|Bidrääg]]).',
 'editcomment'                 => "De Ännerkommentar weer: ''$1''.", # only shown if there is an edit comment
 'revertpage'                  => 'Ännern vun [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskuschoon]]) rut un de Version vun [[User:$1]] wedderhaalt', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Ännern vun $1 trüchsett op letzte Version vun $2.',
@@ -1657,7 +1652,7 @@
 Disse Akschoon is nu ut Sekerheitsgrünn afbraken, dat de Ännern nich verkehrt en annern Bruker toornt warrt.
 Gah een Sied trüch un versöök dat noch wedder.',
 'protectlogpage'              => 'Sietenschuul-Logbook',
-'protectlogtext'              => 'Dit is en List vun de blockten Sieten. Kiek [[Special:Protectedpages|Schulte Sieten]] för mehr Informatschonen.',
+'protectlogtext'              => 'Dit is en List vun de blockten Sieten. Kiek [[Special:ProtectedPages|Schulte Sieten]] för mehr Informatschonen.',
 'protectedarticle'            => 'Siet $1 schuult',
 'modifiedarticleprotection'   => 'Schuul op „[[$1]]“ sett',
 'unprotectedarticle'          => 'Siet $1 freegeven',
@@ -1787,89 +1782,90 @@
 'whatlinkshere-filters'    => 'Filters',
 
 # Block/unblock
-'blockip'                     => 'IP-Adress blocken',
-'blockip-legend'              => 'Bruker blocken',
-'blockiptext'                 => 'Bruuk dat Formular, ene IP-Adress to blocken.
+'blockip'                         => 'IP-Adress blocken',
+'blockip-legend'                  => 'Bruker blocken',
+'blockiptext'                     => 'Bruuk dat Formular, ene IP-Adress to blocken.
 Dit schall blots maakt warrn, Vandalismus to vermasseln, aver jümmer in Övereenstimmen mit uns [[{{MediaWiki:Policy-url}}|Leidlienen]].
 Ok den Grund för dat Blocken indregen.',
-'ipaddress'                   => 'IP-Adress',
-'ipadressorusername'          => 'IP-Adress oder Brukernaam:',
-'ipbexpiry'                   => 'Aflooptiet',
-'ipbreason'                   => 'Grund',
-'ipbreasonotherlist'          => 'Annern Grund',
-'ipbreason-dropdown'          => '* Allgemene Sperrgrünn
+'ipaddress'                       => 'IP-Adress',
+'ipadressorusername'              => 'IP-Adress oder Brukernaam:',
+'ipbexpiry'                       => 'Aflooptiet',
+'ipbreason'                       => 'Grund',
+'ipbreasonotherlist'              => 'Annern Grund',
+'ipbreason-dropdown'              => '* Allgemene Sperrgrünn
 ** Tofögen vun verkehrte Infos
 ** Leddigmaken vun Sieden
 ** Schrifft Tüdelkraam in Sieden
 ** Bedroht annere
 ** Brukernaam nich akzeptabel',
-'ipbanononly'                 => 'Blot anonyme Brukers blocken',
-'ipbcreateaccount'            => 'Anleggen vun Brukerkonto verhinnern',
-'ipbemailban'                 => 'E-Mail schrieven sperren',
-'ipbenableautoblock'          => 'Sperr de aktuell vun dissen Bruker bruukte IP-Adress un automaatsch all de annern, vun de ut he Sieden ännern oder Brukers anleggen will',
-'ipbsubmit'                   => 'Adress blocken',
-'ipbother'                    => 'Annere Tiet:',
-'ipboptions'                  => '1 Stünn:1 hour,2 Stünnen:2 hours,6 Stünnen:6 hours,1 Dag:1 day,3 Daag:3 days,1 Week:1 week,2 Weken:2 weeks,1 Maand:1 month,3 Maand:3 months,1 Johr:1 year,ahn Enn:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'Annere Duer',
-'ipbotherreason'              => 'Annern Grund:',
-'ipbhidename'                 => 'Brukernaam in dat Sperr-Logbook, de List vun de aktiven Sperren un de Brukerlist versteken.',
-'ipbwatchuser'                => 'Op Brukersiet un Brukerdiskuschoon oppassen',
-'badipaddress'                => 'De IP-Adress hett en falsch Format.',
-'blockipsuccesssub'           => 'Blocken hett Spood',
-'blockipsuccesstext'          => 'De IP-Adress „$1“ is nu blockt.
+'ipbanononly'                     => 'Blot anonyme Brukers blocken',
+'ipbcreateaccount'                => 'Anleggen vun Brukerkonto verhinnern',
+'ipbemailban'                     => 'E-Mail schrieven sperren',
+'ipbenableautoblock'              => 'Sperr de aktuell vun dissen Bruker bruukte IP-Adress un automaatsch all de annern, vun de ut he Sieden ännern oder Brukers anleggen will',
+'ipbsubmit'                       => 'Adress blocken',
+'ipbother'                        => 'Annere Tiet:',
+'ipboptions'                      => '1 Stünn:1 hour,2 Stünnen:2 hours,6 Stünnen:6 hours,1 Dag:1 day,3 Daag:3 days,1 Week:1 week,2 Weken:2 weeks,1 Maand:1 month,3 Maand:3 months,1 Johr:1 year,ahn Enn:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'Annere Duer',
+'ipbotherreason'                  => 'Annern Grund:',
+'ipbhidename'                     => 'Brukernaam in dat Sperr-Logbook, de List vun de aktiven Sperren un de Brukerlist versteken.',
+'ipbwatchuser'                    => 'Op Brukersiet un Brukerdiskuschoon oppassen',
+'badipaddress'                    => 'De IP-Adress hett en falsch Format.',
+'blockipsuccesssub'               => 'Blocken hett Spood',
+'blockipsuccesstext'              => 'De IP-Adress „$1“ is nu blockt.
 
-<br />Op de [[Special:Ipblocklist|IP-Blocklist]] is en List vun alle Blocks to finnen.',
-'ipb-edit-dropdown'           => 'Blockgrünn bearbeiden',
-'ipb-unblock-addr'            => '„$1“ freegeven',
-'ipb-unblock'                 => 'IP-Adress/Bruker freegeven',
-'ipb-blocklist-addr'          => 'Aktuelle Sperren för „$1“ wiesen',
-'ipb-blocklist'               => 'Aktuelle Sperren wiesen',
-'unblockip'                   => 'IP-Adress freegeven',
-'unblockiptext'               => 'Bruuk dat Formular, üm en blockte IP-Adress freetogeven.',
-'ipusubmit'                   => 'Disse Adress freegeven',
-'unblocked'                   => '[[User:$1|$1]] freegeven',
-'unblocked-id'                => 'Sperr $1 freegeven',
-'ipblocklist'                 => 'List vun blockte IP-Adressen',
-'ipblocklist-legend'          => 'Blockten Bruker finnen',
-'ipblocklist-username'        => 'Brukernaam oder IP-Adress:',
-'ipblocklist-submit'          => 'Söken',
-'blocklistline'               => '$1, $2 hett $3 blockt ($4)',
-'infiniteblock'               => 'unbegrenzt',
-'expiringblock'               => 'löppt $1 af',
-'anononlyblock'               => 'blot Anonyme',
-'noautoblockblock'            => 'Autoblock afstellt',
-'createaccountblock'          => 'Brukerkonten opstellen sperrt',
-'emailblock'                  => 'E-Mail schrieven sperrt',
-'ipblocklist-empty'           => 'De List is leddig.',
-'ipblocklist-no-results'      => 'De söchte IP-Adress/Brukernaam is nich sperrt.',
-'blocklink'                   => 'blocken',
-'unblocklink'                 => 'freegeven',
-'contribslink'                => 'Bidrääg',
-'autoblocker'                 => 'Automatisch Block, vun wegen dat du en IP-Adress bruukst mit „$1“. Grund: „$2“.',
-'blocklogpage'                => 'Brukerblock-Logbook',
-'blocklogentry'               => 'block [[$1]] för en Tiedruum vun: $2 $3',
-'blocklogtext'                => 'Dit is en Logbook över Blocks un Freegaven vun Brukern. Automatisch blockte IP-Adressen sünd nich opföhrt.
-Kiek [[Special:Ipblocklist|IP-Blocklist]] för en List vun den blockten Brukern.',
-'unblocklogentry'             => 'Block vun [[$1]] ophoven',
-'block-log-flags-anononly'    => 'blots anonyme Brukers',
-'block-log-flags-nocreate'    => 'Brukerkonten opstellen sperrt',
-'block-log-flags-noautoblock' => 'Autoblock utschalt',
-'block-log-flags-noemail'     => 'E-Mail schrieven sperrt',
-'range_block_disabled'        => 'De Mööglichkeit, ganze Adressrüüm to sparren, is nich aktiveert.',
-'ipb_expiry_invalid'          => 'De angeven Aflooptiet is nich güllig.',
-'ipb_expiry_temp'             => 'Versteken Brukernaam-Sperren schöölt duurhaft wesen.',
-'ipb_already_blocked'         => '„$1“ is al blockt.',
-'ipb_cant_unblock'            => 'Fehler: Block-ID $1 nich funnen. De Sperr is villicht al wedder ophoven.',
-'ipb_blocked_as_range'        => 'Fehler: De IP-Adress $1 is as Deel vun de IP-Reeg $2 indirekt sperrt worrn. De Sperr trüchnehmen för $1 alleen geiht nich.',
-'ip_range_invalid'            => 'Ungüllig IP-Addressrebeet.',
-'blockme'                     => 'Sperr mi',
-'proxyblocker'                => 'Proxyblocker',
-'proxyblocker-disabled'       => 'Disse Funkschoon is afstellt.',
-'proxyblockreason'            => 'Dien IP-Adress is blockt, vun wegen dat se en apenen Proxy is.
+<br />Op de [[Special:IPBlockList|IP-Blocklist]] is en List vun alle Blocks to finnen.',
+'ipb-edit-dropdown'               => 'Blockgrünn bearbeiden',
+'ipb-unblock-addr'                => '„$1“ freegeven',
+'ipb-unblock'                     => 'IP-Adress/Bruker freegeven',
+'ipb-blocklist-addr'              => 'Aktuelle Sperren för „$1“ wiesen',
+'ipb-blocklist'                   => 'Aktuelle Sperren wiesen',
+'unblockip'                       => 'IP-Adress freegeven',
+'unblockiptext'                   => 'Bruuk dat Formular, üm en blockte IP-Adress freetogeven.',
+'ipusubmit'                       => 'Disse Adress freegeven',
+'unblocked'                       => '[[User:$1|$1]] freegeven',
+'unblocked-id'                    => 'Sperr $1 freegeven',
+'ipblocklist'                     => 'List vun blockte IP-Adressen',
+'ipblocklist-legend'              => 'Blockten Bruker finnen',
+'ipblocklist-username'            => 'Brukernaam oder IP-Adress:',
+'ipblocklist-submit'              => 'Söken',
+'blocklistline'                   => '$1, $2 hett $3 blockt ($4)',
+'infiniteblock'                   => 'unbegrenzt',
+'expiringblock'                   => 'löppt $1 af',
+'anononlyblock'                   => 'blot Anonyme',
+'noautoblockblock'                => 'Autoblock afstellt',
+'createaccountblock'              => 'Brukerkonten opstellen sperrt',
+'emailblock'                      => 'E-Mail schrieven sperrt',
+'ipblocklist-empty'               => 'De List is leddig.',
+'ipblocklist-no-results'          => 'De söchte IP-Adress/Brukernaam is nich sperrt.',
+'blocklink'                       => 'blocken',
+'unblocklink'                     => 'freegeven',
+'contribslink'                    => 'Bidrääg',
+'autoblocker'                     => 'Automatisch Block, vun wegen dat du en IP-Adress bruukst mit „$1“. Grund: „$2“.',
+'blocklogpage'                    => 'Brukerblock-Logbook',
+'blocklogentry'                   => 'block [[$1]] för en Tiedruum vun: $2 $3',
+'blocklogtext'                    => 'Dit is en Logbook över Blocks un Freegaven vun Brukern. Automatisch blockte IP-Adressen sünd nich opföhrt.
+Kiek [[Special:IPBlockList|IP-Blocklist]] för en List vun den blockten Brukern.',
+'unblocklogentry'                 => 'Block vun [[$1]] ophoven',
+'block-log-flags-anononly'        => 'blots anonyme Brukers',
+'block-log-flags-nocreate'        => 'Brukerkonten opstellen sperrt',
+'block-log-flags-noautoblock'     => 'Autoblock utschalt',
+'block-log-flags-noemail'         => 'E-Mail schrieven sperrt',
+'block-log-flags-angry-autoblock' => 'utwiedt Autoblock aktiv',
+'range_block_disabled'            => 'De Mööglichkeit, ganze Adressrüüm to sparren, is nich aktiveert.',
+'ipb_expiry_invalid'              => 'De angeven Aflooptiet is nich güllig.',
+'ipb_expiry_temp'                 => 'Versteken Brukernaam-Sperren schöölt duurhaft wesen.',
+'ipb_already_blocked'             => '„$1“ is al blockt.',
+'ipb_cant_unblock'                => 'Fehler: Block-ID $1 nich funnen. De Sperr is villicht al wedder ophoven.',
+'ipb_blocked_as_range'            => 'Fehler: De IP-Adress $1 is as Deel vun de IP-Reeg $2 indirekt sperrt worrn. De Sperr trüchnehmen för $1 alleen geiht nich.',
+'ip_range_invalid'                => 'Ungüllig IP-Addressrebeet.',
+'blockme'                         => 'Sperr mi',
+'proxyblocker'                    => 'Proxyblocker',
+'proxyblocker-disabled'           => 'Disse Funkschoon is afstellt.',
+'proxyblockreason'                => 'Dien IP-Adress is blockt, vun wegen dat se en apenen Proxy is.
 Kontakteer dien Provider oder diene Systemtechnik un informeer se över dat möögliche Sekerheitsproblem.',
-'proxyblocksuccess'           => 'Trech.',
-'sorbsreason'                 => 'Diene IP-Adress steiht in de DNSBL vun {{SITENAME}} as apen PROXY.',
-'sorbs_create_account_reason' => 'Diene IP-Adress steiht in de DNSBL vun {{SITENAME}} as apen PROXY. Du kannst keen Brukerkonto nee opstellen.',
+'proxyblocksuccess'               => 'Trech.',
+'sorbsreason'                     => 'Diene IP-Adress steiht in de DNSBL vun {{SITENAME}} as apen PROXY.',
+'sorbs_create_account_reason'     => 'Diene IP-Adress steiht in de DNSBL vun {{SITENAME}} as apen PROXY. Du kannst keen Brukerkonto nee opstellen.',
 
 # Developer tools
 'lockdb'              => 'Datenbank sparren',
@@ -1896,12 +1892,15 @@
 'move-page-legend'        => 'Siet schuven',
 'movepagetext'            => "Mit dit Formular kannst du en Siet en ne’en Naam geven, tohoop mit all Versionen.
 De ole Titel wiest denn achterna na den ne’en.
-Verwiesen op den olen Titel warrt nich ännert.
-Kiek also na, wat dor kene dubbelten un kaputten Redirects nablifft.
+Verwiesen op den olen Titel köönt automaatsch ännert warrn.
+Wenn du dat automaatsche Utbetern vun de Redirects nich utwählst, denn kiek na, wat dor kene [[Special:DoubleRedirects|dubbelten]] un [[Special:BrokenRedirects|kaputten Redirects]] nablifft.
 Dat is dien Opgaav, optopassen, dat de Lenken all dorhen wiest, wo se hen wiesen schöölt.
 
 De Siet warrt '''nich''' schaven, wenn dat al en Siet mit’n ne’en Naam gifft. Utnahmen vun disse Regel sünd blot leddige Sieden un Redirects, wenn disse Sieden kene öllern Versionen hebbt.
-Dat bedüüdt, dat du ene jüst verschavene Siet na’n olen Titel trüchschuven kannst, wenn du en Fehler maakt hest, un dat du kene vörhannenen Sieden överschrieven kannst.",
+Dat bedüüdt, dat du ene jüst verschavene Siet na’n olen Titel trüchschuven kannst, wenn du en Fehler maakt hest, un dat du kene vörhannenen Sieden överschrieven kannst.
+
+'''WOHRSCHAU!'''
+Dit kann sik temlich dull utwarken bi veel bruukte Sieden. Stell seker, dat du weetst, wie sik dat utwarkt, ehrdat du wiedermaakst.",
 'movepagetalktext'        => "De tohören Diskuschoonssiet warrt, wenn een dor is, mitverschaven, ''mit disse Utnahmen:''
 * Du schuffst de Siet in en annern Naamruum oder
 * dat gifft al en Diskuschoonssiet mit dissen Naam, oder
@@ -1909,10 +1908,6 @@
 
 In disse Fäll musst du de Siet, wenn du dat willst, vun Hand schuven.",
 'movearticle'             => 'Siet schuven',
-'movenologin'             => 'Du büst nich anmellt',
-'movenologintext'         => 'Du muttst en registreert Bruker un
-[[Special:Userlogin|anmellt]] ween,
-üm en Siet to schuven.',
 'movenotallowed'          => 'Du hest nich de Rechten, op {{SITENAME}} Sieden to schuven.',
 'newtitle'                => 'To ne’en Titel',
 'move-watch'              => 'Op disse Siet oppassen',
@@ -1941,13 +1936,15 @@
 'delete_and_move'         => 'Wegsmieten un Schuven',
 'delete_and_move_text'    => '== Siet gifft dat al, wegsmieten? ==
 
-De Siet „[[$1]]“ gifft dat al. Wullt du ehr wegsmieten, dat disse Siet schaven warrn kann?',
+De Siet „[[:$1]]“ gifft dat al. Wullt du ehr wegsmieten, dat disse Siet schaven warrn kann?',
 'delete_and_move_confirm' => 'Jo, de Siet wegsmieten',
 'delete_and_move_reason'  => 'wegsmeten, Platz to maken för Schuven',
 'selfmove'                => 'Utgangs- un Teelnaam sünd desülve; en Siet kann nich över sik sülvst röver schaven warrn.',
 'immobile_namespace'      => 'De Utgangs- oder Teelnaamruum is schuult; Schuven na oder ut dissen Naamruum geiht nich.',
 'imagenocrossnamespace'   => 'Datein köönt nich na buten den {{ns:image}}-Naamruum schaven warrn',
 'imagetypemismatch'       => 'De ne’e Dateiennen passt nich to de ole',
+'imageinvalidfilename'    => 'De ne’e Dateinaam is ungüllig',
+'fix-double-redirects'    => 'All Redirects, de na den olen Titel wiest, op den ne’en ännern',
 
 # Export
 'export'            => 'Sieden exporteren',
@@ -2166,7 +2163,7 @@
 'show-big-image'       => 'Dat Bild wat grötter',
 'show-big-image-thumb' => '<small>Grött vun disse Vörschau: $1 × $2 Pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Ne’e Biller',
 'imagelisttext'         => 'Hier is en List vun {{PLURAL:$1|een Bild|$1 Biller}}, sorteert $2.',
 'newimages-summary'     => 'Disse Spezialsiet wiest de Datein, de toletzt hoochladen worrn sünd.',
@@ -2448,7 +2445,7 @@
 
 # External editor support
 'edit-externally'      => 'Änner disse Datei mit en extern Programm',
-'edit-externally-help' => '<span class="plainlinks">Lees de [http://meta.wikimedia.org/wiki/Help:External_editors Installatschoonshelp] wenn du dor mehr to weten wist.</span>',
+'edit-externally-help' => '<span class="plainlinks">Lees de [http://www.mediawiki.org/wiki/Manual:External_editors Installatschoonshelp] wenn du dor mehr to weten wist.</span>',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'all',
@@ -2510,7 +2507,7 @@
 'recreate'            => 'wedder nee anleggen',
 
 # HTML dump
-'redirectingto' => 'Redirect sett na [[$1]]...',
+'redirectingto' => 'Redirect sett na [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Den Cache vun disse Siet leddig maken?
@@ -2557,8 +2554,8 @@
 Versöök de normale Vörschau.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Ännern, de jünger as $1 Sekunnen sünd, warrt in de List noch nich wiest.',
-'lag-warn-high'   => 'De Datenbank is temlich dull utlast. Ännern, de jünger as $1 Sekunnen sünd, warrt in de List noch nich wiest.',
+'lag-warn-normal' => 'Ännern, de jünger as {{PLURAL:$1|ene Sekunn|$1 Sekunnen}} sünd, warrt in de List noch nich wiest.',
+'lag-warn-high'   => 'De Datenbank is temlich dull utlast. Ännern, de jünger as $1 {{PLURAL:$1|Sekunn|Sekunnen}} sünd, warrt in de List noch nich wiest.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Du hest {{PLURAL:$1|ene Siet|$1 Sieden}} op diene Oppasslist, Diskuschoonssieden nich tellt.',
@@ -2608,7 +2605,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Dateipadd',
 'filepath-page'    => 'Datei:',
 'filepath-submit'  => 'Padd',
@@ -2646,7 +2643,7 @@
 'specialpages-group-redirects'   => 'Redirect-Spezialsieden',
 'specialpages-group-spam'        => 'Spam-Warktüüch',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Leddige Sied',
 'intentionallyblankpage' => 'Disse Sied is mit Afsicht leddig.',
 
Index: languages/messages/MessagesWo.php
===================================================================
--- languages/messages/MessagesWo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesWo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,11 +5,7 @@
  * @file
  *
  * @author Ibou
- * @author Siebrand
  * @author SF-Language
- * @author SPQRobin
- * @author M.M.S.
- * @author Jon Harald Søby
  */
 
 $fallback = 'fr';
@@ -77,42 +73,42 @@
 'thu'           => 'alx',
 'fri'           => 'ajj',
 'sat'           => 'gaa',
-'january'       => 'Tamxarit',
-'february'      => 'Diggi-gamu',
-'march'         => 'Gamu',
-'april'         => 'Rakki-gamu',
-'may_long'      => 'Rakkaati-gamu',
-'june'          => 'Maami-koor',
-'july'          => 'Ndeyi-koor',
-'august'        => 'Baraxlu',
-'september'     => 'Koor',
-'october'       => 'Kori',
-'november'      => 'Diggi-tabaski',
-'december'      => 'Tabaski',
-'january-gen'   => 'Tamxarit',
-'february-gen'  => 'Diggi-gamu',
-'march-gen'     => 'Gamu',
-'april-gen'     => 'Rakki-gamu',
-'may-gen'       => 'Rakkaati-gamu',
-'june-gen'      => 'Maami-koor',
-'july-gen'      => 'Ndeyi-koor',
-'august-gen'    => 'Baraxlu',
-'september-gen' => 'Koor',
-'october-gen'   => 'Kori',
-'november-gen'  => 'Diggi-tabaski',
-'december-gen'  => 'Tabaski',
-'jan'           => 'Tam',
-'feb'           => 'Dig',
-'mar'           => 'Gam',
-'apr'           => 'Rak',
-'may'           => 'Rakkaati',
-'jun'           => 'Maa',
-'jul'           => 'Nde',
-'aug'           => 'Bar',
-'sep'           => 'Koo',
-'oct'           => 'Kor',
-'nov'           => 'Diggi-ta',
-'dec'           => 'Tab',
+'january'       => 'Samwiye',
+'february'      => 'Fewiriye',
+'march'         => 'Maars',
+'april'         => 'Awril',
+'may_long'      => 'Mee',
+'june'          => 'Suwe',
+'july'          => 'Sulet',
+'august'        => 'Ut',
+'september'     => 'Sattumbar',
+'october'       => 'Oktoobar',
+'november'      => 'Nowembar',
+'december'      => 'Disembar',
+'january-gen'   => 'Samwiriye',
+'february-gen'  => 'Fewiriye',
+'march-gen'     => 'Maars',
+'april-gen'     => 'Awril',
+'may-gen'       => 'Mee',
+'june-gen'      => 'Suwe',
+'july-gen'      => 'Sulet',
+'august-gen'    => 'Ut',
+'september-gen' => 'Sattumbar',
+'october-gen'   => 'Oktoobar',
+'november-gen'  => 'Nowembar',
+'december-gen'  => 'Disembar',
+'jan'           => 'Sam',
+'feb'           => 'Few',
+'mar'           => 'Maa',
+'apr'           => 'Awr',
+'may'           => 'Mee',
+'jun'           => 'Suw',
+'jul'           => 'Sul',
+'aug'           => 'Ut',
+'sep'           => 'Sat',
+'oct'           => 'Okt',
+'nov'           => 'Now',
+'dec'           => 'Dis',
 
 # Categories related messages
 'pagecategories'                 => '{{PLURAL:$1|Wàll |Wàll }}',
@@ -288,7 +284,7 @@
 'nosuchspecialpage' => 'Xëtu jagleel wu amul',
 'nospecialpagetext' => "<big>'''Da nga laaj aw xëtu jagleel wu wiki bi xamul.'''</big>
 
-Ab limu xëti jagleel yépp, ma nees na koo gis ci [[Special:Specialpages|{{int:specialpages}}]].",
+Ab limu xëti jagleel yépp, ma nees na koo gis ci [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Njuumte',
@@ -310,9 +306,11 @@
 
 Li koy waral yenn saa yi mooy da ngay jéma ubbi ab lëkkalekaay, jaare ko ci ab jaar-jaar walla méngaleeb ay sumb yu aw xët wu faru.
 
-Su dul loolu kon daa am ag njuumte ci tëriinu Mediawiki bi. Di la sakku nga yegge ko ab yorkat, jox ko URL bi.',
+Su dul loolu kon daa am ag njuumte ci tëriinu Mediawiki bi. 
+Di la sakku nga yegge ko ab [[Special:ListUsers/sysop|yorkat]] , jox ko màkkaan bi.',
 'missingarticle-rev'   => '(Limu sumb mi# : $1)',
-'readonly_lag'         => 'Dattub njoxe bi daa caabiwu ngir may ñaareeli joxekat yi dap joxekat bu njëkk bi.',
+'missingarticle-diff'  => '(Wuute : $1, $2)',
+'readonly_lag'         => 'Dàttub njoxe bi daa caabi boppam ngir may ñaareelu joxekaay yi dap joxekaay bu njëkk bi.',
 'internalerror'        => 'Njuumte gu biir',
 'internalerror_info'   => 'Njuumte gu biir : $1',
 'filecopyerror'        => 'Duppig dencukaay bii di « $1 » jëm « $2 » antuwul.',
@@ -338,6 +336,7 @@
 'actionthrottledtext'  => 'Ngir xeex spam yi, jëf ji nga namm a def dañ kaa digal ci yoon yoo ko man ci benn diir bu gatt. Te mel na ne romb nga boobu dig. Jéemaatal fii aki simili.',
 'protectedpagetext'    => 'Wii xêt dañ kaa aar ngir bañ ag coppiteem.',
 'viewsourcetext'       => 'Man ngaa xool te duppi li nekk ci bii jukki ngir man cee liggéey :',
+'protectedinterface'   => 'Xët wii dafa am ay mbind yu bokk ci jokkalekaayu tëriin wi, moo tax ñu caabi ko ngir bañ ku ci ëppal.',
 'sqlhidden'            => '(Laaju SQL nëbbu na)',
 'cascadeprotected'     => 'Xët wii dañ kaa aar ndaxte daa ëmbu ci {{PLURAL:$1|xët wi toftal|xët yi toftal}}, di yu ñu aar :
 $2',
@@ -503,10 +502,6 @@
 'blockededitsource'         => "Ëmbitu '''say coppite''' yi nga def fii '''$1''' mooy lii ci suuf:",
 'whitelistedittitle'        => 'Laaj na nga bindu ngir man a soppi ëmbit li',
 'whitelistedittext'         => 'Faaw nga doon $1 ngir am sañ-sañu soppi ëmbit li.',
-'whitelistreadtitle'        => 'Laaj na nga bindu ngir man a jàng ëmbit li',
-'whitelistreadtext'         => 'Ngir man a jàng ëmbit li, laaj na nga [[Special:Userlogin|duggu]].',
-'whitelistacctitle'         => 'Amoo sañ-sañu bindu.',
-'whitelistacctext'          => 'Ngir nga man a sos yeneeni sàq ci bii wiki, laaj na nga [[Special:Userlogin|duggu]] te it xaar ba am sañ-sañ yi mu laaj.',
 'confirmedittitle'          => 'Laaj na nga dëggal sa m-bataaxal ngir man a soppi xët yi',
 'confirmedittext'           => 'Ngir man a soppi dara faaw nga dëggal sa m-bataaxal. Ngir kocc-koccal walla dëggal sa màkkaan demal ci say [[Special:Preferences|tànneef]].',
 'nosuchsectiontitle'        => 'Xaaj bi amul',
@@ -518,7 +513,7 @@
 'accmailtext'               => 'Baatujàll bu « $1 » yónne nañ ko ci bii màkkaan $2.',
 'newarticle'                => '(Bees)',
 'newarticletext'            => "Da ngaa topp ab lëkkalekaay buy jëme ci aw xët wu amagul. ngir sos xët wi léegi, duggalal sa mbind ci boyot bii ci suuf (man ngaa yër [[{{MediaWiki:Helppage}}|xëtu ndimbal wi]] ngir yeneeni xamle). Su fekkee njuumtee la fi indi cuqal ci '''dellu''' bu sa joowukaay.",
-'anontalkpagetext'          => "---- ''Yaa ngi ci xëtu waxtaanuwaayu ab jëfandikukat bu kenn-xamul, bu bindoogul walla du jëfandikoo sàqam. Kon ngir xamme ko faaw nga jëfandikoo màkkaanub IP wan. Te màkkaanub IP jëfandikukat yu bari man nañ ka bokk. Su fekkee jëfandikukat bu kenn-xamul nga, te nga gis ne dañ laa féetale ay sànni-kaddu yoo moomul, man ngaa [[Special:Userlogin|bindu walla duggu]] ngi benn jaxase bañatee am ëllëg .''",
+'anontalkpagetext'          => "---- ''Yaa ngi ci xëtu waxtaanuwaayu ab jëfandikukat bu kenn-xamul, bu bindoogul walla du jëfandikoo sàqam. Kon ngir xamme ko faaw nga jëfandikoo màkkaanub IP wan. Te màkkaanub IP jëfandikukat yu bari man nañ ka bokk. Su fekkee jëfandikukat bu kenn-xamul nga, te nga gis ne dañ laa féetale ay sànni-kaddu yoo moomul, man ngaa [[Special:UserLogin|bindu walla duggu]] ngi benn jaxase bañatee am ëllëg .''",
 'noarticletext'             => 'Fi mu ne ni amul benn mbind ci xët wii; man ngaa [[Special:Search/{{PAGENAME}}|tambli ab seet ci koju xët wii]] walla [{{fullurl:{{FULLPAGENAME}}|action=edit}} soppi xët wii].',
 'userpage-userdoesnotexist' => 'Bii sàqum jëfandikukat « $1 » du bu ku bindu. Seetal bu baax ndax da ngaa namma sos walla soppi wii xët.',
 'clearyourcache'            => "'''Karmat :''' Soo dence xët wi ba noppi, faaw nga bës ci si sa arafukaay yii di toftal, te nga bàyyi xel ci joowukaay bi ngay jëfandikoo : '''Mozilla / Konqueror / Firefox :''' ''Shift-Ctrl-R'', '''Internet Explorer / Opera :''' ''Ctrl-F5'', '''Safari :''' ''Cmd-R''.",
@@ -576,7 +571,7 @@
 'template-semiprotected'    => '(aaru-diggu)',
 'hiddencategories'          => '{{PLURAL:$1|wàll bu nëbbu bu|wàll yu nëbbu yu }} xët wii bokk :',
 'nocreatetitle'             => 'Digalu sosteefu xët',
-'nocreatetext'              => 'Jëfandikukat yi bindu rekk a man a sosi xët ci {{SITENAME}}. Man nga dellu ginnaaw walla soppi aw xët wu am ba noppi, [[Special:Userlogin|duggu walla sos am sàq]].',
+'nocreatetext'              => 'Jëfandikukat yi bindu rekk a man a sosi xët ci {{SITENAME}}. Man nga dellu ginnaaw walla soppi aw xët wu am ba noppi, [[Special:UserLogin|duggu walla sos am sàq]].',
 'nocreate-loggedin'         => 'Amuloo sañ-sañ yu doy ngir man a sosi xët yu bees ci {{SITENAME}}.',
 'permissionserrors'         => 'Njuumte ci sañ-sañ yi',
 'permissionserrorstext'     => 'Amuloo sañ-sañu àggali jëf ji nga tambali, ngax {{PLURAL:$1|lii toftal|yii toftal}} :',
@@ -708,7 +703,7 @@
 'mypreferences'            => 'Samay tànneef',
 'prefs-edits'              => 'Limu coppite yi:',
 'prefsnologin'             => 'Duggoo',
-'prefsnologintext'         => 'Laaj na nga [[Special:Userlogin|duggu]] ngir soppi say tànneef.',
+'prefsnologintext'         => 'Laaj na nga [[Special:UserLogin|duggu]] ngir soppi say tànneef.',
 'prefsreset'               => 'Tànneef yi loppanti nañ leen.',
 'qbsettings'               => 'Banqaasu jumtukaay',
 'qbsettings-none'          => 'Kenn',
@@ -788,7 +783,7 @@
 'uploadbtn'                   => 'Yeb dencukaay bi',
 'reupload'                    => 'Yebaat ko',
 'uploadnologin'               => 'Lonkuwoo',
-'uploadnologintext'           => 'Faaw nga [[Special:Userlogin|lonku]] ngir mana yebi dencukaay.',
+'uploadnologintext'           => 'Faaw nga [[Special:UserLogin|lonku]] ngir mana yebi dencukaay.',
 'upload_directory_missing'    => 'Wayndareb yeb bu ($1) nekku fi te joxekaayub web bi manu koo sos.',
 'upload_directory_read_only'  => 'Joxekaayub web bi manuta bind ci wayndareb yeb bu ($1).',
 'uploaderror'                 => 'Njuumte ci yeb gi',
@@ -804,7 +799,7 @@
 'filestatus'                  => 'Ay xibaar ci aqi aji-sos :',
 'filesource'                  => 'Gongikuwaay :',
 'uploadedfiles'               => 'Dencukaay yiñ fi yeb',
-'ignorewarning'               => 'tanqamlu aartu gi te daggal dencukaay bi.',
+'ignorewarning'               => 'Tanqamlu aartu gi te duggal dencukaay bi.',
 'ignorewarnings'              => 'tanqamlu bépp aartu',
 'minlength1'                  => 'Turu dencukaay bi war na am benn araf lumu néew néew.',
 'illegalfilename'             => 'Turu dencukaay bu « $1 » am na ay araf yuñ dul nangu ci boppi xët yi. Jox ko beneen tur te jéemaat koo yeb.',
@@ -846,7 +841,7 @@
 
 Jaar-jaaru far gi man na laa dimbali ci nga see ndaxam jar na nga yebaat ko.",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => 'Limu nataal yi',
 'imagelist_user' => 'Jëfëndikookat',
 
@@ -915,7 +910,7 @@
 'log-search-submit'    => 'waaw',
 'logempty'             => 'Dara nekkul ci jaar-jaaru xët mii.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'         => 'Xët yëpp',
 'alphaindexline'   => '$1 ba $2',
 'nextpage'         => 'Xët wi tegu ($1)',
@@ -934,7 +929,7 @@
 'special-categories-sort-count' => 'nose sàq',
 'special-categories-sort-abc'   => 'nose abajada',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Wone',
 
 # E-mail user
@@ -952,7 +947,7 @@
 'nowatchlist'          => 'Sa limu toppte amul benn jukki.',
 'watchlistanontext'    => 'Ngir mana gis walla soppi jëfkayu sa limu toppte, faw nga  $1.',
 'watchnologin'         => 'Duggoo de',
-'watchnologintext'     => 'Yaa wara nekk [[Special:Userlogin|duggal]] ngir soppi lim gi.',
+'watchnologintext'     => 'Yaa wara nekk [[Special:UserLogin|duggal]] ngir soppi lim gi.',
 'addedwatch'           => 'Yokk ci sa limu toppte',
 'removedwatch'         => 'Jëlee ci sa limu toppte',
 'watch'                => 'Topp',
@@ -1010,7 +1005,7 @@
 'autoblocker'                 => 'Dañ la téye ndax sa màkkanu IP « $1 » moo ko mujje jëfandikoo. Li waral téyeg $1 mooy ne : « $2 ».',
 'blocklogpage'                => 'Jaar-jaaru téye yi',
 'blocklogentry'               => 'moo téye « [[$1]] » - ci diirub : $2 $3',
-'blocklogtext'                => 'Lii ab lim la ci téye ak téyedi yu jëfandikukat yi. Màkkaani IP yi ñu téye cig boppal limu ñu leen fi. yëral [[Special:Ipblocklist|limu jëfandikukat yiñ téye]] ngi gis ñi ñu téye nii-nii.',
+'blocklogtext'                => 'Lii ab lim la ci téye ak téyedi yu jëfandikukat yi. Màkkaani IP yi ñu téye cig boppal limu ñu leen fi. yëral [[Special:IPBlockList|limu jëfandikukat yiñ téye]] ngi gis ñi ñu téye nii-nii.',
 'unblocklogentry'             => 'moo téyedi « $1 »',
 'block-log-flags-anononly'    => 'jëfandikukat yi binduwul rek',
 'block-log-flags-nocreate'    => 'Tere nañ sa sosum sàq',
@@ -1046,7 +1041,6 @@
 # Move page
 'move-page-legend' => 'Tuddewaat aw xët',
 'movearticle'      => 'Tuddewaatal jukki bi',
-'movenologintext'  => 'Ngir man a tuddewaat aw xët, da ngaa war a [[Special:Userlogin|dugg]] ni jëfëndikookat bu bindu te saw sàq war naa am yaggaa bi mu laaj.',
 'newtitle'         => 'Koj bu bees',
 'move-watch'       => 'Topp xët wii',
 'articleexists'    => 'Am na ba noppi ab jukki gu am gii koj, walla koj gi nga tann baaxul. tannal bennen.',
@@ -1183,7 +1177,7 @@
 'file-info-size' => '($1 × $2 pixels, réyaayu file bi : $3, type MIME : $4)',
 'show-big-image' => 'Ngandalal nataal gii',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Seet',
 'bydate'   => 'ci diir',
 
Index: languages/messages/MessagesKrj.php
===================================================================
--- languages/messages/MessagesKrj.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKrj.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -214,7 +214,7 @@
 
 'upload-file-error' => 'Sayup internal',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile' => 'inayap',
 
 # File deletion
@@ -234,7 +234,7 @@
 # Special:Categories
 'categories' => 'Manga Kategorya',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Ipakita',
 
 # E-mail user
@@ -263,7 +263,7 @@
 'tooltip-ca-delete'  => 'Paraun ang dya nga Pahina',
 'tooltip-p-logo'     => 'Pono nga Pahina',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Sagap',
 
 # action=purge
@@ -278,7 +278,7 @@
 # Special:Version
 'version-specialpages' => 'Manga espesyal nga pahina',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Inayap:',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesIke_latn.php
===================================================================
--- languages/messages/MessagesIke_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIke_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author M.M.S.
  */
 
 $messages = array(
@@ -237,7 +235,7 @@
 # Special:Log
 'log-search-submit' => 'aivuk',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'sunamittuq mappitaq',
 'nextpage'       => 'tagga mappitaq ($1)',
 'allpagesprev'   => 'tunullipaaq',
@@ -333,7 +331,7 @@
 'previousdiff' => '← tunullipaaq asiaNngutuq',
 'nextdiff'     => 'tagga asiaNngutuq mappitaq →',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ivaaqpuq',
 'bydate'   => 'pitaaruttuq inuulirvik',
 
@@ -350,7 +348,7 @@
 'monthsall' => 'sunamittuq',
 
 # HTML dump
-'redirectingto' => 'qaningani kamagijaq aasit nakit [[$1]]...',
+'redirectingto' => 'qaningani kamagijaq aasit nakit [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'akaujuq',
Index: languages/messages/MessagesSt.php
===================================================================
--- languages/messages/MessagesSt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -123,7 +123,7 @@
 'longpages'      => 'Maqephe a matelele',
 'newpages'       => 'Maqephe a matjha',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Maqephe ohle',
 
 # Special:Categories
Index: languages/messages/MessagesLa.php
===================================================================
--- languages/messages/MessagesLa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,12 @@
  * @ingroup Language
  * @file
  *
+ * @author LeighvsOptimvsMaximvs
+ * @author Omnipaedista
+ * @author Rafaelgarcia
+ * @author SPQRobin
  * @author UV
- * @author SPQRobin
- * @author Rafaelgarcia
  * @author לערי ריינהארט
- * @author Omnipaedista
- * @author Siebrand
- * @author LeighvsOptimvsMaximvs
  */
 
 $skinNames = array(
@@ -396,7 +395,7 @@
 'nosuchspecialpage' => 'Pagina specialis non est',
 'nospecialpagetext' => "<big>'''Paginam specialem invalidam petivisti.'''</big>
 
-Pro indice paginarum specialum validarum, vide [[Special:Specialpages|{{int:specialpages}}]].",
+Pro indice paginarum specialum validarum, vide [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erratum',
@@ -571,9 +570,6 @@
 'blockededitsource'         => "Textus '''tuarum emendationum''' in '''$1''' subter monstratur:",
 'whitelistedittitle'        => 'Conventum aperiendum ut recenseas',
 'whitelistedittext'         => 'Necesse est tibi $1 priusquam paginas recenseas.',
-'whitelistreadtitle'        => 'Conventum aperiendum ut legas',
-'whitelistreadtext'         => 'Necesse est tibi [[Special:Userlogin|conventum aperire]] priusquam paginas legas.',
-'whitelistacctitle'         => 'Non licet tibi rationem creare',
 'confirmedittitle'          => 'Adfirmanda est inscriptio tua electronica prisuquam recenseas',
 'confirmedittext'           => 'Tua inscriptio electronica est adfirmanda priusquam paginas recenseas. Quaesumus eam selige et adfirma per tuas [[Special:Preferences|praeferentias]].',
 'nosuchsectiontitle'        => 'Haec pars non est',
@@ -588,7 +584,7 @@
 Novam paginam si vis creare, in capsam infra praebitam scribe.
 (Vide [[{{MediaWiki:Helppage}}|paginam auxilii]] si plura cognoscere vis.)
 Si hic es propter errorem, solum '''Retrorsum''' in navigatro tuo preme.",
-'anontalkpagetext'          => "---- ''Haec est pagina disputationis usoris anonymi, solum a loco IP suo noti. Memento locos IP aliquando mutaturos, et a usoribus multis fortasse adhibitos. Si es usor ignotus, et tibi querulae sine ratione datae sunt, conventum [[Special:Userlogin|aperi vel crea]] ad confusionem solvendam. Nota locum IP tuum concelatum esse convento aperto si de rebus privatis tuis es sollicitatus.''",
+'anontalkpagetext'          => "---- ''Haec est pagina disputationis usoris anonymi, solum a loco IP suo noti. Memento locos IP aliquando mutaturos, et a usoribus multis fortasse adhibitos. Si es usor ignotus, et tibi querulae sine ratione datae sunt, conventum [[Special:UserLogin|aperi vel crea]] ad confusionem solvendam. Nota locum IP tuum concelatum esse convento aperto si de rebus privatis tuis es sollicitatus.''",
 'noarticletext'             => 'In hac pagina nondum litterae sunt. Potes etiam [[Special:Search/{{PAGENAME}}|hanc rem in aliis paginis quaerere]] aut [{{fullurl:{{FULLPAGENAME}}|action=edit}} hanc paginam creare].',
 'userpage-userdoesnotexist' => 'Usor "$1" non est. Visne re vera hanc paginam creare vel recensere?',
 'updated'                   => '(Novata)',
@@ -723,7 +719,7 @@
 'mypreferences'            => 'Praeferentiae meae',
 'prefs-edits'              => 'Numerus recensionum:',
 'prefsnologin'             => 'Conventum non apertum',
-'prefsnologintext'         => '[[Special:Userlogin|Conventum aperire]] debes ut praeferentiae tuae perscribere.',
+'prefsnologintext'         => '[[Special:UserLogin|Conventum aperire]] debes ut praeferentiae tuae perscribere.',
 'prefsreset'               => 'Praeferentiae tuae reperscriptae sunt.',
 'qbsettings'               => 'Figuratio claustri celeris',
 'qbsettings-none'          => 'Nullus',
@@ -789,12 +785,13 @@
 'group-bureaucrat' => 'Grapheocrates',
 'group-all'        => '(omnes)',
 
-'group-user-member'       => 'Usor',
-'group-bot-member'        => 'Automaton',
-'group-sysop-member'      => 'Magistratus',
-'group-bureaucrat-member' => 'Grapheocrates',
+'group-user-member'       => 'usor',
+'group-bot-member'        => 'automaton',
+'group-sysop-member'      => 'magistratus',
+'group-bureaucrat-member' => 'grapheocrates',
 
 'grouppage-user'       => '{{ns:project}}:Usores',
+'grouppage-bot'        => '{{ns:project}}:Automata',
 'grouppage-sysop'      => '{{ns:project}}:Magistratus',
 'grouppage-bureaucrat' => '{{ns:project}}:Grapheocrates',
 
@@ -855,6 +852,7 @@
 'show'                              => 'monstrare',
 'minoreditletter'                   => 'm',
 'newpageletter'                     => 'N',
+'boteditletter'                     => 'a',
 'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|usor custodiens|usores custodientes}}]',
 'rc_categories_any'                 => 'Ulla',
 'newsectionsummary'                 => '/* $1 */ nova pars',
@@ -871,10 +869,10 @@
 'reupload'           => 'Iterum imponere',
 'reuploaddesc'       => 'Siste imponere et ad imponendi formam redi',
 'uploadnologin'      => 'Conventum non apertum est',
-'uploadnologintext'  => 'Oportet [[Special:Userlogin|aperire conventum]] ut fasciculos imponas.',
+'uploadnologintext'  => 'Oportet [[Special:UserLogin|aperire conventum]] ut fasciculos imponas.',
 'uploaderror'        => 'Imponendi erratum',
 'uploadtext'         => "Utere formam subter ad fasciculos imponendos.
-Ut fasciculos antea impositos videas aut quaeras, adi ad [[Special:Imagelist|indicem fasciculorum impositorum]]. Fasciculi impositi et deleti quoque in [[Special:Log/upload|notatione fasciculorum impositorum]] notantur.
+Ut fasciculos antea impositos videas aut quaeras, adi ad [[Special:ImageList|indicem fasciculorum impositorum]]. Fasciculi impositi et deleti quoque in [[Special:Log/upload|notatione fasciculorum impositorum]] notantur.
 
 Ad fasciculum in pagina includendum, utere nexu
 '''<nowiki>[[</nowiki>{{ns:image}}:Fasciculus.jpg]]''' aut
@@ -916,7 +914,7 @@
 
 'license-nopreview' => '(Praevisum monstrari non potest)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'fasciculus',
 'imagelist'             => 'Fasciculorum index',
 'imagelist_name'        => 'Nomen',
@@ -939,7 +937,7 @@
 'imagelinks'                => 'Nexus',
 'linkstoimage'              => '{{PLURAL:$1|Haec pagina ad hunc fasciculum nectit:|Hae $1 paginae ad hunc fasciculum nectunt:}}',
 'nolinkstoimage'            => 'Nullae paginae ad hunc fasciculum nectunt.',
-'morelinkstoimage'          => 'Videre [[Special:Whatlinkshere/$1|plures nexus]] ad hunc fasciculum.',
+'morelinkstoimage'          => 'Videre [[Special:WhatLinksHere/$1|plures nexus]] ad hunc fasciculum.',
 'redirectstofile'           => '{{PLURAL:$1|Fasciculus sequens ad hunc fasciculum redirigit:|Hae $1 fasciculi sequentes ad hunc fasciculum redirigunt:}}',
 'noimage'                   => 'Fasciculus huius nominis non est. $1 potes.',
 'noimage-linktext'          => 'Fasciculum huius nominis imponere',
@@ -947,17 +945,17 @@
 
 # File reversion
 'filerevert-legend'         => 'Reverti fasciculum',
-'filerevert-intro'          => '<span class="plainlinks">Reverteris \'\'\'[[Media:$1|$1]]\'\'\' ad [emendationem $4 ex $3, $2].</span>',
+'filerevert-intro'          => "Reverteris '''[[Media:$1|$1]]''' ad [emendationem $4 ex $3, $2].",
 'filerevert-comment'        => 'Sententia:',
 'filerevert-defaultcomment' => 'Reverti ad emendationem ex $2, $1',
 'filerevert-submit'         => 'Revertere',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' reversum est ad [emendationem $4 ex $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' reversum est ad [emendationem $4 ex $3, $2].",
 
 # File deletion
 'filedelete'                  => 'Delere $1',
 'filedelete-legend'           => 'Fasciculum delere',
 'filedelete-intro'            => "Deles '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Deles fasciculi \'\'\'[[Media:$1|$1]]\'\'\' emendationem [$4 ex $3, $2].</span>',
+'filedelete-intro-old'        => "Deles fasciculi '''[[Media:$1|$1]]''' emendationem [$4 ex $3, $2].",
 'filedelete-comment'          => 'Causa deletionis:',
 'filedelete-submit'           => 'Delere',
 'filedelete-success'          => "'''$1''' deletum est.",
@@ -1002,7 +1000,7 @@
 Hoc aequat fere '''$5''' mutationes per paginam, et '''$6''' visae per mutationem.
 
 '''$7''' [http://www.mediawiki.org/wiki/Manual:Job_queue operationes etiam exspectant perfacier].",
-'userstatstext' => "'''$1''' {{PLURAL:$1|[[Special:Listusers|usor]] relatus est|[[Special:Listusers|usores]] relati sunt}}, quorum '''$2''' (vel '''$4%''') {{PLURAL:$2|est|sunt}} $5.",
+'userstatstext' => "'''$1''' {{PLURAL:$1|[[Special:ListUsers|usor]] relatus est|[[Special:ListUsers|usores]] relati sunt}}, quorum '''$2''' (vel '''$4%''') {{PLURAL:$2|est|sunt}} $5.",
 
 'disambiguations'      => 'Paginae disambiguationis',
 'disambiguationspage'  => 'Template:Discretiva',
@@ -1010,15 +1008,17 @@
 Eae ad aptas paginas magis nectendae sunt.<br />
 Pagina discretivam esse putatur si formulam adhibet ad quem [[MediaWiki:Disambiguationspage]] nectit.",
 
-'doubleredirects' => 'Redirectiones duplices',
+'doubleredirects'            => 'Redirectiones duplices',
+'double-redirect-fixed-move' => '[[$1]] mota est et nunc redirigit ad [[$2]]',
+'double-redirect-fixer'      => 'Rectificator redirectionum',
 
 'brokenredirects'        => 'Redirectiones fractae',
-'brokenredirectstext'    => 'Hae redirectiones ad paginas inexistentes nectunt:',
+'brokenredirectstext'    => 'Hae redirectiones ad paginas inexistentes nectunt.',
 'brokenredirects-edit'   => '(recensere)',
 'brokenredirects-delete' => '(delere)',
 
 'withoutinterwiki'         => 'Paginae sine nexibus ad linguas alias',
-'withoutinterwiki-summary' => 'Paginae sequentes non ad paginas in linguis aliis nectunt:',
+'withoutinterwiki-summary' => 'Paginae sequentes non ad paginas in linguis aliis nectunt.',
 'withoutinterwiki-legend'  => 'Praefixum',
 'withoutinterwiki-submit'  => 'Monstrare',
 
@@ -1083,7 +1083,7 @@
 Adspectum graciliorem potes facere modum indicum, nomen usoris, vel titulum paginae seligendo.',
 'log-title-wildcard'   => 'Quaerere titulos qui incipiunt litteris',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Paginae omnes',
 'alphaindexline'    => '$1 ad $2',
 'nextpage'          => 'Pagina proxima ($1)',
@@ -1105,7 +1105,7 @@
 'special-categories-sort-count' => 'ordinare secundum numerum',
 'special-categories-sort-abc'   => 'ordinare secundum abecedarium',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Monstrare',
 
 # E-mail user
@@ -1132,9 +1132,9 @@
 'nowatchlist'          => 'Nullas paginas custodis.',
 'watchlistanontext'    => 'Necesse est $1 ad indicem paginarum custoditarum inspiciendum vel recensendum.',
 'watchnologin'         => 'Conventum non est apertum',
-'watchnologintext'     => '[[Special:Userlogin|Conventum aperire]] debes ut indicem paginarum custoditarum mutes.',
+'watchnologintext'     => '[[Special:UserLogin|Conventum aperire]] debes ut indicem paginarum custoditarum mutes.',
 'addedwatch'           => 'Pagina custodita',
-'addedwatchtext'       => "Pagina \"[[:\$1]]\" in [[Special:Watchlist|paginas tuas custoditas]] addita est. Mutationes posthac huic paginae et paginae disputationis ibi notabuntur, et pagina '''litteris pinguibus''' apparebit in [[Special:Recentchanges|nuper mutatorum]] indice, ut sit facilius electu.
+'addedwatchtext'       => "Pagina \"[[:\$1]]\" in [[Special:Watchlist|paginas tuas custoditas]] addita est. Mutationes posthac huic paginae et paginae disputationis ibi notabuntur, et pagina '''litteris pinguibus''' apparebit in [[Special:RecentChanges|nuper mutatorum]] indice, ut sit facilius electu.
 
 Si paginam ex indice paginarum custoditarum removere vis, imprime \"decustodire\" ab summa pagina.",
 'removedwatch'         => 'Non iam custodita',
@@ -1198,11 +1198,13 @@
 'rollbacklink'              => 'reverti',
 'rollbackfailed'            => 'Reversum defecit',
 'cantrollback'              => 'Haec non potest reverti; conlator proximus solus auctor huius rei est.',
-'alreadyrolled'             => 'Ad mutationem proxima paginae "[[$1]]" ab usore "[[User:$2|$2]]" ([[User talk:$2|disputatio]]) reverti non potest; alius paginam iam recensuit vel revertit. Mutatio proxima ab usore "[[User:$3|$3]]" ([[User talk:$3|disputatio]]) effecta est.',
+'alreadyrolled'             => 'Ad mutationem proximam paginae [[:$1]] ab usore [[User:$2|$2]] ([[User talk:$2|Disputatio]] | [[Special:Contributions/$2|{{int:contribslink}}]]) reverti non potest; alius paginam iam recensuit vel revertit.
+
+Mutatio proxima ab usore [[User:$3|$3]] ([[User talk:$3|Disputatio]] | [[Special:Contributions/$3|{{int:contribslink}}]]) effecta est.',
 'editcomment'               => 'Dictum recensiti erat: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                => 'Reverti recensiones ab usore [[Special:Contributions/$2|$2]] ([[User talk:$2|Disputatio]]) ad mutationem proximam ab [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'protectlogpage'            => 'Index protectionum',
-'protectlogtext'            => 'Subter est index protectionum et deprotectionum paginarum. Vide [[Special:Protectedpages|indicem paginarum nunc protectarum]].',
+'protectlogtext'            => 'Subter est index protectionum et deprotectionum paginarum. Vide [[Special:ProtectedPages|indicem paginarum nunc protectarum]].',
 'protectedarticle'          => 'protegit "[[$1]]"',
 'modifiedarticleprotection' => 'mutavit protectionem paginae "[[$1]]"',
 'unprotectedarticle'        => 'deprotegit "[[$1]]"',
@@ -1275,7 +1277,7 @@
 
 # What links here
 'whatlinkshere'            => 'Nexus ad paginam',
-'whatlinkshere-title'      => 'Paginae quae ad $1 nectunt',
+'whatlinkshere-title'      => 'Paginae quae ad "$1" nectunt',
 'whatlinkshere-page'       => 'Pagina:',
 'linklistsub'              => '(Index nexuum)',
 'linkshere'                => "Hae paginae ad '''[[:$1]]''' nectunt:",
@@ -1308,14 +1310,14 @@
 'badipaddress'             => 'Locus IP male formatus',
 'blockipsuccesssub'        => 'Locus prospere obstructus est',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|$1]] obstructus est.
-<br />Vide [[Special:Ipblocklist|indicem usorum obstructorum]] ut obstructos revideas.',
+<br />Vide [[Special:IPBlockList|indicem usorum obstructorum]] ut obstructos revideas.',
 'ipb-edit-dropdown'        => 'Causas obstructionum recensere',
 'ipb-unblock-addr'         => 'Deobstruere $1',
 'ipb-unblock'              => 'Deobstruere nomen usoris vel locum IP',
 'unblockip'                => 'Deobstruere locum IP',
 'unblockiptext'            => 'Formam inferam usere ut locum IP deobstruere.',
 'ipusubmit'                => 'Deobstruere hanc locum',
-'ipblocklist'              => 'Usores obstructi',
+'ipblocklist'              => 'Usores locique IP obstructi',
 'ipblocklist-legend'       => 'Usorem obstructum quaerere',
 'ipblocklist-username'     => 'Nomen usoris vel locus IP:',
 'ipblocklist-submit'       => 'Quaerere',
@@ -1331,7 +1333,7 @@
 'autoblocker'              => 'Obstructus es automatice quia "[[User:$1|$1]]" nuper tuum locum IP adhibuit. Ratio data ob obstructionem usoris $1 est "\'\'\'$2\'\'\'".',
 'blocklogpage'             => 'Index obstructionum',
 'blocklogentry'            => 'obstruxit [[$1]], exire $2 $3',
-'blocklogtext'             => 'Hic est index actorum obstructionis deobstructionisque. Loci IP qui automatice obstructi sunt non enumerantur. Vide [[Special:Ipblocklist|indicem usorum locorumque IP obstructorum]] pro indice toto.',
+'blocklogtext'             => 'Hic est index actorum obstructionis deobstructionisque. Loci IP qui automatice obstructi sunt non enumerantur. Vide [[Special:IPBlockList|indicem usorum locorumque IP obstructorum]] pro indice toto.',
 'unblocklogentry'          => 'deobstruxit $1',
 'block-log-flags-nocreate' => 'creatio rationum obstructa',
 'block-log-flags-noemail'  => 'Litterae electronicae obstructae',
@@ -1352,18 +1354,18 @@
 'lockdbsuccesssub'    => 'Basis datorum prospere obstructa est',
 'unlockdbsuccesssub'  => 'Basis datorum prospere deobstructa est',
 'lockdbsuccesstext'   => 'Basis datorum obstructa est.
-<br />Memento eam dein [[Special:Unlockdb|deobstruere]].',
+<br />Memento eam dein [[Special:UnlockDB|deobstruere]].',
 'unlockdbsuccesstext' => 'Basis datorum deobstructa est.',
 'databasenotlocked'   => 'Basis datorum non obstructa est.',
 
 # Move page
 'move-page-legend'        => 'Paginam movere',
 'movepagetext'            => "Formam inferam utere ad paginam renominandum et ad historiam eius ad nomen novum movendum.
-Index vetus paginam redirectionis ad indicem novum fiet.
+Titulus vetus paginam redirectionis ad titulum novum fiet.
 Nexus ad paginam veterem non mutabuntur;
 redirectiones duplices aut fractas quaerere et figere debebis.
 
-Pagina '''non''' movebitur si pagina sub indice novo iam est, nisi est vacua aut pagina redirectionis et nullam historiam habet.
+Pagina '''non''' movebitur si pagina sub titulo novo iam est, nisi est vacua aut pagina redirectionis et nullam historiam habet.
 
 '''MONITUM!'''
 Haec mutatio vehemens et improvisa potest esse pro pagina populare;
@@ -1375,9 +1377,7 @@
 
 Ergo manu necesse disputationes motare vel contribuere erit, si vis.",
 'movearticle'             => 'Paginam movere:',
-'movenologin'             => 'Conventum non apertum',
-'movenologintext'         => 'Rationem usoris habere et [[Special:Userlogin|conventum aperire]] debes ad movendum paginam.',
-'newtitle'                => 'Ad indicem novum:',
+'newtitle'                => 'Ad titulum novum:',
 'move-watch'              => 'Hanc paginam custodire',
 'movepagebtn'             => 'Paginam movere',
 'pagemovedsub'            => 'Pagina mota est',
@@ -1398,9 +1398,10 @@
 'revertmove'              => 'reverti',
 'delete_and_move'         => 'Delere et movere',
 'delete_and_move_text'    => '==Deletio necesse est==
-Paginae nomen petitum "[[$1]]" iam existit. Vin tu eam delere ut pagina illic moveatur?',
+Paginae nomen petitum "[[:$1]]" iam existit. Vin tu eam delere ut pagina illic moveatur?',
 'delete_and_move_confirm' => 'Ita, paginam delere',
 'delete_and_move_reason'  => 'Deleta ut moveatur',
+'fix-double-redirects'    => 'Rectificare redirectiones ad titulum veterem',
 
 # Export
 'export'            => 'Paginas exportare',
@@ -1508,9 +1509,10 @@
 'widthheightpage' => '$1×$2, $3 {{PLURAL:$3|pagina|paginae}}',
 'show-big-image'  => 'Resolutio completa',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Fasciculi novi',
 'imagelisttext' => "Subter est index {{PLURAL:$1|'''unius''' fasciculi|'''$1''' fasciculorum}} digestus $2.",
+'showhidebots'  => '($1 automata)',
 'noimages'      => 'Nullum videndum.',
 'ilsubmit'      => 'Quaerere',
 'bydate'        => 'ex die',
@@ -1622,7 +1624,7 @@
 'version-software-product' => 'Productum',
 'version-software-version' => 'Versio',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'      => 'Fasciculorum inscriptio',
 'filepath-page' => 'Fasciculus:',
 
@@ -1633,7 +1635,7 @@
 # Special:SpecialPages
 'specialpages' => 'Paginae speciales',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage' => 'Pagina vacua',
 
 );
Index: languages/messages/MessagesSrn.php
===================================================================
--- languages/messages/MessagesSrn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSrn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Stretsh
  * @author Adfokati
  * @author Jordi
- * @author Siebrand
  * @author Ooswesthoesbes
- * @author Jon Harald Søby
+ * @author Stretsh
  */
 
 $fallback = 'nl';
@@ -291,7 +289,7 @@
 'nosuchspecialpage' => 'A spesrutu papira disi no de',
 'nospecialpagetext' => "<big>'''Yu aksi fu si wan spesrutu papira san no de.'''</big>
 
-Wan réy fu spesrutu papira de fu feni na [[Special:Specialpages|{{int:specialpages}}]].",
+Wan réy fu spesrutu papira de fu feni na [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Fowtu',
@@ -454,9 +452,6 @@
 Yu IP now na $3 en a tapu pasi ID na #$5. Gi wan, noso ala tu, ini yu brifi te yu o skrifi fu aksi san psa.",
 'whitelistedittitle'     => 'Yu mu kon fu a kenki',
 'whitelistedittext'      => 'Yu mu $1 fu a kenki fu peprewoysi.',
-'whitelistreadtitle'     => 'Yu mu kon fu a leysi',
-'whitelistreadtext'      => 'Yu mu [[Special:Userlogin|kon]] fu a leysi fu peprewoysi.',
-'whitelistacctitle'      => 'Yu kan no masyin skopu',
 'loginreqtitle'          => 'Yu mu kon',
 'loginreqlink'           => 'kon',
 'loginreqpagetext'       => 'Yu mu $1 tu a libi si fu trawan peprewoysi.',
@@ -488,7 +483,7 @@
 'template-protected'     => '(a sroto)',
 'template-semiprotected' => '(sroto wan pisi)',
 'nocreatetext'           => '{{SITENAME}} puru den primisi fu meki nyun papira.
-Yu kan go baka fu kenki papira di de kba, noso yu kan [[Special:Userlogin|psa kon noso meki wan account]].',
+Yu kan go baka fu kenki papira di de kba, noso yu kan [[Special:UserLogin|psa kon noso meki wan account]].',
 'recreate-deleted-warn'  => "'''Warskow: yu e meki wan papira, di ben puru fu dyaso kaba, baka.'''
 
 Denki fosi efu na wan bun sani fu meki a papira disi baka. A log buku fu puru sori dyaso gi yepi:",
@@ -686,7 +681,7 @@
 
 'license-nopreview' => '(No fusi)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Suku na gefre:',
 'imgfile'               => 'gefre',
 'imagelist'             => 'Réy fu file',
@@ -721,17 +716,17 @@
 # File reversion
 'filerevert'                => '$1 bakadray',
 'filerevert-legend'         => 'Gefre bakadray',
-'filerevert-intro'          => '<span class="plainlinks">Yu ben \'\'\'[[Media:$1|$1]]\'\'\' bakadrayn tu a [$4 si opo $2, $3]</span>.',
+'filerevert-intro'          => "Yu ben '''[[Media:$1|$1]]''' bakadrayn tu a [$4 si opo $2, $3]",
 'filerevert-comment'        => 'Opotaki:',
 'filerevert-defaultcomment' => 'E bakadray tu a si opo $1, $2',
 'filerevert-submit'         => 'Bakadray',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ben bakadray tu a [$4 si opo $2, $3]</span>.',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ben bakadray tu a [$4 si opo $2, $3]",
 
 # File deletion
 'filedelete'             => '"$1" trowe',
 'filedelete-legend'      => 'Gefre trowe',
 'filedelete-intro'       => "Yu ben '''[[Media:$1|$1]]''' trowen.",
-'filedelete-intro-old'   => '<span class="plainlinks">Yu ben a si fu \'\'\'[[Media:$1|$1]]\'\'\' fu [$4 $3, $2] trowen.</span>',
+'filedelete-intro-old'   => "Yu ben a si fu '''[[Media:$1|$1]]''' fu [$4 $3, $2] trowen.",
 'filedelete-comment'     => 'Opotaki:',
 'filedelete-submit'      => 'Trowe',
 'filedelete-success'     => "'''$1''' ben e trowe.",
@@ -841,7 +836,7 @@
 'log-search-submit'    => 'Go',
 'log-title-wildcard'   => 'Peprewoysi suku dy nanga disi nen bigin',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Ala papira',
 'alphaindexline'    => '$1 te go miti $2',
 'nextpage'          => "A papira d'e kon ($1)",
@@ -857,7 +852,7 @@
 # Special:Categories
 'categories' => 'Den grupu',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Masyin libi si fu:',
 'listusers-submit'   => 'Libi si',
 'listusers-noresult' => 'No masyin dyaso.',
@@ -879,7 +874,7 @@
 'mywatchlist'          => 'Mi Tan luku réy',
 'watchlistfor'         => "(fu '''$1''')",
 'addedwatch'           => 'Presi a yu sirey',
-'addedwatchtext'       => "A papira \"[[:\$1]]\" ben presi a yu [[Special:Watchlist|sirey]]. Folo kenki fu disi papira nanga a taki sey opo [[Special:Watchlist|yu sirey]] nanga sey '''deku''' ini a [[Special:Recentchanges|rey fu bakseywan kenki]].
+'addedwatchtext'       => "A papira \"[[:\$1]]\" ben presi a yu [[Special:Watchlist|sirey]]. Folo kenki fu disi papira nanga a taki sey opo [[Special:Watchlist|yu sirey]] nanga sey '''deku''' ini a [[Special:RecentChanges|rey fu bakseywan kenki]].
 
 Iksi yu wan papira no langar wana si, go na a papira nanga du opo \"No si\" ini a menu.",
 'removedwatch'         => 'Trowe fu yu sirey',
@@ -995,7 +990,6 @@
 * A takipapira ondro a nyun nen da ala ben;
 * Yu a ondroben box odu.",
 'movearticle'      => 'Dribi papira:',
-'movenologin'      => 'No kon',
 'newtitle'         => 'Na nyun papiranen:',
 'move-watch'       => 'Disi papira si',
 'movepagebtn'      => 'Dribi papira',
@@ -1087,7 +1081,7 @@
 'show-big-image'       => 'Moro srapu',
 'show-big-image-thumb' => '<small>Bigi fu a luku-na-fesi disi: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'    => 'Nyun file',
 'showhidebots' => '(Bot $1)',
 'noimages'     => 'Noti a si.',
@@ -1117,7 +1111,7 @@
 
 # External editor support
 'edit-externally'      => 'Kenki a file disi ini wan dorosey wrokosani.',
-'edit-externally-help' => 'Luku ini a [http://meta.wikimedia.org/wiki/Help:External_editors skorobuku fu den seti] gi moro yepi.',
+'edit-externally-help' => 'Luku ini a [http://www.mediawiki.org/wiki/Manual:External_editors skorobuku fu den seti] gi moro yepi.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ala',
Index: languages/messages/MessagesLi.php
===================================================================
--- languages/messages/MessagesLi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Cicero
+ * @author Matthias
  * @author Ooswesthoesbes
  * @author Tibor
- * @author Matthias
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Cicero
- * @author SPQRobin
  */
 
 $fallback = 'nl';
@@ -93,8 +91,8 @@
 'tog-enotifrevealaddr'        => 'Mien e-mailadres tune in e-mailberichter',
 'tog-shownumberswatching'     => "'t Aantal gebroekers tune die deze pazjena volge",
 'tog-fancysig'                => 'Handjteikening zónger link nao dien gebroekerspazjena',
-'tog-externaleditor'          => "Standaard 'ne externe teksbewèrker gebroeke",
-'tog-externaldiff'            => "Standaard 'n extern vergeliekingsprogramma gebroeke",
+'tog-externaleditor'          => "Standaard 'ne externe teksbewèrker gebroeke (noer veur henkels, speciaal instellige zi'jn neudig)",
+'tog-externaldiff'            => "Standaard 'n extern vergeliekingsprogramma gebroeke (noer veur henkels, speciaal instellige zi'jn neudig)",
 'tog-showjumplinks'           => '"gank nao"-toegankelikheidslinks mäögelik make',
 'tog-uselivepreview'          => '"live veurbesjouwing" gebroeke (vereis JavaScript - experimenteel)',
 'tog-forceeditsummary'        => "'ne Meljing gaeve biej 'n laege samevatting",
@@ -365,6 +363,12 @@
 'readonlytext'         => 'De database van {{SITENAME}} is momenteel gesloten voor nieuwe bewerkingen en wijzigingen, waarschijnlijk voor bestandsonderhoud.
 De verantwoordelijke systeembeheerder gaf hiervoor volgende reden op:
 <p>$1',
+'missing-article'      => "In de database is gein inhaald aongetroffe veur de pagina \"\$1\" die tr wéél zaw motte zi'jn (\$2).
+
+Dit kan veurkomme as g'r ein veraalderde verwi'jzing naor 't verschil tusse twee versies van ein pagina volgt of ein versie opvraogt die is verwi'jderd.
+
+As dit neet 't geval is, hebt g'r wééllicht ein faalt in de software gevonge.
+Maok hiervan melding bi'j ein systeembeheerder van {{SITENAME}} en vermeld daorbi'j de URL van deze pagina.",
 'missingarticle-rev'   => '(versienummer: $1)',
 'missingarticle-diff'  => '(Wijziging: $1, $2)',
 'readonly_lag'         => 'De database is automatisch vergrendeld wiele de slave databaseservers synchronisere mèt de master.',
@@ -406,6 +410,11 @@
 'titleprotected'       => "'t aanmake van deze pagina is beveilig door [[User:$1|$1]].
 De gegaeve ree is ''$2''.",
 
+# Virus scanner
+'virus-badscanner'     => 'Slechte configuratie: onbekenge virusscanner: <i>$1</i>',
+'virus-scanfailed'     => 'scanne is mislukt (code $1)',
+'virus-unknownscanner' => 'onbekeng antivirus:',
+
 # Login and logout pages
 'logouttitle'                => 'Aafmèlde gebroeker',
 'logouttext'                 => 'De bis noe aafgemèld. De kins {{SITENAME}} noe anoniem (mit vermèlding van IP adres) gebroeke, of opnuui aanmèlde onger dezelfde of ein anger naam.',
@@ -458,7 +467,7 @@
 'nouserspecified'            => "Doe deens 'ne gebroekersnaam op te gaeve.",
 'wrongpassword'              => "'t Ingegaeve wachwaord is neet zjus. Perbeer 't obbenuujts.",
 'wrongpasswordempty'         => "'t Ingegaeve wachwoord waor laeg. Perbeer 't obbenuujts.",
-'passwordtooshort'           => "Dien wachwaord is te kort. 't Mót minstes oet $1 teikes besjtaon.",
+'passwordtooshort'           => "Dien wachwaord is te kort. 't Mót minstes oet {{PLURAL:$1|1 teike|$1 teikes}} besjtaon.",
 'mailmypassword'             => "Sjik mich 'n nuuj wachwaord",
 'passwordremindertitle'      => 'Nuuj tiedelik wachwaord van {{SITENAME}}',
 'passwordremindertext'       => 'Emes (waarsjienliek dich zelf) vanaaf IP-adres $1 haet verzoch u een nieuw wachtwoord voor {{SITENAME}} toe te zenden ($4). Het nieuwe wachtwoord voor gebroeker "$2" is "$3". Advies: nu aanmelden en uw wachtwoord wijzigigen.',
@@ -469,7 +478,7 @@
 'eauthentsent'               => "Dao is 'ne bevèstigingse-mail nao 't genomineerd e-mailadres gesjik.
 Iedat anger mail nao dat account versjik kan weure, mós te de insjtructies in daen e-mail volge,
 óm te bevèstige dat dit wirkelik dien account is.",
-'throttled-mailpassword'     => "'n Wachwaordherinnering wörd gedurende de letste $1 oer verzönje. Om misbroek te veurkomme, wörd d'r sjlechs éin herinnering per $1 oer verzönje.",
+'throttled-mailpassword'     => "'n Wachwaordherinnering wörd gedurende de letste {{PLURAL:$1|1 oer|$1 oer}} verzönje. Om misbroek te veurkomme, wörd d'r sjlechs éin herinnering per {{PLURAL:$1|oer|$1 oer}} verzönje.",
 'mailerror'                  => "Fout bie 't versjture van mail: $1",
 'acct_creation_throttle_hit' => "Sorry, de höbs al $1 accounts aangemak. De kins d'r gein mië aanmake.",
 'emailauthenticated'         => 'Dien e-mailadres is op $1 geauthentiserd.',
@@ -562,10 +571,6 @@
 'blockededitsource'                => "Hiej onger stuit de teks van '''dien bewèrkinge''' aan '''$1''':",
 'whitelistedittitle'               => 'Geer mót óch inlogke óm te bewirke',
 'whitelistedittext'                => 'Geer mót uch $1 óm pajzená te bewirke.',
-'whitelistreadtitle'               => 'Geer mót óch inlogke óm dit te kónne laeze',
-'whitelistreadtext'                => "Geer mót óch [[Special:Userlogin|inlogke]] óm pazjena's te laeze.",
-'whitelistacctitle'                => 'Geer maag gein account aanmake',
-'whitelistacctext'                 => 'Óm accounts op {{SITENAME}} aan te make mót geer [[Special:Userlogin|ingelog]] zeen en de zjuste permissies höbbe.',
 'confirmedittitle'                 => 'E-mailbevestiging is verplich veurdets te kèns bewirke',
 'confirmedittext'                  => "De mós dien e-mailadres bevestige veurdats te kèns bewirke.
 Veur dien e-mailadres in en bevestig 'm bie [[Special:Preferences|dien veurkäöre]].",
@@ -580,7 +585,7 @@
 'newarticletext'                   => "De höbs 'ne link gevolg nao 'n pazjena die nog neet besjteit.
 Type in de box hiejónger óm de pazjena te beginne (zuug de [[{{MediaWiki:Helppage}}|helppazjena]] veur mier informatie).
 Es te hie per óngelök terech bis gekómme, klik dan op de '''trök'''-knóp van diene browser.",
-'anontalkpagetext'                 => "----''Dit is de euverlèkpazjena veur 'ne anonieme gebroeker dae nog gein account haet aangemaak of dae 't neet gebroek. Daoveur gebroeke v'r 't IP-adres óm de gebroeker te identificere. Dat adres kan waere gedeild doer mierdere gebroekers. Es te 'ne anonieme gebroeker bis en de höbs 't geveul dat 'r ónrelevante commentare aan dich gerich zeen, kèns te 't bèste [[Special:Userlogin|'n account crëere of inlogge]] óm toekomstige verwarring mit anger anoniem gebroekers te veurkomme.''",
+'anontalkpagetext'                 => "----''Dit is de euverlèkpazjena veur 'ne anonieme gebroeker dae nog gein account haet aangemaak of dae 't neet gebroek. Daoveur gebroeke v'r 't IP-adres óm de gebroeker te identificere. Dat adres kan waere gedeild doer mierdere gebroekers. Es te 'ne anonieme gebroeker bis en de höbs 't geveul dat 'r ónrelevante commentare aan dich gerich zeen, kèns te 't bèste [[Special:UserLogin|'n account crëere of inlogge]] óm toekomstige verwarring mit anger anoniem gebroekers te veurkomme.''",
 'noarticletext'                    => 'Dees pazjena bevat gein teks.
 De kèns [[Special:Search/{{PAGENAME}}|nao deze term zeuke]] in anger pazjena\'s of <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} dees pazjena bewirke]</span>.',
 'userpage-userdoesnotexist'        => 'Doe bewerks \'n gebroekerspagina van \'ne gebroeker dae neet besteit (gebroeker "$1"). Lèvver te controlere ofse deze pagina waal wils aanmake/bewerke.',
@@ -634,7 +639,7 @@
 'hiddencategories'                 => 'Dees pazjena velt in de volgendje verbórge {{PLURAL:$1|categorie|categorië}}:',
 'nocreatetitle'                    => "'t Aanmake van pazjena's is beperk",
 'nocreatetext'                     => "{{SITENAME}} haet de mäögelikheid óm nuuj pazjena's te make bepèrk.
-De kèns al besjtaonde pazjena's verangere, of de kèns [[Special:Userlogin|dich aanmelje of 'n gebroekersaccount aanmake]].",
+De kèns al besjtaonde pazjena's verangere, of de kèns [[Special:UserLogin|dich aanmelje of 'n gebroekersaccount aanmake]].",
 'nocreate-loggedin'                => "De kèns gein nuuj pazjena's make op {{SITENAME}}.",
 'permissionserrors'                => 'Foute inne rèchter',
 'permissionserrorstext'            => 'Doe höbs gein rèchter om det te daon om de volgende {{PLURAL:$1|reje|rejer}}:',
@@ -751,7 +756,7 @@
 # Suppression log
 'suppressionlog'     => 'Verbergingslogbook',
 'suppressionlogtext' => 'De ongerstaonde lies bevat de verwiederinge en blokkades die veur beheerders verborge zeen.
-In de [[Special:Ipblocklist|IP-blokkeerlies]] zeen de hudige blokkades te bekieke.',
+In de [[Special:IPBlockList|IP-blokkeerlies]] zeen de hudige blokkades te bekieke.',
 
 # History merging
 'mergehistory'                     => "Gesjiedenis van pagina's samevoege",
@@ -819,7 +824,7 @@
 'searchall'                 => 'alle',
 'showingresults'            => 'Hieonger staon de <b>$1</b> {{PLURAL:$1|resultaat|resultaat}}, vanaaf #<b>$2</b>.',
 'showingresultsnum'         => "Hieonger {{PLURAL:$3|steit '''1''' resultaat|staon '''$3''' resultate}} vanaaf #<b>$2</b>.",
-'showingresultstotal'       => "Hie onger waere de resultate '''$1 toet $2''' van '''$3''' weergegaeve",
+'showingresultstotal'       => "Hie onger {{PLURAL:$3|wordt resultaat '''$1'''|waere de resultate '''$1 toet $2''' van '''$3'''}} weergegaeve",
 'nonefound'                 => '<strong>Lèt op:</strong> \'n zeukopdrach kan mislökke door \'t gebroek van (in \'t Ingelsj) väöl veurkómmende wäörd wie "of" en "be", die neet geïndexeerd zint, of door versjillende zeukterme tegeliek op te gaeve (de kries dan allein pazjena\'s te zeen woerin alle opgegaeve terme veurkómme).',
 'powersearch'               => 'Zeuke',
 'powersearch-legend'        => 'Oetgebrèd zeuke',
@@ -835,7 +840,7 @@
 'mypreferences'            => 'Mien veurkäöre',
 'prefs-edits'              => 'Aantal bewèrkinge:',
 'prefsnologin'             => 'Neet aangemèld',
-'prefsnologintext'         => 'De mós zeen [[Special:Userlogin|aangemeld]] óm dien veurkäöre te kónne insjtèlle.',
+'prefsnologintext'         => 'De mós zeen [[Special:UserLogin|aangemeld]] óm dien veurkäöre te kónne insjtèlle.',
 'prefsreset'               => 'Sjtandaardveurkäöre hersjtèld.',
 'qbsettings'               => 'Menubalkinsjtèllinge',
 'qbsettings-none'          => 'Oetgesjakeld',
@@ -887,6 +892,8 @@
 'servertime'               => 'Server tied is noe',
 'guesstimezone'            => 'Invulle van browser',
 'allowemail'               => 'E-mail van anger gebroekers toesjtaon',
+'prefs-searchoptions'      => 'Zeukinstellinge',
+'prefs-namespaces'         => 'Naamruimte',
 'defaultns'                => 'Zeuk sjtandaard in dees naomruumdes:',
 'default'                  => 'sjtandaard',
 'files'                    => 'Bestenj',
@@ -907,7 +914,7 @@
 'userrights-reason'           => "Reje veur 't verangere:",
 'userrights-no-interwiki'     => "Doe höbs gein rechte om gebroekersrechte op anger wiki's te wiezige.",
 'userrights-nodatabase'       => 'Database $1 besteit neet of is gein plaatselike database.',
-'userrights-nologin'          => "Doe mos dich [[Special:Userlogin|aanmelle]] mit 'ne gebroeker mit de zjuuste rech om gebroekersrech toe te wieze.",
+'userrights-nologin'          => "Doe mos dich [[Special:UserLogin|aanmelle]] mit 'ne gebroeker mit de zjuuste rech om gebroekersrech toe te wieze.",
 'userrights-notallowed'       => 'Doe höbs gein rechte om gebroekersrechte toe te wieze.',
 'userrights-changeable-col'   => 'Gróppe dies te kèns behere',
 'userrights-unchangeable-col' => 'Gróppe dies te neet kèns behere',
@@ -944,6 +951,7 @@
 'right-createaccount'        => 'Nuwe gebroekers aanmake',
 'right-minoredit'            => 'Bewerkinge markere as klein',
 'right-move'                 => "Pagina's hernaome",
+'right-move-subpages'        => "Pagina's inclusief subpagina's verplaatse",
 'right-suppressredirect'     => "Een doorverwijzing op de doelpagina verwijdere bie 't hernaome van 'n pagina",
 'right-upload'               => 'Bestande uploade',
 'right-reupload'             => "'n bestaond bestand euversjrieve",
@@ -975,6 +983,7 @@
 'right-editusercssjs'        => 'De CSS- en JS-bestande van angere gebroekers bewerke',
 'right-rollback'             => "Snel de letste bewerking(e) van 'n gebroeker van 'n pagina terugdraaie",
 'right-markbotedits'         => 'Teruggedraaide bewerkinge markere es botbewerkinge',
+'right-noratelimit'          => "Heet gein ti'jdsafhankelijke beperkinge",
 'right-import'               => "Pagina's oet angere wiki's importere",
 'right-importupload'         => "Pagina's importere oet 'n bestandsupload",
 'right-patrol'               => 'Bewerkinge es gecontroleerd markere',
@@ -1034,11 +1043,11 @@
 'reupload'                    => 'Opnuui uploade',
 'reuploaddesc'                => "Truuk nao 't uploadformeleer.",
 'uploadnologin'               => 'Neet aangemèld',
-'uploadnologintext'           => 'De mos [[Special:Userlogin|zien aangemèld]] om besjtande te uploade.',
+'uploadnologintext'           => 'De mos [[Special:UserLogin|zien aangemèld]] om besjtande te uploade.',
 'upload_directory_read_only'  => 'De webserver kin neet sjrieve in de uploadmap ($1).',
 'uploaderror'                 => "fout in 't uploade",
 'uploadtext'                  => "Gebroek 't óngersjtaonde formuleer óm besjtande op te laje.
-Óm ierder opgelaje besjtande te bekieke of te zeuke, gank nao de [[Special:Imagelist|lies van opgelaje besjtande]].
+Óm ierder opgelaje besjtande te bekieke of te zeuke, gank nao de [[Special:ImageList|lies van opgelaje besjtande]].
 Uploads en verwiederinge waere ouch biegehauwte in 't [[Special:Log/upload|uploadlogbook]].
 
 Gebroek óm 'n plaetje of 'n besjtand in 'n pazjena op te numme 'ne link in de vörm:
@@ -1125,7 +1134,7 @@
 'upload_source_url'  => " ('ne geldige, publiek toegankelike URL)",
 'upload_source_file' => " ('n bestand op diene computer)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Op dees speciaal pazjena zeen alle toegevoogde bestenj te bekieke.
 Standerd waere de lets toegevoogde bestenj baovenaan de lies weergegaeve.
 Klikke op 'ne kolomkop verangert de sortering.",
@@ -1153,7 +1162,7 @@
 'imagelinks'                     => 'Aafbeildingsverwiezinge',
 'linkstoimage'                   => "Dees aafbeilding weurt op de volgende {{PLURAL:$1|pazjena|pazjena's}} gebroek:",
 'nolinkstoimage'                 => 'Gein enkele pazjena gebroek dees aafbeilding.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Mier verwijzinge]] naor dit bestaand bekèèke.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Mier verwijzinge]] naor dit bestaand bekèèke.',
 'redirectstofile'                => 'De volgende bestaande verwèèze door naor dit bestaand:',
 'duplicatesoffile'               => 'De nègsvóggendje bestenj zeen identiek aan dit bestandj:',
 'sharedupload'                   => 'literal translation',
@@ -1172,18 +1181,18 @@
 # File reversion
 'filerevert'                => '$1 trökdrèjje',
 'filerevert-legend'         => 'Bestandj trökdrejje',
-'filerevert-intro'          => '<span class="plainlinks">Doe bös \'\'\'[[Media:$1|$1]]\'\'\' aan \'t trökdrèjje tot de [$4 versie op $2, $3]</span>.',
+'filerevert-intro'          => "Doe bös '''[[Media:$1|$1]]''' aan 't trökdrèjje tot de [$4 versie op $2, $3]",
 'filerevert-comment'        => 'Opmèrking:',
 'filerevert-defaultcomment' => 'Trökgedrèjt tot de versie op $1, $2',
 'filerevert-submit'         => 'Trökdrèjje',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' is trökgedrèjt tot de [$4 versie op $2, $3]</span>.',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' is trökgedrèjt tot de [$4 versie op $2, $3]",
 'filerevert-badversion'     => "d'r is geine vörge lokale versie van dit bestand mit 't opgegaeve tiejdstip.",
 
 # File deletion
 'filedelete'                  => 'Wis $1',
 'filedelete-legend'           => 'Wis bestand',
 'filedelete-intro'            => "Doe bös '''[[Media:$1|$1]]''' aan 't wisse.",
-'filedelete-intro-old'        => '<span class="plainlinks">Doe bös de versie van \'\'\'[[Media:$1|$1]]\'\'\' van [$4 $3, $2] aan \'t wisse.</span>',
+'filedelete-intro-old'        => "Doe bös de versie van '''[[Media:$1|$1]]''' van [$4 $3, $2] aan 't wisse.",
 'filedelete-comment'          => 'Opmèrking:',
 'filedelete-submit'           => 'Wisse',
 'filedelete-success'          => "'''$1''' is gewis.",
@@ -1244,9 +1253,11 @@
 Deze heure waarsjienlik direct nao 't zjuste ongerwerp te verwiezen.<br />
 'ne pagina wörd gezeen es redirect wen d'r 'n sjabloon op stuit det gelink is vanaaf [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Dobbel redirects',
-'doubleredirectstext' => '<b>Kiek oet:</b> In dees lies kanne redirects sjtaon die neet dao-in toeshure. Dat kump meistal doordat nao de #REDIRECT nog anger links op de pazjena sjtaon.<br />
+'doubleredirects'            => 'Dobbel redirects',
+'doubleredirectstext'        => '<b>Kiek oet:</b> In dees lies kanne redirects sjtaon die neet dao-in toeshure. Dat kump meistal doordat nao de #REDIRECT nog anger links op de pazjena sjtaon.<br />
 Op eder raegel vings te de ierste redirectpazjena, de twiede redirectpazjena en de iesjte raegel van de twiede redirectpazjena. Normaal bevat dees litste de pazjena woe de iesjte redirect naotoe zouw mótte verwieze.',
+'double-redirect-fixed-move' => "[[$1]] is verplaats en is noe 'n doorverwiezing nao [[$2]]",
+'double-redirect-fixer'      => 'Doorverwiezinge opsjone',
 
 'brokenredirects'        => 'Gebraoke redirects',
 'brokenredirectstext'    => "De óngersjtaonde redirectpazjena's bevatte 'n redirect nao 'n neet-besjtaonde pazjena.",
@@ -1279,6 +1290,7 @@
 'popularpages'            => 'Populaire artikels',
 'wantedcategories'        => 'Gewunsjde categorieë',
 'wantedpages'             => "Gewunsjde pazjena's",
+'missingfiles'            => 'Neet-bestaonde bestenj mit verwiezinge',
 'mostlinked'              => "Meis gelinkde pazjena's",
 'mostlinkedcategories'    => 'Meis-gelinkde categorië',
 'mostlinkedtemplates'     => 'Meis-gebroekde sjablone',
@@ -1330,7 +1342,7 @@
 'logempty'             => "d'r Zeen gein regels in 't logbook die voldaon aan deze criteria.",
 'log-title-wildcard'   => "Zeuk pagina's die met deze naam beginne",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => "Alle pazjena's",
 'alphaindexline'    => '$1 nao $2',
 'nextpage'          => 'Volgende pazjena ($1)',
@@ -1353,12 +1365,12 @@
 'special-categories-sort-count' => 'op aantal sortere',
 'special-categories-sort-abc'   => 'alfabetisch sortere',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Tuun gebroekers vanaaf:',
 'listusers-submit'   => 'Tuun',
 'listusers-noresult' => 'Gein(e) gebroeker(s) gevonje.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rechte van gebroekersgróppe',
 'listgrouprights-summary'  => 'Op dees pazjena sjtaon de gebroekersgróppe in deze wiki besjreve, mit zien biebehurende rechte.
 Infermasie daoreuver vunds te [[{{MediaWiki:Listgrouprights-helppage}}|hie]].',
@@ -1369,7 +1381,7 @@
 
 # E-mail user
 'mailnologin'     => 'Gein e-mailadres bekènd veur deze gebroeker',
-'mailnologintext' => "De mos zien [[Special:Userlogin|aangemèld]] en 'n gèldig e-mailadres in bie dien [[Special:Preferences|veurkäöre]] höbbe ingevuld om mail nao anger gebroekers te sjture.",
+'mailnologintext' => "De mos zien [[Special:UserLogin|aangemèld]] en 'n gèldig e-mailadres in bie dien [[Special:Preferences|veurkäöre]] höbbe ingevuld om mail nao anger gebroekers te sjture.",
 'emailuser'       => "Sjik deze gebroeker 'nen e-mail",
 'emailpage'       => "Sjik gebroeker 'nen e-mail",
 'emailpagetext'   => "As deze gebroeker e geljig e-mailadres heet opgegaeve dan kant geer via dit formuleer e berich sjikke. 't E-mailadres wat geer heet opgegeve bie eur veurkäöre zal as versjikker aangegaeve waere.",
@@ -1386,6 +1398,7 @@
 'emailccsubject'  => 'Kopie van dien berich aan $1: $2',
 'emailsent'       => 'E-mail sjikke',
 'emailsenttext'   => 'Die berich is versjik.',
+'emailuserfooter' => 'Deze e-mail is verstuurd door $1 aan $2 door de functie "Deze gebroeker e-maile" van {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Volglies',
@@ -1394,11 +1407,11 @@
 'nowatchlist'          => "D'r sjtit niks op dien volglies.",
 'watchlistanontext'    => '$1 is verplich om dien volglies in te zeen of te wiezige.',
 'watchnologin'         => 'De bis neet aangemèld',
-'watchnologintext'     => "De mós [[Special:Userlogin|aangemèld]] zeen veur 't verangere van dien volglies.",
+'watchnologintext'     => "De mós [[Special:UserLogin|aangemèld]] zeen veur 't verangere van dien volglies.",
 'addedwatch'           => 'Aan volglies toegeveug',
 'addedwatchtext'       => 'De pazjena "<nowiki>$1</nowiki>" is aan dien [[Special:Watchlist|volglies]] toegeveug.
 Toekomstige verangeringe aan deze pazjena en de biebehurende euverlikpazjena weure hie vermèld.
-Ouch versjiene gevolgde pazjena\'s in \'t <b>vet</b> in de [[Special:Recentchanges|liest van recènte verangeringe]]. <!-- zodat u ze eenvoudiger kan opmerken.-->
+Ouch versjiene gevolgde pazjena\'s in \'t <b>vet</b> in de [[Special:RecentChanges|liest van recènte verangeringe]]. <!-- zodat u ze eenvoudiger kan opmerken.-->
 
 <!-- huh? Wen se ein pazjena van dien volgliest wils haole mos e op "sjtop volge"  -- pagina wenst te verwijderen van uw volgliest klik dan op "Van volgliest verwijderen" in de menubalk. -->',
 'removedwatch'         => 'Van volglies aafhoale',
@@ -1507,7 +1520,7 @@
 'sessionfailure'              => "d'r Liek 'n probleem te zeen mit dien aanmelsessie. Diene hanjeling is gestop oet veurzorg taenge 'n beveiligingsrisico (det bestuit oet meugelik \"hijacking\"(euverkape) van deze sessie). Gao 'n pazjena trök, laaj die pazjena opnuuj en probeer 't nog ins.",
 'protectlogpage'              => "Logbook besjermde pazjena's",
 'protectlogtext'              => "Hiej onger staon pazjena's die recèntelik beveilig zeen, of wo van de beveiliging is opgeheve.
-Zuug de [[Special:Protectedpages|lies mit beveiligde pazjena's]] veur alle hujige beveiligde pazjena's.",
+Zuug de [[Special:ProtectedPages|lies mit beveiligde pazjena's]] veur alle hujige beveiligde pazjena's.",
 'protectedarticle'            => '$1 besjermd',
 'modifiedarticleprotection'   => 'verangerde beveiligingsniveau van "[[$1]]"',
 'unprotectedarticle'          => 'besjerming van $1 opgeheve',
@@ -1557,6 +1570,7 @@
 'undeletepagetitle'            => "''''t Volgende besteit oet verwiederde bewèrkinge van [[:$1]]'''.",
 'viewdeletedpage'              => "Tuun gewisde pazjena's",
 'undeletepagetext'             => "De ongersjtaande pazjena's zint verwiederd, meh bevinge zich nog sjteeds in 't archief, en kinne weure truukgeplaatsj.",
+'undelete-fieldset-title'      => 'Versies trukplaatse',
 'undeleteextrahelp'            => "Om de algehele pazjena inclusief alle irdere versies trök te plaatse: laot alle hökskes onafgevink en klik op '''''Trökplaatse'''''. Om slechs bepaalde versies trök te zètte: vink de trök te plaatse versies aan en klik op '''''Trökplaatse'''''. Esse op '''''Reset''''' kliks wörd 't toelichtingsveld laeggemaak en waere alle versies gedeselecteerd.",
 'undeleterevisions'            => "$1 {{PLURAL:$1|versie|versies}} in 't archief",
 'undeletehistory'              => 'Als u een pagina terugplaatst, worden alle versies als oude versies teruggeplaatst. Als er al een nieuwe pagina met dezelfde naam is aangemaakt, zullen deze versies als oude versies worden teruggeplaatst, maar de huidige versie neet gewijzigd worden.',
@@ -1633,15 +1647,15 @@
 'whatlinkshere-filters'    => 'Filters',
 
 # Block/unblock
-'blockip'                     => 'Blokkeer dit IP-adres',
-'blockip-legend'              => "'ne Gebroeker of IP-adres blokkere",
-'blockiptext'                 => "Gebroek 't óngerstjaondj formeleer óm sjrieftoegank van e zeker IP-adres te verbeje. Dit maag allein gedaon weure om vandalisme te veurkómme.",
-'ipaddress'                   => 'IP-adres',
-'ipadressorusername'          => 'IP-adres of gebroekersnaam',
-'ipbexpiry'                   => "Verlöp (maak 'n keuze)",
-'ipbreason'                   => 'Reje',
-'ipbreasonotherlist'          => 'Angere reje',
-'ipbreason-dropdown'          => '*Väöl veurkommende rejer veur blokkaazjes
+'blockip'                         => 'Blokkeer dit IP-adres',
+'blockip-legend'                  => "'ne Gebroeker of IP-adres blokkere",
+'blockiptext'                     => "Gebroek 't óngerstjaondj formeleer óm sjrieftoegank van e zeker IP-adres te verbeje. Dit maag allein gedaon weure om vandalisme te veurkómme.",
+'ipaddress'                       => 'IP-adres',
+'ipadressorusername'              => 'IP-adres of gebroekersnaam',
+'ipbexpiry'                       => "Verlöp (maak 'n keuze)",
+'ipbreason'                       => 'Reje',
+'ipbreasonotherlist'              => 'Angere reje',
+'ipbreason-dropdown'              => '*Väöl veurkommende rejer veur blokkaazjes
 ** Foutieve informatie inveure
 ** Verwiedere van informatie oet artikele
 ** Spamlinks nao externe websites
@@ -1649,69 +1663,70 @@
 ** Intimiderend gedraag
 ** Misbroek van meerdere gebroekers
 ** Onacceptabele gebroekersnaam',
-'ipbanononly'                 => 'Blokkeer allein anonieme gebroekers',
-'ipbcreateaccount'            => 'Blokkeer aanmake gebroekers',
-'ipbemailban'                 => "Haoj de gebrorker van 't sture van e-mail",
-'ipbenableautoblock'          => 'Automatisch de IP-adresse van deze gebroeker blokkere',
-'ipbsubmit'                   => 'Blokkeer dit IP-adres',
-'ipbother'                    => 'Anger verloup',
-'ipboptions'                  => '2 oer:2 hours,1 daag:1 day,3 daag:3 days,1 waek:1 week,2 waek:2 weeks,1 maondj:1 month,3 maondj:3 months,6 maondj:6 months,1 jaor:1 year,veur iwweg:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'anger verloup',
-'ipbotherreason'              => 'Angere/eventuele rejer:',
-'ipbhidename'                 => "Verberg gebroekersnaam van 't blokkeerlogbook, de actieve blokkeerlies en de gebroekerslies",
-'ipbwatchuser'                => 'Gebroekerspazjena en euverlèkpazjena op vólglies plaatse',
-'badipaddress'                => "'t IP-adres haet 'n ongeldige opmaak.",
-'blockipsuccesssub'           => 'Blokkaad gelök',
-'blockipsuccesstext'          => '\'t IP-adres "$1" is geblokkeerd.<br />
-Zuug de [[Special:Ipblocklist|lies van geblokkeerde IP-adresse]].',
-'ipb-edit-dropdown'           => 'Bewerk lies van rejer',
-'ipb-unblock-addr'            => 'Ónblokkeer $1',
-'ipb-unblock'                 => "Ónblokkeer 'ne gebroeker of IP-adres",
-'ipb-blocklist-addr'          => 'Bekiek bestaonde blokkades veur $1',
-'ipb-blocklist'               => 'Bekiek bestaonde blokkades',
-'unblockip'                   => 'Deblokkeer IP adres',
-'unblockiptext'               => 'Gebroek het ongersjtaonde formeleer om weer sjrieftoegang te gaeve aan e geblokkierd IP adres.',
-'ipusubmit'                   => 'Deblokkeer dit IP-adres.',
-'unblocked'                   => 'Blokkade van [[User:$1|$1]] is opgeheve',
-'unblocked-id'                => 'Blokkade $1 is opgeheve',
-'ipblocklist'                 => 'Lies van geblokkeerde IP-adressen',
-'ipblocklist-legend'          => "'ne Geblokkeerde gebroeker zeuke",
-'ipblocklist-username'        => 'Gebroekersnaam of IP-adres:',
-'ipblocklist-submit'          => 'Zeuk',
-'blocklistline'               => 'Op $1 blokkeerde $2 $3 ($4)',
-'infiniteblock'               => 'veur iwweg',
-'expiringblock'               => 'verlöp op $1',
-'anononlyblock'               => 'allein anoniem',
-'noautoblockblock'            => 'autoblok neet actief',
-'createaccountblock'          => 'aanmake gebroekers geblokkeerd',
-'emailblock'                  => 'e-mail geblokkeerd',
-'ipblocklist-empty'           => 'De blokkeerlies is laeg.',
-'ipblocklist-no-results'      => 'Dit IP-adres of deze gebroekersnaam is neet geblokkeerd.',
-'blocklink'                   => 'Blokkeer',
-'unblocklink'                 => 'deblokkere',
-'contribslink'                => 'biedrages',
-'autoblocker'                 => 'Ómdets te \'n IP-adres deils mit "$1" (geblokkeerd mit raeje "$2") bis te automatisch geblokkeerd.',
-'blocklogpage'                => 'Blokkeerlogbook',
-'blocklogentry'               => '"[[$1]]" is geblokkeerd veur d\'n tied van $2 $3',
-'blocklogtext'                => "Dit is 'n log van blokkades van gebroekers. Automatisch geblokkeerde IP-adresse sjtoon hie neet bie. Zuug de [[Special:Ipblocklist|Lies van geblokkeerde IP-adresse]] veur de lies van op dit mement wèrkende blokkades.",
-'unblocklogentry'             => 'blokkade van $1 opgeheve',
-'block-log-flags-anononly'    => 'allein anoniem',
-'block-log-flags-nocreate'    => 'aanmake gebroekers geblokkeerd',
-'block-log-flags-noautoblock' => 'autoblok ongedaon gemaak',
-'block-log-flags-noemail'     => 'e-mail geblokkeerd',
-'range_block_disabled'        => "De meugelikheid veur beheerders om 'ne groep IP-adresse te blokkere is oetgesjakeld.",
-'ipb_expiry_invalid'          => 'Ongeldig verloup.',
-'ipb_already_blocked'         => '"$1" is al geblokkeerd',
-'ipb_cant_unblock'            => 'Fout: Blokkadenummer $1 neet gevonje. Mesjiens is de blokkade al opgeheve.',
-'ipb_blocked_as_range'        => "Fout: 't IP-adres $1 is neet direct geblokkeerd en de blokkade kan neet opgeheve waere. De blokkade is ongerdeil van de reeks $2, wovan de blokkade waal opgeheve kan waere.",
-'ip_range_invalid'            => 'Ongeldige IP-reeks',
-'blockme'                     => 'Blokkeer mich',
-'proxyblocker'                => 'Proxyblokker',
-'proxyblocker-disabled'       => 'Deze functie is oetgesjakeld.',
-'proxyblockreason'            => "Dien IP-adres is geblokkeerd ómdat 't 'n aope proxy is. Contacteer estebleef diene internet service provider of technische óngersjteuning en informeer ze euver dit serjeus veiligheidsprebleem.",
-'proxyblocksuccess'           => 'Klaor.',
-'sorbsreason'                 => 'Dien IP-adres is opgenaome in de DNS-blacklist es open proxyserver, dae {{SITENAME}} gebroek.',
-'sorbs_create_account_reason' => 'Dien IP-adres is opgenómme in de DNS-blacklist es open proxyserver, dae {{SITENAME}} gebroek. De kèns gein gebroekersaccount aanmake.',
+'ipbanononly'                     => 'Blokkeer allein anonieme gebroekers',
+'ipbcreateaccount'                => 'Blokkeer aanmake gebroekers',
+'ipbemailban'                     => "Haoj de gebrorker van 't sture van e-mail",
+'ipbenableautoblock'              => 'Automatisch de IP-adresse van deze gebroeker blokkere',
+'ipbsubmit'                       => 'Blokkeer dit IP-adres',
+'ipbother'                        => 'Anger verloup',
+'ipboptions'                      => '2 oer:2 hours,1 daag:1 day,3 daag:3 days,1 waek:1 week,2 waek:2 weeks,1 maondj:1 month,3 maondj:3 months,6 maondj:6 months,1 jaor:1 year,veur iwweg:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'anger verloup',
+'ipbotherreason'                  => 'Angere/eventuele rejer:',
+'ipbhidename'                     => "Verberg gebroekersnaam van 't blokkeerlogbook, de actieve blokkeerlies en de gebroekerslies",
+'ipbwatchuser'                    => 'Gebroekerspazjena en euverlèkpazjena op vólglies plaatse',
+'badipaddress'                    => "'t IP-adres haet 'n ongeldige opmaak.",
+'blockipsuccesssub'               => 'Blokkaad gelök',
+'blockipsuccesstext'              => '\'t IP-adres "$1" is geblokkeerd.<br />
+Zuug de [[Special:IPBlockList|lies van geblokkeerde IP-adresse]].',
+'ipb-edit-dropdown'               => 'Bewerk lies van rejer',
+'ipb-unblock-addr'                => 'Ónblokkeer $1',
+'ipb-unblock'                     => "Ónblokkeer 'ne gebroeker of IP-adres",
+'ipb-blocklist-addr'              => 'Bekiek bestaonde blokkades veur $1',
+'ipb-blocklist'                   => 'Bekiek bestaonde blokkades',
+'unblockip'                       => 'Deblokkeer IP adres',
+'unblockiptext'                   => 'Gebroek het ongersjtaonde formeleer om weer sjrieftoegang te gaeve aan e geblokkierd IP adres.',
+'ipusubmit'                       => 'Deblokkeer dit IP-adres.',
+'unblocked'                       => 'Blokkade van [[User:$1|$1]] is opgeheve',
+'unblocked-id'                    => 'Blokkade $1 is opgeheve',
+'ipblocklist'                     => 'Lies van geblokkeerde IP-adressen',
+'ipblocklist-legend'              => "'ne Geblokkeerde gebroeker zeuke",
+'ipblocklist-username'            => 'Gebroekersnaam of IP-adres:',
+'ipblocklist-submit'              => 'Zeuk',
+'blocklistline'                   => 'Op $1 blokkeerde $2 $3 ($4)',
+'infiniteblock'                   => 'veur iwweg',
+'expiringblock'                   => 'verlöp op $1',
+'anononlyblock'                   => 'allein anoniem',
+'noautoblockblock'                => 'autoblok neet actief',
+'createaccountblock'              => 'aanmake gebroekers geblokkeerd',
+'emailblock'                      => 'e-mail geblokkeerd',
+'ipblocklist-empty'               => 'De blokkeerlies is laeg.',
+'ipblocklist-no-results'          => 'Dit IP-adres of deze gebroekersnaam is neet geblokkeerd.',
+'blocklink'                       => 'Blokkeer',
+'unblocklink'                     => 'deblokkere',
+'contribslink'                    => 'biedrages',
+'autoblocker'                     => 'Ómdets te \'n IP-adres deils mit "$1" (geblokkeerd mit raeje "$2") bis te automatisch geblokkeerd.',
+'blocklogpage'                    => 'Blokkeerlogbook',
+'blocklogentry'                   => '"[[$1]]" is geblokkeerd veur d\'n tied van $2 $3',
+'blocklogtext'                    => "Dit is 'n log van blokkades van gebroekers. Automatisch geblokkeerde IP-adresse sjtoon hie neet bie. Zuug de [[Special:IPBlockList|Lies van geblokkeerde IP-adresse]] veur de lies van op dit mement wèrkende blokkades.",
+'unblocklogentry'                 => 'blokkade van $1 opgeheve',
+'block-log-flags-anononly'        => 'allein anoniem',
+'block-log-flags-nocreate'        => 'aanmake gebroekers geblokkeerd',
+'block-log-flags-noautoblock'     => 'autoblok ongedaon gemaak',
+'block-log-flags-noemail'         => 'e-mail geblokkeerd',
+'block-log-flags-angry-autoblock' => 'oetgebreide automatische blokkade ingesjakeld',
+'range_block_disabled'            => "De meugelikheid veur beheerders om 'ne groep IP-adresse te blokkere is oetgesjakeld.",
+'ipb_expiry_invalid'              => 'Ongeldig verloup.',
+'ipb_already_blocked'             => '"$1" is al geblokkeerd',
+'ipb_cant_unblock'                => 'Fout: Blokkadenummer $1 neet gevonje. Mesjiens is de blokkade al opgeheve.',
+'ipb_blocked_as_range'            => "Fout: 't IP-adres $1 is neet direct geblokkeerd en de blokkade kan neet opgeheve waere. De blokkade is ongerdeil van de reeks $2, wovan de blokkade waal opgeheve kan waere.",
+'ip_range_invalid'                => 'Ongeldige IP-reeks',
+'blockme'                         => 'Blokkeer mich',
+'proxyblocker'                    => 'Proxyblokker',
+'proxyblocker-disabled'           => 'Deze functie is oetgesjakeld.',
+'proxyblockreason'                => "Dien IP-adres is geblokkeerd ómdat 't 'n aope proxy is. Contacteer estebleef diene internet service provider of technische óngersjteuning en informeer ze euver dit serjeus veiligheidsprebleem.",
+'proxyblocksuccess'               => 'Klaor.',
+'sorbsreason'                     => 'Dien IP-adres is opgenaome in de DNS-blacklist es open proxyserver, dae {{SITENAME}} gebroek.',
+'sorbs_create_account_reason'     => 'Dien IP-adres is opgenómme in de DNS-blacklist es open proxyserver, dae {{SITENAME}} gebroek. De kèns gein gebroekersaccount aanmake.',
 
 # Developer tools
 'lockdb'              => 'Database blokkere',
@@ -1727,7 +1742,7 @@
 'unlockdbsuccesssub'  => 'Blokkering van de database opgeheven',
 'lockdbsuccesstext'   => "De database is geblokkeerd.<br />
 
-Vergaet neet de database opnuuj te [[Special:Unlockdb|deblokkere]] wens te klaor bis mit 't óngerhaud.",
+Vergaet neet de database opnuuj te [[Special:UnlockDB|deblokkere]] wens te klaor bis mit 't óngerhaud.",
 'unlockdbsuccesstext' => 'Blokkering van de database van {{SITENAME}} is opgeheven.',
 'lockfilenotwritable' => "Gein sjriefrechte op 't databaselockbestandj. Om de database te kinne blokkere of vrie te gaeve, dient de webserver sjriefrechte op dit bestandj te höbbe.",
 'databasenotlocked'   => 'De database is neet geblokkeerd.',
@@ -1740,8 +1755,6 @@
 * es al 'n euverlikpazjena besjteit ónger de angere naam
 * es doe 't óngersjtaond vekske neet aanvinks",
 'movearticle'             => 'Verplaats pazjena',
-'movenologin'             => 'Neet aangemèld',
-'movenologintext'         => "Veur 't verplaatsje van 'n pazjena mos e zien [[Special:Userlogin|aangemèld]].",
 'movenotallowed'          => "De kèns gein pazjena's verplaatse op {{SITENAME}}.",
 'newtitle'                => 'Nao de nuje titel',
 'move-watch'              => 'Volg deze pazjena',
@@ -1767,13 +1780,15 @@
 'delete_and_move'         => 'Wis en verplaats',
 'delete_and_move_text'    => '==Wisse vereis==
 
-De doeltitel "[[$1]]" besjteit al. Wils te dit artikel wisse óm ruumde te make veur de verplaatsing?',
+De doeltitel "[[:$1]]" besjteit al. Wils te dit artikel wisse óm ruumde te make veur de verplaatsing?',
 'delete_and_move_confirm' => 'Jao, wis de pazjena',
 'delete_and_move_reason'  => 'Gewis óm artikel te kónne verplaatse',
 'selfmove'                => "De kèns 'n pazjena neet verplaatse nao dezelfde paginanaam.",
 'immobile_namespace'      => "De gewinsde paginanaam is van 'n speciaal type. 'ne Pazjena kin neet hernömp waere nao die naamruumde.",
 'imagenocrossnamespace'   => "'n Mediabestandj kin neet nao 'ne angere naamruumdje verplaats waere",
 'imagetypemismatch'       => "De nuje bestandjsextensie is neet gliek aan 't bestandjstype.",
+'imageinvalidfilename'    => 'De nuje bestandsnaam is ongeldig',
+'fix-double-redirects'    => 'Alle doorverwiezinge biewerke die verwieze nao de originele paginanaam',
 
 # Export
 'export'            => "Exporteer pazjena's",
@@ -1992,10 +2007,10 @@
 'show-big-image'       => 'Hogere rezolusie',
 'show-big-image-thumb' => '<small>Gruutde van deze afbeilding: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Nuuj plaetjes',
 'imagelisttext'         => "Hie volg 'n lies mit $1 {{PLURAL:$1|aafbeilding|aafbeildinge}} geordend $2.",
-'newimages-summary'     => 'Op dees speciaal pazjena waere de meis recènt toegevoogde bestenj weergegaeve',
+'newimages-summary'     => 'Op dees speciaal pazjena waere de meis recènt toegevoogde bestenj weergegaeve.',
 'showhidebots'          => '($1 Bots)',
 'noimages'              => 'Niks te zeen.',
 'ilsubmit'              => 'Zeuk',
@@ -2274,7 +2289,7 @@
 
 # External editor support
 'edit-externally'      => "Bewirk dit bestand mit 'n extern toepassing",
-'edit-externally-help' => 'Zuug de [http://meta.wikimedia.org/wiki/Help:External_editors setupinsjtructies] veur mier informatie.',
+'edit-externally-help' => 'Zuug de [http://www.mediawiki.org/wiki/Manual:External_editors setupinsjtructies] veur mier informatie.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'al',
@@ -2341,7 +2356,7 @@
 'recreate'            => 'Pazjena obbenuujts make',
 
 # HTML dump
-'redirectingto' => "Aan 't doorverwieze nao [[$1]]...",
+'redirectingto' => "Aan 't doorverwieze nao [[:$1]]...",
 
 # action=purge
 'confirm_purge'        => 'Wils te de buffer vaan dees paas wisse?
@@ -2441,7 +2456,7 @@
 'version-software-product'         => 'Perduk',
 'version-software-version'         => 'Versie',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Bestandjspaad',
 'filepath-page'    => 'Bestandj:',
 'filepath-submit'  => 'Zeuk',
@@ -2463,6 +2478,9 @@
 
 # Special:SpecialPages
 'specialpages'                   => "Speciaal pazjena's",
+'specialpages-note'              => '----
+* Normale speciale pagina\'s
+* <span class="mw-specialpagerestricted">Beperk toegankelijke speciale pagina\'s</span>',
 'specialpages-group-maintenance' => 'Óngerhajingsrapporter',
 'specialpages-group-other'       => "Euverige speciaal pazjena's",
 'specialpages-group-login'       => 'Aanmelje / registrere',
@@ -2470,5 +2488,14 @@
 'specialpages-group-media'       => 'Mediaeuverzichte en uploads',
 'specialpages-group-users'       => 'Gebroekers en rechte',
 'specialpages-group-highuse'     => "Väölgebroekde pazjena's",
+'specialpages-group-pages'       => 'Pazjenalieste',
+'specialpages-group-pagetools'   => 'Pazjenahölpmiddele',
+'specialpages-group-wiki'        => 'Wikigegaeves en -hölpmiddele',
+'specialpages-group-redirects'   => "Doorverwiezende speciaal pazjena's",
+'specialpages-group-spam'        => 'Spamhölpmiddele',
 
+# Special:BlankPage
+'blankpage'              => 'Laeg pazjena',
+'intentionallyblankpage' => 'Deze pagina is bewus laeg gelaote en wurt gebroek veur benchmarks, enzovoort.',
+
 );
Index: languages/messages/MessagesSzl.php
===================================================================
--- languages/messages/MessagesSzl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSzl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,16 +4,13 @@
  * @ingroup Language
  * @file
  *
- * @author Lajsikonik
- * @author Timpul
+ * @author Danny B.
  * @author Herr Kriss
- * @author Pimke
- * @author Siebrand
- * @author Ozi64
- * @author SPQRobin
- * @author Jon Harald Søby
+ * @author Lajsikonik
  * @author Leinad
- * @author Danny B.
+ * @author Ozi64
+ * @author Pimke
+ * @author Timpul
  */
 
 $fallback = 'pl';
@@ -295,7 +292,7 @@
 'nosuchspecialpage' => 'Ńy mo takij špecyjalnyj zajty',
 'nospecialpagetext' => "<big>'''Uoprogramowańy ńy rozpoznowo takij špecyjalnyj zajty.'''</big>
 
-Lista špecyjalnych zajtůw znejdźeš na [[Special:Specialpages|{{int:specialpages}}]].",
+Lista špecyjalnych zajtůw znejdźeš na [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Feler',
@@ -526,10 +523,6 @@
 'blockededitsource'                => "Tekst '''Twojich sprowjyń''' na '''$1''' zostou pokozany půnižyj:",
 'whitelistedittitle'               => 'Začym začńyš sprowjać ta zajta, muśiš być zalůgowany.',
 'whitelistedittext'                => 'Muśiš $1 coby můc sprowjać artikle.',
-'whitelistreadtitle'               => 'Před přečytańym muśiš śe zalůgować',
-'whitelistreadtext'                => 'Muśiš śe [[Special:Userlogin|zalůgować]], coby čytać zajty.',
-'whitelistacctitle'                => 'Ńy wolno Ći zakuodać kůnta',
-'whitelistacctext'                 => 'Zakuodańy kůnt na {{GRAMMAR:MS.lp|{{SITENAME}}}} wymogo [[Special:Userlogin|zalůgowańo]] a pośadańo uodpowjedńich uprowńyń.',
 'confirmedittitle'                 => 'Wymogane potwjyrdzyńy e-brifa, cobyś můg sam sprowjać',
 'confirmedittext'                  => 'Muśiš podać a potwjerdźić swůj e-brif, coby můc sam sprowjać.
 Možeš to zrobić we [[Special:Preferences|swojich štalowańach]].',
@@ -544,7 +537,7 @@
 'newarticletext'                   => 'Ńy ma sam ješče artikla uo tym tytule. W polu ńižyj možeš naškryflać jygo pjyršy fragmynt. Kej chćoužeś zrobić co inkše, naćiś ino knefel "Nazod".',
 'anontalkpagetext'                 => "---- ''To jest zajta godki lo užytkowńikůw anůnimowych - takich, keři ńy majům ješče swojigo kůnta abo ńy chcům go terozki užywać.
 By ich identyfikować, užywomy numerůw IP.
-Jeli ježeś anůnimowym užytkowńikym a wydowo Ći śe, aže zamjyščůne sam kůmyntoře ńy sům skjyrowane do Ćebje, [[Special:Userlogin|utwůř proša kůnto abo zalůguj śe]] - bez tůž uńikńeš potym podobnych ńyporozumjyń.''",
+Jeli ježeś anůnimowym užytkowńikym a wydowo Ći śe, aže zamjyščůne sam kůmyntoře ńy sům skjyrowane do Ćebje, [[Special:UserLogin|utwůř proša kůnto abo zalůguj śe]] - bez tůž uńikńeš potym podobnych ńyporozumjyń.''",
 'noarticletext'                    => 'Ńy mo ješče zajty uo tym titelu. Možeš [{{fullurl:{{FULLPAGENAME}}|action=edit}} wćepać artikel {{FULLPAGENAME}}] abo [[Special:Search/{{PAGENAME}}|šnupać za {{PAGENAME}} w inkšych artiklach]].',
 'userpage-userdoesnotexist'        => 'Užytkowńik "$1" ńy je zareještrowany. Sprowdź eli na pewno chćoužeś stwořyć/pomjynić gynau ta zajta.',
 'clearyourcache'                   => "'''Dej pozůr:''' Coby uobejřeć pomjyńańo pů naškryflańu nowych štalowań poleć přeglůndorce wyčyśćić zawartość pamjyńći podrynčnyj (cache). '''Mozilla / Firefox / Safari:''' přitřimej ''Shift'' klikajůnc na ''Uodśwjyž'' abo wciś ''Ctrl-Shift-R'' (''Cmd-Shift-R'' na Macintoshu), '''IE :''' přitřimej ''Ctrl'' klikajůnc na ''Uodśwjyž'' abo wciś ''Ctrl-F5''; '''Konqueror:''': kliknij knefel ''Uodśwjyž'' abo wciś ''F5''; užytkowńicy '''Opery''' mogům być zmušeńi coby coukym wyčyśćić jejich pamjyńć podrynčno we menu ''Werkcojgi→Preferencyje''.",
@@ -597,7 +590,7 @@
 'hiddencategories'                 => 'Ta zajta je {{PLURAL:$1|w jednyj schrůńunyj katygoryji|we $1 schrůńunych katygoryjach}}:',
 'nocreatetitle'                    => 'Uograńičůno wćepywańy zajtůw',
 'nocreatetext'                     => 'Na {{GRAMMAR:MS.lp|{{SITENAME}}}} twořyńy nowych zajtůw uograńičůno.
-Možeš sprowjać te co juž sům, abo [[Special:Userlogin|zalogować śe, abo zauožyć konto]].',
+Možeš sprowjać te co juž sům, abo [[Special:UserLogin|zalogować śe, abo zauožyć konto]].',
 'nocreate-loggedin'                => 'Ńy moš uprowńyń do škryflańo zajtůw na {{GRAMMAR:MS.lp|{{SITENAME}}}}.',
 'permissionserrors'                => 'Felerne uprowńyńa',
 'permissionserrorstext'            => 'Ńy moš uprowńyń do takij akcyje {{PLURAL:$1|skuli tego, co:|bestůž, co:}}',
@@ -712,7 +705,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Log schrůńyńć',
-'suppressionlogtext' => 'Půńižyj je lista nojnowšych wyćepań i zawarć s uwzglyndńyńym treśći schrůńůnej do admińistratorůw. Coby přejřeć lista aktualnych banůw i zawarć, uobezdřij [[Special:Ipblocklist|IP block list]].',
+'suppressionlogtext' => 'Půńižyj je lista nojnowšych wyćepań i zawarć s uwzglyndńyńym treśći schrůńůnej do admińistratorůw. Coby přejřeć lista aktualnych banůw i zawarć, uobezdřij [[Special:IPBlockList|IP block list]].',
 
 # History merging
 'mergehistory'                     => 'Pouůnč historyjo půmjyńań zajtůw',
@@ -795,7 +788,7 @@
 'mypreferences'            => 'Moje preferyncyje',
 'prefs-edits'              => 'Ličba sprowjyń:',
 'prefsnologin'             => 'Ńy ježeś zalůgowany',
-'prefsnologintext'         => 'Muśiš śe [[Special:Userlogin|zalůgować]] coby štalować swoje preferyncyje.',
+'prefsnologintext'         => 'Muśiš śe [[Special:UserLogin|zalůgować]] coby štalować swoje preferyncyje.',
 'prefsreset'               => 'Preferyncyje důmyślne zostouy uodtwořůne.',
 'qbsettings'               => 'Gurt šybkigo dostympu',
 'qbsettings-none'          => 'Brak',
@@ -869,7 +862,7 @@
 'userrights-reason'           => 'Skuli čego je půmjeńeńy:',
 'userrights-no-interwiki'     => 'Ńy moš dostympu do sprowjańo uprawńyń.',
 'userrights-nodatabase'       => 'Baza danych $1 ńy istńije abo ńy je lokalno.',
-'userrights-nologin'          => 'Muśiš [[Special:Userlogin|zalůgować śe]] na kůnto admińistratora, coby nadować uprawńyńo užytkowńikům.',
+'userrights-nologin'          => 'Muśiš [[Special:UserLogin|zalůgować śe]] na kůnto admińistratora, coby nadować uprawńyńo užytkowńikům.',
 'userrights-notallowed'       => 'Ńy moš dostympu do nadawańo uprawńyń užytkowńikům.',
 'userrights-changeable-col'   => 'Grupy, kere možeš wybrać',
 'userrights-unchangeable-col' => 'Grupy, kerych ńy možeš wybrać',
@@ -1000,11 +993,11 @@
 'reupload'                    => 'Wćepnij zaś',
 'reuploaddesc'                => 'Nazod do formulařa uod wćepywańo.',
 'uploadnologin'               => 'Ńy jest žeś zalogůwany',
-'uploadnologintext'           => 'Muśyš śe [[Special:Userlogin|zalůgować]] ńim wćepńeš pliki.',
+'uploadnologintext'           => 'Muśyš śe [[Special:UserLogin|zalůgować]] ńim wćepńeš pliki.',
 'upload_directory_read_only'  => 'Serwer ńy može škryflać do katalůgu ($1) kery je přeznačůny na wćepywane pliki.',
 'uploaderror'                 => 'Feler při wćepywańu',
 'uploadtext'                  => "Ůžyj formulařa půńižej do wćepywańo plikůw.
-Jak chceš přejřeć dotychčas wćepane pliki, abo w ńich šnupać, přeńdź do [[Special:Imagelist|listy douůnčůnych plikůw]]. Wšyjstke wćepańo uodnotowane sům we [[Special:Log/upload|rejeře přesůuanych plikůw]].
+Jak chceš přejřeć dotychčas wćepane pliki, abo w ńich šnupać, přeńdź do [[Special:ImageList|listy douůnčůnych plikůw]]. Wšyjstke wćepańo uodnotowane sům we [[Special:Log/upload|rejeře přesůuanych plikůw]].
 
 Plik pojawi śe na zajće, jak užyješ linka wedle jydnygo s nastympujůncych wzorůw:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Plik.jpg]]</nowiki>''',
@@ -1087,7 +1080,7 @@
 'upload_source_url'  => ' (poprowny, publičńy dostympny URL)',
 'upload_source_file' => ' (plik na twojym komputře)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'To je ekstra zajta na kery sům pokazywane wšyske pliki wćepane na serwer. Důmyślńy na wiyrchu listy wyśwjetlajům śe pliki wćepane na uostatku. Coby půmjyńić sposůb sortowańo, klikńij na naguůwek kolůmny.',
 'imagelist_search_for'  => 'Šnupej za grafikům uo mjańe:',
 'imgfile'               => 'plik',
@@ -1113,7 +1106,7 @@
 'imagelinks'                     => 'Co sam linkuje',
 'linkstoimage'                   => 'Nastympujůnce zajty sům adrésowane do tygo plika:',
 'nolinkstoimage'                 => 'Žodno zajta ńy je adrésowano do tygo plika.',
-'morelinkstoimage'               => 'Pokož [[Special:Whatlinkshere/$1|wjyncy uodnośnikůw]] do tygo plika.',
+'morelinkstoimage'               => 'Pokož [[Special:WhatLinksHere/$1|wjyncy uodnośnikůw]] do tygo plika.',
 'redirectstofile'                => 'Nastympujůnce pliki překerowujům do tygo plika:',
 'duplicatesoffile'               => 'Nastympujůnce pliki sům kopjami tygo plika:',
 'sharedupload'                   => 'Tyn plik je wćepńjynty na wspůlny serwer i inkše projekty tyž můgům go užywać.',
@@ -1132,18 +1125,18 @@
 # File reversion
 'filerevert'                => 'Přiwracańy $1',
 'filerevert-legend'         => 'Přiwracańy poprzedńy wersje plika',
-'filerevert-intro'          => '<span class="plainlinks">Zamjeřoš přiwrůćić \'\'\'[[Media:$1|$1]]\'\'\' do wersje z [$4 $3, $2].</span>',
+'filerevert-intro'          => "Zamjeřoš přiwrůćić '''[[Media:$1|$1]]''' do wersje z [$4 $3, $2].",
 'filerevert-comment'        => 'Kůmyntorz:',
 'filerevert-defaultcomment' => 'Přiwrůcůno wersyjo z $2, $1',
 'filerevert-submit'         => 'Přiwrůć',
-'filerevert-success'        => '<span class="plainlinks">Plik \'\'\'[[Media:$1|$1]]\'\'\' zostou cofniynty do [wersyje $4 ze $3, $2].</span>',
+'filerevert-success'        => "Plik '''[[Media:$1|$1]]''' zostou cofńynty do [wersyje $4 ze $3, $2].",
 'filerevert-badversion'     => 'Ńy ma sam popředńij lokalnyj wersyji tygo plika s podanům datům.',
 
 # File deletion
 'filedelete'                  => 'Wyćepańe $1',
 'filedelete-legend'           => 'Wyćep plik',
 'filedelete-intro'            => "Wyćepuješ '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Wyćepuješ wersyja plika \'\'\'[[Media:$1|$1]]\'\'\' s datům [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Wyćepuješ wersyja plika '''[[Media:$1|$1]]''' s datům [$4 $3, $2].",
 'filedelete-comment'          => 'Čymu chceš wyćepnůńć:',
 'filedelete-submit'           => 'Wyćep',
 'filedelete-success'          => "Wyćepano plik '''$1'''.",
@@ -1290,7 +1283,7 @@
 'logempty'             => 'Ńy ma wpisůw we rejeře',
 'log-title-wildcard'   => 'Šnupej za titlami kere začynojům śe uod tygo tekstu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Wšyskie zajty',
 'alphaindexline'    => 'úod $1 do $2',
 'nextpage'          => 'Nostympno zajta ($1)',
@@ -1313,12 +1306,12 @@
 'special-categories-sort-count' => 'sortowanie wedle ličby',
 'special-categories-sort-abc'   => 'sortowanie wedle alfabyta',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Pokaž užytkowńikůw začynojůnc uod:',
 'listusers-submit'   => 'Pokož',
 'listusers-noresult' => 'Ńy znejdźůno žodnygo užytkowńika.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Uprawńyńo grup užytkowńikůw',
 'listgrouprights-summary'  => 'Půńižy znojdowo śe spis grup užytkowńikůw zdefińowanych na tej wiki, s wyščygůlńyńym přidźelůnych im praw dostympu.
 Wjyncyj informacyji uo indywidualnych prawach idźe znejść [[{{MediaWiki:Listgrouprights-helppage}}|sam tukej]].',
@@ -1329,7 +1322,7 @@
 
 # E-mail user
 'mailnologin'     => 'Brak adresu',
-'mailnologintext' => 'Muśyš śe [[Special:Userlogin|zalůgować]] i mjeć wpisany aktualny adres e-brif w swojich [[Special:Preferences|preferyncyjach]], coby můc wysuać e-brif do inkšygo užytkowńika.',
+'mailnologintext' => 'Muśyš śe [[Special:UserLogin|zalůgować]] i mjeć wpisany aktualny adres e-brif w swojich [[Special:Preferences|preferyncyjach]], coby můc wysuać e-brif do inkšygo užytkowńika.',
 'emailuser'       => 'Wyślij e-brif do tygo užytkowńika',
 'emailpage'       => 'Wyślij e-brif do užytkowńika',
 'emailpagetext'   => 'Půńižšy formulař pozwala na wysuańy jydnej wjadůmośći do užytkowńika pod warůnkym, aže wpisou uůn poprawny adres e-brif w swojich preferyncyjoch. Adres e-brif, kery zostou bez Ćebje wprowadzůny w Twoich preferyncyjoch ukaže śe w polu „Uod”, bez tůž uodbjorca bydźe můg Ci uodpowjydźeć.',
@@ -1354,10 +1347,10 @@
 'nowatchlist'          => 'Ńy ma žodnych pozycyji na liśće zajtůw, na kere dowoš pozůr.',
 'watchlistanontext'    => '$1 coby uobejřeć abo sprowjać elymynty listy zajtůw, na kere dowoš pozůr',
 'watchnologin'         => 'Ńy jest žeś zalůgowany',
-'watchnologintext'     => 'Muśyš śe [[Special:Userlogin|zalůgować]] coby modyfikować lista zajtůw, na kere dowoš pozůr.',
+'watchnologintext'     => 'Muśyš śe [[Special:UserLogin|zalůgować]] coby modyfikować lista zajtůw, na kere dowoš pozůr.',
 'addedwatch'           => 'Dodane do pozorlisty',
 'addedwatchtext'       => "Zajta \"[[:\$1]]\" zostoua dodano do Twojyj [[Special:Watchlist|listy artikli, na kere dowoš pozůr]].
-Na tyi liśće bydzieš miou rejer přišuych sprawjyń tyi zajty i jei zajty godki, a mjano zajty bydźeš mjou škryflane '''tustym''' na [[Special:Recentchanges|liśće pomjyńanych na ůostatku]], cobyś mjou wygoda w jei pomjyńańa filować.",
+Na tyi liśće bydzieš miou rejer přišuych sprawjyń tyi zajty i jei zajty godki, a mjano zajty bydźeš mjou škryflane '''tustym''' na [[Special:RecentChanges|liśće pomjyńanych na ůostatku]], cobyś mjou wygoda w jei pomjyńańa filować.",
 'removedwatch'         => 'Wyćepńjynte s pozorlisty',
 'removedwatchtext'     => 'Artikel "[[:$1]]" zostou wyćepńjynty s pozorlisty.',
 'watch'                => 'Dej pozor',
@@ -1472,7 +1465,7 @@
 Naćiś „cofej”, přeuaduj zajta, a potym zaś wydej polecyńy',
 'protectlogpage'              => 'Zawarte',
 'protectlogtext'              => 'Půńižej znojdowo śe lista zawarć i uodymkńjyńć pojydynčych zajtůw.
-Coby přejřeć lista uobecńy zawartych zajtůw, přeńdź na zajta wykazu [[Special:Protectedpages|zawartych zajtůw]].',
+Coby přejřeć lista uobecńy zawartych zajtůw, přeńdź na zajta wykazu [[Special:ProtectedPages|zawartych zajtůw]].',
 'protectedarticle'            => 'zawar [[$1]]',
 'modifiedarticleprotection'   => 'pomjyńiu poziům zawarćo [[$1]]',
 'unprotectedarticle'          => 'uodymknyu [[$1]]',
@@ -1640,7 +1633,7 @@
 'badipaddress'                => 'Felerny adres IP',
 'blockipsuccesssub'           => 'Zawarće uod sprowjyń udane',
 'blockipsuccesstext'          => 'Užytkowńik [[Special:Contributions/$1|$1]] zostou zawarty uod sprowjyń.<br />
-Přyńdź do [[Special:Ipblocklist|listy zawartych adresůw IP]] coby přejřeć zawarća.',
+Přyńdź do [[Special:IPBlockList|listy zawartych adresůw IP]] coby přejřeć zawarća.',
 'ipb-edit-dropdown'           => 'Sprowjej powody zawjyrańo uod sprowjyń',
 'ipb-unblock-addr'            => 'Uodymknij $1',
 'ipb-unblock'                 => 'Uodymknij užytkowńika abo adres IP',
@@ -1673,7 +1666,7 @@
 'blocklogentry'               => 'zawarto [[$1]], bydźe uodymkńynty: $2 $3',
 'blocklogtext'                => "Půńižej znojdowo śe lista zawarć zouožůnych i zdjyntych s poščygůlnych adresůw IP.
 Na li'śće ńy mo adresůw IP, kere zawarto w sposůb autůmatyčny.
-Coby přejřeć lista uobecńy aktywnych zawarć, přyńdź na zajta [[Special:Ipblocklist|zawartych adresůw i užytkowńikůw]].",
+Coby přejřeć lista uobecńy aktywnych zawarć, přyńdź na zajta [[Special:IPBlockList|zawartych adresůw i užytkowńikůw]].",
 'unblocklogentry'             => 'uodymknyu $1',
 'block-log-flags-anononly'    => 'ino anůnimowi',
 'block-log-flags-nocreate'    => 'twořyńe kůnta je zawarte',
@@ -1710,7 +1703,7 @@
 'lockdbsuccesssub'    => 'Baza danych zostoua půmyślńy zawarto',
 'unlockdbsuccesssub'  => 'Baza danych zostoua půmyślńy uodymkńynto',
 'lockdbsuccesstext'   => 'Baza danych zostoua zawarto.<br />
-Pamjyntej coby [[Special:Unlockdb|jům uodymknůńć]] po zakůńčyńu dźouań admińistracyjnych.',
+Pamjyntej coby [[Special:UnlockDB|jům uodymknůńć]] po zakůńčyńu dźouań admińistracyjnych.',
 'unlockdbsuccesstext' => 'Baza danych zostoua uodymkńynto.',
 'lockfilenotwritable' => 'Ńy idźe naškreflać plika zawarća bazy danych.
 Zawjerańy i uodmykańy bazy danych wymogo coby plik můgu być naškreflany bez web serwer.',
@@ -1733,8 +1726,6 @@
 *ńy ma sam zajty godki o takiym mjańe
 W takiych razach tekst godki třa přećepać, a jak třeba to i pouůnčyć z tym co juž sam jest, rynčńe. Abo možeš sie namyślić i nie přećepywać wcale ("checkbox" půnižyi).',
 'movearticle'             => 'Přećiś artikel:',
-'movenologin'             => 'Ńy jestžeś zalůgowany',
-'movenologintext'         => 'Muśyš być zarejerowanym i [[Special:Userlogin|zalůgowanym]] užytkowńikym coby můc přećepnůńć zajta.',
 'movenotallowed'          => 'Ńy moš uprownień do přećepywańo zajtůw na {{GRAMMAR:MS.lp|{{SITENAME}}}}.',
 'newtitle'                => 'Nowy titel:',
 'move-watch'              => 'Dej pozor',
@@ -1756,7 +1747,7 @@
 'revertmove'              => 'cofej',
 'delete_and_move'         => 'Wyćep i przećep',
 'delete_and_move_text'    => '== Přećepańy wymaga wyćepańo inkšyj zajty ==
-Zajta docelowo „[[$1]]” juž sam jest.
+Zajta docelowo „[[:$1]]” juž sam jest.
 Čy chceš jům wyćepać, coby zrobić plac do přećepywanej zajty?',
 'delete_and_move_confirm' => 'Toć, wyćep zajta',
 'delete_and_move_reason'  => 'Wyćepano coby zrobić plac do přećepywanyj zajty',
@@ -1987,10 +1978,10 @@
 'show-big-image'       => 'Oryginalno rozdźelčość',
 'show-big-image-thumb' => '<small>Rozmiar podglůndu: $1 × $2 pikseli</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerjo nowych uobrozkůw',
 'imagelisttext'         => "Půnižyj na {{PLURAL:$1||posortowanyj $2}} liśće {{PLURAL:$1|znojdowo|znojdujům|znojdowo}} śe '''$1''' {{PLURAL:$1|plik|pliki|plikůw}}.",
-'newimages-summary'     => 'Na tyi ekstra zajće prezyntowane sům uostatńo wćepńjynte pliki.',
+'newimages-summary'     => 'Na tyi ekstra zajće prezyntowane sům uostatńo wćepńynte pliki.',
 'showhidebots'          => '($1 boty)',
 'noimages'              => 'Brak plikůw do pokozańo.',
 'ilsubmit'              => 'Šnupej',
@@ -2270,7 +2261,7 @@
 
 # External editor support
 'edit-externally'      => 'Edytuj tyn plik bez zewnyntřno aplikacyjo',
-'edit-externally-help' => 'Zoboč wjyncyj informacyji uo užywańu [http://meta.wikimedia.org/wiki/Help:External_editors zewnyntřnych edytorůw].',
+'edit-externally-help' => 'Zoboč wjyncyj informacyji uo užywańu [http://www.mediawiki.org/wiki/Manual:External_editors zewnyntřnych edytorůw].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'wšyjstke',
@@ -2339,7 +2330,7 @@
 'recreate'            => 'Wćepej nazod',
 
 # HTML dump
-'redirectingto' => 'Překerowańy do [[$1]]...',
+'redirectingto' => 'Překerowańy do [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Wyčyśćić pamjyńć podrynčnům do tyi zajty?
@@ -2436,7 +2427,7 @@
 'version-software-product'         => 'Mjano',
 'version-software-version'         => 'Wersjo',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Śćežka do plika',
 'filepath-page'    => 'Plik:',
 'filepath-submit'  => 'Śćežka',
Index: languages/messages/MessagesKk_kz.php
===================================================================
--- languages/messages/MessagesKk_kz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKk_kz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,9 +1,9 @@
 <?php
-/**
- * Kazakh (Kazakhstan) (Қазақша (Қазақстан))
+/** Kazakh (Kazakhstan) (‪Қазақша (Қазақстан)‬)
  *
  * @ingroup Language
  * @file
+ *
  */
 
 # Inherit everything for now
Index: languages/messages/MessagesHr.php
===================================================================
--- languages/messages/MessagesHr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,17 +4,16 @@
  * @ingroup Language
  * @file
  *
- * @author SpeedyGonsales
  * @author Dalibor Bosits
- * @author MayaSimFan
- * @author Roberta F.
+ * @author Demicx
  * @author Dnik
- * @author Siebrand
  * @author Luka Krstulovic
+ * @author MayaSimFan
+ * @author Roberta F.
+ * @author SpeedyGonsales
+ * @author Suradnik13
  * @author Treecko
  * @author לערי ריינהארט
- * @author Suradnik13
- * @author Demicx
  */
 
 $skinNames = array(
@@ -338,7 +337,7 @@
 'nosuchspecialpage' => 'Posebna stranica ne postoji',
 'nospecialpagetext' => "<big>'''Takva posebna stranica ne postoji.'''</big>
 
-Za popis svih posebnih stranica posjetite [[Special:Specialpages|ovdje]].",
+Za popis svih posebnih stranica posjetite [[Special:SpecialPages|ovdje]].",
 
 # General errors
 'error'                => 'Pogreška',
@@ -381,7 +380,7 @@
 'cannotdelete'         => 'Ne mogu obrisati navedenu stranicu ili sliku. (Moguće da je već obrisana.)',
 'badtitle'             => 'Loš naslov',
 'badtitletext'         => 'Navedeni naslov stranice nepravilan ili loše formirana interwiki poveznica.',
-'perfdisabled'         => 'Privremeno onemogućeno. Koristite kopiju snimljenu $1:',
+'perfdisabled'         => 'Ova mogućnost je privremeno isključena jer usporava bazu podataka do mjere koja svima onemogućava korištenje wikija.',
 'perfcached'           => 'Sljedeći podaci su iz međuspremnika i možda nisu najsvježiji:',
 'perfcachedts'         => 'Sljedeći podaci su iz međuspremnika i zadnji puta su ažurirani u $1.',
 'querypage-no-updates' => 'Osvježavanje ove stranice je trenutačno onemogućeno. Nove promjene neće biti vidljive.',
@@ -416,8 +415,9 @@
 ili se možete ponovo prijaviti pod istim ili drugim imenom. Neke se stranice mogu
 prikazivati kao da ste još uvijek prijavljeni, sve dok ne očistite međuspremnik svog preglednika.',
 'welcomecreation'            => '== Dobrodošli, $1! ==
+Vaš je suradnički račun otvoren. 
 
-Vaš je suradnički račun otvoren. Ne zaboravite podesiti suradničke postavke.',
+Ne zaboravite prilagoditi [[Special:Preferences|{{SITENAME}} postavke]].',
 'loginpagetitle'             => 'Prijava suradnika',
 'yourname'                   => 'Suradničko ime',
 'yourpassword'               => 'Upišite lozinku',
@@ -467,7 +467,7 @@
 'nouserspecified'            => 'Molimo navedite suradničko ime.',
 'wrongpassword'              => 'Lozinka koju ste unijeli nije ispravna. Pokušajte ponovno.',
 'wrongpasswordempty'         => 'Niste unijeli lozinku. Pokušajte ponovno.',
-'passwordtooshort'           => 'Vaša je lozinka prekratka. Lozinke moraju sadržavati najmanje $1 znakova.',
+'passwordtooshort'           => 'Vaša je lozinka nevaljana ili prekratka. Lozinka mora sadržavati najmanje {{PLURAL:$1|1 znak|$1 znakova}} i mora biti različita od imena.',
 'mailmypassword'             => 'Pošalji mi novu lozinku',
 'passwordremindertitle'      => '{{SITENAME}}: nova lozinka.',
 'passwordremindertext'       => 'Netko je (vjerojatno vi, s IP adrese $1)
@@ -583,10 +583,6 @@
 'blockededitsource'                => "Tekst '''vaše izmjene''' na članku '''$1''' prikazan je ispod:",
 'whitelistedittitle'               => 'Za uređivanje stranice morate se prijaviti',
 'whitelistedittext'                => 'Za uređivanje stranice morate se $1.',
-'whitelistreadtitle'               => 'Za čitanje stranice morate se prijaviti',
-'whitelistreadtext'                => 'Za čitanje stranice morate se [[Special:Userlogin|prijaviti]].',
-'whitelistacctitle'                => 'Ne možete otvoriti suradnički račun',
-'whitelistacctext'                 => 'Da biste otvarali suradničke račune na ovom wikiju morate se [[Special:Userlogin|prijaviti]] i posjedovati odgovarajuća ovlaštenja.',
 'confirmedittitle'                 => 'Ovjera e-mail adrese nužna za uređivanje',
 'confirmedittext'                  => 'Morate ovjeriti vašu e-mail adresu prije nego što vam bude omogućeno uređivanje. Molim unesite i ovjerite vašu e-mail adresu u [[Special:Preferences|suradničkim postavkama]].',
 'nosuchsectiontitle'               => 'Odlomak ne postoji',
@@ -601,7 +597,7 @@
 *Ako želite unijeti sadržaj, počnite tipkati u prozor ispod ovog teksta.
 *Ako vam treba pomoć, idite na [[{{MediaWiki:Helppage}}|stranicu za pomoć]].
 *Ako ste ovamo dospjeli slučajno, kliknite "Natrag" (Back) u svom programu.',
-'anontalkpagetext'                 => "----''Ovo je stranica za razgovor s anonimnim suradnikom koji nije otvorio suradnički račun ili se njime ne koristi. Zbog toga se moramo služiti brojčanom IP adresom kako bismo ga identificirali. Takvu adresu često koristi više ljudi. Ako ste anonimni suradnik i smatrate da su vam upućeni irelevantni komentari, molimo vas da [[Special:Userlogin|otvorite suradnički račun ili se prijavite]] te tako u budućnosti izbjegnete zamjenu s drugim anonimnim suradnicima.''",
+'anontalkpagetext'                 => "----''Ovo je stranica za razgovor s anonimnim suradnikom koji nije otvorio suradnički račun ili se njime ne koristi. Zbog toga se moramo služiti brojčanom IP adresom kako bismo ga identificirali. Takvu adresu često koristi više ljudi. Ako ste anonimni suradnik i smatrate da su vam upućeni irelevantni komentari, molimo vas da [[Special:UserLogin|otvorite suradnički račun ili se prijavite]] te tako u budućnosti izbjegnete zamjenu s drugim anonimnim suradnicima.''",
 'noarticletext'                    => 'Na ovoj stranici trenutačno nema sadržaja, možete [[Special:Search/{{PAGENAME}}|potražiti ovaj naslov]] u drugim stranicama ili [{{fullurl:{{FULLPAGENAME}}|action=edit}} urediti ovu stranicu].',
 'userpage-userdoesnotexist'        => 'Suradničko ime "$1" nije prijavljeno. Jeste li sigurni da želite stvoriti/uređivati ovu stranicu?',
 'clearyourcache'                   => "'''Napomena:''' Nakon snimanja trebate očistiti međuspremnik svog preglednika kako biste vidjeli promjene.
@@ -621,7 +617,7 @@
 
 ''Budući da je na ovom wikiju ({{SITENAME}}) omogućen unos HTML oznaka (tagova), pretpregled je skriven kao mjera predstrožnosti protiv napada pomoću JavaScripta.''
 
-<strong>Ukoliko ste pokušali vidjeti kako stranica izgleda, molimo probajte opet. Ako ne uspije, odjavite se i prijavite se ponovo.</strong>",
+<strong>Ukoliko ste pokušali vidjeti kako stranica izgleda, molimo probajte opet. Ako ne uspije, [[Special:UserLogout|odjavite se]] i prijavite se ponovo.</strong>",
 'token_suffix_mismatch'            => '<strong>Vaše uređivanje je odbačeno jer je vaš web preglednik ubacio znak/znakove interpunkcije u token uređivanja.
 Stoga je uređivanje odbačeno da se spriječi uništavanje stranice.
 To se događa ponekad kad rabite neispravan web-baziran anonimni proxy.</strong>',
@@ -659,7 +655,7 @@
 'hiddencategories'                 => 'Ova stranica je član {{PLURAL:$1|1 skrivene kategorija|$1 skrivene kategorije|$1 skrivenih kategorija}}:',
 'nocreatetitle'                    => 'Otvaranje novih stranica ograničeno',
 'nocreatetext'                     => 'Na ovom je projektu ograničeno otvaranje novih stranica.
-Možete se vratiti i uređivati već postojeće stranice ili se [[Special:Userlogin|prijaviti ili otvoriti suradnički račun]].',
+Možete se vratiti i uređivati već postojeće stranice ili se [[Special:UserLogin|prijaviti ili otvoriti suradnički račun]].',
 'nocreate-loggedin'                => 'Nemate ovlasti za stvaranje novih stranica na {{SITENAME}}.',
 'permissionserrors'                => 'Pogreška u pravima',
 'permissionserrorstext'            => 'Nemate ovlasti za tu radnju iz sljedećih {{PLURAL:$1|razlog|razloga}}:',
@@ -777,7 +773,7 @@
 # Suppression log
 'suppressionlog'     => 'Evidencije sakrivanja',
 'suppressionlogtext' => 'Slijedi popis brisanja i blokiranja koji uključuje sadržaj skriven za administratore.<br />
-Vidi [[Special:Ipblocklist|Popis blokiranih IP adresa]] za popis trenutačno aktivnih blokiranih adresa.',
+Vidi [[Special:IPBlockList|Popis blokiranih IP adresa]] za popis trenutačno aktivnih blokiranih adresa.',
 
 # History merging
 'mergehistory'                     => 'Spoji povijesti starih izmjena stranice',
@@ -819,7 +815,7 @@
 # Search results
 'searchresults'             => 'Rezultati pretrage',
 'searchresulttext'          => 'Za više obavijesti o pretraživanju projekta {{SITENAME}} vidi [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "Za upit '''[[:$1]]'''",
+'searchsubtitle'            => 'Tražili ste \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|sve stranice koje počinju sa "$1"]] | [[Special:WhatLinksHere/$1|sve stranice koje povezuju na "$1"]])',
 'searchsubtitleinvalid'     => 'Za upit "$1"',
 'noexactmatch'              => "'''Ne postoji stranica naziva \"\$1\".''' Možete [[:\$1|kreirati tu stranicu]].",
 'noexactmatch-nocreate'     => "'''Nema stranice s imenom: \"\$1\".'''",
@@ -862,7 +858,7 @@
 'mypreferences'            => 'Moje postavke',
 'prefs-edits'              => 'Broj vaših uređivanja:',
 'prefsnologin'             => 'Niste prijavljeni',
-'prefsnologintext'         => 'Morate biti [[Special:Userlogin|prijavljeni]]
+'prefsnologintext'         => 'Morate biti [[Special:UserLogin|prijavljeni]]
 za podešavanje suradničkih postavki.',
 'prefsreset'               => 'Postavke su vraćene na prvotne vrijednosti.',
 'qbsettings'               => 'Traka',
@@ -937,7 +933,7 @@
 'userrights-reason'           => 'Razlog za promjenu:',
 'userrights-no-interwiki'     => 'Nemate prava da uređujete prava suradnika na drugim wikijima.',
 'userrights-nodatabase'       => 'Baza podataka $1 ne postoji ili nije lokalno dostupna.',
-'userrights-nologin'          => 'Trebate se [[Special:Userlogin|prijaviti]] s administratorskim računom da bi mogli dodijeliti suradnička prava.',
+'userrights-nologin'          => 'Trebate se [[Special:UserLogin|prijaviti]] s administratorskim računom da bi mogli dodijeliti suradnička prava.',
 'userrights-notallowed'       => 'Vaš trenutačni suradnički račun nema ovlasti mijenjanja suradničkih prava.',
 'userrights-changeable-col'   => 'Grupe koje možete promjeniti',
 'userrights-unchangeable-col' => 'Grupe koje nemožete promjeniti',
@@ -1065,12 +1061,12 @@
 'reupload'                    => 'Ponovno postavi',
 'reuploaddesc'                => 'Vratite se u obrazac za postavljanje.',
 'uploadnologin'               => 'Niste prijavljeni',
-'uploadnologintext'           => 'Za postavljanje datoteka morate biti  [[Special:Userlogin|prijavljeni]].',
+'uploadnologintext'           => 'Za postavljanje datoteka morate biti  [[Special:UserLogin|prijavljeni]].',
 'upload_directory_missing'    => 'Mapa za datoteke ($1) nedostaje i webserver ju ne može napraviti.',
 'upload_directory_read_only'  => 'Server ne može pisati u direktorij za postavljanje ($1).',
 'uploaderror'                 => 'Pogreška kod postavljanja',
 'uploadtext'                  => "Ovaj obrazac služi za postavljanje slika. Za pregledavanje i pretraživanje već postavljenih slika
-vidi [[Special:Imagelist|popis postavljenih datoteka]]. Postavljanja i brisanja bilježe se i u [[Special:Log|evidenciji]].
+vidi [[Special:ImageList|popis postavljenih datoteka]]. Postavljanja i brisanja bilježe se i u [[Special:Log|evidenciji]].
 
 Stavljanjem oznake u odgovarajući kvadratić morate potvrditi da postavljanjem slike ne kršite ničija autorska prava.
 Na kraju pritisnite dugme \"Postavi datoteku\".
@@ -1158,7 +1154,7 @@
 'upload_source_url'  => ' (valjani, javno dostupni URL)',
 'upload_source_file' => ' (datoteka na vašem računalu)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ova posebna stranica pokazuje sve postavljene datoteke.
 Na vrhu popisa se nalaze najnovije postavljene datoteke.
 Poredak datoteka mijenja se pritiskom na naslov stupca.',
@@ -1186,7 +1182,7 @@
 'imagelinks'                     => 'Poveznice slike',
 'linkstoimage'                   => '{{PLURAL:$1|Sljedeća stranica povezuje|$1 Sljedeće stranice povezuju}} na ovu datoteku:',
 'nolinkstoimage'                 => 'Nijedna stranica ne povezuje na ovu sliku.',
-'morelinkstoimage'               => 'Pogledaj [[Special:Whatlinkshere/$1|više poveznica]] za ovu datoteku.',
+'morelinkstoimage'               => 'Pogledaj [[Special:WhatLinksHere/$1|više poveznica]] za ovu datoteku.',
 'redirectstofile'                => '{{PLURAL:$1|Sljedeća datoteka preusmjerava|$1 Sljedeće datoteke preusmjeravaju}} na ovu datoteku:',
 'duplicatesoffile'               => '{{PLURAL:$1|Sljedeća datoteka je kopija|$1 Sljedeće datoteke su kopije}} ove datoteke:',
 'sharedupload'                   => 'Ova je datoteka postavljena na zajedničkom poslužitelju i mogu je koristiti ostali wikiji',
@@ -1205,18 +1201,18 @@
 # File reversion
 'filerevert'                => 'Ukloni ← $1',
 'filerevert-legend'         => 'Vrati datoteku',
-'filerevert-intro'          => '<span class="plainlinks">Vraćate \'\'\'[[Media:$1|$1]]\'\'\' na [$4 promjenu od $3, $2].</span>',
+'filerevert-intro'          => "Vraćate '''[[Media:$1|$1]]''' na [$4 promjenu od $3, $2].",
 'filerevert-comment'        => 'Komentar:',
 'filerevert-defaultcomment' => 'Vraćeno na inačicu od $2, $1',
 'filerevert-submit'         => 'Vrati',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' je vraćena na [$4 promjenu od $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' je vraćena na [$4 promjenu od $3, $2].",
 'filerevert-badversion'     => 'Nema prethodne lokalne inačice datoteke s zadanim datumom i vremenom.',
 
 # File deletion
 'filedelete'                  => 'Izbriši $1',
 'filedelete-legend'           => 'Izbriši datoteku',
 'filedelete-intro'            => "Brišete datoteku '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Brišete inačicu \'\'\'[[Media:$1|$1]]\'\'\' od [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Brišete inačicu '''[[Media:$1|$1]]''' od [$4 $3, $2].",
 'filedelete-comment'          => 'Komentar:',
 'filedelete-submit'           => 'Izbriši',
 'filedelete-success'          => "Datoteka '''$1''' je izbrisana.",
@@ -1274,7 +1270,7 @@
 U prosjeku to iznosi '''$5''' uređivanja po stranici, i '''$6''' pregleda po uređivanju.
 
 Duljina [http://www.mediawiki.org/wiki/Manual:Job_queue zadataka za izvršavanje] je '''$7'''.",
-'userstatstext'          => "Broj prijavljenih [[Special:Listusers|suradnika]] je '''$1'''. Od toga {{PLURAL:$2|je '''$2''' (ili '''$4%''') administrator|su '''$2''' (ili '''$4%''') administratora|su '''$2''' (ili '''$4%''') administratori}}, tj. imaju $5 prava.",
+'userstatstext'          => "Broj prijavljenih [[Special:ListUsers|suradnika]] je '''$1'''. Od toga {{PLURAL:$2|je '''$2''' (ili '''$4%''') administrator|su '''$2''' (ili '''$4%''') administratora|su '''$2''' (ili '''$4%''') administratori}}, tj. imaju $5 prava.",
 'statistics-mostpopular' => 'Najposjećenije stranice',
 
 'disambiguations'      => 'Razdvojbene stranice',
@@ -1283,10 +1279,11 @@
 Umjesto toga bi trebale povezivati na prikladnu temu.<br />
 Stranica se tretira kao razdvojbena stranica ako koristi predložak na kojega vodi [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Dvostruka preusmjeravanja',
-'doubleredirectstext' => 'Ovo je popis preusmjeravanja na stranice za preusmjeravanje.
+'doubleredirects'            => 'Dvostruka preusmjeravanja',
+'doubleredirectstext'        => 'Ovo je popis preusmjeravanja na stranice za preusmjeravanje.
 Svaki redak sadrži poveznice na prvo i drugo preusmjeravanje, te na prvi redak teksta drugog preusmjeravanja
 koja obično ukazuje na "pravu" odredišnu stranicu, na koju bi trebalo pokazivati prvo preusmjeravanje.',
+'double-redirect-fixed-move' => '[[$1]] je premješten, sada je preusmjeravanje na [[$2]]',
 
 'brokenredirects'        => 'Kriva preusmjeravanja',
 'brokenredirectstext'    => 'Sljedeća preusmjeravanja pokazuju na nepostojeće članke.',
@@ -1373,7 +1370,7 @@
 'logempty'             => 'Nema pronađenih stavki.',
 'log-title-wildcard'   => 'Traži stranice koje počinju s navedenim izrazom',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Sve stranice',
 'alphaindexline'    => '$1 do $2',
 'nextpage'          => 'Sljedeća stranica ($1)',
@@ -1396,12 +1393,12 @@
 'special-categories-sort-count' => 'razvrstavanje po broju',
 'special-categories-sort-abc'   => 'abecedno razvrstavanje',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Prikaži suradnike počevši od:',
 'listusers-submit'   => 'Prikaži',
 'listusers-noresult' => 'Nema takvih suradnika.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Prava suradničkih skupina',
 'listgrouprights-summary'  => 'Ovo je popis suradničkih skupina određenih na ovoj wiki, s njihovim pripadajućim pravima.
 Dodatne informacije o pojedinim pravim se mogu pronaći [[{{MediaWiki:Listgrouprights-helppage}}|ovdje]].',
@@ -1412,7 +1409,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nema adrese pošiljaoca',
-'mailnologintext' => 'Morate biti [[Special:Userlogin|prijavljeni]]
+'mailnologintext' => 'Morate biti [[Special:UserLogin|prijavljeni]]
 i imati valjanu adresu e-pošte u svojim [[Special:Preferences|postavkama]]
 da bi mogli slati poštu drugim suradnicima.',
 'emailuser'       => 'Pošalji e-poštu ovom suradniku',
@@ -1442,12 +1439,12 @@
 'nowatchlist'          => 'Na vašem popisu praćenja nema nijednog članka.',
 'watchlistanontext'    => 'Molimo Vas $1 kako bi mogli vidjeti ili uređivati vaš popis praćenih stranica.',
 'watchnologin'         => 'Niste prijavljeni',
-'watchnologintext'     => 'Morate biti [[Special:Userlogin|prijavljeni]]
+'watchnologintext'     => 'Morate biti [[Special:UserLogin|prijavljeni]]
 za promjene u popisu praćenja.',
 'addedwatch'           => 'Dodano u popis praćenja',
 'addedwatchtext'       => 'Stranica "<nowiki>$1</nowiki>" je dodana na vaš [[Special:Watchlist|popis praćenja]].
 Promjene na ovoj stranici i njenoj stranici za razgovor bit će tamo prikazani, a stranica će biti ispisana
-<b>podebljano</b> u [[Special:Recentchanges|popisu nedavnih promjena]], da biste je lakše primijetili.
+<b>podebljano</b> u [[Special:RecentChanges|popisu nedavnih promjena]], da biste je lakše primijetili.
 <p>Ako poželite ukloniti stranicu s popisa praćenja, pritisnite "Prekini praćenje" u traci s naredbama.</p>',
 'removedwatch'         => 'Odstranjena s popisa praćenja',
 'removedwatchtext'     => 'Stranica "<nowiki>$1</nowiki>" je odstranjena s vašeg popisa praćenja.',
@@ -1562,7 +1559,7 @@
 s koje ste stigli.',
 'protectlogpage'              => 'Evidencija zaštićivanja',
 'protectlogtext'              => 'Ispod je evidencija zaštićivanja i uklanjanja zaštite pojedinih stranica.
-Pogledajte [[Special:Protectedpages|zaštićene stranice]] za popis trenutačno zaštićenih stranica.',
+Pogledajte [[Special:ProtectedPages|zaštićene stranice]] za popis trenutačno zaštićenih stranica.',
 'protectedarticle'            => 'članak "[[$1]]" je zaštićen',
 'modifiedarticleprotection'   => 'promijenjen stupanj zaštite za "[[$1]]"',
 'unprotectedarticle'          => 'uklonjena zaštita članka "[[$1]]"',
@@ -1727,7 +1724,7 @@
 'badipaddress'                    => 'Nevaljana IP adresa.',
 'blockipsuccesssub'               => 'Uspješno blokirano',
 'blockipsuccesstext'              => 'Suradnik [[Special:Contributions/$1|$1]] je blokiran.<br />
-Pogledaj [[Special:Ipblocklist|popis blokiranih IP adresa]] za pregled.',
+Pogledaj [[Special:IPBlockList|popis blokiranih IP adresa]] za pregled.',
 'ipb-edit-dropdown'               => 'Uredi razloge blokiranja',
 'ipb-unblock-addr'                => 'Odblokiraj $1',
 'ipb-unblock'                     => 'Odblokiraj suradničko ime ili IP adresu',
@@ -1757,7 +1754,7 @@
 'autoblocker'                     => 'Automatski ste blokirani jer je vašu IP adresu nedavno koristio "[[User:$1|$1]]" koji je blokiran zbog: "$2".',
 'blocklogpage'                    => 'Evidencija blokiranja',
 'blocklogentry'                   => 'Blokiran je "[[$1]]" na rok $2 $3',
-'blocklogtext'                    => 'Ovo je evidencija blokiranja i deblokiranja. Na popisu nema automatski blokiranih IP adresa. Za popis trenutačnih zabrana i blokiranja vidi [[Special:Ipblocklist|popis IP blokiranja]].',
+'blocklogtext'                    => 'Ovo je evidencija blokiranja i deblokiranja. Na popisu nema automatski blokiranih IP adresa. Za popis trenutačnih zabrana i blokiranja vidi [[Special:IPBlockList|popis IP blokiranja]].',
 'unblocklogentry'                 => 'Deblokiran "$1"',
 'block-log-flags-anononly'        => 'samo za neprijavljene (anonimne) suradnike',
 'block-log-flags-nocreate'        => 'otvaranje novih suradničkih imena nije moguće',
@@ -1820,8 +1817,6 @@
 U tim slučajevima ćete morati sami premjestiti ili iskopirati stranicu za razgovor,
 ako to želite.",
 'movearticle'             => 'Premjesti stranicu',
-'movenologin'             => 'Niste prijavljeni',
-'movenologintext'         => 'Ako želite premjestiti stranicu morate biti [[Special:Userlogin|prijavljeni]].',
 'movenotallowed'          => 'Nemate pravo premještanja stranica na ovom projektu ({{SITENAME}}).',
 'newtitle'                => 'Na novi naslov',
 'move-watch'              => 'Prati ovu stranicu',
@@ -1849,7 +1844,7 @@
 'delete_and_move'         => 'Izbriši i premjesti',
 'delete_and_move_text'    => '==Nužno brisanje==
 
-Odredišni članak "[[$1]]" već postoji. Želite li ga obrisati da biste napravili mjesto za premještaj?',
+Odredišni članak "[[:$1]]" već postoji. Želite li ga obrisati da biste napravili mjesto za premještaj?',
 'delete_and_move_confirm' => 'Da, izbriši stranicu',
 'delete_and_move_reason'  => 'Obrisano kako bi se napravilo mjesta za premještaj.',
 'selfmove'                => 'Izvorni i odredišni naslov su isti; ne mogu premjestiti stranicu na nju samu.',
@@ -1857,6 +1852,7 @@
 'imagenocrossnamespace'   => 'Datoteka ne može biti premještena u imenski prostor koji nije za datoteke',
 'imagetypemismatch'       => 'Ekstenzija nove datoteke se ne poklapa sa svojim tipom.',
 'imageinvalidfilename'    => 'Ciljano ime datoteke je nevaljano',
+'fix-double-redirects'    => 'Ažuriraj sva preusmjeravanja koja vode na originalni naslov',
 
 # Export
 'export'            => 'Izvezi stranice',
@@ -2052,9 +2048,10 @@
 'markedaspatrollederror-noautopatrol' => 'Ne možete vlastite promjene označiti patroliranima.',
 
 # Patrol log
-'patrol-log-page' => 'Evidencija pregledavanja promjena',
-'patrol-log-line' => 'promjena broj $1 stranice $2 pregledana $3',
-'patrol-log-auto' => '(automatski pregledano)',
+'patrol-log-page'   => 'Evidencija pregledavanja promjena',
+'patrol-log-header' => 'Ovo su evidencije patroliranih izmjena.',
+'patrol-log-line'   => 'promjena broj $1 stranice $2 pregledana $3',
+'patrol-log-auto'   => '(automatski pregledano)',
 
 # Image deletion
 'deletedrevision'                 => 'Izbrisana stara inačica $1',
@@ -2084,10 +2081,10 @@
 'show-big-image'       => 'Vidi sliku u punoj veličini (rezoluciji)',
 'show-big-image-thumb' => '<small>Veličina pretpregleda: $1 × $2 piksela</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerija novih datoteka',
 'imagelisttext'         => 'Ispod je popis {{PLURAL:$1|$1 slike|$1 slike|$1 slika}} složen $2.',
-'newimages-summary'     => 'Ova posebna stranica pokazuje zadnje nedavno postavljene datoteke',
+'newimages-summary'     => 'Ova posebna stranica pokazuje zadnje nedavno postavljene datoteke.',
 'showhidebots'          => '($1 botova)',
 'noimages'              => 'Nema slika.',
 'ilsubmit'              => 'Traži',
@@ -2372,7 +2369,7 @@
 
 # External editor support
 'edit-externally'      => 'Uredi koristeći se vanjskom aplikacijom',
-'edit-externally-help' => 'Vidi [http://meta.wikimedia.org/wiki/Help:External_editors setup upute] za više informacija.',
+'edit-externally-help' => 'Vidi [http://www.mediawiki.org/wiki/Manual:External_editors setup upute] za više informacija.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'sve',
@@ -2442,7 +2439,7 @@
 'recreate'            => 'Vrati',
 
 # HTML dump
-'redirectingto' => 'Preusmjeravam na [[$1]]...',
+'redirectingto' => 'Preusmjeravam na [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Isprazniti međuspremnik stranice?
@@ -2540,7 +2537,7 @@
 'version-software-product'         => 'Proizvod',
 'version-software-version'         => 'Verzija',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Putanja datoteke',
 'filepath-page'    => 'Datoteka:',
 'filepath-submit'  => 'Putanja',
@@ -2578,7 +2575,7 @@
 'specialpages-group-redirects'   => 'Preusmjeravajuće posebne stranice',
 'specialpages-group-spam'        => 'Spam alati',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Prazna stranica',
 'intentionallyblankpage' => 'Ova stranica je namjerno ostavljena praznom',
 
Index: languages/messages/MessagesEn_gb.php
===================================================================
--- languages/messages/MessagesEn_gb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEn_gb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -7,6 +7,13 @@
  * @author Jon Harald Søby
  */
 
+$specialPageAliases = array(
+	'Uncategorizedpages'        => array( 'UncategorisedPages' ),
+	'Uncategorizedcategories'   => array( 'UncategorisedCategories' ),
+	'Uncategorizedimages'       => array( 'UncategorisedImages' ),
+	'Uncategorizedtemplates'    => array( 'UncategorisedTemplates' ),
+);
+
 $messages = array(
 # Main script and global functions
 'nosuchactiontext' => 'The action specified by the URL is not recognised by the wiki',
Index: languages/messages/MessagesPl.php
===================================================================
--- languages/messages/MessagesPl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,23 +4,22 @@
  * @ingroup Language
  * @file
  *
- * @author Sp5uhe
+ * @author Beau
  * @author Derbeth
- * @author ToSter
- * @author לערי ריינהארט
- * @author Wpedzich
+ * @author Equadus
+ * @author Herr Kriss
+ * @author Lajsikonik
  * @author Leinad
- * @author Beau
- * @author Siebrand
- * @author Stv
+ * @author Maikking
  * @author Masti
- * @author Maikking
- * @author Ymar
  * @author Matma Rex
- * @author Equadus
- * @author Lajsikonik
+ * @author Sp5uhe
+ * @author Stv
  * @author Szczepan1990
- * @author Herr Kriss
+ * @author ToSter
+ * @author Wpedzich
+ * @author Ymar
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -75,6 +74,8 @@
 	'.' => ','
 );
 
+$linkTrail = '/^([a-zęóąśłżźćńĘÓĄŚŁŻŹĆŃ]+)(.*)$/sDu';
+
 $specialPageAliases = array(
 	'DoubleRedirects'           => array( 'Podwójne_przekierowania' ),
 	'BrokenRedirects'           => array( 'Zerwane_przekierowania' ),
@@ -490,7 +491,7 @@
 'nosuchspecialpage' => 'Brak takiej strony specjalnej',
 'nospecialpagetext' => "<big>'''Brak żądanej strony specjalnej.'''</big>
 
-Listę dostępnych stron specjalnych znajdziesz [[Special:Specialpages|tutaj]].",
+Listę dostępnych stron specjalnych znajdziesz [[Special:SpecialPages|tutaj]].",
 
 # General errors
 'error'                => 'Błąd',
@@ -521,7 +522,7 @@
 Zazwyczaj jest to spowodowane odwołaniem do nieaktualnego linku prowadzącego do różnicy pomiędzy dwoma wersjami strony lub do wersji z historii usuniętej strony.
 
 Jeśli tak nie jest, możliwe, że problem został wywołany przez błąd w oprogramowaniu.
-Można zgłosić ten fakt administratorowi, podając adres URL.',
+Można zgłosić ten fakt [[Special:ListUsers/sysop|administratorowi]], podając adres URL.',
 'missingarticle-rev'   => '(wersja: $1)',
 'missingarticle-diff'  => '(różnica: $1, $2)',
 'readonly_lag'         => 'Baza danych została automatycznie zablokowana na czas potrzebny do wykonania synchronizacji zmian między serwerem głównym i serwerami pośredniczącymi.',
@@ -575,11 +576,11 @@
 'logouttitle'                => 'Wylogowanie użytkownika',
 'logouttext'                 => '<strong>Zostałeś wylogowany.</strong>
 
-Możesz kontynuować pracę w {{GRAMMAR:MS.lp|{{SITENAME}}}} jako niezarejestrowany użytkownik albo zalogować się ponownie jako ten sam lub inny użytkownik.
-Zauważ, że do momentu wyczyszczenia pamięci podręcznej przeglądarki niektóre strony oglądane przez Ciebie wcześniej, gdy byłeś zalogowany, mogą być nadal przeglądane.',
+Możesz kontynuować pracę w {{GRAMMAR:MS.lp|{{SITENAME}}}} jako niezarejestrowany użytkownik albo [[Special:UserLogin|zalogować się ponownie]] jako ten sam lub inny użytkownik.
+Zauważ, że do momentu wyczyszczenia pamięci podręcznej przeglądarki niektóre strony mogą wyglądać tak, jakbyś wciąż był zalogowany.',
 'welcomecreation'            => '== Witaj, $1! ==
-Konto zostało utworzone.
-Nie zapomnij dostosować preferencji dla {{GRAMMAR:D.lp|{{SITENAME}}}}.',
+Twoje konto zostało utworzone.
+Nie zapomnij dostosować [[Special:Preferences|preferencji dla {{GRAMMAR:D.lp|{{SITENAME}}}}]].',
 'loginpagetitle'             => 'Logowanie',
 'yourname'                   => 'Nazwa użytkownika:',
 'yourpassword'               => 'Hasło:',
@@ -760,10 +761,6 @@
 'blockededitsource'                => "Tekst '''Twoich edycji''' na '''$1''' został pokazany poniżej:",
 'whitelistedittitle'               => 'Przed edycją musisz się zalogować',
 'whitelistedittext'                => 'Musisz $1, by edytować strony.',
-'whitelistreadtitle'               => 'Czytanie możliwe jest dopiero po zalogowaniu się',
-'whitelistreadtext'                => 'Musisz [[Special:Userlogin|zalogować się]], żeby czytać strony.',
-'whitelistacctitle'                => 'Nie masz uprawnień do założenia konta',
-'whitelistacctext'                 => 'Zakładanie kont w {{GRAMMAR:MS.lp|{{SITENAME}}}} wymaga [[Special:Userlogin|zalogowania się]] oraz posiadania odpowiednich uprawnień.',
 'confirmedittitle'                 => 'Edytowanie jest możliwe dopiero po zweryfikowaniu adresu e-mail',
 'confirmedittext'                  => 'Edytowanie jest możliwe dopiero po zweryfikowaniu adresu e-mail.
 Podaj adres e-mail i potwierdź go w swoich [[Special:Preferences|ustawieniach użytkownika]].',
@@ -779,9 +776,10 @@
 'newarticletext'                   => "Brak strony o tym tytule.
 Jeśli chcesz ją utworzyć, wpisz treść strony w poniższym polu (więcej informacji odnajdziesz [[{{MediaWiki:Helppage}}|na stronie pomocy]]). 
 Jeśli utworzenie nowej strony nie było Twoim zamiarem, wciśnij ''Wstecz'' w swojej przeglądarce.",
-'anontalkpagetext'                 => "---- ''To jest strona dyskusji anonimowego użytkownika – takiego, który nie ma jeszcze swojego konta lub nie chce go w tej chwili używać. By go identyfikować, używamy adresów IP.
+'anontalkpagetext'                 => "---- ''To jest strona dyskusji anonimowego użytkownika – takiego, który nie ma jeszcze swojego konta lub nie chce go w tej chwili używać.
+By go identyfikować, używamy adresów IP.
 Jednak adres IP może być współdzielony przez wielu użytkowników.
-Jeśli jesteś anonimowym użytkownikiem i uważasz, że zamieszczone tu komentarze nie są skierowane do Ciebie, [[Special:Userlogin|utwórz konto lub zaloguj się]] – dzięki temu unikniesz w przyszłości podobnych nieporozumień.''",
+Jeśli jesteś anonimowym użytkownikiem i uważasz, że zamieszczone tu komentarze nie są skierowane do Ciebie, [[Special:UserLogin/signup|utwórz konto]] lub [[Special:UserLogin|zaloguj się]] – dzięki temu unikniesz w przyszłości podobnych nieporozumień.''",
 'noarticletext'                    => 'Brak strony o tym tytule. Możesz [[Special:Search/{{PAGENAME}}|poszukać {{PAGENAME}} na innych stronach]] lub [{{fullurl:{{FULLPAGENAME}}|action=edit}} utworzyć stronę {{FULLPAGENAME}}].',
 'userpage-userdoesnotexist'        => 'Użytkownik „$1” nie jest zarejestrowany. Upewnij się, czy na pewno zamierzałeś utworzyć/zmodyfikować właśnie tę stronę.',
 'clearyourcache'                   => "'''Uwaga:''' Zmiany po zapisaniu nowych ustawień mogą nie być widoczne. Należy wyczyścić zawartość pamięci podręcznej przeglądarki internetowej.
@@ -798,12 +796,15 @@
 'note'                             => '<strong>Uwaga:</strong>',
 'previewnote'                      => '<strong>To jest tylko podgląd – zmiany nie zostały jeszcze zapisane!</strong>',
 'previewconflict'                  => 'Podgląd odnosi się do tekstu z górnego pola edycji. Tak będzie wyglądać strona, jeśli zdecydujesz się ją zapisać.',
-'session_fail_preview'             => '<strong>Uwaga! Serwer nie może przetworzyć tej edycji z powodu utraty danych sesji. Spróbuj jeszcze raz. Jeśli to nie pomoże – wyloguj się i zaloguj ponownie.</strong>',
+'session_fail_preview'             => '<strong>Uwaga! Serwer nie może przetworzyć tej edycji z powodu utraty danych sesji.
+Spróbuj jeszcze raz.
+Jeśli to nie pomoże – [[Special:UserLogout|wyloguj się]] i zaloguj ponownie.</strong>',
 'session_fail_preview_html'        => "<strong>Uwaga! Serwer nie może przetworzyć tej edycji z powodu utraty danych sesji.</strong>
 
 ''Ponieważ w {{GRAMMAR:MS.lp|{{SITENAME}}}} włączona została opcja „surowy HTML”, podgląd został ukryty w celu zabezpieczenia przed atakami JavaScript.''
 
-<strong>Jeśli jest to uprawniona próba dokonania edycji, spróbuj jeszcze raz. Jeśli to nie pomoże – wyloguj się i zaloguj ponownie.</strong>",
+<strong>Jeśli jest to uprawniona próba dokonania edycji, spróbuj jeszcze raz.
+Jeśli to nie pomoże – [[Special:UserLogout|wyloguj się]] i zaloguj ponownie.</strong>",
 'token_suffix_mismatch'            => '<strong>Twoja edycja została odrzucona, ponieważ twój klient pomieszał znaki interpunkcyjne w żetonie edycyjnym.
 Twoja edycja została odrzucona by zapobiec zniszczeniu tekstu strony.
 Takie problemy zdarzają się w wypadku korzystania z wadliwych anonimowych sieciowych usług proxy.</strong>',
@@ -846,7 +847,7 @@
 'edittools'                        => '<!-- Znajdujący się tutaj tekst zostanie pokazany pod polem edycji i formularzem przesyłania plików. -->',
 'nocreatetitle'                    => 'Ograniczono możliwość tworzenia nowych stron',
 'nocreatetext'                     => 'W {{GRAMMAR:MS.lp|{{SITENAME}}}} ograniczono możliwość tworzenia nowych stron.
-Możesz edytować istniejące strony bądź też [[Special:Userlogin|zalogować się lub utworzyć konto]].',
+Możesz edytować istniejące strony bądź też [[Special:UserLogin|zalogować się lub utworzyć konto]].',
 'nocreate-loggedin'                => 'Nie masz uprawnień do tworzenia stron w {{GRAMMAR:MS.lp|{{SITENAME}}}}.',
 'permissionserrors'                => 'Błędy uprawnień',
 'permissionserrorstext'            => 'Nie masz uprawnień do tego działania z {{PLURAL:$1|następującej przyczyny|następujących przyczyn}}:',
@@ -965,7 +966,7 @@
 # Suppression log
 'suppressionlog'     => 'Rejestr utajniania',
 'suppressionlogtext' => 'Poniżej znajduje się lista usunięć i blokad utajnionych przed administratorami.
-Zobacz [[Special:Ipblocklist|rejestr blokowania adresów IP]], jeśli chcesz sprawdzić aktualne zakazy i blokady.',
+Zobacz [[Special:IPBlockList|rejestr blokowania adresów IP]], jeśli chcesz sprawdzić aktualne zakazy i blokady.',
 
 # History merging
 'mergehistory'                     => 'Scal historię zmian stron',
@@ -1007,7 +1008,8 @@
 # Search results
 'searchresults'             => 'Wyniki wyszukiwania',
 'searchresulttext'          => 'Więcej informacji o przeszukiwaniu {{GRAMMAR:D.lp|{{SITENAME}}}} odnajdziesz na [[{{MediaWiki:Helppage}}|stronach pomocy]].',
-'searchsubtitle'            => "Wyniki dla zapytania '''[[:$1]]'''",
+'searchsubtitle'            => "Wyniki dla zapytania '''[[:$1]]''' ([[Special:Prefixindex/$1|strony zaczynające się od „$1”]] |
+[[Special:WhatLinksHere/$1|strony, które linkują do „$1”]])",
 'searchsubtitleinvalid'     => "Dla zapytania '''$1'''",
 'noexactmatch'              => "'''Brak strony zatytułowanej „$1”.'''
 Możesz [[:$1|utworzyć tę stronę]].",
@@ -1053,7 +1055,7 @@
 'mypreferences'            => 'preferencje',
 'prefs-edits'              => 'Liczba edycji',
 'prefsnologin'             => 'Nie jesteś zalogowany',
-'prefsnologintext'         => 'Musisz się [[Special:Userlogin|zalogować]] przed zmianą swoich preferencji.',
+'prefsnologintext'         => 'Musisz się [[Special:UserLogin|zalogować]] przed zmianą swoich preferencji.',
 'prefsreset'               => 'Preferencje domyślne zostały odtworzone.',
 'qbsettings'               => 'Pasek szybkiego dostępu',
 'qbsettings-none'          => 'Brak',
@@ -1129,7 +1131,7 @@
 'userrights-reason'           => 'Powód zmiany',
 'userrights-no-interwiki'     => 'Nie masz dostępu do edycji uprawnień na innych wiki.',
 'userrights-nodatabase'       => 'Baza danych $1 nie istnieje lub nie jest lokalna.',
-'userrights-nologin'          => 'Musisz [[Special:Userlogin|zalogować się]] na konto administratora, by nadawać uprawnienia użytkownikom.',
+'userrights-nologin'          => 'Musisz [[Special:UserLogin|zalogować się]] na konto administratora, by nadawać uprawnienia użytkownikom.',
 'userrights-notallowed'       => 'Nie masz dostępu do nadawania uprawnień użytkownikom.',
 'userrights-changeable-col'   => 'Grupy, które możesz wybrać',
 'userrights-unchangeable-col' => 'Grupy, których nie możesz wybrać',
@@ -1259,23 +1261,24 @@
 'reupload'                    => 'Prześlij ponownie',
 'reuploaddesc'                => 'Przerwij wysyłanie i wróć do formularza wysyłki',
 'uploadnologin'               => 'Nie jesteś zalogowany',
-'uploadnologintext'           => 'Musisz się [[Special:Userlogin|zalogować]] przed przesłaniem plików.',
+'uploadnologintext'           => 'Musisz się [[Special:UserLogin|zalogować]] przed przesłaniem plików.',
 'upload_directory_missing'    => 'Katalog dla przesyłanych plików ($1) nie istnieje i nie może zostać utworzony przez serwer WWW.',
 'upload_directory_read_only'  => 'Serwer nie może zapisywać do katalogu ($1) przeznaczonego na przesyłane pliki.',
 'uploaderror'                 => 'Błąd wysyłania',
 'uploadtext'                  => "Użyj poniższego formularza do przesłania plików.
-Jeśli chcesz przejrzeć lub przeszukać dotychczas przesłane pliki, przejdź do [[Special:Imagelist|listy plików]]. Każde przesłanie jest odnotowane w [[Special:Log/upload|rejestrze przesyłanych plików]].
+Jeśli chcesz przejrzeć lub przeszukać dotychczas przesłane pliki, przejdź do [[Special:ImageList|listy plików]]. Każde przesłanie jest odnotowane w [[Special:Log/upload|rejestrze przesyłanych plików]], a usunięcie w [[Special:Log/delete|rejestrze usuniętych]].
 
 Plik pojawi się na stronie, jeśli użyjesz linku według jednego z następujących wzorów:
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Plik.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Plik.png|tekst opisu]]</nowiki>''' lub
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Plik.ogg]]</nowiki>''' aby uzyskać bezpośredni link do pliku.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Plik.jpg]]</nowiki></tt>''' pokaże plik w pełnej postaci
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Plik.png|200px|thumb|left|podpis grafiki]]</nowiki></tt>''' pokaże szeroką na 200 pikseli miniaturkę umieszczoną przy lewym marginesie, otoczoną ramką, z podpisem „podpis grafiki”
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Plik.ogg]]</nowiki></tt>''' utworzy bezpośredni link do pliku bez wyświetlania samego pliku",
 'upload-permitted'            => 'Dopuszczalne formaty plików: $1.',
 'upload-preferred'            => 'Zalecane formaty plików: $1.',
 'upload-prohibited'           => 'Zabronione formaty plików: $1.',
 'uploadlog'                   => 'rejestr przesyłania plików',
 'uploadlogpage'               => 'Przesłane',
-'uploadlogpagetext'           => 'Lista ostatnio przesłanych plików.',
+'uploadlogpagetext'           => 'Lista ostatnio przesłanych plików.
+Przejdź na stronę [[Special:NewImages|galerii nowych plików]], by zobaczyć pliki jako miniaturki.',
 'filename'                    => 'Nazwa pliku',
 'filedesc'                    => 'Opis',
 'fileuploadsummary'           => 'Opis',
@@ -1359,11 +1362,11 @@
 'upload-proto-error-text' => 'Zdalne przesyłanie plików wymaga podania adresu URL zaczynającego się od <code>http://</code> lub <code>ftp://</code>.',
 'upload-file-error'       => 'Błąd wewnętrzny',
 'upload-file-error-text'  => 'Wystąpił błąd wewnętrzny podczas próby utworzenia tymczasowego pliku na serwerze.
-Skontaktuj się z administratorem systemu.',
+Skontaktuj się z [[Special:ListUsers/sysop|administratorem systemu]].',
 'upload-misc-error'       => 'Nieznany błąd przesyłania',
 'upload-misc-error-text'  => 'Wystąpił nieznany błąd podczas przesyłania.
-Sprawdź czy podany adres URL jest poprawny i dostępny, a następnie spróbuj ponownie.
-Jeśli problem będzie się powtarzał skontaktuj się z administratorem systemu.',
+Sprawdź, czy podany adres URL jest poprawny i dostępny, a następnie spróbuj ponownie.
+Jeśli problem będzie się powtarzał, skontaktuj się z [[Special:ListUsers/sysop|administratorem systemu]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Adres URL jest nieosiągalny',
@@ -1379,7 +1382,7 @@
 'upload_source_url'  => ' (poprawny, publicznie dostępny adres URL)',
 'upload_source_file' => ' (plik na twoim komputerze)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Na tej stronie specjalnej prezentowane są wszystkie pliki przesłane na serwer.
 Domyślnie na górze listy umieszczane są ostatnio przesłane pliki.
 Kliknięcie w nagłówek kolumny zmienia sposób sortowania.',
@@ -1407,7 +1410,7 @@
 'imagelinks'                     => 'Odnośniki do pliku',
 'linkstoimage'                   => '{{PLURAL:$1|Poniższa strona odwołuje|Następujące strony odwołują}} się do tego pliku:',
 'nolinkstoimage'                 => 'Żadna strona nie odwołuje się do tego pliku.',
-'morelinkstoimage'               => 'Pokaż [[Special:Whatlinkshere/$1|więcej odnośników]] do tego pliku.',
+'morelinkstoimage'               => 'Pokaż [[Special:WhatLinksHere/$1|więcej odnośników]] do tego pliku.',
 'redirectstofile'                => '{{PLURAL:$1|Następujący plik przekierowuje|Następujące pliki przekierowują}} do tego pliku:',
 'duplicatesoffile'               => '{{PLURAL:$1|Następujący plik jest kopią|Następujące pliki są kopiami}} tego pliku:',
 'sharedupload'                   => 'Ten plik znajduje się na wspólnym serwerze plików i może być używany w innych projektach.',
@@ -1426,18 +1429,18 @@
 # File reversion
 'filerevert'                => 'Przywracanie $1',
 'filerevert-legend'         => 'Przywracanie poprzedniej wersji pliku',
-'filerevert-intro'          => '<span class="plainlinks">Zamierzasz przywrócić \'\'\'[[Media:$1|$1]]\'\'\' do [wersji $4 z $3, $2].</span>',
+'filerevert-intro'          => "Zamierzasz przywrócić '''[[Media:$1|$1]]''' do [wersji $4 z $3, $2].",
 'filerevert-comment'        => 'Komentarz:',
 'filerevert-defaultcomment' => 'Przywrócono wersję z $2, $1',
 'filerevert-submit'         => 'Przywróć',
-'filerevert-success'        => '<span class="plainlinks">Plik \'\'\'[[Media:$1|$1]]\'\'\' został cofnięty do [wersji $4 z $3, $2].</span>',
+'filerevert-success'        => "Plik '''[[Media:$1|$1]]''' został cofnięty do [wersji $4 z $3, $2].",
 'filerevert-badversion'     => 'Brak poprzedniej lokalnej wersji tego pliku z podaną datą.',
 
 # File deletion
 'filedelete'                  => 'Usuń „$1”',
 'filedelete-legend'           => 'Usuń plik',
 'filedelete-intro'            => "Usuwasz '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Usuwasz wersję pliku \'\'\'[[Media:$1|$1]]\'\'\' z datą [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Usuwasz wersję pliku '''[[Media:$1|$1]]''' z datą [$4 $3, $2].",
 'filedelete-comment'          => 'Komentarz:',
 'filedelete-submit'           => 'Usuń',
 'filedelete-success'          => "Usunięto plik '''$1'''.",
@@ -1504,8 +1507,10 @@
 a powinny odwoływać się bezpośrednio do stron treści.<br />
 Strona uznawana jest za ujednoznaczniającą, jeśli zawiera ona szablon linkowany przez stronę [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Podwójne przekierowania',
-'doubleredirectstext' => 'Lista zawiera strony z przekierowaniami do stron, które przekierowują do innej strony. Każdy wiersz zawiera linki do pierwszego i drugiego przekierowania oraz link, do którego prowadzi drugie przekierowanie. Ostatni link prowadzi zazwyczaj do strony, do której powinna w rzeczywistości przekierowywać pierwsza strona.',
+'doubleredirects'            => 'Podwójne przekierowania',
+'doubleredirectstext'        => 'Lista zawiera strony z przekierowaniami do stron, które przekierowują do innej strony. Każdy wiersz zawiera linki do pierwszego i drugiego przekierowania oraz link, do którego prowadzi drugie przekierowanie. Ostatni link prowadzi zazwyczaj do strony, do której powinna w rzeczywistości przekierowywać pierwsza strona.',
+'double-redirect-fixed-move' => 'strona [[$1]] została zastąpiona przekierowaniem, ponieważ została przeniesiona do [[$2]]',
+'double-redirect-fixer'      => 'Korektor przekierowań',
 
 'brokenredirects'        => 'Zerwane przekierowania',
 'brokenredirectstext'    => 'Poniższe przekierowania wskazują na nieistniejące strony.',
@@ -1591,7 +1596,7 @@
 'logempty'             => 'Brak wpisów w rejestrze.',
 'log-title-wildcard'   => 'Szukaj tytułów zaczynających się od tego tekstu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Wszystkie strony',
 'alphaindexline'    => 'od $1 do $2',
 'nextpage'          => 'Następna strona ($1)',
@@ -1614,15 +1619,15 @@
 'special-categories-sort-count' => 'sortowanie według liczby',
 'special-categories-sort-abc'   => 'sortowanie alfabetyczne',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Pokaż użytkowników zaczynając od',
 'listusers-submit'   => 'Pokaż',
 'listusers-noresult' => 'Nie znaleziono żadnego użytkownika.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Uprawnienia grup użytkowników',
-'listgrouprights-summary'  => 'Poniżej znajduje się spis zdefiniowanych na tej wiki grup użytkowników, z wyszczególnieniem przydzielonych im praw dostępu.
-Szczegółową informację o uprawnieniach odnajdziesz [[{{MediaWiki:Listgrouprights-helppage}}|tutaj]].',
+'listgrouprights-summary'  => 'Poniżej znajduje się spis zdefiniowanych na tej wiki grup użytkowników, z wyszczególnieniem przydzielonych im uprawnień.
+Sprawdź stronę z [[{{MediaWiki:Listgrouprights-helppage}}|dodatkowymi informacjami]] o uprawnieniach.',
 'listgrouprights-group'    => 'Grupa',
 'listgrouprights-rights'   => 'Uprawnienia',
 'listgrouprights-helppage' => 'Help:Uprawnienia grup użytkowników',
@@ -1630,10 +1635,11 @@
 
 # E-mail user
 'mailnologin'     => 'Brak adresu',
-'mailnologintext' => 'Musisz się [[Special:Userlogin|zalogować]] i mieć wpisany aktualny adres e-mailowy w swoich [[Special:Preferences|preferencjach]], aby móc wysłać e-mail do innego użytkownika.',
+'mailnologintext' => 'Musisz się [[Special:UserLogin|zalogować]] i mieć wpisany aktualny adres e-mailowy w swoich [[Special:Preferences|preferencjach]], aby móc wysłać e-mail do innego użytkownika.',
 'emailuser'       => 'Wyślij e-mail do tego użytkownika',
 'emailpage'       => 'Wyślij e-mail do użytkownika',
-'emailpagetext'   => 'Poniższy formularz pozwala na wysłanie jednej wiadomości do użytkownika pod warunkiem, że wpisał on poprawny adres e-mail w swoich preferencjach. Adres e-mailowy, który został przez Ciebie wprowadzony w Twoich preferencjach pojawi się w polu „Od”, dzięki czemu odbiorca będzie mógł Ci odpowiedzieć.',
+'emailpagetext'   => 'Poniższy formularz pozwala na wysłanie jednej wiadomości do użytkownika pod warunkiem, że wpisał on poprawny adres e-mail w swoich preferencjach.
+Adres e-mailowy, który został przez Ciebie wprowadzony w [[Special:Preferences|Twoich preferencjach]], pojawi się w polu „Od”, dzięki czemu odbiorca będzie mógł Ci odpowiedzieć.',
 'usermailererror' => 'Moduł obsługi poczty zwrócił błąd:',
 'defemailsubject' => 'Wiadomość z {{GRAMMAR:D.lp|{{SITENAME}}}}',
 'noemailtitle'    => 'Brak adresu e-mail',
@@ -1656,12 +1662,12 @@
 'nowatchlist'          => 'Lista obserwowanych przez Ciebie stron jest pusta.',
 'watchlistanontext'    => '$1, aby obejrzeć lub edytować elementy listy obserwowanych.',
 'watchnologin'         => 'Nie jesteś zalogowany',
-'watchnologintext'     => 'Musisz się [[Special:Userlogin|zalogować]] przed modyfikacją listy obserwowanych artykułów.',
+'watchnologintext'     => 'Musisz się [[Special:UserLogin|zalogować]] przed modyfikacją listy obserwowanych artykułów.',
 'addedwatch'           => 'Dodana do listy obserwowanych',
 'addedwatchtext'       => "Strona „[[:$1|$1]]” została dodana do Twojej [[Special:Watchlist|listy obserwowanych]].
-Każda zmiana treści tej strony lub związanej z nią strony dyskusji zostanie odnotowana na poniższej liście. Dodatkowo nazwa strony zostanie '''wytłuszczona''' na [[Special:Recentchanges|liście ostatnich zmian]], aby ułatwić Ci zauważenie faktu zmiany.",
+Każda zmiana treści tej strony lub związanej z nią strony dyskusji zostanie odnotowana na poniższej liście. Dodatkowo nazwa strony zostanie '''wytłuszczona''' na [[Special:RecentChanges|liście ostatnich zmian]], aby ułatwić Ci zauważenie faktu zmiany.",
 'removedwatch'         => 'Usunięto z listy obserwowanych',
-'removedwatchtext'     => 'Strona „[[:$1]]” została usunięta z Twojej listy obserwowanych.',
+'removedwatchtext'     => 'Strona „[[:$1]]” została usunięta z Twojej [[Special:Watchlist|listy obserwowanych]].',
 'watch'                => 'Obserwuj',
 'watchthispage'        => 'Obserwuj',
 'unwatch'              => 'nie obserwuj',
@@ -1761,10 +1767,10 @@
 'rollbacklink'                => 'cofnij',
 'rollbackfailed'              => 'Nie udało się cofnąć zmiany',
 'cantrollback'                => 'Nie można cofnąć edycji, ponieważ jest tylko jedna wersja tej strony.',
-'alreadyrolled'               => 'Nie można dla strony [[:$1|$1]] cofnąć ostatniej zmiany, którą wykonał [[User:$2|$2]] ([[User talk:$2|dyskusja]]).
+'alreadyrolled'               => 'Nie można dla strony [[:$1|$1]] cofnąć ostatniej zmiany, którą wykonał [[User:$2|$2]] ([[User talk:$2|dyskusja]] | [[Special:Contributions/$2|{{int:contribslink}}]]).
 Ktoś inny zdążył już to zrobić lub wprowadził własne poprawki do treści strony.
 
-Autorem ostatniej zmiany jest teraz [[User:$3|$3]] ([[User talk:$3|dyskusja]]).',
+Autorem ostatniej zmiany jest teraz [[User:$3|$3]] ([[User talk:$3|dyskusja]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Edycję opisano: „<i>$1</i>”.', # only shown if there is an edit comment
 'revertpage'                  => 'Wycofano edycje użytkownika [[Special:Contributions/$2|$2]] ([[User talk:$2|dyskusja]]). Autor przywróconej wersji to [[User:$1|$1]].', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Wycofano edycje użytkownika $1.
@@ -1774,7 +1780,7 @@
 Naciśnij „wstecz” w przeglądarce, przeładuj stronę, po czym ponownie wydaj polecenie.',
 'protectlogpage'              => 'Zabezpieczone',
 'protectlogtext'              => 'Poniżej znajduje się lista blokad założonych i zdjętych z pojedynczych stron.
-Aby przejrzeć listę obecnie działających zabezpieczeń, przejdź na stronę wykazu [[Special:Protectedpages|zabezpieczonych stron]].',
+Aby przejrzeć listę obecnie działających zabezpieczeń, przejdź na stronę wykazu [[Special:ProtectedPages|zabezpieczonych stron]].',
 'protectedarticle'            => 'zabezpieczył [[$1]]',
 'modifiedarticleprotection'   => 'zmienił poziom zabezpieczenia [[$1]]',
 'unprotectedarticle'          => 'odbezpieczył [[$1]]',
@@ -1944,7 +1950,7 @@
 'badipaddress'                    => 'Niepoprawny adres IP',
 'blockipsuccesssub'               => 'Zablokowanie powiodło się',
 'blockipsuccesstext'              => 'Użytkownik [[Special:Contributions/$1|$1]] został zablokowany.<br />
-Przejdź do [[Special:Ipblocklist|listy zablokowanych adresów IP]], by przejrzeć blokady.',
+Przejdź do [[Special:IPBlockList|listy zablokowanych adresów IP]], by przejrzeć blokady.',
 'ipb-edit-dropdown'               => 'Edytuj przyczynę blokady',
 'ipb-unblock-addr'                => 'Odblokuj $1',
 'ipb-unblock'                     => 'Odblokuj użytkownika lub adres IP',
@@ -1977,7 +1983,7 @@
 'blocklogentry'                   => 'zablokował [[$1]], czas blokady: $2 $3',
 'blocklogtext'                    => 'Poniżej znajduje się lista blokad założonych i zdjętych z poszczególnych adresów IP.
 Na liście nie znajdą się adresy IP, które zablokowano w sposób automatyczny.
-By przejrzeć listę obecnie aktywnych blokad, przejdź na stronę [[Special:Ipblocklist|zablokowanych adresów i użytkowników]].',
+By przejrzeć listę obecnie aktywnych blokad, przejdź na stronę [[Special:IPBlockList|zablokowanych adresów i użytkowników]].',
 'unblocklogentry'                 => 'odblokował $1',
 'block-log-flags-anononly'        => 'tylko anonimowi',
 'block-log-flags-nocreate'        => 'blokada tworzenia konta',
@@ -2016,7 +2022,7 @@
 'lockdbsuccesssub'    => 'Baza danych została pomyślnie zablokowana',
 'unlockdbsuccesssub'  => 'Blokada bazy danych została zdjęta',
 'lockdbsuccesstext'   => 'Baza danych została zablokowana.<br />
-Pamiętaj by [[Special:Unlockdb|zdjąć blokadę]] po zakończeniu działań administracyjnych.',
+Pamiętaj by [[Special:UnlockDB|zdjąć blokadę]] po zakończeniu działań administracyjnych.',
 'unlockdbsuccesstext' => 'Baza danych została odblokowana.',
 'lockfilenotwritable' => 'Nie można zapisać pliku blokady bazy danych.
 Blokowanie i odblokowywanie bazy danych, wymaga by plik mógł być zapisywany przez web serwer.',
@@ -2027,14 +2033,12 @@
 'move-page-legend'        => 'Przeniesienie strony',
 'movepagetext'            => "Za pomocą poniższego formularza zmienisz nazwę strony, przenosząc jednocześnie jej historię.
 Pod starym tytułem zostanie umieszczona strona przekierowująca.
-Linki do starego tytułu pozostaną niezmienione.
-Upewnij się, że uwzględniasz podwójne lub zerwane przekierowania.
-Odpowiadasz za to, żeby linki odnosiły się do właściwych artykułów!
+Możesz automatycznie zaktualizować przekierowania wskazujące na tytuł przed zmianą.
+Jeśli nie wybierzesz tej opcji, upewnij się po przeniesieniu strony, czy nie powstały [[Special:DoubleRedirects|podwójne]] lub [[Special:BrokenRedirects|zerwane przekierowania]].
+Jesteś odpowiedzialny za to, by linki w dalszym ciągu pokazywały tam, gdzie powinny.
 
-Strona '''nie''' zostanie przeniesiona, jeśli:
-*jest pusta i nigdy nie była edytowana
-*jest stroną przekierowującą
-*strona o nowej nazwie już istnieje, chyba że jest pusta lub jest przekierowaniem i ma pustą historię edycji. To oznacza, że błędną operację zmiany nazwy można bezpiecznie odwrócić, zmieniając nową nazwę strony na poprzednią.
+Strona '''nie''' zostanie przeniesiona, jeśli strona o nowej nazwie już istnieje, chyba że jest pusta lub jest przekierowaniem i ma pustą historię edycji.
+To oznacza, że błędną operację zmiany nazwy można bezpiecznie odwrócić, zmieniając nową nazwę strony na poprzednią, i że nie można nadpisać istniejącej strony.
 
 '''UWAGA!'''
 Może to być drastyczna lub nieprzewidywalna zmiana w przypadku popularnych stron.
@@ -2045,8 +2049,6 @@
 
 W takich przypadkach treść dyskusji można przenieść tylko ręcznie.',
 'movearticle'             => 'Przeniesienie strony',
-'movenologin'             => 'Nie jesteś zalogowany',
-'movenologintext'         => 'Przenoszenie stron jest możliwe dopiero po zarejestrowaniu się i [[Special:Userlogin|zalogowaniu]].',
 'movenotallowed'          => 'Nie masz uprawnień do przenoszenia stron w {{GRAMMAR:MS.lp|{{SITENAME}}}}.',
 'newtitle'                => 'Nowy tytuł',
 'move-watch'              => 'Obserwuj',
@@ -2073,7 +2075,7 @@
 'revertmove'              => 'cofnij',
 'delete_and_move'         => 'Usuń i przenieś',
 'delete_and_move_text'    => '== Przeniesienie wymaga usunięcia innej strony ==
-Strona docelowa „[[$1]]” istnieje.
+Strona docelowa „[[:$1]]” istnieje.
 Czy chcesz ją usunąć, by zrobić miejsce dla przenoszonej strony?',
 'delete_and_move_confirm' => 'Tak, usuń stronę',
 'delete_and_move_reason'  => 'Usunięto, by zrobić miejsce dla przenoszonej strony',
@@ -2084,6 +2086,7 @@
 'imagenocrossnamespace'   => 'Nie można przenieść grafiki do przestrzeni nazw nie przeznaczonej dla grafik',
 'imagetypemismatch'       => 'Nowe rozszerzenie nazwy pliku jest innego typu niż zawartość',
 'imageinvalidfilename'    => 'Nazwa pliku docelowego jest nieprawidłowa',
+'fix-double-redirects'    => 'Popraw przekierowania wskazujące na oryginalny tytuł strony',
 
 # Export
 'export'            => 'Eksport stron',
@@ -2131,7 +2134,7 @@
 'import-interwiki-history'   => 'Kopiuj całą historię edycji tej strony',
 'import-interwiki-submit'    => 'Importuj',
 'import-interwiki-namespace' => 'Przenieś strony do przestrzeni nazw',
-'importtext'                 => 'Używając narzędzia Special:Export, wyeksportuj plik ze źródłowej wiki, zapisz go na swoim dysku, a następnie prześlij go tutaj.',
+'importtext'                 => 'Używając narzędzia [[Special:Export|eksportu]], wyeksportuj plik ze źródłowej wiki, zapisz go na swoim dysku, a następnie prześlij go tutaj.',
 'importstart'                => 'Trwa importowanie stron...',
 'import-revision-count'      => '$1 {{PLURAL:$1|wersja|wersje|wersji}}',
 'importnopages'              => 'Brak stron do importu.',
@@ -2282,9 +2285,10 @@
 'markedaspatrollederror-noautopatrol' => 'Nie masz uprawnień wymaganych do oznaczania swoich edycji jako „sprawdzone”.',
 
 # Patrol log
-'patrol-log-page' => 'Dziennik patrolowania',
-'patrol-log-line' => 'oznaczył wersję $1 hasła $2 jako sprawdzoną $3',
-'patrol-log-auto' => '(automatycznie)',
+'patrol-log-page'   => 'Dziennik patrolowania',
+'patrol-log-header' => 'Poniżej znajduje się dziennik patrolowania stron.',
+'patrol-log-line'   => 'oznaczył wersję $1 hasła $2 jako sprawdzoną $3',
+'patrol-log-auto'   => '(automatycznie)',
 
 # Image deletion
 'deletedrevision'                 => 'Usunięto poprzednie wersje $1',
@@ -2313,7 +2317,7 @@
 'show-big-image'       => 'Oryginalna rozdzielczość',
 'show-big-image-thumb' => '<small>Rozmiar podglądu: $1 × $2 pikseli</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Najnowsze pliki',
 'imagelisttext'         => "Poniżej na {{PLURAL:$1||posortowanej $2}} liście {{PLURAL:$1|znajduje|znajdują|znajduje}} się '''$1''' {{PLURAL:$1|plik|pliki|plików}}.",
 'newimages-summary'     => 'Na tej stronie specjalnej prezentowane są ostatnio przesłane pliki.',
@@ -2601,7 +2605,7 @@
 
 # External editor support
 'edit-externally'      => 'Edytuj plik, używając zewnętrznej aplikacji',
-'edit-externally-help' => "Więcej informacji o używaniu [http://meta.wikimedia.org/wiki/Help:External_editors zewnętrznych edytorów] (''ang.'').",
+'edit-externally-help' => "Więcej informacji o używaniu [http://www.mediawiki.org/wiki/Manual:External_editors zewnętrznych edytorów] (''ang.'').",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'wszystkie',
@@ -2671,7 +2675,7 @@
 'recreate'            => 'Utwórz ponownie',
 
 # HTML dump
-'redirectingto' => 'Przekierowanie do [[$1]]...',
+'redirectingto' => 'Przekierowanie do [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Wyczyścić pamięć podręczną dla tej strony?
@@ -2719,8 +2723,8 @@
 'livepreview-error'   => 'Nieudane połączenie: $1 „$2” Spróbuj podglądu standardowego.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Na tej liście zmiany nowsze niż $1 sekund mogą nie być widoczne.',
-'lag-warn-high'   => 'Z powodu dużego obciążenia serwerów bazy danych, na tej liście zmiany nowsze niż $1 sekund mogą nie być widoczne.',
+'lag-warn-normal' => 'Zmiany nowsze niż $1 {{PLURAL:$1|sekunda|sekundy|sekund}} mogą nie być widoczne na tej liście.',
+'lag-warn-high'   => 'Z powodu dużego obciążenia serwerów bazy danych, zmiany nowsze niż $1 {{PLURAL:$1|sekunda|sekundy|sekund}} mogą nie być widoczne na tej liście.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Twoja lista obserwowanych zawiera {{PLURAL:$1|1 tytuł|$1 tytuły|$1 tytułów}}, nieuwzględniając stron dyskusji.',
@@ -2753,9 +2757,12 @@
 'iranian-calendar-m3'  => 'Chordād',
 'iranian-calendar-m5'  => 'Mordād',
 'iranian-calendar-m6'  => 'Szahriwar',
+'iranian-calendar-m7'  => 'Mehr',
 'iranian-calendar-m8'  => 'Ābān',
 'iranian-calendar-m9'  => 'Āsar',
 'iranian-calendar-m10' => 'Déi',
+'iranian-calendar-m11' => 'Bahman',
+'iranian-calendar-m12' => 'Esfand',
 
 # Hebrew month names
 'hebrew-calendar-m1'      => 'Tiszri',
@@ -2799,7 +2806,7 @@
 'version-software-product'         => 'Nazwa',
 'version-software-version'         => 'Wersja',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Ścieżka do pliku',
 'filepath-page'    => 'Plik',
 'filepath-submit'  => 'Ścieżka',
@@ -2838,7 +2845,7 @@
 'specialpages-group-redirects'   => 'Specjalne strony przekierowujące',
 'specialpages-group-spam'        => 'Narzędzia walki ze spamem',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pusta strona',
 'intentionallyblankpage' => 'Ta strona umyślnie pozostała pusta',
 
Index: languages/messages/MessagesNds_nl.php
===================================================================
--- languages/messages/MessagesNds_nl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNds_nl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,17 +1,15 @@
 <?php
-/** Nedersaksisch (Nedersaksisch)
+/**  ()
  *
  * @ingroup Language
  * @file
  *
+ * @author Erwin85
+ * @author Jens Frank
  * @author Servien
- * @author Siebrand
- * @author לערי ריינהארט
  * @author Slomox
- * @author SPQRobin
- * @author Erwin85
  * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- * @author Jens Frank
+ * @author לערי ריינהארט
  */
 
 $fallback = 'nl';
@@ -533,7 +531,7 @@
 'nosuchspecialpage' => 'Der besteet gien speciale pagina mit disse naam',
 'nospecialpagetext' => "<big>'''Disse speciale pagina wonnen neet herkend deur de pregrammetuur.'''</big>
 
-Een lieste mit bestaonde speciale pagina ku-j vienen op [[Special:Specialpages|{{int:specialpages}}]].",
+Een lieste mit bestaonde speciale pagina ku-j vienen op [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Foutmelding',
@@ -562,7 +560,7 @@
 Dit kan koemen deurda-j een ouwe verwiezing naor \'t verschil tussen twee versies van een pagina volgen of een versie opvragen dee vort-edaon is.
 
 As dat neet zo is, dan he-j meschien een fout in de pregremmetuur evunnen.
-Meld \'t dan effen bie een systeembeheerder van {{SITENAME}} en vermeld derbie de internetverwiezing van disse pagina.',
+Meld \'t dan effen bie een [[Special:ListUsers/sysop|systeembeheerder]] van {{SITENAME}} en vermeld derbie de internetverwiezing van disse pagina.',
 'missingarticle-rev'   => '(versienummer: $1)',
 'missingarticle-diff'  => '(Wieziging: $1, $2)',
 'readonly_lag'         => 'De databanke is autematisch beveilig, zodat de onder-eschikken servers zich kunnen synchroniseren mit de centrale server.',
@@ -606,7 +604,10 @@
 
 # Login and logout pages
 'logouttitle'                => 'Ofmelden gebruker',
-'logouttext'                 => 'Je bin noen of-emeld. Je kunnen {{SITENAME}} noen anneniem gebruken of onder een aandere gebrukersnaam weer anmelden.',
+'logouttext'                 => "<strong>Je bin noen of-emeld.</strong>
+
+Je kunnen {{SITENAME}} noen anneniem gebruken of onder disse of een aandere gebrukersnaam je eigen weer anmelden.
+'t Kan ween dat der een antal pagina's weer-egeven wonnen asof je an-emeld bin totda-j de kas van joew webblaojeraar leegmaken.",
 'welcomecreation'            => '<h2>Welkom, $1!</h2><p>Joew gebrukersprefiel is an-emaak. Je kunnen noen joew persoonlijke veurkeuren instellen.</p>',
 'loginpagetitle'             => 'Gebrukersnaam',
 'yourname'                   => 'Gebrukersnaam',
@@ -618,7 +619,7 @@
 'loginproblem'               => "<b>Der was een prebleem mit 't anmelden.</b><br />Prebleem 't opniej!",
 'login'                      => 'Anmelden',
 'nav-login-createaccount'    => 'Anmelden',
-'loginprompt'                => 'Je mutten [[cookie]]s an hemmen staon um an te kunnen melden bie {{SITENAME}}.',
+'loginprompt'                => 'Je mutten cookies an hemmen staon um an te kunnen melden bie {{SITENAME}}.',
 'userlogin'                  => 'Anmelden',
 'logout'                     => 'Ofmelden',
 'userlogout'                 => 'Ofmelden',
@@ -763,12 +764,8 @@
 'blockednoreason'                  => 'gien rejen op-egeven',
 'blockedoriginalsource'            => "De brontekse van '''$1''' wonnen hieronder weer-egeven:",
 'blockededitsource'                => "De tekse van '''joew eigen bewarkingen''' an '''$1''' wonnen hieronder weer-egeven:",
-'whitelistedittitle'               => 'Anmelden is verplich',
+'whitelistedittitle'               => 'Um disse pagina te bewarken, mu-j je anmelden',
 'whitelistedittext'                => "Um pagina's te kunnen wiezigen, mu-j $1 ween",
-'whitelistreadtitle'               => 'Anmelden is verplich',
-'whitelistreadtext'                => 'Um dit artikel te kunnen lezen, mu-j [[Special:Userlogin|an-emeld]] ween.',
-'whitelistacctitle'                => 'Nieje gebrukersnaam anmaken neet toe-estaon',
-'whitelistacctext'                 => 'Nieje gebrukersprefielen op {{SITENAME}} kunnen allinnig an-emaak wonnen deur [[Special:Userlogin|an-emelde]] gebrukers mit de juuste rechten.',
 'confirmedittitle'                 => 'Berichbevestiging is neudig um te bewarken.',
 'confirmedittext'                  => "Je mutten je e-mailadres bevestigen veurda-j bewarken kunnen. Vul je adres in en bevestig 't via [[Special:Preferences|mien veurkeuren]].",
 'nosuchsectiontitle'               => 'Disse sectie besteet neet',
@@ -779,9 +776,8 @@
 'accmailtitle'                     => 'Wachwoord is verzunnen.',
 'accmailtext'                      => "Wachwoord veur '$1' is verzunnen naor $2.",
 'newarticle'                       => '(Niej)',
-'newarticletext'                   => '<div class=plainlinks style="border: 1px solid #ccc; padding: .2em 1em; margin-bottom: .8em; color: #000;"><div align=right style="font-size:110%; float:right; border:none; width:40%;">[[Special:Prefixindex/{{PAGENAME}}|Prefixindex]] | [[Special:Search/{{PAGENAME}}|Zeuken]]</div><div style="font-size:110%;">Je bin de pagina "{{FULLPAGENAME}}" an \'t schrieven...</div></div>',
-'anontalkpagetext'                 => "<hr style=\"margin-top:2em;\">
-<em>Disse overlegpagina heurt bie een annenieme gebruker dee: óf gien gebrukersnaam hef, óf 't neet gebruuk. We gebruken daorumme 't IP-adres ter herkenning, mar 't kan oek ween dat meerdere personen 'tzelfde IP-adres gebruken, en da-j hiermee berichen ontvangen dee neet veur joe bedoeld bin. A-j dit veurkoemen willen, dan ku-j 't bes [[Special:Userlogin|een gebrukersnaam anmaken of anmelden]].</em>",
+'newarticletext'                   => "Disse pagina besteet nog neet. Hieronder ku-j wat schrieven en naokieken of opslaon. A-j hier per ongelok terechtekeumen bin gebruuk dan de knoppe ''veurige'' um weerumme te gaon.",
+'anontalkpagetext'                 => "---- ''Disse overlegpagina heurt bie een annenieme gebruker dee: óf gien gebrukersnaam hef, óf 't neet gebruuk. We gebruken daorumme 't IP-adres ter herkenning, mar 't kan oek ween dat meerdere personen 'tzelfde IP-adres gebruken, en da-j hiermee berichen ontvangen dee neet veur joe bedoeld bin. A-j dit veurkoemen willen, dan ku-j 't bes [[Special:UserLogin|een gebrukersnaam anmaken of anmelden]].''",
 'noarticletext'                    => 'Disse pagina besteet nog neet.
 Je kunnen \'t woord [[Special:Search/{{PAGENAME}}|opzeuken]] in aandere pagina\'s of <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} disse pagina bewarken]</span>.',
 'userpage-userdoesnotexist'        => 'Je bewarken een gebrukerspagina van een gebruker dee neet besteet (gebruker "$1"). Kiek effen nao o-j disse pagina wel anmaken/bewarken willen.',
@@ -836,7 +832,7 @@
 'template-semiprotected'           => '(semibeveilig)',
 'hiddencategories'                 => 'Disse pagina vuilt in de volgende verbörgen {{PLURAL:$1|kattegerie|kattegerieën}}:',
 'nocreatetitle'                    => "'t Anmaken van pagina's is beteund",
-'nocreatetext'                     => "Disse webstee hef de meugelijkheid um nieje pagina's an te maken beteund. Je kunnen pagina's dee al bestaon wiezigen of je kunnen je [[Special:Userlogin|anmelden of een gebrukerspagina anmaken]].",
+'nocreatetext'                     => "Disse webstee hef de meugelijkheid um nieje pagina's an te maken beteund. Je kunnen pagina's dee al bestaon wiezigen of je kunnen je [[Special:UserLogin|anmelden of een gebrukerspagina anmaken]].",
 'nocreate-loggedin'                => "Je maggen gien nieje pagina's anmaken op disse wiki.",
 'permissionserrors'                => 'Fouten mit de rechen',
 'permissionserrorstext'            => 'Je maggen of kunnen dit neet doon. De {{PLURAL:$1|rejen|rejens}} daoveur {{PLURAL:$1|is|bin}}:',
@@ -951,7 +947,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Verbargingslogboek',
-'suppressionlogtext' => 'De onderstaande lieste bevat de pagina dee vort-edaon bin en blokkeringen dee veur beheerders verbörgen bin. In de [[Special:Ipblocklist|IP-blokkeerlieste]] bin de blokkeringen dee noen van toepassing bin te bekieken.',
+'suppressionlogtext' => 'De onderstaande lieste bevat de pagina dee vort-edaon bin en blokkeringen dee veur beheerders verbörgen bin. In de [[Special:IPBlockList|IP-blokkeerlieste]] bin de blokkeringen dee noen van toepassing bin te bekieken.',
 
 # History merging
 'mergehistory'                     => "Geschiedenisse van pagina's bie mekaar doon",
@@ -1033,7 +1029,7 @@
 'mypreferences'            => 'Mien veurkeuren',
 'prefs-edits'              => 'Antal bewarkingen:',
 'prefsnologin'             => 'Neet an-meld',
-'prefsnologintext'         => 'Je mutten [[Special:Userlogin|an-emeld]] ween um je veurkeuren in te kunnen stellen.',
+'prefsnologintext'         => 'Je mutten [[Special:UserLogin|an-emeld]] ween um je veurkeuren in te kunnen stellen.',
 'prefsreset'               => 'Standardveurkeuren hersteld.',
 'qbsettings'               => 'Paginalieste',
 'qbsettings-none'          => 'Gien',
@@ -1107,7 +1103,7 @@
 'userrights-reason'           => 'Rejen:',
 'userrights-no-interwiki'     => "Je hemmen gien rechen um gebrukersrechen op aandere wiki's te wiezigen.",
 'userrights-nodatabase'       => 'Databanke $1 besteet neet of is gien plaoselijke databanke.',
-'userrights-nologin'          => 'Je mutten [[Special:Userlogin|an-emeld]] ween en as gebruker de juuste rechen hemmen um gebrukersrechen toe te kunnen wiezen.',
+'userrights-nologin'          => 'Je mutten [[Special:UserLogin|an-emeld]] ween en as gebruker de juuste rechen hemmen um gebrukersrechen toe te kunnen wiezen.',
 'userrights-notallowed'       => 'Je hemmen gien rechen um gebrukersrechen toe te kunnen wiezen.',
 'userrights-changeable-col'   => 'Groepen dee-j beheren kunnen',
 'userrights-unchangeable-col' => 'Groepen dee-j neet beheren kunnen',
@@ -1235,12 +1231,12 @@
 'reupload'                    => 'Opniej toevoegen',
 'reuploaddesc'                => 'Weerumme naor bestandtoevoegingsformelier.',
 'uploadnologin'               => 'Neet an-emeld',
-'uploadnologintext'           => 'Je mutten [[Special:Userlogin|an-emeld]] ween um bestanden toe te kunnen voegen.',
+'uploadnologintext'           => 'Je mutten [[Special:UserLogin|an-emeld]] ween um bestanden toe te kunnen voegen.',
 'upload_directory_read_only'  => "Op 't mement ku-j gien bestanden toevoegen wegens technische rejens ($1).",
 'uploaderror'                 => "Fout bie 't toevoegen van 't bestand",
 'uploadtext'                  => "Gebruuk 't onderstaonde formelier um bestanden toe te voegen.
-Um eerder toe-evoegen bestanden te bekieken of te zeuken ku-j naor de [[Special:Imagelist|bestanslieste]] gaon.
-Toe-evoegen bestanden en media dee vort-edaon bin wonnen bie-ehuilen in 't [[Special:Log/upload|logboek mit toe-evoegen bestanden]].
+Um eerder toe-evoegen bestanden te bekieken of te zeuken ku-j naor de [[Special:ImageList|bestanslieste]] gaon.
+Toe-evoegen bestanden en media dee vort-edaon bin wonnen bie-ehuilen in 't [[Special:Log/upload|logboek mit toe-evoegen bestanden]] en 't [[Special:Log/delete|logboek mit vort-edaon bestanden]].
 
 Um 't bestand in te voegen in een pagina ku-j een van de volgende codes gebruken:
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bestand.jpg]]</nowiki>'''
@@ -1251,7 +1247,8 @@
 'upload-prohibited'           => 'Verbeujen bestanstypes: $1.',
 'uploadlog'                   => 'Toe-evoegen bestanden',
 'uploadlogpage'               => 'Toe-evoegen bestanden',
-'uploadlogpagetext'           => 'Hieronder steet een lieste mit bestanden dee net niej bin.',
+'uploadlogpagetext'           => 'Hieronder steet een lieste mit bestanden dee net niej bin.
+Zie de [[Special:NewImages|gallerieje mit media]] veur een overzichte.',
 'filename'                    => 'Bestansnaam',
 'filedesc'                    => 'Beschrieving',
 'fileuploadsummary'           => 'Beschrieving:',
@@ -1312,7 +1309,7 @@
 'upload-proto-error'      => 'Verkeerde protocol',
 'upload-proto-error-text' => 'Um op disse meniere bestanden toe te voegen mutten webadressen beginnen mit <code>http://</code> of <code>ftp://</code>.',
 'upload-file-error'       => 'Interne fout',
-'upload-file-error-text'  => 'Een interne fout vun plaose to een tiejelijk bestand op de server an-emaak wönnen. Neem kontak op mit een systeembeheerder.',
+'upload-file-error-text'  => 'Bie ons gung der effen wat fout to een tiejelijk bestand op de server an-emaak wönnen. Neem kontak op mit een [[Special:ListUsers/sysop|systeembeheerder]].',
 'upload-misc-error'       => "Onbekende fout bie 't toevoegen van joew bestand",
 'upload-misc-error-text'  => "Der is bie toevoegen van 't bestand een onbekende fout op-etrejen. Kiek effen nao of de verwiezing 't wel dut en prebeer 't opniej. As 't prebleem anhuilt, neem dan kontak op mit één van de systeembeheerders.",
 
@@ -1328,7 +1325,7 @@
 'upload_source_url'  => ' (een geldig, pebliek toegankelijk webadres)',
 'upload_source_file' => ' (een bestand op joew computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Op disse speciale pagina ku-j alle toe-evoegen bestanden bekieken.
 Standard wonnen de les toe-evoegen bestanden bovenan de lieste ezet.
 Klikken op een kelomkop veraandert de sortering.',
@@ -1356,7 +1353,7 @@
 'imagelinks'                     => 'Gebruuk van dit bestand',
 'linkstoimage'                   => "Disse ofbeelding wonnen gebruuk op de volgende {{PLURAL:$1|pagina|$1 pagina's}}:",
 'nolinkstoimage'                 => 'Ofbeelding is neet in gebruuk.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Meer verwiezingen]] naor dit bestand bekieken.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Meer verwiezingen]] naor dit bestand bekieken.',
 'redirectstofile'                => "{{PLURAL:$1|'t Volgende bestand verwies|De volgende $1 bestanden verwiezen}} deur naor dit bestand:",
 'duplicatesoffile'               => "{{PLURAL:$1|'t Volgende bestand is|De volgende $1 bestanden bin}} liekeleens as dit bestand:",
 'sharedupload'                   => 'Dit bestand is een gedeelde upload en kan ook deur andere prejekken ebruukt worden.',
@@ -1375,7 +1372,7 @@
 # File reversion
 'filerevert'                => '$1 weerummedreien',
 'filerevert-legend'         => 'Bestand weerummezetten',
-'filerevert-intro'          => '<span class="plainlinks">Je bin \'\'\'[[Media:$1|$1]]\'\'\' an \'t weerummedreien tot de [$4 versie van $2, $3]</span>.',
+'filerevert-intro'          => "Je bin '''[[Media:$1|$1]]''' an 't weerummedreien tot de [$4 versie van $2, $3]",
 'filerevert-comment'        => 'Opmarkingen:',
 'filerevert-defaultcomment' => 'Weerummedreid tot de versie van $1, $2',
 'filerevert-submit'         => 'Weerummedreien',
@@ -1386,7 +1383,7 @@
 'filedelete'                  => '$1 vortdoon',
 'filedelete-legend'           => 'Bestand vortdoon',
 'filedelete-intro'            => "Je doon '''[[Media:$1|$1]]''' noen vort.",
-'filedelete-intro-old'        => '<span class="plainlinks">Je bin de versie van \'\'\'[[Media:$1|$1]]\'\'\' van [$4 $3, $2] vort an \'t doon.</span>',
+'filedelete-intro-old'        => "Je bin de versie van '''[[Media:$1|$1]]''' van [$4 $3, $2] vort an 't doon.",
 'filedelete-comment'          => 'Opmarking:',
 'filedelete-submit'           => 'Vortdoon',
 'filedelete-success'          => "'''$1''' is vort-edaon.",
@@ -1455,7 +1452,7 @@
 'brokenredirects-delete' => '(vortdoon)',
 
 'withoutinterwiki'         => "Pagina's zonder verwiezingen naor aandere talen",
-'withoutinterwiki-summary' => "De volgende pagina's verwiezen neet naor versies in een aandere taal:",
+'withoutinterwiki-summary' => "De volgende pagina's verwiezen neet naor versies in een aandere taal.",
 'withoutinterwiki-legend'  => 'Veurvoegsel',
 'withoutinterwiki-submit'  => 'Bekieken',
 
@@ -1532,7 +1529,7 @@
 'logempty'             => "Der steet gien infermasie in 't logboek dee voldut an disse criteria.",
 'log-title-wildcard'   => 'Zeuk naor titels dee beginnen mit disse tekse:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => "Alle pagina's",
 'alphaindexline'    => '$1 tot $2',
 'nextpage'          => 'Volgende pagina ($1)',
@@ -1555,12 +1552,12 @@
 'special-categories-sort-count' => 'op antal sorteren',
 'special-categories-sort-abc'   => 'alfebetisch sorteren',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Teun vanof:',
 'listusers-submit'   => 'Teun',
 'listusers-noresult' => 'Gien gebrukers evunnen. Zeuk oek naor varianten mit kleine letters of heufletters.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rechen van gebrukersgroepen',
 'listgrouprights-group'    => 'Groep',
 'listgrouprights-rights'   => 'Rechen',
@@ -1569,7 +1566,7 @@
 
 # E-mail user
 'mailnologin'     => 'Neet an-emeld.',
-'mailnologintext' => 'Je mutten [[Special:Userlogin|an-emeld]] ween en een geldig e-mailadres in "[[Special:Preferences|mien veurkeuren]]" invoeren um disse functie te kunnen gebruken.',
+'mailnologintext' => 'Je mutten [[Special:UserLogin|an-emeld]] ween en een geldig e-mailadres in "[[Special:Preferences|mien veurkeuren]]" invoeren um disse functie te kunnen gebruken.',
 'emailuser'       => 'Een berich sturen',
 'emailpage'       => 'Gebruker een berich sturen',
 'emailpagetext'   => "As disse gebruker een geldig e-mailadres op-egeven hef, dan ku-j via dit formelier een berich versturen. 't Adres da-j op-egeven hemmen bie joew veurkeuren zal as ofzender gebruuk wonnen.",
@@ -1593,10 +1590,10 @@
 'watchlistfor'         => "(veur '''$1''')",
 'nowatchlist'          => 'Gien artikels in volglieste.',
 'watchnologin'         => 'Neet an-emeld',
-'watchnologintext'     => 'Um je volglieste an te passen mu-j eers [[Special:Userlogin|an-emeld]] ween.',
+'watchnologintext'     => 'Um je volglieste an te passen mu-j eers [[Special:UserLogin|an-emeld]] ween.',
 'addedwatch'           => 'Disse pagina steet noen op joew volglieste',
 'addedwatchtext'       => "De pagina \"[[:\$1]]\" steet noen op joew [[Special:Watchlist|volglieste]].
-Toekomstige wiezigingen op disse pagina en de overlegpagina zullen hier vermeld wonnen, oek zullen disse pagina's '''vet-edrok''' ween in de lieste mit de [[Special:Recentchanges|leste wiezigingen]] zoda-j 't makkelijker zien kunnen.",
+Toekomstige wiezigingen op disse pagina en de overlegpagina zullen hier vermeld wonnen, oek zullen disse pagina's '''vet-edrok''' ween in de lieste mit de [[Special:RecentChanges|leste wiezigingen]] zoda-j 't makkelijker zien kunnen.",
 'removedwatch'         => 'Van volglieste ofhaolen',
 'removedwatchtext'     => 'De pagina "$1" is van joew volglieste op-ehaold.',
 'watch'                => 'Volg',
@@ -1675,9 +1672,9 @@
 'sessionfailure'              => 'Der is een prebleem mit joew anmeldsessie. De actie is stop-ezet uut veurzörg tegen een beveiligingsrisico (dat besteet uut \'t meugelijke "kraken" van disse sessie). Gao een pagina weerumme, laot disse pagina opniej en prebeer \'t nog es.',
 'protectlogpage'              => 'Beveiligingslogboek',
 'protectlogtext'              => "Hieronder steet een lieste mit pagina's dee beveilig bin.",
-'protectedarticle'            => '[[$1]] is beveilig',
-'modifiedarticleprotection'   => 'beveiligingsnivo van "[[$1]]"  ewiezig',
-'unprotectedarticle'          => '[[$1]] vrie-egeven',
+'protectedarticle'            => '[[:$1]] is beveilig',
+'modifiedarticleprotection'   => 'beveiligingsnivo van "[[:$1]]"  ewiezig',
+'unprotectedarticle'          => '[[:$1]] vrie-egeven',
 'protectcomment'              => 'Rejen',
 'protectexpiry'               => 'Duur',
 'protect_expiry_invalid'      => 'Verlooptied is ongeldig.',
@@ -1811,7 +1808,7 @@
 'blockipsuccesssub'           => 'Succesvol eblokkeerd',
 'blockipsuccesstext'          => 'IP-adres "$1" is noen eblokkeerd.
 
-Op de [[Special:Ipblocklist|IP-blokkeerlieste]] steet een lieste mit alle blokkeringen.',
+Op de [[Special:IPBlockList|IP-blokkeerlieste]] steet een lieste mit alle blokkeringen.',
 'ipb-edit-dropdown'           => 'Blokkeerrejens bewarken',
 'ipb-unblock-addr'            => 'Deblokkeer $1',
 'ipb-unblock'                 => 'Deblokkeer een gebruker of IP-adres',
@@ -1841,7 +1838,7 @@
 'autoblocker'                 => 'Vanzelf eblokkeerd umdat \'t IP-adres overenekump mit \'t IP-adres van [[User:$1|$1]], dee eblokkeerd is mit as rejen: "$2"',
 'blocklogpage'                => 'Blokkeerlogboek',
 'blocklogentry'               => 'blokkeren "[[$1]]" veur $2 $3',
-'blocklogtext'                => "Hier zie-j een lieste van de leste blokkeringen en deblokkeringen. Autematische blokkeringen en deblokkeringen koemen neet in 't logboek te staon. Zie de [[Special:Ipblocklist|IP-blokkeerlieste]] veur de lieste van adressen dee noen eblokkeerd bin.",
+'blocklogtext'                => "Hier zie-j een lieste van de leste blokkeringen en deblokkeringen. Autematische blokkeringen en deblokkeringen koemen neet in 't logboek te staon. Zie de [[Special:IPBlockList|IP-blokkeerlieste]] veur de lieste van adressen dee noen eblokkeerd bin.",
 'unblocklogentry'             => 'Blokkering van [[$1]] op-eheven',
 'block-log-flags-anononly'    => 'allinnig anneniemen',
 'block-log-flags-nocreate'    => 'anmaken van gebrukersprefielen uut-eschakeld',
@@ -1882,8 +1879,6 @@
 * As der al een neet-lege overlegpagina besteet onder de aandere naam
 * A-j 't onderstaonde vinkjen vorthaolen",
 'movearticle'             => 'Herneum',
-'movenologin'             => 'Neet an-emeld.',
-'movenologintext'         => 'Je mutten [[Special:Userlogin|an-emeld]] ween um de naam van een pagina te wiezigen.',
 'newtitle'                => 'Nieje naam',
 'move-watch'              => 'volg disse pagina',
 'movepagebtn'             => 'Herneum',
@@ -1894,15 +1889,15 @@
 'talkexists'              => "De pagina zelf is verplaos, mar de overlegpagina kon neet verplaos wonnen, umdat de doelnaam al een neet-lege overlegpagina had. Combineer de overlegpagina's haandmaotig.",
 'movedto'                 => 'wiezigen naor',
 'movetalk'                => "De overlegpagina oek wiezigen, as 't meuglijk is.",
-'1movedto2'               => '[[$1]] is ewiezig naor [[$2]]',
-'1movedto2_redir'         => '[[$1]] is ewiezig over de deurverwiezing [[$2]] hinne',
+'1movedto2'               => '[[:$1]] is ewiezig naor [[:$2]]',
+'1movedto2_redir'         => '[[:$1]] is ewiezig over de deurverwiezing [[:$2]] hinne',
 'movelogpage'             => 'Titelwiezigingen',
 'movelogpagetext'         => "Hieronder steet een lieste mit pagina's dee herneumd bin.",
 'movereason'              => 'Rejen:',
 'revertmove'              => 'Weerummedreien',
 'delete_and_move'         => 'Vortdoon en herneumen',
 'delete_and_move_text'    => '==Mut vort-edaon wonnen==
-<div style="color: red"> Onder de nieje naam "[[$1]]" besteet al een artikel. Wi-j \'t vortdoon um plaose te maken veur \'t herneumen?</div>',
+<div style="color: red"> Onder de nieje naam "[[:$1]]" besteet al een artikel. Wi-j \'t vortdoon um plaose te maken veur \'t herneumen?</div>',
 'delete_and_move_confirm' => 'Ja, disse pagina vortdoon',
 'delete_and_move_reason'  => 'Vort-edaon vanwegen naamwieziging',
 'selfmove'                => "De naam kan neet ewiezig wonnen naor de naam dee 't al hef.",
@@ -1960,7 +1955,7 @@
 # Import log
 'importlogpage'             => 'Invoerlogboek',
 'importlogpagetext'         => "Administratieve invoer van pagina's mit geschiedenisse van aandere wiki's.",
-'import-logentry-upload'    => '[[$1]] in-evoerd via een bestanstoevoeging',
+'import-logentry-upload'    => '[[:$1]] in-evoerd via een bestanstoevoeging',
 'import-logentry-interwiki' => 'transwiki $1',
 
 # Tooltip help for the actions
@@ -2095,7 +2090,7 @@
 'show-big-image'       => 'Ofbeelding in hogere resolusie',
 'show-big-image-thumb' => '<small>Grootte van disse weergave: $1 × $2 beeldpunten</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Nieje ofbeeldingen',
 'noimages'              => 'Niks te zien.',
 'ilsubmit'              => 'Zeuk',
@@ -2308,7 +2303,7 @@
 
 # External editor support
 'edit-externally'      => 'Wiezig dit bestand mit een extern pregramma',
-'edit-externally-help' => 'Zie de [http://meta.wikimedia.org/wiki/Help:External_editors installasie-instructies] veur meer infermasie.',
+'edit-externally-help' => 'Zie de [http://www.mediawiki.org/wiki/Manual:External_editors installasie-instructies] veur meer infermasie.',
 
 # 'all' in various places, this might be different for inflected languages
 'imagelistall'  => 'alles',
@@ -2351,7 +2346,7 @@
 'recreate'            => 'Herschrieven',
 
 # HTML dump
-'redirectingto' => 'Bezig mit deursturen naor [[$1]]...',
+'redirectingto' => 'Bezig mit deursturen naor [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Klik op 'bevestig' um de kas van disse pagina te legen.
@@ -2383,7 +2378,7 @@
 # Auto-summaries
 'autosumm-blank'   => 'Pagina leeg-emaak',
 'autosumm-replace' => "Tekse vervungen deur '$1'",
-'autoredircomment' => 'deurverwiezing naor [[$1]]',
+'autoredircomment' => 'deurverwiezing naor [[:$1]]',
 'autosumm-new'     => 'Nieje pagina: $1',
 
 # Live preview
@@ -2433,7 +2428,7 @@
 'version-software'                 => 'Eïnstalleren pregrammetuur',
 'version-software-product'         => 'Preduk',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Bestanslokasie',
 'filepath-submit'  => 'Zeuken',
 'filepath-summary' => "Disse speciale pagina geef 't hele pad veur een bestand. Ofbeeldingen wonnen in resolusie helemaole weer-egeven. Aandere bestanstypen wonnen gelieke in 't mit 't MIME-type verbunnen pregramma los edaon.
Index: languages/messages/MessagesTk.php
===================================================================
--- languages/messages/MessagesTk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,19 @@
  * @ingroup Language
  * @file
  *
+ * @author Flrn
  * @author Runningfridgesrule
  */
 
 $messages = array(
 # Dates
+'sunday'        => 'Ýekşenbe',
+'monday'        => 'Duşenbe',
+'tuesday'       => 'Sişenbe',
+'wednesday'     => 'Çarşenbe',
+'thursday'      => 'Penşenbe',
+'friday'        => 'Anna',
+'saturday'      => 'Şenbe',
 'sun'           => 'Dynç.',
 'mon'           => 'Baş.',
 'tue'           => 'Ýaş.',
@@ -16,35 +24,35 @@
 'thu'           => 'Sogap.',
 'fri'           => 'Anna.',
 'sat'           => 'Ruh.',
-'january'       => 'Türkmenbaşy aý',
-'february'      => 'Baýdak aý',
-'march'         => 'Nowruz aý',
-'april'         => 'Gurbansoltan aý',
+'january'       => 'ýanwar',
+'february'      => 'fewral',
+'march'         => 'mart',
+'april'         => 'aprel',
 'may_long'      => 'Magtymguly aý',
-'june'          => 'Oguzhan aý',
-'july'          => 'Gorkut aý',
-'august'        => 'Alp Arslan aý',
-'september'     => 'Ruhnama aý',
-'october'       => 'Garaşsyzlyk aý',
-'november'      => 'Sanjar aý',
-'december'      => 'Bitaraplyk aý',
-'january-gen'   => 'Türkmenbaşy aý',
-'february-gen'  => 'Baýdak aý',
-'march-gen'     => 'Nowruz aý',
-'april-gen'     => 'Gurbansoltan aý',
-'may-gen'       => 'Magtymguly aý',
-'june-gen'      => 'Oguzhan aý',
-'july-gen'      => 'Gorkut aý',
-'august-gen'    => 'Alp Arslan aý',
-'september-gen' => 'Ruhnama aý',
-'october-gen'   => 'Garaşsyzlyk aý',
-'november-gen'  => 'Sanjar aý',
-'december-gen'  => 'Bitaraplyk aý',
+'june'          => 'iýun',
+'july'          => 'iýul',
+'august'        => 'awgust',
+'september'     => 'sentýabr',
+'october'       => 'oktýabr',
+'november'      => 'noýabr',
+'december'      => 'dekabr',
+'january-gen'   => 'ýanwar',
+'february-gen'  => 'fewral',
+'march-gen'     => 'mart',
+'april-gen'     => 'aprel',
+'may-gen'       => 'maý',
+'june-gen'      => 'iýun',
+'july-gen'      => 'iýul',
+'august-gen'    => 'awgust',
+'september-gen' => 'sentýabr',
+'october-gen'   => 'oktýabr',
+'november-gen'  => 'noýabr',
+'december-gen'  => 'dekabr',
 'jan'           => 'Türkmenbaşy aý',
 'feb'           => 'Baýdak aý',
 'mar'           => 'Nowruz aý',
 'apr'           => 'Gurbansoltan aý',
-'may'           => 'Magtymguly aý',
+'may'           => 'maý',
 'jun'           => 'Oguzhan aý',
 'jul'           => 'Gorkut aý',
 'aug'           => 'Alp Arslan aý',
@@ -131,7 +139,7 @@
 # Miscellaneous special pages
 'move' => 'Atyňy özgert',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Git',
 
 # Namespace form on various pages
Index: languages/messages/MessagesPap.php
===================================================================
--- languages/messages/MessagesPap.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPap.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author לערי ריינהארט
- * @author SPQRobin
- * @author Siebrand
  * @author Kamizu
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -122,7 +120,7 @@
 'nosuchspecialpage' => 'E página spesial no ta eksistí',
 'nospecialpagetext' => "<big>'''Bo a pidi un página spesial inválido.'''</big>
 
-Bo por haña un lista di tur [[Special:Specialpages|{{int:specialpages}}]].",
+Bo por haña un lista di tur [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'         => 'Eror',
@@ -167,15 +165,12 @@
 Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e historia di kambionan hasí na e página aki.',
 'blockedtitle'       => 'Uzadó ta blokiá',
 'whitelistedittitle' => 'Mester outentiká promé pa editá',
-'whitelistreadtitle' => 'Mester outentiká promé pa lesa',
-'whitelistreadtext'  => 'Bo mester [[Special:Userlogin|outentiká bo mes]] pa lesa página.',
-'whitelistacctitle'  => 'Bo no ta pèrmití pa traha un kuenta nobo',
 'confirmedittitle'   => 'Konfirmashon di e-mail eksigí pa editá',
 'confirmedittext'    => 'Bo mester konfirmá bo e-mail adrès promé ku bo editá página. Por fabor duna i validá bo e-mail adrès via bo [[Special:Preferences|preferensianan]].',
 'accmailtitle'       => 'Kontraseña mandá.',
 'accmailtext'        => "E kontraseña pa '$1' tabata mandá pa $2.",
 'newarticle'         => '(Nobo)',
-'anontalkpagetext'   => "----''Esaki ta e página di diskushon pa un uzadó anonimo ku no a traha un kuenta ahinda, òf no sa uza e. Ta pa e rason aki nos tin ku uza IP adrès pa identifiká e persona. Diferente uzadó por uza e IP adrès aki. Si bo ta un uzadó anonimo i ta sinti ku komentario irelevante tabata mandá pa bo, por fabor [[Special:Userlogin|registrá un kuenta nobo òf outentiká bo mes]] pa evitá konfushon den futuro.''",
+'anontalkpagetext'   => "----''Esaki ta e página di diskushon pa un uzadó anonimo ku no a traha un kuenta ahinda, òf no sa uza e. Ta pa e rason aki nos tin ku uza IP adrès pa identifiká e persona. Diferente uzadó por uza e IP adrès aki. Si bo ta un uzadó anonimo i ta sinti ku komentario irelevante tabata mandá pa bo, por fabor [[Special:UserLogin|registrá un kuenta nobo òf outentiká bo mes]] pa evitá konfushon den futuro.''",
 'yourtext'           => 'Bo teksto',
 'yourdiff'           => 'Diferensianan',
 
@@ -233,7 +228,7 @@
 'alllogstext' => 'Esaki ta un bista kombiná di registronan.
 Bo por skohe un tipo di registro tambe, òf filtrá e bista ku un nòmber di uzadó òf un título di un artíkulo.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tur página',
 'alphaindexline'    => '$1 pa $2',
 'allpagesfrom'      => 'Mustra páginanan kuminsando na:',
@@ -265,11 +260,11 @@
 # Watchlist
 'watchlist'         => 'Mi lista di observashon',
 'nowatchlist'       => 'Bo lista di observashon ta bashí.',
-'watchnologintext'  => 'Bo mester [[Special:Userlogin|outentiká bo mes]] pa modifiká bo lista di observashon.',
+'watchnologintext'  => 'Bo mester [[Special:UserLogin|outentiká bo mes]] pa modifiká bo lista di observashon.',
 'addedwatch'        => 'Añadí na lista di observashon',
 'addedwatchtext'    => "E página \"[[:\$1]]\" tabata añadí na bo [[Special:Watchlist|lista di observashon]].
 Lo lista kambionan hasí na e página aki i su página di diskushon einan,
-i e página lo aparesé '''vet''' den e [[Special:Recentchanges|lista di kambionan resien]] pa
+i e página lo aparesé '''vet''' den e [[Special:RecentChanges|lista di kambionan resien]] pa
 e ta mas fásil pa bo mira.
 
 Si despues bo ke kita e página for di bo lista di observashon, primi \"Stop di observá\" den e menú ariba.",
@@ -308,7 +303,7 @@
 'badipaddress'       => 'IP adrès ta inválido',
 'blockipsuccesssub'  => 'Blokeo eksitoso',
 'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] tabata blokiá.<br />
-Wak e [[Special:Ipblocklist|lista di blokeonan]] pa wak tur blokeo aktivo.',
+Wak e [[Special:IPBlockList|lista di blokeonan]] pa wak tur blokeo aktivo.',
 'unblockip'          => 'Desblokia uzadó',
 'blocklink'          => 'blokia',
 'unblocklink'        => 'desblokia',
Index: languages/messages/MessagesTo.php
===================================================================
--- languages/messages/MessagesTo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
+ * @author Cbrown1023
  * @author Tauʻolunga
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Cbrown1023
  */
 
 $messages = array(
@@ -343,10 +341,6 @@
 'blockededitsource'       => "ʻOku ʻasi ʻi lalo ʻa e tohi ʻo '''hoʻo ngaahi fatu''' ki he '''$1''':",
 'whitelistedittitle'      => 'ʻOku pau ke kau ki ai ke fatuʻi',
 'whitelistedittext'       => 'ʻOku pau te ke $1 kapau te ke fiefatu ʻa e ngaahi kupu.',
-'whitelistreadtitle'      => 'ʻOku pau ke kau ki ai ke lau',
-'whitelistreadtext'       => 'ʻOku pau te ke [[Special:Userlogin|kau ki ai]] kapau te ke fielau ʻa e ngaahi kupu.',
-'whitelistacctitle'       => 'ʻOku ʻikai ngofua kia te koe ʻe fakatupu ha tohi kau-ki-ai',
-'whitelistacctext'        => 'Ke tuku ange ʻi he fakatupu ʻo e ngaahi tohi kau-ki-ai ʻi heni, ʻoku pau te ke [[Special:Userlogin|kau-ki-ai]] mo ʻoku ʻi ai haʻo fakangofua totonu.',
 'confirmedittitle'        => 'ʻOku pau ʻe fakaʻmoʻoniʻi hoʻo tohila kapau te ke fieʻetita',
 'confirmedittext'         => 'ʻOku pau te ke fakamoʻoniʻi ho tuʻasila tohila ʻi muʻa hoʻo fatu kupu. Kātaki ʻe fakamoʻoniʻi ia ngāueʻaki hoʻo [[Special:Preferences|faʻiteliha]] fakaʻetita.',
 'loginreqtitle'           => 'ʻOku pau te ke kau ki ai',
@@ -356,7 +350,7 @@
 'accmailtext'             => 'ʻOsi ʻave ʻa e leatapu maʻa "$1" ki he $2.',
 'newarticle'              => '(Foʻou)',
 'newarticletext'          => "Naʻa ke muimui ha fehokotaki ki he peesi ʻoku teʻeki fakatupu. Kapau te ke fiefakatupi he pēsí ni, kamata hoʻo tohi ʻi he puha ʻi lalo. (Vakai ki he [[{{MediaWiki:Helppage}}|tokoni]] mo hano ongoongo lahi ange.) Kapau ʻoku hala pē heni, lomiʻi pē he meʻa-lolomi 'ki mui' ʻo ho palausa.",
-'anontalkpagetext'        => "----''Ko e peesi ʻeni ko e peesi alea ia maʻa e ʻetita taʻehingoa teʻeki ʻene fakatupu ʻo e tohi kau-ki-ai pe ʻoku ʻikai ngāueʻaki mo ia. Ko ia ai ʻoku fakapapauʻi ia ʻe he tuʻasila IP fakafika pē. Ka ʻe lava ʻoku vahevahe ʻa e tuʻasila IP pehē ʻe he kau ʻetita tokolahi. Kapau ko koe ko e ʻetita taʻehingoa, ʻoku ke tui ko e ngaahi fakamatala ʻi heni ʻoku ʻikai maʻau, mahalo pē ʻoku sai ange ke ke [[Special:Userlogin|fai ha tohi kau-ki-ai, pe kau-ki-ai]] he taimí ni pea fakaʻehiʻehi ha ngaahi meʻafihi ē ʻi he kahaʻu.''",
+'anontalkpagetext'        => "----''Ko e peesi ʻeni ko e peesi alea ia maʻa e ʻetita taʻehingoa teʻeki ʻene fakatupu ʻo e tohi kau-ki-ai pe ʻoku ʻikai ngāueʻaki mo ia. Ko ia ai ʻoku fakapapauʻi ia ʻe he tuʻasila IP fakafika pē. Ka ʻe lava ʻoku vahevahe ʻa e tuʻasila IP pehē ʻe he kau ʻetita tokolahi. Kapau ko koe ko e ʻetita taʻehingoa, ʻoku ke tui ko e ngaahi fakamatala ʻi heni ʻoku ʻikai maʻau, mahalo pē ʻoku sai ange ke ke [[Special:UserLogin|fai ha tohi kau-ki-ai, pe kau-ki-ai]] he taimí ni pea fakaʻehiʻehi ha ngaahi meʻafihi ē ʻi he kahaʻu.''",
 'noarticletext'           => 'Ko e pēsi ni, ʻoku ʻikai haʻane tohi ʻi ai he taimi ni. ʻE lava koe ʻo [[Special:Search/{{PAGENAME}}|kumi ki heʻene hingoa]] ʻi ha ngaahi peesi ʻe taha, pe [{{fullurl:{{FULLPAGENAME}}|action=edit}} ʻetita ʻi ai.]',
 'clearyourcache'          => "'''Tokanga''', ʻosi he haofaki e peesi, mahalo pē ʻoku pau te ke fakaʻatā ʻa e fafaʻo ʻo ho palausa, naʻa ʻikai te ke sio ʻa e paaki foʻou.",
 'updated'                 => '(Fakafoʻou)',
@@ -385,7 +379,7 @@
 'templatesusedpreview'    => 'Ngaahi sīpinga ʻoku ngāueʻaki he vakaí ni:',
 'templatesusedsection'    => 'Ngaahi sīpinga ʻoku ngāueʻaki he kongá ni:',
 'nocreatetitle'           => 'ʻOku fakangatangata ʻa e fakatupu ʻo e peesi.',
-'nocreatetext'            => 'Naʻe fakangatangata ʻe he tuʻuʻangá ni ʻa e lava ke fakatupu ha peesi foʻou. ʻOku ke lava ke foki pea fatu ha peesi tuʻu, pe [[Special:Userlogin|kau-ki-ai, pe fakatupu ha tohi-kau-ki-ai]].',
+'nocreatetext'            => 'Naʻe fakangatangata ʻe he tuʻuʻangá ni ʻa e lava ke fakatupu ha peesi foʻou. ʻOku ke lava ke foki pea fatu ha peesi tuʻu, pe [[Special:UserLogin|kau-ki-ai, pe fakatupu ha tohi-kau-ki-ai]].',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'ʻOku ʻikai lava fakatupu e tohi kau-ki-ai',
@@ -521,7 +515,7 @@
 'reupload'                    => 'Toe hiki hake',
 'reuploaddesc'                => 'Foki ki he foomu hiki',
 'uploadnologin'               => 'Teʻeki kau ki ai',
-'uploadnologintext'           => 'ʻOku pau ke [[Special:Userlogin|kau-ki-ai]] kapau te ke fiehiki hake ha faile.',
+'uploadnologintext'           => 'ʻOku pau ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fiehiki hake ha faile.',
 'upload_directory_read_only'  => 'ʻOku ʻikai lava ʻo tohi ʻa e takafi ($1) ʻe he tauhia matamatakupenga.',
 'uploaderror'                 => 'Halaʻi hiki hake',
 'uploadlog'                   => 'tohinoa ʻo e ngaahi hiki hake',
@@ -556,7 +550,7 @@
 'license'   => 'Laiseni:',
 'nolicense' => 'ʻIkai fili ha taha',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Kumi ki he hingoa ʻo e faitā:',
 'imgfile'               => 'faile',
 'imagelist'             => 'Hokohoko faitā',
@@ -579,11 +573,11 @@
 # File reversion
 'filerevert'                => 'Toe foki $1 ki hono tuʻunga muʻa',
 'filerevert-legend'         => 'Toe foki ʻa e faile ki hono tuʻunga muʻa',
-'filerevert-intro'          => '<span class="plainlinks">ʻOku ke toe foki ʻa e \'\'\'[[Media:$1|$1]]\'\'\' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.</span>',
+'filerevert-intro'          => "ʻOku ke toe foki ʻa e '''[[Media:$1|$1]]''' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.",
 'filerevert-comment'        => 'Fakamatala:',
 'filerevert-defaultcomment' => 'Kuo toe foki $1 ki hono tuʻunga muʻa ʻo e $2',
 'filerevert-submit'         => 'Toe foki ki hono tuʻunga muʻa',
-'filerevert-success'        => '<span class="plainlinks">Kuo toe foki ʻa e \'\'\'[[Media:$1|$1]]\'\'\' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.</span>',
+'filerevert-success'        => "Kuo toe foki ʻa e '''[[Media:$1|$1]]''' ki hono tuʻunga muʻa, paaki $4 ʻo e $2 $3.",
 
 # MIME search
 'mimesearch' => 'Kumi fakaMIME',
@@ -680,7 +674,7 @@
 'alllogstext'          => 'Fakaʻaliʻali fakakātoa ʻo e ngaahi tohinoa hiki hake, mo tāmateʻi, mo maluʻi, mo taʻofi, mo fakapule. ʻOku lava ke ke sivi ʻa e fakaʻaliʻalí ni ʻi he fili ʻo e falenga tohinoa pe hingoa ʻo e ʻetita pe peesi hūkitonu.',
 'logempty'             => 'ʻOku maha ʻa e tohinoa.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Peesi kotoa',
 'alphaindexline'    => '$1 ki he $2',
 'nextpage'          => 'Peesi hoko ($1)',
@@ -699,7 +693,7 @@
 'categories'         => 'Faʻahinga',
 'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'    => 'ʻAsi mai kau ʻetita mei he:',
 'listusers-submit' => 'ʻAsi mai',
 
@@ -726,9 +720,9 @@
 'nowatchlist'          => 'ʻOku ʻikai ha meʻa ʻi hoʻo hokohoko leʻo.',
 'watchlistanontext'    => 'Kātaki, ʻe $1 kapau te ke fievakai pe fiefatu ha ngaahi meʻa ʻi hoʻo hokohoko leʻo.',
 'watchnologin'         => 'Teʻeki kau ki ai',
-'watchnologintext'     => 'ʻOku pau te ke [[Special:Userlogin|kau-ki-ai]] kapau te ke fieliliu hoʻo hokohoko leʻo.',
+'watchnologintext'     => 'ʻOku pau te ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fieliliu hoʻo hokohoko leʻo.',
 'addedwatch'           => 'Kuo tānaki ki hoʻo hokohoko leʻo',
-'addedwatchtext'       => 'Ko e peesi "[[:$1]]" naʻe tānaki ia ki hoʻo [[Special:Watchlist|hokohoko leʻo]]. Ko e ngaahi liliu ʻo e kahaʻu ʻi he pēsí ni mo hono peesi aleá, ʻe ʻoatu ʻi heni mo ʻasi mai  ʻi he hokohoko ʻo e [[Special:Recentchanges|ngaahi toki liliu]], ʻoku sinolahi ke fanāfotu.
+'addedwatchtext'       => 'Ko e peesi "[[:$1]]" naʻe tānaki ia ki hoʻo [[Special:Watchlist|hokohoko leʻo]]. Ko e ngaahi liliu ʻo e kahaʻu ʻi he pēsí ni mo hono peesi aleá, ʻe ʻoatu ʻi heni mo ʻasi mai  ʻi he hokohoko ʻo e [[Special:RecentChanges|ngaahi toki liliu]], ʻoku sinolahi ke fanāfotu.
 
 Kapau ʻaho ʻe taha, te ke fietoʻo ʻa e pēsí mei hoʻo hokohoko leʻo, lomiʻi "taʻeleʻo" ʻi he pā tafaʻaki.',
 'removedwatch'         => 'Kuo toʻo mei he hokohoko leʻo',
@@ -852,7 +846,7 @@
 'badipaddress'         => 'Tuʻasila IP taʻeʻaongaʻi',
 'blockipsuccesssub'    => 'Ola ʻo e taʻofi',
 'blockipsuccesstext'   => 'Kuo taʻofia ʻa [[Special:Contributions/$1|$1]]
-<br />Vakai ki he [[Special:Ipblocklist|hokohoko ʻo e taʻofi]] ʻo toe fakakaukau ʻi ai.',
+<br />Vakai ki he [[Special:IPBlockList|hokohoko ʻo e taʻofi]] ʻo toe fakakaukau ʻi ai.',
 'unblockip'            => 'Taʻetaʻofia ʻetita',
 'unblockiptext'        => 'Ngāueʻaki ʻa e foomu ʻi lalo ke fakafoki e ngofua tohi maʻa e tuʻasila IP pe hingoa ʻo e kau-ki-ai ʻosi taʻofi.',
 'ipusubmit'            => 'Taʻetaʻofia ʻa e ʻetitá ni',
@@ -869,7 +863,7 @@
 'autoblocker'          => 'ʻOku taʻofi ʻiate ia pe, koeʻuhi ko hoʻo tuaʻasila IP naʻe ngāueʻaki ia ʻe he ʻetita "[[User:$1|$1]]". Ko e ʻuhinga maʻa e taʻofi ʻo $1 ko "\'\'\'$2\'\'\'" ia.',
 'blocklogpage'         => 'Tohinoa ʻo e taʻofi',
 'blocklogentry'        => 'taʻofia [[$1]] mo ha fuoloa $2 $3',
-'blocklogtext'         => 'Ko e tohinoa ʻeni ʻo e ngāue ʻo e ngaahi taʻofi mo e taʻetaʻofi ʻo e kau ʻetita. ʻOku ʻikai ʻasi ha ngaahi tuʻasila IP ʻoku taʻofi ngaue ʻia te ia pē. Vakai ki he [[Special:Ipblocklist|hokohoko taʻofi IP]] kapau te ke fiemaʻu ʻa e hokohoko ʻo e ngaahi taʻofi taka kotoa.',
+'blocklogtext'         => 'Ko e tohinoa ʻeni ʻo e ngāue ʻo e ngaahi taʻofi mo e taʻetaʻofi ʻo e kau ʻetita. ʻOku ʻikai ʻasi ha ngaahi tuʻasila IP ʻoku taʻofi ngaue ʻia te ia pē. Vakai ki he [[Special:IPBlockList|hokohoko taʻofi IP]] kapau te ke fiemaʻu ʻa e hokohoko ʻo e ngaahi taʻofi taka kotoa.',
 'unblocklogentry'      => 'taʻetaʻofia $1',
 'range_block_disabled' => 'ʻOku fakataʻeʻaongaʻi ʻa e fakatupu fakapule-fakafounga ʻo ngaahi taʻofi fakavā.',
 'ipb_expiry_invalid'   => 'ʻOku taʻeʻaongaʻi ʻa e taimi ki he mate.',
@@ -909,8 +903,6 @@
 *te ke tiki ʻa e puha ʻi lalo.
 ʻI he meʻa ko ia, ʻe ʻunuʻi pe fakatahaʻi ʻa e peesi alea faiʻaki ʻa e nima.",
 'movearticle'             => 'ʻUnu ʻa e kupu',
-'movenologin'             => 'ʻOku ʻikai ke kau-ki-ai',
-'movenologintext'         => 'Kuo pau ko e ʻetita lēsisita koe pea [[Special:Userlogin|kau-ki-ai]] kapau te ke fieʻunu ha peesi.',
 'newtitle'                => 'Ki he hingoa foʻou',
 'move-watch'              => 'Leʻo he pēsí ni',
 'movepagebtn'             => 'Peesi ʻunu',
@@ -928,7 +920,7 @@
 'delete_and_move'         => 'Tāmateʻi pea ʻunu',
 'delete_and_move_text'    => '==Fiemaʻu tāmateʻi==
 
-ʻOku toka tuʻu ʻa e kupu pehē "[[$1]]". ʻOku ke fietāmateʻi ia ke fakaʻatā he ʻunu?',
+ʻOku toka tuʻu ʻa e kupu pehē "[[:$1]]". ʻOku ke fietāmateʻi ia ke fakaʻatā he ʻunu?',
 'delete_and_move_confirm' => 'ʻIo, tāmateʻi e pēsí',
 'delete_and_move_reason'  => 'Kuo tāmateʻi maʻa e fakaʻatā he ʻunu',
 
@@ -1013,7 +1005,7 @@
 'show-big-image'       => 'ʻAsi ʻa e faitā auiiki',
 'show-big-image-thumb' => '<small>Vakai pē ʻi hono lahi: $1 x $2 tefitoʻifaitā</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Fakaʻaliʻali ʻo e ngaahi faitā foʻou',
 'imagelisttext'         => "ʻOku ʻasi ʻi lalo ha hokohoko ʻo e '''$1''' vahevahe he $2.",
 'showhidebots'          => '($1 fatu fakamīsini)',
@@ -1136,7 +1128,7 @@
 
 # External editor support
 'edit-externally'      => 'Fatuʻi ʻa e failé ni ngāueʻaki mo e polokalama ʻi tuʻa',
-'edit-externally-help' => 'Vakai ki he [http://meta.wikimedia.org/wiki/Help:External_editors fakahinohino ki he fokotuʻu] maʻa toe fakamatala.',
+'edit-externally-help' => 'Vakai ki he [http://www.mediawiki.org/wiki/Manual:External_editors fakahinohino ki he fokotuʻu] maʻa toe fakamatala.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kotoa',
@@ -1178,7 +1170,7 @@
 'recreate'            => 'Toe fakatupu',
 
 # HTML dump
-'redirectingto' => 'ʻOku leʻei ki [[$1]]...',
+'redirectingto' => 'ʻOku leʻei ki [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Fakaʻatā ko e fafaʻo ʻo e pēsí ni?
@@ -1219,7 +1211,7 @@
 # Special:Version
 'version' => 'Paaki', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Hala ki he faile',
 'filepath-page'   => 'Faile:',
 'filepath-submit' => 'Ko e hala',
Index: languages/messages/MessagesPt.php
===================================================================
--- languages/messages/MessagesPt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,24 +4,22 @@
  * @ingroup Language
  * @file
  *
- * @author 555
- * @author Malafaya
- * @author Siebrand
  * @author Lijealso
- * @author לערי ריינהארט
+ * @author Lugusto
  * @author MCruz
- * @author SPQRobin
- * @author Rei-artur
- * @author Waldir
+ * @author Malafaya
+ * @author Manuel Menezes de Sequeira
  * @author Minh Nguyen
- * @author Villate
- * @author Yves Marques Junqueira
- * @author Rodrigo Calanca Nishino
  * @author Nuno Tavares
  * @author Paulo Juntas
- * @author Manuel Menezes de Sequeira
+ * @author Rei-artur
+ * @author Rodrigo Calanca Nishino
  * @author Sérgio Ribeiro
- * @author Lugusto
+ * @author Villate
+ * @author Waldir
+ * @author Yves Marques Junqueira
+ * @author לערי ריינהארט
+ * @author 555
  */
 
 $namespaceNames = array(
@@ -70,86 +68,89 @@
 #$linkTrail = '/^([a-z]+)(.*)$/sD';# ignore list
 
 $specialPageAliases = array(
-	'DoubleRedirects'           => array( 'Redireccionamentos_duplos', 'redirecionamentos_duplos' ),
-	'BrokenRedirects'           => array( 'Redireccionamentos_quebrados', 'redirecionamentos_quebrados' ),
-	'Disambiguations'           => array( 'Páginas_de_desambiguação', 'Desambiguar', 'Desambiguações' ),
-	'Userlogin'                 => array( 'Entrar', 'Login' ),
-	'Userlogout'                => array( 'Sair', 'Logout' ),
-	'CreateAccount'             => array( 'Criar_conta' ),
-	'Preferences'               => array( 'Preferências' ),
-	'Watchlist'                 => array( 'Páginas_vigiadas', 'Artigos_vigiados', 'Vigiados' ),
-	'Recentchanges'             => array( 'Mudanças_recentes' ),
-	'Upload'                    => array( 'Carregar_imagem', 'Carregar_ficheiro', 'Carregar_arquivo', 'Enviar' ),
-	'Imagelist'                 => array( 'Lista_de_imagens', 'Lista_de_ficheiros', 'Lista_de_arquivos' ),
-	'Newimages'                 => array( 'Imagens_novas', 'Ficheiros_novos', 'Arquivos_novos' ),
-	'Listusers'                 => array( 'Lista_de_usuários', 'Lista_de_utilizadores' ),
-	'Listgrouprights'           => array( 'Listar_privilégios_de_grupos' ),
-	'Statistics'                => array( 'Estatísticas' ),
-	'Randompage'                => array( 'Aleatória', 'Aleatório', 'Página_aleatória', 'Artigo_aleatório' ),
-	'Lonelypages'               => array( 'Páginas_órfãs', 'Artigos_órfãos', 'Páginas_sem_afluentes', 'Artigos_sem_afluentes' ),
-	'Uncategorizedpages'        => array( 'Páginas_sem_categorias', 'Artigos_sem_categorias' ),
-	'Uncategorizedcategories'   => array( 'Categorias_sem_categorias' ),
-	'Uncategorizedimages'       => array( 'Imagens_sem_categorias', 'Ficheiros_sem_categorias', 'Arquivos_sem_categorias' ),
-	'Uncategorizedtemplates'    => array( 'Predefinições_não_categorizadas', 'Predefinições_sem_categorias' ),
-	'Unusedcategories'          => array( 'Categorias_não_utilizadas', 'Categorias_sem_uso' ),
-	'Unusedimages'              => array( 'Imagens_sem_uso', 'Imagens_não_utilizadas', 'Ficheiros_sem_uso', 'Ficheiros_não_utilizados', 'Arquivos_sem_uso', 'Arquivos_não_utilizados' ),
-	'Wantedpages'               => array( 'Páginas_em_falta', 'Artigos_em_falta', 'Páginas_pedidas', 'Artigos_pedidos' ),
-	'Wantedcategories'          => array( 'Categorias_em_falta', 'Categorias_inexistentes' ),
-	'Mostlinked'                => array( 'Páginas_com_mais_afluentes', 'Artigos_com_mais_afluentes' ),
-	'Mostlinkedcategories'      => array( 'Categorias_com_mais_afluentes' ),
-	'Mostlinkedtemplates'       => array( 'Predefinições_com_mais_afluentes' ),
-	'Mostcategories'            => array( 'Páginas_com_mais_categorias', 'Artigos_com_mais_categorias' ),
-	'Mostimages'                => array( 'Imagens_com_mais_afluentes', 'Ficheiros_com_mais_afluentes', 'Arquivos_com_mais_afluentes' ),
-	'Mostrevisions'             => array( 'Páginas_com_mais_edições', 'Artigos_com_mais_edições' ),
-	'Fewestrevisions'           => array( 'Páginas_com_menos_edições', 'Artigos_com_menos_edições', 'Artigos_menos_editados' ),
-	'Shortpages'                => array( 'Páginas_curtas', 'Artigos_curtos' ),
-	'Longpages'                 => array( 'Páginas_longas', 'Artigos_extensos' ),
-	'Newpages'                  => array( 'Páginas_novas', 'Artigos_novos' ),
-	'Ancientpages'              => array( 'Páginas_inativas', 'Artigos_inativos' ),
-	'Deadendpages'              => array( 'Páginas_sem_saída', 'Artigos_sem_saída' ),
-	'Protectedpages'            => array( 'Páginas_protegidas', 'Artigos_protegidos' ),
-	'Protectedtitles'           => array( 'Títulos_protegidos' ),
-	'Allpages'                  => array( 'Todas_as_páginas', 'Todos_os_artigos', 'Todas_páginas', 'Todos_artigos' ),
-	'Prefixindex'               => array( 'Índice_de_prefixo', 'Índice_por_prefixo' ),
-	'Ipblocklist'               => array( 'Registo_de_bloqueios', 'Registro_de_bloqueios', 'IPs_bloqueados', 'Utilizadores_bloqueados', 'Usuários_bloqueados' ),
-	'Specialpages'              => array( 'Páginas_especiais' ),
-	'Contributions'             => array( 'Contribuições' ),
-	'Emailuser'                 => array( 'Contactar_usuário', 'Contactar_utilizador', 'Contatar_usuário' ),
-	'Confirmemail'              => array( 'Confirmar_e-mail', 'Confirmar_email' ),
-	'Whatlinkshere'             => array( 'Páginas_afluentes', 'Artigos_afluentes' ),
-	'Recentchangeslinked'       => array( 'Novidades_relacionadas', 'Mudanças_relacionadas' ),
-	'Movepage'                  => array( 'Mover', 'Mover_página', 'Mover_artigo' ),
-	'Blockme'                   => array( 'Bloquear-me', 'Auto-bloqueio' ),
-	'Booksources'               => array( 'Fontes_de_livros' ),
-	'Categories'                => array( 'Categorias' ),
-	'Export'                    => array( 'Exportar' ),
-	'Version'                   => array( 'Versão', 'Sobre' ),
-	'Allmessages'               => array( 'Todas_as_mensagens', 'Todas_mensagens' ),
-	'Log'                       => array( 'Registo', 'Registro', 'Registos', 'Registros' ),
-	'Blockip'                   => array( 'Bloquear', 'Bloquear_IP', 'Bloquear_utilizador', 'Bloquear_usuário' ),
-	'Undelete'                  => array( 'Restaurar', 'Restaurar_páginas_eliminadas', 'Restaurar_artigos_eliminados' ),
-	'Import'                    => array( 'Importar' ),
-	'Lockdb'                    => array( 'Bloquear_a_base_de_dados', 'Bloquear_banco_de_dados' ),
-	'Unlockdb'                  => array( 'Desbloquear_a_base_de_dados', 'Desbloquear_banco_de_dados' ),
-	'Userrights'                => array( 'Privilégios', 'Direitos', 'Estatutos' ),
-	'MIMEsearch'                => array( 'Busca_MIME' ),
-	'FileDuplicateSearch'       => array( 'Busca_de_ficheiros_duplicados', 'Busca_de_arquivos_duplicados' ),
-	'Unwatchedpages'            => array( 'Páginas_não-vigiadas', 'Páginas_não_vigiadas', 'Artigos_não-vigiados', 'Artigos_não_vigiados' ),
-	'Listredirects'             => array( 'Redireccionamentos', 'Redirecionamentos', 'Lista_de_redireccionamentos', 'Lista_de_redirecionamentos' ),
-	'Revisiondelete'            => array( 'Eliminar_edição', 'Eliminar_revisão', 'Apagar_edição', 'Apagar_revisão' ),
-	'Unusedtemplates'           => array( 'Predefinições_sem_uso', 'Predefinições_não_utilizadas' ),
-	'Randomredirect'            => array( 'Redireccionamento_aleatório', 'Redirecionamento_aleatório' ),
-	'Mypage'                    => array( 'Minha_página' ),
-	'Mytalk'                    => array( 'Minha_discussão' ),
-	'Mycontributions'           => array( 'Minhas_contribuições', 'Minhas_edições', 'Minhas_constribuições' ),
-	'Listadmins'                => array( 'Administradores', 'Admins', 'Lista_de_administradores', 'Lista_de_admins' ),
-	'Listbots'                  => array( 'Bots', 'Lista_de_bots' ),
-	'Popularpages'              => array( 'Páginas_populares', 'Artigos_populares' ),
-	'Search'                    => array( 'Busca', 'Buscar', 'Procurar', 'Pesquisar', 'Pesquisa' ),
-	'Resetpass'                 => array( 'Repor_senha', 'Zerar_senha' ),
-	'Withoutinterwiki'          => array( 'Páginas_sem_interwikis', 'Artigos_sem_interwikis' ),
-	'MergeHistory'              => array( 'Fundir_históricos', 'Fundir_edições' ),
-	'Filepath'                  => array( 'Diretório_de_ficheiro', 'Diretório_de_arquivo' ),
+	'DoubleRedirects'         => array( 'Redireccionamentos duplos', 'redirecionamentos duplos' ),
+	'BrokenRedirects'         => array( 'Redireccionamentos quebrados', 'redirecionamentos quebrados' ),
+	'Disambiguations'         => array( 'Páginas de desambiguação', 'Desambiguar', 'Desambiguações' ),
+	'Userlogin'               => array( 'Entrar', 'Login' ),
+	'Userlogout'              => array( 'Sair', 'Logout' ),
+	'CreateAccount'           => array( 'Criar conta' ),
+	'Preferences'             => array( 'Preferências' ),
+	'Watchlist'               => array( 'Páginas vigiadas', 'Artigos vigiados', 'Vigiados' ),
+	'Recentchanges'           => array( 'Mudanças recentes' ),
+	'Upload'                  => array( 'Carregar imagem', 'Carregar ficheiro', 'Carregar arquivo', 'Enviar' ),
+	'Imagelist'               => array( 'Lista de imagens', 'Lista de ficheiros', 'Lista de arquivos' ),
+	'Newimages'               => array( 'Imagens novas', 'Ficheiros novos', 'Arquivos novos' ),
+	'Listusers'               => array( 'Lista de usuários', 'Lista de utilizadores' ),
+	'Listgrouprights'         => array( 'Listar privilégios de grupos' ),
+	'Statistics'              => array( 'Estatísticas' ),
+	'Randompage'              => array( 'Aleatória', 'Aleatório', 'Página aleatória', 'Artigo aleatório' ),
+	'Lonelypages'             => array( 'Páginas órfãs', 'Artigos órfãos', 'Páginas sem afluentes', 'Artigos sem afluentes' ),
+	'Uncategorizedpages'      => array( 'Páginas sem categorias', 'Artigos sem categorias' ),
+	'Uncategorizedcategories' => array( 'Categorias sem categorias' ),
+	'Uncategorizedimages'     => array( 'Imagens sem categorias', 'Ficheiros sem categorias', 'Arquivos sem categorias' ),
+	'Uncategorizedtemplates'  => array( 'Predefinições não categorizadas', 'Predefinições sem categorias' ),
+	'Unusedcategories'        => array( 'Categorias não utilizadas', 'Categorias sem uso' ),
+	'Unusedimages'            => array( 'Imagens sem uso', 'Imagens não utilizadas', 'Ficheiros sem uso', 'Ficheiros não utilizados', 'Arquivos sem uso', 'Arquivos não utilizados' ),
+	'Wantedpages'             => array( 'Páginas em falta', 'Artigos em falta', 'Páginas pedidas', 'Artigos pedidos' ),
+	'Wantedcategories'        => array( 'Categorias em falta', 'Categorias inexistentes' ),
+	'Missingfiles'            => array( 'Ficheiros em falta', 'Arquivos em falta', 'Imagens em falta', '' ),
+	'Mostlinked'              => array( 'Páginas com mais afluentes', 'Artigos com mais afluentes' ),
+	'Mostlinkedcategories'    => array( 'Categorias com mais afluentes' ),
+	'Mostlinkedtemplates'     => array( 'Predefinições com mais afluentes' ),
+	'Mostcategories'          => array( 'Páginas com mais categorias', 'Artigos com mais categorias' ),
+	'Mostimages'              => array( 'Imagens com mais afluentes', 'Ficheiros com mais afluentes', 'Arquivos com mais afluentes' ),
+	'Mostrevisions'           => array( 'Páginas com mais edições', 'Artigos com mais edições' ),
+	'Fewestrevisions'         => array( 'Páginas com menos edições', 'Artigos com menos edições', 'Artigos menos editados' ),
+	'Shortpages'              => array( 'Páginas curtas', 'Artigos curtos' ),
+	'Longpages'               => array( 'Páginas longas', 'Artigos extensos' ),
+	'Newpages'                => array( 'Páginas novas', 'Artigos novos' ),
+	'Ancientpages'            => array( 'Páginas inativas', 'Artigos inativos' ),
+	'Deadendpages'            => array( 'Páginas sem saída', 'Artigos sem saída' ),
+	'Protectedpages'          => array( 'Páginas protegidas', 'Artigos protegidos' ),
+	'Protectedtitles'         => array( 'Títulos protegidos' ),
+	'Allpages'                => array( 'Todas as páginas', 'Todos os artigos', 'Todas páginas', 'Todos artigos' ),
+	'Prefixindex'             => array( 'Índice de prefixo', 'Índice por prefixo' ),
+	'Ipblocklist'             => array( 'Registo de bloqueios', 'Registro de bloqueios', 'IPs bloqueados', 'Utilizadores bloqueados', 'Usuários bloqueados' ),
+	'Specialpages'            => array( 'Páginas especiais' ),
+	'Contributions'           => array( 'Contribuições' ),
+	'Emailuser'               => array( 'Contactar usuário', 'Contactar utilizador', 'Contatar usuário' ),
+	'Confirmemail'            => array( 'Confirmar e-mail', 'Confirmar email' ),
+	'Whatlinkshere'           => array( 'Páginas afluentes', 'Artigos afluentes' ),
+	'Recentchangeslinked'     => array( 'Novidades relacionadas', 'Mudanças relacionadas' ),
+	'Movepage'                => array( 'Mover', 'Mover página', 'Mover artigo' ),
+	'Blockme'                 => array( 'Bloquear-me', 'Auto-bloqueio' ),
+	'Booksources'             => array( 'Fontes de livros' ),
+	'Categories'              => array( 'Categorias' ),
+	'Export'                  => array( 'Exportar' ),
+	'Version'                 => array( 'Versão', 'Sobre' ),
+	'Allmessages'             => array( 'Todas as mensagens', 'Todas mensagens' ),
+	'Log'                     => array( 'Registo', 'Registro', 'Registos', 'Registros' ),
+	'Blockip'                 => array( 'Bloquear', 'Bloquear IP', 'Bloquear utilizador', 'Bloquear usuário' ),
+	'Undelete'                => array( 'Restaurar', 'Restaurar páginas eliminadas', 'Restaurar artigos eliminados' ),
+	'Import'                  => array( 'Importar' ),
+	'Lockdb'                  => array( 'Bloquear a base de dados', 'Bloquear banco de dados' ),
+	'Unlockdb'                => array( 'Desbloquear a base de dados', 'Desbloquear banco de dados' ),
+	'Userrights'              => array( 'Privilégios', 'Direitos', 'Estatutos' ),
+	'MIMEsearch'              => array( 'Busca MIME' ),
+	'FileDuplicateSearch'     => array( 'Busca de ficheiros duplicados', 'Busca de arquivos duplicados' ),
+	'Unwatchedpages'          => array( 'Páginas não-vigiadas', 'Páginas não vigiadas', 'Artigos não-vigiados', 'Artigos não vigiados' ),
+	'Listredirects'           => array( 'Redireccionamentos', 'Redirecionamentos', 'Lista de redireccionamentos', 'Lista de redirecionamentos' ),
+	'Revisiondelete'          => array( 'Eliminar edição', 'Eliminar revisão', 'Apagar edição', 'Apagar revisão' ),
+	'Unusedtemplates'         => array( 'Predefinições sem uso', 'Predefinições não utilizadas' ),
+	'Randomredirect'          => array( 'Redireccionamento aleatório', 'Redirecionamento aleatório' ),
+	'Mypage'                  => array( 'Minha página' ),
+	'Mytalk'                  => array( 'Minha discussão' ),
+	'Mycontributions'         => array( 'Minhas contribuições', 'Minhas edições', 'Minhas constribuições' ),
+	'Listadmins'              => array( 'Administradores', 'Admins', 'Lista de administradores', 'Lista de admins' ),
+	'Listbots'                => array( 'Bots', 'Lista de bots' ),
+	'Popularpages'            => array( 'Páginas populares', 'Artigos populares' ),
+	'Search'                  => array( 'Busca', 'Buscar', 'Procurar', 'Pesquisar', 'Pesquisa' ),
+	'Resetpass'               => array( 'Repor senha', 'Zerar senha' ),
+	'Withoutinterwiki'        => array( 'Páginas sem interwikis', 'Artigos sem interwikis' ),
+	'MergeHistory'            => array( 'Fundir históricos', 'Fundir edições' ),
+	'Filepath'                => array( 'Diretório de ficheiro', 'Diretório de arquivo' ),
+	'Invalidateemail'         => array( 'Invalidar e-mail' ),
+	'Blankpage'               => array( 'Página em branco' ),
 );
 
 $messages = array(
@@ -431,7 +432,7 @@
 'nosuchspecialpage' => 'Não existe a página especial requisitada',
 'nospecialpagetext' => "<big>'''Você requisitou uma página especial inválida.'''</big>
 
-Uma lista de páginas especiais válidas poderá ser encontrada em [[Special:Specialpages|{{int:specialpages}}]].",
+Uma lista de páginas especiais válidas poderá ser encontrada em [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erro',
@@ -680,10 +681,6 @@
 'blockededitsource'                => "O texto das '''suas edições''' em '''$1''' é mostrado abaixo:",
 'whitelistedittitle'               => 'É necessário autenticar-se para editar páginas',
 'whitelistedittext'                => 'Precisa de se $1 para poder editar páginas.',
-'whitelistreadtitle'               => 'É necessária a autentificação para poder visualizar',
-'whitelistreadtext'                => 'Precisa de se [[Special:Userlogin|autenticar]] para poder visualizar páginas.',
-'whitelistacctitle'                => 'Não lhe é permitido criar uma conta',
-'whitelistacctext'                 => 'De modo a poder criar contas de utilizador neste Wiki terá que se [[Special:Userlogin|autenticar]] e possuir as devidas permissões.',
 'confirmedittitle'                 => 'Confirmação de e-mail requerida para editar',
 'confirmedittext'                  => 'Você precisa confirmar o seu endereço de e-mail antes de começar a editar páginas.
 Por favor, introduza um e valide-o através das suas [[Special:Preferences|preferências de utilizador]].',
@@ -701,7 +698,7 @@
 Se você chegou até aqui por engano, clique no botão '''voltar''' (ou ''back'') do seu navegador.",
 'anontalkpagetext'                 => "----''Esta é a página de discussão para um utilizador anónimo que ainda não criou uma conta ou que não a utiliza, de modo a que temos que utilizar o endereço de IP para identificá-lo(a).
 Um endereço de IP pode ser partilhado por vários utilizadores.
-Se é um utilizador anónimo e sente que comentários irrelevantes foram direccionados a você, por favor [[Special:Userlogin|crie uma conta ou autentique-se]] para evitar futuras confusões com outros utilizadores anónimos.''",
+Se é um utilizador anónimo e sente que comentários irrelevantes foram direccionados a você, por favor [[Special:UserLogin|crie uma conta ou autentique-se]] para evitar futuras confusões com outros utilizadores anónimos.''",
 'noarticletext'                    => 'Não existe actualmente texto nesta página; você pode [[Special:Search/{{PAGENAME}}|pesquisar pelo título desta página noutras páginas]] ou [{{fullurl:{{FULLPAGENAME}}|action=edit}} editar esta página].',
 'userpage-userdoesnotexist'        => 'A conta "$1" não se encontra registada. Por gentileza, verifique se deseja mesmo criar/editar esta página.',
 'clearyourcache'                   => "'''Nota:''' Após salvar, terá de limpar a cache do seu navegador para ver as alterações.'''
@@ -765,7 +762,7 @@
 'edittools'                        => '<!-- O texto aqui disponibilizado será exibido abaixo dos formulários de edição e de envio de ficheiros. -->',
 'nocreatetitle'                    => 'A criação de páginas encontra-se limitada',
 'nocreatetext'                     => '{{SITENAME}} tem restringida a habilidade de criar novas páginas.
-Pode voltar atrás e editar uma página já existente, ou [[Special:Userlogin|autenticar-se ou criar uma conta]].',
+Pode voltar atrás e editar uma página já existente, ou [[Special:UserLogin|autenticar-se ou criar uma conta]].',
 'nocreate-loggedin'                => 'Você não possui permissões de criar novas páginas neste wiki.',
 'permissionserrors'                => 'Erros de permissões',
 'permissionserrorstext'            => 'Você não possui permissão de fazer isso, {{PLURAL:$1|pelo seguinte motivo|pelos seguintes motivos}}:',
@@ -884,7 +881,7 @@
 # Suppression log
 'suppressionlog'     => 'Registo de supressões',
 'suppressionlogtext' => 'Abaixo está uma lista das remoções e bloqueios envolvendo conteúdo ocultado por administradores.
-Veja a [[Special:Ipblocklist|lista de bloqueios]] para uma lista de banimentos e bloqueios em efeito neste momento.',
+Veja a [[Special:IPBlockList|lista de bloqueios]] para uma lista de banimentos e bloqueios em efeito neste momento.',
 
 # History merging
 'mergehistory'                     => 'Fundir histórico de páginas',
@@ -968,7 +965,7 @@
 'mypreferences'            => 'Minhas preferências',
 'prefs-edits'              => 'Número de edições:',
 'prefsnologin'             => 'Não autenticado',
-'prefsnologintext'         => 'Precisa estar [[Special:Userlogin|autenticado]] para definir suas preferências.',
+'prefsnologintext'         => 'Precisa estar [[Special:UserLogin|autenticado]] para definir suas preferências.',
 'prefsreset'               => 'As preferências foram restauradas tal como se encontravam na base de dados.',
 'qbsettings'               => 'Barra Rápida',
 'qbsettings-none'          => 'Nenhuma',
@@ -1042,7 +1039,7 @@
 'userrights-reason'           => 'Motivo de alterações:',
 'userrights-no-interwiki'     => 'Você não tem permissão de alterar privilégios de utilizadores em outras wikis.',
 'userrights-nodatabase'       => 'A base de dados $1 não existe ou não é uma base de dados local.',
-'userrights-nologin'          => 'Você precisa [[Special:Userlogin|autenticar-se]] como um administrador para especificar os privilégios de utilizador.',
+'userrights-nologin'          => 'Você precisa [[Special:UserLogin|autenticar-se]] como um administrador para especificar os privilégios de utilizador.',
 'userrights-notallowed'       => 'Sua conta não possui permissão para conceder privilégios a utilizadores.',
 'userrights-changeable-col'   => 'Grupos que pode alterar',
 'userrights-unchangeable-col' => 'Grupos que não pode alterar',
@@ -1172,12 +1169,12 @@
 'reupload'                    => 'Re-enviar',
 'reuploaddesc'                => 'Cancelar o envio e retornar ao formulário de upload',
 'uploadnologin'               => 'Não autenticado',
-'uploadnologintext'           => 'Você necessita estar [[Special:Userlogin|autenticado]] para enviar ficheiros.',
+'uploadnologintext'           => 'Você necessita estar [[Special:UserLogin|autenticado]] para enviar ficheiros.',
 'upload_directory_missing'    => 'A directoria de carregamentos ($1) está em falta e não pôde ser criada pelo webserver.',
 'upload_directory_read_only'  => 'O directório de recebimento de ficheiros ($1) não tem permissões de escrita para o servidor Web.',
 'uploaderror'                 => 'Erro ao carregar',
 'uploadtext'                  => "Utilize o formulário abaixo para carregar novos ficheiros.
-Para ver ou pesquisar imagens anteriormente carregadas consulte a [[Special:Imagelist|lista de ficheiros carregados]]. Carregamentos e eliminações são também registados no [[Special:Log|registo do projecto]].
+Para ver ou pesquisar imagens anteriormente carregadas consulte a [[Special:ImageList|lista de ficheiros carregados]]. Carregamentos e eliminações são também registados no [[Special:Log|registo do projecto]].
 
 Para incluír a imagem numa página, utilize o link na forma de
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:ficheiro.jpg]]</nowiki>''',
@@ -1277,7 +1274,7 @@
 'upload_source_url'  => ' (um URL válido, publicamente acessível)',
 'upload_source_file' => ' (um ficheiro no seu computador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Esta página especial mostra todos os ficheiros carregados.
 Por defeito, os últimos ficheiros carregados são mostrados no topo da lista.
 Um clique sobre um cabeçalho de coluna altera a ordenação.',
@@ -1305,7 +1302,7 @@
 'imagelinks'                     => 'Ligações',
 'linkstoimage'                   => '{{PLURAL:$1|A seguinte página aponta|As seguintes $1 páginas apontam}} para este ficheiro:',
 'nolinkstoimage'                 => 'Nenhuma página aponta para este ficheiro.',
-'morelinkstoimage'               => 'Ver [[Special:Whatlinkshere/$1|mais ligações]] para este ficheiro.',
+'morelinkstoimage'               => 'Ver [[Special:WhatLinksHere/$1|mais ligações]] para este ficheiro.',
 'redirectstofile'                => '{{PLURAL:$1|O seguinte ficheiro redirecciona|Os seguintes ficheiros redireccionam}} para este ficheiro:',
 'duplicatesoffile'               => '{{PLURAL:$1|O seguinte ficheiro é duplicado|Os seguintes ficheiros são duplicados}} deste ficheiro:',
 'sharedupload'                   => 'Este ficheiro encontra-se partilhado e pode ser utilizado por outros projectos.',
@@ -1335,7 +1332,7 @@
 'filedelete'                  => 'Eliminar $1',
 'filedelete-legend'           => 'Eliminar ficheiro',
 'filedelete-intro'            => "Você está prestes a eliminar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Você se encontra prestes a eliminar a versão de \'\'\'[[Media:$1|$1]]\'\'\' tal como se encontrava em [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Você se encontra prestes a eliminar a versão de '''[[Media:$1|$1]]''' tal como se encontrava em [$4 $3, $2].",
 'filedelete-comment'          => 'Motivo de eliminação:',
 'filedelete-submit'           => 'Eliminar',
 'filedelete-success'          => "'''$1''' foi eliminado.",
@@ -1396,8 +1393,10 @@
 'disambiguations-text' => "As páginas a seguir ligam a \"''páginas de desambiguação''\" ao invés de aos tópicos adequados.<br /> 
 Uma página é considerada como de desambiguação se utilizar uma predefinição que esteja definida em [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redireccionamentos duplos',
-'doubleredirectstext' => 'Cada linha contém ligações para o primeiro e segundo redireccionamento, bem como a primeira linha de conteúdo do segundo redireccionamento, geralmente contendo a página destino "real", que devia ser o destino do primeiro redireccionamento.',
+'doubleredirects'            => 'Redireccionamentos duplos',
+'doubleredirectstext'        => 'Cada linha contém ligações para o primeiro e segundo redireccionamento, bem como a primeira linha de conteúdo do segundo redireccionamento, geralmente contendo a página destino "real", que devia ser o destino do primeiro redireccionamento.',
+'double-redirect-fixed-move' => '[[$1]] foi movido, passando a redirecionar para [[$2]]',
+'double-redirect-fixer'      => 'Corretor de redirecionamentos',
 
 'brokenredirects'        => 'Redireccionamentos quebrados',
 'brokenredirectstext'    => 'Os seguintes redireccionamentos ligam para páginas inexistentes:',
@@ -1483,7 +1482,7 @@
 'logempty'             => 'Nenhum item idêntico no registo.',
 'log-title-wildcard'   => 'Procurar por títulos que sejam iniciados com o seguinte texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Todas as páginas',
 'alphaindexline'    => '$1 até $2',
 'nextpage'          => 'Próxima página ($1)',
@@ -1506,12 +1505,12 @@
 'special-categories-sort-count' => 'ordenar por contagem',
 'special-categories-sort-abc'   => 'ordenar alfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostrar utilizadores começando em:',
 'listusers-submit'   => 'Exibir',
 'listusers-noresult' => 'Não foram encontrados utilizadores para a forma pesquisada.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Privilégios de grupo de utilizadores',
 'listgrouprights-summary'  => 'A seguinte lista contém os grupos de utilizadores definidos neste wiki, com os seus privilégios de acessos associados.
 Informação adicional sobre direitos individuais pode ser encontrada [[{{MediaWiki:Listgrouprights-helppage}}|aqui]].',
@@ -1522,7 +1521,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nenhum endereço de envio',
-'mailnologintext' => 'Necessita de estar [[Special:Userlogin|autenticado]] e de possuir um endereço de e-mail válido nas suas [[Special:Preferences|preferências]] para poder enviar um e-mail a outros utilizadores.',
+'mailnologintext' => 'Necessita de estar [[Special:UserLogin|autenticado]] e de possuir um endereço de e-mail válido nas suas [[Special:Preferences|preferências]] para poder enviar um e-mail a outros utilizadores.',
 'emailuser'       => 'Contactar este utilizador',
 'emailpage'       => 'Contactar utilizador',
 'emailpagetext'   => 'Se o utilizador introduziu um endereço válido de e-mail
@@ -1551,10 +1550,10 @@
 'nowatchlist'          => 'A sua lista de vigiados não possui títulos.',
 'watchlistanontext'    => 'Por favor $1 para ver ou editar os itens na sua lista de artigos vigiados.',
 'watchnologin'         => 'Não está autenticado',
-'watchnologintext'     => 'Você precisa estar [[Special:Userlogin|autenticado]] para modificar a sua lista de artigos vigiados.',
+'watchnologintext'     => 'Você precisa estar [[Special:UserLogin|autenticado]] para modificar a sua lista de artigos vigiados.',
 'addedwatch'           => 'Adicionado à lista',
 'addedwatchtext'       => "A página \"[[:\$1]]\" foi adicionada à sua [[Special:Watchlist|lista de vigiados]].
-Modificações futuras em tal página e páginas de discussão a ela associadas serão listadas lá, com a página aparecendo a '''negrito''' na [[Special:Recentchanges|lista de mudanças recentes]], para que possa encontrá-la com maior facilidade.",
+Modificações futuras em tal página e páginas de discussão a ela associadas serão listadas lá, com a página aparecendo a '''negrito''' na [[Special:RecentChanges|lista de mudanças recentes]], para que possa encontrá-la com maior facilidade.",
 'removedwatch'         => 'Removida da lista de artigos vigiados',
 'removedwatchtext'     => 'A página "<nowiki>$1</nowiki>" foi removida de sua lista de artigos vigiados.',
 'watch'                => 'Vigiar',
@@ -1669,7 +1668,7 @@
 Experimente usar o botão "Voltar" e refrescar a página de onde veio e tente novamente.',
 'protectlogpage'              => 'Registo de protecção',
 'protectlogtext'              => 'Abaixo encontra-se o registo de protecção e desprotecção de páginas.
-Veja a [[Special:Protectedpages|lista de páginas protegidas]] para uma listagem das páginas que se encontram protegidas no momento.',
+Veja a [[Special:ProtectedPages|lista de páginas protegidas]] para uma listagem das páginas que se encontram protegidas no momento.',
 'protectedarticle'            => 'protegeu "[[$1]]"',
 'modifiedarticleprotection'   => 'foi alterado o nível de protecção para "[[$1]]"',
 'unprotectedarticle'          => 'desprotegeu "[[$1]]"',
@@ -1830,7 +1829,7 @@
 'badipaddress'                    => 'Endereço de IP inválido',
 'blockipsuccesssub'               => 'Bloqueio bem sucedido',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] foi bloqueado.<br />
-Consulte a [[Special:Ipblocklist|lista de IPs bloqueados]] para rever os bloqueios.',
+Consulte a [[Special:IPBlockList|lista de IPs bloqueados]] para rever os bloqueios.',
 'ipb-edit-dropdown'               => 'Editar motivos de bloqueio',
 'ipb-unblock-addr'                => 'Desbloquear $1',
 'ipb-unblock'                     => 'Desbloquear um utilizador ou endereço de IP',
@@ -1862,7 +1861,7 @@
 'blocklogentry'                   => '"[[$1]]" foi bloqueado com um tempo de expiração de $2 $3',
 'blocklogtext'                    => 'Este é um registo de acções de bloqueio e desbloqueio.
 Endereços IP sujeitos a bloqueio automático não são listados.
-Consulte a [[Special:Ipblocklist|lista de IPs bloqueados]] para obter a lista de bloqueios e banimentos actualmente válidos.',
+Consulte a [[Special:IPBlockList|lista de IPs bloqueados]] para obter a lista de bloqueios e banimentos actualmente válidos.',
 'unblocklogentry'                 => 'desbloqueou $1',
 'block-log-flags-anononly'        => 'apenas utilizadores anónimos',
 'block-log-flags-nocreate'        => 'criação de contas desabilitada',
@@ -1920,8 +1919,6 @@
 
 Nestes casos, você terá que mover ou mesclar a página manualmente, se assim desejar.",
 'movearticle'             => 'Mover página',
-'movenologin'             => 'Não autenticado',
-'movenologintext'         => 'Você precisa ser um utilizador registado e [[Special:Userlogin|autenticado]] para poder mover uma página.',
 'movenotallowed'          => 'Você não possui permissão de mover páginas neste wiki.',
 'newtitle'                => 'Para novo título',
 'move-watch'              => 'Vigiar esta página',
@@ -1948,7 +1945,7 @@
 'revertmove'              => 'reverter',
 'delete_and_move'         => 'Eliminar e mover',
 'delete_and_move_text'    => '==Eliminação necessária==
-A página de destino ("[[$1]]") já existe. Deseja eliminá-la de modo a poder mover?',
+A página de destino ("[[:$1]]") já existe. Deseja eliminá-la de modo a poder mover?',
 'delete_and_move_confirm' => 'Sim, eliminar a página',
 'delete_and_move_reason'  => 'Eliminada para poder mover outra página para este título',
 'selfmove'                => 'O título fonte e o título destinatário são os mesmos; não é possível mover uma página para ela mesma.',
@@ -1956,6 +1953,7 @@
 'imagenocrossnamespace'   => 'Não é possível mover imagem para espaço nominal que não de imagens',
 'imagetypemismatch'       => 'A extensão do novo ficheiro não corresponde ao seu tipo',
 'imageinvalidfilename'    => 'O nome do ficheiro alvo é inválido',
+'fix-double-redirects'    => 'Atualizar todos os redirecionamentos que apontem para o título original',
 
 # Export
 'export'            => 'Exportação de páginas',
@@ -2183,10 +2181,10 @@
 'show-big-image'       => 'Resolução completa',
 'show-big-image-thumb' => '<small>Tamanho desta previsão: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria de novos ficheiros',
 'imagelisttext'         => "É exibida a seguir uma listagem {{PLURAL:$1|de '''um''' ficheiro organizado|de '''$1''' ficheiros organizados}} por $2.",
-'newimages-summary'     => 'Esta página especial mostra os ficheiros mais recentemente enviados',
+'newimages-summary'     => 'Esta página especial mostra os ficheiros mais recentemente enviados.',
 'showhidebots'          => '($1 robôs)',
 'noimages'              => 'Nada para ver.',
 'ilsubmit'              => 'Procurar',
@@ -2466,7 +2464,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar este ficheiro utilizando uma aplicação externa',
-'edit-externally-help' => 'Consulte as [http://meta.wikimedia.org/wiki/Help:External_editors instruções de instalação] para mais informação.',
+'edit-externally-help' => 'Consulte as [http://www.mediawiki.org/wiki/Manual:External_editors instruções de instalação] para mais informação.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'todas',
@@ -2535,7 +2533,7 @@
 'recreate'            => 'Recriar',
 
 # HTML dump
-'redirectingto' => 'Redireccionando para [[$1]]...',
+'redirectingto' => 'Redireccionando para [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Limpar a memória cache desta página?
@@ -2634,7 +2632,7 @@
 'version-software-product'         => 'Produto',
 'version-software-version'         => 'Versão',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Diretório do ficheiro',
 'filepath-page'    => 'Ficheiro:',
 'filepath-submit'  => 'Diretório',
@@ -2672,7 +2670,7 @@
 'specialpages-group-redirects'   => 'Páginas especias redirecionadoras',
 'specialpages-group-spam'        => 'Ferramentas anti-spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Página em branco',
 'intentionallyblankpage' => 'Esta página foi intencionalmente deixada em branco e é usada para medições de performance, etc.',
 
Index: languages/messages/MessagesTs.php
===================================================================
--- languages/messages/MessagesTs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -141,7 +141,7 @@
 'nosuchspecialpage' => 'Ku hava Tluka rero rohlawuleka',
 'nospecialpagetext' => "<big>'''U kombele tluka ro hlawuleka ro ka ri nga ri kona.'''</big>
 
-Vona nxaxamelo wa ma tluka yo hlawuleka e [[Special:Specialpages|{{int:specialpages}}]].",
+Vona nxaxamelo wa ma tluka yo hlawuleka e [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Xihoxo',
@@ -272,7 +272,7 @@
 # Upload
 'upload' => 'Khandziyisa fayili',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'fayili',
 'imagelist'      => 'Nxaxamelo wa tifayili',
 'imagelist_date' => 'Siku',
@@ -292,7 +292,7 @@
 # Special:Log
 'specialloguserlabel' => 'Mutirhisi:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'    => 'Matluka hinkwawo',
 'allarticles' => 'Matluka hinkwawo',
 
Index: languages/messages/MessagesLmo.php
===================================================================
--- languages/messages/MessagesLmo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLmo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,18 +4,16 @@
  * @ingroup Language
  * @file
  *
+ * @author Amgine
+ * @author Clamengh
  * @author Dakrismeno
- * @author SPQRobin
- * @author SabineCretella
- * @author Malafaya
- * @author Siebrand
- * @author Kemmótar
+ * @author DracoRoboter
  * @author Flavio05
- * @author Clamengh
- * @author Snowdog
- * @author Amgine
+ * @author Kemmótar
+ * @author Malafaya
  * @author Remulazz
- * @author DracoRoboter
+ * @author SabineCretella
+ * @author Snowdog
  */
 
 $fallback = 'it';
@@ -200,7 +198,7 @@
 'showdiff'             => 'Famm vedè i cambiament',
 'anoneditwarning'      => 'Tì te set minga entraa. In de la crunulugia de la pagina se vedarà el tò IP.',
 'accmailtext'          => 'La parola d\'urdin per "$1" l\'è stada mandada a $2.',
-'anontalkpagetext'     => "----''Questa chì l'è la pagina de discüssiun de un ütent che l'ha minga ammò registraa un cünt, upür che el vör minga duperàll; dunca, el pò vess identificaa dumà cunt el sò IP, ch'el pò vess spartii tra tanti ütent diferent. Se ti te set un ütent anonim e t'hee vist un quai messacc ch'el te par ch'el gh'entra nagott cun tì, pröva a [[Special:Userlogin|creà el tò cünt]] per fà pü casott.''",
+'anontalkpagetext'     => "----''Questa chì l'è la pagina de discüssiun de un ütent che l'ha minga ammò registraa un cünt, upür che el vör minga duperàll; dunca, el pò vess identificaa dumà cunt el sò IP, ch'el pò vess spartii tra tanti ütent diferent. Se ti te set un ütent anonim e t'hee vist un quai messacc ch'el te par ch'el gh'entra nagott cun tì, pröva a [[Special:UserLogin|creà el tò cünt]] per fà pü casott.''",
 'noarticletext'        => "Gh'è minga del test in quella pagina chì. Te pòdet [[Special:Search/{{PAGENAME}}|cercà in d'on'altra pagina]] oppur [{{fullurl:{{FULLPAGENAME}}|action=edit}} creàla tì].",
 'clearyourcache'       => "'''Nòta:''' dòpu che avii salvaa, pudaría véss neçessari de scancelá la memòria \"cache\" dal vòst prugráma də navigazziún in reet par vidé i mudifich faa. '''Mozilla / Firefox / Safari:''' tegní schiscjaa al butún ''Shift'' intaant che sə clica ''Reload'', upüür schiscjá ''Ctrl-Shift-R'' (''Cmd-Shift-R'' sül Apple Mac); '''IE:''' schiscjá ''Ctrl'' intaant che sə clica ''Refresh'', upüür schiscjá ''Ctrl-F5''; '''Konqueror:''': semplicemeent clicá al butún ''Reload'', upüür schiscjá ''F5''; '''Opera''' i üteent pudarían vech büsögn da scancelá cumpletameent la memòria \"cache\" in ''Tools&rarr;Preferences''.",
 'previewnote'          => "<strong>'''Atenziun'''! Questa pagina la serviss dumà de vardà. I cambiament hinn minga staa salvaa.</strong>",
@@ -276,7 +274,7 @@
 'userrights-reason'        => 'Motivo della modifica:',
 'userrights-no-interwiki'  => 'Non si dispone dei permessi necessari per modificare i diritti degli utenti su altri siti.',
 'userrights-nodatabase'    => 'Il database $1 non esiste o non è un database locale.',
-'userrights-nologin'       => "Per assegnare diritti agli utenti è necessario [[Special:Userlogin|effettuare l'accesso]] come amministratore.",
+'userrights-nologin'       => "Per assegnare diritti agli utenti è necessario [[Special:UserLogin|effettuare l'accesso]] come amministratore.",
 'userrights-notallowed'    => "L'utente non dispone dei permessi necessari per assegnare diritti agli utenti.",
 
 # Recent changes
@@ -307,7 +305,7 @@
 'sourcefilename'    => "Nomm da l'archivi surgeent:",
 'destfilename'      => "Nomm da l'archivi da destinazziun:",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Listá i imàgin',
 
 # Image description page
@@ -366,7 +364,7 @@
 'speciallogtitlelabel' => 'Titul:',
 'logempty'             => "El log l'è vöj.",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Tücc i pagin',
 'allpagesfrom'   => 'Famm vedè i pagin a partì de:',
 'allarticles'    => 'Tütt i vus',
@@ -387,7 +385,7 @@
 'addedwatchtext'   => "La pagina \"[[:\$1]]\" l'è staja gjüntava a la lista dii [[Special:Watchlist|paginn da tegn d'öcc]].
 I cambiameent che i vegnará fai a chesta pagina chi e a la sóa pagina dii cumünicazziún
 i vegnará segnalaa chichinscí e la pagina la sa vedará cun caráter '''spèss''' in la
-[[Special:Recentchanges|lista dii cambiameent reçeent]] gjüst par evidenziála.
+[[Special:RecentChanges|lista dii cambiameent reçeent]] gjüst par evidenziála.
 <p>Se ti vörat tirá via chesta pagina chi dala lista dai paginn da tegn d'öcc ti pòdat schiscjá
 al butún \"tegn piü d'öcc\".",
 'removedwatch'     => 'Scancelaa dala lista di usservazziún.',
@@ -506,13 +504,13 @@
 'imagemaxsize' => 'Limitá i imagin süi pagin da descrizziún dii imagin a:',
 'thumbsize'    => 'Dimensiún diapusitiif:',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Espusizziun di imàgin nööf',
 'ilsubmit'  => 'Truvá',
 
 # External editor support
 'edit-externally'      => 'Redatá chest archivi cunt un prugramari da fö',
-'edit-externally-help' => 'Vidé i [http://meta.wikimedia.org/wiki/Help:External_editors istrüzziún] pər vech püssè infurmazziún (in Inglees).',
+'edit-externally-help' => 'Vidé i [http://www.mediawiki.org/wiki/Manual:External_editors istrüzziún] pər vech püssè infurmazziún (in Inglees).',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tücc',
@@ -536,7 +534,7 @@
 # Special:Version
 'version' => 'Versiun', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'Percuurz daj archivi',
 
 # Special:SpecialPages
Index: languages/messages/MessagesAst.php
===================================================================
--- languages/messages/MessagesAst.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAst.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Esbardu
  * @author Mikel
- * @author SPQRobin
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -326,7 +324,7 @@
 'nosuchspecialpage' => 'Nun esiste esa páxina especial',
 'nospecialpagetext' => "<big>'''Pidisti una páxina especial non válida.'''</big>
 
-Pues consultar la llista de les páxines especiales válides en [[Special:Specialpages|{{int:specialpages}}]].",
+Pues consultar la llista de les páxines especiales válides en [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -356,8 +354,8 @@
 
 Esto débese davezu a siguir una dif caducada o un enllaz d'historial a una páxina que foi borrada.
 
-Si ésti nun ye'l casu, seique tengas atopao un bug nel software.
-Por favor informa d'esto a un alministrador, anotando la URL.",
+Si esti nun ye'l casu, seique tengas atopao un bug nel software.
+Por favor informa d'esto a un [[Special:ListUsers/sysop|alministrador]], anotando la URL.",
 'missingarticle-rev'   => '(revisión: $1)',
 'missingarticle-diff'  => '(dif: $1, $2)',
 'readonly_lag'         => 'La base de datos foi protexida automáticamente mentes los servidores de la base de datos esclava se sincronicen cola maestra',
@@ -406,11 +404,12 @@
 # Login and logout pages
 'logouttitle'                => 'Desconexón',
 'logouttext'                 => "<strong>Yá tas desconectáu.</strong><br />
-Pues siguir usando {{SITENAME}} de forma anónima, o pues volver a entrar como'l mesmu o como otru usuariu.
+
+Pues siguir usando {{SITENAME}} de forma anónima, o pues [[Special:UserLogin|volver a entrar]] como'l mesmu o como otru usuariu.
 Ten en cuenta que dalgunes páxines van continuar saliendo como si tovía tuvieres coneutáu, hasta que llimpies la caché del navegador.",
 'welcomecreation'            => "== Bienveníu, $1! ==
-
-La to cuenta ta creada. Nun t'escaezas d'escoyer les tos preferencies de {{SITENAME}}.",
+La to cuenta ta creada.
+Nun t'escaezas d'escoyer les tos [[Special:Preferences|preferencies de {{SITENAME}}]].",
 'loginpagetitle'             => "Identificación d'usuariu",
 'yourname'                   => "Nome d'usuariu:",
 'yourpassword'               => 'Clave:',
@@ -443,7 +442,8 @@
 'yourvariant'                => 'Variante llingüística:',
 'yournick'                   => 'Firma:',
 'badsig'                     => 'Firma cruda non válida; comprueba les etiquetes HTML.',
-'badsiglength'               => 'Nomatu demasiao llargu; ha tener menos de $1 carauteres.',
+'badsiglength'               => 'El nomatu ye demasiao llargu.
+Ha tener menos de $1 {{PLURAL:$1|caráuter|carauteres}}.',
 'email'                      => 'Corréu',
 'prefs-help-realname'        => "El nome real ye opcional y si decides conseñalu va ser usáu p'atribuyite'l to trabayu.",
 'loginerror'                 => "Error d'identificación",
@@ -548,7 +548,8 @@
 'blockedtitle'                     => "L'usuariu ta bloquiáu",
 'blockedtext'                      => "<big>'''El to nome d'usuariu o la to direición IP foi bloquiáu.'''</big>
 
-El bloquéu féxolu $1. El motivu conseñáu ye ''$2''.
+El bloquéu féxolu $1.
+El motivu conseñáu ye ''$2''.
 
 * Entamu del bloquéu: $8
 * Caducidá del bloquéu: $6
@@ -557,30 +558,28 @@
 Pues ponete en contautu con $1 o con cualesquier otru [[{{MediaWiki:Grouppage-sysop}}|alministrador]] pa discutir el bloquéu.
 Nun pues usar la funcionalidá 'manda-y un email a esti usuariu' a nun ser que tea especificada una direición de corréu válida
 na to [[Special:Preferences|páxina de preferencies]] y que nun te tengan bloquiao el so usu.
-La to direición IP actual ye $3, y el númberu d'identificación del bloquéu ye $5. Por favor, amiesta dalgún o dambos d'estos datos nes tos consultes.",
-'autoblockedtext'                  => "La to direición IP foi bloquiada automáticamente porque foi usada por otru usuariu que foi bloquiáu por \$1.
+La to direición IP actual ye $3, y el númberu d'identificación del bloquéu ye $5.
+Por favor, amiesta dalgún o dambos d'estos datos nes tos consultes.",
+'autoblockedtext'                  => 'La to direición IP foi bloquiada automáticamente porque foi usada por otru usuariu que foi bloquiáu por $1.
 El motivu conseñáu foi esti:
 
-:''\$2''
+:\'\'$2\'\'
 
-* Entamu del bloquéu: \$8
-* Caducidá del bloquéu: \$6
+* Entamu del bloquéu: $8
+* Caducidá del bloquéu: $6
+* Usuariu que se quier bloquiar: $7
 
-Pues contautar con \$1 o con otru
-[[{{MediaWiki:Grouppage-sysop}}|alministrador]] p'aldericar sobre'l bloquéu.
+Pues ponete en contautu con $1 o con cualesquier otru [[{{MediaWiki:Grouppage-sysop}}|alministrador]] p\'aldericar sobre\'l bloquéu.
 
-Fíxate en que nun pues usar la funcionalidá d'\"unvia-y un corréu a esti usuariu\" a nun se que tengas una direición de corréu válida rexistrada na to [[Special:Preferences|páxina de preferencies]] y que nun teas bloquiáu pa usala.
+Fíxate en que nun pues usar la funcionalidá d\'"unvia-y un corréu a esti usuariu" a nun se que tengas una direición de corréu válida rexistrada na to [[Special:Preferences|páxina de preferencies]] y que nun teas bloquiáu pa usala.
 
-El códigu d'identificación del bloquéu ye'l \$5. Por favor amiesta esti códigu nes consultes que faigas.",
+La to direición IP actual ye $3, y el númberu d\'identificación del bloquéu ye $5.
+Por favor, amiesta toos estos detalles nes consultes que faigas.',
 'blockednoreason'                  => 'nun se dio nengún motivu',
 'blockedoriginalsource'            => "El códigu fonte de '''$1''' amuésase equí:",
 'blockededitsource'                => "El testu de '''les tos ediciones''' en '''$1''' amuésase equí:",
 'whitelistedittitle'               => 'Ye necesario tar identificáu pa poder editar',
 'whitelistedittext'                => 'Tienes que $1 pa editar páxines.',
-'whitelistreadtitle'               => 'Necesítase identificación pa lleer',
-'whitelistreadtext'                => "Tienes que t'[[Special:Userlogin|identificar]] pa lleer páxines.",
-'whitelistacctitle'                => 'Nun tienes permisu pa crear una cuenta',
-'whitelistacctext'                 => 'Pa poder crear cuentes en {{SITENAME}} has tar [[Special:Userlogin|identificáu]] y tener los permisos afayadizos.',
 'confirmedittitle'                 => 'Requerida la confirmación de corréu electrónicu pa editar',
 'confirmedittext'                  => "Has confirmar la to direición de corréu electrónicu enantes d'editar páxines. Por favor, configúrala y valídala nes tos [[Special:Preferences|preferencies d'usuariu]].",
 'nosuchsectiontitle'               => 'Nun esiste tala seición',
@@ -592,7 +591,7 @@
 'accmailtext'                      => 'La clave de "$1" foi unviada a $2.',
 'newarticle'                       => '(Nuevu)',
 'newarticletext'                   => 'Siguisti un enllaz a un artículu qu\'inda nun esiste. Pa crealu, empecipia a escribir na caxa d\'equí embaxo. Si llegasti equí por enquivocu, namás tienes que calcar nel botón "atrás" del to navegador.',
-'anontalkpagetext'                 => "----''Esta ye la páxina de'alderique pa un usuariu anónimu qu'inda nun creó una cuenta o que nun la usa. Pola mor d'ello ha usase la direición numérica IP pa identificalu/la. Tala IP pue ser compartida por varios usuarios. Si yes un usuariu anónimu y notes qu'hai comentarios irrelevantes empobinaos pa ti, por favor [[Special:Userlogin|crea una cuenta o rexístrate]] pa evitar futures confusiones con otros usuarios anónimos.''",
+'anontalkpagetext'                 => "----''Esta ye la páxina de'alderique pa un usuariu anónimu qu'inda nun creó una cuenta o que nun la usa. Pola mor d'ello ha usase la direición numérica IP pa identificalu/la. Tala IP pue ser compartida por varios usuarios. Si yes un usuariu anónimu y notes qu'hai comentarios irrelevantes empobinaos pa ti, por favor [[Special:UserLogin/signup|crea una cuenta]] o [[Special:UserLogin/signup|rexístrate]] pa evitar futures confusiones con otros usuarios anónimos.''",
 'noarticletext'                    => "Nestos momentos nun hai testu nesta páxina. Pues [[Special:Search/{{PAGENAME}}|buscar esti títulu]] n'otres páxines, o [{{fullurl:{{FULLPAGENAME}}|action=edit}} editar ésta equí].",
 'userpage-userdoesnotexist'        => 'La cuenta d\'usuariu "$1" nun ta rexistrada. Por favor asegúrate de que quies crear/editar esta páxina.',
 'clearyourcache'                   => "'''Nota:''' Llueu de salvar, seique tengas que llimpiar la caché del navegador pa ver los cambeos.
@@ -614,7 +613,7 @@
 
 ''Como {{SITENAME}} tien activáu'l HTML puru, la previsualización nun s'amosará como precaución escontra ataques en JavaScript.''
 
-<strong>Si esti ye un intentu llexítimu d'edición, por favor inténtalo otra vuelta. Si tovía asina nun furrula, intenta desconeutate y volver a identificate.</strong>",
+<strong>Si esti ye un intentu llexítimu d'edición, por favor inténtalo otra vuelta. Si tovía asina nun furrula, intenta [[Special:UserLogout|desconeutate]] y volver a identificate.</strong>",
 'token_suffix_mismatch'            => "<strong>La to edición nun foi aceutada porque'l to navegador mutiló los carauteres de puntuación
 nel editor. La edición nun foi aceutada pa prevenir corrupciones na páxina de testu. Esto hai vegaes
 que pasa cuando tas usando un proxy anónimu basáu en web que seya problemáticu.</strong>",
@@ -657,7 +656,7 @@
 'hiddencategories'                 => 'Esta páxina pertenez a {{PLURAL:$1|una categoría oculta|$1 categoríes ocultes}}:',
 'nocreatetitle'                    => 'Creación de páxines limitada',
 'nocreatetext'                     => '{{SITENAME}} tien restrinxida la capacidá de crear páxines nueves.
-Pues volver atrás y editar una páxina esistente, o bien [[Special:Userlogin|identificate o crear una cuenta]].',
+Pues volver atrás y editar una páxina esistente, o bien [[Special:UserLogin|identificate o crear una cuenta]].',
 'nocreate-loggedin'                => 'Nun tienes permisu pa crear páxines nueves en {{SITENAME}}.',
 'permissionserrors'                => 'Errores de Permisos',
 'permissionserrorstext'            => 'Nun tienes permisu pa facer eso {{PLURAL:$1|pol siguiente motivu|polos siguientes motivos}}:',
@@ -683,7 +682,7 @@
 'undo-success' => "La edición pue esfacese. Por favor comprueba la comparanza d'embaxo pa verificar que ye eso lo que quies facer, y depués guarda los cambeos p'acabar d'esfacer la edición.",
 'undo-failure' => "Nun se pudo esfacer la edición pola mor d'ediciones intermedies conflictives.",
 'undo-norev'   => 'Nun se pudo esfacer la edición porque nun esiste o foi eliminada.',
-'undo-summary' => 'Esfecha la revisión $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|alderique]])',
+'undo-summary' => 'Esfecha la revisión $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|alderique]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Nun se pue crear la cuenta',
@@ -779,7 +778,7 @@
 # Suppression log
 'suppressionlog'     => 'Rexistru de supresiones',
 'suppressionlogtext' => "Embaxo amuésase una llista de los borraos y bloqueos rellacionaos con conteníu ocultu a los alministradores.
-Mira'l [[Special:Ipblocklist|rexistru de bloqueos d'IP]] pa ver una llista de los bloqueos activos anguaño.",
+Mira'l [[Special:IPBlockList|rexistru de bloqueos d'IP]] pa ver una llista de los bloqueos activos anguaño.",
 
 # History merging
 'mergehistory'                     => 'Fusionar historiales de páxina',
@@ -862,7 +861,7 @@
 'mypreferences'            => 'Les mios preferencies',
 'prefs-edits'              => "Númberu d'ediciones:",
 'prefsnologin'             => 'Non identificáu',
-'prefsnologintext'         => 'Necesites tar [[Special:Userlogin|identificáu]] pa poder camudar les preferencies.',
+'prefsnologintext'         => 'Necesites tar [[Special:UserLogin|identificáu]] pa poder camudar les preferencies.',
 'prefsreset'               => 'Les preferencies fueron restablecíes a los valores por defeutu.',
 'qbsettings'               => 'Barra rápida',
 'qbsettings-none'          => 'Nenguna',
@@ -936,7 +935,7 @@
 'userrights-reason'           => 'Motivu del cambéu:',
 'userrights-no-interwiki'     => "Nun tienes permisu pa editar los derechos d'usuariu n'otres wikis.",
 'userrights-nodatabase'       => 'La base de datos $1 nun esiste o nun ye llocal.',
-'userrights-nologin'          => "Has tar [[Special:Userlogin|identificáu]] con una cuenta d'alministrador p'asignar derechos d'usuariu.",
+'userrights-nologin'          => "Has tar [[Special:UserLogin|identificáu]] con una cuenta d'alministrador p'asignar derechos d'usuariu.",
 'userrights-notallowed'       => "La to cuenta nun tien permisos p'asignar derechos d'usuariu.",
 'userrights-changeable-col'   => 'Grupos que pues camudar',
 'userrights-unchangeable-col' => 'Grupos que nun pues camudar',
@@ -1065,23 +1064,24 @@
 'reupload'                    => 'Volver a xubir',
 'reuploaddesc'                => 'Cancelar la xubida y tornar al formulariu de xubíes',
 'uploadnologin'               => 'Nun tas identificáu',
-'uploadnologintext'           => 'Tienes que tar [[Special:Userlogin|identificáu]] pa poder xubir archivos.',
+'uploadnologintext'           => 'Tienes que tar [[Special:UserLogin|identificáu]] pa poder xubir archivos.',
 'upload_directory_missing'    => 'El direutoriu de xubida ($1) nun esiste y nun pudo ser creáu pol servidor de web.',
 'upload_directory_read_only'  => "El servidor nun pue modificar el direutoriu de xubida d'archivos ($1).",
 'uploaderror'                 => 'Error de xubida',
 'uploadtext'                  => "Usa'l formulariu d'abaxo pa xubir archivos.
-Pa ver o buscar archivos xubíos previamente, vete a la [[Special:Imagelist|llista d'archivos xubíos]]. Les xubíes y los borraos tamién queden conseñaos nel [[Special:Log/upload|rexistru de xubíes]].
+Pa ver o buscar archivos xubíos previamente, vete a la [[Special:ImageList|llista d'archivos xubíos]]. Les xubíes tamién queden conseñaos nel [[Special:Log/upload|rexistru de xubíes]], y los borraos nel [[Special:Log/delete|rexistru de borraos]].
 
-P'amiestar un archivu nuna páxina, usa un enllaz col formatu
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivu.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivu.png|testu alternativu]]</nowiki>''' o
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Archivu.ogg]]</nowiki>''' pa enllazar direutamente al archivu.",
+P'amiestar un archivu nuna páxina, usa un enllaz con ún de los siguientes formatos:
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivu.jpg]]</nowiki></tt>''' pa usar la versión completa del archivu
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Archivu.png|200px|thumb|left|testu alternativu]]</nowiki></tt>''' pa usar un renderizáu de 200 píxeles d'anchu nun caxellu al marxe esquierdu con 'testu alternativu' como la so descripción
+*'''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Archivu.ogg]]</nowiki></tt>''' pa enllazar direutamente al archivu ensin amosar l'archivu",
 'upload-permitted'            => "Menes d'archivu permitíes: $1.",
 'upload-preferred'            => "Menes d'archivu preferíes: $1.",
 'upload-prohibited'           => "Menes d'archivu prohibíes: $1.",
 'uploadlog'                   => 'rexistru de xubíes',
 'uploadlogpage'               => 'Rexistru de xubíes',
-'uploadlogpagetext'           => "Abaxo amuésase una llista de les xubíes d'archivos más recientes.",
+'uploadlogpagetext'           => "Abaxo amuésase una llista de les xubíes d'archivos más recientes.
+Mira la [[Special:NewImages|galería d'archivos nuevos]] pa una güeyada más visual.",
 'filename'                    => "Nome d'archivu",
 'filedesc'                    => 'Resume',
 'fileuploadsummary'           => 'Resume:',
@@ -1140,9 +1140,12 @@
 'upload-proto-error'      => 'Protocolu incorreutu',
 'upload-proto-error-text' => "La xubida remota requier que l'URL entame por <code>http://</code> o <code>ftp://</code>.",
 'upload-file-error'       => 'Error internu',
-'upload-file-error-text'  => 'Hebo un error al intentar crear un archivu temporal nel servidor. Por favor contauta con un alministrador del sistema.',
+'upload-file-error-text'  => 'Hebo un error al intentar crear un archivu temporal nel servidor.
+Por favor contauta con un [[Special:ListUsers/sysop|alministrador]] del sistema.',
 'upload-misc-error'       => 'Error de xubida desconocíu',
-'upload-misc-error-text'  => "Hebo un error desconocíu na xubida del archivu. Por favor verifica que l'URL ye válidu y accesible, y inténtalo otra vuelta. Si'l problema persiste, contauta con un alministrador del sistema.",
+'upload-misc-error-text'  => "Hebo un error desconocíu na xubida del archivu.
+Por favor verifica que l'URL ye válidu y accesible, y inténtalo otra vuelta.
+Si'l problema persiste, contauta con un [[Special:ListUsers/sysop|alministrador]] del sistema.",
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Nun se pudo acceder a la URL',
@@ -1156,7 +1159,7 @@
 'upload_source_url'  => ' (una URL válida y accesible públicamente)',
 'upload_source_file' => ' (un archivu del to ordenador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Esta páxina especial amuesa tolos archivos xubíos.
 Por defeutu los caberos archivos xubíos amuésense a lo cimero de la llista.
 Calcando na cabecera d'una columna camúdase l'orde acordies con ella.",
@@ -1184,7 +1187,7 @@
 'imagelinks'                     => 'Enllaces a esta imaxe',
 'linkstoimage'                   => '{{PLURAL:$1|La páxina siguiente enllacia|Les páxines siguientes enllacien}} a esti archivu:',
 'nolinkstoimage'                 => "Nun hai páxines qu'enllacien a esti archivu.",
-'morelinkstoimage'               => 'Ver [[Special:Whatlinkshere/$1|más enllaces]] a esti archivu.',
+'morelinkstoimage'               => 'Ver [[Special:WhatLinksHere/$1|más enllaces]] a esti archivu.',
 'redirectstofile'                => '{{PLURAL:$1|El siguiente archivu redirixe|Los siguientes $1 archivos redirixen}} a esti archivu:',
 'duplicatesoffile'               => "{{PLURAL:$1|El siguiente archivu ye un duplicáu|Los siguientes $1 archivos son duplicaos}} d'esti archivu:",
 'sharedupload'                   => "L'archivu ye una xubida compartida y pue tar siendo usáu por otros proyeutos.",
@@ -1203,18 +1206,18 @@
 # File reversion
 'filerevert'                => 'Revertir $1',
 'filerevert-legend'         => 'Revertir archivu',
-'filerevert-intro'          => '<span class="plainlinks">Tas revirtiendo \'\'\'[[Media:$1|$1]]\'\'\' a la [$4 versión del $3 a les $2].</span>',
+'filerevert-intro'          => "Tas revirtiendo '''[[Media:$1|$1]]''' a la [$4 versión del $3 a les $2].",
 'filerevert-comment'        => 'Comentariu:',
 'filerevert-defaultcomment' => 'Revertida a la versión del $2 a les $1',
 'filerevert-submit'         => 'Revertir',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' foi revertida a la [$4 versión del $3 a les $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' foi revertida a la [$4 versión del $3 a les $2].",
 'filerevert-badversion'     => "Nun hai nenguna versión llocal previa d'esti archivu cola fecha conseñada.",
 
 # File deletion
 'filedelete'                  => 'Borrar $1',
 'filedelete-legend'           => 'borrar archivu',
 'filedelete-intro'            => "Tas borrando '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Tas borrando la versión de \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $3 a les $2].</span>',
+'filedelete-intro-old'        => "Tas borrando la versión de '''[[Media:$1|$1]]''' del [$4 $3 a les $2].",
 'filedelete-comment'          => 'Comentariu:',
 'filedelete-submit'           => 'Borrar',
 'filedelete-success'          => "'''$1''' foi borráu.",
@@ -1268,7 +1271,7 @@
 Esto fai una media de '''\$5''' ediciones per páxina, y '''\$6''' visites per edición.
 
 La [http://www.mediawiki.org/wiki/Manual:Job_queue cola de xeres] ye de '''\$7'''.",
-'userstatstext'          => "Hai {{PLURAL:$1|'''1''' [[Special:Listusers|usuariu]] rexistráu, del|'''$1''' [[Special:Listusers|usuarios]] rexistraos, de los}} que
+'userstatstext'          => "Hai {{PLURAL:$1|'''1''' [[Special:ListUsers|usuariu]] rexistráu, del|'''$1''' [[Special:ListUsers|usuarios]] rexistraos, de los}} que
 '''$2''' (el '''$4%''') {{PLURAL:$2|tien|tienen}} privilexos de $5.",
 'statistics-mostpopular' => 'Páxines más vistes',
 
@@ -1276,8 +1279,10 @@
 'disambiguationspage'  => 'Template:dixebra',
 'disambiguations-text' => "Les siguientes páxines enllacien a una '''páxina de dixebra'''. En cuenta d'ello habríen enllaciar al artículu apropiáu.<br />Una páxina considérase de dixebra si usa una plantía que tea enllaciada dende [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redireiciones dobles',
-'doubleredirectstext' => 'Esta páxina llista páxines que redireicionen a otres páxines de redireición. Cada filera contién enllaces a la primer y segunda redireición, asina como al oxetivu de la segunda redireición, que normalmente ye la páxina oxetivu "real", aonde la primer redireición habría empobinar.',
+'doubleredirects'            => 'Redireiciones dobles',
+'doubleredirectstext'        => 'Esta páxina llista páxines que redireicionen a otres páxines de redireición. Cada filera contién enllaces a la primer y segunda redireición, asina como al oxetivu de la segunda redireición, que normalmente ye la páxina oxetivu "real", aonde la primer redireición habría empobinar.',
+'double-redirect-fixed-move' => '[[$1]] foi treslladáu, agora ye una redireición haza [[$2]]',
+'double-redirect-fixer'      => 'Iguador de redireiciones',
 
 'brokenredirects'        => 'Redireiciones rotes',
 'brokenredirectstext'    => 'Les siguientes redireiciones enllacien a páxines que nun esisten:',
@@ -1362,7 +1367,7 @@
 'logempty'             => 'Nun hai coincidencies nel rexistru.',
 'log-title-wildcard'   => "Buscar títulos qu'emprimen con esti testu",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Toles páxines',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Páxina siguiente ($1)',
@@ -1385,15 +1390,15 @@
 'special-categories-sort-count' => 'ordenar por tamañu',
 'special-categories-sort-abc'   => 'ordenar alfabéticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Amosar usuarios emprimando dende:',
 'listusers-submit'   => 'Amosar',
 'listusers-noresult' => "Nun s'atoparon usuarios.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Drechos de los grupos d'usuariu",
 'listgrouprights-summary'  => "La siguiente ye una llista de grupos d'usuariu definíos nesta wiki, colos sos drechos d'accesu asociaos.
-Pue atopase información adicional tocante a drechos individuales [[{{MediaWiki:Listgrouprights-helppage}}|equí]].",
+Pue haber [[{{MediaWiki:Listgrouprights-helppage}}|información adicional]] tocante a drechos individuales.",
 'listgrouprights-group'    => 'Grupu',
 'listgrouprights-rights'   => 'Drechos',
 'listgrouprights-helppage' => 'Help:Drechos de grupu',
@@ -1401,12 +1406,12 @@
 
 # E-mail user
 'mailnologin'     => "Ensin direición d'unviu",
-'mailnologintext' => 'Has tar [[Special:Userlogin|identificáu]]
+'mailnologintext' => 'Has tar [[Special:UserLogin|identificáu]]
 y tener una direición de corréu válida nes tos [[Special:Preferences|preferencies]]
 pa poder unviar correos a otros usuarios.',
 'emailuser'       => 'Manda-y un email a esti usuariu',
 'emailpage'       => "Corréu d'usuariu",
-'emailpagetext'   => "Si esti usuariu metió una direición de corréu electrónicu válida nes sos preferencies d'usuariu, el formulariu d'embaxo va unviar un mensaxe simple. La direición de corréu electrónicu que metisti nes tos preferencies d'usuariu va apaecer como la direición \"Dende\" del corréu, pa que'l que lo recibe seya quien a responder.",
+'emailpagetext'   => "Si esti usuariu metió una direición de corréu electrónicu válida nes sos preferencies d'usuariu, el formulariu d'embaxo va unviar un mensaxe simple. La direición de corréu electrónicu que metisti [[Special:Preferences|nes tos preferencies d'usuariu]] va apaecer como la direición \"Dende\" del corréu, pa que'l que lo recibe seya quien a responder.",
 'usermailererror' => "L'operador de corréu devolvió un error:",
 'defemailsubject' => 'Corréu electrónicu de {{SITENAME}}',
 'noemailtitle'    => 'Ensin direición de corréu',
@@ -1430,9 +1435,9 @@
 'nowatchlist'          => 'La to llista de vixilancia ta vacia.',
 'watchlistanontext'    => 'Por favor $1 pa ver o editar entraes na to llista de vixilancia.',
 'watchnologin'         => 'Non identificáu',
-'watchnologintext'     => 'Tienes que tar [[Special:Userlogin|identificáu]] pa poder camudar la to llista de vixilancia.',
+'watchnologintext'     => 'Tienes que tar [[Special:UserLogin|identificáu]] pa poder camudar la to llista de vixilancia.',
 'addedwatch'           => 'Añadida a la llista de vixilancia',
-'addedwatchtext'       => 'Añadióse la páxina "[[:$1]]" a la to [[Special:Watchlist|llista de vixilancia]]. Los cambeos nesta páxina y la so páxina d\'alderique asociada van salite en negrina na llista de [[Special:Recentchanges|cambeos recientes]] pa que seya más fácil de vela.
+'addedwatchtext'       => 'Añadióse la páxina "[[:$1]]" a la to [[Special:Watchlist|llista de vixilancia]]. Los cambeos nesta páxina y la so páxina d\'alderique asociada van salite en negrina na llista de [[Special:RecentChanges|cambeos recientes]] pa que seya más fácil de vela.
 
 Si más tarde quies quitala de la llista de vixilancia calca en "Dexar de vixilar" nel menú llateral.',
 'removedwatch'         => 'Eliminada de la llista de vixilancia',
@@ -1537,10 +1542,10 @@
 'rollbacklink'                => 'revertir',
 'rollbackfailed'              => 'Falló la reversión',
 'cantrollback'                => "Nun se pue revertir la edición; el postrer collaborador ye l'únicu autor d'esta páxina.",
-'alreadyrolled'               => 'Nun se pue revertir la postrer edición de [[:$1]]
-fecha por [[User:$2|$2]] ([[User talk:$2|alderique]]); daquién más yá editó o revirtió la páxina.
+'alreadyrolled'               => 'Nun se pue revertir la postrer edición de [[:$1]] fecha por [[User:$2|$2]] ([[User talk:$2|alderique]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
+daquién más yá editó o revirtió la páxina.
 
-La postrer edición foi fecha por [[User:$3|$3]] ([[User talk:$3|alderique]]).',
+La postrer edición foi fecha por [[User:$3|$3]] ([[User talk:$3|alderique]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'El comentariu de la edición yera: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Revertíes les ediciones de [[Special:Contributions/$2|$2]] ([[User talk:$2|alderique]]) hasta la cabera versión de [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Revertíes les ediciones de $1; camudáu a la última versión de $2.',
@@ -1548,7 +1553,7 @@
 cancelóse l\'aición que pidisti. Da-y al botón "Atrás" del
 navegador pa cargar otra vuelta la páxina y vuelve a intentalo.',
 'protectlogpage'              => 'Rexistru de proteiciones',
-'protectlogtext'              => 'Esti ye un rexistru de les páxines protexíes y desprotexíes. Consulta la [[Special:Protectedpages|llista de páxines protexíes]] pa ver les proteiciones actives nestos momentos.',
+'protectlogtext'              => 'Esti ye un rexistru de les páxines protexíes y desprotexíes. Consulta la [[Special:ProtectedPages|llista de páxines protexíes]] pa ver les proteiciones actives nestos momentos.',
 'protectedarticle'            => 'protexó $1',
 'modifiedarticleprotection'   => 'camudó\'l nivel de proteición de "[[$1]]"',
 'unprotectedarticle'          => 'desprotexó "[[$1]]"',
@@ -1667,7 +1672,7 @@
 
 # What links here
 'whatlinkshere'            => "Lo qu'enllaza equí",
-'whatlinkshere-title'      => "Páxines qu'enllacien a $1",
+'whatlinkshere-title'      => 'Páxines qu\'enllacien a "$1"',
 'whatlinkshere-page'       => 'Páxina:',
 'linklistsub'              => "(Llista d'enllaces)",
 'linkshere'                => "Les páxines siguientes enllacien a '''[[:$1]]''':",
@@ -1717,7 +1722,7 @@
 'badipaddress'                    => 'IP non válida',
 'blockipsuccesssub'               => 'Bloquéu fechu correctamente',
 'blockipsuccesstext'              => "Bloquióse al usuariu [[Special:Contributions/$1|$1]].
-<br />Mira na [[Special:Ipblocklist|llista d'IPs bloquiaes]] pa revisar los bloqueos.",
+<br />Mira na [[Special:IPBlockList|llista d'IPs bloquiaes]] pa revisar los bloqueos.",
 'ipb-edit-dropdown'               => 'Editar motivos de bloquéu',
 'ipb-unblock-addr'                => 'Desbloquiar $1',
 'ipb-unblock'                     => "Desbloquiar un nome d'usuariu o direición IP",
@@ -1728,7 +1733,7 @@
 'ipusubmit'                       => 'Desbloquiar esta direición',
 'unblocked'                       => '[[User:$1|$1]] foi desbloquiáu',
 'unblocked-id'                    => 'El bloquéu $1 foi elimináu',
-'ipblocklist'                     => "Llista de direiciones IP y nomes d'usuarios bloquiaos",
+'ipblocklist'                     => "Direiciones IP y nomes d'usuarios bloquiaos",
 'ipblocklist-legend'              => 'Atopar un usuariu bloquiáu',
 'ipblocklist-username'            => "Nome d'usuariu o direición IP:",
 'ipblocklist-submit'              => 'Buscar',
@@ -1749,7 +1754,7 @@
 'blocklogentry'                   => 'bloquió [[$1]] con una caducidá de $2 $3',
 'blocklogtext'                    => "Esti ye un rexistru de los bloqueos y desbloqueos d'usuarios.
 Les direcciones IP bloquiaes automáticamente nun salen equí.
-Pa ver los bloqueos qu'hai agora mesmo, mira na [[Special:Ipblocklist|llista d'IP bloquiaes]].",
+Pa ver los bloqueos qu'hai agora mesmo, mira na [[Special:IPBlockList|llista d'IP bloquiaes]].",
 'unblocklogentry'                 => 'desbloquió $1',
 'block-log-flags-anononly'        => 'namái usuarios anónimos',
 'block-log-flags-nocreate'        => 'creación de cuentes deshabilitada',
@@ -1790,8 +1795,8 @@
 'locknoconfirm'       => 'Nun activasti la caxa de confirmación.',
 'lockdbsuccesssub'    => 'Proteición de la base de datos efeutuáu correutamente',
 'unlockdbsuccesssub'  => 'Eliminada la proteición de la base de datos',
-'lockdbsuccesstext'   => "Protexóse la base de datos.
-<br />Alcuérdate de [[Special:Unlockdb|desprotexela]] depués d'acabar el so mantenimientu.",
+'lockdbsuccesstext'   => "Candóse la base de datos.
+<br />Alcuérdate de [[Special:UnlockDB|descandala]] depués d'acabar el so mantenimientu.",
 'unlockdbsuccesstext' => 'La base de datos foi desprotexida.',
 'lockfilenotwritable' => "L'archivu de proteición de la base de datos nun ye escribible. Pa protexer o desprotexer la base de datos ésti tien que poder ser modificáu pol servidor.",
 'databasenotlocked'   => 'La base de datos nun ta protexida.',
@@ -1799,10 +1804,10 @@
 # Move page
 'move-page'               => 'Treslladar $1',
 'move-page-legend'        => 'Treslladar páxina',
-'movepagetext'            => "Usando'l siguiente formulariu vas renomar una páxina, treslladando'l so historial al nuevu nome. El nome vieyu va convertise nuna
-redireición al nuevu.
-Los enllaces qu'hubiera al nome vieyu nun van camudase;
-asegúrate de que nun dexes redireiciones dobles o rotes.
+'movepagetext'            => "Usando'l siguiente formulariu vas renomar una páxina, treslladando'l so historial al nuevu nome.
+El nome vieyu va convertise nuna redireición al nuevu.
+Pues actualizar redireiciones qu'enllacien al títulu orixinal automáticamente.
+Si prefieres nun lo facer, asegúrate de que nun dexes [[Special:DoubleRedirects|redireiciones dobles]] o [[Special:BrokenRedirects|rotes]].
 Tu yes el responsable de facer que los enllaces queden apuntando aonde se supón qu'han apuntar.
 
 Recuerda que la páxina '''nun''' va movese si yá hai una páxina col nuevu títulu, a nun ser que tea vacia o seya una redireición que nun tenga historial.
@@ -1817,8 +1822,6 @@
 
 Nestos casos vas tener que treslladar o fusionar la páxina manualmente.",
 'movearticle'             => 'Treslladar la páxina:',
-'movenologin'             => 'Non identificáu',
-'movenologintext'         => 'Tienes que ser un usuariu rexistráu y tar [[Special:Userlogin|identificáu]] pa treslladar una páxina.',
 'movenotallowed'          => 'Nun tienes permisu pa mover páxines en {{SITENAME}}.',
 'newtitle'                => 'Al títulu nuevu:',
 'move-watch'              => 'Vixilar esta páxina',
@@ -1845,7 +1848,7 @@
 'delete_and_move'         => 'Borrar y treslladar',
 'delete_and_move_text'    => '==Necesítase borrar==
 
-La páxina de destín "[[$1]]" yá esiste. ¿Quies borrala pa dexar sitiu pal treslláu?',
+La páxina de destín "[[:$1]]" yá esiste. ¿Quies borrala pa dexar sitiu pal treslláu?',
 'delete_and_move_confirm' => 'Sí, borrar la páxina',
 'delete_and_move_reason'  => 'Borrada pa facer sitiu pal treslláu',
 'selfmove'                => "Los nomes d'orixe y destín son los mesmos, nun se pue treslladar una páxina sobre ella mesma.",
@@ -1853,6 +1856,7 @@
 'imagenocrossnamespace'   => "Nun se pue treslladar una imaxe a nun espaciu de nomes que nun ye d'imáxenes",
 'imagetypemismatch'       => 'La estensión nueva del archivu nun concueya cola so mena',
 'imageinvalidfilename'    => 'El nome del archivu oxetivu nun ye válidu',
+'fix-double-redirects'    => 'Actualizar cualesquier redireición que señale al títulu orixinal',
 
 # Export
 'export'            => 'Esportar páxines',
@@ -1903,7 +1907,8 @@
 'import-interwiki-history'   => "Copiar toles versiones d'historial d'esta páxina",
 'import-interwiki-submit'    => 'Importar',
 'import-interwiki-namespace' => 'Tresferir páxines al espaciu de nome:',
-'importtext'                 => "Por favor, esporta l'archivu dende la wiki d'orixe usando la utilidá Especial:Export, guárdalu nel to discu duru y xúbilu equí.",
+'importtext'                 => "Por favor, esporta l'archivu dende la wiki d'orixe usando la [[Special:Export|utilidá d'esportación]].
+Guárdalu nel to ordenador y xúbilu equí.",
 'importstart'                => 'Importando les páxines...',
 'import-revision-count'      => '$1 {{PLURAL:$1|revisión|revisiones}}',
 'importnopages'              => 'Nun hai páxines pa importar.',
@@ -2045,9 +2050,10 @@
 'markedaspatrollederror-noautopatrol' => 'Nun pues marcar los tos propios cambeos como supervisaos.',
 
 # Patrol log
-'patrol-log-page' => 'Rexistru de supervisión',
-'patrol-log-line' => 'marcó la versión $1 de $2 como supervisada $3',
-'patrol-log-auto' => '(automática)',
+'patrol-log-page'   => 'Rexistru de supervisión',
+'patrol-log-header' => 'Esti ye un rexistru de les revisiones supervisaes.',
+'patrol-log-line'   => 'marcó la versión $1 de $2 como supervisada $3',
+'patrol-log-auto'   => '(automática)',
 
 # Image deletion
 'deletedrevision'                 => 'Borrada la reversión vieya $1',
@@ -2076,10 +2082,10 @@
 'show-big-image'       => 'Resolución completa',
 'show-big-image-thumb' => "<small>Tamañu d'esta previsualización: $1 × $2 píxeles</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => "Galería d'imáxenes nueves",
 'imagelisttext'         => "Embaxo ta la llista {{PLURAL:$1|d'un archivu ordenáu|de '''$1''' archivos ordenaos}} $2.",
-'newimages-summary'     => 'Esta páxina especial amuesa los caberos archivos xubíos',
+'newimages-summary'     => 'Esta páxina especial amuesa los caberos archivos xubíos.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Nun hai nada que ver.',
 'ilsubmit'              => 'Buscar',
@@ -2359,7 +2365,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar esti ficheru usando una aplicación externa',
-'edit-externally-help' => 'Pa más información echa un güeyu a les [http://meta.wikimedia.org/wiki/Help:External_editors instrucciones de configuración].',
+'edit-externally-help' => 'Pa más información echa un güeyu a les [http://www.mediawiki.org/wiki/Manual:External_editors instrucciones de configuración].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'toos',
@@ -2431,7 +2437,7 @@
 'recreate'            => 'Volver a crear',
 
 # HTML dump
-'redirectingto' => 'Redireicionando a [[$1]]...',
+'redirectingto' => 'Redireicionando a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "¿Llimpiar la caché d'esta páxina?
@@ -2476,8 +2482,8 @@
 'livepreview-error'   => 'Nun se pudo coneutar: $1 "$2". Intenta la previsualización normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => "Los cambeos de los caberos $1 segundos pue que nun s'amuesen nesta llista.",
-'lag-warn-high'   => "Pol mor d'un importante retrasu del servidor de la base de datos, los cambeos de los caberos $1 segundos pue que nun s'amuesen nesta llista.",
+'lag-warn-normal' => "Los cambeos más recién de $1 {{PLURAL:$|segundu|segundos}} pue que nun s'amuesen nesta llista.",
+'lag-warn-high'   => "Pol mor d'un importante retrasu del servidor de la base de datos, los cambeos más recién de $1 {{PLURAL:$1|segundu|segundos}} pue que nun s'amuesen nesta llista.",
 
 # Watchlist editor
 'watchlistedit-numitems'       => "La to llista de vixilancia tien {{PLURAL:$1|1 títulu|$1 títulos}}, escluyendo les páxines d'alderique.",
@@ -2528,7 +2534,7 @@
 'version-software-product'         => 'Productu',
 'version-software-version'         => 'Versión',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => "Ruta d'archivu",
 'filepath-page'    => 'Archivu:',
 'filepath-submit'  => 'Ruta',
@@ -2566,7 +2572,7 @@
 'specialpages-group-redirects'   => 'Páxines especiales de redireición',
 'specialpages-group-spam'        => 'Ferramientes pa spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Páxina en blanco',
 'intentionallyblankpage' => 'Esta páxina ta en blanco arrémente',
 
Index: languages/messages/MessagesGot.php
===================================================================
--- languages/messages/MessagesGot.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGot.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,90 +1,496 @@
 <?php
-/** Gothic ()
+/** Gothic (𐌲𐌿𐍄𐌹𐍃𐌺)
  *
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
+ * @author Jocke Pirat
  */
 
 $messages = array(
+'underline-always' => 'Sinteino',
+'underline-never'  => 'Niu',
+
+# Dates
+'sunday'        => 'Sunnonsdags',
+'monday'        => 'Meninsdags',
+'tuesday'       => 'Tiwisdags',
+'wednesday'     => 'Midiwiko',
+'thursday'      => 'Þeiƕonsdags',
+'friday'        => 'Fraujonsdags',
+'saturday'      => 'Þwahlisdags',
+'sun'           => 'Sun',
+'mon'           => 'Men',
+'tue'           => 'Tiw',
+'wed'           => 'Mid',
+'thu'           => 'Þei',
+'fri'           => 'Fra',
+'sat'           => 'Þwa',
+'january'       => 'Aftuma Jiuleis',
+'february'      => 'Fanimenoþs',
+'march'         => 'Kaldmenoþs',
+'april'         => 'Grasmenoþs',
+'may_long'      => 'Blomamenoþs',
+'june'          => 'Warmmenoþs',
+'july'          => 'Hawimenoþs',
+'august'        => 'Asanmenoþs',
+'september'     => 'Akranmenoþs',
+'october'       => 'Weinmenoþs',
+'november'      => 'Fruma Jiuleis',
+'december'      => 'Jiuleis',
+'january-gen'   => 'Aftumins Jiuleis',
+'february-gen'  => 'Fanimenoþis',
+'march-gen'     => 'Kaldmenoþis',
+'april-gen'     => 'Grasmenoþis',
+'may-gen'       => 'Blomamenoþis',
+'june-gen'      => 'Warmmenoþis',
+'july-gen'      => 'Hawimenoþis',
+'august-gen'    => 'Asanmenoþis',
+'september-gen' => 'Akranmenoþis',
+'october-gen'   => 'Weinmenoþis',
+'november-gen'  => 'frumins Jiuleis',
+'december-gen'  => 'Jiuleis',
+'jan'           => 'Aft',
+'feb'           => 'Fan',
+'mar'           => 'Kal',
+'apr'           => 'Gra',
+'may'           => 'Blo',
+'jun'           => 'War',
+'jul'           => 'Haw',
+'aug'           => 'Asa',
+'sep'           => 'Akr',
+'oct'           => 'Wei',
+'nov'           => 'Fru',
+'dec'           => 'Jiu',
+
 # Categories related messages
-'pagecategories' => '{{PLURAL:$1||}}',
+'pagecategories'        => '{{PLURAL:$1|𐌺𐌿𐌽𐌾𐌰|𐌺𐌿𐌽𐌾𐍉𐍃}}',
+'category_header'       => 'Seidos inn kunja "$1"',
+'subcategories'         => 'Dalaþkunjos',
+'category-media-header' => 'Medja inn kunja "$1"',
 
-'qbspecialpages' => '',
-'mypage'         => ' ',
-'mytalk'         => ' ',
+'about'          => 'Iubair',
+'article'        => 'saþssiedo',
+'newwindow'      => '(andhuljiþ inn niuja áugadaúro)',
+'cancel'         => 'Halts',
+'qbfind'         => 'Sokeiþ',
+'qbedit'         => 'Máidjan',
+'qbmyoptions'    => 'Meina seidos',
+'qbspecialpages' => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉𐍃',
+'moredotdotdot'  => 'Máis...',
+'mypage'         => '𐌼𐌴𐌹𐌽 𐍃𐌴𐌹𐌳𐍉',
+'mytalk'         => '𐌼𐌴𐌹𐌽𐌰 𐌼𐌰𐌸𐌻𐌴𐌹',
 'and'            => 'jah',
 
-'search'         => '',
-'searchbutton'   => '',
-'searcharticle'  => '',
-'talkpage'       => '',
-'talk'           => '',
-'toolbox'        => ' ',
-'otherlanguages' => ' ',
+# Metadata in edit box
+'metadata_help' => 'Ufardata:',
 
+'errorpagetitle'    => 'Faírina dwalis',
+'returnto'          => 'Gawandjan at $1.',
+'tagline'           => 'Fram {{SITENAME}}',
+'help'              => 'Hilpa',
+'search'            => '𐍃𐍉𐌺𐌴𐌹𐌸',
+'searchbutton'      => '𐍃𐍉𐌺𐌴𐌹𐌸',
+'go'                => 'Gagga',
+'searcharticle'     => '𐌰𐍆𐌲𐌰𐌲𐌲𐌰𐌽',
+'history'           => 'Seido Airis',
+'history_short'     => 'Airis',
+'printableversion'  => 'Driusan seido',
+'permalink'         => 'Áweins táiknjabandi',
+'edit'              => 'Máidjan',
+'editthispage'      => 'Máidja þo seido',
+'delete'            => 'Taíran',
+'deletethispage'    => 'Taíra þo siedo',
+'protect'           => 'Baírgan',
+'protectthispage'   => 'Baírga þo siedo',
+'unprotect'         => 'Nibaírga',
+'unprotectthispage' => 'Nibaírga þo siedo',
+'newpage'           => 'Niuja seido',
+'talkpage'          => '𐌼𐌰𐌸𐌻𐌴𐌹𐍃𐌴𐌹𐌳𐍉',
+'talkpagelinktext'  => 'Maþleiseido',
+'specialpage'       => 'Ussindseidos',
+'personaltools'     => 'Waírleiks brukwaíhts',
+'talk'              => '𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰',
+'views'             => 'Siuneis',
+'toolbox'           => '𐍄𐌰𐌿𐌹 𐌰𐍂𐌺𐌰',
+'otherlanguages'    => '𐌰𐌽𐌸𐌰𐍂 𐍂𐌰𐌶𐌳𐍉𐍃',
+'redirectedfrom'    => '(Náuþjan framis $1)',
+'redirectpagesub'   => 'Táikjaseido',
+'jumpto'            => 'Gaggan at:',
+'jumptonavigation'  => 'seidogawiss',
+'jumptosearch'      => 'sokeiþ',
+
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutpage'  => 'Project:Iubair',
-'bugreports' => '',
-'portal'     => ' ',
-'portal-url' => 'Project: ',
+'aboutsite'            => 'Ufar {{SITENAME}}',
+'aboutpage'            => 'Project:Ufar',
+'bugreports'           => '𐌰𐌹𐍂𐌶𐌹𐌸𐌰𐌷𐌰𐌿𐍃𐌴𐌹𐌽𐌴𐌹𐍃',
+'copyrightpage'        => '{{ns:project}}:Manleikawitoþa',
+'currentevents'        => 'Niuja waíhts',
+'currentevents-url'    => 'Project:Nu her',
+'disclaimers'          => 'Afaikan witoþ',
+'disclaimerpage'       => 'Project:Afaikan witoþ',
+'edithelp'             => 'Hilpa máidjan',
+'edithelppage'         => 'Help:Máidja',
+'helppage'             => 'Hilpa:Háubidaseido',
+'mainpage'             => 'Háubidaseido',
+'mainpage-description' => 'Haubidaseido',
+'portal'               => '𐌱𐌰𐌿𐍂𐌲𐍃 𐌲𐌰𐍅𐌹',
+'portal-url'           => 'Project:𐌱𐌰𐌿𐍂𐌲𐍃 𐌲𐌰𐍅𐌹',
+'privacy'              => 'Anasila witoþ',
+'privacypage'          => 'Project:Anasila witoþ',
 
+'retrievedfrom'       => 'Niman fram "$1"',
+'youhavenewmessages'  => 'Þu habis $1 ($2).',
+'newmessageslink'     => 'niujo maþlei',
+'newmessagesdifflink' => 'spedumists máideins',
+'editsection'         => 'máidjan',
+'editold'             => 'máidjan',
+'editsectionhint'     => 'Máidjan af fera: $1',
+'toc'                 => 'Innana',
+'showtoc'             => 'áugja',
+'hidetoc'             => 'filhan',
+'site-rss-feed'       => '$1 RSS Miþnatifodjan',
+'site-atom-feed'      => '$1 Atom Miþnatifodjan',
+
 # Short words for each namespace, by default used in the namespace tab in monobook
-'nstab-main'     => '',
-'nstab-user'     => '',
-'nstab-special'  => '',
-'nstab-image'    => 'Manleika',
-'nstab-template' => '',
-'nstab-help'     => '',
+'nstab-main'     => '𐍃𐌴𐌹𐌳𐍉',
+'nstab-user'     => '𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃𐍃𐌴𐌹𐌳𐍉',
+'nstab-special'  => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉',
+'nstab-project'  => 'Reikiseido',
+'nstab-image'    => 'Feilans',
+'nstab-template' => '𐌼𐌰𐍂𐌺𐌰',
+'nstab-help'     => '𐌷𐌹𐌻𐍀𐌰',
 'nstab-category' => 'Kunja',
 
 # General errors
-'viewsource' => ' ',
+'viewsource'    => '𐍃𐌰𐌹𐍈𐌰 𐌹𐌽𐌽𐌰𐌽𐌰',
+'viewsourcefor' => 'fáur $1',
 
 # Login and logout pages
-'userlogout' => '',
+'yourname'                => 'Niutandisnamo:',
+'yourpassword'            => 'Analaúgns wáurda:',
+'login'                   => 'Atgaggan',
+'nav-login-createaccount' => 'Atgaggan / Galangjan Niutandis',
+'userlogin'               => 'Atgaggan / gaskapjan niutandis',
+'logout'                  => 'Leiþan',
+'userlogout'              => '𐌻𐌴𐌹𐌸𐌰𐌽',
+'nologinlink'             => 'Gaskapjan þein niutandis',
+'createaccount'           => 'Galagjan niutandis',
+'gotaccount'              => 'Habiþ þu niutandis? $1',
+'gotaccountlink'          => 'Atgaggan',
+'loginlanguagelabel'      => 'Razda: $1',
 
+# Edit page toolbar
+'bold_sample'     => 'Abrs boka',
+'bold_tip'        => 'Abr waúrda',
+'italic_sample'   => 'Wráiqs waúrda',
+'italic_tip'      => 'Driuso boka',
+'link_sample'     => 'Táikjanbandi namo',
+'link_tip'        => 'táikjanbandi innana',
+'extlink_sample'  => 'http://www.example.com Táikjandandi namo',
+'extlink_tip'     => 'Uta táikjabandi (maúdjan http://)',
+'headline_sample' => 'Háubidawaúrda',
+'headline_tip'    => 'Háuhs háubidaboka 2',
+'math_sample'     => 'Lagjan formula her',
+'math_tip'        => 'Maþemateikaleiks formula (LaTeX)',
+'media_tip'       => 'Táikjabandjis feilanis',
+'hr_tip'          => 'Ráihtsbáurd (brukjan miþ niufarussus)',
+
 # Edit pages
-'watchthis' => ' ',
+'summary'                => 'Máidjanspillon',
+'subject'                => 'Háubidaboka',
+'minoredit'              => 'Sa ist lietila máideins',
+'watchthis'              => '𐍅𐌰𐍂𐌰𐌽 𐍃𐌴𐌹𐌳𐍉',
+'savearticle'            => 'Melja seido',
+'preview'                => 'Faúrsáiƕa seido',
+'showpreview'            => 'Witan faúrsáiƕa',
+'showdiff'               => 'Witan máideins',
+'newarticle'             => '(Niu)',
+'updated'                => '(Nuwisan)',
+'previewnote'            => '<strong>Sah ist faúrsaiƕa. Máideins gameljiþ ni af þizos seidos!</strong>',
+'editing'                => 'Máidjan af $1',
+'editingsection'         => 'Máidjan af $1 (fera)',
+'editingcomment'         => 'Máidjan af $1 (rodjafera)',
+'yourdiff'               => 'Missalieks',
+'template-protected'     => '(gabaírgan)',
+'template-semiprotected' => '(halb-gabaírgjan)',
 
+# History pages
+'currentrev'          => 'Nu máideins',
+'revisionasof'        => 'Gamelido us $1',
+'revision-info'       => 'Máideins fram $1 bi $2',
+'previousrevision'    => '←Áiris Máideins',
+'nextrevision'        => 'Iftuma máideins→',
+'currentrevisionlink' => 'Numáideins',
+'cur'                 => 'nu',
+'next'                => 'iftuma',
+'last'                => 'aftumists',
+'page_first'          => 'frumists',
+'page_last'           => 'spedumists',
+'histfirst'           => 'Faúrþis',
+'histlast'            => 'Spedumists',
+
+# Revision feed
+'history-feed-item-nocomment' => '$1 at $2', # user at time
+
+# Diffs
+'history-title' => 'Árismáideins af "$1"',
+'lineno'        => 'Bokarigilo $1:',
+'editundo'      => 'niuskapjan',
+
+# Search results
+'prevn'        => 'aftuma $1',
+'nextn'        => 'iftuma $1',
+'viewprevnext' => 'Siuneis ($1) ($2) ($3)',
+'powersearch'  => 'Sokeiþ',
+
 # Preferences page
-'preferences'   => 'Meinos brukjamaideineis',
-'mypreferences' => ' ',
+'preferences'       => 'Meinos brukjamaideineis',
+'mypreferences'     => '𐌼𐌴𐌹𐌽𐍉𐍃 𐌱𐍂𐌿𐌺𐌾𐌰',
+'skin'              => 'Seidofill',
+'saveprefs'         => 'Melja',
+'searchresultshead' => 'Sokeiþ',
 
+'grouppage-sysop' => '{{ns:project}}:Seidofaþs',
+
+# User rights log
+'rightslog'  => 'Niutandis stutjanlog',
+'rightsnone' => '(ni áinshun)',
+
 # Recent changes
-'recentchanges' => ' ',
+'nchanges'        => '$1 {{PLURAL:$1|máidein|máideins}}',
+'recentchanges'   => '𐌰𐍆𐍄𐌿𐌼𐌹𐍃𐍄𐍉𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐌴𐌹𐍃',
+'rcshowhideminor' => '$1 lietila máideins',
+'rcshowhidebots'  => '$1 bota',
+'rcshowhideliu'   => '$1 niutandis',
+'rcshowhideanons' => '$1 gasteis',
+'rcshowhidemine'  => '$1 mein máideins',
+'diff'            => 'leiks',
+'hist'            => 'áiris',
+'hide'            => 'Filhan',
+'show'            => 'Huljan',
+'minoreditletter' => 'l',
+'newpageletter'   => 'N',
+'boteditletter'   => 'b',
 
+# Recent changes linked
+'recentchangeslinked' => 'Máideinlieks',
+
 # Upload
-'upload' => ' ',
+'upload'          => '𐌿𐍃𐌷𐌻𐌰𐌸𐌰𐌹𐌸 𐍆𐌴𐌹𐌻𐌰𐌽𐍃',
+'uploadbtn'       => 'Ushlaþaiþ Feilans',
+'uploadlogpage'   => 'Log af Ushlaþan',
+'uploadedimage'   => 'ushlaþiþ "[[$1]]"',
+'watchthisupload' => 'Witan so seido',
 
+# Special:ImageList
+'imgfile'   => 'Feilans',
+'imagelist' => 'Feilans tala',
+
+# Image description page
+'filehist'            => 'Feilans áiris',
+'filehist-current'    => 'nu',
+'filehist-datetime'   => 'Ƕeila',
+'filehist-user'       => 'Niutandis',
+'filehist-dimensions' => 'Wahstus',
+'filehist-filesize'   => 'Feilans wahstus',
+'filehist-comment'    => 'Leitilaspillon',
+'imagelinks'          => 'Táiknjabandja',
+
+# File deletion
+'filedelete-submit' => 'Taíran',
+
+# MIME search
+'mimesearch' => 'MIME sokeiþ',
+
+# List redirects
+'listredirects' => 'Tala af táikjanseidos',
+
 # Random page
-'randompage' => ' ',
+'randompage' => '𐍃𐌻𐌿𐌼𐍀𐌼𐌰𐍃𐍃𐌹𐌲 𐍃𐌴𐌹𐌳𐍉',
 
 # Statistics
 'statistics' => 'Seidostatistik',
+'sitestats'  => '{{SITENAME}} seidostatistik',
 
+'brokenredirects-edit'   => '(máidjan)',
+'brokenredirects-delete' => '(taíran)',
+
 # Miscellaneous special pages
-'ncategories' => '$1 {{PLURAL:$1||}}',
-'move'        => ' ',
+'nbytes'       => '$1 {{PLURAL:$1|báit|báita}}',
+'ncategories'  => '$1 {{PLURAL:$1|𐌺𐌿𐌽𐌾𐌰|𐌺𐌿𐌽𐌾𐍉𐍃}}',
+'nlinks'       => '$1 {{PLURAL:$1|táikjanbandi|táikjanbandja}}',
+'nmembers'     => '$1 {{PLURAL:$1|niutand|niutanda}}',
+'wantedpages'  => 'Gaírnedum seidam',
+'shortpages'   => 'Leitila seidos',
+'longpages'    => 'Lagga seidos',
+'listusers'    => 'Niutandis tala',
+'newpages'     => 'Niuja seidos',
+'move'         => '𐌽𐌰𐌼𐌾𐌰𐌽 𐌰𐍆𐍄𐍂𐌰',
+'movethispage' => 'Skiuban sa seido',
 
+# Special:Log
+'specialloguserlabel'  => 'Niutand:',
+'speciallogtitlelabel' => 'Namo:',
+'log'                  => 'Logbokos',
+'all-logs-page'        => 'Alla logos',
+'log-search-submit'    => 'Afgaggan',
+
+# Special:AllPages
+'allpages'       => 'Allis seidos',
+'alphaindexline' => '$1 du $2',
+'nextpage'       => 'Iftuma seido ($1)',
+'prevpage'       => 'Aftuma seido ($1)',
+'allarticles'    => 'Alja seidos',
+'allpagessubmit' => 'Afgaggan',
+
 # Special:Categories
-'categories' => '',
+'categories' => '𐌺𐌿𐌽𐌾𐍉𐍃',
 
+# E-mail user
+'emailuser' => 'Sandjan þo niutand bokom',
+
 # Watchlist
-'watchlist'     => ' ',
-'mywatchlist'   => ' ',
-'watch'         => '',
-'watchthispage' => ' ',
-'unwatch'       => '',
+'watchlist'            => '𐌼𐌴𐌹𐌽𐍉𐍃 𐍅𐌹𐍄𐌰𐌽𐌳𐍃𐌻𐌴𐌹𐍃𐍄𐌰',
+'mywatchlist'          => '𐌼𐌴𐌹𐌽𐍉𐍃 𐍅𐌹𐍄𐌰𐌽𐌳𐍃𐌻𐌴𐌹𐍃𐍄𐌰',
+'watchlistfor'         => "(fáur '''$1''')",
+'watch'                => '𐍅𐌰𐍂𐌰𐌽',
+'watchthispage'        => '𐍅𐌰𐍂𐌰𐌽 𐍃𐌴𐌹𐌳𐍉',
+'unwatch'              => '𐌽𐌹𐍅𐌰𐍂𐌰𐌽',
+'watchlist-details'    => '{{PLURAL:$1|$1 seido|$1 seidona}} witáiþs inu maþleiseidam.',
+'watchlist-hide-minor' => 'Filhan leitila máideins',
 
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => 'Wita...',
+'unwatching' => 'Niwita...',
+
+'created' => 'gaskapjan',
+
+# Delete/protect/revert
+'deletepage'            => 'Taíra seido',
+'delete-legend'         => 'Taíran',
+'actioncomplete'        => 'Wasuh Ita Gaustiuhan',
+'deletedarticle'        => 'taíriþ "[[$1]]"',
+'dellogpage'            => 'Taíra áirwboka',
+'deleteotherreason'     => 'Anþar/máis mitons:',
+'deletereasonotherlist' => 'Anþar mitons',
+'rollbacklink'          => 'afwalwjan',
+'protectlogpage'        => 'Log af Baírgjan',
+'protect-unchain'       => 'Ungalukan sa skiubanfreihals',
+'protect-level-sysop'   => 'Seidofaþs áinaha',
+'protect-expiring'      => 'bláuþiþ $1 (UTC)',
+'restriction-type'      => 'Freihals:',
+
+# Restrictions (nouns)
+'restriction-edit' => 'Máidjan',
+'restriction-move' => 'Skiuban',
+
+# Undelete
+'undeletebtn'            => 'Aftra gabotjan',
+'undelete-search-submit' => 'Sokeiþ',
+
+# Namespace form on various pages
+'namespace'      => 'Seidofera:',
+'invert'         => 'Afwandjan kustus',
+'blanknamespace' => '(Frumists)',
+
 # Contributions
-'mycontris' => ' ',
+'contributions' => 'Niutandis gibos',
+'mycontris'     => '𐌼𐌴𐌹𐌽𐍉𐍃 𐌰𐌹𐍅𐌻𐌰𐌲𐌹𐍉𐍃',
+'contribsub2'   => 'Faúr $1 ($2)',
+'uctop'         => '(háubiþ)',
+'month'         => 'Fram menoþs (jah aftuma):',
+'year'          => 'Fram jera (jah aftuma):',
 
+'sp-contributions-newbies-sub' => 'Faúr niujis niutandis',
+'sp-contributions-blocklog'    => 'Logboka af afdraúsjan',
+
 # What links here
-'whatlinkshere' => '   ',
+'whatlinkshere'       => '𐍈𐌰𐍂𐌾𐌹𐍃 𐍃𐌴𐌹𐌳𐍉𐌽𐌰 𐌷𐌻𐌰𐌲𐌺𐌾𐌰𐌽𐌳 𐌷𐌹𐌳𐍂𐌴',
+'whatlinkshere-title' => 'Seidos hwarjis du $1 táiknjan',
+'linklistsub'         => '(Tala af táikjanbanjam)',
+'isredirect'          => 'táikjaseido',
+'istemplate'          => 'ináukan',
+'whatlinkshere-prev'  => '{{PLURAL:$1|aftuma|aftumans $1}}',
+'whatlinkshere-next'  => '{{PLURAL:$1|iftuma|iftumans $1}}',
+'whatlinkshere-links' => '← táikajanbandja',
 
+# Block/unblock
+'blockip'            => 'Afdráusjan niutandis',
+'ipbreason'          => 'Faírina:',
+'ipbotheroption'     => 'anþar',
+'ipblocklist-submit' => 'Sokeiþ',
+'infiniteblock'      => 'ajukduþs',
+'blocklink'          => 'wargjan',
+'unblocklink'        => 'wandjan',
+'contribslink'       => 'gibos',
+'blocklogpage'       => 'Logboka af afdraúsjan',
+'blocklogentry'      => 'afdraúsiþ [[$1]] fáur $2 $3',
+
+# Move page
+'movearticle' => 'Skiuba seido:',
+'newtitle'    => 'Du niujis namos:',
+'move-watch'  => 'Witan so seido',
+'movepagebtn' => 'Skiuba seido',
+'movedto'     => 'skiubiþ du',
+'1movedto2'   => '[[:$1]] skiubiþ du [[:$2]]',
+'movelogpage' => 'Log af skiubans',
+'movereason'  => 'Faírina:',
+'revertmove'  => 'ráidjan',
+
+# Thumbnails
+'thumbnail-more' => 'Biáuknan',
+
+# Tooltip help for the actions
+'tooltip-pt-userpage'    => 'Meina niutandisseido',
+'tooltip-pt-mytalk'      => 'Meina maþleiseido',
+'tooltip-pt-preferences' => 'Meinos brukjamaideineis',
+'tooltip-pt-mycontris'   => 'Tala af meina gibom',
+'tooltip-pt-logout'      => 'leiþan',
+'tooltip-ca-protect'     => 'Baírga þo seido',
+'tooltip-ca-delete'      => 'Taíran so seido',
+'tooltip-ca-move'        => 'Skiuban so seido',
+'tooltip-search'         => 'Sokeiþ {{SITENAME}}',
+'tooltip-p-logo'         => 'Háubidaseido',
+'tooltip-n-mainpage'     => 'Saihwan sa Háubidaseido',
+'tooltip-t-upload'       => 'Ushlaþaiþ Feilans',
+'tooltip-t-specialpages' => 'Findiþ alla ussindseidos',
+'tooltip-ca-nstab-user'  => 'Sáihwan sa niutandisseido',
+'tooltip-save'           => 'Skreiban þein máideins',
+
+# Browsing diffs
+'previousdiff' => '← Aftuma áiris',
+'nextdiff'     => 'Iftuma áiris →',
+
+# Media information
+'show-big-image' => 'Fullis wahstus',
+
+# Special:NewImages
+'ilsubmit' => 'Sokeiþ',
+
+# Metadata
+'metadata' => 'Ufardata',
+
+# 'all' in various places, this might be different for inflected languages
+'recentchangesall' => 'allis',
+'imagelistall'     => 'allis',
+'watchlistall2'    => 'allis',
+'namespacesall'    => 'allis',
+'monthsall'        => 'allis',
+
+# Multipage image navigation
+'imgmultigo' => 'Afgaggan!',
+
+# Table pager
+'table_pager_limit_submit' => 'Affgaggan',
+
+# Special:Version
+'version-other' => 'Anþar',
+
+# Special:FilePath
+'filepath-page' => 'Feilans:',
+
 # Special:SpecialPages
-'specialpages' => '',
+'specialpages' => '𐌿𐍃𐍃𐌹𐌽𐌳𐍃𐌴𐌹𐌳𐍉𐍃',
 
 );
Index: languages/messages/MessagesIa.php
===================================================================
--- languages/messages/MessagesIa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author McDutchie
  * @author Malafaya
+ * @author McDutchie
  * @author לערי ריינהארט
- * @author Siebrand
  */
 
 $skinNames = array(
@@ -186,7 +185,7 @@
 'returnto'          => 'Retornar a $1.',
 'tagline'           => 'De {{SITENAME}}',
 'help'              => 'Adjuta',
-'search'            => 'Cercar',
+'search'            => 'Recerca',
 'searchbutton'      => 'Cercar',
 'go'                => 'Ir',
 'searcharticle'     => 'Ir',
@@ -217,7 +216,7 @@
 'postcomment'       => 'Publicar un commento',
 'articlepage'       => 'Vider pagina de contento',
 'talk'              => 'Discussion',
-'views'             => 'Vistas',
+'views'             => 'Visitas',
 'toolbox'           => 'Instrumentario',
 'userpage'          => 'Vider pagina del usator',
 'projectpage'       => 'Vider pagina de projecto',
@@ -230,8 +229,8 @@
 'otherlanguages'    => 'In altere linguas',
 'redirectedfrom'    => '(Redirigite de $1)',
 'redirectpagesub'   => 'Pagina de redirection',
-'lastmodifiedat'    => 'Iste pagina esseva modificate le plus recentemente le $1 a $2.', # $1 date, $2 time
-'viewcount'         => 'Iste pagina esseva accessate {{PLURAL:$1|un vice|$1 vices}}.',
+'lastmodifiedat'    => 'Ultime modification de iste pagina: le $1 a $2.', # $1 date, $2 time
+'viewcount'         => 'Iste pagina ha essite visitate {{PLURAL:$1|un vice|$1 vices}}.',
 'protectedpage'     => 'Pagina protegite',
 'jumpto'            => 'Saltar a:',
 'jumptonavigation'  => 'navigation',
@@ -252,7 +251,7 @@
 'edithelp'             => 'Adjuta de modification',
 'edithelppage'         => 'Help:Modification',
 'faq'                  => 'FAQ',
-'faqpage'              => 'Project:Questiones_frequente',
+'faqpage'              => 'Project:FAQ',
 'helppage'             => 'Help:Contento',
 'mainpage'             => 'Frontispicio',
 'mainpage-description' => 'Frontispicio',
@@ -309,12 +308,12 @@
 'nstab-category'  => 'Categoria',
 
 # Main script and global functions
-'nosuchaction'      => 'Action non recognoscite',
+'nosuchaction'      => 'Non existe tal action',
 'nosuchactiontext'  => 'Le action specificate in le adresse URL non es recognoscite per le wiki',
 'nosuchspecialpage' => 'Pagina special invalide',
 'nospecialpagetext' => "<big>'''Tu ha requestate un pagina special que es non es valide.'''</big>
 
-Un lista de paginas special valide se trova a [[Special:Specialpages|{{int:specialpages}}]].",
+Un lista de paginas special valide se trova a [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -346,7 +345,7 @@
 Causas normal de iste problema es: tu ha consultate un \'\'diff\'\' obsolete, o tu sequeva un ligamine de historia verso un pagina que ha essite delite.
 
 Si isto non es le caso, es possibile que tu ha trovate un error in le software.
-Per favor reporta isto a un administrator, faciente nota del adresse URL.',
+Per favor reporta isto a un [[Special:ListUsers/sysop|administrator]], faciente nota del adresse URL.',
 'missingarticle-rev'   => '(numero del revision: $1)',
 'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'Le base de datos ha essite automaticamente blocate durante que le servitores de base de datos secundari se synchronisa con le servitor principal.',
@@ -402,15 +401,15 @@
 'logouttitle'                => 'Session claudite',
 'logouttext'                 => '<strong>Tu ha claudite tu session.</strong>
 
-Tu pote continuar a usar {{SITENAME}} anonymemente, o initiar un nove session como le mesme o como un altere usator.
+Tu pote continuar a usar {{SITENAME}} anonymemente, o tu pote [[Special:UserLogin|initiar un nove session]] como le mesme o como un altere usator.
 Nota que alcun paginas pote continuar a monstrar se como si le session esserea ancora active. Pro remediar isto, tu pote vacuar le cache de tu navigator.',
 'welcomecreation'            => '== Benvenite, $1! ==
 Tu conto ha essite create.
-Non oblida personalisar tu preferentias in {{SITENAME}}.',
+Non oblida personalisar tu [[Special:Preferences|preferentias in {{SITENAME}}]].',
 'loginpagetitle'             => 'Aperir session',
 'yourname'                   => 'Nomine de usator:',
 'yourpassword'               => 'Contrasigno:',
-'yourpasswordagain'          => 'Repeter contrasigno:',
+'yourpasswordagain'          => 'Repete contrasigno:',
 'remembermypassword'         => 'Memorar mi contrasigno in iste computator',
 'yourdomainname'             => 'Tu dominio:',
 'externaldberror'            => 'O il occureva un error in le base de datos de authentification externe, o tu non ha le autorisation de actualisar tu conto externe.',
@@ -560,43 +559,42 @@
 'blockedtitle'                     => 'Le usator es blocate',
 'blockedtext'                      => "<big>'''Tu nomine de usator o adresse IP ha essite blocate.'''</big>
 
-Le blocada esseva facite per $1. Le motivo presentate es ''$2''.
+Le blocada esseva facite per $1.
+Le motivo presentate es ''$2''.
 
 * Initio del blocada: $8
 * Expiration del blocada: $6
 * Le blocato intendite: $7
 
-Tu pote contactar $1 o un del altere [[{{MediaWiki:Grouppage-sysop}}|administratores]] pro discuter le blocada.
+Tu pote contactar $1 o un altere [[{{MediaWiki:Grouppage-sysop}}|administrator]] pro discuter le blocada.
 Tu non pote usar le function 'inviar e-mail a iste usator' salvo que un adresse de e-mail valide es specificate in le
 [[Special:Preferences|preferentias de tu conto]] e que tu non ha essite blocate de usar lo.
-Tu adresse IP actual es $3, e le ID del blocada es #$5. Per favor include un de iste informationes o ambes in omne questiones.",
+Tu adresse IP actual es $3, e le ID del blocada es #$5.
+Per favor include tote le detalios supra specificate in omne correspondentia.",
 'autoblockedtext'                  => 'Tu adresse de IP ha essite automaticamente blocate proque un altere usator lo usava qui esseva blocate per $1.
-Le ration date es:
+Le motivo presentate es:
 
 :\'\'$2\'\'
 
 * Initio del blocada: $8
 * Expiration del blocada: $6
+* Blocato intendite: $7
 
 Tu pote contactar $1 o un del altere [[{{MediaWiki:Grouppage-sysop}}|administratores]] pro discuter le blocada.
 
-Nota que tu non pote utilisar le function "inviar e-mail a iste usator" si tu non ha registrate un adresse de e-mail valide in tu [[Special:Preferences|preferentias de usator]] e si tu non ha essite blocate de usar lo.
+Nota que tu non pote utilisar le function "inviar e-mail a iste usator" salvo que tu ha registrate un adresse de e-mail valide in tu [[Special:Preferences|preferentias de usator]] e que tu non ha essite blocate de usar lo.
 
-Le ID de iste blocada es $5.
-Per favor include iste ID in omne correspondentia.',
+Tu adresse IP actual es $3, e le ID del blocada es #$5.
+Per favor include tote le detalios supra specificate in omne correspondentia.',
 'blockednoreason'                  => 'nulle ration date',
 'blockedoriginalsource'            => "Le codice-fonte de '''$1''' se monstra infra:",
 'blockededitsource'                => "Le texto de '''tu modificationes''' in '''$1''' se monstra infra:",
 'whitelistedittitle'               => 'Identification requirite pro modificar',
 'whitelistedittext'                => 'Tu debe $1 pro poter modificar paginas.',
-'whitelistreadtitle'               => 'Identification requirite pro leger',
-'whitelistreadtext'                => 'Tu debe [[Special:Userlogin|aperir un session]] pro poter leger paginas.',
-'whitelistacctitle'                => 'Tu non ha le permission de crear un conto',
-'whitelistacctext'                 => 'Le permission de crear contos in {{SITENAME}} require que tu [[Special:Userlogin|aperi un session]] e que tu ha le autorisation appropriate.',
 'confirmedittitle'                 => 'Confirmation del adresse de e-mail es requirite pro poter modificar',
 'confirmedittext'                  => 'Tu debe confirmar tu adresse de e-mail pro poter modificar paginas.
 Per favor defini e valida tu adresse de e-mail per medio de tu [[Special:Preferences|preferentias de usator]].',
-'nosuchsectiontitle'               => 'Tal section non existe',
+'nosuchsectiontitle'               => 'Non existe tal section',
 'nosuchsectiontext'                => 'Tu essayava modificar un section que non existe.
 Viste que il non ha alcun section $1, il non ha alcun location pro publicar tu modification.',
 'loginreqtitle'                    => 'Identification requirite',
@@ -608,9 +606,9 @@
 'newarticletext'                   => "Tu ha sequite un ligamine verso un pagina que non existe ancora.
 Pro crear iste pagina, comencia a scriber in le quadro infra (consulta le [[{{MediaWiki:Helppage}}|pagina de adjuta]] pro plus informationes).
 Si tu ha arrivate hic per error, clicca le button '''Retornar''' de tu navigator.",
-'anontalkpagetext'                 => "---- ''Isto es le pagina de discussion pro un usator anonyme qui non ha ancora create un conto o qui non lo usa. Consequentemente nos debe usar le adresse IP numeric pro identificar le/la.
+'anontalkpagetext'                 => "---- ''Isto es le pagina de discussion pro un usator anonyme qui non ha ancora create un conto, o qui non lo usa. Consequentemente nos debe usar le adresse IP numeric pro identificar le/la.
 Un tal adresse IP pote esser usate in commun per varie personas.
-Si tu es un usator anonyme e pensa que commentos irrelevante ha essite dirigite a te, per favor [[Special:Userlogin|crea un conto o aperi un session]] pro evitar futur confusiones con altere usatores anonyme.''",
+Si tu es un usator anonyme e pensa que commentos irrelevante ha essite dirigite a te, per favor [[Special:UserLogin/signup|crea un conto]] o [[Special:UserLogin|aperi un session]] pro evitar futur confusiones con altere usatores anonyme.''",
 'noarticletext'                    => 'Actualmente il non ha texto in iste pagina. Tu pote [[Special:Search/{{PAGENAME}}|cercar iste titulo]] in le texto de altere paginas o [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificar iste pagina].',
 'userpage-userdoesnotexist'        => 'Le conto de usator "$1" non es registrate. Per favor verifica que tu vole crear/modificar iste pagina.',
 'clearyourcache'                   => "'''Nota - Post confirmar, il pote esser necessari refrescar le ''cache'' de tu navigator pro vider le cambiamentos.''' '''Mozilla / Firefox / Safari:''' tenente ''Shift'' clicca ''Reload,'' o preme ''Ctrl-F5'' o ''Ctrl-R'' (''Command-R'' in un Macintosh); '''Konqueror: '''clicca ''Reload'' o preme ''F5;'' '''Opera:''' vacua le ''cache'' in ''Tools → Preferences;'' '''Internet Explorer:''' tenente ''Ctrl'' clicca ''Refresh,'' o preme ''Ctrl-F5.''",
@@ -626,12 +624,14 @@
 'previewconflict'                  => 'Iste previsualisation reflecte le apparentia final del texto in le area de modification superior
 si tu opta pro publicar lo.',
 'session_fail_preview'             => '<strong>Excusa! Nos non poteva processar tu modification proque nos perdeva le datos del session.
-Per favor reprova. Si illo ancora non va, prova clauder e reaperir tu session.</strong>',
+Per favor reprova.
+Si illo ancora non va, prova [[Special:UserLogout|clauder tu session]] e aperir un nove session.</strong>',
 'session_fail_preview_html'        => "<strong>Excusa! Nos non poteva processar tu modification proque nos perdeva le datos del session.</strong>
 
 ''Viste que HTML crude es active in {{SITENAME}}, le previsualisation es celate como precaution contra attaccos via JavaScript.''
 
-<strong>Si isto es un tentativa de modification legitime, per favor reprova lo. Si illo ancora non va, prova clauder e reaperir tu session.</strong>",
+<strong>Si isto es un tentativa de modification legitime, per favor reprova lo.
+Si illo ancora non va, prova [[Special:UserLogout|clauder tu session]] e aperir un nove session.</strong>",
 'token_suffix_mismatch'            => "<strong>Tu modification ha essite refusate proque tu cliente corrumpeva le characteres de punctuation in le indicio de modification.
 Iste refusa es pro evitar le corruption del texto del pagina.
 Isto pote occurrer quando tu usa un servicio problematic de ''proxy'' anonyme a base de web.</strong>",
@@ -681,7 +681,7 @@
 'edittools'                        => '<!-- Iste texto se monstrara sub le formularios de modificar articulos e de cargar files. -->',
 'nocreatetitle'                    => 'Creation de paginas limitate',
 'nocreatetext'                     => '{{SITENAME}} ha restringite le permission de crear nove paginas.
-Tu pote retornar e modificar un pagina existente, o [[Special:Userlogin|identificar te, o crear un conto]].',
+Tu pote retornar e modificar un pagina existente, o [[Special:UserLogin|identificar te, o crear un conto]].',
 'nocreate-loggedin'                => 'Tu non ha le permission de crear nove paginas in {{SITENAME}}.',
 'permissionserrors'                => 'Errores de permissiones',
 'permissionserrorstext'            => 'Tu non ha le permission de facer isto, pro le sequente {{PLURAL:$1|motivo|motivos}}:',
@@ -704,10 +704,11 @@
 'post-expand-template-argument-category'  => 'Paginas que omitte alcun parametros de patrono',
 
 # "Undo" feature
-'undo-success' => 'Le modification es reversibile. Per favor controla le comparation infra pro verificar que tu vole facer isto, e alora immagazina le modificationes infra pro completar le reversion del modification.',
-'undo-failure' => 'Le modification non poteva esser revertite a causa de conflicto con modificationes intermedie.',
-'undo-norev'   => 'Impossibile reverter le modification proque illo non existe o esseva delite.',
-'undo-summary' => 'Reverte le revision $1 per [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]])',
+'undo-success' => 'Le modification pote esser annullate.
+Per favor controla le comparation infra pro verificar que tu vole facer isto, e alora immagazina le modificationes infra pro assi annullar le modification.',
+'undo-failure' => 'Le modification non poteva esser annullate a causa de conflicto con modificationes intermedie.',
+'undo-norev'   => 'Impossibile annullar le modification proque illo non existe o esseva delite.',
+'undo-summary' => 'Annullava le revision $1 per [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Non pote crear conto',
@@ -801,7 +802,7 @@
 # Suppression log
 'suppressionlog'     => 'Registro de suppressiones',
 'suppressionlogtext' => 'Infra es un lista de deletiones e blocadas que involve contento que es celate de administratores.
-Vide le [[Special:Ipblocklist|lista de blocadas IP]] pro le lista de bannimentos e blocadas actualmente in operation.',
+Vide le [[Special:IPBlockList|lista de blocadas IP]] pro le lista de bannimentos e blocadas actualmente in operation.',
 
 # History merging
 'mergehistory'                     => 'Fusionar historias del paginas',
@@ -837,13 +838,13 @@
 'difference'              => '(Differentia inter revisiones)',
 'lineno'                  => 'Linea $1:',
 'compareselectedversions' => 'Comparar versiones seligite',
-'editundo'                => 'reverter',
+'editundo'                => 'annullar',
 'diff-multi'              => '({{PLURAL:$1|Un revision intermedie|$1 revisiones intermedie}} non se revela.)',
 
 # Search results
 'searchresults'             => 'Resultatos del recerca',
 'searchresulttext'          => 'Pro plus information super le recerca de {{SITENAME}}, vide [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => 'Tu cercava "[[:$1]]"',
+'searchsubtitle'            => 'Tu cercava \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|tote le paginas que comencia con "$1"]] | [[Special:WhatLinksHere/$1|tote le paginas con ligamines a "$1"]])',
 'searchsubtitleinvalid'     => 'Tu cercava "$1"',
 'noexactmatch'              => "'''Non existe un pagina con le titulo \"\$1\".'''
 Tu pote [[:\$1|crear iste pagina]].",
@@ -889,7 +890,7 @@
 'mypreferences'            => 'Mi preferentias',
 'prefs-edits'              => 'Numero de modificationes:',
 'prefsnologin'             => 'Tu non te ha identificate',
-'prefsnologintext'         => 'Tu debe [[Special:Userlogin|aperir un session]] pro poter configurar tu preferentias.',
+'prefsnologintext'         => 'Tu debe [[Special:UserLogin|aperir un session]] pro poter configurar tu preferentias.',
 'prefsreset'               => 'Tu preferentias anterior ha essite restaurate.',
 'qbsettings'               => 'Barra rapide',
 'qbsettings-none'          => 'Nulle',
@@ -965,7 +966,7 @@
 'userrights-reason'           => 'Motivo pro le cambio:',
 'userrights-no-interwiki'     => 'Tu non ha le permission de modificar le derectos de usatores in altere wikis.',
 'userrights-nodatabase'       => 'Le base de datos $1 non existe o non es local.',
-'userrights-nologin'          => 'Tu debe [[Special:Userlogin|aperir un session]] con un conto de administrator pro poter assignar derectos de usator.',
+'userrights-nologin'          => 'Tu debe [[Special:UserLogin|aperir un session]] con un conto de administrator pro poter assignar derectos de usator.',
 'userrights-notallowed'       => 'Tu conto non ha le permission de assignar derectos de usator.',
 'userrights-changeable-col'   => 'Gruppos que tu pote modificar',
 'userrights-unchangeable-col' => 'Gruppos que tu non pote modificar',
@@ -1032,7 +1033,7 @@
 'right-editprotected'        => 'Modificar paginas protegite (sin cascada)',
 'right-editinterface'        => 'Modificar le interfacie de usator',
 'right-editusercssjs'        => 'Modificar le files CSS e JS de altere usatores',
-'right-rollback'             => 'Rapidemente reverter le modificationes del ultime usator que modificava un pagina particular',
+'right-rollback'             => 'Rapidemente revocar le modificationes del ultime usator que modificava un pagina particular',
 'right-markbotedits'         => 'Marcar modificationes de reversion como facite per un bot',
 'right-noratelimit'          => 'Non esser subjecte al limites de frequentia de actiones',
 'right-import'               => 'Importar paginas de altere wikis',
@@ -1075,7 +1076,7 @@
 'minoreditletter'                   => 'M',
 'newpageletter'                     => 'N',
 'boteditletter'                     => 'b',
-'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|usator|usatores}} observante]',
+'number_of_watching_users_pageview' => '[observate per $1 {{PLURAL:$1|usator|usatores}}]',
 'rc_categories'                     => 'Limite a categorias (separar con "|")',
 'rc_categories_any'                 => 'Qualcunque',
 'newsectionsummary'                 => '/* $1 */ nove section',
@@ -1095,23 +1096,24 @@
 'reupload'                    => 'Recargar',
 'reuploaddesc'                => 'Cancellar le carga e retornar al formulario de carga',
 'uploadnologin'               => 'Tu non te ha identificate',
-'uploadnologintext'           => 'Tu debe [[Special:Userlogin|aperir un session]] pro poter cargar files.',
+'uploadnologintext'           => 'Tu debe [[Special:UserLogin|aperir un session]] pro poter cargar files.',
 'upload_directory_missing'    => 'Le directorio de cargamento ($1) manca, e le servitor de web non poteva crear lo.',
 'upload_directory_read_only'  => 'Le servitor de web non ha le permission de scriber in le directorio de cargamento ($1).',
 'uploaderror'                 => 'Error de carga',
 'uploadtext'                  => "Tu pote cargar files con le formulario infra.
-Pro vider o cercar imagines cargate previemente, visita le [[Special:Imagelist|lista de imagines cargate]]. In ultra, le cargas e deletiones es registrate in le [[Special:Log/upload|registro de cargas]].
+Pro vider o cercar imagines cargate anteriormente, visita le [[Special:ImageList|lista de imagines cargate]]. In ultra, le (re)cargas es registrate in le [[Special:Log/upload|registro de cargas]], le deletiones in le [[Special:Log/delete|registro de deletiones]].
 
-Pro includer un file in un articulo, usa un ligamine in le forma
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|texto alternative]]</nowiki>''', o
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' pro facer un ligamine directe al file.",
+Pro includer un file in un articulo, usa un ligamine in un del sequente formas:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' pro usar le version complete del file
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|texto alternative]]</nowiki></tt>''' pro usar un rendition a largor de 200 pixel in un quadro in le margine sinistre con 'texto alternative' qua description
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' pro facer un ligamine directe al file sin monstrar le file",
 'upload-permitted'            => 'Typos de file permittite: $1.',
 'upload-preferred'            => 'Typos de file preferite: $1.',
 'upload-prohibited'           => 'Typos de file prohibite: $1.',
 'uploadlog'                   => 'registro de cargas',
 'uploadlogpage'               => 'Registro de cargas',
-'uploadlogpagetext'           => 'Infra es un lista del plus recente cargas de files.',
+'uploadlogpagetext'           => 'Infra es un lista del plus recente cargas de files.
+Vide le [[Special:NewImages|galeria de nove files]] pro un presentation plus visual.',
 'filename'                    => 'Nomine del file',
 'filedesc'                    => 'Summario',
 'fileuploadsummary'           => 'Summario:',
@@ -1197,11 +1199,11 @@
 'upload-proto-error-text' => 'Le cargamento remote require que le adresses URL comencia con <code>http://</code> o <code>ftp://</code>.',
 'upload-file-error'       => 'Error interne',
 'upload-file-error-text'  => 'Un error interne occurreva quando se tentava crear un file temporari in le servitor.
-Per favor contacta un administrator de systemas.',
+Per favor contacta un [[Special:ListUsers/sysop|administrator]].',
 'upload-misc-error'       => 'Error de cargamento non cognoscite',
 'upload-misc-error-text'  => 'Un error non cognoscite occurreva durante le cargamento.
 Per favor verifica que le adresse URL sia valide e accessible, e reprova.
-Si le problema persiste, contacta un administrator de systemas.',
+Si le problema persiste, contacta un [[Special:ListUsers/sysop|administrator]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Non poteva acceder al URL',
@@ -1218,7 +1220,7 @@
 'upload_source_url'  => ' (un adresse URL valide e publicamente accessibile)',
 'upload_source_file' => ' (un file in tu computator)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Iste pagina special monstra tote le files cargate.
 Per predefinition le ultime files cargate se monstra al initio del lista.
 Tu pote reordinar le lista con un clic super le titulo de un columna.',
@@ -1246,7 +1248,7 @@
 'imagelinks'                     => 'Ligamines',
 'linkstoimage'                   => 'Le sequente {{PLURAL:$1|pagina ha un ligamine|$1 paginas ha ligamines}} a iste file:',
 'nolinkstoimage'                 => 'Necun pagina se liga a iste imagine.',
-'morelinkstoimage'               => 'Vider [[Special:Whatlinkshere/$1|plus ligamines]] a iste file.',
+'morelinkstoimage'               => 'Vider [[Special:WhatLinksHere/$1|plus ligamines]] a iste file.',
 'redirectstofile'                => 'Le sequente {{PLURAL:$1|file|$1 files}} se redirige a iste file:',
 'duplicatesoffile'               => 'Le sequente {{PLURAL:$1|files es un duplicato|$1 files es duplicatos}} de iste file:',
 'sharedupload'                   => 'Iste file ha essite cargate pro uso in commun; altere projectos pote usar lo.',
@@ -1265,18 +1267,18 @@
 # File reversion
 'filerevert'                => 'Reverter $1',
 'filerevert-legend'         => 'Reverter file',
-'filerevert-intro'          => '<span class="plainlinks">Tu reverte \'\'\'[[Media:$1|$1]]\'\'\' al [$4 version del $3 a $2].</span>',
+'filerevert-intro'          => "Tu reverte '''[[Media:$1|$1]]''' al [$4 version del $3 a $2].",
 'filerevert-comment'        => 'Commento:',
 'filerevert-defaultcomment' => 'Revertite al version del $2 a $1',
 'filerevert-submit'         => 'Reverter',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ha essite revertite al [$4 version del $3 a $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ha essite revertite al [$4 version del $3 a $2].",
 'filerevert-badversion'     => 'Non existe un version local anterior de iste file con le data e hora providite.',
 
 # File deletion
 'filedelete'                  => 'Deler $1',
 'filedelete-legend'           => 'Deler file',
 'filedelete-intro'            => "Tu va deler '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Tu va deler le version de \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $3 a $2].</span>',
+'filedelete-intro-old'        => "Tu va deler le version de '''[[Media:$1|$1]]''' del [$4 $3 a $2].",
 'filedelete-comment'          => 'Motivo pro deletion:',
 'filedelete-submit'           => 'Deler',
 'filedelete-success'          => "'''$1''' ha essite delite.",
@@ -1336,7 +1338,7 @@
 Isto representa un media de '''\$5''' modificationes per pagina, e '''\$6''' visitas per modification.
 
 Le longor del [http://www.mediawiki.org/wiki/Manual:Job_queue cauda de actiones] es '''\$7'''.",
-'userstatstext'          => "Il ha {{PLURAL:$1|'''1''' [[Special:Listusers|usator]]|'''$1''' [[Special:Listusers|usatores]]}} registrate, del quales '''$2''' (i.e. '''$4%''') ha le derectos de $5.",
+'userstatstext'          => "Il ha {{PLURAL:$1|'''1''' [[Special:ListUsers|usator]]|'''$1''' [[Special:ListUsers|usatores]]}} registrate, del quales '''$2''' (i.e. '''$4%''') ha le derectos de $5.",
 'statistics-mostpopular' => 'Le paginas plus visitate',
 
 'disambiguations'      => 'Paginas de disambiguation',
@@ -1345,14 +1347,13 @@
 Istes deberea esser reimplaciate con ligamines al topicos appropriate.<br />
 Un pagina se tracta como pagina de disambiguation si illo usa un patrono al qual [[MediaWiki:Disambiguationspage]] ha un ligamine.",
 
-'doubleredirects'     => 'Redirectiones duple',
-'doubleredirectstext' => '<b>Attention:</b> Iste lista pote continer items false.
-Illo generalmente significa que il ha texto additional con ligamines sub le prime #REDIRECT.<br />
-Cata linea contine ligamines al prime e secunde redirection, assi como le prime linea del
-secunde texto de redirection, generalmente exhibiente le articulo scopo "real",
-al qual le prime redirection deberea referer se.',
+'doubleredirects'            => 'Redirectiones duple',
+'doubleredirectstext'        => 'Iste pagina lista paginas de redirection verso altere paginas de redirection.
+Cata linea contine ligamines al prime e al secunde redirection, con le destination del secunde redirection, le qual es normalmente un "ver" pagina de destination, verso le qual le prime redirection deberea punctar.',
+'double-redirect-fixed-move' => '[[$1]] ha essite renominate, e es ora un redirection verso [[$2]]',
+'double-redirect-fixer'      => 'Corrector de redirectiones',
 
-'brokenredirects'        => 'Redirectiones van',
+'brokenredirects'        => 'Redirectiones rupte',
 'brokenredirectstext'    => 'Le redirectiones sequente se liga a articulos inexistente.',
 'brokenredirects-edit'   => '(modificar)',
 'brokenredirects-delete' => '(deler)',
@@ -1372,7 +1373,7 @@
 'nrevisions'              => '$1 {{PLURAL:$1|revision|revisiones}}',
 'nviews'                  => '$1 {{PLURAL:$1|visita|visitas}}',
 'specialpage-empty'       => 'Il non ha resultatos pro iste reporto.',
-'lonelypages'             => 'Paginas orphanas',
+'lonelypages'             => 'Paginas orphanate',
 'lonelypagestext'         => 'Nulle pagina in {{SITENAME}} ha ligamines al paginas sequente.',
 'uncategorizedpages'      => 'Paginas non classificate',
 'uncategorizedcategories' => 'Categorias non classificate',
@@ -1420,7 +1421,7 @@
 'suppress'                => 'Supervisor',
 
 # Book sources
-'booksources'               => 'Fornitores de libros',
+'booksources'               => 'Fontes de libros',
 'booksources-search-legend' => 'Cercar fontes de libros',
 'booksources-go'            => 'Ir',
 'booksources-text'          => 'Infra es un lista de ligamines a altere sitos que vende libros nove e usate, e pote etiam haber altere informationes super libros que tu cerca:',
@@ -1437,7 +1438,7 @@
 'logempty'             => 'Le registro contine nihil pro iste pagina.',
 'log-title-wildcard'   => 'Cercar titulos que comencia con iste texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tote le paginas',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Sequente pagina ($1)',
@@ -1461,15 +1462,15 @@
 'special-categories-sort-count' => 'ordinar per numero',
 'special-categories-sort-abc'   => 'ordinar alphabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Monstrar usatores a partir de:',
 'listusers-submit'   => 'Revelar',
 'listusers-noresult' => 'Nulle usator trovate.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Derectos del gruppos de usatores',
 'listgrouprights-summary'  => 'Lo sequente es un lista de gruppos de usatores definite in iste wiki, con lor derectos de accesso associate.
-Informationes additional super derectos individual se trova a [[{{MediaWiki:Listgrouprights-helppage}}]].',
+Il pote haber [[{{MediaWiki:Listgrouprights-helppage}}|informationes additional]] super derectos individual.',
 'listgrouprights-group'    => 'Gruppo',
 'listgrouprights-rights'   => 'Derectos',
 'listgrouprights-helppage' => 'Help:Derectos de gruppos',
@@ -1477,7 +1478,7 @@
 
 # E-mail user
 'mailnologin'     => 'Necun adresse de invio',
-'mailnologintext' => 'Tu debe [[Special:Userlogin|aperir un session]]
+'mailnologintext' => 'Tu debe [[Special:UserLogin|aperir un session]]
 e haber un adresse de e-mail valide in tu [[Special:Preferences|preferentias]]
 pro inviar e-mail a altere usatores.',
 'emailuser'       => 'Inviar e-mail a iste usator',
@@ -1510,12 +1511,11 @@
 'nowatchlist'          => 'Tu non ha paginas sub observation.',
 'watchlistanontext'    => 'Tu debe $1 pro poter vider o modificar entratas in tu observatorio.',
 'watchnologin'         => 'Tu non ha aperite un session',
-'watchnologintext'     => 'Tu debe [[Special:Userlogin|aperir un session]]
-pro modificar tu lista de paginas sub observation.',
+'watchnologintext'     => 'Tu debe [[Special:UserLogin|aperir un session]] pro modificar tu observatorio.',
 'addedwatch'           => 'Addite al observatorio',
 'addedwatchtext'       => "Le pagina \"<nowiki>\$1</nowiki>\" es ora in tu [[Special:Watchlist|observatorio]].
 Omne modificationes futur a iste pagina e su pagina de discussion associate essera listate ibi,
-e le pagina apparera '''in litteras grasse''' in le [[Special:Recentchanges|lista de modificationes recente]] pro
+e le pagina apparera '''in litteras grasse''' in le [[Special:RecentChanges|lista de modificationes recente]] pro
 facilitar su identification.",
 'removedwatch'         => 'Eliminate del observatorio',
 'removedwatchtext'     => 'Le pagina "<nowiki>$1</nowiki>" non es plus sub observation.',
@@ -1582,7 +1582,7 @@
 {{fullurl:{{MediaWiki:Helppage}}}}',
 
 # Delete/protect/revert
-'deletepage'                  => 'Eliminar pagina',
+'deletepage'                  => 'Deler pagina',
 'confirm'                     => 'Confirmar',
 'excontent'                   => "contento esseva: '$1'",
 'excontentauthor'             => "contento esseva: '$1' (e le sol contributor esseva '[[Special:Contributions/$2|$2]]')",
@@ -1591,10 +1591,8 @@
 'delete-confirm'              => 'Deler "$1"',
 'delete-legend'               => 'Deler',
 'historywarning'              => 'Attention: Le pagina que tu va deler ha un historia:',
-'confirmdeletetext'           => 'Tu es a puncto de eliminar permanentemente un pagina
-o imagine del base de datos, conjunctemente con tote su chronologia de versiones.
-Per favor, confirma que, si tu intende facer lo, tu comprende le consequentias,
-e tu lo face de accordo con [[{{MediaWiki:Policy-url}}]].',
+'confirmdeletetext'           => 'Tu va deler un pagina con tote su historia.
+Per favor confirma que tu intende facer isto, que tu comprende le consequentias, e que tu face isto in accordo con [[{{MediaWiki:Policy-url}}|le politicas]].',
 'actioncomplete'              => 'Action complite',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" ha essite eliminate.
 Vide $2 pro un registro de eliminationes recente.',
@@ -1618,25 +1616,26 @@
 'delete-warning-toobig'       => 'Iste pagina ha un grande historia de modificationes con plus de $1 {{PLURAL:$1|revision|revisiones}}.
 Le deletion de illo pote disrumper le operationes del base de datos de {{SITENAME}};
 procede con caution.',
-'rollback'                    => 'Reverter modificationes',
-'rollback_short'              => 'Reverter',
-'rollbacklink'                => 'reverter',
-'rollbackfailed'              => 'Reversion fallite',
-'cantrollback'                => 'Impossibile reverter le modification; le ultime contributor es le sol autor de iste pagina.',
-'alreadyrolled'               => 'Non pote reverter le ultime modification de [[:$1]] per [[User:$2|$2]] ([[User talk:$2|Talk]]);
-un altere persona ha ja modificate o revertite le pagina.
+'rollback'                    => 'Revocar modificationes',
+'rollback_short'              => 'Revocar',
+'rollbacklink'                => 'revocar',
+'rollbackfailed'              => 'Revocation fallite',
+'cantrollback'                => 'Impossibile revocar le modification;
+le ultime contributor es le sol autor de iste pagina.',
+'alreadyrolled'               => 'Non pote revocar le ultime modification de [[:$1]] per [[User:$2|$2]] ([[User talk:$2|discussion]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
+un altere persona ha ja modificate o revocate le pagina.
 
-Le ultime modification esseva facite per [[User:$3|$3]] ([[User talk:$3|Talk]]).',
+Le ultime modification esseva facite per [[User:$3|$3]] ([[User talk:$3|discussion]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Le commento del modification esseva: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Reverteva modificationes per [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]]) al ultime version per [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'rollback-success'            => 'Reverteva modificationes per $1;
+'rollback-success'            => 'Revocava modificationes per $1;
 retornava al version per $2.',
 'sessionfailure'              => 'Il pare haber un problema con tu session de conto;
 iste action ha essite cancellate como precaution contra le sequestramento de sessiones.
 Per favor preme "retro" e recarga le pagina de ubi tu ha venite, postea reprova.',
 'protectlogpage'              => 'Registro de protectiones',
 'protectlogtext'              => 'Infra es un lista de protection e disprotection de paginas.
-Vide le [[Special:Protectedpages|lista de paginas protegite]] pro le lista de protectiones de paginas actualmente in operation.',
+Vide le [[Special:ProtectedPages|lista de paginas protegite]] pro le lista de protectiones de paginas actualmente in operation.',
 'protectedarticle'            => 'protegeva "[[$1]]"',
 'modifiedarticleprotection'   => 'cambiava nivello de protection de "[[$1]]"',
 'unprotectedarticle'          => 'disprotegeva "[[$1]]"',
@@ -1692,10 +1691,10 @@
 'undeleteextrahelp'            => "Pro restaurar le pagina integre, lassa tote le quadratos dismarcate e clicca '''''Restaurar'''''.
 Pro executar un restauration selective, marca le quadratos correspondente al revisiones pro restaurar, e clicca '''''Restaurar'''''. Con le button '''''Reinitiar''''' tu pote rader le campo de commento e tote le quadratos.",
 'undeleterevisions'            => '$1 {{PLURAL:$1|revision|revisiones}} archivate',
-'undeletehistory'              => 'Si tu restaura un pagina, tote le revisiones essera restaurate al chronologia.
-Si un nove pagina con le mesme nomine ha essite create post le elimination, le revisiones
-restaurate apparera in le chronologia anterior, e le revision currente del pagina in vigor
-non essera automaticamente substituite.',
+'undeletehistory'              => 'Si tu restaura un pagina, tote le revisiones essera restaurate al historia.
+Si un nove pagina con le mesme nomine ha essite create post le deletion, le revisiones
+restaurate apparera in le historia anterior.
+Nota etiam que le restrictiones super revisiones de files es perdite al tempore de restauration.',
 'undeleterevdel'               => 'Le restauration non essera executate si illo resultara in le deletion partial del revision le plus recente del pagina o del file.
 In tal casos, tu debe dismarcar o revelar le revision delite le plus recente.',
 'undeletehistorynoadmin'       => 'Iste pagina ha essite delite.
@@ -1756,7 +1755,7 @@
 
 # What links here
 'whatlinkshere'            => 'Referentias a iste pagina',
-'whatlinkshere-title'      => 'Paginas con ligamines a $1',
+'whatlinkshere-title'      => 'Paginas con ligamines verso $1',
 'whatlinkshere-page'       => 'Pagina:',
 'linklistsub'              => '(Lista de ligamines)',
 'linkshere'                => "Le paginas sequente se liga a '''[[:$1]]''':",
@@ -1810,7 +1809,7 @@
 'badipaddress'                    => 'Adresse IP mal formate.',
 'blockipsuccesssub'               => 'Blocada succedite',
 'blockipsuccesstext'              => 'Le adresse IP "$1" ha essite blocate.
-<br />Vide [[Special:Ipblocklist|Lista de IPs blocate]] pro revider le blocadas.',
+<br />Vide [[Special:IPBlockList|Lista de IPs blocate]] pro revider le blocadas.',
 'ipb-edit-dropdown'               => 'Modificar motivos del blocada',
 'ipb-unblock-addr'                => 'Disblocar $1',
 'ipb-unblock'                     => 'Disblocar un nomine de usator o un adresse IP',
@@ -1819,14 +1818,14 @@
 'unblockip'                       => 'Disblocar adresse IP',
 'unblockiptext'                   => 'Usa le formulario infra pro restaurar le accesso de scriptura
 a un adresse IP blocate previemente.',
-'ipusubmit'                       => 'Disbloca iste adresse',
+'ipusubmit'                       => 'Disblocar iste adresse',
 'unblocked'                       => '[[User:$1|$1]] ha essite disblocate',
 'unblocked-id'                    => 'Le blocada $1 ha essite eliminate',
-'ipblocklist'                     => 'Lista de adresses IP blocate',
+'ipblocklist'                     => 'Adresses IP e nomines de usator blocate',
 'ipblocklist-legend'              => 'Cercar un usator blocate',
 'ipblocklist-username'            => 'Nomine de usator o adresse IP:',
 'ipblocklist-submit'              => 'Cercar',
-'blocklistline'                   => '$1, $2 ha blockate $3 ($4)',
+'blocklistline'                   => '$1, $2 blocava $3 ($4)',
 'infiniteblock'                   => 'infinite',
 'expiringblock'                   => 'expira le $1',
 'anononlyblock'                   => 'anon. solmente',
@@ -1844,7 +1843,7 @@
 'blocklogentry'                   => 'blocava [[$1]] con un tempore de expiration de $2 $3',
 'blocklogtext'                    => 'Isto es un registro de blocadas e disblocadas de usatores.
 Le adresses IP automaticamente blocate non es includite.
-Vide le [[Special:Ipblocklist|lista de blocadas IP]] pro le lista de bannimentos e blocadas actualmente in operation.',
+Vide le [[Special:IPBlockList|lista de blocadas IP]] pro le lista de bannimentos e blocadas actualmente in operation.',
 'unblocklogentry'                 => 'disblocava $1',
 'block-log-flags-anononly'        => 'usatores anonyme solmente',
 'block-log-flags-nocreate'        => 'creation de contos disactivate',
@@ -1898,28 +1897,24 @@
 # Move page
 'move-page'               => 'Renominar $1',
 'move-page-legend'        => 'Renominar pagina',
-'movepagetext'            => "Per medio del formulario infra tu pote renominar un pagina, e transferer tote su historia al nove nomine.
-Le titulo anterior devenira un pagina de redirection al nove titulo.
-Le ligamines al pagina anterior non essera modificate;
-assecura te de reparar omne redirectiones duple o defecte.
-Tu es responsabile pro assecurar que le ligamines continua a punctar a ubi illos deberea.
+'movepagetext'            => "Per medio del formulario infra tu pote renominar un pagina, transferente tote su historia al nove nomine.
+Le titulo anterior devenira un pagina de redirection verso le nove titulo.
+Tu pote actualisar automaticamente le redirectiones que puncta verso le titulo original.
+Si tu opta contra facer lo, assecura te de reparar omne redirectiones [[Special:DoubleRedirects|duple]] o [[Special:BrokenRedirects|defecte]].
+Tu es responsabile pro assecurar que le ligamines continua a punctar verso ubi illos deberea.
 
-Nota que le pagina '''non''' essera renominate si existe ja un pagina sub le nove titulo, salvo si illo es vacue o un redirection e non ha un historia de modificationes passate. Isto significa que tu
-pote renominar un pagina a su titulo original si tu lo ha renominate per error, e que tu non pote superscriber un pagina existente.
+Nota que le pagina '''non''' essera renominate si existe ja un pagina sub le nove titulo, salvo si illo es vacue o un redirection e non ha un historia de modificationes passate.
+Isto significa que tu pote renominar un pagina a su titulo original si tu lo ha renominate per error, e que tu non pote superscriber un pagina existente.
 
 '''ATTENTION!'''
 Isto pote esser un cambio drastic e inexpectate pro un pagina popular;
-per favor assecura te que tu comprende le consequentias de isto
-ante que tu procede.",
+per favor assecura te que tu comprende le consequentias de isto ante que tu procede.",
 'movepagetalktext'        => "Le pagina de discussion associate essera automaticamente renominate conjunctemente con illo '''a minus que''':
 *Un pagina de discussion non vacue ja existe sub le nove nomine, o
 *Tu dismarca le quadrato infra.
 
 Il tal casos, tu debera renominar o fusionar le pagina manualmente si desirate.",
 'movearticle'             => 'Renominar pagina:',
-'movenologin'             => 'Tu non ha aperite un session',
-'movenologintext'         => 'Tu debe esser un usator registrate e [[Special:Userlogin|aperir un session]]
-pro mover un pagina.',
 'movenotallowed'          => 'Tu non ha le permission de renominar paginas in {{SITENAME}}.',
 'newtitle'                => 'Al nove titulo:',
 'move-watch'              => 'Observar iste pagina',
@@ -1947,7 +1942,7 @@
 'revertmove'              => 'reverter',
 'delete_and_move'         => 'Deler e renominar',
 'delete_and_move_text'    => '==Deletion requirite==
-Le pagina de destination "[[$1]]" existe ja.
+Le pagina de destination "[[:$1]]" existe ja.
 Esque tu vole deler lo pro permitter le renomination?',
 'delete_and_move_confirm' => 'Si, deler le pagina',
 'delete_and_move_reason'  => 'Delite pro permitter renomination',
@@ -1958,6 +1953,7 @@
 'imagenocrossnamespace'   => 'Non pote renominar file verso un spatio de nomines non-file',
 'imagetypemismatch'       => 'Le nove extension del nomine del file non corresponde al typo del file',
 'imageinvalidfilename'    => 'Le nomine del file de destination es invalide',
+'fix-double-redirects'    => 'Actualisar tote le redirectiones que puncta verso le titulo original',
 
 # Export
 'export'            => 'Exportar paginas',
@@ -2005,7 +2001,8 @@
 'import-interwiki-history'   => 'Copiar tote le versiones del historia de iste pagina',
 'import-interwiki-submit'    => 'Importar',
 'import-interwiki-namespace' => 'Transferer paginas verso le spatio de nomines:',
-'importtext'                 => 'Per favor exporta le file del wiki de origine con le function Special:Export, immagazina lo in tu disco e carga lo hic.',
+'importtext'                 => 'Per favor exporta le file del wiki de origine con le [[Special:Export|facilitate pro exportar]].
+Immagazina lo in tu disco e carga lo hic.',
 'importstart'                => 'In processo de importar paginas...',
 'import-revision-count'      => '$1 {{PLURAL:$1|revision|revisiones}}',
 'importnopages'              => 'Nulle paginas a importar.',
@@ -2170,9 +2167,10 @@
 'markedaspatrollederror-noautopatrol' => 'Tu non es permittite a marcar tu proprie modificationes como patruliate.',
 
 # Patrol log
-'patrol-log-page' => 'Registro de patrulia',
-'patrol-log-line' => 'marcava $1 de $2 como patruliate $3',
-'patrol-log-auto' => '(automaticamente)',
+'patrol-log-page'   => 'Registro de patrulia',
+'patrol-log-header' => 'Isto es un registro de revisiones patruliate.',
+'patrol-log-line'   => 'marcava $1 de $2 como patruliate $3',
+'patrol-log-auto'   => '(automaticamente)',
 
 # Image deletion
 'deletedrevision'                 => 'Deleva le ancian revision $1',
@@ -2201,10 +2199,10 @@
 'show-big-image'       => 'Plen resolution',
 'show-big-image-thumb' => '<small>Dimensiones de iste previsualisation: $1 × $2 pixels</small>',
 
-# Special:Newimages
-'newimages'             => 'Galleria de nove files',
+# Special:NewImages
+'newimages'             => 'Galeria de nove files',
 'imagelisttext'         => "Infra es un lista de '''$1''' {{PLURAL:$1|imagine|imagines}} ordinate $2.",
-'newimages-summary'     => 'Iste pagina special detalia le recente files cargate',
+'newimages-summary'     => 'Iste pagina special detalia le recente files cargate.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Nihil a vider.',
 'ilsubmit'              => 'Cercar',
@@ -2469,7 +2467,7 @@
 'exif-gpslongitude-e' => 'Longitude est',
 'exif-gpslongitude-w' => 'Longitude west',
 
-'exif-gpsstatus-a' => 'Mesura in progresso',
+'exif-gpsstatus-a' => 'Mesura in curso',
 'exif-gpsstatus-v' => 'Interoperabilitate del mesura',
 
 'exif-gpsmeasuremode-2' => 'Mesura bidimensional',
@@ -2486,7 +2484,7 @@
 
 # External editor support
 'edit-externally'      => 'Modificar iste file con un programma externe',
-'edit-externally-help' => 'Vide le [http://meta.wikimedia.org/wiki/Help:External_editors instructiones de configuration] pro ulterior informationes.',
+'edit-externally-help' => 'Vide le [http://www.mediawiki.org/wiki/Manual:External_editors instructiones de configuration] pro ulterior informationes.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'totes',
@@ -2558,7 +2556,7 @@
 'recreate'            => 'Recrear',
 
 # HTML dump
-'redirectingto' => 'Redirection verso [[$1]] in progresso...',
+'redirectingto' => 'Redirection verso [[:$1]] in curso…',
 
 # action=purge
 'confirm_purge'        => 'Rader le cache de iste pagina?
@@ -2591,20 +2589,20 @@
 'table_pager_empty'        => 'Nulle resultatos',
 
 # Auto-summaries
-'autosumm-blank'   => 'Se elimina tote le contento del pagina',
+'autosumm-blank'   => 'Tote le contento es removite del pagina',
 'autosumm-replace' => "Reimplacia contento del pagina con '$1'",
 'autoredircomment' => 'Redirection verso [[$1]]',
 'autosumm-new'     => 'Nove pagina: $1',
 
 # Live preview
-'livepreview-loading' => 'Cargamento in progresso…',
-'livepreview-ready'   => 'Cargamento in progresso… Preste!',
+'livepreview-loading' => 'Cargamento in curso…',
+'livepreview-ready'   => 'Cargamento in curso… Preste!',
 'livepreview-failed'  => 'Le previsualisation directe ha fallite! Prova le previsualisation normal.',
 'livepreview-error'   => 'Impossibile connecter: $1 "$2". Prova le previsualisation normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Le modificationes plus nove que $1 secundas possibilemente non se revela in iste lista.',
-'lag-warn-high'   => 'A causa de un alte latentia del servitor de base de datos, le modificationes plus nove que $1 secundas possibilemente non se revela in iste lista.',
+'lag-warn-normal' => 'Le modificationes plus nove que $1 {{PLURAL:$1|secunda|secundas}} possibilemente non se revela in iste lista.',
+'lag-warn-high'   => 'A causa de un alte latentia del servitor de base de datos, le modificationes plus nove que $1 {{PLURAL:$1|secunda|secundas}} possibilemente non se revela in iste lista.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Tu observatorio contine {{PLURAL:$1|1 titulo|$1 titulos}}, excludente le paginas de discussion.',
@@ -2657,7 +2655,7 @@
 'version-software-product'         => 'Producto',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Cammino del file',
 'filepath-page'    => 'File:',
 'filepath-submit'  => 'Cammino',
@@ -2696,7 +2694,7 @@
 'specialpages-group-redirects'   => 'Redirection de paginas special',
 'specialpages-group-spam'        => 'Instrumentos antispam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pagina vacue',
 'intentionallyblankpage' => 'Iste pagina es intentionalmente vacue',
 
Index: languages/messages/MessagesKk_arab.php
===================================================================
--- languages/messages/MessagesKk_arab.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKk_arab.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,10 +1,11 @@
 <?php
-/** Kazakh (Arabic) (‫قازاقشا (توتە))
+/** Kazakh (Arabic script) (‫قازاقشا (تٴوتە)‬)
  *
  * @ingroup Language
+ * @file
  *
- * @author GaiJin
  * @author AlefZet
+ * @author GaiJin
  */
 
 /**
@@ -549,7 +550,7 @@
 'mypage'         => 'جەكە بەتىم',
 'mytalk'         => 'تالقىلاۋىم',
 'anontalk'       => 'IP تالقىلاۋى',
-'navigation'     => 'باعىتتاۋ',
+'navigation'     => 'شارلاۋ',
 'and'            => 'جانە',
 
 # Metadata in edit box
@@ -614,26 +615,26 @@
 'aboutsite'            => '{{SITENAME}} تۋرالى',
 'aboutpage'            => '{{ns:project}}:جوبا تۋرالى',
 'bugreports'           => 'قاتەلىك باياناتتارى',
-'bugreportspage'       => '{{ns:project}}:قاتەلىك باياناتتارى',
+'bugreportspage'       => 'Project:قاتەلىك ەسەپتەمەلەرى',
 'copyright'            => 'ماعلۇمات $1 شارتىمەن جەتىمدى.',
 'copyrightpagename'    => '{{SITENAME}} اۋتورلىق قۇقىقتارى',
 'copyrightpage'        => '{{ns:project}}:اۋتورلىق قۇقىقتار',
 'currentevents'        => 'اعىمداعى وقىيعالار',
-'currentevents-url'    => '{{ns:project}}:اعىمداعى وقىيعالار',
+'currentevents-url'    => 'Project:اعىمداعى وقىيعالار',
 'disclaimers'          => 'جاۋاپكەرشىلىكتەن باس تارتۋ',
-'disclaimerpage'       => '{{ns:project}}:جاۋاپكەرشىلىكتەن باس تارتۋ',
+'disclaimerpage'       => 'Project:جاۋاپكەرشىلىكتەن باس تارتۋ',
 'edithelp'             => 'وندەۋ انىقتاماسى',
-'edithelppage'         => '{{ns:help}}:وڭدەۋ',
+'edithelppage'         => 'Help:وڭدەۋ',
 'faq'                  => 'ٴجىيى قويىلعان ساۋالدار',
-'faqpage'              => '{{ns:project}}:ٴجىيى قويىلعان ساۋالدار',
-'helppage'             => '{{ns:help}}:مازمۇنى',
+'faqpage'              => 'Project:ٴجىيى قويىلعان ساۋالدار',
+'helppage'             => 'Help:مازمۇنى',
 'mainpage'             => 'باستى بەت',
 'mainpage-description' => 'باستى بەت',
-'policy-url'           => '{{ns:project}}:ەرەجەلەر',
+'policy-url'           => 'Project:ەرەجەلەر',
 'portal'               => 'قاۋىم پورتالى',
-'portal-url'           => '{{ns:project}}:قاۋىم پورتالى',
+'portal-url'           => 'Project:قاۋىم پورتالى',
 'privacy'              => 'جەكە قۇپىيياسىن ساقتاۋ',
-'privacypage'          => '{{ns:project}}:جەكە قۇپىيياسىن ساقتاۋ',
+'privacypage'          => 'Project:جەكە قۇپىيياسىن ساقتاۋ',
 
 'badaccess'        => 'رۇقسات قاتەسى',
 'badaccess-group0' => 'سۇراتىلعان ارەكەتىڭىزدى جەگۋىڭىزگە رۇقسات ەتىلمەيدى.',
@@ -952,10 +953,6 @@
 'blockededitsource'                => "'''$1''' دەگەنگە جاسالعان '''وڭدەمەلەرىڭىزدىڭ''' ٴماتىنى تومەندە كورسەتىلەدى:",
 'whitelistedittitle'               => 'وڭدەۋ ٴۇشىن كىرۋىڭىز ٴجون.',
 'whitelistedittext'                => 'بەتتەردى وڭدەۋ ٴۇشىن $1 ٴجون.',
-'whitelistreadtitle'               => 'وقۋ ٴۇشىن كىرۋىڭىز ٴجون',
-'whitelistreadtext'                => 'بەتتەردى وقۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون.',
-'whitelistacctitle'                => 'تىركەلگى جاساۋىڭىزعا رۇقسات بەرىلمەگەن',
-'whitelistacctext'                 => '{{SITENAME}} جوباسىنا تىركەلگى جاساۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] كەرەك جانە جاناسىمدى رۇقساتتارىڭىز بولۋ كەرەك.',
 'confirmedittitle'                 => 'قۇپتاۋ حاتى قايتا وڭدەلۋى ٴجون',
 'confirmedittext'                  => 'بەتتەردى وڭدەۋ ٴۇشىن الدىن الا ە-پوشتا مەكەنجايىڭىزدى قۇپتاۋىڭىز ٴجون.
 ە-پوشتا مەكەنجايىڭىزدى [[{{#special:Preferences}}|پايدالانۋشىلىق باپتالىمدارىڭىز]] ارقىلى قويىڭىز دا جارامدىلىعىن تەكسەرىپ شىعىڭىز.',
@@ -974,7 +971,7 @@
 'anontalkpagetext'                 => "----''بۇل تىركەلگىسىز (نەمەسە تىركەلگىسىن قولدانباعان) قاتىسۋشى تالقىلاۋ بەتى. وسى قاتىسۋشىنى ٴبىز تەك ساندىق IP مەكەنجايىمەن تەڭدەستىرەمىز.
 وسىنداي IP مەكەنجاي بىرنەشە قاتىسۋشىعا ورتاقتاستىرىلعان بولۋى مۇمكىن.
 ەگەر ٴسىز تىركەلگىسىز قاتىسۋشى بولساڭىز جانە سىزگە قاتىسسىز ماندەمەلەر جىبەرىلگەنىن سەزسەڭىز, باسقا تىركەلگىسىز قاتىسۋشىلارمەن ارالاستىرماۋى ٴۇشىن [[{{#special:Userlogin}}|تىركەلىڭىز نە كىرىڭىز]].''",
-'noarticletext'                    => 'بۇل بەتتە اعىمدا ەش ٴماتىن جوق, دەگەنمەن باسقا بەتتەردەن [[{{#special:Search}}/{{PAGENAME}}|بۇل بەت تاقىرىبى اتىن ىزدەي]] نە [{{fullurl:{{FULLPAGENAME}}|action=edit}} بۇل بەتتى وڭدەي] الاسىز.',
+'noarticletext'                    => 'بۇل بەتتە اعىمدا ەش ٴماتىن جوق, باسقا بەتتەردەن وسى بەت اتاۋىن [[Special:Search/{{PAGENAME}}|ىزدەپ كورۋىڭىزگە]] نەمەسە وسى بەتتى [{{fullurl:{{FULLPAGENAME}}|action=edit}} تۇزەتۋىڭىزگە] بولادى.',
 'userpage-userdoesnotexist'        => '«$1» قاتىسۋشى تىركەلگىسى جازىپ الىنباعان. بۇل بەتتى باستاۋ/وڭدەۋ تالابىڭىزدى تەكسەرىپ شىعىڭىز.',
 'clearyourcache'                   => "'''اڭعارتپا:''' ساقتاعاننان كەيىن, وزگەرىستەردى كورۋ ٴۇشىن شولعىش بۇركەمەسىن وراعىتۋ ىقتىيمال. '''Mozilla / Firefox / Safari:''' ''قايتا جۇكتەۋ'' باتىرماسىن نۇقىعاندا ''Shift'' تۇتىڭىز, نە ''Ctrl-Shift-R'' باسىڭىز (Apple Mac — ''Cmd-Shift-R''); '''IE:''' ''جاڭارتۋ'' باتىرماسىن نۇقىعاندا ''Ctrl'' تۇتىڭىز, نە ''Ctrl-F5'' باسىڭىز; '''Konqueror:''': ''جاڭارتۋ'' باتىرماسىن جاي نۇقىڭىز, نە ''F5'' باسىڭىز; '''Opera''' پايدانۋشىلارى ''قۇرالدار→باپتالىمدار'' دەگەنگە بارىپ بۇركەمەسىن تولىق تازارتۋ ٴجون.",
 'usercssjsyoucanpreview'           => '<strong>اقىل-كەڭەس:</strong> جاڭا CSS/JS فايلىن ساقتاۋ الدىندا «قاراپ شىعۋ» باتىرماسىن قولدانىپ سىناقتاڭىز.',
@@ -1066,11 +1063,11 @@
 'undo-success' => 'بۇل وڭدەمە جوققا شىعارىلۋى مۇمكىن. تالابىڭىزدى قۇپتاپ الدىن الا تومەندەگى سالىستىرۋدى تەكسەرىپ شىعىڭىز دا, وڭدەمەنى جوققا شىعارۋىن ٴبىتىرۋ ٴۇشىن تومەندەگى وزگەرىستەردى ساقتاڭىز.',
 'undo-failure' => 'بۇل وڭدەمە جوققا شىعارىلمايدى, سەبەبى ارادا قاقتىعىستى وڭدەمەلەر بار.',
 'undo-norev'   => 'بۇل وڭدەمە جوققا شىعارىلمايدى, سەبەبى بۇل جوق نەمەسە جويىلعان.',
-'undo-summary' => '[[{{#special:Contributions}}/$2|$2]] ([[{{ns:user_talk}}:$2|تالقىلاۋى]]) ىستەگەن ٴنومىر $1 تۇزەتۋىن جوققا شىعاردى',
+'undo-summary' => '[[Special:Contributions/$2|$2]] ([[User_talk:$2|تالقىلاۋى]]) ىستەگەن ٴنومىر $1 نۇسقاسىن جوققا شىعاردى',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'جاڭا تىركەلگى جاسالمادى',
-'cantcreateaccount-text' => "بۇل IP مەكەنجايدان ('''$1''') جاڭا تىركەلگى جاساۋىن [[{{ns:user}}:$3|$3]] بۇعاتتاعان.
+'cantcreateaccount-text' => "بۇل IP جايدان ('''$1''') جاڭا تىركەلگى جاساۋىن [[User:$3|$3]] بۇعاتتاعان.
 
 $3 كەلتىرىلگەن سەبەبى: ''$2''",
 
@@ -1247,7 +1244,7 @@
 'mypreferences'            => 'باپتالىمدارىم',
 'prefs-edits'              => 'وڭدەمە سانى:',
 'prefsnologin'             => 'كىرمەگەنسىز',
-'prefsnologintext'         => 'پايدالانۋشىلىق باپتالىمدارىڭىزدى قويۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون.',
+'prefsnologintext'         => 'باپتاۋىڭىزدى قويۋ ٴۇشىن [[Special:UserLogin|كىرۋىڭىز]] ٴتىيىستى.',
 'prefsreset'               => 'باپتالىمدار ارقاۋدان قايتا قويىلدى.',
 'qbsettings'               => 'ٴمازىر',
 'qbsettings-none'          => 'ەشقانداي',
@@ -1312,7 +1309,7 @@
 'userrights-lookup-user'      => 'قاتىسۋشى توپتارىن رەتتەۋ',
 'userrights-user-editname'    => 'قاتىسۋشى اتىن ەنگىزىڭىز:',
 'editusergroup'               => 'قاتىسۋشى توپتارىن وڭدەۋ',
-'editinguser'                 => "قاتىسۋشى قۇقىقتارىن وزگەرتۋ: '''[[{{ns:user}}:$1|$1]]''' ([[{{ns:user_talk}}:$1|{{int:talkpagelinktext}}]] | [[{{#special:Contributions}}/$1|{{int:contribslink}}]])",
+'editinguser'                 => "قاتىسۋشى قۇقىقتارىن وزگەرتۋ: '''[[User:$1|$1]]''' ([[User_talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-editusergroup'    => 'قاتىسۋشى توپتارىن وڭدەۋ',
 'saveusergroups'              => 'قاتىسۋشى توپتارىن ساقتاۋ',
 'userrights-groupsmember'     => 'مۇشەلىگى:',
@@ -1453,7 +1450,7 @@
 'reupload'                    => 'قايتا قوتارىپ بەرۋ',
 'reuploaddesc'                => 'قوتارىپ بەرۋدى بولدىرماۋ جانە قوتارۋ پىشىنىنە قايتا كەلۋ.',
 'uploadnologin'               => 'كىرمەگەنسىز',
-'uploadnologintext'           => 'فايلداردى قوتارىپ بەرۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون.',
+'uploadnologintext'           => 'فايل قوتارۋ ٴۇشىن [[Special:UserLogin|كىرۋىڭىز]] كەرەك.',
 'upload_directory_missing'    => 'قوتارىپ بەرمەك قالتاسى ($1) جەتىسپەيدى جانە ۆەب-سەرۆەر جاراتا المايدى.',
 'upload_directory_read_only'  => 'قوتارىپ بەرمەك قالتاسىنا ($1) ۆەب-سەرۆەر جازا المايدى.',
 'uploaderror'                 => 'قوتارىپ بەرۋ قاتەسى',
@@ -1560,7 +1557,7 @@
 'upload_source_url'  => ' (جارامدى, بارشاعا قاتىناۋلى URL)',
 'upload_source_file' => ' (كومپيۋتەرىڭىزدەگى فايل)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'بۇل ارنايى بەتتە بارلىق قوتارىپ بەرىلگەن فايلدار كورسەتىلەدى.
 سوڭعى قوتارىپ بەرىلگەن فايلدار تىزىمدە جوعارعى شەتىمەن ادەپكىدەن كورسەتىلەدى.
 باعاننىڭ باس جولىن نۇقىعاندا سۇرىپتاۋدىڭ رەتتەۋى وزگەرتىلەدى.',
@@ -1607,17 +1604,17 @@
 # File reversion
 'filerevert'                => '$1 دەگەندى قايتارۋ',
 'filerevert-legend'         => 'فايلدى قايتارۋ',
-'filerevert-intro'          => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' دەگەندى [$4 $3, $2 كەزىندەگى نۇسقاسىنا] قايتارۋداسىز.</span>',
+'filerevert-intro'          => "'''[[Media:$1|$1]]''' دەگەندى [$4 $3, $2 كەزىندەگى نۇسقاسىنا] قايتارۋداسىز.",
 'filerevert-comment'        => 'ماندەمەسى:',
 'filerevert-defaultcomment' => '$2, $1 كەزىندەگى نۇسقاسىنا قايتارىلدى',
 'filerevert-submit'         => 'قايتار',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' دەگەن [$4 $3, $2 كەزىندەگى نۇسقاسىنا] قايتارىلدى.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' دەگەن [$4 $3, $2 كەزىندەگى نۇسقاسىنا] قايتارىلدى.",
 'filerevert-badversion'     => 'كەلتىرىلگەن ۋاقىت بەلگىسىمەن بۇل فايلدىڭ الدىڭعى جەرگىلىكتى نۇسقاسى جوق.',
 
 # File deletion
 'filedelete'                  => '$1 دەگەندى جويۋ',
 'filedelete-legend'           => 'فايلدى جويۋ',
-'filedelete-intro'            => "'''[[{{ns:media}}:$1|$1]]''' دەگەندى جويماقسىز.",
+'filedelete-intro'            => "'''[[Media:$1|$1]]''' دەگەندى جويۋداسىز.",
 'filedelete-intro-old'        => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' — [$4 $3, $2 كەزىندەگى نۇسقاسىن] جويۋداسىز.</span>',
 'filedelete-comment'          => 'جويۋ سەبەبى:',
 'filedelete-submit'           => 'جوي',
@@ -1771,7 +1768,7 @@
 'logempty'             => 'جۋرنالدا سايكەس دانالار جوق.',
 'log-title-wildcard'   => 'مىنا ماتىننەڭ باستالىتىن تاقىرىپ اتتارىن ىزدەۋ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'بارلىق بەتتەر',
 'alphaindexline'    => '$1 — $2',
 'nextpage'          => 'كەلەسى بەتكە ($1)',
@@ -1795,12 +1792,12 @@
 'special-categories-sort-count' => 'سانىمەن سۇرىپتاۋ',
 'special-categories-sort-abc'   => 'الىپبىيمەن سۇرىپتاۋ',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'مىنا قاتىسۋشىدان باستاپ كورسەتۋ:',
 'listusers-submit'   => 'كورسەت',
 'listusers-noresult' => 'قاتىسۋشى تابىلعان جوق.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'قاتىسۋشى توبى قۇقىقتارى',
 'listgrouprights-summary'  => 'كەلەسى تىزىمدە بۇل ۋىيكىيدە تاعايىندالعان قاتىسۋشى قۇقىقتارى (بايلانىستى قاتىناۋ قۇقىقتارىمەن بىرگە) كورسەتىلەدى.
 جەكە قۇقىقتار تۋرالى كوبىرەك اقپاراتتى [[{{MediaWiki:Listgrouprights-helppage}}|مىندا]] تابا الاسىز.',
@@ -1811,7 +1808,7 @@
 
 # E-mail user
 'mailnologin'     => 'ەش مەكەنجاي جونەلتىلگەن جوق',
-'mailnologintext' => 'باسقا قاتىسۋشىعا حات جونەلتۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون, جانە [[{{#special:Preferences}}|باپتالىمدارىڭىزدا]] جارامدى ە-پوشتا مەكەنجايى بولۋى ٴجون.',
+'mailnologintext' => 'باسقا قاتىسۋشىعا حات جونەلتۋ ٴۇشىن [[Special:UserLogin|كىرۋىڭىز]] كەرەك, جانە [[Special:Preferences|باپتاۋىڭىزدا]] جارامدى ە-پوشتا جايى بولۋى ٴجون.',
 'emailuser'       => 'قاتىسۋشىعا حات جازۋ',
 'emailpage'       => 'قاتىسۋشىعا حات جازۋ',
 'emailpagetext'   => 'ەگەر بۇل قاتىسۋشى باپتاۋلارىندا جارامدى ە-پوشتا مەكەنجايىن ەنگىزسە, تومەندەگى ٴپىشىن ارقىلى بۇعان جالعىز ە-پوشتا حاتىن جونەلتۋگە بولادى.
@@ -1837,7 +1834,7 @@
 'nowatchlist'          => 'باقىلاۋ تىزىمىڭىزدە ەش دانا جوق',
 'watchlistanontext'    => 'باقىلاۋ تىزىمىڭىزدەگى دانالاردى قاراۋ, نە وڭدەۋ ٴۇشىن $1 كەرەك.',
 'watchnologin'         => 'كىرمەگەنسىز',
-'watchnologintext'     => 'باقىلاۋ ٴتىزىمىڭىزدى وزگەرتۋ ٴۇشىن [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون.',
+'watchnologintext'     => 'باقىلاۋ ٴتىزىمىڭىزدى وزگەرتۋ ٴۇشىن [[Special:UserLogin|كىرۋىڭىز]] ٴجون.',
 'addedwatch'           => 'باقىلاۋ تىزىمىنە ۇستەلدى',
 'addedwatchtext'       => "«[[:$1]]» بەتى [[{{#special:Watchlist}}|باقىلاۋ تىزىمىڭىزگە]] ۇستەلدى.
 بۇل بەتتىڭ جانە بايلانىستى تالقىلاۋ بەتىنىڭ كەلەشەكتەگى وزگەرىستەرى مىندا تىزىمدەلىنەدى دە, جانە بەتتىڭ اتاۋى جەڭىل تابىلۋ ٴۇشىن [[{{#special:Recentchanges}}|جۋىقتاعى وزگەرىستەر تىزىمىندە]] '''جۋان ارپىمەن''' كورسەتىلەدى.",
@@ -2225,8 +2222,6 @@
 
 وسى ورايدا, قالاۋىڭىز بولسا, بەتتى قولدان جىلجىتا نە قوسا الاسىز.",
 'movearticle'             => 'جىلجىتپاق بەت:',
-'movenologin'             => 'جۇيەگە كىرمەگەنسىز',
-'movenologintext'         => 'بەتتى جىلجىتۋ ٴۇشىن تىركەلگەن بولۋىڭىز جانە [[{{#special:Userlogin}}|كىرۋىڭىز]] ٴجون.',
 'movenotallowed'          => '{{SITENAME}} جوباسىندا بەتتەردى جىلجىتۋ رۋقساتىڭىز جوق.',
 'newtitle'                => 'جاڭا تاقىرىپ اتىنا:',
 'move-watch'              => 'بۇل بەتتى باقىلاۋ',
@@ -2253,7 +2248,7 @@
 'revertmove'              => 'قايتارۋ',
 'delete_and_move'         => 'جويۋ جانە جىلجىتۋ',
 'delete_and_move_text'    => '==جويۋ كەرەك==
-«[[$1]]» دەگەن نىسانا بەت الداقاشان بار.
+«[[:$1]]» دەگەن نىسانا بەت الداقاشان بار.
 جىلجىتۋعا جول بەرۋ ٴۇشىن بۇنى جوياسىز با?',
 'delete_and_move_confirm' => 'ٴىيا, بۇل بەتتى جوي',
 'delete_and_move_reason'  => 'جىلجىتۋعا جول بەرۋ ٴۇشىن جويىلعان',
@@ -2288,7 +2283,7 @@
 'allmessagescurrent'        => 'اعىمدىق ٴماتىنى',
 'allmessagestext'           => 'مىندا {{ns:mediawiki}} ەسىم اياسىندا جەتىمدى جۇيە حابار ٴتىزىمى بەرىلەدى.
 ەگەر امبەباپ MediaWiki جەرسىندىرۋگە ۇلەس قوسقىڭىز كەلسە [http://www.mediawiki.org/wiki/Localisation MediaWiki جەرسىندىرۋ بەتىنە] جانە [http://translatewiki.net Betawiki جوباسىنا] بارىپ شىعىڭىز.',
-'allmessagesnotsupportedDB' => "'''\$wgUseDatabaseMessages''' وشىرىلگەن سەبەبىنەن '''{{#special:AllMessages}}''' بەتى قولدانىلمايدى.",
+'allmessagesnotsupportedDB' => "'''\$wgUseDatabaseMessages''' وشىرىلگەن سەبەبىنەن '''{{ns:special}}:AllMessages''' بەتى قولدانىلمايدى.",
 'allmessagesfilter'         => 'حاباردى اتاۋىمەن سۇزگىلەۋ:',
 'allmessagesmodified'       => 'تەك وزگەرتىلگەندى كورسەت',
 
@@ -2508,7 +2503,7 @@
 'show-big-image'       => 'جوعارى اجىراتىلىمدى',
 'show-big-image-thumb' => '<small>قاراپ شىعۋ مولشەرى: $1 × $2 نۇكتە</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'جاڭا فايلدار كورمەسى',
 'imagelisttext'         => "تومەندە $2 سۇرىپتالعان '''$1''' فايل ٴتىزىمى.",
 'newimages-summary'     => 'بۇل ارنايى بەتىندە سوڭعى قوتارىپ بەرىلگەن فايلدار كورسەتىلەدى',
@@ -2799,7 +2794,7 @@
 
 # External editor support
 'edit-externally'      => 'بۇل فايلدى شەتتىك قوندىرما ارقىلى وڭدەۋ',
-'edit-externally-help' => 'كوبىرەك اقپارات ٴۇشىن [http://meta.wikimedia.org/wiki/Help:External_editors ورناتۋ نۇسقامالارىن] قاراڭىز.',
+'edit-externally-help' => 'كوبىرەك اقپارات ٴۇشىن [http://www.mediawiki.org/wiki/Manual:External_editors ورناتۋ نۇسقامالارىن] قاراڭىز.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'بارلىعىن',
@@ -2874,7 +2869,7 @@
 'unit-pixel' => ' نۇكتە',
 
 # HTML dump
-'redirectingto' => '[[$1]] بەتىنە ايداتۋدا…',
+'redirectingto' => '[[:$1]] بەتىنە ايداتۋدا…',
 
 # action=purge
 'confirm_purge'        => 'بۇل بەتتىن بۇركەمەسىن تازارتاسىز با?
@@ -2892,7 +2887,6 @@
 # Separators for various lists, etc.
 'semicolon-separator' => '؛',
 'comma-separator'     => '،&#32;',
-'colon-separator'     => ':&#32;',
 
 # Multipage image navigation
 'imgmultipageprev' => '← الدىڭعى بەتكە',
@@ -3025,7 +3019,7 @@
 'version-software-product'         => 'ٴونىم',
 'version-software-version'         => 'نۇسقاسى',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'فايل ورنالاسۋى',
 'filepath-page'    => 'فايل اتى:',
 'filepath-submit'  => 'ورنالاسۋىن تاپ',
Index: languages/messages/MessagesZh_hant.php
===================================================================
--- languages/messages/MessagesZh_hant.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh_hant.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,5 +1,5 @@
 <?php
-/** Traditional Chinese (‪中文(傳統字)‬)
+/** Traditional Chinese (‪中文(繁體)‬)
  *
  * @ingroup Language
  * @file
@@ -342,7 +342,7 @@
 'nosuchspecialpage' => '此特殊頁面不存在',
 'nospecialpagetext' => "<big>'''您請求的特殊頁面無效。'''</big>
 
-[[Special:Specialpages|{{int:specialpages}}]]中載有所有有效特殊頁面的列表。",
+[[Special:SpecialPages|{{int:specialpages}}]]中載有所有有效特殊頁面的列表。",
 
 # General errors
 'error'                => '錯誤',
@@ -373,7 +373,7 @@
 <p>通常這是由於修訂歷史頁上過時的連結到已經被刪除的頁面所導致的。</p>
 
 <p>如果情況不是這樣，您可能找到了軟體內的一個臭蟲。
-請記錄下URL地址，並向管理員報告。</p>',
+請記錄下URL地址，並向[[Special:ListUsers/sysop|管理員]]報告。</p>',
 'missingarticle-rev'   => '(修訂#: $1)',
 'missingarticle-diff'  => '(差異: $1, $2)',
 'readonly_lag'         => '附屬資料庫伺服器正在將快取更新到主伺服器，資料庫已被自動鎖定',
@@ -420,8 +420,8 @@
 # Login and logout pages
 'logouttitle'                => '用戶退出',
 'logouttext'                 => '您現在已經退出。
-您可以繼續以匿名方式使用{{SITENAME}}，或再次以相同或不同用戶身份登入。',
-'welcomecreation'            => '<h2>歡迎，$1!</h2><p>您的帳號已經建立，不要忘記設置{{SITENAME}}個人參數。</p>',
+您可以繼續以匿名方式使用{{SITENAME}}，或再次以相同或不同用戶身份[[Special:UserLogin|登入]]。',
+'welcomecreation'            => '<h2>歡迎，$1!</h2><p>您的帳號已經建立，不要忘記設置[[Special:Preferences|{{SITENAME}}個人參數]]。</p>',
 'loginpagetitle'             => '用戶登入',
 'yourname'                   => '您的用戶名:',
 'yourpassword'               => '您的密碼:',
@@ -557,7 +557,7 @@
 你可以聯絡$1或者其他的[[{{MediaWiki:Grouppage-sysop}}|管理員]]，討論這次查封。
 除非你已經在你的[[Special:Preferences|帳號參數設置]]中設定了一個有效的電子郵件地址，否則你是不能使用「電郵這位用戶」的功能。當設定了一個有效的電子郵件地址後，這個功能是不會封鎖的。
 
-你目前的IP地址是$3，而該查封ID是 #$5。 請你在所有查詢中註明這地址及／或查封ID。",
+你目前的IP地址是$3，而該查封ID是 #$5。 請在你的查詢中註明以上所有的資料。",
 'autoblockedtext'                  => "你的IP地址已經被自動查封，由於先前的另一位用戶被$1所查封。
 而查封的原因是：
 
@@ -565,20 +565,17 @@
 
 * 這次查封的開始時間是：$8
 * 這次查封的到期時間是：$6
+* 對於被查封者：$7
 
 你可以聯絡$1或者其他的[[{{MediaWiki:Grouppage-sysop}}|管理員]]，討論這次查封。
 除非你已經在你的[[Special:Preferences|帳號參數設置]]中設定了一個有效的電子郵件地址，否則你是不能使用「電郵這位用戶」的功能。當設定了一個有效的電子郵件地址後，這個功能是不會封鎖的。
 
-您的查封ID是 #$5。 請你在所有查詢中註明這個查封ID。",
+您現時正在使用的 IP 地址是 $3，查封ID是 #$5。 請在你的查詢中註明以上所有的資料。",
 'blockednoreason'                  => '無給出原因',
 'blockedoriginalsource'            => "以下是'''$1'''的原始碼:",
 'blockededitsource'                => "你對'''$1'''進行'''編輯'''的文字如下:",
 'whitelistedittitle'               => '登入後才可編輯',
 'whitelistedittext'                => '您必須先$1才可編輯頁面。',
-'whitelistreadtitle'               => '登入後才可閱讀',
-'whitelistreadtext'                => '您必須先[[Special:Userlogin|登入]]才可閱讀頁面。',
-'whitelistacctitle'                => '您被禁止建立帳號',
-'whitelistacctext'                 => '在{{SITENAME}}中建立帳號您必須先[[Special:Userlogin|登入]]並擁有相關許可權。',
 'confirmedittitle'                 => '郵件確認後才可編輯',
 'confirmedittext'                  => '在編輯此頁之前您必須確認您的郵箱位址。請透過[[Special:Preferences|參數設定]]設定並驗証您的郵箱位址。',
 'nosuchsectiontitle'               => '沒有這個段落',
@@ -592,7 +589,7 @@
 'newarticletext'                   => '您進入了一個尚未創建的頁面。
 要創建該頁面，請在下面的編輯框中輸入內容(詳情參見[[Help:幫助|幫助]])。
 如果您是不小心來到此頁面，直接點擊您瀏覽器中的"返回"按鈕返回。',
-'anontalkpagetext'                 => "---- ''這是一個還未建立帳號的匿名用戶的對話頁。我們因此只能用IP地址來與他／她聯絡。該IP地址可能由幾名用戶共享。如果您是一名匿名用戶並認為本頁上的評語與您無關，請[[Special:Userlogin|創建新帳號或登入]]以避免在未來於其他匿名用戶混淆。''",
+'anontalkpagetext'                 => "---- ''這是一個還未建立帳號的匿名用戶的對話頁。我們因此只能用IP地址來與他／她聯絡。該IP地址可能由幾名用戶共享。如果您是一名匿名用戶並認為本頁上的評語與您無關，請[[Special:UserLogin/signup|創建新帳號]]或[[Special:UserLogin|登入]]以避免在未來於其他匿名用戶混淆。''",
 'noarticletext'                    => '此頁目前沒有內容，您可以在其它頁[[Special:Search/{{PAGENAME}}|搜索此頁標題]]或[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} 編輯此頁]。',
 'userpage-userdoesnotexist'        => '用戶帳號「$1」未曾創建。請在創建／編輯這個頁面前先檢查一下。',
 'clearyourcache'                   => "'''注意 - 在儲存以後, 您必須清除瀏覽器的快取才能看到所作出的改變。''' '''Mozilla / Firefox / Safari:''' 按著 ''Shift'' 再點擊''重新整理''，或按下''Ctrl-F5''或''Ctrl-R''，(在Macintosh上按下''Command-R'')；'''Konqueror:''' 只需點擊 ''重新整理''或按下''F5''；'''Opera:''' 在 ''工具→設定'' 中完整地清除它們的快取；'''Internet Explorer:''' 按著 ''Ctrl'' 再點擊 ''重新整理''，或按下 ''Ctrl-F5''。",
@@ -604,12 +601,12 @@
 'note'                             => '<strong>注意:</strong>',
 'previewnote'                      => '<strong>請記住這只是預覽，內容還未保存！</strong>',
 'previewconflict'                  => '這個預覽顯示了上面文字編輯區中的內容。它將在你選擇保存後出現。',
-'session_fail_preview'             => '<strong>很抱歉！由於部份資料遺失，我們無法處理您的編輯。請再試一次，如果仍然失敗，請登出後重新登入。</strong>',
+'session_fail_preview'             => '<strong>很抱歉！由於部份資料遺失，我們無法處理您的編輯。請再試一次，如果仍然失敗，請[[Special:UserLogout|登出]]後重新登入。</strong>',
 'session_fail_preview_html'        => "<strong>很抱歉！部份資料已遺失，我們無法處理您的編輯。</strong>
 
 ''由於{{SITENAME}}已經開放原始 HTML 碼，預覽已經隱藏以預防 JavaScript 的攻擊。''
 
-<strong>如果這個編輯過程沒有問題，請再試一次。如果仍然有問題，請登出後再重新登入一次。</strong>",
+<strong>如果這個編輯過程沒有問題，請再試一次。如果仍然有問題，請[[Special:UserLogout|登出]]後再重新登入一次。</strong>",
 'token_suffix_mismatch'            => '<strong>由於您用戶端中的編輯信符毀損了一些標點符號字元，為防止編輯的文字損壞，您的編輯已經被拒絕。
 這種情況通常出現於使用含有很多臭蟲、以網絡為主的匿名代理服務的時候。</strong>',
 'editing'                          => '正在編輯$1',
@@ -651,7 +648,7 @@
 'hiddencategories'                 => '這個頁面是屬於$1個隱藏分類的成員:',
 'edittools'                        => '<!-- 此處的文字將被顯示在以下編輯和上傳表單中。 -->',
 'nocreatetitle'                    => '創建頁面受限',
-'nocreatetext'                     => '{{SITENAME}}限制了創建新頁面的功能。你可以返回並編輯已有的頁面，或者[[Special:Userlogin|登錄或創建新賬戶]]。',
+'nocreatetext'                     => '{{SITENAME}}限制了創建新頁面的功能。你可以返回並編輯已有的頁面，或者[[Special:UserLogin|登錄或創建新賬戶]]。',
 'nocreate-loggedin'                => '您在{{SITENAME}}中並無許可權去創建新頁面。',
 'permissionserrors'                => '權限錯誤',
 'permissionserrorstext'            => '根據以下的{{PLURAL:$1|原因|原因}}，您並無權限去做以下的動作:',
@@ -768,7 +765,7 @@
 # Suppression log
 'suppressionlog'     => '廢止日誌',
 'suppressionlogtext' => '以下是刪除以及由操作員牽涉到內容封鎖的清單。
-參看[[Special:Ipblocklist|IP封鎖名單]]去參看現時進行中的禁止以及封鎖之名單。',
+參看[[Special:IPBlockList|IP封鎖名單]]去參看現時進行中的禁止以及封鎖之名單。',
 
 # History merging
 'mergehistory'                     => '合併頁面歷史',
@@ -808,7 +805,7 @@
 # Search results
 'searchresults'             => '搜索結果',
 'searchresulttext'          => '有關搜索{{SITENAME}}的更多詳情,參見[[{{MediaWiki:Helppage}}|{{int:help}}]]。',
-'searchsubtitle'            => '查詢"[[:$1]]"',
+'searchsubtitle'            => '查詢\'\'\'[[:$1]]\'\'\'([[Special:Prefixindex/$1|所有以 "$1" 開頭的頁面]] | [[Special:WhatLinksHere/$1|所有鏈接到 "$1" 的頁面]])',
 'searchsubtitleinvalid'     => '查詢"$1"',
 'noexactmatch'              => "'''沒找到標題為\"\$1\"的頁面。''' 您可以[[:\$1|創建此頁面]]。",
 'noexactmatch-nocreate'     => "'''沒找到標題為\"\$1\"的頁面。'''",
@@ -851,7 +848,7 @@
 'mypreferences'            => '我的參數設置',
 'prefs-edits'              => '編輯數量:',
 'prefsnologin'             => '還未登入',
-'prefsnologintext'         => '您必須先[[Special:Userlogin|登入]]才能設置個人參數。',
+'prefsnologintext'         => '您必須先[[Special:UserLogin|登入]]才能設置個人參數。',
 'prefsreset'               => '參數已重新設置。',
 'qbsettings'               => '快速導航條',
 'qbsettings-none'          => '無',
@@ -925,7 +922,7 @@
 'userrights-reason'           => '更改原因:',
 'userrights-no-interwiki'     => '您並沒有權限去編輯在其它wiki上的用戶權限。',
 'userrights-nodatabase'       => '資料庫$1不存在或並非為本地的。',
-'userrights-nologin'          => '您必須要以操作員帳戶[[Special:Userlogin|登入]]之後才可以指定用戶權限。',
+'userrights-nologin'          => '您必須要以操作員帳戶[[Special:UserLogin|登入]]之後才可以指定用戶權限。',
 'userrights-notallowed'       => '您的帳戶無權限去指定用戶權限。',
 'userrights-changeable-col'   => '您可以更改的群組',
 'userrights-unchangeable-col' => '您不可以更改的群組',
@@ -1055,26 +1052,28 @@
 'reupload'                    => '重新上載',
 'reuploaddesc'                => '取消上載並返回上載表單',
 'uploadnologin'               => '未登入',
-'uploadnologintext'           => '您必須先[[Special:Userlogin|登入]]
+'uploadnologintext'           => '您必須先[[Special:UserLogin|登入]]
 才能上載檔案。',
 'upload_directory_missing'    => '上傳目錄($1)遺失，不能由網頁伺服器建立。',
 'upload_directory_read_only'  => '上傳目錄($1)不存在或無寫權限。',
 'uploaderror'                 => '上載錯誤',
 'uploadtext'                  => "使用下面的表單來上傳檔案。
 要檢視或搜索以前上傳的檔案
-可以進入[[Special:Imagelist|檔案上傳清單]]，
-上傳和刪除將在[[Special:Log/upload|上傳日誌]]中記錄。
+可以進入[[Special:ImageList|檔案上傳清單]]，
+（重新）上傳將在[[Special:Log/upload|上傳日誌]]中記錄，
+而刪除將在[[Special:Log/delete|刪除日誌]]中記錄。
 
-要在頁面中加入檔案，使用以下形式的連接:
-'''<nowiki>[[{{ns:image}}:file.jpg]]</nowiki>'''，
-'''<nowiki>[[{{ns:image}}:file.png|替換文字]]</nowiki>''' 或
-'''<nowiki>[[{{ns:media}}:file.ogg]]</nowiki>'''。",
+要在頁面中加入檔案，使用以下其中一種形式的連接:
+* '''<tt><nowiki>[[{{ns:image}}:file.jpg]]</nowiki></tt>'''去用檔案的完整版本
+* '''<tt><nowiki>[[{{ns:image}}:file.png|200px|thumb|left|替換文字]]</nowiki></tt>'''去用一個200像素寬，左面盒上有'替換文字'的描述
+* '''<tt><nowiki>[[{{ns:media}}:file.ogg]]</nowiki></tt>'''去直接連接到檔案而不顯示檔案",
 'upload-permitted'            => '准許的檔案類型: $1。',
 'upload-preferred'            => '建議的檔案類型: $1。',
 'upload-prohibited'           => '禁止的檔案類型: $1。',
 'uploadlog'                   => '上載紀錄',
 'uploadlogpage'               => '上載紀錄',
-'uploadlogpagetext'           => '以下是最近上載的檔案的一覽表。',
+'uploadlogpagetext'           => '以下是最近上載的檔案的一覽表。
+查看[[Special:NewImages|新檔案畫廊]]去看更富圖像的總覽。',
 'filename'                    => '檔案名',
 'filedesc'                    => '檔案描述',
 'fileuploadsummary'           => '檔案描述:',
@@ -1133,9 +1132,9 @@
 'upload-proto-error'      => '協議錯誤',
 'upload-proto-error-text' => '遠程上傳要求 URL 以 <code>http://</code> 或 <code>ftp://</code> 開頭。',
 'upload-file-error'       => '內部錯誤',
-'upload-file-error-text'  => '當試圖在伺服器上創建臨時檔案時發生內部錯誤。請與系統管理員聯繫。',
+'upload-file-error-text'  => '當試圖在伺服器上創建臨時檔案時發生內部錯誤。請與[[Special:ListUsers/sysop|管理員]]聯繫。',
 'upload-misc-error'       => '未知的上傳錯誤',
-'upload-misc-error-text'  => '在上傳時發生未知的錯誤. 請驗証使用了正確並可訪問的 URL，然後進行重試。如果問題仍然存在，請與系統管理員聯繫。',
+'upload-misc-error-text'  => '在上傳時發生未知的錯誤. 請驗証使用了正確並可訪問的 URL，然後進行重試。如果問題仍然存在，請與[[Special:ListUsers/sysop|管理員]]聯繫。',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => '無法訪問 URL',
@@ -1149,7 +1148,7 @@
 'upload_source_url'  => ' (一個有效的，可公開訪問的 URL)',
 'upload_source_file' => ' (在您電腦上的一個檔案)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => '這個特殊頁面顯示所有上傳過的檔案。
 預設中最後上傳的檔案會顯示在這個列表中的最頂處。
 點擊一欄的標題去改變這個排列。',
@@ -1177,7 +1176,7 @@
 'imagelinks'                     => '連結',
 'linkstoimage'                   => '以下的$1個頁面連接到本檔案:',
 'nolinkstoimage'                 => '沒有頁面連接到本檔案。',
-'morelinkstoimage'               => '查看連接到這個檔案的[[Special:Whatlinkshere/$1|更多連結]]。',
+'morelinkstoimage'               => '查看連接到這個檔案的[[Special:WhatLinksHere/$1|更多連結]]。',
 'redirectstofile'                => '以下的$1個檔案重新定向到這個檔案:',
 'duplicatesoffile'               => '以下的$1個檔案是跟這個檔案重覆:',
 'sharedupload'                   => '該檔案是一個共享上傳，它可能在其它項目中被應用。',
@@ -1196,22 +1195,22 @@
 # File reversion
 'filerevert'                => '恢復$1',
 'filerevert-legend'         => '恢復檔案',
-'filerevert-intro'          => '<span class="plainlinks">您現正在恢復\'\'\'[[Media:$1|$1]]\'\'\'到[$4 於$2 $3的版本]。</span>',
+'filerevert-intro'          => "您現正在恢復'''[[Media:$1|$1]]'''到[$4 於$2 $3的版本]。",
 'filerevert-comment'        => '註解:',
 'filerevert-defaultcomment' => '已經恢復到於$1 $2的版本',
 'filerevert-submit'         => '恢復',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'已經恢復到[$4 於$2 $3的版本]。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''已經恢復到[$4 於$2 $3的版本]。",
 'filerevert-badversion'     => '這個檔案所提供的時間截記並無先前的本地版本。',
 
 # File deletion
 'filedelete'                  => '刪除$1',
 'filedelete-legend'           => '刪除檔案',
 'filedelete-intro'            => "您現正刪除'''[[Media:$1|$1]]'''。",
-'filedelete-intro-old'        => '<span class="plainlinks">你現正刪除\'\'\'[[Media:$1|$1]]\'\'\'於[$4 $2 $3]的版本。</span>',
+'filedelete-intro-old'        => "你現正刪除'''[[Media:$1|$1]]'''於[$4 $2 $3]的版本。",
 'filedelete-comment'          => '刪除理由:',
 'filedelete-submit'           => '刪除',
 'filedelete-success'          => "'''$1'''已經刪除。",
-'filedelete-success-old'      => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'於 $2 $3 的版本已經刪除。</span>',
+'filedelete-success-old'      => "'''[[Media:$1|$1]]'''於 $2 $3 的版本已經刪除。",
 'filedelete-nofile'           => "'''$1'''在{{SITENAME}}中不存在。",
 'filedelete-nofile-old'       => "在已指定屬性的情況下，這裡沒有'''$1'''於 $2 $3 的版本。",
 'filedelete-iscurrent'        => '您現正嘗試刪除這個檔案的最近版本。請先將個該檔案回退成較舊的版本。',
@@ -1262,7 +1261,7 @@
 即每頁平均編輯'''\$5'''次，各次編輯後頁面的每個版本平均瀏覽'''\$6'''次。
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue 工作隊列]的長度是'''\$7'''。",
-'userstatstext'          => "網站有'''$1'''位註冊[[Special:Listusers|用戶]]，其中
+'userstatstext'          => "網站有'''$1'''位註冊[[Special:ListUsers|用戶]]，其中
 '''$2''' (或 '''$4%''') 有$5許可權。",
 'statistics-mostpopular' => '被查閱次數最多的頁面',
 
@@ -1276,16 +1275,18 @@
 Template:消除歧義',
 'disambiguations-text' => '以下的頁面都有到<b>消含糊頁</b>的鏈接, 但它們應該是連到適當的標題。<br />一個頁面會被視為消含糊頁如果它是連自[[MediaWiki:Disambiguationspage]]。',
 
-'doubleredirects'     => '雙重重定向頁面',
-'doubleredirectstext' => '這一頁列出所有重定向頁面重定向到另一個重定向頁的頁面。每一行都包含到第一和第二個重定向頁面的鏈接，以及第二個重定向頁面的目標，通常顯示的都會是"真正"的目標頁面，也就是第一個重定向頁面應該指向的頁面。',
+'doubleredirects'            => '雙重重定向頁面',
+'doubleredirectstext'        => '這一頁列出所有重定向頁面重定向到另一個重定向頁的頁面。每一行都包含到第一和第二個重定向頁面的鏈接，以及第二個重定向頁面的目標，通常顯示的都會是"真正"的目標頁面，也就是第一個重定向頁面應該指向的頁面。',
+'double-redirect-fixed-move' => '[[$1]]已經完成移動，它現在重新定向到[[$2]]',
+'double-redirect-fixer'      => '重新定向修正器',
 
 'brokenredirects'        => '損壞的重定向頁',
-'brokenredirectstext'    => '以下的重定向頁指向的是不存在的頁面:',
+'brokenredirectstext'    => '以下的重定向頁指向的是不存在的頁面。',
 'brokenredirects-edit'   => '(編輯)',
 'brokenredirects-delete' => '(刪除)',
 
 'withoutinterwiki'         => '未有語言鏈接的頁面',
-'withoutinterwiki-summary' => '以下的頁面是未有語言鏈接到其它語言版本:',
+'withoutinterwiki-summary' => '以下的頁面是未有語言鏈接到其它語言版本。',
 'withoutinterwiki-legend'  => '前綴',
 'withoutinterwiki-submit'  => '顯示',
 
@@ -1362,7 +1363,7 @@
 'logempty'             => '在日誌中不存在匹配項。',
 'log-title-wildcard'   => '搜尋以這個文字開始的標題',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '所有頁面',
 'alphaindexline'    => '$1 到 $2',
 'nextpage'          => '下一頁($1)',
@@ -1385,12 +1386,12 @@
 'special-categories-sort-count' => '按數量排列',
 'special-categories-sort-abc'   => '按字母排列',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '給定顯示用戶條件:',
 'listusers-submit'   => '顯示',
 'listusers-noresult' => '找不到用戶。',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => '用戶群組權限',
 'listgrouprights-summary'  => '以下面是一個在這個wiki中定義出來的用戶權限清單，以及它們的存取權。
 更多有關個別權限的細節可以在[[{{MediaWiki:Listgrouprights-helppage}}|這裏]]找到。',
@@ -1401,12 +1402,12 @@
 
 # E-mail user
 'mailnologin'     => '無電郵地址',
-'mailnologintext' => '您必須先[[Special:Userlogin|登入]]
+'mailnologintext' => '您必須先[[Special:UserLogin|登入]]
 並在[[Special:Preferences|參數設置]]
 中有一個有效的e-mail地址才可以電郵其他用戶。',
 'emailuser'       => 'E-mail該用戶',
 'emailpage'       => 'E-mail用戶',
-'emailpagetext'   => '如果該用戶已經在他或她的參數設置頁中輸入了有效的e-mail地址，以下的表格將寄一個訊息給該用戶。您在您參數設置中所輸入的e-mail地址將出現在郵件「發件人」一欄中，這樣該用戶就可以回覆您。',
+'emailpagetext'   => '如果該用戶已經在他或她的參數設置頁中輸入了有效的e-mail地址，以下的表格將寄一個訊息給該用戶。您在[[Special:Preferences|您參數設置]]中所輸入的e-mail地址將出現在郵件「發件人」一欄中，這樣該用戶就可以回覆您。',
 'usermailererror' => '目標郵件地址返回錯誤：',
 'defemailsubject' => '{{SITENAME}}電子郵件',
 'noemailtitle'    => '無e-mail地址',
@@ -1430,15 +1431,15 @@
 'nowatchlist'          => '您的監視列表為空。',
 'watchlistanontext'    => '請$1以檢視或編輯您的監視列表。',
 'watchnologin'         => '未登入',
-'watchnologintext'     => '您必須先[[Special:Userlogin|登入]]
+'watchnologintext'     => '您必須先[[Special:UserLogin|登入]]
 才能更改您的監視列表',
 'addedwatch'           => '加入到監視列表',
 'addedwatchtext'       => "頁面\"[[:\$1]]\"已經被加入到您的[[Special:Watchlist|監視清單]]中。
 將來有關此頁面及其討論頁的任何修改將會在那裡列出，
-而且還會在[[Special:Recentchanges|最近更改]]中
+而且還會在[[Special:RecentChanges|最近更改]]中
 以'''粗體'''形式列出以使起更容易識別。",
 'removedwatch'         => '已停止監視',
-'removedwatchtext'     => '頁面「<nowiki>$1</nowiki>」已經從您的監視頁面中移除。',
+'removedwatchtext'     => '頁面「<nowiki>$1</nowiki>」已經從[[Special:Watchlist|您的監視頁面]]中移除。',
 'watch'                => '監視',
 'watchthispage'        => '監視本頁',
 'unwatch'              => '取消監視',
@@ -1537,16 +1538,16 @@
 'rollbacklink'                => '恢復',
 'rollbackfailed'              => '無法恢復',
 'cantrollback'                => '無法恢復編輯；最後的貢獻者是本文的唯一作者。',
-'alreadyrolled'               => '無法恢復由[[User:$2|$2]] ([[User talk:$2|討論]])進行的[[$1]]的最後編輯；
+'alreadyrolled'               => '無法恢復由[[User:$2|$2]] ([[User talk:$2|討論]]  | [[Special:Contributions/$2|{{int:contribslink}}]])進行的[[$1]]的最後編輯；
 其他人已經編輯或是恢復了該頁。
 
-最後編輯者: [[User:$3|$3]] ([[User talk:$3|討論]])。',
+最後對頁面編輯的編輯者: [[User:$3|$3]] ([[User talk:$3|討論]] | [[Special:Contributions/$3|{{int:contribslink}}]])。',
 'editcomment'                 => '編輯說明: "<i>$1</i>"。', # only shown if there is an edit comment
 'revertpage'                  => '恢復由[[Special:Contributions/$2|$2]] ([[User talk:$2|對話]])的編輯至[[User:$1|$1]]的最後一個版本', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '恢復由$1的編輯；更改回$2的最後一個版本。',
 'sessionfailure'              => '您的登入資訊似乎有問題，為防止此該訊息被攔截，本次操作已經取消，請按「上一頁」重新載入。',
 'protectlogpage'              => '保護日誌',
-'protectlogtext'              => '下面是頁面鎖定和取消鎖定的列表。請參考[[Special:Protectedpages|保護頁面清單]]以檢視當前進行的頁面保護。',
+'protectlogtext'              => '下面是頁面鎖定和取消鎖定的列表。請參考[[Special:ProtectedPages|保護頁面清單]]以檢視當前進行的頁面保護。',
 'protectedarticle'            => '已保護"[[$1]]"',
 'modifiedarticleprotection'   => '已經更改 "[[$1]]" 的保護等級',
 'unprotectedarticle'          => '已解除保護"[[$1]]"',
@@ -1654,7 +1655,7 @@
 
 # What links here
 'whatlinkshere'            => '鏈入頁面',
-'whatlinkshere-title'      => '鏈接到$1的頁面',
+'whatlinkshere-title'      => '鏈接到「$1」的頁面',
 'whatlinkshere-page'       => '頁面:',
 'linklistsub'              => '(連結列表)',
 'linkshere'                => '以下頁面連結到[[:$1]]：',
@@ -1706,7 +1707,7 @@
 'badipaddress'                    => 'IP地址不正確。',
 'blockipsuccesssub'               => '查封成功',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]]已經被查封。
-<br />參看[[Special:Ipblocklist|被封IP地址列表]]以覆審查封。',
+<br />參看[[Special:IPBlockList|被封IP地址列表]]以覆審查封。',
 'ipb-edit-dropdown'               => '編輯查封原因',
 'ipb-unblock-addr'                => '解除封禁$1',
 'ipb-unblock'                     => '解除禁封用戶名或IP地址',
@@ -1736,7 +1737,7 @@
 'autoblocker'                     => '你的IP和被封了的 "$1" 是一樣的。封鎖原因： "$2".',
 'blocklogpage'                    => '封鎖記錄',
 'blocklogentry'                   => '[[$1]]已被查封 $3 ，終止時間為$2',
-'blocklogtext'                    => '這是關於用戶封禁和解除封禁操作的記錄。被自動封禁的IP地址沒有被列出。請參閱[[Special:Ipblocklist|被查封的IP地址和用戶列表]]。',
+'blocklogtext'                    => '這是關於用戶封禁和解除封禁操作的記錄。被自動封禁的IP地址沒有被列出。請參閱[[Special:IPBlockList|被查封的IP地址和用戶列表]]。',
 'unblocklogentry'                 => '[[$1]]已被解封',
 'block-log-flags-anononly'        => '僅限匿名用戶',
 'block-log-flags-nocreate'        => '禁止此IP/用戶建立新帳戶',
@@ -1783,8 +1784,8 @@
 'move-page-legend'        => '移動頁面',
 'movepagetext'            => "用下面的表單來重新命名一個頁面，並將其修訂歷史同時移動到新頁面。
 老的頁面將成為新頁面的重定向頁。
-連結到老頁面的連結並不會自動更改；
-請檢查雙重或損壞重定向連結。
+您可以自動地更新指到原標題的重定向。
+如果您選擇不去做的話，請檢查[[Special:DoubleRedirects|雙重]]或[[Special:BrokenRedirects|損壞重定向]]連結。
 您應當負責確定所有連結依然會連到指定的頁面。
 
 注意如果新頁面已經有內容的話，頁面將'''不會'''被移動，
@@ -1802,9 +1803,6 @@
 
 在這些情況下，您在必要時必須手工移動或合併頁面。",
 'movearticle'             => '移動頁面:',
-'movenologin'             => '未登入',
-'movenologintext'         => '您必須是一名登記用戶並且[[Special:Userlogin|登入]]
-後才可移動一個頁面。',
 'movenotallowed'          => '您在{{SITENAME}}中度並沒有許可權去移動頁面。',
 'newtitle'                => '新標題:',
 'move-watch'              => '監視此頁',
@@ -1832,7 +1830,7 @@
 'delete_and_move'         => '刪除並移動',
 'delete_and_move_text'    => '==需要刪除==
 
-目標頁面"[[$1]]"已經存在。你確認需要刪除原頁面並以進行移動嗎？',
+目標頁面"[[:$1]]"已經存在。你確認需要刪除原頁面並以進行移動嗎？',
 'delete_and_move_confirm' => '是的，刪除此頁面',
 'delete_and_move_reason'  => '刪除以便移動',
 'selfmove'                => '原始標題與目標標題相同，您不能移動一頁覆蓋本身。',
@@ -1840,6 +1838,7 @@
 'imagenocrossnamespace'   => '不可以移動檔案到非檔案名字空間',
 'imagetypemismatch'       => '該新副檔名不匹配它的類型',
 'imageinvalidfilename'    => '目標檔案名稱是無效的',
+'fix-double-redirects'    => '更新指到原先標題的任何重新定向',
 
 # Export
 'export'            => '匯出頁面',
@@ -1888,7 +1887,8 @@
 'import-interwiki-history'   => '複製此頁的所有歷史版本',
 'import-interwiki-submit'    => '匯入',
 'import-interwiki-namespace' => '將頁面轉移到名字空間:',
-'importtext'                 => '請使用 Special:Export 功能從源 wiki 匯出檔案，儲存到您的磁片並上傳到這裡。',
+'importtext'                 => '請使用[[Special:Export|匯出功能]]從源 wiki 匯出檔案，
+儲存到您的磁片並上傳到這裡。',
 'importstart'                => '正在匯入頁面...',
 'import-revision-count'      => '$1個修訂',
 'importnopages'              => '沒有匯入的頁面。',
@@ -2052,9 +2052,10 @@
 'markedaspatrollederror-noautopatrol' => '您無法將你自己所作的更改標記為已檢查。',
 
 # Patrol log
-'patrol-log-page' => '巡查日誌',
-'patrol-log-line' => '$2的版本$1已被標記為已檢查的$3',
-'patrol-log-auto' => '(自動)',
+'patrol-log-page'   => '巡查日誌',
+'patrol-log-header' => '這個是已經巡查過的日誌。',
+'patrol-log-line'   => '$2的版本$1已被標記為已檢查的$3',
+'patrol-log-auto'   => '(自動)',
 
 # Image deletion
 'deletedrevision'                 => '已刪除舊版本$1',
@@ -2083,10 +2084,10 @@
 'show-big-image'       => '完整解像度',
 'show-big-image-thumb' => '<small>這幅縮圖的解像度: $1 × $2 像素</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新建圖像畫廊',
 'imagelisttext'         => "以下是按$2排列的'''$1'''個檔案列表。",
-'newimages-summary'     => '這個特殊頁面中顯示最後已上傳的檔案',
+'newimages-summary'     => '這個特殊頁面中顯示最後已上傳的檔案。',
 'showhidebots'          => '($1機器人)',
 'noimages'              => '無可檢視圖像。',
 'ilsubmit'              => '搜尋',
@@ -2382,7 +2383,7 @@
 
 # External editor support
 'edit-externally'      => '用外部程式編輯此檔案',
-'edit-externally-help' => '請參見[http://meta.wikimedia.org/wiki/Help:External_editors 設定步驟]了解詳細資訊。',
+'edit-externally-help' => '請參見[http://www.mediawiki.org/wiki/Manual:External_editors 設定步驟]了解詳細資訊。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全部',
@@ -2409,7 +2410,7 @@
 郵件傳送員回應: $1',
 'confirmemail_invalid'     => '無效的確認碼，該代碼可能已經過期。',
 'confirmemail_needlogin'   => '您需要$1以確認您的郵箱位址。',
-'confirmemail_success'     => '您的郵箱已經被確認。您現下可以登錄並使用此網站了。',
+'confirmemail_success'     => '您的郵箱已經被確認。您現在可以[[Special:UserLogin|登錄]]並使用此網站了。',
 'confirmemail_loggedin'    => '您的郵箱位址現下已被確認。',
 'confirmemail_error'       => '你的確認過程發生錯誤。',
 'confirmemail_subject'     => '{{SITENAME}}郵箱位址確認',
@@ -2444,11 +2445,12 @@
 
 # Delete conflict
 'deletedwhileediting' => '警告: 此頁在您開始編輯之後已經被刪除﹗',
-'confirmrecreate'     => '在您編輯這個頁面後，用戶[[User:$1|$1]]([[User talk:$1|對話]])以下列原因刪除了這個頁面: $2。請在重新創建頁面前三思。',
+'confirmrecreate'     => '在您編輯這個頁面後，用戶[[User:$1|$1]]([[User talk:$1|對話]])以下列原因刪除了這個頁面: $2。
+請確認在您重新創建頁面前三思。',
 'recreate'            => '重建',
 
 # HTML dump
-'redirectingto' => '重定向到[[$1]]...',
+'redirectingto' => '重定向到[[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '要清除此頁面的快取嗎?\\n\\n$1',
@@ -2543,7 +2545,7 @@
 'version-software-product'         => '產品',
 'version-software-version'         => '版本',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => '檔案路徑',
 'filepath-page'    => '檔案名:',
 'filepath-submit'  => '搜尋路徑',
@@ -2581,7 +2583,7 @@
 'specialpages-group-redirects'   => '重新定向特殊頁面',
 'specialpages-group-spam'        => '反垃圾工具',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => '空白頁面',
 'intentionallyblankpage' => '這個頁面是為空白，以用來作測試速度等用途',
 
Index: languages/messages/MessagesFur.php
===================================================================
--- languages/messages/MessagesFur.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFur.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Helix84
  * @author Klenje
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Helix84
  */
 
 $fallback = 'it';
@@ -149,6 +148,7 @@
 'tog-externaldiff'            => 'Dopre editôr difarencis esterni come opzion predeterminade',
 'tog-watchlisthideown'        => 'Plate i miei cambiaments inte liste des pagjinis tignudis di voli',
 'tog-ccmeonemails'            => 'Mandimi une copie dai messaçs che o mandi ai altris utents',
+'tog-showhiddencats'          => 'Mostre categoriis platadis',
 
 'underline-always'  => 'Simpri',
 'underline-never'   => 'Mai',
@@ -209,12 +209,20 @@
 'dec'           => 'Dic',
 
 # Categories related messages
-'pagecategories'         => '{{PLURAL:$1|Categorie|Categoriis}}',
-'category_header'        => 'Vôs inte categorie "$1"',
-'subcategories'          => 'Sot categoriis',
-'category-media-header'  => 'Files inte categorie "$1"',
-'category-empty'         => "''Par cumò la categorie no conten ni pagjinis ni files multimediâi.''",
-'listingcontinuesabbrev' => 'cont.',
+'pagecategories'                 => '{{PLURAL:$1|Categorie|Categoriis}}',
+'category_header'                => 'Vôs inte categorie "$1"',
+'subcategories'                  => 'Sot categoriis',
+'category-media-header'          => 'Files inte categorie "$1"',
+'category-empty'                 => "''Par cumò la categorie no conten ni pagjinis ni files multimediâi.''",
+'hidden-categories'              => '{{PLURAL:$1|Categorie platade|Categoriis platadis}}',
+'hidden-category-category'       => 'Categoriis platadis', # Name of the category where hidden categories will be listed
+'category-subcat-count'          => '{{PLURAL:$2|Cheste categorie e conten une sot categorie, mostrade ca sot.|Cheste categorie e conten {{PLURAL:$1|la sot categorie|lis $1 sot categoriis}} ca sot suntun totâl di $2.}}',
+'category-subcat-count-limited'  => 'Cheste categorie e conten {{PLURAL:$1|une sot categorie, mostrade|$1 sot categoriis, mostradis}} sot.',
+'category-article-count'         => '{{PLURAL:$2|Cheste categorie e conten dome une pagjine mostrade ca sot.|Cheste categorie e conten {{PLURAL:$1|la pagjine indicade|lis $1 pagjinis indicadis}} di seguit, suntun totâl di $2.}}',
+'category-article-count-limited' => 'Cheste categorie e conten {{PLURAL:$1|la pagjine|lis $1 pagjinis}} ca sot.',
+'category-file-count'            => '{{PLURAL:$2|Cheste categorie e conten dome un file, mostrât ca sot.|Cheste categorie e conten {{PLURAL:$1|un file, mostrât|$1 files, mostrâts}} ca sot, suntun totâl di $2.}}',
+'category-file-count-limited'    => 'Cheste categorie e conten {{PLURAL:$1|il file mostrât|i $1 files mostrâts}} ca sot.',
+'listingcontinuesabbrev'         => 'cont.',
 
 'mainpagetext' => "'''MediaWiki e je stade instalade cun sucès.'''",
 
@@ -342,7 +350,7 @@
 # Main script and global functions
 'nospecialpagetext' => "<big>'''Tu âs cirût une pagjine speciâl no valide.'''</big>
 
-Une liste des pagjinis speciâls validis a si pues cjatâ su [[Special:Specialpages|{{int:specialpages}}]].",
+Une liste des pagjinis speciâls validis a si pues cjatâ su [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'           => 'Erôr',
@@ -466,8 +474,10 @@
 'savearticle'            => 'Salve la pagjine',
 'preview'                => 'Anteprime',
 'showpreview'            => 'Mostre anteprime',
+'showlivepreview'        => "Anteprime ''live''",
 'showdiff'               => 'Mostre cambiaments',
 'anoneditwarning'        => 'No tu sês jentrât cuntun non utent. La to direzion IP e vignarà regjistrade tal storic di cheste pagjine.',
+'missingcommenttext'     => 'Inserìs un coment ca sot.',
 'summary-preview'        => 'Anteprime dal somari',
 'subject-preview'        => 'Anteprime ogjet/intestazion',
 'blockedtitle'           => 'Utent blocât',
@@ -514,7 +524,7 @@
 'templatesusedsection'   => 'Modei doprâts in cheste sezion:',
 'template-protected'     => '(protezût)',
 'template-semiprotected' => '(semi-protezût)',
-'nocreatetext'           => '{{SITENAME}} al à limitât la pussibilitât di creâ gnovis pagjinis ai utents regjistrâts. Tu puedis tornâ indaûr e cambiâ une pagjine che e esist o se no [[Special:Userlogin|jentrâ o creâ une gnove identitât]].',
+'nocreatetext'           => '{{SITENAME}} al à limitât la pussibilitât di creâ gnovis pagjinis ai utents regjistrâts. Tu puedis tornâ indaûr e cambiâ une pagjine che e esist o se no [[Special:UserLogin|jentrâ o creâ une gnove identitât]].',
 'recreate-deleted-warn'  => "'''Atenzion: tu stâs par tornâ a creâ une pagjine che e je stade eliminade timp fa.'''
 
 Siguriti che sedi pardabon oportun lâ indevant cun la modifiche di cheste pagjine.
@@ -661,7 +671,7 @@
 'reupload'           => 'Torne a cjamâ sù',
 'uploadnologin'      => 'No jentrât',
 'uploaderror'        => 'Erôr cjamant sù',
-'uploadtext'         => "Dopre la form ca sot par cjamâ sù un file, par cjalâ o cirî i files cjamâts sù in precedence va te [[Special:Imagelist|liste dai files cjamâts sù]], lis cjamadis e lis eliminazions a son ancje regjistrâts tal [[Special:Log/upload|regjistri des cjamadis]].
+'uploadtext'         => "Dopre la form ca sot par cjamâ sù un file, par cjalâ o cirî i files cjamâts sù in precedence va te [[Special:ImageList|liste dai files cjamâts sù]], lis cjamadis e lis eliminazions a son ancje regjistrâts tal [[Special:Log/upload|regjistri des cjamadis]].
 
 Par includi une figure intune pagjine, dopre un leam inte form
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:file.jpg]]</nowiki>''',
@@ -687,7 +697,7 @@
 'sourcefilename'     => 'Non dal file origjinâl:',
 'destfilename'       => 'Non dal file di destinazion:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'             => 'Liste des figuris',
 'imagelist_date'        => 'Date',
 'imagelist_name'        => 'Non',
@@ -749,7 +759,7 @@
 O vin vût in dut '''\$3''' {{PLURAL:\$3|viodude|viodudis}} des pagjinis e '''\$4''' {{PLURAL:\$4|cambiament|cambiaments}} aes pagjinis di cuant che la wiki e je stade implantade. Chest al vûl dî une medie di '''\$5''' cambiaments par pagjine, e '''\$6''' viodudis par ogni cambiament.
 
 La code dai [http://www.mediawiki.org/wiki/Manual:Job_queue procès di fâ] e conten {{PLURAL:\$7|'''1''' element|'''\$7''' elements}}.",
-'userstatstext'          => "{{PLURAL:$1|Al è '''1''' [[Special:Listusers|utent]] regjistrât|A son '''$1''' [[Special:Listusers|utents]] regjistrâts}}, di chescj  '''$2''' (o il '''$4%''') {{PLURAL:$2|al è|a son}} $5 .",
+'userstatstext'          => "{{PLURAL:$1|Al è '''1''' [[Special:ListUsers|utent]] regjistrât|A son '''$1''' [[Special:ListUsers|utents]] regjistrâts}}, di chescj  '''$2''' (o il '''$4%''') {{PLURAL:$2|al è|a son}} $5 .",
 'statistics-mostpopular' => 'Pagjinis plui visitadis',
 
 'disambiguations' => 'Pagjinis di disambiguazion',
@@ -772,6 +782,7 @@
 'nlinks'                  => '$1 {{PLURAL:$1|leam|leams}}',
 'nmembers'                => '$1 {{PLURAL:$1|element|elements}}',
 'lonelypages'             => 'Pagjinis solitaris',
+'lonelypagestext'         => 'Nissune pagjine in {{SITENAME}} e à leams aes pagjinis ca sot.',
 'uncategorizedpages'      => 'Pagjinis cence categorie',
 'uncategorizedcategories' => 'Categoriis cence categorie',
 'uncategorizedimages'     => 'Files cence une categorie',
@@ -813,7 +824,7 @@
 Tu puedis strenzi la viodude sielzint un gjenar di regjistri, un non utent o la vôs che ti interesse.',
 'logempty'             => 'Nissun element corispondint tal regjistri.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Dutis lis pagjinis',
 'alphaindexline'    => 'di $1 a $2',
 'nextpage'          => 'Prossime pagjine ($1)',
@@ -830,10 +841,16 @@
 # Special:Categories
 'categories'         => 'Categoriis',
 'categoriespagetext' => 'Te wiki a esistin lis categoriis ca sot.',
+'categoriesfrom'     => 'Mostre lis categoriis scomençant di:',
 
-# Special:Listusers
+# Special:ListUsers
+'listusersfrom'    => 'Mostre i utents scomençant di:',
 'listusers-submit' => 'Mostre',
 
+# Special:ListGroupRights
+'listgrouprights-group'  => 'Grup',
+'listgrouprights-rights' => 'Dirits',
+
 # E-mail user
 'emailuser'       => 'Messaç di pueste a chest utent',
 'emailpage'       => 'Mande un messaç di pueste eletroniche al utent',
@@ -852,11 +869,11 @@
 'watchlistfor'         => "(par '''$1''')",
 'nowatchlist'          => 'Nissun element al è tignût di voli.',
 'watchnologin'         => 'No tu sês jentrât',
-'watchnologintext'     => "Tu 'nd âs di [[Special:Userlogin|jentrâ]] par modificâ la liste des pagjinis tignudis di voli.",
+'watchnologintext'     => "Tu 'nd âs di [[Special:UserLogin|jentrâ]] par modificâ la liste des pagjinis tignudis di voli.",
 'addedwatch'           => 'Zontât aes pagjinis tignudis di voli',
 'addedwatchtext'       => "La pagjine \"<nowiki>\$1</nowiki>\" e je stade zontade ae [[Special:Watchlist|liste di chês tignudis di voli]].
 Tal futûr i cambiaments a cheste pagjine e ae pagjine di discussion relative a saran segnalâts ca,
-e la pagjine e sarà '''gruessute''' te [[Special:Recentchanges|liste dai ultins cambiaments]] cussì che tu puedis notâle daurman.
+e la pagjine e sarà '''gruessute''' te [[Special:RecentChanges|liste dai ultins cambiaments]] cussì che tu puedis notâle daurman.
 
 <p>Se tu vuelis gjavâle de liste pi indevant, frache su \"No stâ tignî di voli\" te sbare in alt.",
 'removedwatch'         => 'Gjavade de liste',
@@ -865,6 +882,7 @@
 'watchthispage'        => 'Ten di voli cheste pagjine',
 'unwatch'              => 'No stâ tignî di voli',
 'unwatchthispage'      => 'No stâ tignî di voli plui',
+'notanarticle'         => 'Cheste pagjine no je une vôs',
 'watchnochange'        => 'Nissun element di chei tignûts di voli al è stât cambiât tal periodi mostrât.',
 'watchlist-details'    => '{{PLURAL:$1|$1 pagjine tignude|$1 pagjinis tignudis}} di voli cence contâ lis pagjinis di discussion.',
 'wlheader-enotif'      => '* Notifiche par pueste eletroniche ativade.',
@@ -883,8 +901,10 @@
 'watching'   => 'Daûr a zontâ aes pagjinis tignudis di voli...',
 'unwatching' => 'Daûr a gjavâ des pagjinis tignudis di voli...',
 
-'changed' => 'cambiade',
-'created' => 'creade',
+'enotif_impersonal_salutation' => 'Utent di {{SITENAME}}',
+'changed'                      => 'cambiade',
+'created'                      => 'creade',
+'enotif_anon_editor'           => 'utent anonim $1',
 
 # Delete/protect/revert
 'deletepage'                  => 'Elimine pagjine',
@@ -932,13 +952,18 @@
 'protect-cantedit'            => 'No tu puedis cambiâ i nivei di protezion par cheste pagjine, parcè che no tu âs i permès par modificâle.',
 'restriction-type'            => 'Permès:',
 'restriction-level'           => 'Nivel di restrizion:',
+'pagesize'                    => '(bytes)',
 
 # Restrictions (nouns)
-'restriction-edit' => 'Cambie',
-'restriction-move' => 'Spostament',
+'restriction-edit'   => 'Cambie',
+'restriction-move'   => 'Spostament',
+'restriction-create' => 'Creazion',
 
 # Undelete
-'undeletebtn' => 'Ripristine',
+'undeletebtn'            => 'Ripristine',
+'undeletecomment'        => 'Coment:',
+'undeletedarticle'       => 'al à recuperât "[[$1]]"',
+'undelete-search-submit' => 'Cîr',
 
 # Namespace form on various pages
 'namespace'      => 'Non dal spazi:',
@@ -956,20 +981,23 @@
 
 'sp-contributions-newbies-sub' => 'Pai gnûfs utents',
 'sp-contributions-blocklog'    => 'Regjistri dai blocs',
+'sp-contributions-submit'      => 'Cîr',
 
 # What links here
-'whatlinkshere'       => 'Leams a cheste vôs',
-'whatlinkshere-title' => 'Pagjinis che a son leadis a $1',
-'whatlinkshere-page'  => 'Pagjine:',
-'linklistsub'         => '(Liste di leams)',
-'linkshere'           => "Lis pagjinis ca sot a son leadis a '''[[:$1]]''':",
-'nolinkshere'         => "Nissune pagjine e à leams a '''[[:$1]]'''.",
-'nolinkshere-ns'      => "No son pagjine leadis a '''[[:$1]]''' intal spazi dai nons sielt.",
-'isredirect'          => 'pagjine di reindirizament',
-'istemplate'          => 'includude',
-'whatlinkshere-prev'  => '{{PLURAL:$1|precedent|precedents $1}}',
-'whatlinkshere-next'  => '{{PLURAL:$1|sucessîf|sucessîfs $1}}',
-'whatlinkshere-links' => '← leams',
+'whatlinkshere'           => 'Leams a cheste vôs',
+'whatlinkshere-title'     => 'Pagjinis che a son leadis a $1',
+'whatlinkshere-page'      => 'Pagjine:',
+'linklistsub'             => '(Liste di leams)',
+'linkshere'               => "Lis pagjinis ca sot a son leadis a '''[[:$1]]''':",
+'nolinkshere'             => "Nissune pagjine e à leams a '''[[:$1]]'''.",
+'nolinkshere-ns'          => "No son pagjine leadis a '''[[:$1]]''' intal spazi dai nons sielt.",
+'isredirect'              => 'pagjine di reindirizament',
+'istemplate'              => 'includude',
+'whatlinkshere-prev'      => '{{PLURAL:$1|precedent|precedents $1}}',
+'whatlinkshere-next'      => '{{PLURAL:$1|sucessîf|sucessîfs $1}}',
+'whatlinkshere-links'     => '← leams',
+'whatlinkshere-hidelinks' => '$1 leams',
+'whatlinkshere-filters'   => 'Filtris',
 
 # Block/unblock
 'blockip'            => 'Bloche utent',
@@ -1011,8 +1039,6 @@
 
 In chescj câs, tu varâs di movi o unî a man lis informazions contignudis te pagjine di discussion, se tu lu desideris.",
 'movearticle'      => 'Môf la vôs',
-'movenologin'      => 'No tu sês jentrât',
-'movenologintext'  => 'Tu âs di jessi un utent regjistrât e <a href="{{localurl:Special:Userlogin}}">jentrât</a> par movi une pagjine.',
 'newtitle'         => 'Al gnûf titul',
 'move-watch'       => 'Ten di voli cheste pagjine',
 'movepagebtn'      => 'Môf pagjine',
@@ -1144,6 +1170,7 @@
 
 # Media information
 'thumbsize'            => 'Dimension miniature:',
+'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|pagjine|pagjinis}}',
 'file-info'            => 'Dimensions: $1, gjenar MIME: $2',
 'file-info-size'       => '($1 × $2 pixel, dimensions: $3, gjenar MIME: $4)',
 'file-nohires'         => '<small>No son disponibilis versions cun risoluzion plui alte.</small>',
@@ -1151,7 +1178,7 @@
 'show-big-image'       => 'Version a risoluzion plene',
 'show-big-image-thumb' => '<small>Dimensions di cheste anteprime: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Galarie dai gnûfs files',
 'imagelisttext' => 'Ca sot e je une liste di $1 {{PLURAL:$1|file|files}} ordenâts $2.',
 'showhidebots'  => '($1 i bots)',
@@ -1183,14 +1210,18 @@
 # EXIF tags
 'exif-imagewidth'       => 'Largjece',
 'exif-imagelength'      => 'Altece',
+'exif-orientation'      => 'Orientament',
+'exif-xresolution'      => 'Risoluzion orizontâl',
+'exif-yresolution'      => 'Risoluzion verticâl',
 'exif-imagedescription' => 'Titul de figure',
 'exif-make'             => 'Produtôr machine',
 'exif-model'            => 'Model di machine fotografiche',
-'exif-software'         => 'Software doprÂt',
+'exif-software'         => 'Software doprât',
 'exif-artist'           => 'Autôr',
 'exif-datetimeoriginal' => 'Date e ore di creazion dai dâts',
 'exif-exposuretime'     => 'Timp di esposizion',
 'exif-flash'            => 'Flash',
+'exif-focallength'      => 'Lungjece focâl obietîf',
 'exif-contrast'         => 'Control contrast',
 
 # EXIF attributes
@@ -1202,7 +1233,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifiche chest file cuntune aplicazion esterne',
-'edit-externally-help' => 'Cjale [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] par altris informazions.',
+'edit-externally-help' => 'Cjale [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] par altris informazions.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ducj',
@@ -1228,7 +1259,7 @@
 'scarytranscludetoolong'  => '[URL masse lungje; o si scusin]',
 
 # HTML dump
-'redirectingto' => 'Daûr a tornâ a indreçâ a [[$1]]...',
+'redirectingto' => 'Daûr a tornâ a indreçâ a [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Va indevant',
@@ -1243,8 +1274,12 @@
 # Multipage image navigation
 'imgmultipageprev' => '← pagjine precedente',
 'imgmultipagenext' => 'pagjine sucessive →',
+'imgmultigo'       => 'Va!',
+'imgmultigoto'     => 'Va ae pagjine $1',
 
 # Table pager
+'ascending_abbrev'         => 'asc',
+'descending_abbrev'        => 'disc',
 'table_pager_next'         => 'Pagjine sucessive',
 'table_pager_prev'         => 'Pagjine precedente',
 'table_pager_first'        => 'Prime pagjine',
@@ -1258,11 +1293,14 @@
 
 # Live preview
 'livepreview-loading' => 'Daûr a cjamâ…',
+'livepreview-ready'   => 'Daûr a cjamâ… pront!',
 
 # Watchlist editor
 'watchlistedit-numitems'      => 'La liste des pagjinis tignudis di voli e conten {{PLURAL:$1|une pagjine|$1 pagjinis}}, cence contâ lis pagjinis di discussion.',
 'watchlistedit-noitems'       => 'La liste des pagjinis tignudis di voli e je vueide.',
+'watchlistedit-normal-title'  => 'Modifiche tignûts di voli',
 'watchlistedit-normal-submit' => 'Elimine pagjinis',
+'watchlistedit-normal-done'   => '{{PLURAL:$1|1 pagjine e je stade eliminade|$1 pagjinis a son stadis eliminadis}} de liste des pagjinis tignudis di voli:',
 'watchlistedit-raw-titles'    => 'Pagjinis:',
 
 # Watchlist editing tools
@@ -1271,10 +1309,22 @@
 'watchlisttools-raw'  => 'Modifiche la liste des pagjinis tignudis di voli in formât testuâl',
 
 # Special:Version
-'version'         => 'Version', # Not used as normal message but as header for the special page itself
-'version-version' => 'Version',
+'version'                  => 'Version', # Not used as normal message but as header for the special page itself
+'version-version'          => 'Version',
+'version-software-version' => 'Version',
 
+# Special:FilePath
+'filepath-page' => 'Non dal file:',
+
 # Special:SpecialPages
-'specialpages' => 'Pagjinis speciâls',
+'specialpages'                 => 'Pagjinis speciâls',
+'specialpages-note'            => '----
+* Pagjinis speciâls no riservadis.
+* <span class="mw-specialpagerestricted">Pagjinis speciâls a ciertis categoriis di utents.</span>',
+'specialpages-group-other'     => 'Altris pagjinis speciâls',
+'specialpages-group-changes'   => 'Ultins cambiaments e regjistris',
+'specialpages-group-users'     => 'Utents e dirits',
+'specialpages-group-pages'     => 'Listis di pagjinis',
+'specialpages-group-pagetools' => 'Imprescj utii pes pagjinis',
 
 );
Index: languages/messages/MessagesIe.php
===================================================================
--- languages/messages/MessagesIe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Jmb
  * @author Malafaya
- * @author SPQRobin
  * @author לערי ריינהארט
- * @author Jmb
  */
 
 $messages = array(
@@ -249,7 +248,7 @@
 'filedesc'  => 'Descrition',
 'savefile'  => 'Conservar file',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Liste de images',
 
 # Image description page
@@ -283,7 +282,7 @@
 'specialloguserlabel'  => 'Usator:',
 'speciallogtitlelabel' => 'Titul:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Omni págines',
 'allarticles'    => 'Omni págines',
 'allpagessubmit' => 'Vade',
@@ -294,7 +293,7 @@
 # Watchlist
 'watchlist'            => 'Liste de sequet págines',
 'addedwatch'           => 'Adjuntet al liste',
-'addedwatchtext'       => "Li págine ''[[$1]]'' ha esset adjuntet a vor [[Special:Watchlist|liste de sequet págines]]. Li proxim modificationes de ti ci págine e del associat págine de discussion va esser listat ci, e li págine va aperir '''aspessat''' in li [[Special:Recentchanges|liste de recent modificationes]] por esser trovat plu facilmen. Por supresser ti ci págine ex vor liste, ples claccar sur « Ne plu sequer » in li cadre de navigation.",
+'addedwatchtext'       => "Li págine ''[[$1]]'' ha esset adjuntet a vor [[Special:Watchlist|liste de sequet págines]]. Li proxim modificationes de ti ci págine e del associat págine de discussion va esser listat ci, e li págine va aperir '''aspessat''' in li [[Special:RecentChanges|liste de recent modificationes]] por esser trovat plu facilmen. Por supresser ti ci págine ex vor liste, ples claccar sur « Ne plu sequer » in li cadre de navigation.",
 'watch'                => 'Sequer',
 'watchthispage'        => 'Sequer ti págine',
 'watchlist-hide-bots'  => 'Celar modificationes de bot',
@@ -325,7 +324,6 @@
 
 # Move page
 'movearticle' => 'Moer págine:',
-'movenologin' => 'Vu ne ha intrat',
 'movepagebtn' => 'Moer págine',
 'movedto'     => 'moet a',
 '1movedto2'   => '[[$1]] moet a [[$2]]',
@@ -345,7 +343,7 @@
 'tooltip-n-mainpage'     => 'Visita li Principal págine',
 'tooltip-t-specialpages' => 'Liste de omni special págines',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Galerie de nov images',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesGsw.php
===================================================================
--- languages/messages/MessagesGsw.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGsw.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author 80686
- * @author Siebrand
- * @author לערי ריינהארט
  * @author Spacebirdy
- * @author Jon Harald Søby
+ * @author לערי ריינהארט
+ * @author 80686
  */
 
 $fallback = 'de';
@@ -303,7 +301,7 @@
 
 S automatisch generiert Passwort fier de Benutzer $2 lutet jetzert: $3
 
-Du sottsch dich jetzt onmelde un s Passwort ändere: {{fullurl:Special:Userlogin}}
+Du sottsch dich jetzt onmelde un s Passwort ändere: {{fullurl:Special:UserLogin}}
 
 Bitte ignorier diä E-Mail, wenn du s nit selber ongfordert hesch. S alt Passwort blibt witerhin gültig.',
 'noemail'                    => 'Dr Benutzer "$1" het kei E-Mail-Adress ongebe.',
@@ -352,8 +350,6 @@
 'missingsummary'           => "'''Obacht:''' Du hesch kei Zämefassig ongebe. Wenn du erneijt uf Spacher durcksch, wird d Änderung ohni gspychert.",
 'missingcommenttext'       => 'Bitte gib dinr Kommentar unte ii.',
 'whitelistedittext'        => 'Sie müssen sich $1, um Artikel bearbeiten zu können.',
-'whitelistreadtext'        => 'Sie müssen sich [[Special:Userlogin|hier anmelden]], um Artikel lesen zu können.',
-'whitelistacctext'         => 'Um in diesem Wiki Accounts anlegen zu dürfen, müssen Sie sich [[Special:Userlogin|hier anmelden]] und die nötigen Berechtigungen haben.',
 'confirmedittitle'         => 'Zuem Ändere isch e bschtätigti E-Bost-Adräss nötig.',
 'confirmedittext'          => 'Si muen Ihri E-Bost-Adräss erscht bstätige bevor Si Syte go ändere chönne. Bitte setze Si in [[Special:Preferences|Ihre Iistellige]] Ihri E-Bost Adräss ii un löhn Si si pruefe.',
 'accmailtitle'             => 'S Bassword isch verschickt worre.',
@@ -361,7 +357,7 @@
 'newarticletext'           => '<div id="newarticletext">
 {{MediaWiki:Newarticletext/{{NAMESPACE}}}}
 </div>',
-'anontalkpagetext'         => "----''Sell isch e Diskussionssyte vome anonyme Benutzer wo chei Zuegang aaglegt het odr wo ihn nit bruucht. Sälleweg muen mir di numerischi IP-Adräss bruuche um ihn odr si z'identifiziere. Sone IP-Adräss cha au vo mehrere Benutzer deilt werde. Wenn Si en anonyme Benutzer sin un 's Gfuehl hen, dass do irrelevanti Kommentar an Si grichtet wärde, denn [[Special:Userlogin|lege Si sich bitte en Zuegang aa odr mälde sich aa]] go in Zuekunft Verwirrige mit andere anonyme Benutzer z'vermeide.''",
+'anontalkpagetext'         => "----''Sell isch e Diskussionssyte vome anonyme Benutzer wo chei Zuegang aaglegt het odr wo ihn nit bruucht. Sälleweg muen mir di numerischi IP-Adräss bruuche um ihn odr si z'identifiziere. Sone IP-Adräss cha au vo mehrere Benutzer deilt werde. Wenn Si en anonyme Benutzer sin un 's Gfuehl hen, dass do irrelevanti Kommentar an Si grichtet wärde, denn [[Special:UserLogin|lege Si sich bitte en Zuegang aa odr mälde sich aa]] go in Zuekunft Verwirrige mit andere anonyme Benutzer z'vermeide.''",
 'noarticletext'            => '<div id="noarticletext">
 {{MediaWiki:Noarticletext/{{NAMESPACE}}}}
 </div>',
@@ -428,7 +424,7 @@
 # Preferences page
 'preferences'        => 'Iistellige',
 'prefsnologin'       => 'Nid aagmäldet',
-'prefsnologintext'   => 'Du muesch [[Special:Userlogin|aagmäldet]] sy, für Benutzerystellige chönne z ändere',
+'prefsnologintext'   => 'Du muesch [[Special:UserLogin|aagmäldet]] sy, für Benutzerystellige chönne z ändere',
 'prefsreset'         => 'Du hesch itz wider Standardystellige',
 'changepassword'     => 'Passwort ändere',
 'datedefault'        => 'kei Aagab',
@@ -495,8 +491,8 @@
 # Upload
 'upload'            => 'Datei uffelade',
 'uploadbtn'         => 'Bild lokal ufelade',
-'uploadnologintext' => 'Sie müssen [[Special:Userlogin|angemeldet sein]], um Dateien hochladen zu können.',
-'uploadtext'        => "Bruuche Si sell Formular unte go Dateie uffelade. Zuem aaluege odr fruener uffegladeni Bilder go sueche lueg uff de [[Special:Imagelist|Lischte vo uffegladene Dateie]], Uffeladige un Löschige sin au protokolliert uff [[Special:Log/upload|Uffeladige Protokoll]].
+'uploadnologintext' => 'Sie müssen [[Special:UserLogin|angemeldet sein]], um Dateien hochladen zu können.',
+'uploadtext'        => "Bruuche Si sell Formular unte go Dateie uffelade. Zuem aaluege odr fruener uffegladeni Bilder go sueche lueg uff de [[Special:ImageList|Lischte vo uffegladene Dateie]], Uffeladige un Löschige sin au protokolliert uff [[Special:Log/upload|Uffeladige Protokoll]].
 
 Go e Datei odr en Bild innere Syte iizbaue schriibe Si eifach ane:
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:file.jpg]]</nowiki>'''
@@ -505,7 +501,7 @@
 * '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:file.ogg]]</nowiki>'''
 go direkt e Gleich uff d Datei z'mache.",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Lischte vo Bilder',
 
 # Image description page
@@ -579,7 +575,7 @@
 Si chönnet d Aazeig iischränke wenn Si e Protokoll, e Benutzername odr e Sytename iigän.',
 'logempty'    => 'Kei passendi Yträg gfunde.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'alli Sytene',
 'alphaindexline'    => 'vo $1 bis $2',
 'nextpage'          => 'Nächscht Syte ($1)',
@@ -598,7 +594,7 @@
 
 # E-mail user
 'mailnologin'     => 'Du bisch nid aagmäldet oder hesch keis Mail aaggä',
-'mailnologintext' => 'Du muesch [[Special:Userlogin|aagmäldet sy]] und e bestätigeti e-Mail-Adrässen i dynen [[Special:Preferences|Ystelligen]] aaggä ha, für das du öpper anderem es e-Mail chasch schicke.',
+'mailnologintext' => 'Du muesch [[Special:UserLogin|aagmäldet sy]] und e bestätigeti e-Mail-Adrässen i dynen [[Special:Preferences|Ystelligen]] aaggä ha, für das du öpper anderem es e-Mail chasch schicke.',
 'emailuser'       => 'Es Mail schrybe',
 'emailpage'       => 'e-Mail ane BenutzerIn',
 'emailpagetext'   => 'Öpperem, wo sälber e bestätigeti e-Mail-Adrässe het aaggä, chasch du mit däm Formular es Mail schicke. Im Absänder steit dyni eigeti e-Mail-Adrässe, so das me dir cha antworte.',
@@ -617,10 +613,10 @@
 'watchlist'         => 'Beobachtigslischte',
 'mywatchlist'       => 'Beobachtigslischte',
 'nowatchlist'       => 'Du hesch ke Yträg uf dyre Beobachtigslischte.',
-'watchnologintext'  => 'Du musst [[Special:Userlogin|angemeldet]] sein, um deine Beobachtungsliste zu bearbeiten.',
+'watchnologintext'  => 'Du musst [[Special:UserLogin|angemeldet]] sein, um deine Beobachtungsliste zu bearbeiten.',
 'addedwatch'        => 'zue de Beobachtigslischte drzue do',
 'addedwatchtext'    => 'D Syte "[[:$1]]" stoht jetz uf Ihre [[Special:Watchlist|Beobachtigslischte]].
-Neui Änderige an de Syte odr de Diskussionssyte drvo chasch jetz dört seh. Usserdem sin selli Änderige uf de [[Special:Recentchanges|letschte Änderige]] fett gschriibe, dass Si s schneller finde.
+Neui Änderige an de Syte odr de Diskussionssyte drvo chasch jetz dört seh. Usserdem sin selli Änderige uf de [[Special:RecentChanges|letschte Änderige]] fett gschriibe, dass Si s schneller finde.
 
 Wenn Si d Syte spöter wiedr vo de Lischte striiche wenn, denn drucke Si eifach uf "nümm beobachte".',
 'watch'             => 'beobachte',
@@ -668,7 +664,7 @@
 
 Di letschti Änderig het [[User:$3|$3]] ([[User talk:$3|Talk]]) gmacht.',
 'revertpage'        => 'Rückgängig gmacht zuer letschte Änderig vo $1', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'protectlogtext'    => 'Dies ist eine Liste der blockierten Seiten. Siehe [[Special:Protectedpages|Geschützte Seiten]] für mehr Informationen.',
+'protectlogtext'    => 'Dies ist eine Liste der blockierten Seiten. Siehe [[Special:ProtectedPages|Geschützte Seiten]] für mehr Informationen.',
 'protectcomment'    => 'Grund der Sperrung',
 
 # Undelete
@@ -703,7 +699,7 @@
 'contribslink'    => 'Byträg',
 'blocklogpage'    => 'Sperrigs-Protokoll',
 'blocklogentry'   => 'sperrt [[$1]] für d Ziit vo: $2 $3',
-'blocklogtext'    => 'Des ischs Logbuech yber Sperrunge un Entsperrunge vun Bnutzer. Automatisch blockti IP-Adresse werre nit erfasst. Lueg au [[Special:Ipblocklist|IP-Block Lischt]] fyr ä Lischt vun gsperrti Bnutzer.',
+'blocklogtext'    => 'Des ischs Logbuech yber Sperrunge un Entsperrunge vun Bnutzer. Automatisch blockti IP-Adresse werre nit erfasst. Lueg au [[Special:IPBlockList|IP-Block Lischt]] fyr ä Lischt vun gsperrti Bnutzer.',
 'unblocklogentry' => 'Blockade von $1 aufgehoben',
 
 # Move page
@@ -716,8 +712,6 @@
 
 I söttigne Fäll müessti d Diskussionssyten allefalls vo Hand kopiert wärde.",
 'movearticle'      => 'Artikel verschiebe',
-'movenologin'      => 'Du bisch nid aagmäldet',
-'movenologintext'  => 'Du muesch dich z’ersch [[Special:Userlogin|aamälde]] damit du die Syte chasch zügle.',
 'newtitle'         => 'Zum nöie Titel',
 'movepagebtn'      => 'Artikel verschiebe',
 'pagemovedsub'     => 'Verschiebig erfolgrych',
@@ -829,7 +823,7 @@
 'imagemaxsize' => 'Maximali Gröössi vo de Bilder uf de Bildbeschrybigs-Sytene:',
 'thumbsize'    => 'Bildvorschou-Gröössi:',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Gallery vo noie Bilder',
 'imagelisttext' => 'Hier ist eine Liste von $1 Bildern, sortiert $2.',
 'ilsubmit'      => 'Suech',
Index: languages/messages/MessagesEn.php
===================================================================
--- languages/messages/MessagesEn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,7 +6,7 @@
  *
  * Changes in this file will be lost during software upgrades.
  * You can make your customizations on the wiki.
- * While logged in as a sysop user, go to [[Special:Allmessages]]
+ * While logged in as a sysop user, go to [[Special:AllMessages]]
  * and edit the MediaWiki:* pages listed there.
  */
 
@@ -340,6 +340,7 @@
 	'hiddencat'              => array( 1,    '__HIDDENCAT__'          ),
 	'pagesincategory'        => array( 1,    'PAGESINCATEGORY', 'PAGESINCAT' ),
 	'pagesize'               => array( 1,    'PAGESIZE'               ),
+	'staticredirect'         => array( 1,    '__STATICREDIRECT__'     ),
 );
 
 /**
@@ -440,7 +441,7 @@
  * Regular expression matching the "link trail", e.g. "ed" in [[Toast]]ed, as
  * the first group, and the remainder of the string as the second group.
  */
-$linkTrail = '/^(\p{L&}+)(.*)$/usD';
+$linkTrail = '/^([a-z]+)(.*)$/sD';
 
 /**
  * List of filenames for some ui images that can be overridden per language
@@ -779,7 +780,7 @@
 'nosuchspecialpage' => 'No such special page',
 'nospecialpagetext' => "<big>'''You have requested an invalid special page.'''</big>
 
-A list of valid special pages can be found at [[Special:Specialpages|{{int:specialpages}}]].",
+A list of valid special pages can be found at [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -810,7 +811,7 @@
 This is usually caused by following an outdated diff or history link to a page that has been deleted.
 
 If this is not the case, you may have found a bug in the software.
-Please report this to an administrator, making note of the URL.',
+Please report this to an [[Special:ListUsers/sysop|administrator]], making note of the URL.',
 'missingarticle-rev'   => '(revision#: $1)',
 'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'The database has been automatically locked while the slave database servers catch up to the master',
@@ -867,11 +868,11 @@
 'logouttitle'                => 'User logout',
 'logouttext'                 => '<strong>You are now logged out.</strong>
 
-You can continue to use {{SITENAME}} anonymously, or you can log in again as the same or as a different user.
+You can continue to use {{SITENAME}} anonymously, or you can [[Special:UserLogin|log in again]] as the same or as a different user.
 Note that some pages may continue to be displayed as if you were still logged in, until you clear your browser cache.',
 'welcomecreation'            => '== Welcome, $1! ==
 Your account has been created.
-Do not forget to change your {{SITENAME}} preferences.',
+Do not forget to change your [[Special:Preferences|{{SITENAME}} preferences]].',
 'loginpagetitle'             => 'User login',
 'yourname'                   => 'Username:',
 'yourpassword'               => 'Password:',
@@ -1046,7 +1047,7 @@
 You can contact $1 or another [[{{MediaWiki:Grouppage-sysop}}|administrator]] to discuss the block.
 You cannot use the 'e-mail this user' feature unless a valid e-mail address is specified in your [[Special:Preferences|account preferences]] and you have not been blocked from using it.
 Your current IP address is $3, and the block ID is #$5.
-Please include either or both of these in any queries.",
+Please include all above details in any queries you make.",
 'autoblockedtext'                  => 'Your IP address has been automatically blocked because it was used by another user, who was blocked by $1.
 The reason given is this:
 
@@ -1054,22 +1055,19 @@
 
 * Start of block: $8
 * Expiry of block: $6
+* Intended blockee: $7
 
 You may contact $1 or one of the other [[{{MediaWiki:Grouppage-sysop}}|administrators]] to discuss the block.
 
 Note that you may not use the "e-mail this user" feature unless you have a valid e-mail address registered in your [[Special:Preferences|user preferences]] and you have not been blocked from using it.
 
-Your block ID is $5.
-Please include this ID in any queries you make.',
+Your current IP address is $3, and the block ID is #$5.
+Please include all above details in any queries you make.',
 'blockednoreason'                  => 'no reason given',
 'blockedoriginalsource'            => "The source of '''$1''' is shown below:",
 'blockededitsource'                => "The text of '''your edits''' to '''$1''' is shown below:",
 'whitelistedittitle'               => 'Login required to edit',
 'whitelistedittext'                => 'You have to $1 to edit pages.',
-'whitelistreadtitle'               => 'Login required to read',
-'whitelistreadtext'                => 'You have to [[Special:Userlogin|login]] to read pages.',
-'whitelistacctitle'                => 'You are not allowed to create an account',
-'whitelistacctext'                 => 'To be allowed to create accounts in {{SITENAME}} you have to [[Special:Userlogin|log]] in and have the appropriate permissions.',
 'confirmedittitle'                 => 'E-mail confirmation required to edit',
 'confirmedittext'                  => 'You must confirm your e-mail address before editing pages.
 Please set and validate your e-mail address through your [[Special:Preferences|user preferences]].',
@@ -1087,10 +1085,10 @@
 If you are here by mistake, click your browser's '''back''' button.",
 'newarticletextanon'               => '{{int:newarticletext}}', # do not translate or duplicate this message to other languages
 'talkpagetext'                     => '<!-- MediaWiki:talkpagetext -->', # do not translate or duplicate this message to other languages
-'anontalkpagetext'                 => "----''This is the discussion page for an anonymous user who has not created an account yet or who does not use it.
+'anontalkpagetext'                 => "----''This is the discussion page for an anonymous user who has not created an account yet, or who does not use it.
 We therefore have to use the numerical IP address to identify him/her.
 Such an IP address can be shared by several users.
-If you are an anonymous user and feel that irrelevant comments have been directed at you, please [[Special:Userlogin|create an account or log in]] to avoid future confusion with other anonymous users.''",
+If you are an anonymous user and feel that irrelevant comments have been directed at you, please [[Special:UserLogin/signup|create an account]] or [[Special:UserLogin|log in]] to avoid future confusion with other anonymous users.''",
 'noarticletext'                    => 'There is currently no text in this page, you can [[Special:Search/{{PAGENAME}}|search for this page title]] in other pages or [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page].',
 'noarticletextanon'                => '{{int:noarticletext}}', # do not translate or duplicate this message to other languages
 'userpage-userdoesnotexist'        => 'User account "$1" is not registered.
@@ -1108,13 +1106,13 @@
 'previewconflict'                  => 'This preview reflects the text in the upper text editing area as it will appear if you choose to save.',
 'session_fail_preview'             => '<strong>Sorry! We could not process your edit due to a loss of session data.
 Please try again.
-If it still does not work, try logging out and logging back in.</strong>',
+If it still does not work, try [[Special:UserLogout|logging out]] and logging back in.</strong>',
 'session_fail_preview_html'        => "<strong>Sorry! We could not process your edit due to a loss of session data.</strong>
 
 ''Because {{SITENAME}} has raw HTML enabled, the preview is hidden as a precaution against JavaScript attacks.''
 
 <strong>If this is a legitimate edit attempt, please try again.
-If it still does not work, try logging out and logging back in.</strong>",
+If it still does not work, try [[Special:UserLogout|logging out]] and logging back in.</strong>",
 'token_suffix_mismatch'            => '<strong>Your edit has been rejected because your client mangled the punctuation characters in the edit token.
 The edit has been rejected to prevent corruption of the page text.
 This sometimes happens when you are using a buggy web-based anonymous proxy service.</strong>',
@@ -1162,7 +1160,7 @@
 'edittools'                        => '<!-- Text here will be shown below edit and upload forms. -->', # only translate this message to other languages if you have to change it
 'nocreatetitle'                    => 'Page creation limited',
 'nocreatetext'                     => '{{SITENAME}} has restricted the ability to create new pages.
-You can go back and edit an existing page, or [[Special:Userlogin|log in or create an account]].',
+You can go back and edit an existing page, or [[Special:UserLogin|log in or create an account]].',
 'nocreate-loggedin'                => 'You do not have permission to create new pages on {{SITENAME}}.',
 'permissionserrors'                => 'Permissions Errors',
 'permissionserrorstext'            => 'You do not have permission to do that, for the following {{PLURAL:$1|reason|reasons}}:',
@@ -1249,7 +1247,7 @@
 'rev-delundel'                => 'show/hide',
 'revisiondelete'              => 'Delete/undelete revisions',
 'revdelete-nooldid-title'     => 'Invalid target revision',
-'revdelete-nooldid-text'      => 'You have either not specified a target revision(s) to perform this 
+'revdelete-nooldid-text'      => 'You have either not specified a target revision(s) to perform this
 function, the specified revision does not exist, or you are attempting to hide the current revision.',
 'revdelete-selected'          => '{{PLURAL:$2|Selected revision|Selected revisions}} of [[:$1]]:',
 'logdelete-selected'          => '{{PLURAL:$1|Selected log event|Selected log events}}:',
@@ -1287,7 +1285,7 @@
 # Suppression log
 'suppressionlog'     => 'Suppression log',
 'suppressionlogtext' => 'Below is a list of deletions and blocks involving content hidden from sysops.
-See the [[Special:Ipblocklist|IP block list]] for the list of currently operational bans and blocks.',
+See the [[Special:IPBlockList|IP block list]] for the list of currently operational bans and blocks.',
 
 # History merging
 'mergehistory'                     => 'Merge page histories',
@@ -1329,7 +1327,7 @@
 # Search results
 'searchresults'             => 'Search results',
 'searchresulttext'          => 'For more information about searching {{SITENAME}}, see [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "You searched for '''[[:$1]]'''",
+'searchsubtitle'            => 'You searched for \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|all pages starting with "$1"]] | [[Special:WhatLinksHere/$1|all pages that link to "$1"]])',
 'searchsubtitleinvalid'     => "You searched for '''$1'''",
 'noexactmatch'              => "'''There is no page titled \"\$1\".'''
 You can [[:\$1|create this page]].",
@@ -1394,7 +1392,7 @@
 'mypreferences'            => 'My preferences',
 'prefs-edits'              => 'Number of edits:',
 'prefsnologin'             => 'Not logged in',
-'prefsnologintext'         => 'You must be [[Special:Userlogin|logged in]] to set user preferences.',
+'prefsnologintext'         => 'You must be [[Special:UserLogin|logged in]] to set user preferences.',
 'prefsreset'               => 'Preferences have been reset from storage.',
 'qbsettings'               => 'Quickbar',
 'qbsettings-none'          => 'None',
@@ -1459,10 +1457,10 @@
 'userrights-summary'             => '', # do not translate or duplicate this message to other languages
 'userrights-lookup-user'         => 'Manage user groups',
 'userrights-user-editname'       => 'Enter a username:',
-'editusergroup'                  => 'Edit User Groups',
+'editusergroup'                  => 'Edit user groups',
 'editinguser'                    => "Changing user rights of user '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-editusergroup'       => 'Edit user groups',
-'saveusergroups'                 => 'Save User Groups',
+'saveusergroups'                 => 'Save user groups',
 'userrights-groupsmember'        => 'Member of:',
 'userrights-groups-help'         => 'You may alter the groups this user is in:
 * A checked box means the user is in that group.
@@ -1471,7 +1469,7 @@
 'userrights-reason'              => 'Reason for change:',
 'userrights-no-interwiki'        => 'You do not have permission to edit user rights on other wikis.',
 'userrights-nodatabase'          => 'Database $1 does not exist or is not local.',
-'userrights-nologin'             => 'You must [[Special:Userlogin|log in]] with an administrator account to assign user rights.',
+'userrights-nologin'             => 'You must [[Special:UserLogin|log in]] with an administrator account to assign user rights.',
 'userrights-notallowed'          => 'Your account does not have permission to assign user rights.',
 'userrights-changeable-col'      => 'Groups you can change',
 'userrights-unchangeable-col'    => 'Groups you cannot change',
@@ -1487,12 +1485,12 @@
 'group-suppress'      => 'Oversights',
 'group-all'           => '(all)',
 
-'group-user-member'          => 'User',
-'group-autoconfirmed-member' => 'Autoconfirmed user',
-'group-bot-member'           => 'Bot',
-'group-sysop-member'         => 'Sysop',
-'group-bureaucrat-member'    => 'Bureaucrat',
-'group-suppress-member'      => 'Oversight',
+'group-user-member'          => 'user',
+'group-autoconfirmed-member' => 'autoconfirmed user',
+'group-bot-member'           => 'bot',
+'group-sysop-member'         => 'sysop',
+'group-bureaucrat-member'    => 'bureaucrat',
+'group-suppress-member'      => 'oversight',
 
 'grouppage-user'          => '{{ns:project}}:Users',
 'grouppage-autoconfirmed' => '{{ns:project}}:Autoconfirmed users',
@@ -1606,25 +1604,26 @@
 'reupload'                    => 'Re-upload',
 'reuploaddesc'                => 'Cancel upload and return to the upload form',
 'uploadnologin'               => 'Not logged in',
-'uploadnologintext'           => 'You must be [[Special:Userlogin|logged in]] to upload files.',
+'uploadnologintext'           => 'You must be [[Special:UserLogin|logged in]] to upload files.',
 'upload_directory_missing'    => 'The upload directory ($1) is missing and could not be created by the webserver.',
 'upload_directory_read_only'  => 'The upload directory ($1) is not writable by the webserver.',
 'uploaderror'                 => 'Upload error',
 'upload-summary'              => '', # do not translate or duplicate this message to other languages
 'uploadtext'                  => "Use the form below to upload files.
-To view or search previously uploaded files go to the [[Special:Imagelist|list of uploaded files]], uploads and deletions are also logged in the [[Special:Log/upload|upload log]].
+To view or search previously uploaded files go to the [[Special:ImageList|list of uploaded files]], (re)uploads are also logged in the [[Special:Log/upload|upload log]], deletions in the [[Special:Log/delete|deletion log]].
 
-To include a file in a page, use a link in the form
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''' or
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' for directly linking to the file.",
+To include a file in a page, use a link in one of the following forms:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' to use the full version of the file
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alt text]]</nowiki></tt>''' to use a 200 pixel wide rendition in a box in the left margin with 'alt text' as description
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' for directly linking to the file without displaying the file",
 'upload-permitted'            => 'Permitted file types: $1.',
 'upload-preferred'            => 'Preferred file types: $1.',
 'upload-prohibited'           => 'Prohibited file types: $1.',
 'uploadfooter'                => '-', # do not translate or duplicate this message to other languages
 'uploadlog'                   => 'upload log',
 'uploadlogpage'               => 'Upload log',
-'uploadlogpagetext'           => 'Below is a list of the most recent file uploads.',
+'uploadlogpagetext'           => 'Below is a list of the most recent file uploads.
+See the [[Special:NewImages|gallery of new files]] for a more visual overview.',
 'filename'                    => 'Filename',
 'filedesc'                    => 'Summary',
 'fileuploadsummary'           => 'Summary:',
@@ -1711,11 +1710,11 @@
 'upload-proto-error-text' => 'Remote upload requires URLs beginning with <code>http://</code> or <code>ftp://</code>.',
 'upload-file-error'       => 'Internal error',
 'upload-file-error-text'  => 'An internal error occurred when attempting to create a temporary file on the server.
-Please contact a system administrator.',
+Please contact an [[Special:ListUsers/sysop|administrator]].',
 'upload-misc-error'       => 'Unknown upload error',
 'upload-misc-error-text'  => 'An unknown error occurred during the upload.
 Please verify that the URL is valid and accessible and try again.
-If the problem persists, contact a system administrator.',
+If the problem persists, contact an [[Special:ListUsers/sysop|administrator]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Could not reach URL',
@@ -1733,7 +1732,7 @@
 'upload_source_url'  => ' (a valid, publicly accessible URL)',
 'upload_source_file' => ' (a file on your computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'This special page shows all uploaded files.
 By default the last uploaded files are shown at top of the list.
 A click on a column header changes the sorting.',
@@ -1761,7 +1760,7 @@
 'imagelinks'                     => 'Links',
 'linkstoimage'                   => 'The following {{PLURAL:$1|page links|$1 pages link}} to this file:',
 'nolinkstoimage'                 => 'There are no pages that link to this file.',
-'morelinkstoimage'               => 'View [[Special:Whatlinkshere/$1|more links]] to this file.',
+'morelinkstoimage'               => 'View [[Special:WhatLinksHere/$1|more links]] to this file.',
 'redirectstofile'                => 'The following {{PLURAL:$1|file redirects|$1 files redirect}} to this file:',
 'duplicatesoffile'               => 'The following {{PLURAL:$1|file is a duplicate|$1 files are duplicates}} of this file:',
 'sharedupload'                   => 'This file is a shared upload and may be used by other projects.',
@@ -1782,11 +1781,11 @@
 'filerevert'                => 'Revert $1',
 'filerevert-backlink'       => '← $1', # only translate this message to other languages if you have to change it
 'filerevert-legend'         => 'Revert file',
-'filerevert-intro'          => '<span class="plainlinks">You are reverting \'\'\'[[Media:$1|$1]]\'\'\' to the [$4 version as of $3, $2].</span>',
+'filerevert-intro'          => "You are reverting '''[[Media:$1|$1]]''' to the [$4 version as of $3, $2].",
 'filerevert-comment'        => 'Comment:',
 'filerevert-defaultcomment' => 'Reverted to version as of $2, $1',
 'filerevert-submit'         => 'Revert',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' has been reverted to the [$4 version as of $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' has been reverted to the [$4 version as of $3, $2].",
 'filerevert-badversion'     => 'There is no previous local version of this file with the provided timestamp.',
 
 # File deletion
@@ -1794,7 +1793,7 @@
 'filedelete-backlink'         => '← $1', # only translate this message to other languages if you have to change it
 'filedelete-legend'           => 'Delete file',
 'filedelete-intro'            => "You are deleting '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">You are deleting the version of \'\'\'[[Media:$1|$1]]\'\'\' as of [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "You are deleting the version of '''[[Media:$1|$1]]''' as of [$4 $3, $2].",
 'filedelete-comment'          => 'Reason for deletion:',
 'filedelete-submit'           => 'Delete',
 'filedelete-success'          => "'''$1''' has been deleted.",
@@ -1855,7 +1854,7 @@
 That comes to '''\$5''' average edits per page, and '''\$6''' views per edit.
 
 The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''\$7'''.",
-'userstatstext'          => "There {{PLURAL:$1|is '''1''' registered [[Special:Listusers|user]]|are '''$1''' registered [[Special:Listusers|users]]}}, of which '''$2''' (or '''$4%''') {{PLURAL:$2|has|have}} $5 rights.",
+'userstatstext'          => "There {{PLURAL:$1|is '''1''' registered [[Special:ListUsers|user]]|are '''$1''' registered [[Special:ListUsers|users]]}}, of which '''$2''' (or '''$4%''') {{PLURAL:$2|has|have}} $5 rights.",
 'statistics-mostpopular' => 'Most viewed pages',
 'statistics-footer'      => '', # do not translate or duplicate this message to other languages
 
@@ -1875,12 +1874,12 @@
 
 'brokenredirects'         => 'Broken redirects',
 'brokenredirects-summary' => '', # do not translate or duplicate this message to other languages
-'brokenredirectstext'     => 'The following redirects link to non-existent pages:',
+'brokenredirectstext'     => 'The following redirects link to non-existent pages.',
 'brokenredirects-edit'    => '(edit)',
 'brokenredirects-delete'  => '(delete)',
 
 'withoutinterwiki'         => 'Pages without language links',
-'withoutinterwiki-summary' => 'The following pages do not link to other language versions:',
+'withoutinterwiki-summary' => 'The following pages do not link to other language versions.',
 'withoutinterwiki-legend'  => 'Prefix',
 'withoutinterwiki-submit'  => 'Show',
 
@@ -1989,7 +1988,7 @@
 'logempty'             => 'No matching items in log.',
 'log-title-wildcard'   => 'Search titles starting with this text',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'All pages',
 'allpages-summary'  => '', # do not translate or duplicate this message to other languages
 'alphaindexline'    => '$1 to $2',
@@ -2015,15 +2014,15 @@
 'special-categories-sort-count' => 'sort by count',
 'special-categories-sort-abc'   => 'sort alphabetically',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Display users starting at:',
 'listusers-submit'   => 'Show',
 'listusers-noresult' => 'No user found.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'               => 'User group rights',
 'listgrouprights-summary'       => 'The following is a list of user groups defined on this wiki, with their associated access rights.
-Additional information about individual rights can be found at [[{{MediaWiki:Listgrouprights-helppage}}]].',
+There may be [[{{MediaWiki:Listgrouprights-helppage}}|additional information]] about individual rights.',
 'listgrouprights-group'         => 'Group',
 'listgrouprights-rights'        => 'Rights',
 'listgrouprights-helppage'      => 'Help:Group rights',
@@ -2032,11 +2031,11 @@
 
 # E-mail user
 'mailnologin'     => 'No send address',
-'mailnologintext' => 'You must be [[Special:Userlogin|logged in]] and have a valid e-mail address in your [[Special:Preferences|preferences]] to send e-mail to other users.',
+'mailnologintext' => 'You must be [[Special:UserLogin|logged in]] and have a valid e-mail address in your [[Special:Preferences|preferences]] to send e-mail to other users.',
 'emailuser'       => 'E-mail this user',
 'emailpage'       => 'E-mail user',
 'emailpagetext'   => 'If this user has entered a valid e-mail address in his or her user preferences, the form below will send a single message.
-The e-mail address you entered in your user preferences will appear as the "From" address of the mail, so the recipient will be able to reply.',
+The e-mail address you entered in [[Special:Preferences|your user preferences]] will appear as the "From" address of the e-mail, so the recipient will be able to reply.',
 'usermailererror' => 'Mail object returned error:',
 'defemailsubject' => '{{SITENAME}} e-mail',
 'noemailtitle'    => 'No e-mail address',
@@ -2059,12 +2058,12 @@
 'nowatchlist'          => 'You have no items on your watchlist.',
 'watchlistanontext'    => 'Please $1 to view or edit items on your watchlist.',
 'watchnologin'         => 'Not logged in',
-'watchnologintext'     => 'You must be [[Special:Userlogin|logged in]] to modify your watchlist.',
+'watchnologintext'     => 'You must be [[Special:UserLogin|logged in]] to modify your watchlist.',
 'addedwatch'           => 'Added to watchlist',
 'addedwatchtext'       => "The page \"[[:\$1]]\" has been added to your [[Special:Watchlist|watchlist]].
-Future changes to this page and its associated talk page will be listed there, and the page will appear '''bolded''' in the [[Special:Recentchanges|list of recent changes]] to make it easier to pick out.",
+Future changes to this page and its associated talk page will be listed there, and the page will appear '''bolded''' in the [[Special:RecentChanges|list of recent changes]] to make it easier to pick out.",
 'removedwatch'         => 'Removed from watchlist',
-'removedwatchtext'     => 'The page "[[:$1]]" has been removed from your watchlist.',
+'removedwatchtext'     => 'The page "[[:$1]]" has been removed from [[Special:Watchlist|your watchlist]].',
 'watch'                => 'Watch',
 'watchthispage'        => 'Watch this page',
 'unwatch'              => 'Unwatch',
@@ -2168,10 +2167,10 @@
 'rollbackfailed'              => 'Rollback failed',
 'cantrollback'                => 'Cannot revert edit;
 last contributor is only author of this page.',
-'alreadyrolled'               => 'Cannot rollback last edit of [[:$1]] by [[User:$2|$2]] ([[User talk:$2|Talk]]);
+'alreadyrolled'               => 'Cannot rollback last edit of [[:$1]] by [[User:$2|$2]] ([[User talk:$2|Talk]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
 someone else has edited or rolled back the page already.
 
-Last edit was by [[User:$3|$3]] ([[User talk:$3|Talk]]).',
+The last edit to the page was by [[User:$3|$3]] ([[User talk:$3|Talk]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'The edit comment was: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Reverted edits by [[Special:Contributions/$2|$2]] ([[User talk:$2|Talk]]) to last version by [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Reverted edits by $1;
@@ -2181,7 +2180,7 @@
 Please hit "back" and reload the page you came from, then try again.',
 'protectlogpage'              => 'Protection log',
 'protectlogtext'              => 'Below is a list of page locks and unlocks.
-See the [[Special:Protectedpages|protected pages list]] for the list of currently operational page protections.',
+See the [[Special:ProtectedPages|protected pages list]] for the list of currently operational page protections.',
 'protectedarticle'            => 'protected "[[$1]]"',
 'modifiedarticleprotection'   => 'changed protection level for "[[$1]]"',
 'unprotectedarticle'          => 'unprotected "[[$1]]"',
@@ -2305,7 +2304,7 @@
 
 # What links here
 'whatlinkshere'            => 'What links here',
-'whatlinkshere-title'      => 'Pages that link to $1',
+'whatlinkshere-title'      => 'Pages that link to "$1"',
 'whatlinkshere-summary'    => '', # do not translate or duplicate this message to other languages
 'whatlinkshere-page'       => 'Page:',
 'whatlinkshere-barrow'     => '>', # only translate this message to other languages if you have to change it
@@ -2358,7 +2357,7 @@
 'badipaddress'                    => 'Invalid IP address',
 'blockipsuccesssub'               => 'Block succeeded',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] has been blocked.<br />
-See [[Special:Ipblocklist|IP block list]] to review blocks.',
+See [[Special:IPBlockList|IP block list]] to review blocks.',
 'ipb-edit-dropdown'               => 'Edit block reasons',
 'ipb-unblock-addr'                => 'Unblock $1',
 'ipb-unblock'                     => 'Unblock a username or IP address',
@@ -2369,7 +2368,7 @@
 'ipusubmit'                       => 'Unblock this address',
 'unblocked'                       => '[[User:$1|$1]] has been unblocked',
 'unblocked-id'                    => 'Block $1 has been removed',
-'ipblocklist'                     => 'List of blocked IP addresses and usernames',
+'ipblocklist'                     => 'Blocked IP addresses and usernames',
 'ipblocklist-legend'              => 'Find a blocked user',
 'ipblocklist-username'            => 'Username or IP address:',
 'ipblocklist-summary'             => '', # do not translate or duplicate this message to other languages
@@ -2392,7 +2391,7 @@
 'blocklogentry'                   => 'blocked [[$1]] with an expiry time of $2 $3',
 'blocklogtext'                    => 'This is a log of user blocking and unblocking actions.
 Automatically blocked IP addresses are not listed.
-See the [[Special:Ipblocklist|IP block list]] for the list of currently operational bans and blocks.',
+See the [[Special:IPBlockList|IP block list]] for the list of currently operational bans and blocks.',
 'unblocklogentry'                 => 'unblocked $1',
 'block-log-flags-anononly'        => 'anonymous users only',
 'block-log-flags-nocreate'        => 'account creation disabled',
@@ -2434,7 +2433,7 @@
 'lockdbsuccesssub'    => 'Database lock succeeded',
 'unlockdbsuccesssub'  => 'Database lock removed',
 'lockdbsuccesstext'   => 'The database has been locked.<br />
-Remember to [[Special:Unlockdb|remove the lock]] after your maintenance is complete.',
+Remember to [[Special:UnlockDB|remove the lock]] after your maintenance is complete.',
 'unlockdbsuccesstext' => 'The database has been unlocked.',
 'lockfilenotwritable' => 'The database lock file is not writable.
 To lock or unlock the database, this needs to be writable by the web server.',
@@ -2446,8 +2445,8 @@
 'move-page-legend'        => 'Move page',
 'movepagetext'            => "Using the form below will rename a page, moving all of its history to the new name.
 The old title will become a redirect page to the new title.
-Links to the old page title will not be changed;
-be sure to check for double or broken redirects.
+You can update redirects that point to the original title automatically.
+If you choose not to, be sure to check for [[Special:DoubleRedirects|double]] or [[Special:BrokenRedirects|broken redirects]].
 You are responsible for making sure that links continue to point where they are supposed to go.
 
 Note that the page will '''not''' be moved if there is already a page at the new title, unless it is empty or a redirect and has no past edit history.
@@ -2462,8 +2461,6 @@
 
 In those cases, you will have to move or merge the page manually if desired.",
 'movearticle'             => 'Move page:',
-'movenologin'             => 'Not logged in',
-'movenologintext'         => 'You must be a registered user and [[Special:Userlogin|logged in]] to move a page.',
 'movenotallowed'          => 'You do not have permission to move pages on {{SITENAME}}.',
 'newtitle'                => 'To new title:',
 'move-watch'              => 'Watch this page',
@@ -2491,7 +2488,7 @@
 'revertmove'              => 'revert',
 'delete_and_move'         => 'Delete and move',
 'delete_and_move_text'    => '==Deletion required==
-The destination page "[[$1]]" already exists.
+The destination page "[[:$1]]" already exists.
 Do you want to delete it to make way for the move?',
 'delete_and_move_confirm' => 'Yes, delete the page',
 'delete_and_move_reason'  => 'Deleted to make way for move',
@@ -2550,7 +2547,8 @@
 'import-interwiki-history'   => 'Copy all history versions for this page',
 'import-interwiki-submit'    => 'Import',
 'import-interwiki-namespace' => 'Transfer pages into namespace:',
-'importtext'                 => 'Please export the file from the source wiki using the Special:Export utility, save it to your disk and upload it here.',
+'importtext'                 => 'Please export the file from the source wiki using the [[Special:Export|export utility]].
+Save it to your computer and upload it here.',
 'importstart'                => 'Importing pages...',
 'import-revision-count'      => '$1 {{PLURAL:$1|revision|revisions}}',
 'importnopages'              => 'No pages to import.',
@@ -2782,7 +2780,7 @@
 
 # Patrol log
 'patrol-log-page'   => 'Patrol log',
-'patrol-log-header' => '', # do not translate or duplicate this message to other languages
+'patrol-log-header' => 'This is a log of patrolled revisions.',
 'patrol-log-line'   => 'marked $1 of $2 patrolled $3',
 'patrol-log-auto'   => '(automatic)',
 'patrol-log-diff'   => 'r$1', # only translate this message to other languages if you have to change it
@@ -2815,10 +2813,10 @@
 'show-big-image'       => 'Full resolution',
 'show-big-image-thumb' => '<small>Size of this preview: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Gallery of new files',
 'imagelisttext'         => "Below is a list of '''$1''' {{PLURAL:$1|file|files}} sorted $2.",
-'newimages-summary'     => 'This special page shows the last uploaded files',
+'newimages-summary'     => 'This special page shows the last uploaded files.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Nothing to see.',
 'ilsubmit'              => 'Search',
@@ -3175,7 +3173,7 @@
 
 # External editor support
 'edit-externally'      => 'Edit this file using an external application',
-'edit-externally-help' => 'See the [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] for more information.',
+'edit-externally-help' => 'See the [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] for more information.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'all',
@@ -3205,7 +3203,7 @@
 The code may have expired.',
 'confirmemail_needlogin'   => 'You need to $1 to confirm your e-mail address.',
 'confirmemail_success'     => 'Your e-mail address has been confirmed.
-You may now log in and enjoy the wiki.',
+You may now [[Special:UserLogin|log in]] and enjoy the wiki.',
 'confirmemail_loggedin'    => 'Your e-mail address has now been confirmed.',
 'confirmemail_error'       => 'Something went wrong saving your confirmation.',
 'confirmemail_subject'     => '{{SITENAME}} e-mail address confirmation',
@@ -3245,13 +3243,13 @@
 'deletedwhileediting' => 'Warning: This page has been deleted after you started editing!',
 'confirmrecreate'     => "User [[User:$1|$1]] ([[User talk:$1|talk]]) deleted this page after you started editing with reason:
 : ''$2''
-Please confirm that really want to recreate this page.",
+Please confirm that you really want to recreate this page.",
 'recreate'            => 'Recreate',
 
 'unit-pixel' => 'px', # only translate this message to other languages if you have to change it
 
 # HTML dump
-'redirectingto' => 'Redirecting to [[$1]]...',
+'redirectingto' => 'Redirecting to [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Clear the cache of this page?
@@ -3334,8 +3332,8 @@
 Try normal preview.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Changes newer than $1 seconds may not be shown in this list.',
-'lag-warn-high'   => 'Due to high database server lag, changes newer than $1 seconds may not be shown in this list.',
+'lag-warn-normal' => 'Changes newer than $1 {{PLURAL:$1|second|seconds}} may not be shown in this list.',
+'lag-warn-high'   => 'Due to high database server lag, changes newer than $1 {{PLURAL:$1|second|seconds}} may not be shown in this list.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Your watchlist contains {{PLURAL:$1|1 title|$1 titles}}, excluding talk pages.',
@@ -3451,7 +3449,7 @@
 'version-software-product'         => 'Product',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'File path',
 'filepath-page'    => 'File:',
 'filepath-submit'  => 'Path',
@@ -3491,7 +3489,7 @@
 'specialpages-group-redirects'   => 'Redirecting special pages',
 'specialpages-group-spam'        => 'Spam tools',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Blank page',
 'intentionallyblankpage' => 'This page is intentionally left blank',
 
Index: languages/messages/MessagesJut.php
===================================================================
--- languages/messages/MessagesJut.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesJut.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Ælsån
  * @author Huslåke
- * @author Siebrand
- * @author M.M.S.
+ * @author Ælsån
  */
 
 $fallback = 'da';
@@ -424,7 +422,7 @@
 'templatesusedpreview'   => 'Følgende skablåner bruges åf denne ertikelførhåndsvesnenge:',
 'template-protected'     => '(skrevebeskyttet)',
 'template-semiprotected' => '(skrevebeskyttet før ekke ånmeldte og nye brugere)',
-'nocreatetext'           => "Æ'n åpdiin har begrænset åprettelse åf nye sider. Bestående sider ken ændres æller [[Special:Userlogin|loĝge på]].",
+'nocreatetext'           => "Æ'n åpdiin har begrænset åprettelse åf nye sider. Bestående sider ken ændres æller [[Special:UserLogin|loĝge på]].",
 'recreate-deleted-warn'  => "'''Advarsel: Du er ve at genskabe en tidligere slettet side.'''
  
 Åvervej det'm er passende at genåprette'n side. De slettede hersenenger før 
@@ -510,7 +508,7 @@
 'uploadlogpage' => 'Åplægnengslog',
 'uploadedimage' => 'Låĝde "[[$1]]" åp',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Billetliste',
 
 # Image description page
@@ -597,7 +595,7 @@
 'log'                  => 'Loglister',
 'all-logs-page'        => 'Åle loglister',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Åle ertikler',
 'alphaindexline' => '$1 til $2',
 'nextpage'       => 'Næste side ($1)',
@@ -618,7 +616,7 @@
 'mywatchlist'          => 'Åvervågnengsliste',
 'watchlistfor'         => "(før '''$1''')",
 'addedwatch'           => 'Tilføjet til din åvervågnengsliste',
-'addedwatchtext'       => "Æ side \"<nowiki>\$1</nowiki>\" er blevet tilføjet til din [[Special:Watchlist|åvervågningsliste]]. Fremtidige ændrenger til denne side og den tilhørende diskusjeside hvil bleve listet der, og æ side hvil fremstå '''fremhævet''' i'n [[Special:Recentchanges|liste ve de seneste ændrenger]] før at gøre det lettere at finde den. Hves du senere hvilst fjerne'n side frå din åvervågningsliste, så klik \"Fjern åvervågnenge\".",
+'addedwatchtext'       => "Æ side \"[[:\$1]]\" er blevet tilføjet til din [[Special:Watchlist|åvervågningsliste]]. Fremtidige ændrenger til denne side og den tilhørende diskusjeside hvil bleve listet der, og æ side hvil fremstå '''fremhævet''' i'n [[Special:RecentChanges|liste ve de seneste ændrenger]] før at gøre det lettere at finde den. Hves du senere hvilst fjerne'n side frå din åvervågningsliste, så klik \"Fjern åvervågnenge\".",
 'removedwatch'         => 'Fjernet frå åvervågnengsliste',
 'removedwatchtext'     => 'Æ side "<nowiki>$1</nowiki>" er blevet fjernet frå din åvervågnengsliste.',
 'watch'                => 'Åvervåg',
@@ -809,7 +807,7 @@
 'show-big-image'       => 'Hersenenge i større åpløsnenge',
 'show-big-image-thumb' => '<small>Størrelse åf førhåndsvesnenge: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Liste ve de nyeste billeter',
 
 # Bad image list
@@ -832,7 +830,7 @@
 
 # External editor support
 'edit-externally'      => "Redigær denne gøret ve'n utsende redigærstøme",
-'edit-externally-help' => 'Se [http://meta.wikimedia.org/wiki/Help:External_editors setup hjælpje] før mære informasje.',
+'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors setup hjælpje] før mære informasje.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'åle',
Index: languages/messages/MessagesAs.php
===================================================================
--- languages/messages/MessagesAs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Priyankoo
+ * @author Psneog
  * @author Rajuonline
- * @author Psneog
- * @author Siebrand
- * @author Priyankoo
  */
 
 $fallback='hi';
@@ -132,6 +131,7 @@
 'hidden-category-category'      => 'গোপন শ্রেণী সমুহ', # Name of the category where hidden categories will be listed
 'category-subcat-count'         => '{{PLURAL:$2|এই শ্রেণীত নিম্নলিখিত উপশ্রেণী আছে| এই শ্রেণীত নিম্নলিখিত {{PLURAL:$1|উপশ্রেণীটো|$1 উপশ্রেণীসমুহ}} আছে, মুঠতে $2  তা উপশ্রেণী।}}',
 'category-subcat-count-limited' => 'এই শ্রেণীত নিম্নলিখিত {{PLURAL:$1|উপশ্রেণী আছে|$1 উপশ্রেণী আছে}}.',
+'category-article-count'        => '{{PLURAL:$2|এই শ্রেণীটোত কেবল তলত দিয়া লিখনীটোহে আছে।|এই শ্রেণীটোত তলৰ  {{PLURAL:$1|এটা লিখনী আছে|$1 টা লিখনী আছে}}, মুঠ লিখনী $2 টা।}}',
 'listingcontinuesabbrev'        => 'আগলৈ',
 
 'about'          => 'বিষয়ে',
@@ -260,6 +260,7 @@
 'thisisdeleted'           => '$1 চাওক বা সলনি কৰক?',
 'viewdeleted'             => '$1 চাওক?',
 'page-rss-feed'           => '"$1" আৰ-এচ-এচ ফীড',
+'red-link-title'          => '$1 (এতিয়ালৈকে সৃষ্টি কৰা হোৱা নাই)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'পৃষ্ঠা',
@@ -279,7 +280,7 @@
 'nosuchspecialpage' => 'এনেকুৱা কোনো বিশেষ পৃষ্ঠা নাই',
 'nospecialpagetext' => "<big>'''আপুনি অস্তিত্বত নথকা বিশেষ পৃষ্ঠা এটা বিচাৰিছে '''</big>
 
-   বিশেষ পৃষ্ঠাহমুহৰ তালিকা ইয়াত পাব [[Special:Specialpages|{{int:specialpages}}]].",
+   বিশেষ পৃষ্ঠাহমুহৰ তালিকা ইয়াত পাব [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'ভুল',
@@ -300,12 +301,19 @@
 'filerenameerror'      => '"$1" ফাইলৰ নাম সলনি কৰি "$2" কৰিব পৰা নগল ।',
 'filedeleteerror'      => '"$1" ফাইলতো বিলোপ কৰিব পৰা নগল।',
 'directorycreateerror' => '"$1" ডাইৰেক্টৰি বনাব পৰা নগল।',
+'filenotfound'         => '"$1" নামৰ ফাইলটো বিচাৰি পোৱা নগল।',
+'fileexistserror'      => '"$1" ফাইলটোত লিখিব নোৱাৰি: ফাইলটো আগৰ পৰাই আছে',
+'unexpected'           => 'অনাকাংক্ষিত মুল্য: "$1"="$2".',
+'formerror'            => 'ভুল: ফর্ম খন জমা দিব পৰা নগল',
+'badarticleerror'      => 'এই পৃষ্ঠাটোত এই কামটো কৰিব নোৱাৰি ।',
 'badtitle'             => 'অনভিপ্রেত শিৰোণামা',
 'badtitletext'         => 'আপুনি বিচৰা পৃষ্ঠাটোৰ শিৰোণামা অযোগ্য, খালী বা ভুলকে জৰিত আন্তর্ভাষিক বা আন্তর্ৱিকি শিৰোণামা। ইয়াত এক বা ততোধিক বর্ণ থাকিব পাৰে যাক শিৰোণামাত ব্যৱহাৰ কৰিব নোৱাৰি।',
 'perfdisabled'         => 'ক্ষমা কৰিব! এই সুবিধাতো সাময়িক ভাবে বন্ধ কৰা হৈছে, কাৰণ ই তথ্যকোষ ইমানেই লেহেম কৰি দিয়ে যে কোনেও ৱিকি ব্যৱহাৰ কৰিব নোৱাৰে।',
 'perfcached'           => 'তলত দিয়া তথ্য খিনি আগতে জমা কৰি থোৱা (cached) আৰু সাম্প্রতিক নহব পাৰে।',
 'perfcachedts'         => 'তলত দিয়া তথ্য খিনি আগতে জমা কৰি থোৱা (cached) আৰু শেষবাৰৰ কাৰণে $1 ত নৱীকৰণ কৰা হৈছিল।',
 'querypage-no-updates' => 'এই পৃষ্ঠাটো নৱীকৰণ কৰা ৰোধ কৰা হৈছে। ইয়াৰ তথ্য এতিয়া সতেজ কৰিব নোৱাৰি।',
+'wrong_wfQuery_params' => 'wfQuery() ৰ কাৰণে ভুল মাপদণ্ড দিয়া হৈছে <br />
+কার্য্য: $1<br />পৃষ্ঠা: $2',
 'viewsource'           => 'উৎস চাবলৈ',
 'viewsourcefor'        => '$1 ৰ কাৰণে',
 'actionthrottledtext'  => 'স্পাম ৰোধ কৰিবলৈ এই ক্রিয়াতো কম সময়ৰ ভিতৰত বহু বেছি বাৰ কৰাতো ৰোধ কৰা হৈছে, আৰু আপুনি ইতিমধ্যে সেই সীমা অতিক্রম কৰিলে। 
@@ -337,7 +345,7 @@
 'nav-login-createaccount'    => 'প্রৱেশ/সদস্যভুক্তি',
 'loginprompt'                => '{{SITENAME}}ত প্রৱেশ কৰিবলৈ আপুনি কুকী সক্রীয় কৰিব লাগিব',
 'userlogin'                  => 'প্রৱেশ/সদস্যভুক্তি',
-'logout'                     => 'নিৰ্গম',
+'logout'                     => 'প্রস্থান',
 'userlogout'                 => 'প্রস্থান',
 'notloggedin'                => 'প্রৱেশ কৰা নাই',
 'nologin'                    => 'আপুনি সদস্য নহয়? $1।',
@@ -410,7 +418,10 @@
 'accountcreated'             => 'সদস্যতা সৃষ্টি কৰা হল',
 'accountcreatedtext'         => '$1 ৰ কাৰণে সদস্যভুক্তি কৰা হল।',
 'createaccount-title'        => '{{SITENAME}} ৰ কাৰণে সদস্যভুক্তি কৰক।',
+'createaccount-text'         => 'আপোনাৰ ই-মেইল ঠিকণাৰ কাৰণে {{SITENAME}} ($4) ত "$2" নামৰ কোনোবাই, "$3" গুপ্তশব্দ দি সদস্যভুক্তি কৰিছে। আনুগ্রহ কৰি আপুনি প্রৱেশ কৰক আৰু গুপ্তশব্দটো সলনি কৰক।
 
+যদি এ্য়া ভুলতে হৈছে, তেনেহলে আপুনি এই বার্তাটো অবজ্ঞা কৰিব পাৰে ।',
+
 # Password reset dialog
 'resetpass'               => 'গুপ্তশব্দ পূণর্স্থাপন কৰক',
 'resetpass_announce'      => 'আপুনি ই-মেইলত পোৱা অস্থায়ী গুপ্তশব্দৰে প্রৱেশ কৰিছে।
@@ -421,6 +432,7 @@
 'resetpass_bad_temporary' => 'অস্থায়ী গুপ্তশব্দ ভুল ।
 হয়তো আপুনি আগতেই গুপ্তশব্দ সলনি কৰিছে, অথবা নতুন গুপ্তশব্দৰ কাৰণে অনুৰোধ পঠাইছে।',
 'resetpass_forbidden'     => '{{SITENAME}} ত গুপ্তশব্দ সলনি কৰিব নোৱাৰি',
+'resetpass_missing'       => 'ফর্মৰ তথ্য নাই ।',
 
 # Edit page toolbar
 'bold_sample'     => 'শকত পাঠ্য',
@@ -456,16 +468,42 @@
 'missingsummary'         => "'''স্মাৰক:''' আপুনি সম্পাদনা সাৰাংশ দিয়া নাই।
 আপুনি আৰু এবাৰ সংৰক্ষণৰ বাবে ক্লীক কৰিলে সাৰাংশৰ অবিহনে সংৰক্ষিত হব।",
 'missingcommenttext'     => 'অনুগ্রহ কৰি তলত মন্তব্য এটা দিয়্ক।',
+'missingcommentheader'   => "'''স্মাৰক:''' আপুনি এই মন্তব্যটোত শিৰোণামা দিয়া নাই।
+যদি আকৌ এবাৰ সংৰক্ষিত কৰে, তেনেহলে শিৰোণামা অবিহনে সংৰক্ষিত হব।",
 'summary-preview'        => 'সাৰাংশৰ খচৰা',
 'subject-preview'        => 'বিষয়/শিৰোণামাৰ খচৰা',
+'blockedtitle'           => 'সদস্যজনক অবৰোধ কৰা হৈছে',
+'blockedtext'            => "<big>'''আপোনাৰ সদস্যনাম অথবা আই-পি ঠিকণা অবৰোধ কৰা হৈছে ।'''</big>
+
+ $1 ৰ দ্বাৰ এই অবৰোধ কৰা হৈছে । ইয়াৰ বাবে দিয়া কাৰণ হৈছে ''$2'' ।
+
+* অবৰোধ আৰম্ভনী: $8
+* অবৰোধ সমাপ্তি: $6
+* অবৰোধ কৰা হৈছে: $7
+
+আপুনি এই অবৰোধৰ বিষয়ে আলোচনা কৰিবলৈ $1 বা [[{{MediaWiki:Grouppage-sysop}}|প্রবন্ধকৰ]] লগত সম্পর্ক স্থাপন কৰিব পাৰে ।
+আপুনি যেতিয়ালৈ [[Special:Preferences|সদস্য পছন্দ]] পৃষ্ঠাত আপোনাৰ ই-মেইল ঠিকনা নিদিয়ে তেতিয়ালৈ ’সদস্যক ই-মেইল পঠাওক’ সুবিধাতো ব্যৱহাৰ কৰিব নোৱাৰে। আপোনাক এয়া কৰিবলৈ ৰোধ কৰা হোৱা নাই । 
+আপোনাৰ এতিয়াৰ IP ঠিকনা হল $3, আৰু আপোনাৰ অবৰোধ ক্রমিক হৈছে #$5 । 
+এই বিষয়ে হোৱা আলোচনাত ইয়াৰ যিকোনো এটা ব্যৱহাৰ কৰিবলৈ অনুৰোধ কৰা হল।",
+'autoblockedtext'        => "আপোনাৰ IP ঠিকনা নিজে নিজে অবৰোধিত হৈ গৈছে, কাৰণ ইয়াক কোনোবাই ব্যৱহাৰ কৰি থাকোতে $1 ৰ দ্বাৰা অবৰোধ কৰা হৈছে।
+ইয়াৰ বাবে দিয়া কাৰণ হৈছে:
+
+:''$2''
+
+* অবৰোধ আৰম্ভনী:  $8
+* অবৰোধ সমাপ্তি: $6
+* অৱৰোধ কৰা হৈছে: $7
+
+আপুনি এই অবৰোধৰ বিষয়ে আলোচনা কৰিবলৈ $1 বা [[{{MediaWiki:Grouppage-sysop}}|প্রবন্ধক]]ৰ লগত সম্পর্ক স্থাপন কৰিব পাৰে ।
+
+আপুনি যেতিয়ালৈ [[Special:Preferences|সদস্য পছন্দ]] পৃষ্ঠাত আপোনাৰ ই-মেইল ঠিকনা নিদিয়ে তেতিয়ালৈ ’সদস্যক ই-মেইল পঠাওক’ সুবিধাতো ব্যৱহাৰ কৰিব নোৱাৰে। আপোনাক এয়া কৰিবলৈ ৰোধ কৰা হোৱা নাই ।
+অপোনাৰ এতিয়াৰ IP ঠিকনা হৈছে $3, অৰু আপোনাৰ অবৰোধ ক্রমিক হৈছে $5 ।
+এই বিষয়ে হোৱা আলোচনাত ইয়াক ব্যৱহাৰ কৰিবলৈ অনুৰোধ কৰা হল।",
 'blockednoreason'        => 'কাৰণ দিয়া নাই',
 'blockedoriginalsource'  => "'''$1''' ৰ উত্‍স তলত দিয়া হৈছে।",
 'blockededitsource'      => "'''$1''' ৰ '''আপুনি কৰা সাল-সলনি''' ৰ পাঠ্য তলত দিয়া হৈছে:",
 'whitelistedittitle'     => 'সম্পাদনা কৰিবলৈ প্রবেশ কৰিব লাগিব।',
 'whitelistedittext'      => 'সম্পাদনা কৰিবলৈ $1 কৰক ।',
-'whitelistreadtitle'     => 'পঢ়িবলৈ প্রবেশ কৰিব লাগিব',
-'whitelistreadtext'      => 'লিখনী পঢ়িবলৈ [[Special:Userlogin|প্রবেশ]] কৰা আৱশ্যক ।',
-'whitelistacctitle'      => 'আপুনি নতুন সদস্যভুক্তি কৰিব নোৱাৰে।',
 'confirmedittitle'       => 'সম্পাদনা কৰিবলৈ ই-মেইলেৰে নিশ্বয়তা কৰিব লাগিব।',
 'confirmedittext'        => 'সম্পাদনা কৰাৰ আগতে আপুনি আপোনাৰ ই-মেইল ঠিকনাটো প্রমানিত কৰিব লাগিব।
 অনুগ্রহ কৰি [[Special:Preferences|মোৰ পচন্দ]] ত গৈ আপোনাৰ ই-মেইল ঠিকনা দিয়ক আৰু তাক প্রমানিত কৰক।',
@@ -488,6 +526,7 @@
 'previewnote'            => '<strong>মনত ৰাখিব যে এয়া কেৱল খচৰা হে, সাল-সলনিবোৰ এতিয়াও সংৰক্ষিত কৰা হোৱা নাই!</strong>',
 'editing'                => '$1 সম্পাদনা',
 'editingsection'         => '$1 (বিভাগ) সম্পদনা কৰি থকা হৈছে',
+'editingcomment'         => '$1 (মন্তব্য) সম্পাদন',
 'copyrightwarning'       => "অনুগ্ৰহ কৰি মন কৰক যে {{SITENAME}}লৈ কৰা সকলো অৱদান $2 ৰ চর্তাৱলীৰ মতে প্রদান কৰা বুলি ধৰি লোৱা হব (আৰু অধিক জানিবলৈ $1 চাঁওক)। যদি আপুনি আপোনাৰ লিখনি নিৰ্দয়ভাৱে সম্পাদনা কৰা আৰু ইচ্ছামতে পুনৰ্বিতৰণ কৰা ভাল নাপায়, তেনেহ'লে নিজৰ লিখনি ইয়াত নিদিব|
 <br />
 
@@ -495,16 +534,19 @@
 <strong>স্বত্বাধিকাৰযুক্ত কোনো সমল অনুমতি অবিহনে দাখিল নকৰে যেন!</strong>",
 'copyrightwarning2'      => 'অনুগ্ৰহ কৰি মন কৰক যে {{SITENAME}}লৈ কৰা সকলো অৱদান আন সদস্যই সম্পাদনা কৰিব, সলনি কৰিব অথবা মচি দিব পাৰে।
 আপুনি যদি আপোনাৰ লিখনি নিৰ্দয়ভাৱে সম্পাদনা কৰা ভাল নাপায়, তেনেহলে নিজৰ লিখনি ইয়াত নিদিব|<br />
-ইয়াত আপোনাৰ লিখনি দিয়াৰ লগে লগে আপুনি আপোনা-আপুনি প্ৰতিশ্ৰুতি দিছে যে এই লিখনিটো আপোনাৰ মৌলিক লিখনি, বা কোনো স্বত্বাধিকাৰ নথকা বা কোনো ৰাজহুৱা ৱেবছাইট বা তেনে কোনো মুকলি উৎসৰ পৰা আহৰণ কৰা| 
+ইয়াত আপোনাৰ লিখনি দিয়াৰ লগে লগে আপুনি আপোনা-আপুনি প্ৰতিশ্ৰুতি দিছে যে এই লিখনিটো আপোনাৰ মৌলিক লিখনি, বা কোনো স্বত্বাধিকাৰ নথকা বা কোনো ৰাজহুৱা ৱেবছাইট বা তেনে কোনো মুকলি উৎসৰ পৰা আহৰণ কৰা| (অধিক জানিবলৈ $1 চাঁওক)
+
 <strong>স্বত্বাধিকাৰযুক্ত কোনো সমল অনুমতি অবিহনে দাখিল নকৰে যেন!</strong>',
 'longpagewarning'        => '<strong>সাবধান: এই পৃষ্ঠাটো $1 কিলোবাইট আকাৰৰ; কিছুমান ব্রাউজাৰে 32kb বা তাতকৈ বেছি আকাৰৰ পৃষ্ঠা দেখুৱাবলৈ বা সম্পাদনা কৰিবলৈ অসুবিধা পাব পাৰে ।
 অনুগ্রহ কৰি এই পৃষ্ঠাটোক সৰু সৰু খণ্ডত বিভক্ত কৰাৰ কথা বিবেচনা কৰক ।</strong>',
+'longpageerror'          => '<strong>ভুল: আপুনি দিয়া লিখনী $1 কিলো-বাইট আকাৰৰ, যি $2 কিলো-বাইট সীমাটকৈ বেছি।
+ইয়াক সঞ্চিত কৰিব পৰা নাযাব।</strong>',
 'templatesused'          => 'এই পৃষ্ঠাত ব্যৱহৃত ঠাঁচ সমুহ',
 'templatesusedpreview'   => 'ব্যৱহৃত ঠাঁচ সমুহ',
 'template-protected'     => '(সুৰক্ষিত)',
 'template-semiprotected' => '(অর্ধ-সুৰক্ষিত)',
 'nocreatetext'           => '{{SITENAME}} ত নতুন লিখনী লিখা ৰদ কৰা হৈছে।
-আপুনি ঘুৰি গৈ অস্তিত্বত থকা পৃষ্ঠা এটা সম্পাদনা কৰিব পাৰে, বা [[Special:Userlogin| নতুন সদস্যভর্তি হওক/ প্রবেশ কৰক]] ।',
+আপুনি ঘুৰি গৈ অস্তিত্বত থকা পৃষ্ঠা এটা সম্পাদনা কৰিব পাৰে, বা [[Special:UserLogin| নতুন সদস্যভর্তি হওক/ প্রবেশ কৰক]] ।',
 'recreate-deleted-warn'  => "'''সাৱধান: আপুনি আগতে বিলোপিত কৰা পৃষ্ঠা এটা পূণঃনির্মান কৰি আছে। '''
 
 এই পৄষ্ঠাটো সম্পাদনা কৰা উচিত হব নে নাই আপুনি বিবেচনা কৰি চাওক।
@@ -518,12 +560,29 @@
 'nextrevision'        => 'সদ্যসংশোধিত',
 'currentrevisionlink' => 'শেহতীয়া ভাষ্য',
 'cur'                 => 'বর্তমান',
-'last'                => 'আগৰ',
+'next'                => 'পৰবর্তী',
+'last'                => 'পুর্ববর্তি',
 'page_first'          => 'প্রথম',
 'page_last'           => 'অন্তিম',
+'histlegend'          => 'পার্থক্য বাচনী: পার্থক্য চাবলৈ সংকলনবোৰৰ সম্মুখত থকা ৰেডিও বুটামবোৰ বাচনী কৰি এণ্টাৰ টিপক অথবা একেবাৰে তলত দিয়া বুটামতো ক্লীক কৰক <br />
+লিজেণ্ড: (বর্তমান) = বর্তমানৰ সংকলনৰ লগত পার্থক্য,
+(অন্তিম) = আগৰ সংকলনৰ লগত পার্থক্য, M = অগুৰুত্বপুর্ণ সম্পাদনা।',
+'deletedrev'          => '[বিলোপন কৰা হল]',
 'histfirst'           => 'আটাইতকৈ পূৰণি',
 'histlast'            => 'শেহতীয়া',
+'historyempty'        => '(খালী)',
 
+# Revision feed
+'history-feed-title'       => 'সংকলন ইতিহাস',
+'history-feed-description' => 'ৱিকিত উপলব্ধ এই পৃষ্ঠাৰ সংকলন ইতিহাস',
+'history-feed-empty'       => 'এই পৃষ্ঠা বা লিখনীটো নাই।
+হয়তো ইয়াক বিলোপিত কৰা হৈছে অথবা ইয়াৰ নাম সলনী কৰা হৈছে।
+[[Special:Search|সন্ধান]] ব্যৱহাৰ কৰি চাওক।',
+
+# Revision deletion
+'rev-delundel'   => 'দেখোৱা হওক / লুকুওৱা হওক',
+'revisiondelete' => 'সংকলন বিলোপন কৰক / পুণর্স্থাপিত কৰক',
+
 # Diffs
 'history-title'           => '"$1" ৰ সাল-সলনিৰ ইতিহাস',
 'difference'              => 'বিভিন্ন সংস্কৰণৰ প্রভেদ',
@@ -532,17 +591,95 @@
 'editundo'                => 'পূৰ্ববতাৰ্থে',
 
 # Search results
-'noexactmatch' => "'''\"\$1\" শিৰোণামাৰ কোনো লিখনী নাই।''' আপুনী এই লিখনী [[:\$1|লিখিব পাৰে]]।",
-'prevn'        => 'পিছলৈ $1',
-'nextn'        => 'পৰৱর্তি $1',
-'viewprevnext' => 'চাওক ($1) ($2) ($3)',
-'powersearch'  => 'অতিসন্ধান',
+'noexactmatch'          => "'''\"\$1\" শিৰোণামাৰ কোনো লিখনী নাই।''' আপুনী এই লিখনী [[:\$1|লিখিব পাৰে]]।",
+'noexactmatch-nocreate' => "'''\"\$1\" শিৰোণামাৰ কোনো লিখনী নাই।'''",
+'toomanymatches'        => 'বহুত বেছি মিল পোৱা গৈছে, সন্ধাণ-শব্দ সলনি কৰিবলৈ অনুৰোধ কৰা হল',
+'titlematches'          => 'পৃষ্ঠাৰ শিৰোণামা মিলিছে',
+'notitlematches'        => 'এটাও পৃষ্ঠাৰ শিৰোণামা মিলা নাই',
+'textmatches'           => 'লিখনীৰ পাঠ্য মিলিছে',
+'notextmatches'         => 'এটাও লিখনীৰ পাঠ্য মিলা নাই',
+'prevn'                 => 'পুর্ববর্তি $1',
+'nextn'                 => 'পৰৱর্তি $1',
+'viewprevnext'          => 'চাওক ($1) ($2) ($3)',
+'showingresults'        => "তলত #'''$2'''ৰ পৰা {{PLURAL:$1|'''1''' ফলাফল|'''$1''' ফলাফল}} দেখুওৱা হৈছে।",
+'powersearch'           => 'অতিসন্ধান',
+'powersearch-legend'    => 'শক্তিশালী সন্ধান',
+'powersearch-ns'        => 'নামস্থানবোৰত সন্ধান:',
+'powersearch-redir'     => 'পূণঃনির্দেশনা বোৰৰ তালিকা',
+'powersearch-field'     => 'ৰ কাৰণে সন্ধান কৰক',
+'search-external'       => 'বাহ্যিক সন্ধান',
+'searchdisabled'        => '{{SITENAME}} ত অনুসন্ধান কৰা সাময়িক ভাবে নিষ্ক্রিয় কৰা হৈছে।
+তেতিয়ালৈকে গুগলত অনুসন্ধান কৰক।
+মনত ৰাখিব যে তেঁওলোকৰ {{SITENAME}}ৰ ইণ্ডেক্স পুৰণি হব পাৰে।',
 
 # Preferences page
-'preferences'   => 'ৰুচি',
-'mypreferences' => 'মোৰ পচন্দ',
-'retypenew'     => 'নতুন গুপ্তশব্দ আকৌ টাইপ কৰক',
+'preferences'              => 'ৰুচি',
+'mypreferences'            => 'মোৰ পচন্দ',
+'prefs-edits'              => 'সম্পাদনা সমুহৰ সংখ্যা:',
+'prefsnologin'             => 'প্রৱেশ কৰা নাই',
+'prefsnologintext'         => 'আপোনাৰ পচন্দ সলনী কৰিবলৈ হলে [[Special:UserLogin|প্রৱেশ]] কৰাতো আৱশ্যক।',
+'prefsreset'               => 'পচন্দ সমুহ পুর্ববত কৰা হৈছে।',
+'qbsettings'               => 'শীঘ্রদণ্ডিকা',
+'qbsettings-none'          => 'একেবাৰে নহয়',
+'qbsettings-fixedleft'     => 'বাঁওফাল স্থিৰ',
+'qbsettings-fixedright'    => 'সোঁফাল স্থিৰ',
+'qbsettings-floatingleft'  => 'বাঁওফাল অস্থিৰ',
+'qbsettings-floatingright' => 'সোঁফাল অস্থিৰ',
+'changepassword'           => 'গুপ্তশব্দ সলনী কৰক',
+'skin'                     => 'আৱৰন',
+'math'                     => 'গণিত',
+'dateformat'               => 'তাৰিখৰ সজ্জা',
+'datedefault'              => 'বিশেষ পচন্দ নাই',
+'datetime'                 => 'তাৰিখ আৰু সময়',
+'math_failure'             => 'পার্চ কৰিব অসমর্থ',
+'math_unknown_error'       => 'অপৰিচিত সমস্যা',
+'math_unknown_function'    => 'অজ্ঞাত কার্য্য',
+'prefs-personal'           => 'সদস্যৰ বিৱৰণ',
+'prefs-rc'                 => 'শেহতীয়া সাল-সলনী',
+'prefs-watchlist'          => 'লক্ষ্য তালিকা',
+'prefs-watchlist-days'     => 'লক্ষ্য তালিকাত দেখুৱাব লগা দিন:',
+'prefs-watchlist-edits'    => 'বর্ধিত লক্ষ্যসুচীত দেখুৱাব লগা সর্বোচ্চ সাল-সলনী:',
+'prefs-misc'               => 'অন্যান্য',
+'saveprefs'                => 'সঞ্চিত কৰক',
+'resetprefs'               => 'অসঞ্চিত সাল-সলনী বাতিল কৰক',
+'oldpassword'              => 'পূৰণি গুপ্তশব্দ:',
+'newpassword'              => 'নতুন গুপ্তশব্দ:',
+'retypenew'                => 'নতুন গুপ্তশব্দ আকৌ টাইপ কৰক',
+'textboxsize'              => 'সম্পাদন',
+'rows'                     => 'পথালী শাৰী:',
+'columns'                  => 'ঠিয় শাৰী:',
+'searchresultshead'        => 'অনুসন্ধান',
+'resultsperpage'           => 'প্রতি পৃষ্ঠা দর্শন:',
+'contextlines'             => 'প্রতি শাৰী দর্শন:',
+'contextchars'             => 'প্রতি শাৰীত সন্দর্ভ:',
+'stub-threshold'           => '<a href="#" class="stub">আধাৰ সংযোগ</a> ৰ সর্বোচ্চ আকাৰ (বাইটত):',
+'recentchangesdays'        => 'শেহতীয়া সাল-সলনীত দেখুৱাব লগা দিন:',
+'recentchangescount'       => 'শেহতীয়া সাল-সলনী, ইতিহাস আৰু লগ পৃষ্ঠাত দেখুৱাব লগা সম্পাদনাৰ সংখ্যা:',
+'savedprefs'               => 'আপোনাৰ পচন্দসমুহ সংৰক্ষিত কৰা হল।',
+'timezonelegend'           => 'সময় স্থান',
+'timezonetext'             => '¹চার্ভাৰৰ সময় (UTC) আৰু আপোনাৰ সময়ৰ মাজত পার্থক্য (ঘণ্টাত)।',
+'localtime'                => 'স্থানীয় সময়',
+'timezoneoffset'           => 'পার্থক্য¹',
+'servertime'               => 'চার্ভাৰৰ সময়',
+'guesstimezone'            => 'ব্রাউজাৰৰ পৰা ভৰাওক',
+'allowemail'               => 'অন্য সদস্যৰ পৰা ই-মেইল সমর্থ কৰক',
+'prefs-searchoptions'      => 'সন্ধান বিকল্পসমুহ',
+'prefs-namespaces'         => 'নামস্থান',
+'defaultns'                => 'এই নামস্থান সমুহত সদায়ে অনুসন্ধান কৰিব:',
+'default'                  => 'অবিচল',
+'files'                    => 'ফাইলসমুহ',
 
+# User rights
+'userrights'               => 'সদস্যৰ অধিকাৰ ব্যৱস্থাপনা', # Not used as normal message but as header for the special page itself
+'userrights-lookup-user'   => 'সদস্য গোটবোৰ ব্যৱস্থাপনা কৰক',
+'userrights-user-editname' => 'সদস্যনাম দিয়ক:',
+'editusergroup'            => 'সদস্য গোটবোৰ সম্পাদনা কৰক',
+'editinguser'              => "'''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]]) সদস্যজনৰ অধিকাৰ সলনী কৰি থকা হৈছে।",
+'userrights-editusergroup' => 'সদস্য গোট সম্পাদনা কৰক',
+'saveusergroups'           => 'সদস্য গোট সংৰক্ষিত কৰক',
+'userrights-groupsmember'  => 'এই গোটবোৰৰ সদস্য:',
+'userrights-reason'        => 'সালসলনীৰ কাৰণ:',
+
 'grouppage-sysop' => '{{ns:project}}:প্রবন্ধক',
 
 # User rights log
@@ -580,7 +717,7 @@
 'uploadlogpage' => 'আপলোড সুচী',
 'uploadedimage' => '"[[$1]]" আপলোড কৰা হ’ল',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'ফাইলৰ তালিকা',
 
 # Image description page
@@ -645,7 +782,7 @@
 'log'                  => 'আলেখ',
 'all-logs-page'        => 'সকলো সুচী',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'সকলোবোৰ পৃষ্ঠা',
 'alphaindexline' => '$1 -ৰ পৰা $2 -লৈ',
 'nextpage'       => 'পৰৱর্তী পৃষ্ঠা ($1)',
@@ -668,7 +805,7 @@
 'watchlistfor'         => "('''$1''' ৰ কাৰনে)",
 'addedwatch'           => 'লক্ষ্য তালিকাত অন্তর্ভুক্তি কৰা হল',
 'addedwatchtext'       => 'আপোনাৰ [[Special:Watchlist|লক্ষ্য তালিকাত ]]  "<nowiki>$1</nowiki>" অন্তর্ভুক্তি কৰা হল ।
-ভৱিশ্যতে ইয়াত হোৱা সাল-সলনি আপুনি আপোনাৰ লক্ষ্য তালিকাত দেখিব, লগতে [[Special:Recentchanges|সম্প্রতিক সাল-সলনিৰ তালিকাত]] এই পৃষ্ঠাটো শকট আখৰত দেখিব যাতে আপুনি সহজে ধৰিব পাৰে ।',
+ভৱিশ্যতে ইয়াত হোৱা সাল-সলনি আপুনি আপোনাৰ লক্ষ্য তালিকাত দেখিব, লগতে [[Special:RecentChanges|সম্প্রতিক সাল-সলনিৰ তালিকাত]] এই পৃষ্ঠাটো শকট আখৰত দেখিব যাতে আপুনি সহজে ধৰিব পাৰে ।',
 'removedwatch'         => 'লক্ষ্য-তালিকাৰ পৰা আতৰোৱা হল',
 'removedwatchtext'     => '"[[:$1]]" পৃষ্ঠাটো আপোনাৰ লক্ষ্য-তালিকাৰ পৰা আতৰোৱা হৈছে ।',
 'watch'                => 'অনুসৰণাৰ্থে',
@@ -847,7 +984,7 @@
 'show-big-image'       => 'সম্পূর্ণ দৃশ্য',
 'show-big-image-thumb' => '<small>এই খচৰাৰ আকাৰ: $1 × $2 পিক্সেল </small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'নতুন ফাইলৰ বিথীকা',
 
 # Metadata
@@ -867,7 +1004,7 @@
 
 # External editor support
 'edit-externally'      => 'বাহিৰা আহিলা ব্যৱহাৰ কৰি এই ফাইলটো সম্পাদনা কৰক|',
-'edit-externally-help' => 'অধিক জানিবলৈ [http://meta.wikimedia.org/wiki/Help:External_editors নির্দেশনা] চাঁওক ।',
+'edit-externally-help' => 'অধিক জানিবলৈ [http://www.mediawiki.org/wiki/Manual:External_editors নির্দেশনা] চাঁওক ।',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'সকলো',
Index: languages/messages/MessagesMl.php
===================================================================
--- languages/messages/MessagesMl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,19 +4,18 @@
  * @ingroup Language
  * @file
  *
- * @author Shijualex
- * @author Jacob.jose
- * @author Praveenp
- * @author Sadik Khalid
- * @author לערי ריינהארט
- * @author Siebrand
  * @author Anoopan
+ * @author Jacob.jose
  * @author Jyothis
- * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- * @author Sadik Khalid <sadik.khalid@gmail.com>
  * @author Manjith Joseph <manjithkaini@gmail.com>
  * @author Praveen Prakash <me.praveen@gmail.com>
+ * @author Praveenp
+ * @author Sadik Khalid
+ * @author Sadik Khalid <sadik.khalid@gmail.com>
  * @author Shiju Alex <shijualexonline@gmail.com>
+ * @author Shijualex
+ * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -433,7 +432,7 @@
 'red-link-title'          => '$1 (ഇതുവരെ എഴുതപ്പെട്ടിട്ടില്ല)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
-'nstab-main'      => 'താള്‍',
+'nstab-main'      => 'പ്രധാനതാള്‍',
 'nstab-user'      => 'ഉപയോക്തൃതാള്‍',
 'nstab-media'     => 'മീഡിയാ താള്‍',
 'nstab-special'   => 'പ്രത്യേക താള്‍',
@@ -450,7 +449,7 @@
 'nosuchspecialpage' => 'അത്തരമൊരു പ്രത്യേകതാള്‍ നിലവിലില്ല',
 'nospecialpagetext' => "<big>'''താങ്കള്‍ നിലവിലില്ലാത്ത ഒരു പ്രത്യേകതാള്‍ ആണ് ആവശ്യപ്പെട്ടത്.'''</big>
 
-നിലവിലുള്ള പ്രത്യേകതാളുകളുടെ പട്ടിക കാണാന്‍ [[Special:Specialpages|{{int:specialpages}}]] ശ്രദ്ധിക്കുക.",
+നിലവിലുള്ള പ്രത്യേകതാളുകളുടെ പട്ടിക കാണാന്‍ [[Special:SpecialPages|{{int:specialpages}}]] ശ്രദ്ധിക്കുക.",
 
 # General errors
 'error'                => 'കുഴപ്പം',
@@ -660,10 +659,6 @@
 'blockededitsource'         => "'''$1''' എന്ന താളില്‍ '''താങ്കള്‍ നടത്തിയ തിരുത്തലുകളുടെ''' പൂര്‍ണ്ണരൂപം താഴെക്കാണിച്ചിരിക്കുന്നു:",
 'whitelistedittitle'        => 'തിരുത്താന്‍ ലോഗിന്‍ ആവശ്യമാണ്‌',
 'whitelistedittext'         => 'താളുകള്‍ തിരുത്താന്‍ താങ്കള്‍ $1 ചെയ്യേണ്ടതാണ്',
-'whitelistreadtitle'        => 'വായിക്കാന്‍ ലോഗിന്‍ ചെയ്യേണ്ടതാണ്‌',
-'whitelistreadtext'         => 'താളുകള്‍ വായിയ്ക്കാന്‍ താങ്കള്‍ [[Special:Userlogin|ലോഗിന്‍]] ചെയ്യേണ്ടതുണ്ട്.',
-'whitelistacctitle'         => 'താങ്കള്‍ക്ക് അക്കൗണ്ട് സൃഷ്ടിക്കാന്‍ അനുവാദമില്ല',
-'whitelistacctext'          => '{{SITENAME}} സംരംഭത്തില്‍ അക്കൗണ്ട് ഉണ്ടാക്കുന്നതിനുള്ള പ്രത്യേക അനുമതിക്കു താങ്കള്‍ [[Special:Userlogin|ലോഗിന്‍]] ചെയ്യേണ്ടതാകുന്നു.',
 'confirmedittitle'          => 'തിരുത്താന്‍ ഇമെയില്‍ വിലാസം സ്ഥിരീകരിക്കേണ്ടതുണ്ട്',
 'confirmedittext'           => 'താളുകള്‍ തിരുത്തുന്നതിനു മുന്‍പ് താങ്കള്‍ താങ്കളുടെ ഇമെയില്‍ വിലാസം സ്ഥിരീകരിക്കേണ്ടതാണ്‌. ഇമെയില്‍ വിലാസം ക്രമപ്പെടുത്തി സാധുത പരിശോധിക്കാന്‍ [[Special:Preferences|എന്റെ ക്രമീകരണങ്ങള്‍]] എന്ന സം‌വിധാനം ഉപയോഗിക്കുക.',
 'nosuchsectiontitle'        => 'അത്തരം ഉപവിഭാഗം നിലവിലില്ല',
@@ -675,7 +670,7 @@
 'accmailtext'               => '"$1" എന്ന ഉപയോക്താവിനുള്ള രഹസ്യവാക്ക് $2 എന്ന വിലാസത്തിലേക്ക് അയച്ചിട്ടുണ്ട്.',
 'newarticle'                => '(പുതിയത്)',
 'newarticletext'            => 'ഇതുവരെ നിലവിലില്ലാത്ത ഒരു താള്‍ സൃഷ്ടിക്കാനുള്ള ശ്രമത്തിലാണ് താങ്കള്‍. അതിനായി താഴെ ആവശ്യമുള്ള വിവരങ്ങള്‍ എഴുതിച്ചേര്‍ത്ത് സേവ് ചെയ്യുക (കൂടുതല്‍ വിവരങ്ങള്‍ക്ക് [[{{MediaWiki:Helppage}}|സഹായം താള്‍]] കാണുക). താങ്കളിവിടെ അബദ്ധത്തില്‍ വന്നതാണെങ്കില്‍ ബ്രൗസറിന്റെ ബാക്ക് ബട്ടണ്‍ ഞെക്കിയാല്‍ തിരിച്ചുപോകാം.',
-'anontalkpagetext'          => "----''ഇതൊരു അജ്ഞാത ഉപയോക്താവിന്റെ സം‌വാദം താളാണ്, അദ്ദേഹം ഇതുവരെ അംഗത്വം എടുക്കാതിരിക്കുകയോ അഥവാ എടുത്ത അംഗത്വം ഉപയോഗിക്കാതിരിക്കുകയോ ആവാം. നാം അതിനാല്‍ അദ്ദേഹത്തിന്റെ അക്കരൂപത്തിലുള്ള ഐപി വിലാസം താളുകളില്‍ ചേര്‍ത്ത് അദ്ദേഹത്തെ തിരിച്ചറിയാന്‍ ശ്രമിക്കുന്നു. ഒരു ഐപി വിലാസം തന്നെ പല ഉപയോക്താക്കള്‍ ഉപയോഗിക്കുന്നുണ്ടാവാം, അതുകൊണ്ട് താങ്കള്‍ ലോഗിന്‍ ചെയ്യാതിരിക്കുമ്പോള്‍ അനുയോജ്യമല്ലാത്ത ഒരു സന്ദേശം താങ്കള്‍ക്ക് ലഭിക്കാതിരിക്കുവാന്‍ ദയവായി [[Special:Userlogin|അംഗത്വമെടുക്കുകയോ ലോഗിന്‍ ചെയ്യുകയോ]] ചെയ്യുക. ഇത് ഭാവിയില്‍ ഇതര ഉപയോക്താക്കളുമായി ഉണ്ടായേക്കാവുന്ന ആശയക്കുഴപ്പം ഒഴിവാക്കാന്‍ സഹായിക്കും.''",
+'anontalkpagetext'          => "----''ഇതൊരു അജ്ഞാത ഉപയോക്താവിന്റെ സം‌വാദം താളാണ്, അദ്ദേഹം ഇതുവരെ അംഗത്വം എടുക്കാതിരിക്കുകയോ അഥവാ എടുത്ത അംഗത്വം ഉപയോഗിക്കാതിരിക്കുകയോ ആവാം. നാം അതിനാല്‍ അദ്ദേഹത്തിന്റെ അക്കരൂപത്തിലുള്ള ഐപി വിലാസം താളുകളില്‍ ചേര്‍ത്ത് അദ്ദേഹത്തെ തിരിച്ചറിയാന്‍ ശ്രമിക്കുന്നു. ഒരു ഐപി വിലാസം തന്നെ പല ഉപയോക്താക്കള്‍ ഉപയോഗിക്കുന്നുണ്ടാവാം, അതുകൊണ്ട് താങ്കള്‍ ലോഗിന്‍ ചെയ്യാതിരിക്കുമ്പോള്‍ അനുയോജ്യമല്ലാത്ത ഒരു സന്ദേശം താങ്കള്‍ക്ക് ലഭിക്കാതിരിക്കുവാന്‍ ദയവായി [[Special:UserLogin|അംഗത്വമെടുക്കുകയോ ലോഗിന്‍ ചെയ്യുകയോ]] ചെയ്യുക. ഇത് ഭാവിയില്‍ ഇതര ഉപയോക്താക്കളുമായി ഉണ്ടായേക്കാവുന്ന ആശയക്കുഴപ്പം ഒഴിവാക്കാന്‍ സഹായിക്കും.''",
 'noarticletext'             => 'ഈ താളില്‍ ഇതുവരെ ഉള്ളടക്കം ആയിട്ടില്ല, താങ്കള്‍ക്ക് മറ്റുതാളുകളില്‍ [[Special:Search/{{PAGENAME}}|ഇതേക്കുറിച്ച് അന്വേഷിക്കാവുന്നതാണ്]] അല്ലെങ്കില്‍ [{{fullurl:{{FULLPAGENAME}}|action=edit}} ഈ താള്‍ തിരുത്താവുന്നതാണ്].',
 'userpage-userdoesnotexist' => '"$1" എന്ന ഉപയോക്താവ് അംഗത്വമെടുത്തിട്ടില്ല. ഈ താള്‍ സൃഷ്ടിക്കണമോ എന്നതു പരിശോധിക്കുക.',
 'clearyourcache'            => "'''പ്രത്യേക ശ്രദ്ധയ്ക്ക്:'''
@@ -736,7 +731,7 @@
 'hiddencategories'          => 'ഈ താള്‍ അംഗമായ {{PLURAL:$1|മറഞ്ഞിരിക്കുന്ന വിഭാഗം|മറഞ്ഞിരിക്കുന്ന വിഭാഗങ്ങള്‍}}:',
 'nocreatetitle'             => 'താളുകള്‍ സൃഷ്ടിക്കുന്നത് പരിമിതപ്പെടുത്തിയിരിക്കുന്നു',
 'nocreatetext'              => '{{SITENAME}} സംരംഭത്തില്‍ പുതിയ താളുകള്‍ സൃഷ്ടിക്കുവാനുള്ള അവകാശം നിയന്ത്രിതമാണ്‌.
-താങ്കള്‍ ദയവായി തിരിച്ചുചെന്ന് നിലവിലുള്ള ഒരു താള്‍ തിരുത്തുകയോ, അഥവാ [[Special:Userlogin|ലോഗിന്‍ ചെയ്യുകയോ ഒരു അക്കൗണ്ട് സൃഷ്ടിക്കുകയോ]] ചെയ്യാന്‍ അഭ്യര്‍ത്ഥിക്കുന്നു.',
+താങ്കള്‍ ദയവായി തിരിച്ചുചെന്ന് നിലവിലുള്ള ഒരു താള്‍ തിരുത്തുകയോ, അഥവാ [[Special:UserLogin|ലോഗിന്‍ ചെയ്യുകയോ ഒരു അക്കൗണ്ട് സൃഷ്ടിക്കുകയോ]] ചെയ്യാന്‍ അഭ്യര്‍ത്ഥിക്കുന്നു.',
 'nocreate-loggedin'         => 'താങ്കള്‍ക്ക് {{SITENAME}} സംരംഭത്തില്‍ പുതിയ താളുകള്‍ സൃഷ്ടിക്കാന്‍ അനുവാദമില്ല.',
 'permissionserrors'         => 'അനുമതിപ്രശ്നം',
 'permissionserrorstext'     => 'താഴെ കൊടുത്തിരിക്കുന്ന {{PLURAL:$1|കാരണം|കാരണങ്ങള്‍}} കൊണ്ട് താങ്കള്‍ക്ക് ഈ പ്രവൃത്തി ചെയ്യാനുള്ള അനുമതിയില്ല:',
@@ -894,7 +889,7 @@
 'mypreferences'         => 'എന്റെ ക്രമീകരണങ്ങള്‍',
 'prefs-edits'           => 'ആകെ തിരുത്തലുകള്‍:',
 'prefsnologin'          => 'ലോഗിന്‍ ചെയ്തിട്ടില്ല',
-'prefsnologintext'      => 'ഉപയോക്തൃക്രമീകരണങ്ങള്‍ മാറ്റാന്‍ താങ്കള്‍ [[Special:Userlogin|ലോഗിന്‍ ചെയ്തിരിക്കണം]].',
+'prefsnologintext'      => 'ഉപയോക്തൃക്രമീകരണങ്ങള്‍ മാറ്റാന്‍ താങ്കള്‍ [[Special:UserLogin|ലോഗിന്‍ ചെയ്തിരിക്കണം]].',
 'qbsettings-none'       => 'ഒന്നുമില്ല',
 'qbsettings-fixedleft'  => 'സ്ഥിരമായ ഇടത്',
 'qbsettings-fixedright' => 'സ്ഥിരമായ വലത്',
@@ -953,7 +948,7 @@
 'userrights-reason'        => 'മാറ്റത്തിനുള്ള കാരണം:',
 'userrights-no-interwiki'  => 'മറ്റ് വിക്കികളിലെ ഉപയോക്തൃ അവകാശങ്ങള്‍ തിരുത്തുവാന്‍ നിങ്ങള്‍ക്കു അനുമതിയില്ല.',
 'userrights-nodatabase'    => '$1 എന്ന ഡാറ്റാബേസ് നിലവിലില്ല അല്ലെങ്കില്‍ പ്രാദേശികമല്ല.',
-'userrights-nologin'       => 'ഉപയോക്താക്കള്‍ക്ക് അവകാശങ്ങള്‍ കൊടുക്കണമെങ്കില്‍ നിങ്ങള്‍ കാര്യനിര്‍‌വാഹക അക്കൗണ്ട് ഉപയോഗിച്ച് [[Special:Userlogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം.',
+'userrights-nologin'       => 'ഉപയോക്താക്കള്‍ക്ക് അവകാശങ്ങള്‍ കൊടുക്കണമെങ്കില്‍ നിങ്ങള്‍ കാര്യനിര്‍‌വാഹക അക്കൗണ്ട് ഉപയോഗിച്ച് [[Special:UserLogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം.',
 'userrights-notallowed'    => 'ഉപയോക്താക്കള്‍ക്ക് അവകാശങ്ങള്‍ കൊടുക്കാനുള്ള അനുമതി നിങ്ങളുടെ അക്കൗണ്ടിനില്ല.',
 
 # Groups
@@ -1020,11 +1015,11 @@
 'reupload'                    => 'ഒന്നുകൂടി അപ്‌ലോഡ് ചെയ്യുക',
 'reuploaddesc'                => 'വീണ്ടും അപ്‌ലോഡ് ചെയ്ത് നോക്കാനായി തിരിച്ചു പോവുക.',
 'uploadnologin'               => 'ലോഗിന്‍ ചെയ്തിട്ടില്ല',
-'uploadnologintext'           => 'പ്രമാണങ്ങള്‍ അപ്‌ലോഡ് ചെയ്യാന്‍ താങ്കള്‍ [[Special:Userlogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം',
+'uploadnologintext'           => 'പ്രമാണങ്ങള്‍ അപ്‌ലോഡ് ചെയ്യാന്‍ താങ്കള്‍ [[Special:UserLogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം',
 'upload_directory_read_only'  => 'വെബ്ബ് സെര്‍‌വറിനു അപ്‌ലോഡ് ഡയറക്ടറിയിലേക്ക് ($1) എഴുതാന്‍ കഴിഞ്ഞില്ല.',
 'uploaderror'                 => 'അപ്‌ലോഡ് പിശക്',
 'uploadtext'                  => "താഴെ കാണുന്ന ഫോം പ്രമാണം അപ്‌ലോഡ് ചെയ്യുവാന്‍ വേണ്ടി ഉപയോഗിക്കുക.
-നിലവില്‍ അപ്‌ലോഡ് ചെയ്തിരിക്കുന്ന പ്രമാണങ്ങള്‍ കാണുവാന്‍ [[Special:Imagelist|അപ്‌ലോഡ് ചെയ്ത പ്രമാണങ്ങളുടെ പട്ടിക]] സന്ദര്‍ശിക്കുക. [[Special:Log/upload|അപ്‌ലോഡ് ലോഗിലും]] അപ്‌ലോഡിന്റേയും മായ്ക്കലിന്റേയും വിവരങ്ങള്‍ കാണാവുന്നതാണ്‌.
+നിലവില്‍ അപ്‌ലോഡ് ചെയ്തിരിക്കുന്ന പ്രമാണങ്ങള്‍ കാണുവാന്‍ [[Special:ImageList|അപ്‌ലോഡ് ചെയ്ത പ്രമാണങ്ങളുടെ പട്ടിക]] സന്ദര്‍ശിക്കുക. [[Special:Log/upload|അപ്‌ലോഡ് ലോഗിലും]] അപ്‌ലോഡിന്റേയും മായ്ക്കലിന്റേയും വിവരങ്ങള്‍ കാണാവുന്നതാണ്‌.
 
 പ്രമാണം താളില്‍ പ്രദര്‍ശിപ്പിക്കുവാന്‍ താഴെ കാണുന്ന ഒരു വഴി സ്വീകരിക്കുക
 
@@ -1108,7 +1103,7 @@
 'upload_source_url'  => '(സാധുവായ, ആര്‍ക്കും ഉപയോഗിക്കാവുന്ന URL)',
 'upload_source_file' => '(താങ്കളുടെ കമ്പ്യൂട്ടറിലുള്ള ഒരു പ്രമാണം)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'ചുരുക്കം',
 'imagelist_search_for'  => 'മീഡിയ പ്രമാണം തിരയുക:',
 'imgfile'               => 'പ്രമാണം',
@@ -1146,18 +1141,18 @@
 # File reversion
 'filerevert'                => '$1 തിരസ്ക്കരിക്കുക',
 'filerevert-legend'         => 'പ്രമാണം തിരസ്ക്കരിക്കുക',
-'filerevert-intro'          => '<span class="plainlinks">താങ്കള്‍ \'\'\'[[Media:$1|$1]]\'\'\' യെ, [$3, $2 ഉണ്ടായിരുന്ന $4 പതിപ്പിലേക്കു സേവ് ചെയ്യുകയാണ്‌].</span>',
+'filerevert-intro'          => "താങ്കള്‍ '''[[Media:$1|$1]]''' യെ, [$3, $2 ഉണ്ടായിരുന്ന $4 പതിപ്പിലേക്കു സേവ് ചെയ്യുകയാണ്‌].",
 'filerevert-comment'        => 'കുറിപ്പ്:',
 'filerevert-defaultcomment' => '$2 ല്‍ ഉണ്ടായിരുന്ന $1 പതിപ്പിലേക്കു സേവ് ചെയ്തിരിക്കുന്നു',
 'filerevert-submit'         => 'പൂര്‍വ്വസ്ഥിതിയിലാക്കുക',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' യെ,  [$3, $2 ഉണ്ടായിരുന്ന $4] പതിപ്പിലേക്കു സേവ് ചെയ്തിരിക്കുന്നു.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' യെ,  [$3, $2 ഉണ്ടായിരുന്ന $4] പതിപ്പിലേക്കു സേവ് ചെയ്തിരിക്കുന്നു.",
 'filerevert-badversion'     => 'താങ്കള്‍ തന്ന സമയവുമായി യോജിക്കുന്ന മുന്‍ പതിപ്പുകള്‍ ഒന്നും തന്നെ ഈ പ്രമാണത്തിനില്ല.',
 
 # File deletion
 'filedelete'                  => '$1 മായ്ക്കുക',
 'filedelete-legend'           => 'പ്രമാണം മായ്ക്കുക',
 'filedelete-intro'            => "താങ്കള്‍ '''[[Media:$1|$1]]''' നീക്കം ചെയ്യുകയാണ്.",
-'filedelete-intro-old'        => '<span class="plainlinks">നിങ്ങള്‍ \'\'\'[[Media:$1|$1]]\'\'\' യയുടെ [$3, $2 ഉണ്ടായിരുന്ന $4] പതിപ്പാണു മായ്ക്കുവാന്‍ പോകുന്നത്.</span>',
+'filedelete-intro-old'        => "നിങ്ങള്‍ '''[[Media:$1|$1]]''' യയുടെ [$3, $2 ഉണ്ടായിരുന്ന $4] പതിപ്പാണു മായ്ക്കുവാന്‍ പോകുന്നത്.",
 'filedelete-comment'          => 'നീക്കം ചെയ്യാനുള്ള കാരണം:',
 'filedelete-submit'           => 'മായ്ക്കുക',
 'filedelete-success'          => "'''$1''' മായ്ച്ചു കഴിഞ്ഞു.",
@@ -1208,7 +1203,7 @@
 {{SITENAME}} സം‌രംഭം സ്ഥാപിക്കപ്പെട്ടതില്‍ പിന്നെ '''$3''' {{PLURAL:$3|page view|page views}} ഉണ്ടായിട്ടുണ്ട്. മാത്രമല്ല '''$4''' {{PLURAL:$4|തിരുത്തല്‍|തിരുത്തലുകള്‍}} നടന്നിട്ടുണ്ട്. ഇതു പ്രകാരം ശരാശരി ഒരു താള്‍ '''$5''' പ്രാവശ്യം തിരുത്തപ്പെടുകയും, ഓരോ എഡിറ്റിനും '''$6''' പ്രാവശ്യം കാണുകയും ചെയ്തിട്ടുണ്ട്.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue ജോബ് ക്യൂവിന്റെ] നീളം '''$7''' ആണ്‌.",
-'userstatstext'          => "{{SITENAME}} സം‌രംഭത്തില്‍ {{PLURAL:$1|'''1''' രജിസ്റ്റേര്‍ഡ് [[Special:Listusers|ഉപയോക്താവ്]]| '''$1''' രെജിസ്റ്റേര്‍ഡ് [[Special:Listusers|ഉപയോക്താക്കള്‍ ഉണ്ട്.]]}}. അതില്‍ '''$2'''  (or '''$4%''') {{PLURAL:$2|ഉപയോക്താവിനു|ഉപയോക്താക്കള്‍ക്ക്}} $5 അവകാശം ഉണ്ട്.",
+'userstatstext'          => "{{SITENAME}} സം‌രംഭത്തില്‍ {{PLURAL:$1|'''1''' രജിസ്റ്റേര്‍ഡ് [[Special:ListUsers|ഉപയോക്താവ്]]| '''$1''' രെജിസ്റ്റേര്‍ഡ് [[Special:ListUsers|ഉപയോക്താക്കള്‍ ഉണ്ട്.]]}}. അതില്‍ '''$2'''  (or '''$4%''') {{PLURAL:$2|ഉപയോക്താവിനു|ഉപയോക്താക്കള്‍ക്ക്}} $5 അവകാശം ഉണ്ട്.",
 'statistics-mostpopular' => 'ഏറ്റവുമധികം സന്ദര്‍ശിക്കപ്പെട്ട താളുകള്‍',
 
 'disambiguations'      => 'നാനാര്‍ത്ഥ താളുകള്‍',
@@ -1294,7 +1289,7 @@
 'logempty'             => 'താളുമായി ബന്ധപ്പെട്ട രേഖകള്‍ ഒന്നും തന്നെയില്ല.',
 'log-title-wildcard'   => 'ഈ വാക്കില്‍ തുടങ്ങുന്ന തിരച്ചില്‍ ഫലങ്ങള്‍',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'എല്ലാ താളുകളും',
 'alphaindexline'    => '$1 മുതല്‍ $2 വരെ',
 'nextpage'          => 'അടുത്ത താള്‍ ($1)',
@@ -1314,18 +1309,18 @@
 'categoriespagetext'          => 'താഴെ കൊടുത്തിരിക്കുന്ന വിഭാഗങ്ങളില്‍ താളുകളോ പ്രമാണങ്ങളോ ഉണ്ട്.',
 'special-categories-sort-abc' => 'അക്ഷരമാലാക്രമത്തില്‍ ക്രമീകരിക്കുക',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'ഇതില്‍ തുടങ്ങുന്ന ഉപയോക്താക്കളെ പ്രദര്‍ശിപ്പിക്കുക:',
 'listusers-submit'   => 'പ്രദര്‍ശിപ്പിക്കുക',
 'listusers-noresult' => 'ഈ ഗ്രൂപ്പില്‍ ഉള്‍പ്പെടുന്ന ഉപയോക്താക്കള്‍ ആരും ഇല്ല.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'       => 'ഉപയോക്തൃവിഭാഗത്തിന്റെ അവകാശങ്ങള്‍',
 'listgrouprights-group' => 'ഗ്രൂപ്പ്',
 
 # E-mail user
 'mailnologin'     => 'അയയ്ക്കാനുള്ള വിലാസം ലഭ്യമല്ല',
-'mailnologintext' => 'മറ്റ് ഉപയോക്താക്കള്‍ക്കു ഇമെയിലയക്കുവാന്‍ താങ്കള്‍ [[Special:Userlogin|ലോഗിന്‍]] ചെയ്തിരിക്കുകയും, സാധുവായ ഒരു ഇമെയില്‍ വിലാസം താങ്കളുടെ [[Special:Preferences|ക്രമീകരണങ്ങള്‍]] താളില്‍ സജ്ജീകരിച്ചിരിക്കുകയും വേണം.',
+'mailnologintext' => 'മറ്റ് ഉപയോക്താക്കള്‍ക്കു ഇമെയിലയക്കുവാന്‍ താങ്കള്‍ [[Special:UserLogin|ലോഗിന്‍]] ചെയ്തിരിക്കുകയും, സാധുവായ ഒരു ഇമെയില്‍ വിലാസം താങ്കളുടെ [[Special:Preferences|ക്രമീകരണങ്ങള്‍]] താളില്‍ സജ്ജീകരിച്ചിരിക്കുകയും വേണം.',
 'emailuser'       => 'ഈ ഉപയോക്താവിനു ഇമെയില്‍ അയക്കൂ',
 'emailpage'       => 'ഉപയോക്താവിന് ഇമെയില്‍ അയക്കുക',
 'emailpagetext'   => 'ഒരു ഉപയോക്താവ് തന്റെ ക്രമീകരണങ്ങളില്‍ സ്വന്തം ഇമെയില്‍ വിലാസത്തിന്റെ സാധുത തെളിയിച്ചിട്ടുണ്ടെങ്കില്‍, താഴെയുള്ള ഫോം ഇമെയില്‍ അയക്കാന്‍ ഉപയോഗിക്കാം. താങ്കളുടെ ക്രമീകരണങ്ങളില്‍ താങ്കള്‍ ചേര്‍ത്തിട്ടുള്ള ഇമെയില്‍ വിലാസം, അയക്കുന്ന ആളുടെ വിലാസമായി സ്വീകര്‍ത്താവിന് ലഭിക്കുന്നതായിരിക്കും. അതുകൊണ്ട് സ്വീകര്‍ത്താവിന് താങ്കള്‍ക്ക് മറുപടി അയക്കാന്‍ സാധിക്കും.',
@@ -1349,9 +1344,9 @@
 'nowatchlist'          => 'താങ്കള്‍ ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയില്‍ ഇനങ്ങളൊന്നുമില്ല.',
 'watchlistanontext'    => 'നിങ്ങളുടെ ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടിക കാണുവാനോ തിരുത്തുവാനോ $1 ചെയ്യുക.',
 'watchnologin'         => 'ലോഗിന്‍ ചെയ്തിട്ടില്ല',
-'watchnologintext'     => 'ശ്രദ്ധിക്കുന്ന താളിന്റെ പട്ടിക തിരുത്തുവാന്‍ നിങ്ങള്‍ [[Special:Userlogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം.',
+'watchnologintext'     => 'ശ്രദ്ധിക്കുന്ന താളിന്റെ പട്ടിക തിരുത്തുവാന്‍ നിങ്ങള്‍ [[Special:UserLogin|ലോഗിന്‍]] ചെയ്തിരിക്കണം.',
 'addedwatch'           => 'ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയിലേക്കു ചേര്‍ത്തിരിക്കുന്നു',
-'addedwatchtext'       => "\"[[:\$1]]\" എന്ന ഈ താള്‍ താങ്കള്‍ [[Special:Watchlist|ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയിലേക്കു]] ചേര്‍ത്തിരിക്കുന്നു. ഇനിമുതല്‍ ഈ താളിലും ബന്ധപ്പെട്ട സം‌വാദംതാളിലും ഉണ്ടാകുന്ന മാറ്റങ്ങള്‍ ഈ പട്ടികയില്‍ ദൃശ്യമാവും. കൂടാതെ [[Special:Recentchanges|പുതിയ മാറ്റങ്ങള്‍]] താളില്‍ ഈ താളുകളിലെ മാറ്റങ്ങള്‍ താങ്കള്‍ക്ക് എളുപ്പത്തില്‍ തിരിച്ചറിയാന്‍ '''കടുപ്പത്തില്‍''' കാണിക്കുകയും ചെയ്യും.
+'addedwatchtext'       => "\"[[:\$1]]\" എന്ന ഈ താള്‍ താങ്കള്‍ [[Special:Watchlist|ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയിലേക്കു]] ചേര്‍ത്തിരിക്കുന്നു. ഇനിമുതല്‍ ഈ താളിലും ബന്ധപ്പെട്ട സം‌വാദംതാളിലും ഉണ്ടാകുന്ന മാറ്റങ്ങള്‍ ഈ പട്ടികയില്‍ ദൃശ്യമാവും. കൂടാതെ [[Special:RecentChanges|പുതിയ മാറ്റങ്ങള്‍]] താളില്‍ ഈ താളുകളിലെ മാറ്റങ്ങള്‍ താങ്കള്‍ക്ക് എളുപ്പത്തില്‍ തിരിച്ചറിയാന്‍ '''കടുപ്പത്തില്‍''' കാണിക്കുകയും ചെയ്യും.
 
 ഇനി എപ്പോഴെങ്കിലും പ്രസ്തുത താള്‍ ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയില്‍ നിന്നു നീക്കം ചെയ്യണമെങ്കില്‍, താളിന്റെ മുകളിലെ വരിയില്‍ കാണുന്ന \"മാറ്റങ്ങള്‍ അവഗണിക്കുക\" എന്ന ടാബില്‍ ഞെക്കിയാല്‍ മതിയാകും.",
 'removedwatch'         => 'ശ്രദ്ധിക്കുന്ന താളുകളുടെ പട്ടികയില്‍ നിന്നും നീക്കിയിരിക്കുന്നു',
@@ -1578,7 +1573,7 @@
 'badipaddress'                => 'അസാധുവായ ഐപി വിലാസം.',
 'blockipsuccesssub'           => 'തടയല്‍ വിജയിച്ചിരിക്കുന്നു',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]നെ തടഞ്ഞിരിക്കുന്നു.<br />
-തടയല്‍ പുനഃപരിശോധിക്കാന്‍ [[Special:Ipblocklist|IP block list]] കാണുക.',
+തടയല്‍ പുനഃപരിശോധിക്കാന്‍ [[Special:IPBlockList|IP block list]] കാണുക.',
 'ipb-edit-dropdown'           => 'തടഞ്ഞതിന്റെ കാരണം തിരുത്തുക',
 'ipb-unblock-addr'            => '$1 അംഗത്വത്തെ അണ്‍‌ബ്ലോക്ക് ചെയ്യുക',
 'ipb-unblock'                 => 'ഒരു ഐപി വിലാസത്തേയോ ഉപയോക്താവിനേയോ അണ്‍‌ബ്ലോക്ക് ചെയ്യുക',
@@ -1607,7 +1602,7 @@
 'autoblocker'                 => 'താങ്കളുടെ ഐപി വിലാസം "[[User:$1|$1]]" എന്ന ഉപയോക്താവ് ഈ അടുത്ത് ഉപയോഗിക്കുകയും പ്രസ്തുത ഉപയോക്താവിനെ വിക്കിയില്‍ നിന്നു തടയുകയും ചെയ്തിട്ടുള്ളതാണ്‌. അതിനാല്‍ താങ്കളും യാന്ത്രികമായി തടയപ്പെട്ടിരിക്കുന്നു. $1ന്റെ തടയലിനു സൂചിപ്പിക്കപ്പെട്ട കാരണം "$2" ആണ്‌.',
 'blocklogpage'                => 'തടയല്‍ പട്ടിക',
 'blocklogentry'               => '[[$1]]-നെ $2 കാലത്തേക്കു വിലക്കിയിരിക്കുന്നു $3',
-'blocklogtext'                => '{{SITENAME}} സംരംഭത്തില്‍ പ്രവര്‍ത്തിക്കുന്നതില്‍ നിന്ന് ഉപയോക്താക്കെളെ തടഞ്ഞതിന്റേയും, പുന:പ്രവര്‍ത്തനാനുമതി നല്‍കിയതിന്റേയും രേഖകള്‍ താഴെ കാണാം. {{SITENAME}} സംരംഭം സ്വയം  തടയുന്ന ഐപി വിലാസങ്ങള്‍ ഈ പട്ടികയില്‍ ഇല്ല. [[Special:Ipblocklist|തടയപ്പെട്ടിട്ടുള്ള ഐപി വിലാസങ്ങളുടെ പട്ടിക]] എന്നതാളില്‍ നിലവിലുള്ള നിരോധനങ്ങളേയും തടയലുകളേയും കാണാവുന്നതാണ്.',
+'blocklogtext'                => '{{SITENAME}} സംരംഭത്തില്‍ പ്രവര്‍ത്തിക്കുന്നതില്‍ നിന്ന് ഉപയോക്താക്കെളെ തടഞ്ഞതിന്റേയും, പുന:പ്രവര്‍ത്തനാനുമതി നല്‍കിയതിന്റേയും രേഖകള്‍ താഴെ കാണാം. {{SITENAME}} സംരംഭം സ്വയം  തടയുന്ന ഐപി വിലാസങ്ങള്‍ ഈ പട്ടികയില്‍ ഇല്ല. [[Special:IPBlockList|തടയപ്പെട്ടിട്ടുള്ള ഐപി വിലാസങ്ങളുടെ പട്ടിക]] എന്നതാളില്‍ നിലവിലുള്ള നിരോധനങ്ങളേയും തടയലുകളേയും കാണാവുന്നതാണ്.',
 'unblocklogentry'             => '$1 എന്ന ഉപയോക്താവിനെ പുനഃസ്ഥാപിച്ചിരിക്കുന്നു',
 'block-log-flags-anononly'    => 'അജ്ഞാത ഉപയോക്താക്കളെ മാത്രം',
 'block-log-flags-nocreate'    => 'അക്കൗണ്ട് സൃഷ്ടിക്കുന്നതും തടഞ്ഞിരിക്കുന്നു',
@@ -1638,7 +1633,7 @@
 'lockdbsuccesssub'    => 'ഡാറ്റാബേസ് ബന്ധിക്കുവാന്‍ സാധിച്ചില്ല',
 'unlockdbsuccesssub'  => 'ഡാറ്റാബേസ് സ്വതന്ത്രമാക്കിയിരിക്കുന്നു',
 'lockdbsuccesstext'   => 'ഡാറ്റാബേസ് ബന്ധിച്ചിരിക്കുന്നു.<br />
-ശുദ്ധീകരണപ്രവര്‍ത്തനം കഴിഞ്ഞതിനു ശേഷം [[Special:Unlockdb|ഈ കണ്ണിയുപയോഗിച്ച്]] ഡാറ്റാബേസ് സ്വതന്ത്രമാക്കുക.',
+ശുദ്ധീകരണപ്രവര്‍ത്തനം കഴിഞ്ഞതിനു ശേഷം [[Special:UnlockDB|ഈ കണ്ണിയുപയോഗിച്ച്]] ഡാറ്റാബേസ് സ്വതന്ത്രമാക്കുക.',
 'unlockdbsuccesstext' => 'ഡാറ്റാബേസ് സ്വതന്ത്രമാക്കിയിരിക്കുന്നു.',
 'databasenotlocked'   => 'ഡാറ്റാബേസ് ബന്ധിച്ചിട്ടില്ല.',
 
@@ -1665,8 +1660,6 @@
 
 അത്തരം സന്ദര്‍ഭങ്ങളില്‍ സം‌വാദം താളുകള്‍ താങ്കള്‍ സ്വയം കൂട്ടിച്ചേര്‍ക്കേണ്ടതാണ്.",
 'movearticle'             => 'മാറ്റേണ്ട താള്‍',
-'movenologin'             => 'ലോഗിന്‍ ചെയ്തിട്ടില്ല',
-'movenologintext'         => 'തലക്കെട്ടു മാറ്റാനുള്ള അനുമതി കൈവരിക്കാന്‍ താങ്കള്‍ ഒരു രജിസ്റ്റേര്‍ഡ് ഉപയോക്താവായിരിക്കുകയും [[Special:Userlogin|ലോഗിന്‍ ചെയ്തിരിക്കുകയും]] ചെയ്യേണ്ടത് അത്യന്താപേക്ഷിതമാണ്‌.',
 'movenotallowed'          => '{{SITENAME}} സം‌രംഭത്തിലെ താളുകളുടെ തലക്കെട്ടു മാറ്റാന്‍ താങ്കള്‍ക്ക് അനുവാദമില്ല.',
 'newtitle'                => 'പുതിയ തലക്കെട്ട്',
 'move-watch'              => 'ഈ താളിലെ മാറ്റങ്ങള്‍ ശ്രദ്ധിക്കുക',
@@ -1686,7 +1679,7 @@
 'delete_and_move'         => 'മായ്ക്കുകയും മാറ്റുകയും ചെയ്യുക',
 'delete_and_move_text'    => '==താള്‍ മായ്ക്കേണ്ടിയിരിക്കുന്നു==
 
-താങ്കള്‍ സൃഷ്ടിക്കാന്‍ ശ്രമിച്ച "[[$1]]" എന്ന താള്‍ നിലവിലുണ്ട്. ആ താള്‍ മായ്ച്ച് പുതിയ തലക്കെട്ട് നല്‍കേണ്ടതുണ്ടോ?',
+താങ്കള്‍ സൃഷ്ടിക്കാന്‍ ശ്രമിച്ച "[[:$1]]" എന്ന താള്‍ നിലവിലുണ്ട്. ആ താള്‍ മായ്ച്ച് പുതിയ തലക്കെട്ട് നല്‍കേണ്ടതുണ്ടോ?',
 'delete_and_move_confirm' => 'ശരി, താള്‍ നീക്കം ചെയ്യുക',
 'delete_and_move_reason'  => 'താള്‍ മാറ്റാനായി മായ്ച്ചു',
 'selfmove'                => 'സ്രോതസ്സിന്റെ തലക്കെട്ടും ലക്ഷ്യത്തിന്റെ തലക്കെട്ടും ഒന്നാണ്‌. അതിനാല്‍ തലക്കെട്ടുമാറ്റം സാദ്ധ്യമല്ല.',
@@ -1874,7 +1867,7 @@
 'show-big-image'       => 'പൂര്‍ണ്ണ റെസലൂഷന്‍',
 'show-big-image-thumb' => '<small>ഈ പ്രിവ്യൂവിന്റെ വലുപ്പം: $1 × $2 പിക്സലുകള്‍</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'പുതിയ പ്രമാണങ്ങളുടെ ഗാലറി',
 'imagelisttext'         => "$2 പ്രകാരം സോര്‍ട്ട് ചെയ്ത '''$1''' {{PLURAL:$1|പ്രമാണത്തിന്റെ|പ്രമാണങ്ങളുടെ}} പട്ടിക താഴെ കാണാം.",
 'newimages-summary'     => 'ചുരുക്കം',
@@ -2069,7 +2062,7 @@
 
 # External editor support
 'edit-externally'      => 'ഈ പ്രമാണം ഒരു ബാഹ്യ ആപ്ലിക്കേഷന്‍ ഉപയോഗിച്ച് തിരുത്തുക',
-'edit-externally-help' => 'കൂടുതല്‍ വിവരത്തിനു [http://meta.wikimedia.org/wiki/Help:External_editors തിരുത്തല്‍ മാര്‍ഗ്ഗ നിര്‍ദ്ദേശം] കാണുക',
+'edit-externally-help' => 'കൂടുതല്‍ വിവരത്തിനു [http://www.mediawiki.org/wiki/Manual:External_editors തിരുത്തല്‍ മാര്‍ഗ്ഗ നിര്‍ദ്ദേശം] കാണുക',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'എല്ലാം',
@@ -2124,7 +2117,7 @@
 'recreate'            => 'പുനഃസൃഷ്ടിക്കുക',
 
 # HTML dump
-'redirectingto' => '[[$1]] എന്ന താളിലേയ്ക്കു തിരിച്ചുവിടുന്നു...',
+'redirectingto' => '[[:$1]] എന്ന താളിലേയ്ക്കു തിരിച്ചുവിടുന്നു...',
 
 # action=purge
 'confirm_purge'        => 'ഈ താളിന്റെ കാഷെ ക്ലീയര്‍ ചെയ്യട്ടെ?
@@ -2205,7 +2198,7 @@
 'version-software-product' => 'സോഫ്റ്റ്‌വെയര്‍ പ്രൊഡക്ട്',
 'version-software-version' => 'വിവരണം',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'പ്രമാണത്തിലേക്കുള്ള വിലാസം',
 'filepath-page'    => 'പ്രമാണം:',
 'filepath-submit'  => 'പാത',
Index: languages/messages/MessagesFiu_vro.php
===================================================================
--- languages/messages/MessagesFiu_vro.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFiu_vro.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Võrok
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  * @author Niklas Laxsröm
  * @author Sulev Iva (Võrok)
+ * @author Võrok
  */
 
 $fallback = 'et';
@@ -529,10 +526,6 @@
 'blockededitsource'         => "Su tett toimõndus lehe '''$1''' pääl:",
 'whitelistedittitle'        => 'Toimõndamisõs piät nimega sisse minemä',
 'whitelistedittext'         => 'Lehekülgi toimõndamisõs $1.',
-'whitelistreadtitle'        => 'Lugõmisõs piät olõma nimega sisse lännüq',
-'whitelistreadtext'         => 'Lehekülgi lugõmisõs piät [[Special:Userlogin|nimega sisse minemä]].',
-'whitelistacctitle'         => 'Sul olõ-i õigust pruukjakontot luvvaq',
-'whitelistacctext'          => '{{SITENAME}} kontodõ luumisõs piät olõma [[Special:Userlogin|nimega sisse lännüq]] ja sul piät olõma tuu jaos nõvvõtavaq õigusõq.',
 'confirmedittitle'          => 'E-posti kinnütüs',
 'confirmedittext'           => 'Sa saa-i inne lehekülgi toimõndaq, ku olõt kinnütänüq ärq uma e-postiaadrõsi. Tuud saat tetäq uma [[Special:Preferences|säädmislehe]] pääl.',
 'nosuchsectiontitle'        => 'Olõ-i säänest lõiku',
@@ -546,7 +539,7 @@
 'newarticletext'            => "Taad lehekülge olõ-i viil.
 Leheküle luumisõs nakkaq kirotama alanolõvahe kasti.
 Ku sa johtuq siiäq kogõmaldaq, sis klõpsaq võrgokaeja '''Tagasi'''-nuppi.",
-'anontalkpagetext'          => "---- ''Taa om arotusleht nimeldä pruukja kotsilõ, kiä olõ-i loonuq kontot vai pruugi-i tuud. Tuuperäst tulõ meil pruukja kimmästegemises pruukiq timä puutri võrgoaadrõssit. Taa aadrõs või ollaq mitmõ pruukja pääle ütine. Ku olõt nimeldä pruukja ja lövvät, et taa leheküle pääle kirotõt jutt käü suq kotsilõ, sis olõq hää, [[Special:Userlogin|luuq konto vai mineq nimega sisse]], et edespiten segähüisi ärq hoitaq.''",
+'anontalkpagetext'          => "---- ''Taa om arotusleht nimeldä pruukja kotsilõ, kiä olõ-i loonuq kontot vai pruugi-i tuud. Tuuperäst tulõ meil pruukja kimmästegemises pruukiq timä puutri võrgoaadrõssit. Taa aadrõs või ollaq mitmõ pruukja pääle ütine. Ku olõt nimeldä pruukja ja lövvät, et taa leheküle pääle kirotõt jutt käü suq kotsilõ, sis olõq hää, [[Special:UserLogin|luuq konto vai mineq nimega sisse]], et edespiten segähüisi ärq hoitaq.''",
 'noarticletext'             => 'Seo leht om parlaq tühi. Võit [[Special:Search/{{PAGENAME}}|otsiq seo lehe nimme]] tõisi lehti päält vai [{{fullurl:{{FULLPAGENAME}}|action=edit}} naataq seod lehte esiq kirotama].',
 'userpage-userdoesnotexist' => 'Pruukjanimme "$1" olõ-i kirjä pant. Kaeq perrä, kas olõt iks kimmäs, et tahat taad lehte toimõndaq.',
 'clearyourcache'            => "'''Panõq tähele:''' perän pästmist piät muutmiisi nägemises uma võrgokaeja vaihõmälo tühäs tegemä: '''Mozilla:''' vaodaq ''reload''  vai ''ctrl-r'', '''IE / Opera:''' ''ctrl-f5'', '''Safari:''' ''cmd-r'', '''Konqueror''' ''ctrl-r''.",
@@ -594,7 +587,7 @@
 'template-semiprotected'    => '(ärqkaidsõduq nimeldä ja vahtsõq pruukjaq)',
 'nocreatetitle'             => 'Lehekülgi luuminõ piiret',
 'nocreatetext'              => '{{SITENAME}} lupa-i luvvaq vahtsit lehti.
-Võit toimõndaq olõmanolõvit lehti vai [[Special:Userlogin|minnäq nimega sisse]].',
+Võit toimõndaq olõmanolõvit lehti vai [[Special:UserLogin|minnäq nimega sisse]].',
 'nocreate-loggedin'         => 'Sul olõ-i lupa seon vikin vahtsit lehti luvvaq.',
 'permissionserrors'         => 'Õigusõq ei klapiq',
 'permissionserrorstext'     => 'Sul olõ-i lubat taad tetäq, {{PLURAL:$1|tuuperäst, et|tuuperäst, et}}:',
@@ -729,7 +722,7 @@
 'mypreferences'            => 'Mu säädmiseq',
 'prefs-edits'              => 'Tõimõndamiisi arv:',
 'prefsnologin'             => 'Sa olõ-i nimega sisse lännüq',
-'prefsnologintext'         => 'Et säädmiisi tetäq, tulõ sul [[Special:Userlogin|nimega sisse minnäq]].',
+'prefsnologintext'         => 'Et säädmiisi tetäq, tulõ sul [[Special:UserLogin|nimega sisse minnäq]].',
 'prefsreset'               => 'Su säädmiseq ommaq puutrimälo perrä tagasi tettüq.',
 'qbsettings'               => 'Kipõriba säädmine',
 'qbsettings-none'          => 'Olõ-i',
@@ -855,11 +848,11 @@
 'reupload'                    => 'Vahtsõst üleslaatminõ',
 'reuploaddesc'                => 'Tagasi üleslaatmisõ vormi mano.',
 'uploadnologin'               => 'Sa olõ-i nimega sisse lännüq',
-'uploadnologintext'           => 'Kui tahat teedüstüid üles laatiq, piät [[Special:Userlogin|nimega sisse minemä]].',
+'uploadnologintext'           => 'Kui tahat teedüstüid üles laatiq, piät [[Special:UserLogin|nimega sisse minemä]].',
 'upload_directory_read_only'  => 'Serveril olõ-i üleslaatmiskausta ($1) kirotamisõ õigust.',
 'uploaderror'                 => 'Üleslaatmisviga',
 'uploadtext'                  => '<strong>PIÄQ KINNIQ!</strong> Inne ülelaatmist kaeq, et taa käünüq {{SITENAME}} [[{{MediaWiki:Policy-url}}|pilte pruukmisõ kõrra]] perrä.
-<p>Innembält üleslaadiduq pildiq lövvät [[Special:Imagelist|pilte nimekiräst]].
+<p>Innembält üleslaadiduq pildiq lövvät [[Special:ImageList|pilte nimekiräst]].
 <p>Järgmädse vormi abiga saat laatiq üles vahtsit pilte ummi artiklide ilostamisõs. Inämbüsel võrgokaejil näet nuppi "Browse..." vai "Valiq...", miä vii sinno
 su opõratsioonisüsteemi standardsõhe teedüstüide vallalõtegemise aknõhe. Teedüstü valimisõs pandas timä nimi tekstivälä pääle, miä om nupi kõrval.
 Piät ka kastikõistõ märgi tegemä, et kinnütät,
@@ -935,7 +928,7 @@
 'upload_source_url'  => ' (avalik tüütäv võrgoaadrõs)',
 'upload_source_file' => ' (teedüstü su puutrin)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Pildi nime otsminõ:',
 'imgfile'               => 'teedüstü',
 'imagelist'             => 'Pilte nimekiri',
@@ -1098,7 +1091,7 @@
 'logempty'             => 'Muutmisnimekirän olõ-i sääntsit kiräkotussit.',
 'log-title-wildcard'   => 'Otsiq päälkirjo, miä alostasõq taa tekstiga',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Kõik artikliq',
 'alphaindexline'    => '$1 kooniq $2',
 'nextpage'          => 'Järgmäne lehekülg ($1)',
@@ -1118,17 +1111,17 @@
 'categories'         => 'Katõgooriaq',
 'categoriespagetext' => 'Seon vikin ommaq sääntseq katõgooriaq:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Näütäq pruukjit alostõn:',
 'listusers-submit'   => 'Näütäq',
 'listusers-noresult' => 'Olõ-s pruukjit.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights' => 'Pruukjarühmi õigusõq',
 
 # E-mail user
 'mailnologin'     => 'Olõ-i saatja aadrõssit',
-'mailnologintext' => 'Sa piät olõma [[Special:Userlogin|nimega sisse lännüq]]
+'mailnologintext' => 'Sa piät olõma [[Special:UserLogin|nimega sisse lännüq]]
 ja sul piät umin [[Special:Preferences|säädmiisin]] olõma e-postiaadrõs, et sa saasiq tõisilõ pruukjilõ e-kirjo saataq.',
 'emailuser'       => 'Kirodaq taalõ pruukjalõ e-kiri',
 'emailpage'       => 'Kirodaq pruukjalõ e-kiri',
@@ -1154,9 +1147,9 @@
 'nowatchlist'          => 'Perräkaemisnimekiri om tühi.',
 'watchlistanontext'    => 'Perräkaemisnimekirä pruukmisõs $1.',
 'watchnologin'         => 'Olõ-i nimega sisse mint',
-'watchnologintext'     => 'Perräkaemisnimekirä muutmisõs piät [[Special:Userlogin|nimega sisse minemä]].',
+'watchnologintext'     => 'Perräkaemisnimekirä muutmisõs piät [[Special:UserLogin|nimega sisse minemä]].',
 'addedwatch'           => 'Perräkaemisnimekirjä pant',
-'addedwatchtext'       => "Lehekülg \"<nowiki>\$1</nowiki>\" om pant su [[Special:Watchlist|perräkaemisnimekirjä]]. Edespididseq muutmisõq seo lehe ja tä arotuskülgi pääl pandasõq ritta siin ja [[Special:Recentchanges|viimätside muutmiisi lehe pääl]] tuvvasõq '''paksun kirän'''. Ku tahat taad lehte perräkaemisnimekiräst vällä võttaq, klõpsaq nuppi \"Lõpõdaq perräkaeminõ ärq\".",
+'addedwatchtext'       => "Lehekülg \"<nowiki>\$1</nowiki>\" om pant su [[Special:Watchlist|perräkaemisnimekirjä]]. Edespididseq muutmisõq seo lehe ja tä arotuskülgi pääl pandasõq ritta siin ja [[Special:RecentChanges|viimätside muutmiisi lehe pääl]] tuvvasõq '''paksun kirän'''. Ku tahat taad lehte perräkaemisnimekiräst vällä võttaq, klõpsaq nuppi \"Lõpõdaq perräkaeminõ ärq\".",
 'removedwatch'         => 'Perräkaemisnimekiräst vällä võet',
 'removedwatchtext'     => 'Lehekülg "<nowiki>$1</nowiki>" om su perräkaemisnimekiräst vällä võet.',
 'watch'                => 'Kaeq perrä',
@@ -1251,7 +1244,7 @@
 'revertpage'                  => 'Pruukja [[Special:Contributions/$2|$2]] ([[User_talk:$2|arotus]]) toimõndusõq pöörediq tagasi ja leht panti tagasi pruukja [[User:$1|$1]] tettü kujo pääle.', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'sessionfailure'              => 'Paistus ollõv määnegi hädä su toimõndamiskõrraga, tuuperäst om viimäne muutminõ egäs johtumisõs jätet tegemäldä. Vaodaq võrgokaeja "tagasi"-nuppi, laadiq üle lehekülg, kost sa tullit ja prooviq vahtsõst.',
 'protectlogpage'              => 'Lehti kaitsmiisi nimekiri',
-'protectlogtext'              => 'Tan om nimekiri lehti kaitsmiisist ja kaitsmisõ maahavõtmiisist. Parhilla kaitsõ all olõvidõ lehti nimekirä lövvät [[Special:Protectedpages|tast]].',
+'protectlogtext'              => 'Tan om nimekiri lehti kaitsmiisist ja kaitsmisõ maahavõtmiisist. Parhilla kaitsõ all olõvidõ lehti nimekirä lövvät [[Special:ProtectedPages|tast]].',
 'protectedarticle'            => 'pand\' lehe "[[$1]]" kaitsõ ala',
 'unprotectedarticle'          => 'võtt\' lehe "[[$1]]" kaitsõ alt maaha',
 'protect-title'               => 'Lehe "$1" kaitsminõ',
@@ -1384,7 +1377,7 @@
 'badipaddress'                => 'Puutri võrgoaadrõs om võlssi kirotõt.',
 'blockipsuccesssub'           => 'Kinniqpidämine läts kõrda',
 'blockipsuccesstext'          => 'Puutri võrgoaadrõs "$1" om kinniq peet.
-<br />Kõik parhilladsõq kinniqpidämiseq lövvät [[Special:Ipblocklist|kinniqpidämiisi nimekiräst]].',
+<br />Kõik parhilladsõq kinniqpidämiseq lövvät [[Special:IPBlockList|kinniqpidämiisi nimekiräst]].',
 'ipb-edit-dropdown'           => 'Toimõndaq kinniqpidämise põhjuisi',
 'ipb-unblock-addr'            => 'Lõpõdaq pruukja $1 kinniqpidämine ärq',
 'ipb-unblock'                 => 'Lõpõdaq pruukja vai puutri võrgoaadrõasi kinniqpidämine ärq',
@@ -1414,7 +1407,7 @@
 'autoblocker'                 => 'Olõt automaatsõhe kinniq peet, selle et jaat puutri võrgoaadrõssit pruukjaga $1. Kinniqpidämise põhjus: $2.',
 'blocklogpage'                => 'Kinniqpidämiisi nimekiri',
 'blocklogentry'               => 'pidi kinniq pruukja vai puutri võrgoaadrõsi "[[$1]]". Kinniqpidämise tähtaig $2 $3',
-'blocklogtext'                => 'Taa om kinniqpidämiisi ja naidõ maahavõtmiisi nimekiri. Automaatsõhe kinniqpeetüisi puutridõ võrgoaadrõssiid tan näüdätä-i, noid kaeq [[Special:Ipblocklist|puutridõ võrgoaadrõssidõ kinniqpidämise nimekiräst]].',
+'blocklogtext'                => 'Taa om kinniqpidämiisi ja naidõ maahavõtmiisi nimekiri. Automaatsõhe kinniqpeetüisi puutridõ võrgoaadrõssiid tan näüdätä-i, noid kaeq [[Special:IPBlockList|puutridõ võrgoaadrõssidõ kinniqpidämise nimekiräst]].',
 'unblocklogentry'             => "lõpõt' pruukja $1 kinniqpidämise ärq",
 'block-log-flags-anononly'    => 'õnnõ nimeldä pruukjaq',
 'block-log-flags-nocreate'    => 'pruukjanime luuminõ kinniq peet',
@@ -1471,8 +1464,6 @@
 
 Kui om nii, sis panõq vana arotuskülg eräle vai panõq taa kokko vahtsõ arotuskülega.",
 'movearticle'             => 'Panõq artiklilehekülg tõistõ paika',
-'movenologin'             => 'Sa olõ-i nimega sisse lännüq',
-'movenologintext'         => 'Et lehekülge tõistõ paika pandaq, piät hindä pruukjas kirjä pandma ja [[Special:Userlogin|nimega sisse minemä]]',
 'movenotallowed'          => 'Sul olõ-i lupa {{SITENAME}} lehti tõistõ paika nõstaq.',
 'newtitle'                => 'Vahtsõ päälkirä ala',
 'move-watch'              => 'Kaeq taa lehe perrä',
@@ -1489,7 +1480,7 @@
 'movereason'              => 'Põhjus',
 'revertmove'              => 'võtaq tagasi',
 'delete_and_move'         => 'Kistudaq tsihtlehekülg ärq ja panõq timä asõmalõ taa leht',
-'delete_and_move_text'    => 'Tsihtlehekülg  "[[$1]]" om jo olõman, kas tahat tuu ärq kistutaq, et taa leht timä asõmalõ pandaq?',
+'delete_and_move_text'    => 'Tsihtlehekülg  "[[:$1]]" om jo olõman, kas tahat tuu ärq kistutaq, et taa leht timä asõmalõ pandaq?',
 'delete_and_move_confirm' => 'Jah, kistudaq tuu leht ärq',
 'delete_and_move_reason'  => 'Ärq kistutõt, et tõõnõ timä asõmalõ pandaq',
 'selfmove'                => 'Lätte- ja tsihtnimi ommaq samaq; saa-i lehte timä hindä pääle pandaq.',
@@ -1705,7 +1696,7 @@
 'show-big-image'       => 'Täüsterräv kujo',
 'show-big-image-thumb' => '<small>Proovikaemisõ suurus: $1×$2 pikslit</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Vahtsõq pildiq',
 'imagelisttext'         => 'Pilte nimekirän $1 (sordiduq $2).',
 'showhidebots'          => '($1 robodiq)',
@@ -1985,7 +1976,7 @@
 
 # External editor support
 'edit-externally'      => 'Toimõndaq taad teedüstüt välidse programmiga',
-'edit-externally-help' => 'Lisateedüst: [http://meta.wikimedia.org/wiki/Help:External_editors kaeq siist].',
+'edit-externally-help' => 'Lisateedüst: [http://www.mediawiki.org/wiki/Manual:External_editors kaeq siist].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kõik',
@@ -2030,7 +2021,7 @@
 'recreate'            => 'Luuq vahtsõst',
 
 # HTML dump
-'redirectingto' => 'Saadõtas ümbre lehe pääle [[$1]]...',
+'redirectingto' => 'Saadõtas ümbre lehe pääle [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Kas taa lehe vaihõmälokujoq tulõvaq ärq kistutaq?
@@ -2100,7 +2091,7 @@
 'version-version'          => 'Kujo',
 'version-software-version' => 'Kujo',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Teedüstü aadrõs',
 'filepath-page'   => 'Teedüstü:',
 'filepath-submit' => 'Aadrõs',
Index: languages/messages/MessagesMt.php
===================================================================
--- languages/messages/MessagesMt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,20 +4,20 @@
  * @ingroup Language
  * @file
  *
+ * @author Chrisportelli
  * @author Giangian15
- * @author Siebrand
- * @author Chrisportelli
+ * @author Roderick Mallia
  */
 
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Links Sottolinjati:',
 'tog-highlightbroken'         => 'Sawwar links imkissra <a href="" class="new"> hekk </a> (alternattiva: hekk<a href="" class="internal">?</a>).',
-'tog-justify'                 => 'Ġustifika paragrafi',
+'tog-justify'                 => 'Iġġustifika l-paragrafi',
 'tog-hideminor'               => "Aħbi modifiki żgħar f'modifiki riċenti",
 'tog-extendwatchlist'         => "Espandi l-lista t'osservazzjoni biex turi l-bidliet applikabbli kollha",
 'tog-usenewrc'                => 'Modifiki riċenti aħjar (JavaScript)',
-'tog-numberheadings'          => "Titli tas-sezzjonijiet b'ċifri awtomatiki",
+'tog-numberheadings'          => 'Innumera awtomatikament it-titli tas-sezzjonijiet',
 'tog-showtoolbar'             => 'Uri l-kolonna tal-għodda għall-modifikar (JavaScript)',
 'tog-editondblclick'          => 'Modifika l-paġni meta jiġu magħfusa darbtejn (JavaScript)',
 'tog-editsection'             => "Ġiegħel modifiki ta' sezzjonijiet mil-links [modifika]",
@@ -25,11 +25,11 @@
 'tog-showtoc'                 => "Uri t-tabella tal-kontenut (għal paġni b'aktar minn tliet titli)",
 'tog-rememberpassword'        => 'Ftakar il-password (tirrikjedi li taċċetta cookie)',
 'tog-editwidth'               => "Il-Kaxxa tal-modifika għanda wisa' massima",
-'tog-watchcreations'          => "Żied paġni li noħloq fil-lista t'osservazzjoni tiegħi",
-'tog-watchdefault'            => "Żied paġni li nimmodifika fil-lista ta' osservazzjonijiet speċjali",
-'tog-watchmoves'              => "Żied paġni li nċaqlaq għal lista ta' osservazzjonijiet speċjali",
-'tog-watchdeletion'           => "Żied paġni li nħassar mil-lista ta' osservazzjonijiet speċjali",
-'tog-minordefault'            => "Indika bid-''default'' kull modifika bħalha modifika 'żgħira'",
+'tog-watchcreations'          => "Żid il-paġni li noħloq mal-lista ta' osservazzjoni tiegħi",
+'tog-watchdefault'            => "Żid il-paġni li nimmodifika fil-lista ta' osservazzjonijiet speċjali",
+'tog-watchmoves'              => "Żid il-paġni li nċaqlaq mal-lista ta' osservazzjonijiet speċjali",
+'tog-watchdeletion'           => "Żid il-paġni li nħassar mal-lista ta' osservazzjonijiet speċjali",
+'tog-minordefault'            => "Immarka b'mod awtomatiku kull modifika bħala modifika 'żgħira'",
 'tog-previewontop'            => 'Uri l-previżjoni qabel il-kaxxa tal-modifika',
 'tog-previewonfirst'          => 'Uri l-previżjoni qabel l-ewwel modifika',
 'tog-nocache'                 => "Itfi' il-''cache'' tal-paġni",
@@ -80,7 +80,7 @@
 'may_long'      => 'Mejju',
 'june'          => 'Ġunju',
 'july'          => 'Lulju',
-'august'        => 'Awissu',
+'august'        => 'Awwissu',
 'september'     => 'Settembru',
 'october'       => 'Ottubru',
 'november'      => 'Novembru',
@@ -92,7 +92,7 @@
 'may-gen'       => 'Mejju',
 'june-gen'      => 'Ġunju',
 'july-gen'      => 'Lulju',
-'august-gen'    => 'Awissu',
+'august-gen'    => 'Awwissu',
 'september-gen' => 'Settembru',
 'october-gen'   => 'Ottubru',
 'november-gen'  => 'Novembru',
@@ -113,7 +113,7 @@
 # Categories related messages
 'pagecategories'                 => '{{PLURAL:$1|Kategorija|Kategoriji}}',
 'category_header'                => 'Paġni f\'din il-kategorija "$1"',
-'subcategories'                  => 'Subkategoriji',
+'subcategories'                  => 'Sottokategoriji',
 'category-media-header'          => 'Medja fil-kategorija "$1"',
 'category-empty'                 => "''Din il-kategorija bħalissa m'għandiex paġni jew medja.''",
 'hidden-categories'              => '{{PLURAL:$1|Kategorija moħbija|Kategoriji moħbijin}}',
@@ -124,7 +124,7 @@
 'category-article-count-limited' => 'Din il-kategorija għanda {{PLURAL:$1|l-paġna indikata|l-$1 paġni indikati}}.',
 'category-file-count'            => "{{PLURAL:$2|Din il-kategorija għanda biss dan il-fajl, kif indikat|Din il-kategorija għanda {{PLURAL:$1|fajl, kif indikat|$1 fajls, indikati}}, minn total ta' $2.}}",
 'category-file-count-limited'    => "Il-{{PLURAL:$1|fajl indikat huwa|$1 fajls indikati huma}} f'din il-kategorija.",
-'listingcontinuesabbrev'         => 'kompli.',
+'listingcontinuesabbrev'         => 'kompli',
 
 'linkprefix'        => '/^(.*?)([a-żA-Ż\\x80-\\xff]+)$/sD',
 'mainpagetext'      => "<big>'''MedjaWiki ġiet installat b'suċċess.'''</big>",
@@ -136,19 +136,19 @@
 * [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki oħroġ lista ta' posta]",
 
 'about'          => 'Dwar',
-'article'        => 'paġna tal-kontenut',
+'article'        => 'artiklu',
 'newwindow'      => "(tinfetaħ f'window ġdida)",
-'cancel'         => 'Kanċella',
+'cancel'         => 'Ikkanċella',
 'qbfind'         => 'Fittex',
-'qbbrowse'       => 'Browsja',
-'qbedit'         => 'Modifika',
+'qbbrowse'       => 'Qalleb',
+'qbedit'         => 'Immodifika',
 'qbpageoptions'  => 'Din il-paġna',
 'qbpageinfo'     => 'Kuntest',
 'qbmyoptions'    => 'Il-paġni tiegħi',
 'qbspecialpages' => 'Paġni speċjali',
 'moredotdotdot'  => 'Aktar...',
 'mypage'         => 'Il-paġna tiegħi',
-'mytalk'         => 'Diskussjonijiet tiegħi',
+'mytalk'         => 'Id-Diskussjonijiet tiegħi',
 'anontalk'       => 'Diskussjoni għal dan l-IP',
 'navigation'     => 'Navigazzjoni',
 'and'            => 'u',
@@ -157,7 +157,7 @@
 'metadata_help' => 'Metadata:',
 
 'errorpagetitle'    => 'Problema',
-'returnto'          => "Erġa' lura għal $1.",
+'returnto'          => "Erġa' lura lejn $1.",
 'tagline'           => 'Minn {{SITENAME}}',
 'help'              => 'Għajnuna',
 'search'            => 'Fittex',
@@ -170,42 +170,42 @@
 'info_short'        => 'Informazzjoni',
 'printableversion'  => 'Verżjoni għall-ipprintjar',
 'permalink'         => 'Link permanenti',
-'print'             => 'Printja',
-'edit'              => 'Modifika',
+'print'             => 'Ipprintja',
+'edit'              => 'Immodifika',
 'create'            => 'Oħloq',
 'editthispage'      => 'Immodifika din il-paġna',
 'create-this-page'  => 'Oħloq din il-paġna',
 'delete'            => 'Ħassar',
 'deletethispage'    => 'Ħassar din il-paġna',
 'undelete_short'    => 'Irkupra {{PLURAL:$1|modifika waħda|$1 modifika}}',
-'protect'           => 'Protieġi',
-'protect_change'    => 'Biddel protezzjoni',
-'protectthispage'   => 'Protieġi din il-paġna',
-'unprotect'         => 'Tibqax tipprotieġi',
-'unprotectthispage' => 'Tibqax tipprotieġi din il-paġna',
+'protect'           => 'Ipproteġi',
+'protect_change'    => 'Biddel il-protezzjoni',
+'protectthispage'   => 'Ipproteġi din il-paġna',
+'unprotect'         => 'Tibqax tipproteġi',
+'unprotectthispage' => 'Tibqax tipproteġi din il-paġna',
 'newpage'           => 'Paġna ġdida',
-'talkpage'          => 'Diskuti din il-paġna',
-'talkpagelinktext'  => 'Diskuti',
+'talkpage'          => 'Iddiskuti din il-paġna',
+'talkpagelinktext'  => 'Iddiskuti',
 'specialpage'       => 'Paġna speċjali',
 'personaltools'     => 'Għodda personali',
-'postcomment'       => 'Postja kumment',
+'postcomment'       => 'Ħalli kumment',
 'articlepage'       => 'Uri kontenut tal-paġna',
 'talk'              => 'Diskussjoni',
 'views'             => 'Veduti',
-'toolbox'           => 'Kaxxa tal-Għodda',
-'userpage'          => 'Uri paġna tal-utent',
-'projectpage'       => 'Uri paġna tal-proġett',
-'imagepage'         => 'Uri paġna tal-medja',
-'mediawikipage'     => 'Uri paġna tal-messaġġ',
-'templatepage'      => 'Uri paġna tat-template',
-'viewhelppage'      => 'Uri paġna tal-għajnuna',
-'categorypage'      => 'Uri paġna tal-kategorija',
-'viewtalkpage'      => 'Uri diskussjonijiet',
+'toolbox'           => 'Għodda',
+'userpage'          => 'Ara l-paġna tal-utent',
+'projectpage'       => 'Ara l-paġna tal-proġett',
+'imagepage'         => 'Ara l-paġna tal-medja',
+'mediawikipage'     => 'Ara l-paġna tal-messaġġ',
+'templatepage'      => 'Ara l-paġna tat-template',
+'viewhelppage'      => 'Ara l-paġna tal-għajnuna',
+'categorypage'      => 'Ara l-paġna tal-kategorija',
+'viewtalkpage'      => 'Ara d-diskussjonijiet',
 'otherlanguages'    => "F'lingwi oħrajn",
 'redirectedfrom'    => '(Rindirizzat minn $1)',
 'redirectpagesub'   => 'Paġna li tidderieġi',
 'lastmodifiedat'    => 'Din il-paġna kienet modifikata l-aħħar: $2, $1 .', # $1 date, $2 time
-'viewcount'         => 'Din il-paġna ġiet miftuħa {{PLURAL:$1|darba|$1 drabi}}.',
+'viewcount'         => 'Din il-paġna ġiet moqrija {{PLURAL:$1|darba|$1 drabi}}.',
 'protectedpage'     => 'Paġna protetta',
 'jumpto'            => 'Aqbeż għal:',
 'jumptonavigation'  => 'navigazzjoni',
@@ -217,40 +217,40 @@
 'bugreports'           => 'Rapporti dwar żballji',
 'bugreportspage'       => 'Project:Rapporti dwar żballji',
 'copyright'            => 'Kontenut aċċessibli taħt $1.',
-'copyrightpagename'    => '{{SITENAME}} propjetá letterarja',
-'copyrightpage'        => '{{ns:project}}:Propjetá letterarja',
+'copyrightpagename'    => 'Copyright {{SITENAME}}',
+'copyrightpage'        => '{{ns:project}}:Copyright',
 'currentevents'        => 'Ġrajjiet kurrenti',
 'currentevents-url'    => 'Project:Ġrajjiet kurrenti',
 'disclaimers'          => 'Ċaħdiet',
-'disclaimerpage'       => 'Project:Ċaħdiet ġenerali',
+'disclaimerpage'       => 'Project:Ċaħda ġenerali',
 'edithelp'             => 'Għajnuna bil-modifika',
-'edithelppage'         => 'Help:Modifika',
-'faq'                  => 'FAQ',
+'edithelppage'         => 'Help:Kif Timmodifika',
+'faq'                  => 'Mistoqsijiet komuni',
 'faqpage'              => 'Project:FAQ',
 'helppage'             => 'Help:Kontenut',
-'mainpage'             => 'Paġna prinċipali',
-'mainpage-description' => 'Paġna prinċipali',
+'mainpage'             => 'Il-Paġna prinċipali',
+'mainpage-description' => 'Il-Paġna prinċipali',
 'policy-url'           => 'Project:Politika',
 'portal'               => 'Portal tal-komunità',
 'portal-url'           => 'Project:Portal tal-komunità',
-'privacy'              => 'Politika dwar segretezza',
-'privacypage'          => 'Project:Politika dwar segretezza',
+'privacy'              => 'Politika dwar il-privatezza',
+'privacypage'          => 'Project:Politika dwar il-privatezza',
 
-'badaccess'        => 'Problema dwar permess',
-'badaccess-group0' => "M'għandhekx id-dritt li tagħmel din l-azzjoni.",
-'badaccess-group1' => "L-Azzjoni li għamilt rikjesta għal hija restretta għal utenti f'grupp $1.",
-'badaccess-group2' => "L-Azzjoni li għamilt rikjesta għal hija restretta għal utenti minn wieħed mill-gruppijiet ta' $1.",
+'badaccess'        => 'Problema bil-permess',
+'badaccess-group0' => "M'għandekx permess twettaq din l-azzjoni.",
+'badaccess-group1' => 'L-azzjoni li rrikjedejt hija riservata għall-utenti membri tal-grupp $1.',
+'badaccess-group2' => 'L-azzjoni li rrikjedejt hija riservata għal utenti membri tal-gruppi $1.',
 'badaccess-groups' => "L-Azzjoni li għamilt rikjesta għal hija restretta għal utenti minn wieħed mill-gruppijiet ta' $1.",
 
-'versionrequired'     => "Hemm bżonn verżjoni $1 ta' MedjaWiki",
-'versionrequiredtext' => "Hemm bżonn verżjoni $1 ta' MedjaWiki biex tintuża din il-paġna. Ara [[Special:Version|paġna tal-verżjoni]].",
+'versionrequired'     => "Hija meħtieġa l-verżjoni $1 ta' MedjaWiki",
+'versionrequiredtext' => "Hija meħtieġa l-verżjoni $1 ta' MedjaWiki biex tuża din il-paġna. Ara [[Special:Version|paġna tal-verżjoni]].",
 
 'ok'                      => 'OK',
-'retrievedfrom'           => 'Minġub minn "$1"',
+'retrievedfrom'           => 'Miġjub minn "$1"',
 'youhavenewmessages'      => 'Għandek $1 ($2).',
 'newmessageslink'         => 'messaġġi ġodda',
 'newmessagesdifflink'     => 'l-aħħar bidla',
-'youhavenewmessagesmulti' => 'Int għandhek messaġġi ġodda fuq $1',
+'youhavenewmessagesmulti' => 'Għandek messaġġi ġodda fuq $1',
 'editsection'             => 'modifika',
 'editold'                 => 'modifika',
 'viewsourceold'           => 'uri l-kodiċi sorġenti',
@@ -259,7 +259,7 @@
 'showtoc'                 => 'uri',
 'hidetoc'                 => 'aħbi',
 'thisisdeleted'           => 'Uri jew ġib lura $1?',
-'viewdeleted'             => 'Uri $1?',
+'viewdeleted'             => 'Ara $1?',
 'restorelink'             => '{{PLURAL:$1|waħda mill-modifiki mħassra|$1 modifiki mħassra}}',
 'feedlinks'               => 'Feed:',
 'feed-invalid'            => "Tip ta' feed ta' l-abbonar invalidu.",
@@ -272,7 +272,7 @@
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Paġna',
-'nstab-user'      => "Paġna ta' l-utent",
+'nstab-user'      => 'Paġna tal-utent',
 'nstab-media'     => 'Paġna tal-medja',
 'nstab-special'   => 'Speċjali',
 'nstab-project'   => 'Paġna tal-proġett',
@@ -288,7 +288,7 @@
 'nosuchspecialpage' => 'L-Ebda paġna speċjali',
 'nospecialpagetext' => "<big>'''Inti għamilt rikjesta għal paġna speċjali invalida.'''</big>
 
-Lista ta' paġni speċjali validi tinsab hawn [[Special:Specialpages|{{int:specialpages}}]].",
+Lista ta' paġni speċjali validi tinsab hawn [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Problema',
@@ -314,25 +314,25 @@
 'readonlytext'         => 'Id-Database bħalissa magħluq għal daħla ġdid u modifiki oħrajn, probabilment għal manteniment tar-rutina tad-database, wara terġa tiġi għan-normali.
 
 L-amministratur li għalqu offra din l-ispjegazzjoni: $1',
-'missing-article'      => 'Id-Database ma sabx it-test tal-paġna li sippost sab, taħt l-isem ta\' "$1" $2.
+'missing-article'      => 'Id-database ma sabitx it-test tal-paġna li suppost sab, taħt l-isem ta\' "$1" $2.
 
-Is-Soltu din tiġi verifikata meta tiġi mniżżla mill-ġdid. Din hija ġeneralment tkun minħabba li l-kronoloġija jew ir-reviżjonijiet, paġni li ġiet kanċellata, jista\' jkun li r-reviżjonijiet huwa ineżistenti jew minħabba li l-kronoloġija ġiet imnadfa mill-ġdid mir-reviżjonijiet.
+Is-soltu dan jiġri meta l-paġna terġa\' tiġi msejjħa, billi tibda mill-kronoloġija jew mill-konfront bejn ir-reviżjonijiet, link għal paġna mħassra, ma\' konfront bejn reviżjonijiet ineżistenti jew konfront bejn reviżjonijiet imnaddfa mill-kronoloġija.
 
-Jekk dan mhux ir-raġuni, inti wisq probabli sibt problema fis-software. Jekk jogħġbok irraporta dan lil amministratur, u agħmel nota tal-URL.',
+Jekk din mhix ir-raġuni, inti wisq probabli sibt problema fis-software. Jekk jogħġbok irraporta dan lil [[Special:ListUsers/sysop|amministratur]], u agħmel nota tal-URL.',
 'missingarticle-rev'   => '(reviżjoni#: $1)',
 'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'Id-Database ġiet awtomatikament magħluqa sakemm id-databases inferjuri tas-server jilħqu mal-superjur',
 'internalerror'        => 'Problema interna',
 'internalerror_info'   => 'Problema interna: $1',
-'filecopyerror'        => 'Il-Fajls "$1" sa "$2" ma setgħux jiġu kopjati.',
+'filecopyerror'        => 'Ma setax jiġi kkuppjat il-fajl "$1" f\' "$2".',
 'filerenameerror'      => 'Il-Fajls "$1" to "$2" ma setgħux jiġu msemmija mill-ġdid.',
 'filedeleteerror'      => 'Il-Fajl "$1" ma setgħax jiġi mħassar.',
 'directorycreateerror' => 'Id-Direttorju "$1" ma setgħax jiġi maħluq.',
-'filenotfound'         => 'Il-Fajl "$1" ma setgħax jinstab.',
+'filenotfound'         => 'Il-fajl "$1" ma nstabx.',
 'fileexistserror'      => 'Il-Fajl "$1" ma setgħax jiġi miktub: fajl ġa ġie maħluq',
 'unexpected'           => 'Valur mhux mistenni: "$1"="$2".',
 'formerror'            => 'Problema: il-formula ma setgħatx tiġi proċessata',
-'badarticleerror'      => 'Din l-azzjoni ma setgħatx tiġi proċessa fuq din il-paġna.',
+'badarticleerror'      => 'Din l-azzjoni ma setgħetx isseħħ fuq din il-paġna.',
 'cannotdelete'         => "Il-Fajl speċifikat jew paġna ma setgħatx tiġi mħassra.
 Jista' jkun li diġa ġiet imħassra minn xi ħaddieħor.",
 'badtitle'             => 'Titlu ħażin',
@@ -344,9 +344,9 @@
 'wrong_wfQuery_params' => 'Parametri skoretti għal wfQuery()<br />
 Funżjoni: $1<br />
 Rikjesta: $2',
-'viewsource'           => 'Uri l-kodiċi sorġenti',
+'viewsource'           => 'Ara l-fonti',
 'viewsourcefor'        => 'għal $1',
-'actionthrottled'      => 'Azzjoni toħnoq',
+'actionthrottled'      => 'Azzjoni miżmuma',
 'actionthrottledtext'  => "Bħala miżura għal kontra l-ispam, inti limitat li tagħmel din l-azzjoni għal ħafna drabi f'spazju ta' ħin żgħir, u inti qbiżt dan il-limitu.
 Jekk jogħġbok erġa' prova fi ftit minuti oħra.",
 'protectedpagetext'    => "Din il-paġna ġiet magħluqa sabiex twaqqaf kull tip ta' modifika.",
@@ -359,7 +359,7 @@
 $2',
 'namespaceprotected'   => "Inti m'għandhekx il-permess li timodifika paġni fin-''namespace'' '''$1''.",
 'customcssjsprotected' => "Inti m'għandhekx permess li timodifika din il-paġna, minħabba li tinkludi preferenzi personali ta' utent ieħor.",
-'ns-specialprotected'  => 'Paġni speċjali ma jistgħux jiġu modifikati.',
+'ns-specialprotected'  => 'Il-paġni speċjali ma jistgħux jiġu mmodifikati.',
 'titleprotected'       => "Dan it-titlu ġie protett mill-ħolqien minn [[User:$1|$1]].
 Ir-raġuni li ġiet mogħtija kienet ''$2''.",
 
@@ -370,50 +370,50 @@
 
 # Login and logout pages
 'logouttitle'                => 'Oħroġ utent',
-'logouttext'                 => "<strong>Inti issa għamilt log out.</strong>
+'logouttext'                 => "<strong>Int issa illogjajt barra.</strong>
 
-Tista' tkompli tuża {{SITENAME}} bħala utent anonimu, jew tista' terġa tidħol bħala l-istess utent jew wieħed differenti.
+Tista' tkompli tuża' {{SITENAME}} bħala utent anonimu, jew tista' terġa tidħol bħala l-istess utent jew wieħed differenti.
 
-Ċerta paġni jistgħu jkomplu jiġu reveduti bħalikieku l-logout ma sarx, sakemm tħassar il-''cache tal-browser''.",
+Ċerta paġni jistgħu jkomplu jiġu reveduti bħallikieku l-logout ma sarx, sakemm tħassar il-cache tal-browser.",
 'welcomecreation'            => "== Merħba, $1! ==
-Il-Kont tiegħek issa ġie maħluq.
-Tinsiex tbiddel il-preferenzi tiegħek ta' {{SITENAME}}.",
+Il-kont tiegħek ġie maħluq.<br />
+Tinsiex tippersonalizza l-[[Special:Preferences|preferenzi]] ta' {{SITENAME}}.",
 'loginpagetitle'             => 'Idħol utent',
-'yourname'                   => 'L-Isem tal-utent:',
+'yourname'                   => 'Isem l-utent:',
 'yourpassword'               => 'Password:',
 'yourpasswordagain'          => "Erġa' ikteb il-password:",
 'remembermypassword'         => 'Ftakar il-login tiegħi fuq dan il-kompjuter',
-'yourdomainname'             => 'Id-Dominju tiegħek:',
+'yourdomainname'             => 'Id-dominju tiegħek:',
 'externaldberror'            => "Kien hemm problema esterna ta' awtentiċitá jew m'għandhekx permess neċċessarju sabiex tagħmel aġġornamenti fuq l-aċċess estern.",
 'loginproblem'               => "<b>Kien hemm problema bil-login tiegħek.</b><br />Erġa' prova!",
 'login'                      => 'Idħol',
-'nav-login-createaccount'    => 'Idħol / oħloq kont',
-'loginprompt'                => "Irrid ikollhok il-cookies mixewla biex tkun tista' tidħol fuq {{SITENAME}}.",
+'nav-login-createaccount'    => 'Idħol / Oħloq kont',
+'loginprompt'                => "Irid ikollok il-cookies mixgħula biex tkun tista' tidħol fuq {{SITENAME}}.",
 'userlogin'                  => 'Idħol jew oħloq kont ġdid',
 'logout'                     => 'Oħroġ',
 'userlogout'                 => 'Oħroġ',
-'notloggedin'                => 'Aċċess mhux imwettaq',
-'nologin'                    => "M'għandhekx aċċess? $1.",
+'notloggedin'                => 'Għadek ma dħaltx ġewwa',
+'nologin'                    => "Għad m'għandekx kont? $1.",
 'nologinlink'                => 'Oħloq kont',
 'createaccount'              => 'Oħloq kont',
 'gotaccount'                 => 'Diġa għandhek kont? $1.',
 'gotaccountlink'             => 'Idħol',
 'createaccountmail'          => 'bil-posta elettronika',
 'badretype'                  => 'Il-passwords li daħħalt ma jaqblux.',
-'userexists'                 => 'L-Isem tal-Utent li daħħalt huwa ġa użat.
-Jekk jogħġbok agħżel isem ieħor.',
-'youremail'                  => 'Posta-elettronika:',
-'username'                   => 'L-Isem tal-utent:',
+'userexists'                 => 'Isem l-utent li daħħalt huwa diġà meħud.
+Jekk jogħġbok, agħżel isem differenti.',
+'youremail'                  => 'E-mail:',
+'username'                   => 'Isem l-utent:',
 'uid'                        => 'L-ID tal-utent:',
 'prefs-memberingroups'       => "Membru ta' {{PLURAL:$1|grupp|gruppijiet}}:",
-'yourrealname'               => 'L-Isem reali tiegħek:',
+'yourrealname'               => 'Ismek propju:',
 'yourlanguage'               => 'Lingwa:',
-'yourvariant'                => 'Varjanti:',
+'yourvariant'                => 'Varjant:',
 'yournick'                   => 'Firma:',
-'badsig'                     => 'Firma imqaxxra invalida; iċċekja t-tags tal-HTML.',
-'badsiglength'               => 'Il-Firma hija wisq twila.
-Trid tkun taħt $1 {{PLURAL:$1|karratru|karratri}}.',
-'email'                      => 'Posta-elettronika',
+'badsig'                     => 'Il-firma mhux standard, hija invalida; iċċekkja t-tags tal-HTML.',
+'badsiglength'               => 'Il-firma hija twila wisq.
+Trid tkun inqas minn $1 {{PLURAL:$1|karratru|karratri}}.',
+'email'                      => 'E-mail',
 'prefs-help-realname'        => "L-Isem reali mhux ta' bilfors.
 Jekk tagħżel li tiprovdih, dan jintuża biss biex jagħtik attribuzzjoni għax-xogħol tiegħek.",
 'loginerror'                 => 'Problemi fil-login',
@@ -423,14 +423,16 @@
 'nocookieslogin'             => "L-aċċess għal {{SITENAME}} jagħmel użu minn ''cookies'', li bħalissa huma disattivati. Jekk jogħġbok erġa' prova idħol wara li tkun attivajt il-''cookies'' fil-browser.",
 'noname'                     => "Inti ma speċifikajtx isem ta' utent validu.",
 'loginsuccesstitle'          => "Dħalt b'suċċess",
-'loginsuccess'               => "'''Il-Kollegament mas-server ta' {{SITENAME}} bl-isem tal-utent \"\$1\" issa huwa attiv.'''",
+'loginsuccess'               => "'''Irnexxielek taqbad mas-server ta' {{SITENAME}} b'isem l-utent \"\$1\".'''",
 'nosuchuser'                 => 'M\'hemm l-ebda utent bl-isem ta\' "$1".
 Jekk jogħġbok agħmel żġur li ktibta sew, jew inkella oħloq kont ġdid.',
 'nosuchusershort'            => 'M\'hemm l-ebda utent bl-isem "<nowiki>$1</nowiki>".
 Agħmel żġur li ktibta sew.',
-'nouserspecified'            => 'Trid tispeċifika isem tal-utent.',
-'wrongpassword'              => "Il-Password imdaħħal mhux tajjeb. Jekk jogħġbok erġa' prova.",
-'wrongpasswordempty'         => "Il-Password imdaħħal huwa vojt. Jekk jogħġbok erġa' prova.",
+'nouserspecified'            => 'Trid tispeċifika isem l-utent.',
+'wrongpassword'              => "Il-password li daħħalt mhijiex tajba. 
+Jekk jogħġbok, erġa' pprova.",
+'wrongpasswordempty'         => "Ma ddaħlet l-ebda password. 
+Jekk jogħġbok, erġa' pprova.",
 'passwordtooshort'           => 'Il-Password tiegħek huwa invalidu jew qasir wisq.
 Trid tkun mill-inqas {{PLURAL:$1|1 karratru|$1 karattri}} twila u differenti mill-isem tal-utent.',
 'mailmypassword'             => 'Password tal-posta elettronika',
@@ -449,8 +451,8 @@
 'throttled-mailpassword'     => "Posta elettronika sabiex tfakrek il-password ġiet postjata, fl-aħħar {{PLURAL:$1|siegħa|$1 siegħat}}.
 Sabiex jitnaqqas l-abbuż, waħda biss tista' tiġi postjata f'kull {{PLURAL:$1|siegħa|$1 siegħat}}.",
 'mailerror'                  => 'Problema bil-postar tal-messaġġ: $1',
-'acct_creation_throttle_hit' => 'Skuzana, inti ġa ħloqt $1 kontijiet.
-Ma tistax tagħmel aktar.',
+'acct_creation_throttle_hit' => 'Jiddispjaċina, imma diġà ħloqt $1 kontijiet.
+Ma tistax toħloq aktar.',
 'emailauthenticated'         => 'L-Indirizz tal-posta elettronika tiegħek kien awtentikat fuq $1.',
 'emailnotauthenticated'      => "L-Indirizz tal-posta elettronika tiegħek ma ġiex awtentikat s'issa.
 L-ebda posta elettronika se tiġi postjata għal dawn il-faċċilitajiet segwenti.",
@@ -458,8 +460,8 @@
 'emailconfirmlink'           => 'Konferma l-indirizz tal-posta elettronika tiegħek',
 'invalidemailaddress'        => 'L-Indirizz tal-posta elettronika ma jistax jiġi aċċettat għax tidher li għandha format ħażina.
 Jekk jogħġbok daħħal indirizz formatjat tajjeb jew inkella ħassara.',
-'accountcreated'             => 'Il-Kont ġie maħluq',
-'accountcreatedtext'         => 'Il-Kont tal-utent $1 ġie maħluq.',
+'accountcreated'             => 'Il-kont inħoloq',
+'accountcreatedtext'         => 'Inħoloq kont tal-utent għal $1.',
 'createaccount-title'        => 'Ħolqien tal-kont għal {{SITENAME}}',
 'createaccount-text'         => 'Xi ħadd ħoloq kont għall-indirizz tal-posta elettronika tiegħek fuq {{SITENAME}} ($4) bl-isem "$2", bil-password: "$3".
 Huwa opportun li tidħol issa u tbiddel il-password tiegħek mill-ewwel.
@@ -468,10 +470,10 @@
 'loginlanguagelabel'         => 'Lingwa: $1',
 
 # Password reset dialog
-'resetpass'               => 'Resetja l-password tal-kont',
+'resetpass'               => 'Irrisettja l-password tal-kont',
 'resetpass_announce'      => 'L-Aċċess bil-kodiċi temporanju ġie nseħħ, u ġie postjat bil-posta elettronika. Biex tlesti l-aċċess huwa neċessarju toħloq password ġdid hawnhekk:',
 'resetpass_text'          => '<!-- Żied il-kliem hawnhekk -->',
-'resetpass_header'        => 'Resetja il-password',
+'resetpass_header'        => 'Irrisettja l-password',
 'resetpass_submit'        => 'Issettja l-password u idħol fis-sit',
 'resetpass_success'       => 'Il-password ġie modifikat. Aċċess fil-proċess...',
 'resetpass_bad_temporary' => "Password temporanja invalidu.
@@ -480,8 +482,8 @@
 'resetpass_missing'       => "L-Ebda data ta' forma.",
 
 # Edit page toolbar
-'bold_sample'     => 'Kliem ardit',
-'bold_tip'        => 'Kliem ardit',
+'bold_sample'     => 'Tipa ħoxna',
+'bold_tip'        => 'Tipa ħoxna',
 'italic_sample'   => 'Kliem korsiv',
 'italic_tip'      => 'Kliem korsiv',
 'link_sample'     => 'Titlu tal-link',
@@ -496,10 +498,10 @@
 'nowiki_tip'      => 'Tagħtix każ il-formatjar tal-wiki',
 'image_sample'    => 'Eżempju.jpg',
 'image_tip'       => 'Fajl ingastat',
-'media_sample'    => 'Eżempju.org',
+'media_sample'    => 'Eżempju.ogg',
 'media_tip'       => 'Link tal-fajl',
 'sig_tip'         => 'Il-Firma tiegħek u it-timbru tal-ħin',
-'hr_tip'          => 'Linja minduda (uża bil-qies)',
+'hr_tip'          => 'Linja mimduda (uża bil-qies)',
 
 # Edit pages
 'summary'                          => 'Taqsira',
@@ -510,86 +512,88 @@
 'preview'                          => 'Previżjoni',
 'showpreview'                      => 'Uri Previżjoni',
 'showlivepreview'                  => 'Previżjoni bħalissa',
-'showdiff'                         => 'Uri modifiki',
+'showdiff'                         => 'Uri t-tibdiliet',
 'anoneditwarning'                  => "'''Twissija:''' Aċċess mhux inseħħ. L-Indirizz tal-IP tiegħek se jiġi reġistrat fil-kronoloġija tal-modifikar ta' din il-paġna.",
 'missingsummary'                   => "'''Ftakar:''' Li ma provdejtx taqsira dwar il-modifika.
 Jekk terġa tagħfas Modifika, l-modifika se tiġi salvata mingħajr waħda.",
-'missingcommenttext'               => 'Jekk jogħġbok daħħal kumment hawn taħt.',
+'missingcommenttext'               => 'Jekk jogħġbok, ħalli kumment hawn taħt.',
 'missingcommentheader'             => "'''Ftakar:''' Int ma provdejtx suġġett/titlu għal dan il-kumment.
 Jekk terġa tagħfas Modifika, l-modifika tiegħek se tiġi salvata mingħajr waħda.",
 'summary-preview'                  => "Previżjoni ta' taqsira",
 'subject-preview'                  => 'Previżjoni dwar suġġett/titlu',
-'blockedtitle'                     => 'L-Utent ġie blokkat',
-'blockedtext'                      => "<big>'''L-Isem tal-utent jew indirizz tal-IP tiegħek ġie blokkat.'''</big>
+'blockedtitle'                     => 'L-Utent ibblokkjat',
+'blockedtext'                      => "<big>'''L-isem ta' l-utent jew l-indirizz IP tiegħek ġew imblukkati.'''</big>
 
-I-imblokk ġie minn \$1. Ir-raġuni li ġiet mogħtija kienet ''\$2''.
+Il-blokk twettaq minn \$1. Ir-raġuni mogħtiha kienet ''\$2''.
 
-* Bidu tal-imblokk: \$8
-* L-Imblokk jintemm: \$6
-* L-Imblokk kien għal: \$7
+* Il-blokk jibda: \$8
+* Il-blokk jintemm: \$6
+* Il-blokk kien għal: \$7
 
-Int tista' tagħmel kuntatt ma' \$1 jew [[{{MediaWiki:Grouppage-sysop}}|amministratur]] ieħor biex tidiskuti dan l-imblokk.
-Ma tistax tuża l-faċċilita ta' \"ibgħat posta elettronika lil dan l-utent\" sakemm l-indirizz tal-posta elettronika valida mhux speċifikata fil-[[Special:Preferences|preferenzi tal-kont]] tiegħek u int ma ġejtx blokkat milli tuża' .
-L-IP kurrenti tiegħek huwa \$3, u l-ID tal-blokkar huwa #\$5. Jekk jogħġbok inkludi it-tnejn jew wieħed minn din l-inkjesta.",
-'autoblockedtext'                  => 'L-Indirizz tal-IP tiegħek ġie awtomatikament blokkat minħabba li kienet qegħda tiġi użata minn utent ieħor, u ġie blokked minn $1.
-Ir-raġuni li ġiet mogħtija kienet:
+Tista' tikkuntattja lil \$1 jew xi [[{{MediaWiki:Grouppage-sysop}}|amministratur]] ieħor biex tiddiskuti dan il-blokk.
 
-:\'\'$2\'\'
+Ma tistax tuża l-faċilità \"ibgħat email lil dan l-utent\" sakemm m'għandekx indirizz validu tal-email fil-[[Special:Preferences|preferenzi tal-kont]] tiegħek u ma ġejtx miżmum milli tużah.
 
-* Bidu tal-imblokk: $8
-* L-Imblokk jintemm: $6
+L-IP kurrenti tiegħek huwa \$3, u l-ID ta' l-imblukkar huwa #\$5.<br />Jekk jogħġbok inkludi mqar wieħed minn dawn it-tnejn f'kwalunkwe rikjesta.",
+'autoblockedtext'                  => "L-indirizz IP tiegħek ġie awtomatikament imblukkat minħabba li kienet qiegħed jiġi wżat minn utent ieħor, u ġie imblukkat minn \$1.
+Ir-raġuni li ġiet mogħtiha kienet:
 
-Int tista\' tagħmel kuntatt ma\' $1 jew [[{{MediaWiki:Grouppage-sysop}}|amministratur]] ieħor biex tidiskuti dan l-imblokk.
+:''\$2''
 
-Nota li ma tistax tuża l-faċċilita ta\' "ibgħat posta elettronika lil dan l-utent" sakemm l-indirizz tal-posta elettronika valida mhux speċifikata fil-preferenzi tal-kont tiegħek u int ma ġejtx blokkat milli tuża.
+* Bidu tal-blokk: \$8
+* Il-blokk jintemm: \$6
+* Il-blokk kien għal: \$7
 
-L-ID tal-Imblokk tiegħek huwa $5.
-Jekk jogħġbok daħħal l-ID f\'kull inkjesta li tagħmel.',
-'blockednoreason'                  => 'l-ebda raġuni ġiet mogħtija',
-'blockedoriginalsource'            => "Il-Kodiċi sorġenti tal-paġna '''$1''' jinstab hawn taħt:",
+Int tista' tagħmel kuntatt ma' \$1 jew ma' [[{{MediaWiki:Grouppage-sysop}}|amministratur]] ieħor biex tidiskuti dan il-blokk.
+
+Għandek tkun taf li ma tistax tuża l-faċilità ta' \"ibgħat email lil dan l-utent\" sakemm m'għandekx indirizz validu tal-email fil-[[Special:Preferences|preferenzi tiegħek]] u int ma ġejtx imblukkat milli tużaha.
+
+L-IP kurrenti tiegħek huwa \$3, u l-ID ta' l-imblukkar huwa #\$5.<br />
+Jekk jogħġbok inkludi mqar wieħed minn dawn it-tnejn f'kwalunkwe rikjesta.",
+'blockednoreason'                  => 'ma ingħatat l-ebda raġuni',
+'blockedoriginalsource'            => "Il-Fonti tal-paġna '''$1''' jinsab hawn taħt:",
 'blockededitsource'                => "It-test tal-'''modifiki tiegħek''' f' '''$1''' jinstab hawn taħt:",
-'whitelistedittitle'               => "Trid tidħol sabiex tkun tista' tagħmel modifiki",
+'whitelistedittitle'               => "Trid tidħol sabiex tkun tista' timmodifika l-paġna",
 'whitelistedittext'                => "Int trid $1 biex tkun tista' timodifika l-paġni.",
-'whitelistreadtitle'               => "Trid tidħol sabiex tkun tista' taqra",
-'whitelistreadtext'                => 'Biex ikollok l-abilita li taqra l-paġni huwa neċessarju [[Special:Userlogin|tidħol]] bħala utent reġistrat.',
-'whitelistacctitle'                => "Int m'għandhekx id-dritt li toħloq kont",
-'whitelistacctext'                 => "Biex ikollhok id-dritt sabiex toħloq kont f'{{SITENAME}} int trid [[Special:Userlogin|tidħol]] bħalha utent reġistrat u jkollhok il-permessi neċessarji.",
-'confirmedittitle'                 => 'Il-Konfermá tal-posta elettronika tirikjedi modifikar',
-'confirmedittext'                  => "Inti trid tikonferma l-indirizz tal-posta elettronika tiegħek qabel ma tkun tista' tagħmel modifiki.
-Jekk jogħġbok agħmel u valida l-indirizz tal-posta elettronika tiegħek mill-[[Special:Preferences|preferenzi tal-utent]].",
+'confirmedittitle'                 => "Tinħtieġ il-konferma b'e-mail qabel tkun tista' teditja l-paġni",
+'confirmedittext'                  => "Jinħtieġ li tikkonferma l-indirizz tal-e-mail tiegħek sabiex tkun tista' timmodifika l-paġni.
+Jekk jogħġbok, issettja u kkonferma l-indirizz tal-e-mail tiegħek mill-[[Special:Preferences|preferenzi tal-utent]].",
 'nosuchsectiontitle'               => 'L-Ebda sezzjoni',
 'nosuchsectiontext'                => 'Provajt timodifika sezzjoni li ma teżistix.
 Minħabba li $1 ma teżistix, il-modifiki tiegħek ma ġewx salvati.',
 'loginreqtitle'                    => "Sabiex tagħmel modifiki f'din il-paġna huwa neċessarju li tidħol bħalha utent reġistrat fuq dan is-sit.",
 'loginreqlink'                     => 'Aċċessa',
 'loginreqpagetext'                 => "Int trid ikollhok $1 sabiex tkun tista' tara paġni oħrajn.",
-'accmailtitle'                     => 'Password ġiet postjata.',
-'accmailtext'                      => 'Il-password għal "$1" ġie postjat lil $2.',
+'accmailtitle'                     => 'Il-password intbagħtet.',
+'accmailtext'                      => 'Il-password għal "$1" intbagħtet lil $2.',
 'newarticle'                       => '(Ġdid)',
-'newarticletext'                   => "Inti segwejt link għal paġna li qas teżisti għad.
-Sabiex toħloq il-paġna, ikteb fil-kaxxa li tinsab hawn taħt (ara [[{{MediaWiki:Helppage}}|paġna tal-għajnuna]] għal aktar informazzjoni). Jekk qiegħed hawn biż-żball, kemm agħfas il-buttuna '''lura''' fuq il-browser tiegħek.",
-'anontalkpagetext'                 => "----''Din il-paġna tad-diskussjoni hija għal utenti anonimi li għad m'għandhomx kont jew li mhux qegħdin jużawh. B'hekk aħna inkunu rridu nużaw l-indirizz tal-IP tiegħu/tagħha sabiex inkunu nistgħu nsibu l-utent.
-Indirizz tal-IP bħal dan jiġi maqsum bejn ħafna utenti differenti.
-Jekk int utent anonimmu u taħseb li qiegħed tirċievi kumment bla sens, jekk jogħġbok [[Special:Userlogin|oħloq kont ġdid jew idħol]] sabiex tevita konfużjoni fil-futur ma' utenti anonimi oħrajn.''",
+'newarticletext'                   => "Inti segwejt link għal paġna li għadha ma ġietx maħluqa.
+Sabiex toħloq il-paġna, ikteb fil-kaxxa li tinsab hawn taħt (ara [[{{MediaWiki:Helppage}}|paġna tal-għajnuna]] għal aktar informazzjoni). 
+Jekk wasalt hawn biż-żball, agħfas il-buttuna '''lura''' (''back'') fuq il-browser tiegħek.",
+'anontalkpagetext'                 => "----''Din hija l-paġna ta' diskussjoni ta' dak l-utent anonimu li għadu ma ħoloqx kont, jew inkella li ma jużahx. 
+Għaldaqstant biex nidentifikawh ikollna nużaw l-indirizz tal-IP tiegħu.
+L-istess indirizz tal-IP jista' jkun użat minn bosta utenti differenti.
+Jekk int utent anonimu u tħoss li qiegħed tirċievi kummenti irrelevanti jew li ma jagħmlux sens, jekk jogħġbok [[Special:UserLogin|oħloq kont ġdid jew idħol]] sabiex tevita li fil-futur tiġi konfuż ma' utenti anonimi oħrajn.''",
 'noarticletext'                    => "Bħalissa m'hemmx test f'din il-paġna, inti tista' [[Special:Search/{{PAGENAME}}|tfittex it-titlu ta' din il-paġna]] f'paġni oħrajn jew [{{fullurl:{{FULLPAGENAME}}|action=edit}} tista' ukoll tagħmel modifiki lil din il-paġna].",
-'userpage-userdoesnotexist'        => 'Il-Kont tal-utent "$1" mhux reġistrat. Jekk jogħġbok ara jekk ma tridx toħloq/timodifika din il-paġna.',
-'clearyourcache'                   => "'''Nota - Wara li tagħmel il-modifiki, xi drabi jkollhok bżonn tħassar ''il-cache'' sabiex tkun tista' tara dawn il-modifiki.'''  '''Mozilla / Firefox / Safari:''' żomm ''Shift'' waqt li tkun qiegħed tagħfas ''Reload,'' jew agħfas ''Ctrl-F5'' jew ''Ctrl-R'' (''Command-R'' fuq \"Macintosh\"); '''Konqueror: '''agħfas ''Reload'' jew agħfas ''F5;''  '''Opera:''' ħassar il-cache fil-''Għodda → Preferenzi;'' '''Internet Explorer:''' żomm ''Ctrl'' waqt li tagħfas ''Refresh,'' jew agħfas ''Ctrl-F5.''",
-'usercssjsyoucanpreview'           => "<strong>Avviż:</strong> Uża l-buttuna 'Uri previżjoni' sabiex titestja CSS/JS ġodda qabel ma tagħmel il-modifiki.",
+'userpage-userdoesnotexist'        => 'Il-kont tal-utent "$1" mhux reġistrat. 
+Jekk jogħġbok, ara jekk verament tridx toħloq/timodifika din il-paġna.',
+'clearyourcache'                   => "'''Nota - Wara li tagħmel il-modifiki, xi drabi jkollok bżonn tħassar ''il-cache'' sabiex tkun tista' tara t-tibdil li sar.'''  '''Mozilla / Firefox / Safari:''' żomm ''Shift'' waqt li tkun qiegħed tagħfas ''Reload,'' jew agħfas ''Ctrl-F5'' jew ''Ctrl-R'' (''Command-R'' fuq \"Macintosh\"); '''Konqueror: '''agħfas ''Reload'' jew agħfas ''F5;''  '''Opera:''' ħassar il-cache fl-''Għodda → Preferenzi;'' '''Internet Explorer:''' żomm ''Ctrl'' waqt li tagħfas ''Refresh,'' jew agħfas ''Ctrl-F5.''",
+'usercssjsyoucanpreview'           => "<strong>Avviż:</strong> Uża l-buttuna 'Uri previżjoni' sabiex tittestja s-CSS/JS il-ġodda qabel ma tagħmel il-modifiki.",
 'usercsspreview'                   => "'''Ftakar li int qiegħed tara biss previżjoni tal-utent tiegħek tal-CSS, għad trid tiġi salvata!'''",
 'userjspreview'                    => "'''Ftakar li int qiegħed tara biss previżjoni tal-utent tiegħek tal-JavaScript, għad trid tiġi salvata!'''",
-'userinvalidcssjstitle'            => "'''Twissija:''' M'hemmx skin \"\$1\".
-Ftakar li paġni .css u .js jagħmlu użu minn titlu b'ittri żgħar, e.ż.{{ns:user}}:Foo/monobook.css huwa oppost minn {{ns:user}}:Foo/Monobook.css.",
-'updated'                          => '(Informata)',
+'userinvalidcssjstitle'            => "'''Twissija:''' M'hemm l-ebda skin bl-isem \"\$1\".
+Ftakar li l-paġni .css u .js personalizzati għandhom l-ewwel ittra tat-titlu żgħira, eż. {{ns:user}}:Foo/monobook.css u mhux {{ns:user}}:Foo/Monobook.css.",
+'updated'                          => '(Aġġornata)',
 'note'                             => '<strong>Nota:</strong>',
-'previewnote'                      => '<strong>Din hija previżjoni biss; il-modifiki għal paġna għadhom MHUX salvati!</strong>',
+'previewnote'                      => '<strong>Din hija previżjoni biss; il-modifiki li saru fil-paġna għadhom ma ġewx salvati!</strong>',
 'previewconflict'                  => "Din il-previżjoni turi l-kliem li jinsab fiż-żona ta' modifika superjuri u turi kif tidher kieku l-paġna kella tiġi modifikata.",
-'session_fail_preview'             => "<strong>Skuzana! Il-modifika tiegħek ma setgħatx tiġi proċessata minħabba telf ta' informazzjoni tas-sessjoni.
-Jekk jogħġbok erġa' prova. Jekk xorta ma taħdimx, prova oħroġ u erġa' itħol.</strong>",
-'session_fail_preview_html'        => "<strong>Skuzana! Il-modifika tiegħek ma setgħatx tiġi proċessata minħabba telf ta' informazzjoni tas-sessjoni.</strong>
+'session_fail_preview'             => "<strong>Jiddispjaċina imma l-modifika tiegħek ma setgħetx tiġi pproċessata minħabba li ntilfet l-informazzjoni tas-sessjoni.
+Jekk jogħġbok, erġa' pprova. Jekk xorta tibqa' ma taħdimx, ipprova oħroġ u erġa' idħol.</strong>",
+'session_fail_preview_html'        => "<strong>Jiddispjaċina imma l-modifika tiegħek ma setgħetx tiġi pproċessata minħabba li ntilfet l-informazzjoni tas-sessjoni.</strong>
 
-''Minħabba li {{SITENAME}} għanda l-HTML mixewla, l-previżjoni hija moħbija bħala prekawzjoni kontra l-attakki ta' JavaScript.''
+''Peress li f'{{SITENAME}} huwa possibbli l-użu ta' l-HTML mingħajr limitazzjonijiet (''raw HTML''), il-previżjoni tiġi moħbija bħala prekawzjoni kontra l-attakki tal-JavaScript.''
 
-<strong>Jekk dan huwa attentat leġittmu ta' modifika, jekk jogħġbok erġa' prova, prova oħroġ u erġa' idħol.</strong>",
+<strong>Jekk dan huwa attentat leġittmu ta' modifika, jekk jogħġbok erġa' pprova. Jekk tibqa' ma taħdimx, ipprova oħroġ u erġa' idħol.</strong>",
 'token_suffix_mismatch'            => "<strong>Il-modifika tiegħek ma ġietx aċċettata minħabba li klijent tiegħek tertaq l-karratri tal-ortografija fit-token tal-modifika.
 Din il-modifika ma ġietx aċċettata sabiex ma jkunx hemm żballji fit-test tal-paġna. Dan xi kultant jiġri minħabba li qiegħed tuża servizz difettuż anonimu li huwa bbażat fuq il-web ta' prokura.</strong>",
 'editing'                          => 'Qiegħed jiġi modifikat l-artiklu $1',
@@ -599,7 +603,7 @@
 'explainconflict'                  => "Xi ħadd modifika din il-paġna sakemm int kont qiegħed tagħmel il-modifiki. <br />
 Fiż-Żona tal-modifika superjuri jinsab il-kliem tal-paġna kif teżisti bħalissa, kif ġiet modifikata mill-utent l-ieħor. Il-Verżjoni bil-modifiki tiegħek jinsab fiż-żona ta' modifika inferjuri. Jekk trid il-modifiki tiegħek jiġu salvati, inti trid tgħaqqad il-modifiki tiegħek mat-test kif jeżisti bħalissa fiż-żona superjuri.
 Meta tagħfas ''Modifika'', se jiġi salvat '''biss''' it-test li jinsab fiż-żona superjuri.",
-'yourtext'                         => 'It-Test tiegħek',
+'yourtext'                         => 'It-test tiegħek',
 'storedversion'                    => 'Verżjoni mħażna',
 'nonunicodebrowser'                => "<strong>TWISSIJA: Il-Browser tiegħek m'għandux sapport għal unicode.
 Hemm xogħol sabiex iħallik tagħmel modifiki lil paġni mingħajr periklu ta' xejn: karratri li m'humiex ASCII se jidhru fil-kaxxa tal-modifika bħala kodiċi hexadeċimali.</strong>",
@@ -634,7 +638,7 @@
 'edittools'                        => '<!-- Kliem hawnhekk jidher taħt l-formuli tal-modifika u postjar. -->',
 'nocreatetitle'                    => 'Ħolqien tal-paġna limitata',
 'nocreatetext'                     => "{{SITENAME}} limitat l-abbilitá tal-ħolqien ta' paġni ġodda.
-Tista' tmur lura u tagħmel modifiki ta' paġni eżistenti, inkella [[Special:Userlogin|idħol jew oħloq kont ġdid]].",
+Tista' tmur lura u tagħmel modifiki ta' paġni eżistenti, inkella [[Special:UserLogin|idħol jew oħloq kont ġdid]].",
 'nocreate-loggedin'                => "M'għandhekx permess li toħloq paġni ġodda fuq {{SITENAME}}.",
 'permissionserrors'                => 'Problemi bil-permessi',
 'permissionserrorstext'            => "Inti m'għandhekx dritt li tagħmel hekk, għar-{{PLURAL:$1|raġuni|raġunijiet}} segwenti:",
@@ -660,24 +664,24 @@
 'undo-success' => "Din il-modifika tista' tiġi mneħħija. Jekk jogħġbok verifika il-paragun t'hawn taħt u verifika li dan huwa dak li trid int, imbgħad salva l-bidliet t'hawn taħt sabiex tlesti l-proċedura ta' tneħħija.",
 'undo-failure' => "Il-Modifika ma setgħatx tiġi mneħħija minħabba kunflitt ta' modifiki intermedji.",
 'undo-norev'   => 'Il-Modifika ma setgħatx tiġi mneħħija minħabba li ma teżistix jew ġiet imħassra.',
-'undo-summary' => "Neħħi r-reviżjoni $1 ta' [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskuti]])",
+'undo-summary' => "Neħħi r-reviżjoni $1 ta' [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussjoni]])",
 
 # Account creation failure
-'cantcreateaccounttitle' => 'Il-Kont ma jistax jiġi maħluq',
+'cantcreateaccounttitle' => 'Il-kont ma jistax jinħoloq',
 'cantcreateaccount-text' => "Ħolqien tal-kont ta' l-indirizz tal-IP ('''$1''') ġiet blokkata minn [[User:$3|$3]].
 
 Ir-raġuni li ġiet mogħtija mingħand $3 kienet ''$2''",
 
 # History pages
-'viewpagelogs'        => 'Uri l-logs għal din il-paġna',
+'viewpagelogs'        => "Ara r-reġistri ta' din il-paġna",
 'nohistory'           => "M'hemm l-ebda kronoloġija ta' modifika f'din il-paġna.",
 'revnotfound'         => 'Reviżjoni ma ġietx minsuba',
 'revnotfoundtext'     => "Ir-reviżjoni l-antika tal-paġna li staqsejt dwar ma setgħatx tiġi minsuba. Jekk jogħġbok verifika l-URL li użajt sabiex tidħol f'din il-paġna.",
 'currentrev'          => 'Reviżjoni kurrenti',
 'revisionasof'        => "Reviżjoni ta' $1",
 'revision-info'       => "Reviżjoni ta' $1 minn $2",
-'previousrevision'    => '←Reviżjoni preċedenti',
-'nextrevision'        => 'Reviżjoni segwenti→',
+'previousrevision'    => '←Reviżjoni eqdem',
+'nextrevision'        => 'Reviżjoni iġded→',
 'currentrevisionlink' => 'Reviżjoni kurrenti',
 'cur'                 => 'kur',
 'next'                => 'li jmiss',
@@ -741,45 +745,45 @@
 'deletedhist'                 => 'Kronoloġija mħassra',
 'revdelete-content'           => 'kontenut',
 'revdelete-summary'           => 'Taqsira tal-modifika',
-'revdelete-uname'             => 'isem tal-utent',
+'revdelete-uname'             => 'isem l-utent',
 'revdelete-restricted'        => "limiti applikati 'l amministraturi",
 'revdelete-unrestricted'      => "neħħi l-limiti 'l amministraturi",
 'revdelete-hid'               => 'aħbi $1',
-'revdelete-unhid'             => 'taħbix $1',
+'revdelete-unhid'             => 'uri $1',
 'revdelete-log-message'       => '$1 għal $2 {{PLURAL:$2|revision|reviżjoni}}',
 'logdelete-log-message'       => '$1 għal $2 {{PLURAL:$2|event|avvenimenti}}',
 
 # Suppression log
 'suppressionlog'     => "Log ta' ċaħdied",
 'suppressionlogtext' => "Il-lista ta' tħassir u blokjar tinsab hawn taħt din tinkludi kontenut li huwa moħbi mill-amministraturi.
-Ara [[Special:Ipblocklist|IP lista ta' blokjar]] għal lista ta' ċaħdiet u blokjar kurrenti.",
+Ara [[Special:IPBlockList|IP lista ta' blokjar]] għal lista ta' ċaħdiet u blokjar kurrenti.",
 
 # History merging
-'mergehistory'                     => 'agħqqad l-istorji tal-paġni',
-'mergehistory-header'              => "Din il-paġna tħallik tgħaqqad reviżjonijiet li huma tal-kronoloġija ta' paġna (magħrufa bħala paġna t'oriġini) mal-kronoloġija ta' paġna aktar riċenti.
-Huwa neċessarju li din il-bidla se tkompli l-kontinwitá tal-paġna storika.",
-'mergehistory-box'                 => 'Agħqqad ir-reviżjonijiet taż-żewġ paġni:',
-'mergehistory-from'                => 'Paġna tal-oriġini:',
-'mergehistory-into'                => 'Paġna tad-destinazzjoni:',
+'mergehistory'                     => 'Waħħad l-istorji tal-paġni',
+'mergehistory-header'              => "Din il-paġna tħallik twaħħad reviżjonijiet li jappartjenu lil kronoloġija ta' paġna (magħrufa bħala paġna t'oriġini) mal-kronoloġija ta' paġna aktar riċenti.
+Huwa importanti li l-kontinwità storika tal-paġna ma tiġix alterata.",
+'mergehistory-box'                 => 'Waħħad ir-reviżjonijiet taż-żewġ paġni:',
+'mergehistory-from'                => 'Il-paġna tal-oriġini:',
+'mergehistory-into'                => "Il-paġna ta' destinazzjoni:",
 'mergehistory-list'                => 'Kronoloġija tal-modifiki jistgħu jiġu uniti',
 'mergehistory-merge'               => "Ir-reviżjonijiet ta' [[:$1]] jistgħu jiġu magħquda f'[[:$2]].
 Uża l-kolonna tal-buttona tar-radju sabiex tgħaqqad biss dawk ir-reviżjonijiet li ħloqt f'ċerta ħin jew qabel ħin speċifiku.
 Nota li l-użu tal-links tan-navigazzjoni jagħmel reset tal-kolonna.",
 'mergehistory-go'                  => 'Uri modifiki li jistgħu jiġu magħquda',
-'mergehistory-submit'              => 'Agħqqad ir-reviżjonijiet',
+'mergehistory-submit'              => 'Waħħad ir-reviżjonijiet',
 'mergehistory-empty'               => "L-Ebda reviżjoni tista' tiġi magħquda.",
-'mergehistory-success'             => "$3 {{PLURAL:$3|revision|reviżjonijiet}} ta' [[:$1]] ngħaqqdu ma' [[:$2]] b'suċċess.",
-'mergehistory-fail'                => 'Mhux possibli tgħaqqad l-istorji, jekk jogħġbok verifika l-paġna u l-parametri tal-ħin.',
+'mergehistory-success'             => "$3 {{PLURAL:$3|reviżjoni|reviżjonijiet}} ta' [[:$1]] twaħħdu ma' [[:$2]] b'suċċess.",
+'mergehistory-fail'                => 'Mhux possibli li jitwaħħdu l-istejjer, jekk jogħġbok ivverifika l-paġna u l-parametri tal-ħin.',
 'mergehistory-no-source'           => 'Paġna tas-sors $1 ma teżistix.',
 'mergehistory-no-destination'      => 'Paġna tad-destinazzjoni $1 ma teżistix.',
 'mergehistory-invalid-source'      => 'Paġna tas-sors għanda jkollha titlu validu.',
 'mergehistory-invalid-destination' => 'Paġna tad-destinazzjoni għandu jkollu titlu validu.',
-'mergehistory-autocomment'         => "Għaqqad [[:$1]] f' [[:$2]]",
-'mergehistory-comment'             => "Għaqqad [[:$1]] f' [[:$2]]: $3",
+'mergehistory-autocomment'         => "[[:$1]] twaħħad ma' [[:$2]]",
+'mergehistory-comment'             => "[[:$1]] twaħħad ma' [[:$2]]: $3",
 
 # Merge log
-'mergelog'           => "Log ta' tgħaqqid",
-'pagemerge-logentry' => "għaqqad [[$1]] f' [[$2]] (reviżjonijiet sa $3)",
+'mergelog'           => "Reġistru ta' twaħħid",
+'pagemerge-logentry' => "waħħad [[$1]] ma' [[$2]] (reviżjonijiet sa $3)",
 'revertmerge'        => 'Infired',
 'mergelogpagetext'   => "Hawn taħt hawn lista ta' l-aktar tgħaqqid riċenti ta' paġna waħda ta' storja f'oħra.",
 
@@ -787,7 +791,7 @@
 'history-title'           => 'Storja ta\' reviżjoni ta\' "$1"',
 'difference'              => '(Differenzi bejn ir-reviżjonijiet)',
 'lineno'                  => 'Linja $1:',
-'compareselectedversions' => 'Paraguna verżjonijiet magħżula',
+'compareselectedversions' => 'Qabbel il-verżjonijiet magħżula',
 'editundo'                => 'ħassar',
 'diff-multi'              => '({{PLURAL:$1|One intermediate revision|$1 reviżjonijiet intermedji}} mhux qegħdin jidhru.)',
 
@@ -801,11 +805,11 @@
 'noexactmatch-nocreate'     => "'''M'hemmx paġna li jisima \"\$1\".'''",
 'toomanymatches'            => 'Ħafna tqabbil ġew ritornati, jekk jogħġbok prova inkjesta differenti',
 'titlematches'              => 'Titlu tal-paġna taqbel',
-'notitlematches'            => "L-Ebda titlu ta' paġna ġiet mqabbla",
+'notitlematches'            => "L-ebda titlu ta' paġna ma jaqbel",
 'textmatches'               => 'It-Test tal-paġna jaqbel',
-'notextmatches'             => "L-Ebda test ta' paġna ġiet mqabbla",
-'prevn'                     => 'preċedenti $1',
-'nextn'                     => 'segwenti $1',
+'notextmatches'             => "L-ebda test ta' paġna ma jaqbel",
+'prevn'                     => "$1 ta' qabel",
+'nextn'                     => '$1 li jmiss',
 'viewprevnext'              => 'Ara ($1) ($2) ($3)',
 'search-result-size'        => '$1 ({{PLURAL:$2|1 word|$2 kliem}})',
 'search-result-score'       => 'Relevanza: $1%',
@@ -831,17 +835,17 @@
 'powersearch-redir'         => "Lista ta' rindirizzi",
 'powersearch-field'         => 'Fittex',
 'search-external'           => 'Tfittxija esterna',
-'searchdisabled'            => "It-Tfittxija tal-{{SITENAME}} mhux attiva.
-Tista' tfittex bl-użu ta' Google għalissa.
-(Nota li l-indiċi ta' {{SITENAME}} preżenti jistgħu ma jkunux aġġornati.)",
+'searchdisabled'            => "It-Tfittxija fil-{{SITENAME}} mhux attiva.
+Sadanittant, tista' tipprova tfittex bil-Google.
+Innota però li l-werreja tal-kontenut ta' {{SITENAME}} f'dawn is-siti, jistgħu ma jkunux aġġornati.",
 
 # Preferences page
 'preferences'              => 'Preferenzi',
-'mypreferences'            => 'Preferenzi tiegħi',
+'mypreferences'            => 'Il-Preferenzi tiegħi',
 'prefs-edits'              => "Numru ta' modifiki:",
-'prefsnologin'             => "Mhux ''logged in''",
-'prefsnologintext'         => "Sabiex tkun tista' timodifika l-preferenzi huwa neċessarju li twettaq l-[[Special:Userlogin|aċċess]].",
-'prefsreset'               => 'Il-preferenzi ġew resetjati mill-ħażna.',
+'prefsnologin'             => 'Għadek ma dħaltx ġewwa',
+'prefsnologintext'         => "Sabiex tkun tista' timodifika l-preferenzi huwa neċessarju li twettaq l-[[Special:UserLogin|aċċess]].",
+'prefsreset'               => 'Il-preferenzi ġew irrisettjati għall-valuri predefiniti.',
 'qbsettings'               => "''Quickbar''",
 'qbsettings-none'          => 'Xejn',
 'qbsettings-fixedleft'     => 'Mehmuż fix-xellug',
@@ -873,7 +877,7 @@
 'resetprefs'               => 'Neħħi modifiki mhux salvati',
 'oldpassword'              => 'Password antika:',
 'newpassword'              => 'Password ġdida:',
-'retypenew'                => "Erġa' ikteb il-password ġdida:",
+'retypenew'                => "Erġa' ikteb il-password il-ġdida:",
 'textboxsize'              => 'Modifika',
 'rows'                     => 'Filieri:',
 'columns'                  => 'Kolonni:',
@@ -891,8 +895,8 @@
 'timezoneoffset'           => 'Differenza¹',
 'servertime'               => 'Ħin tas-server',
 'guesstimezone'            => "Uża l-ħin tal-''browser'' tiegħek",
-'allowemail'               => 'Faċċilita posta elettronika mingħand utenti oħrajn',
-'prefs-searchoptions'      => 'Preferenzi dwar tfittxija',
+'allowemail'               => 'Ħalli li jaslulek emails mingħand utenti oħrajn',
+'prefs-searchoptions'      => 'Preferenzi għat-tfittxija',
 'prefs-namespaces'         => 'Namespace',
 'defaultns'                => 'Namespace predefinit għat-tfittxija:',
 'default'                  => 'predefinit',
@@ -901,7 +905,7 @@
 # User rights
 'userrights'                  => "Treġija tal-permessi relativi 'l utenti", # Not used as normal message but as header for the special page itself
 'userrights-lookup-user'      => "Treġija tal-gruppijiet ta' utenti",
-'userrights-user-editname'    => 'Daħħal l-isem tal-utent:',
+'userrights-user-editname'    => 'Daħħal isem l-utent:',
 'editusergroup'               => "Modifika l-gruppijiet ta' l-utenti",
 'editinguser'                 => "Modifika tad-drittijiet tal-utent '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-editusergroup'    => "Modifika tal-gruppijiet ta' l-utenti",
@@ -912,10 +916,10 @@
 * Kaxxa bil-punta mhux magħżula tfisser li l-utent mhux fil-grupp
 * Il-Simbolu * jindika li mhux possibli telimina l-grupp wara jiġi maħluq (jew viċe versa)",
 'userrights-reason'           => 'Raġuni għal modifika:',
-'userrights-no-interwiki'     => "M'għandhekx il-permess li tagħmel modifiki fid-drittijiet tal-utenti fuq siti oħrajn.",
+'userrights-no-interwiki'     => "M'għandekx permess tagħmel modifiki fid-drittijiet tal-utenti fuq siti oħrajn.",
 'userrights-nodatabase'       => 'Id-Database $1 ma jeżistix jew inkella mhux database lokali.',
-'userrights-nologin'          => "Sabiex tkun tista' tagħti d-drittijiet lil utenti huwa neċessarju li [[Special:Userlogin|tidħol]] bħalha amministratur.",
-'userrights-notallowed'       => "L-Utent m'għandux permessi neċessarji sabiex ikun jista' jagħti drittijiet lil utenti.",
+'userrights-nologin'          => "Sabiex tkun tista' tagħti d-drittijiet lill-utenti hemm bżonn li [[Special:UserLogin|tidħol]] bħalha amministratur.",
+'userrights-notallowed'       => "M'għandekx permess tagħti drittijiet lill-utenti.",
 'userrights-changeable-col'   => "Gruppijiet f'liem tista' tagħmel modifiki",
 'userrights-unchangeable-col' => "Gruppijiet f'liem ma tistax tagħmel modifiki",
 
@@ -1025,7 +1029,7 @@
 'newpageletter'                     => 'Ġ',
 'boteditletter'                     => 'b',
 'number_of_watching_users_pageview' => '[osservat minn {{PLURAL:$1|utent $1|$1 utenti}}]',
-'rc_categories'                     => 'Limita l-kategoriji (separa b\' "|")',
+'rc_categories'                     => 'Illimita għall-kategoriji (issepara b\' "|")',
 'rc_categories_any'                 => 'Kwalunkwe',
 'newsectionsummary'                 => '/* $1 */ sezzjoni ġdida',
 
@@ -1035,42 +1039,43 @@
 'recentchangeslinked-noresult' => 'L-Ebda modifiki fuq paġni relatati waqt l-perjodu speċifiku.',
 'recentchangeslinked-summary'  => "Din il-paġna speċjali turi l-modifiki l-aktar riċenti f'paġni relatati għal dik speċifikata. Il-paġni osservati fil-[[Special:Watchlist|lista t'osservazzjoni]] huma markati '''arditi'''.",
 'recentchangeslinked-page'     => 'Isem tal-paġna:',
-'recentchangeslinked-to'       => 'Uri modifiki fil-paġni relatati għal dik speċifikata minflok',
+'recentchangeslinked-to'       => "Minflok, uri t-tibdiliet fil-paġni llinkjati ma' dik speċifikata",
 
 # Upload
 'upload'                      => "Tella' fajl",
 'uploadbtn'                   => "Tella' fajl",
 'reupload'                    => "Tella' mill-ġdid",
 'reuploaddesc'                => 'Mur lura għal formula',
-'uploadnologin'               => 'Aċċess mhux imwettaq',
-'uploadnologintext'           => "Sabiex il-fajl jiġu ''uploaded'' inti trid tkun [[Special:Userlogin|dħalt]] b'kont reġistrat.",
+'uploadnologin'               => 'Għadek ma dħaltx ġewwa',
+'uploadnologintext'           => "Sabiex il-fajl jiġu ''uploaded'' inti trid tkun [[Special:UserLogin|dħalt]] b'kont reġistrat.",
 'upload_directory_missing'    => "Id-Direttorju tal-''upload'' ($1) huwa nieqes u ma jistax jiġi maħluq mill-''webserver''.",
 'upload_directory_read_only'  => "Il-''Webserver'' m'għandux il-mezzi sabiex jikteb fil-direttorju tal-''upload'' ($1).",
 'uploaderror'                 => "Problema fl-''upload''",
-'uploadtext'                  => "Uża l-formula t'hawn taħt sabiex il-fajls jiġu ''uploaded''.
-Biex tara jew tfittex fajls li ġew ''uploaded'' mur fil- [[Special:Imagelist|lista ta' fajls ''uploaded'']], ''uploads'' u tħassir jiġu reġistrati wkoll fir-[[Special:Log/upload|reġistru tal-''upload'']].
+'uploadtext'                  => "Uża l-formula t'hawn taħt sabiex ittella' fajl.
+Biex tara jew tfittex fajls li ġew mtellgħin mur fil-[[Special:ImageList|lista ta' fajls mtellgħin]]. Fajls imtellgħin u verżjonijiet ġodda tal-fajls huma reġistrati fir-[[Special:Log/upload|reġistru ta' l-''uploads'']], u dawk li tħassru huma fir-[[Special:Log/upload|reġistru tat-tħassir]].
 
 Biex tinkludi fajl f'paġna, uża l-link fil-forma
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fajl.jpg]]</nowiki>''',
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''' jew
 * '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' biex toħloq link dirett għal fajl.",
 'upload-permitted'            => "Tipi ta' fajls permessi: $1.",
-'upload-preferred'            => "Tipi ta' fajls preferibbli: $1.",
-'upload-prohibited'           => "Tipi ta' fajls projbiti: $1.",
+'upload-preferred'            => "Tipi ta' fajls preferuti: $1.",
+'upload-prohibited'           => "Tipi ta' fajls projibiti: $1.",
 'uploadlog'                   => 'Reġistru tal-uploads',
-'uploadlogpage'               => "Log tal-fajls li ġew ''uploaded''",
-'uploadlogpagetext'           => "Ħawn taħt tinsab il-lista ta' l-aktar ''uploads'' ta' fajls riċenti.",
-'filename'                    => 'Isem tal-fajl',
+'uploadlogpage'               => "Reġistru tal-fajls li ġew imtella'",
+'uploadlogpagetext'           => "Ħawn taħt tinsab il-lista ta' l-aktar fajls imtellgħin riċenti.<br />
+Ara l-[[Special:NewImages|gallerija ta' fajls ġodda]] għal ħarsa viżiva.",
+'filename'                    => 'Isem il-fajl',
 'filedesc'                    => 'Taqsira',
 'fileuploadsummary'           => 'Taqsira:',
 'filestatus'                  => "Informazzjoni dwar il-''copyright'':",
 'filesource'                  => 'Oriġini:',
-'uploadedfiles'               => "Fajls li ġew ''uploaded''",
+'uploadedfiles'               => "Fajls li ġew mtella'",
 'ignorewarning'               => 'Injora twissiji u modifika l-fajl xorta waħda',
 'ignorewarnings'              => 'Injora kull twissija',
-'minlength1'                  => 'Ismijiet tal-fajls irridu jkunu mill-inqas ittra twila.',
+'minlength1'                  => "L-ismijiet tal-fajls għandhom ikunu ta' l-inqas ittra waħda.",
 'illegalfilename'             => 'L-Isem tal-fajl "$1" għandu karattri li mhux permessi fit-titli ta\' paġna. Jekk jogħġbok agħti isem ġdid lil fajl u prova tellgħu mill-ġdid.',
-'badfilename'                 => 'L-Isem tal-fajl ġie modifikat għal "$1".',
+'badfilename'                 => 'Isem il-fajl ġie mibdul għal "$1".',
 'filetype-badmime'            => "Mhux permess li fajls jiġu ''uploaded'' ta' tip MIME \"\$1\".",
 'filetype-unwanted-type'      => "'''\".\$1\"''' huwa tip ta' fajl mhux rikjest.
 {{PLURAL:\$3|Tip ta' fajl preferut huwa|Tipi ta' fajl preferuti huma}} \$2.",
@@ -1100,16 +1105,16 @@
 'fileexists-shared-forbidden' => "Fajl b'dan l-isem ġa jeżisti fl-arkivju ta' risorsi tal-fajls maqsuma. Jekk jogħġbok mur lura u tella' fajl b'isem ġdid. [[Image:$1|thumb|center|$1]]",
 'file-exists-duplicate'       => "Dan il-fajl huwa duplikat ta' {{PLURAL:$1|dan il-fajl|dawn il-fajls}} segwenti:",
 'successfulupload'            => "Mtella' b'suċċess",
-'uploadwarning'               => "Twissija dwar l-''upload''",
+'uploadwarning'               => 'Twissija dwar it-tlugħ tal-fajls',
 'savefile'                    => 'Salva l-fajl',
-'uploadedimage'               => 'Ġie mtella\' "[[$1]]"',
+'uploadedimage'               => 'tella\' "[[$1]]"',
 'overwroteimage'              => 'Verżjoni ġdida ġiet imtella\' "[[$1]]"',
 'uploaddisabled'              => "Skuzana, però ''uploads'' ta' fajls huwa temporalment sospiż.",
 'uploaddisabledtext'          => "''Uploads'' ta' fajls fuq {{SITENAME}} bħalissa mhux attiv.",
 'uploadscripted'              => "Dan il-fajl fih kodiċi ta' ''HTML'' u ''script'' li jista' jkun interpretat hażin mill-''web browser''.",
 'uploadcorrupt'               => "Dan il-fajl jidher li huwa maħruq jew għandu estenżjoni ħażina.
 Jekk jogħġbok verifika l-fajl u erġa' prova tellgħu.",
-'uploadvirus'                 => "Il-fajl fih ''virus''! Dettalji: $1",
+'uploadvirus'                 => "Dan il-fajl huwa infettat b'virus! Dettalji: $1",
 'sourcefilename'              => "L-Isem tal-fajl ta' l-oriġini:",
 'destfilename'                => 'L-Isem tal-fajl tad-destinazzjoni:',
 'upload-maxfilesize'          => 'Daqs massimu tal-fajl: $1',
@@ -1139,10 +1144,12 @@
 'upload-proto-error'      => 'Protocol ħażin',
 'upload-proto-error-text' => "Għal upload remote huwa neċessarju tispeċifika l-URL li jibda' b'<code>http://</code> jew <code>ftp://</code>.",
 'upload-file-error'       => 'Problema interna',
-'upload-file-error-text'  => "Kien hemm problema interna waqt il-ħolqien ta' fajl temporanju fuq is-server.
-Jekk jogħġbok agħmel kuntatt ma' amministratur tas-sistema.",
+'upload-file-error-text'  => "Kien hemm problema interna waqt il-ħolqien ta' fajl temporanju fuq is-server.<br />
+Jekk jogħġbok ikkuntatja lil xi [[Special:ListUsers/sysop|amministratur]].",
 'upload-misc-error'       => 'Problema tal-upload mhux magħrufa',
-'upload-misc-error-text'  => "Ġie verifikat problema mhux magħrufa waqt l-upload tal-fajl. Verifika li l-URL huwa tajjeb u tista' tidħol fih u erga' prova. Jekk il-problema tkompli, agħmel kuntatt ma' amministratur tas-sistema.",
+'upload-misc-error-text'  => "Waqt li l-fajl kien qed jittella', ġiet verifikata problema mhux magħrufha.<br />
+Ivverifika li l-URL huwa validu u aċċessibbli, u erġa' pprova.<br />
+Jekk il-problema tkompli tippersisti, ikkuntatja lil xi [[Special:ListUsers/sysop|amministratur]].",
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL mhux tajjeb',
@@ -1158,7 +1165,7 @@
 'upload_source_url'  => ' (URL validu u aċċessibli)',
 'upload_source_file' => ' (fajl fuq il-komputer tiegħek)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Din il-paġna speċjali turi l-fajls kollha mtella'.
 L-aktar ''uploads'' riċenti jiġu fuq in-naħa ta' fuq tal-lista.
 Biex tagħmel modifika fl-ordni tal-kolonna, klikkja fuq it-titlu tal-kolonna stess.",
@@ -1186,7 +1193,7 @@
 'imagelinks'                     => 'Links għas-stampi',
 'linkstoimage'                   => '{{PLURAL:$1|Il-Paġna segwenti għandha|Il-$1 paġni segwenti għandhom}} links għal-fajl:',
 'nolinkstoimage'                 => "M'hemmx paġni li huma relatati ma' dan il-fajl.",
-'morelinkstoimage'               => 'Uri [[Special:Whatlinkshere/$1|aktar links]] għal dan il-fajl.',
+'morelinkstoimage'               => 'Uri [[Special:WhatLinksHere/$1|aktar links]] għal dan il-fajl.',
 'redirectstofile'                => '{{PLURAL:$1|Il-fajl segwenti huwa rindirizzat|Il-$1 fajls segwenti huma rindirizzati}} għal dan il-fajl.',
 'duplicatesoffile'               => "{{PLURAL:$1|Il-fajl segwenti huwa duplikat|Il-$1 fajls segwenti huma duplikati}} ta' dan il-fajl:",
 'sharedupload'                   => "Dan il-fajl huwa upload li jista' jiġi użat fuq proġetti tal-wiki oħrajn.",
@@ -1205,18 +1212,18 @@
 # File reversion
 'filerevert'                => 'Ġib lura $1',
 'filerevert-legend'         => "Erġa' lura għall-fajl",
-'filerevert-intro'          => '<span class="plainlinks">Inti qiegħed terġa lura għal fajl \'\'\'[[Media:$1|$1]]\'\'\' fil-[verżjoni $4 minn $3, $2].</span>',
+'filerevert-intro'          => "Inti qiegħed terġa lura għal fajl '''[[Media:$1|$1]]''' fil-[verżjoni $4 minn $3, $2].",
 'filerevert-comment'        => 'Kumment:',
 'filerevert-defaultcomment' => "Mort lura għal verżjoni ta' $2, $1",
 'filerevert-submit'         => 'Ġib lura',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'Il-Fajl [[Media:$1|$1]]\'\'\' ġie restorat għal [verżjoni $4 minn $3, $2].</span>',
+'filerevert-success'        => "'''Il-Fajl [[Media:$1|$1]]''' ġie restorat għal [verżjoni $4 minn $3, $2].",
 'filerevert-badversion'     => "M'hemmx verżjoni lokali tal-fajl aktar riċenti b'timbru tal-ħin rikjest.",
 
 # File deletion
 'filedelete'                  => 'Ħassar $1',
-'filedelete-legend'           => 'Ħassar fajl',
+'filedelete-legend'           => 'Ħassar il-fajl',
 'filedelete-intro'            => "Inti se tħassar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Se tħassar il-verżjoni ta\' \'\'\'[[Media:$1|$1]]\'\'\' - [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Se tħassar il-verżjoni ta' '''[[Media:$1|$1]]''' - [$4 $3, $2].",
 'filedelete-comment'          => 'Raġuni għat-tħassir:',
 'filedelete-submit'           => 'Ħassar',
 'filedelete-success'          => "'''$1''' ġie mħassar.",
@@ -1260,16 +1267,16 @@
 # Statistics
 'statistics'             => 'Statistiċi',
 'sitestats'              => "Statistiċi relativi ta' {{SITENAME}}",
-'userstats'              => 'Statistiċi tal-utent',
-'sitestatstext'          => "Id-Database komplessament fija '''$1''' {{PLURAL:$1|paġna|paġni}}.
-Din iċ-ċifra  tinkludi wkoll paġni ta' diskussjoni, paġni dwar {{SITENAME}}, paġni magħrufa bħalha stubs, rindirizzi u paġni oħrajn probabilment li mhux konsidrati parti mill-kontenut tas-sit. Jekk teskludi dan probabilment hemm {{PLURAL:$2|paġna li hija konsidrata leġitima u propja|'''$2''' paġni li huma konsidrati leġitimi u propji}}
+'userstats'              => 'Statistika tal-utent',
+'sitestatstext'          => "B'kollox hemm '''$1''' paġna fil-bankadati.
+Dan in-numru jinkludi wkoll il-paġni ta' diskussjoni, paġni dwar il-{{SITENAME}}, paġni b'informazzjoni minima (''stubs''), riindirizzamenti u paġni oħrajn li probabilment ma jikkwalifikawx bħala paġni b'kontenut. Jekk tneħħi dawk, b'kollox hemm '''$2''' paġni li probabilment huma paġni b'kontenut leġittimu.
 
-{{PLURAL:$8|B'hekk ġew imtella'|B'hekk ġew imtellajn}} '''$8''' fajls.
+'''$8''' fajl ġew imtella'.
 
-Mill-installazjoni tas-sit sa dan il-mument is-sit {{PLURAL:$3|ġiet viżitata paġna waħda|ġew viżitati '''$3''' paġni}} u kien hemm {{PLURAL:$4|modifika waħda|'''$4''' modifiki}}, b'hekk kien hemm medja ta' modifiki għal kull paġna ta' '''$5''' u medja ta' qarrejja għal kull modifika ta' '''$6'''. 
+Minn meta ġie installat is-sit s'issa, inżaru '''$3''' paġna u kien hemm '''$4''' modifika. Din hija ekwivalenti għal medja ta' '''$5''' modifiki għal kull paġna, u medja ta' '''$6''' qarrejja għa' kull modifika. 
 
-Il-Kju tal-proċessi fih {{PLURAL:$7|element wieħed|'''$7''' elementi}}.",
-'userstatstext'          => "F'dan il-mument {{PLURAL:$1|[[Special:Listusers|utent]] wieħed biss reġistrat|'''$1''' [[Special:Listusers|utenti]] reġistrati}}. Il-grupp $5  huwa kompost minn '''$2''' {{PLURAL:$2|utent|utenti}}, jew '''$4%''' tar-reġistrati.",
+Il-kju ta' xogħolijiet fih '''$7''' elementi.",
+'userstatstext'          => "F'dan il-mument {{PLURAL:$1|[[Special:ListUsers|utent]] wieħed biss reġistrat|'''$1''' [[Special:ListUsers|utenti]] reġistrati}}. Il-grupp $5  huwa kompost minn '''$2''' {{PLURAL:$2|utent|utenti}}, jew '''$4%''' tar-reġistrati.",
 'statistics-mostpopular' => 'L-Aktar paġni visitati',
 
 'disambiguations'      => "Paġni ta' diżambigwazzjoni",
@@ -1277,8 +1284,9 @@
 'disambiguations-text' => "Il-Paġni li jinsabu f'din lista huma parti minn '''paġna ta' diżambigwazzjoni''' b'hekk għandhom jiġu relatati mas-suġġett preċiż minflok. <br />
 Paġna tiġi stimata paġna ta' diżambigwazzjoni dawk kollha li jagħmlu użu mit-template elenkat f'[[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Rindirizzi doppji',
-'doubleredirectstext' => '<b>Twissija:</b> Din il-paġna tagħmel lista tal-paġni li jiġu rindirizzati f\'paġni li jiġu rindirizzati mill-ġdid. Kull filiera għandha links għall-ewwel u t-tieni rindirizz, kif ukoll fejn tirindirizza t-tieni paġna, is-soltu magħrufa bħalha l-paġna "reali" fejn se twassal, fejn l-ewwel rindirizz għandu jipponta.',
+'doubleredirects'            => 'Rindirizzi doppji',
+'doubleredirectstext'        => '<b>Twissija:</b> Din il-paġna tagħmel lista tal-paġni li jiġu rindirizzati f\'paġni li jiġu rindirizzati mill-ġdid. Kull filiera għandha links għall-ewwel u t-tieni rindirizz, kif ukoll fejn tirindirizza t-tieni paġna, is-soltu magħrufa bħalha l-paġna "reali" fejn se twassal, fejn l-ewwel rindirizz għandu jipponta.',
+'double-redirect-fixed-move' => '[[$1]] ġie mmexxi awtomatikament, issa hu rindirizz għal [[$2]]',
 
 'brokenredirects'        => 'Rindirizzi ħżiena',
 'brokenredirectstext'    => 'Il-Rindirizzi segwenti għandhom links għal paġni ineżistenti:',
@@ -1308,17 +1316,17 @@
 'uncategorizedtemplates'  => 'Templates mhux kategorizati',
 'unusedcategories'        => 'Kategoriji mhux użati',
 'unusedimages'            => 'Fajls mhux użati',
-'popularpages'            => 'Paġni l-aktar viżitati',
+'popularpages'            => 'L-iktar paġni popolari',
 'wantedcategories'        => 'Kategoriji rikjesti',
 'wantedpages'             => 'Paġni rikjesti',
-'missingfiles'            => 'Fajls nieqsin',
-'mostlinked'              => 'L-Aktar paġni li għandhom links',
-'mostlinkedcategories'    => 'Kategoriji li għandhom l-aktar links',
-'mostlinkedtemplates'     => 'Templates li għandhom l-aktar links',
-'mostcategories'          => 'Paġni bl-aktar kategoriji',
-'mostimages'              => 'Fajls li għandhom l-aktar links',
-'mostrevisions'           => 'Paġni bl-aktar reviżjonijiet',
-'prefixindex'             => 'Indiċi tal-prefissi',
+'missingfiles'            => 'Fajls neqsin',
+'mostlinked'              => "Paġni bl-ikbar numru ta' links li jwasslu għalihom",
+'mostlinkedcategories'    => "Kategoriji bl-ikbar numru ta' links li jwasslu għalihom",
+'mostlinkedtemplates'     => 'L-iktar mudelli wżati',
+'mostcategories'          => "Paġni bl-ikbar numru ta' kategoriji",
+'mostimages'              => "Fajls bl-ikbar numru ta' links li jwasslu għalihom",
+'mostrevisions'           => "Paġni bl-ikbar numru ta' reviżjonijiet",
+'prefixindex'             => 'Werrej',
 'shortpages'              => 'Paġni qosra',
 'longpages'               => 'Paġni twal',
 'deadendpages'            => 'Paġni bla ħruġ',
@@ -1332,7 +1340,7 @@
 'protectedtitlesempty'    => "L-Ebda titli bħalissa huma protetti b'dawn il-parametri.",
 'listusers'               => 'Lista tal-utenti',
 'newpages'                => 'Paġni l-aktar riċenti',
-'newpages-username'       => 'L-Isem tal-utent:',
+'newpages-username'       => 'Isem l-utent:',
 'ancientpages'            => 'Paġni l-inqas riċenti',
 'move'                    => 'Ċaqlaq',
 'movethispage'            => 'Ċaqlaq din il-paġna',
@@ -1360,21 +1368,21 @@
 'all-logs-page'        => 'Ir-Reġistri kollha',
 'log-search-legend'    => 'Fittex logs',
 'log-search-submit'    => 'Mur',
-'alllogstext'          => "Preżentazzjoni unifikata tal-logs relativi fl-operazzjonijiet tal-upload, tħassir, protezzjoni, blokki u amministrazzjoni tas-sit. Tista' ddejjaq l-viżta billi tagħżel tip ta' log, l-isem tal-utent, jew il-paġna affetwata.",
+'alllogstext'          => "Preżentazzjoni unifikata tar-reġistri relattivi għall-operazzjonijiet tal-upload, tħassir, protezzjoni, blokki u amministrazzjoni tas-sit. Tista' ddejjaq il-kriterji ta' riċerka billi tagħżel it-tip ta' reġistru, isem l-utent jew il-paġna affetwata.",
 'logempty'             => "Il-Log m'għandux elementi korrespondenti mat-tfittxija tiegħek.",
 'log-title-wildcard'   => "Tfittxija ta' titli li jibdew b'dan it-test",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Il-Paġni kollha',
 'alphaindexline'    => 'minn $1 sa $2',
-'nextpage'          => 'Paġna segwenti ($1)',
-'prevpage'          => 'Paġna preċedenti ($1)',
+'nextpage'          => 'Il-paġna li jmiss ($1)',
+'prevpage'          => "Il-paġna ta' qabel ($1)",
 'allpagesfrom'      => 'Uri l-paġni li jibdew minn:',
 'allarticles'       => 'L-Artikli kollha',
 'allinnamespace'    => 'Il-Paġni kollha tan-namespace $1',
-'allnotinnamespace' => 'Il-Paġni kollha, minbarra dawk tan-namespace $1',
-'allpagesprev'      => 'Preċedenti',
-'allpagesnext'      => 'Segwenti',
+'allnotinnamespace' => 'Il-paġni kollha, minbarra dawk tan-namespace $1',
+'allpagesprev'      => "Ta' qabel",
+'allpagesnext'      => 'Li jmiss',
 'allpagessubmit'    => 'Mur',
 'allpagesprefix'    => 'Uri l-paġni bil-prefiss:',
 'allpagesbadtitle'  => "It-Titlu indikat għal paġna mhux validu jew fih prefissi inter-lingwali jew interwiki. Jista' għalhekk ikun fih wieħed jew aktar karratri li ma jistgħux jintużaw fit-titli.",
@@ -1387,15 +1395,15 @@
 'special-categories-sort-count' => 'ordna skond in-numru',
 'special-categories-sort-abc'   => 'ordna skond l-alfabett',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Uri utenti minn:',
 'listusers-submit'   => 'Uri',
 'listusers-noresult' => 'l-Ebda utent insab għal din il-kriterja.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Drittijiet tal-grupp ta' l-utenti",
-'listgrouprights-summary'  => "Il-Lista segwenti hija dwar gruppijiet ta' l-utenti tal-wiki, bl-aċċess tad-drittijiet assoċjati. 
-Aktar informazzjoni dwar drittijiet tal-individwi jista' jinsab [[{{MediaWiki:Listgrouprights-helppage}}]].",
+'listgrouprights-summary'  => "Il-lista segwenti hija dwar gruppi ta' l-utenti għal din il-wiki, bl-aċċess tad-drittijiet assoċjati.<br />
+Aktar informazzjoni dwar drittijiet tal-individwi tista' tinstab fuq [[{{MediaWiki:Listgrouprights-helppage}}]].",
 'listgrouprights-group'    => 'Grupp',
 'listgrouprights-rights'   => 'Drittijiet',
 'listgrouprights-helppage' => 'Help:Drittijiet tal-grupp',
@@ -1403,11 +1411,11 @@
 
 # E-mail user
 'mailnologin'     => 'L-Ebda indirizz tal-posta',
-'mailnologintext' => "Sabiex tkun tista' tibgħat posta elettronika 'l utenti oħrajn huwa neċessarju li [[Special:Userlogin|tidħol fis-sit]] bħalha utent reġistrat u jkollhok indirizz validu fil-[[Special:Preferences|preferenzi]] tiegħek.",
+'mailnologintext' => "Sabiex tkun tista' tibgħat posta elettronika 'l utenti oħrajn huwa neċessarju li [[Special:UserLogin|tidħol fis-sit]] bħalha utent reġistrat u jkollhok indirizz validu fil-[[Special:Preferences|preferenzi]] tiegħek.",
 'emailuser'       => 'Ikteb lil dan l-utent',
 'emailpage'       => 'Ibgħat messaġġ lil dan l-utent bil-posta elettronika',
-'emailpagetext'   => 'Jekk dan l-utent daħħal indirizz tal-posta elettronika valida fil-preferenzi tal-utent tiegħu, l-formula t\'hawn se tintbgħat bħalha messaġġ waħdu. 
-L-Indirizz tal-posta elettronika li daħħalt fil-preferenzi tal-utent se jidher bħalha l-indirizz "Minn" fil-messaġġ, għalhekk dak li jirċievi jkun jista\' jagħtik risposta.',
+'emailpagetext'   => "Jekk dan l-utent daħħal indirizz tal-posta elettronika validu fil-preferenzi ta' l-utent tiegħu, l-formula t'hawn se tintbgħat bħala messaġġ waħdu.<br />
+L-indirizz tal-posta elettronika li daħħalt fil-preferenzi ta' l-utent se jidher fl-ispazju \"Minn:\" tal-messaġġ, biex dak li jirċievi l-messaġġ ikun jista'jagħtik risposta.",
 'usermailererror' => 'L-oġġett tal-posta ta l-problema:',
 'defemailsubject' => 'Messaġġ minn {{SITENAME}}',
 'noemailtitle'    => 'L-Ebda indirizz tal-posta elettronika',
@@ -1424,31 +1432,33 @@
 'emailuserfooter' => 'Din il-posta elettronika intbgħattet minn $1 lil $2 bil-"Utent tal-posta elettronika" funżjoni ta\' {{SITENAME}}.',
 
 # Watchlist
-'watchlist'            => 'Osservazzjoni speċjali',
-'mywatchlist'          => 'Osservazzjoni speċjali',
+'watchlist'            => 'Li qed insegwi',
+'mywatchlist'          => 'Li qed insegwi',
 'watchlistfor'         => "(għal '''$1''')",
-'nowatchlist'          => "Il-Lista t'osservazzjoni tiegħek hija vojta.",
-'watchlistanontext'    => "Sabiex tara u timodifika oġġetti fil-lista ta' osservazzjoni tiegħek huwa neċessarji li $1.",
-'watchnologin'         => 'Aċċess mhux imwettaq',
-'watchnologintext'     => "Biex tagħmel modifika fil-lista t'osservazzjoni speċjali huwa neċessarju li l-ewwel [[Special:Userlogin|tidħol]] fil-kont tiegħek.",
-'addedwatch'           => "Żdidet fil-lista t'osservazzjoni",
-'addedwatchtext'       => "Il-Paġna \"[[:\$1]]\" inżdidet fil-[[Special:Watchlist|lista t'osservazzjoni]].
-Minn issa l-quddiem, modifiki f'din il-paġna u fid-diskussjoni tagħha jiġu reġistrati hawnhekk, u il-paġna se tidher '''ardita''' fil-[[Special:Recentchanges|lista ta' modifiki riċenti]] sabiex tkun aktar faċċli biex tinsab.",
+'nowatchlist'          => "Il-lista ta' osservazzjoni tiegħek hija vojta.",
+'watchlistanontext'    => "Sabiex tara u timmodifika l-lista ta' osservazzjoni tiegħek, hemm bżonn li $1.",
+'watchnologin'         => 'Għadek ma dħaltx ġewwa',
+'watchnologintext'     => "Biex tagħmel modifika fil-lista t'osservazzjoni speċjali huwa neċessarju li l-ewwel [[Special:UserLogin|tidħol]] fil-kont tiegħek.",
+'addedwatch'           => "Il-paġna ġiet miżjuda mal-lista ta' osservazzjoni",
+'addedwatchtext'       => "Il-paġna \"[[:\$1]]\" ġiet miżjuda mal-[[Special:Watchlist|lista ta' osservazzjoni]] tiegħek.
+Minn issa 'l quddiem, il-modifiki f'din il-paġna u fil-paġna ta' diskussjoni tagħha jiġu rreġistrati hawnhekk, u l-paġna tibda tidher b'tipa '''ħoxna''' fil-[[Special:RecentChanges|lista ta' modifiki riċenti]] sabiex tinsab iktar faċilment.
+
+Jekk f'xi ħin tkun tixtieq tneħħi l-paġna mil-lista ta' osservazzjoni tiegħek, kemm tagħfas fuq \"tibqax issegwi\" li tinsab fl-iżbarra ta' fuq.",
 'removedwatch'         => "Mneħħija mil-lista t'osservazzjoni",
-'removedwatchtext'     => 'Il-Paġna "[[:$1]]" ġiet eliminata mill-lista t\'osservazzjoni speċjali.',
+'removedwatchtext'     => 'Il-paġna "[[:$1]]" ġiet imneħħiha mil-lista t\'osservazzjoni tiegħek.',
 'watch'                => 'Osserva',
 'watchthispage'        => 'Osserva din il-paġna',
 'unwatch'              => 'Tibqax tosserva',
 'unwatchthispage'      => 'Ieqaf osserva',
 'notanarticle'         => 'Din il-paġna mhux artiklu',
-'notvisiblerev'        => 'Reviżjoni ġiet imħassra',
-'watchnochange'        => 'L-Ebda mill-paġni osservati tiegħek ġew modifikati fil-ħin stipulat.',
-'watchlist-details'    => "Il-Lista t'osservazzjoni speċjali fija {{PLURAL:$1|paġna waħda (u il-paġna rispettiva ta' diskussjoni tagħha)|$1 paġni (u il-paġni rispettivi tagħhom)}}.",
-'wlheader-enotif'      => '* Notifikazzjoni bl-użu tal-posta elettronika huwa attiv.',
-'wlheader-showupdated' => "* Paġni li kienu modifikati mill-aħħar viżita tiegħek huma mogħrija b'mod '''ardit'''",
+'notvisiblerev'        => 'Ir-reviżjoni tħassret',
+'watchnochange'        => 'L-ebda waħda mill-paġni osservati tiegħek ma ġiet modifikata fil-ħin stipulat.',
+'watchlist-details'    => "Il-lista ta' osservazzjoni fiha {{PLURAL:$1|paġna waħda (u l-paġna ta' diskussjoni tagħha)|$1 paġni (u l-paġni ta' diskussjoni tagħhom)}}.",
+'wlheader-enotif'      => '* In-notifikazzjoni bl-użu tal-posta elettronika hija attivata.',
+'wlheader-showupdated' => "* Il-paġni li raw xi tibdil mill-aħħar vista tiegħek qed jiġu murija b'tipa '''ħoxna'''",
 'watchmethod-recent'   => "Kontroll ta' modifiki riċenti għall-osservati speċjali.",
 'watchmethod-list'     => 'Kontroll tal-osservati speċjali għal modifiki riċenti',
-'watchlistcontains'    => "Il-Lista t'osservazzjoni fija {{PLURAL:$1|paġna|$1 paġni}}.",
+'watchlistcontains'    => "Il-lista ta' osservazzjoni fiha {{PLURAL:$1|paġna|$1 paġni}}.",
 'iteminvalidname'      => "Problema bil-paġna'$1', l-isem mhux validu...",
 'wlnote'               => "Hawn taħt hawn {{PLURAL:$1|l-aħħar modifika|l-aħħar '''$1''' modifiki}} fl-aħħar {{PLURAL:$2|siegħa|'''$2''' siegħat}}.",
 'wlshowlast'           => 'Uri l-aħħar $1 siegħat $2 ġranet $3',
@@ -1498,7 +1508,7 @@
 
 # Delete/protect/revert
 'deletepage'                  => 'Ħassar il-paġna',
-'confirm'                     => 'Konferma',
+'confirm'                     => 'Ikkonferma',
 'excontent'                   => "kontenut kien: '$1'",
 'excontentauthor'             => "kontenut kien: '$1' (u l-unika kontributur kien '[[Special:Contributions/$2|$2]]')",
 'exbeforeblank'               => "kontenut qabel ma ġie żvojtjat kien: '$1'",
@@ -1507,7 +1517,7 @@
 'delete-legend'               => 'Ħassar',
 'historywarning'              => 'Twissija: Il-paġna li se tħassar għanda kronoloġija:',
 'confirmdeletetext'           => "Int se tħassar permanentament mid-database paġna jew stampa, flimkien mal-kronoloġija kollha tagħha. Jekk jogħġbok, konferma li hija x-xewqa tiegħek li tkompli bit-tħassir ta' din il-paġna, u tifhem il-konsegwenzi ta' li qiegħed tagħmel, u li qiegħed tagħmilhom skond il- [[{{MediaWiki:Policy-url}}|politika]] stabilita.",
-'actioncomplete'              => 'Azzjoni kompleta',
+'actioncomplete'              => 'Azzjoni mwettqa',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" ġiet imħassra.
 Ara $2 biex tara paġni mħassra riċentament.',
 'deletedarticle'              => 'ħassart "[[$1]]"',
@@ -1518,7 +1528,7 @@
 'reverted'                    => 'Mort lura għal verżjoni preċedenti',
 'deletecomment'               => 'Raġuni dwar it-tħassir:',
 'deleteotherreason'           => 'Raġuni oħrajn:',
-'deletereasonotherlist'       => 'Raġuni oħrajn',
+'deletereasonotherlist'       => 'Raġuni oħra',
 'deletereason-dropdown'       => "*Raġunijiet ta' tħassir komuni
 ** Rikjesta tal-awtur
 ** Vjolazzjoni tal-copyright
@@ -1533,9 +1543,9 @@
 'rollbacklink'                => 'rollback',
 'rollbackfailed'              => 'Rollback ma ħadmitx',
 'cantrollback'                => 'Impossibli tħassar il-modifiki; l-utent li wettaqhom huwa l-unika li għamel kontributi lil din il-paġna.',
-'alreadyrolled'               => "Mhux possibli li tneħħi l-modifiki fil-paġna [[:$1]] ta' [[User:$2|$2]] ([[User talk:$2|Talk]]); utent ieħor ġa għamel modifika lil paġna jew inkella wettaq rollback.
+'alreadyrolled'               => "Mhux possibbli li tneħħi l-modifiki ta' [[User:$2|$2]] ([[User talk:$2|diskussjoni]]) fil-paġna [[:$1]]; utent ieħor diġà immodifika din il-paġna jew inkella reġġa' lura.
 
-Il-modifika l-aktar riċenta lil paġna saret minn [[User:$3|$3]] ([[User talk:$3|Talk]]).",
+L-iktar modifika riċenti fuq dil-paġna saret minn [[User:$3|$3]] ([[User talk:$3|diskussjoni]]).",
 'editcomment'                 => 'Il-Kumment tal-modifika kienet: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => "Modifiki mneħħa minn [[Special:Contributions/$2|$2]] ([[User talk:$2|Talk]]) għall-aħħar verżjoni ta' [[User:$1|$1]]", # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => "Modifiki mneħħa ta' $1;
@@ -1543,12 +1553,12 @@
 'sessionfailure'              => "Ġie verifikat problema fis-sessjoni tal-aċċess; din l-azzjoni ġiet imħassra bħalha prekawzjoni. Mur lura fil-paġna preċedenti bl-użu tal-buttuna 'Lura' tal-browser, niżżel il-paġna mill-ġdid u erġa' prova.",
 'protectlogpage'              => 'Protezzjoni',
 'protectlogtext'              => "Hawn taħt hawn lista ta' l-azzjonijiet tal-protezzjoni u żblokki tal-paġna.
-Ara [[Special:Protectedpages|l-lista ta' paġni protetti]] għal lista ta' paġni bħalissa protetti.",
+Ara [[Special:ProtectedPages|l-lista ta' paġni protetti]] għal lista ta' paġni bħalissa protetti.",
 'protectedarticle'            => '"[[$1]]" huwa protett',
 'modifiedarticleprotection'   => 'modifikajt il-livell ta\' protezzjoni għal "[[$1]]"',
-'unprotectedarticle'          => 'żblokkajt "[[$1]]"',
+'unprotectedarticle'          => 'żblokkjajt "[[$1]]"',
 'protect-title'               => 'Modifika livell ta\' protezzjoni ta\' "$1"',
-'protect-legend'              => 'Konferma l-protezzjoni',
+'protect-legend'              => 'Ikkonferma l-protezzjoni',
 'protectcomment'              => 'Kumment:',
 'protectexpiry'               => 'Jiskadi:',
 'protect_expiry_invalid'      => 'Skadenza mhux valida.',
@@ -1565,7 +1575,7 @@
 'protect-level-autoconfirmed' => 'Utenti reġistrati biss',
 'protect-level-sysop'         => 'Amministraturi biss',
 'protect-summary-cascade'     => 'rikorsiv',
-'protect-expiring'            => 'skadenza: $1 (UTC)',
+'protect-expiring'            => 'jiskadi $1 (UTC)',
 'protect-cascade'             => "Protezzjoni rikorsiva (testendi l-protezzjoni 'l paġni kollha inklużi f'din il-paġna).",
 'protect-cantedit'            => "Ma tistax timodifika l-livelli ta' protezzjoni ta' din il-paġna, għax int m'għandhekx il-permessi neċessarji.",
 'restriction-type'            => 'Permess:',
@@ -1586,15 +1596,15 @@
 'restriction-level-all'           => 'kull livell',
 
 # Undelete
-'undelete'                     => 'Uri paġni mħassra',
-'undeletepage'                 => 'Uri u irkupra paġni mħassra',
+'undelete'                     => 'Ara l-paġni mħassra',
+'undeletepage'                 => 'Ara u rkupra l-paġni mħassra',
 'undeletepagetitle'            => "'''Hawn jinsabu reviżjonijiet imħassra ta' [[:$1|$1]]'''.",
-'viewdeletedpage'              => 'Uri paġni mħassra',
+'viewdeletedpage'              => 'Ara l-paġni mħassra',
 'undeletepagetext'             => 'Il-Paġni indikati ġew imħassra, però għadhom fl-arkivju u għalhekk jistgħu jiġu irkuprati.
 L-Arkivju huwa perjodikament imnadaf.',
 'undelete-fieldset-title'      => 'Irkupra reviżjonijiet',
-'undeleteextrahelp'            => "Biex tirkupra l-paġna sħiħa, ħalli l-kaxxi kollha vojta u klikja fuq '''''Irkupra'''''.
-Biex tirkupra xi ħaġa speċifika, agħżel il-kaxxi korrespondenti mar-reviżjonijiet li għandhom jiġu rkuprati, u agħfas '''''Irkupra'''''. Jekk tagħfas '''''Resetja''''' l-kaxxi kollha jiġu mill-ġdid vojta u l-post fejn tikteb il-kummenti jitħassar.",
+'undeleteextrahelp'            => "Biex tirkupra l-paġna sħiħa, ħalli l-kaxxi kollha vojta u kklikkja fuq '''''Irkupra'''''.
+Biex tirkupra partijiet speċifiċi, agħżel il-kaxxi korrispondenti mar-reviżjonijiet li tixtieq tirkupra u agħfas '''''Irkupra'''''. Jekk tagħfas '''''Irrisettja''''', kemm il-kaxxi kif ukoll l-ispazju għall-kummenti jiżvujtjaw.",
 'undeleterevisions'            => '{{PLURAL:$1|reviżjoni|$1 reviżjonijiet}} fl-arkivju',
 'undeletehistory'              => 'Jekk tirkupra l-paġna, ir-reviżjonijiet kollha jiġu mdaħħla mill-ġdid fil-kronoloġija relativa. Jekk wara t-tħassir paġni ġodda jiġi maħluqa bl-istess titlu, r-reviżjonijiet irkuprati jiġu jidhru fil-kronoloġija preċedenti. Nota wkoll li limitazzjonijiet fuq reviżjonijiet tal-fajl huwa mitlufa waqt li jiġi rkuprati.',
 'undeleterevdel'               => "Jekk il-parti ta' fuq tal-paġna jew ir-reviżjoni tal-fajl huma parzjalment imħassra, l-proċess ta' irkuprar ma ssirx. F'dawn il-każi, int trid ma taħbiex jew ma tagħżilx ir-reviżjoni mħassra l-aktar riċenti.",
@@ -1603,17 +1613,17 @@
 'undelete-revision'            => 'Reviżjoni mħassra tal-paġna $1, $2 minn $3:',
 'undeleterevision-missing'     => "Reviżjoni invalidu jew nieqes.
 Int jista' jkollhok link ħażin, jew jista' jkun li ir-reviżjoni ġie rkuprat jew mneħħa mill-arkivju.",
-'undelete-nodiff'              => 'L-Ebda reviżjoni preċedenti.',
+'undelete-nodiff'              => 'L-ebda reviżjoni preċedenti ma ġiet misjuba.',
 'undeletebtn'                  => 'Irkupra',
 'undeletelink'                 => 'irkupra',
-'undeletereset'                => 'Resetja',
+'undeletereset'                => 'Irrisettja',
 'undeletecomment'              => 'Kumment:',
 'undeletedarticle'             => 'ġie irkuprat "[[$1]]"',
 'undeletedrevisions'           => '{{PLURAL:$1|reviżjoni irkuprata|$1 reviżjonijiet irkuprati}}',
 'undeletedrevisions-files'     => '{{PLURAL:$1|reviżjoni waħda|$1 reviżjonijiet}} u {{PLURAL:$2|fajl wieħed irkuprat|$2 fajls irkuprati}}',
 'undeletedfiles'               => '{{PLURAL:$1|file wieħed|$1 fajls}} irkuprati',
-'cannotundelete'               => 'Irkuprat ma irnexxiex;
-xi ħadd ieħor setgħa irkupra l-paġna l-ewwel.',
+'cannotundelete'               => "L-irkuprar ma irnexxiex;
+jista' jkun li xi ħadd ieħor rkupra l-paġna qabel.",
 'undeletedpage'                => "<big>'''$1 ġie irkuprat'''</big>
 
 Konsulta [[Special:Log/delete|l-log ta' tħassir]] għar-reġistru ta' tħassir riċenti u irkupri.",
@@ -1621,7 +1631,7 @@
 'undelete-search-box'          => 'Fittex paġni mħassra',
 'undelete-search-prefix'       => "Uri l-paġni li t-titlu jibda' bl-ittri:",
 'undelete-search-submit'       => 'Fittex',
-'undelete-no-results'          => "L-Ebda paġni korrispondenti fl-arkivju ta' tħassir.",
+'undelete-no-results'          => "L-ebda paġna korrispondenti ma ġiet misjuba fl-arkivju ta' tħassir.",
 'undelete-filename-mismatch'   => 'Ir-Reviżjoni tal-fajl bit-timbru tal-ħin $1 ma setgħax jiġi mħassar: isem tal-fajl ma jaqbilx',
 'undelete-bad-store-key'       => 'Ir-Reviżjoni tal-fajl bit-timbru tal-ħin $1 ma setgħax jiġi mħassar: fajl kien nieqes qabel it-tħassir.',
 'undelete-cleanup-error'       => 'Problema fit-tħassir ta\' fajl "$1" tal-arkivju li mhux użat.',
@@ -1639,24 +1649,25 @@
 
 # Contributions
 'contributions' => 'Kontribuzzjonijiet tal-utent',
-'mycontris'     => 'Kontribuzzjonijiet tiegħi',
+'mycontris'     => 'Il-Kontribuzzjonijiet tiegħi',
 'contribsub2'   => 'Għal $1 ($2)',
 'nocontribs'    => 'L-Ebda modifiki li jisodisfa l-kriterji tat-tfittxija.',
 'uctop'         => '(l-aħħar għal paġna)',
-'month'         => 'Mix-xahar (u preċedenti):',
-'year'          => 'Mis-sena (u preċedenti):',
+'month'         => 'Mix-xahar (u qabel):',
+'year'          => 'Mis-sena (u qabel):',
 
-'sp-contributions-newbies'     => "Uri kontribuzzjonijiet ta' kontijiet ġodda biss",
-'sp-contributions-newbies-sub' => 'Għal utenti ġodda',
+'sp-contributions-newbies'     => 'Uri biss il-kontribuzzjonijiet tal-utenti l-ġodda',
+'sp-contributions-newbies-sub' => 'Għall-utenti l-ġodda',
 'sp-contributions-blocklog'    => 'Blokki',
 'sp-contributions-search'      => 'Fittex għal kontribuzzjonijiet',
-'sp-contributions-username'    => 'Indirizz IP jew isem tal-utent:',
+'sp-contributions-username'    => 'Indirizz IP jew isem l-utent:',
 'sp-contributions-submit'      => 'Fittex',
 
 # What links here
-'whatlinkshere'            => 'Xi jwassal hawn',
-'whatlinkshere-title'      => 'Paġni li jippontaw għal $1',
+'whatlinkshere'            => "Li jwasslu 'l hawn",
+'whatlinkshere-title'      => 'Paġni li jippuntaw lejn $1',
 'whatlinkshere-page'       => 'Paġna:',
+'whatlinkshere-barrow'     => '>',
 'linklistsub'              => "(Lista ta' links)",
 'linkshere'                => "Il-Paġni segwenti għandhom links għal '''[[:$1]]''':",
 'nolinkshere'              => "L-Ebda paġna għanda link għal '''[[:$1]]'''.",
@@ -1670,20 +1681,20 @@
 'whatlinkshere-hideredirs' => '$1 rindirizzi',
 'whatlinkshere-hidetrans'  => '$1 inklużjonijiet',
 'whatlinkshere-hidelinks'  => '$1 link',
-'whatlinkshere-hideimages' => '$1 links tas-stampi',
+'whatlinkshere-hideimages' => '$1 links tal-istampi',
 'whatlinkshere-filters'    => 'Filtri',
 
 # Block/unblock
-'blockip'                         => 'Blokka l-utenti',
-'blockip-legend'                  => 'Blokka l-utenti',
-'blockiptext'                     => "Uża din il-formula li tinsab hawn taħt sabiex biex tibblokka aċċess tal-kitba minn IP speċifiku jew isem tal-utent.
-L-Imblokk irrid ikun użat biss sabiex inaqqas iċ-ċans ta' vandaliżmu , u osservazzjoni qawwija tal-[[{{MediaWiki:Policy-url}}|politika ta' {{SITENAME}}]]. 
-Imla r-raġuni speċifika hawn taħt (per eżempju, turi paġni partikulari li ġew vandaliżati).",
+'blockip'                         => 'Ibblokkja l-utent',
+'blockip-legend'                  => 'Ibblokkja l-utent',
+'blockiptext'                     => "Uża l-formola t'hawn taħt sabiex biex tibblokkja l-aċċess tal-kitba lil IP speċifiku jew utent.
+Il-blokk irid ikun użat biss sabiex jitnaqqas iċ-ċans ta' vandaliżmu, u għandu josservja b'mod strett il-[[{{MediaWiki:Policy-url}}|politika ta' {{SITENAME}}]]. 
+Indika r-raġuni speċifika għalfejn tixtieq tipproċedi bil-blokk (per eżempju, billi turi l-paġni partikolari li ġew ivvandalizzati).",
 'ipaddress'                       => 'Indirizz tal-IP:',
-'ipadressorusername'              => 'Indirizz tal-IP jew isem tal-utent:',
+'ipadressorusername'              => 'Indirizz tal-IP jew isem l-utent:',
 'ipbexpiry'                       => 'Skadenza tal-imblokk:',
 'ipbreason'                       => 'Raġuni:',
-'ipbreasonotherlist'              => 'Raġunijiet oħrajn',
+'ipbreasonotherlist'              => 'Raġuni oħra',
 'ipbreason-dropdown'              => "*Raġunijiet komuni dwar blokki
 ** Iddaħħal informazzjoni falza
 ** Tneħħi kontenut mill-paġni
@@ -1692,36 +1703,36 @@
 ** Komportament intimidanti jew molestiku
 ** Abbuż minn aktar minn kont wieħed
 ** isem ta' utent mhux aċċettabli",
-'ipbanononly'                     => 'Blokka utenti anonimi biss',
+'ipbanononly'                     => 'Ibblokkja l-utenti anonimi biss',
 'ipbcreateaccount'                => "Impedixxi ħolqien ta' kontijiet oħrajn",
 'ipbemailban'                     => 'Impedixxi utenti milli jkunu jistgħu jibgħatu posta elettronika',
 'ipbenableautoblock'              => 'Awtomatikament blokka l-aħħar indirizz tal-IP użat minn dan l-utent, u IP suċċessivi li jipprovaw jagħmlu modifiki',
-'ipbsubmit'                       => 'Blokka l-utent',
+'ipbsubmit'                       => 'Ibblokja dan l-utent',
 'ipbother'                        => 'Ħin ieħor:',
 'ipboptions'                      => 'sagħtejn:2 hours,ġurnata 1:1 day,3 ġranet:3 days,ġimgħa 1:1 week,ġimgħatejn:2 weeks,xahar 1:1 month,3 xhur:3 months,6 xhur:6 months,sena 1:1 year,infinita:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'                  => 'ieħor',
 'ipbotherreason'                  => 'Raġuni oħrajn:',
-'ipbhidename'                     => "Aħbi l-isem tal-utent mil-log tal-blokki, il-lista ta' blokki attivi u il-lista tal-utenti.",
+'ipbhidename'                     => "Aħbi isem l-utent mir-reġistru tal-blokki, mil-lista ta' blokki attivi u mil-lista tal-utenti.",
 'ipbwatchuser'                    => "Osserva l-paġni u d-diskussjonijiet ta' dan l-utent",
 'badipaddress'                    => "Indirizz ta' IP invalidu",
-'blockipsuccesssub'               => 'L-Imblokk irnexxa',
+'blockipsuccesssub'               => 'Il-Blokk irnexxa',
 'blockipsuccesstext'              => "[[Special:Contributions/$1|$1]] ġie blokkat.<br />
-Ara l-[[Special:Ipblocklist|lista tal-blokki ta' l-IP]] biex tara l-blokki attivi.",
+Ara l-[[Special:IPBlockList|lista tal-blokki ta' l-IP]] biex tara l-blokki attivi.",
 'ipb-edit-dropdown'               => 'Modifika r-raġuni tal-blokkar',
-'ipb-unblock-addr'                => 'Sblokka $1',
-'ipb-unblock'                     => "Sblokka isem ta' utent jew indirizz ta' IP",
+'ipb-unblock-addr'                => 'Żblokkja $1',
+'ipb-unblock'                     => 'Żblokkja isem l-utent jew l-indirizz tal-IP',
 'ipb-blocklist-addr'              => "Uri blokki attivi ta' $1",
 'ipb-blocklist'                   => 'Uri blokki attivi',
-'unblockip'                       => 'Sblokka l-utent',
+'unblockip'                       => 'Żblokkja l-utent',
 'unblockiptext'                   => "Uża l-formula t'hawn taħt sabiex tirkupra aċċess tal-kitba 'l utent jew indirizz tal-IP blokkat.",
-'ipusubmit'                       => 'Sblokka dan l-indirizz',
+'ipusubmit'                       => 'Żblokkja dan l-indirizz',
 'unblocked'                       => 'L-Utent [[User:$1|$1]] ġie sblokkat',
 'unblocked-id'                    => 'L-Imblokk $1 tneħħa',
-'ipblocklist'                     => 'Lista tal-utenti u indirizzi IP blokkati',
-'ipblocklist-legend'              => 'Fittex utent blokkat',
+'ipblocklist'                     => 'Lista tal-utenti u indirizzi IP imblukkati',
+'ipblocklist-legend'              => 'Fittex utent ibblokkjat',
 'ipblocklist-username'            => 'Isem tal-utent u indirizz IP:',
 'ipblocklist-submit'              => 'Fittex',
-'blocklistline'                   => '$1, $2 blokka $3 ($4)',
+'blocklistline'                   => '$1, $2 ibblokkja lil $3 (sa $4)',
 'infiniteblock'                   => 'infinit',
 'expiringblock'                   => 'sa $1',
 'anononlyblock'                   => 'anonimu biss',
@@ -1729,32 +1740,33 @@
 'createaccountblock'              => 'ħolqien tal-kont blokkat',
 'emailblock'                      => 'posta elettronika blokkata',
 'ipblocklist-empty'               => 'Il-Lista tal-blokki hija vojta.',
-'ipblocklist-no-results'          => 'L-Indirizz tal-IP rikjest jew isem tal-utent mhux blokkati.',
-'blocklink'                       => 'blokka',
-'unblocklink'                     => 'sblokka',
+'ipblocklist-no-results'          => 'L-Indirizz tal-IP jew isem l-utent rikjestr, mhux ibblokkjat.',
+'blocklink'                       => 'blokkja',
+'unblocklink'                     => 'żblokkja',
 'contribslink'                    => 'kontributi',
 'autoblocker'                     => 'Blokkat awtomatikament minħabba li l-indirizz tal-IP ġie użat mill-utent "[[User:$1|$1]]". Ir-Raġuni li ġiet mogħtija għall-imblokk ta\' $1 kienet: "$2":',
-'blocklogpage'                    => 'Blokkar',
-'blocklogentry'                   => 'blokajt "[[$1]]"; b\'skadenza $2 $3',
-'blocklogtext'                    => "Dan huwa log tal-azzjonijiet tal-blokkar u sblokkar ta' utent. Indirizzi tal-IP blokkati awtomatikament m'humiex fil-lista. Ara l-[[Special:Ipblocklist|lista tal-IP blokkati]] għal lista tal-blokki attivi bħalissa.",
-'unblocklogentry'                 => 'sblokajt $1',
+'blocklogpage'                    => 'Blokki',
+'blocklogentry'                   => 'ibblokkja lil "[[$1]]" għal $2 $3',
+'blocklogtext'                    => "Dan huwa log tal-azzjonijiet tal-blokkar u sblokkar ta' utent. Indirizzi tal-IP blokkati awtomatikament m'humiex fil-lista. Ara l-[[Special:IPBlockList|lista tal-IP blokkati]] għal lista tal-blokki attivi bħalissa.",
+'unblocklogentry'                 => 'żblokkjajt $1',
 'block-log-flags-anononly'        => 'utenti anonimi biss',
 'block-log-flags-nocreate'        => 'ħolqien tal-kont blokkat',
 'block-log-flags-noautoblock'     => 'blokkar awtomatiku disattivat',
 'block-log-flags-noemail'         => 'posta elettronika blokkata',
 'block-log-flags-angry-autoblock' => 'blokkar awtomatiku avvanzat attivat',
 'range_block_disabled'            => "Il-Possibilitá li timblokka intervali ta' indirizzi tal-IP mhux attiva bħalissa.",
-'ipb_expiry_invalid'              => "Ħin ta' skadenza huwa invalidu.",
+'ipb_expiry_invalid'              => "Il-ħin ta' skadenza huwa invalidu.",
 'ipb_expiry_temp'                 => "Blokkijiet ta' ismijiet ta' l-utent moħbija rridu jkunu permanenti.",
-'ipb_already_blocked'             => 'L-Utent "$1" huwa ġa blokkat',
+'ipb_already_blocked'             => 'L-utent "$1" diġà bblokkjat',
 'ipb_cant_unblock'                => 'Problema: Impossibli ssib il-blokk bl-ID $1. L-Imblokk setgħa jkun ġa sblokkat.',
 'ipb_blocked_as_range'            => "Problema: L-Indirizz tal-IP $1 ma jistax jiġi blokkat waħdu u ma jistax jiġi sblokkat. L-Imblokk huwa attiv però f'livell ta' interval $2, li jista' jkun sblokkat.",
 'ip_range_invalid'                => "Interval ta' indirizzi ta' IP mhux validi.",
-'blockme'                         => 'Blokkani',
+'blockme'                         => 'Ibblokkjani',
 'proxyblocker'                    => "Blokki ta' proxy miftuħa",
-'proxyblocker-disabled'           => 'Din il-funżjoni mhux attivata.',
-'proxyblockreason'                => "L-Indirizz tal-IP tiegħek ġie blokkat minħbba li huwa proxy miftuħ. Jekk jogħġbok agħmel kuntatt mal-provista tas-servizz tal-internet jew grupp tas-sapport tekniku tiegħek u informahom dwar din il-problema ta' sikurta serja.",
-'proxyblocksuccess'               => 'Blokkat.',
+'proxyblocker-disabled'           => 'Din il-funzjoni mhijiex attivata.',
+'proxyblockreason'                => "L-Indirizz tal-IP tiegħek ġie bblokkjat peress li huwa proxy miftuħ. 
+Jekk jogħġbok, ikkuntattja lill-provdituri tas-servizz tal-internet jew lis-support tekniku tiegħek u informahom b'din il-problema serja ta' sigurtà.",
+'proxyblocksuccess'               => 'Blokkjat.',
 'sorbsreason'                     => "L-Indirizz tal-IP tiegħek huwa mniżżel bħala proxy miftuħ fil-DNSBL ta' {{SITENAME}}.",
 'sorbs_create_account_reason'     => 'Mhux possibli toħloq aċċessi ġodda minn dan l-indirizz tal-IP minħabba li huwa mniżżel bħala proxy miftuħ fil-DNSBL użat minn {{SITENAME}}.',
 
@@ -1773,7 +1785,7 @@
 'lockdbsuccesssub'    => "Id-Database ngħalaq b'suċċess",
 'unlockdbsuccesssub'  => 'Id-Database infetaħ',
 'lockdbsuccesstext'   => 'Id-Database ngħalaq.<br />
-Ftakar li [[Special:Unlockdb|tiftaħ]] wara l-manteniment ikun lest.',
+Ftakar li [[Special:UnlockDB|tiftaħ]] wara l-manteniment ikun lest.',
 'unlockdbsuccesstext' => 'Id-database infetaħ.',
 'lockfilenotwritable' => "Impossibli tikteb fuq il-fajl ''agħlaq' tad-database. L-Aċċess tad-database, l-web server irrid ikun jista' jikteb.",
 'databasenotlocked'   => 'Id-Database mhux magħluq.',
@@ -1781,32 +1793,29 @@
 # Move page
 'move-page'               => 'Ċaqlaq $1',
 'move-page-legend'        => 'Ċaqlaq il-paġna',
-'movepagetext'            => "Jekk tuża l-formula li tinsab hawn taħt se terġa' ssemmi l-paġna, ċċaqlaq il-kronoloġija kollha tagħha għall-isem ġdid.
-It-Titlu l-antik se ssir paġna ta' rindirizz għat-titlu ġdid.
-Links għal paġna antika se jiġu modifikati;
-kun ċert li tiverifika għal rindirizzi doppji.
-Inti responsabli li tkun ċert li l-links jibqaw sa punt fejn sippost għandhom ridirieġu.
+'movepagetext'            => "Jekk tuża' l-formula li tinsab hawn taħt se terġa' ssemmi l-paġna, tmexxi l-kronoloġija kollha tagħha għall-isem il-ġdid.<br />
+It-titlu l-antik se jsir paġna ta' rindirizz għat-titlu l-ġdid.<br />
+Tista' taġġorna rindirizzi li jippuntaw awtomatikament lejn l-isem oriġinali.<br />
+Tista' tagħżel li ma tagħmilx dan, imma ftakar biex tivverifika li ċ-ċaqlieq li sar ma ħoloqx rindirizzi [[Special:DoubleRedirects|doppji]] jew [[Special:BrokenRedirects|ħżiena]]. Inti responsabbli li tkun ċert li l-links jibqgħu korretti.
 
-Nota l-paġna '''mhux''' se tiċaqlaq jekk hemm paġna fit-titlu ġdid, hija vojta jew xi rindirizz u m'għanda l-ebda kronoloġija ta' modifika passata. Fil-każ ta' ċaqlieq ħażin tista' tmur lura mal-ewwel għat-titlu l-antik, u mhux possibli li tikteb biż-żball fuq paġna ġa eżistenti.
+Għandek tkun taf li l-paġna '''mhux''' se titmexxa jekk hemm diġà paġna fit-titlu l-ġdid, sakemm tkun vojta jew xi rindirizz u m'għandha l-ebda kronoloġija ta' modifika passata. Fil-każ ta' ċaqlieq ħażin tista' tmur lura mal-ewwel għat-titlu l-antik, u mhux possibli li tikteb bi żball fuq paġna diġà eżistenti.
 
-'''TWISSIJA!'''
-Dan jista' jkun modifika drastika u mhux mistennija ta' paġna popolari; jekk jogħġbok kun ċert li tifhem il-konsegwenzi ta' din qabel ma tkompli.",
+'''ATTENZJONI!'''
+Din tista' tkun bidla drastika u mhux mistenniha għal paġna popolari; jekk jogħġbok kun ċert li tifhem il-konsegwenzi ta' din qabel ma tkompli.",
 'movepagetalktext'        => "Il-Paġna korrispondenti tad-diskussjoni se tiġi awtomatikament imċaqilqa flimkien magħha '''sakemm:'''
 * Paġna mhux vojta ta' diskussjoni ġa teżisti taħt l-isem il-ġdid.
 * Ma tagħżilx il-kaxxa t'hawn taħt.
 
 F'dawn il-każi, inti trid iċaqlaq jew tagħqad il-paġna manwalment jekk dan huwa mixtieq.",
 'movearticle'             => 'Ċaqlaq il-paġna:',
-'movenologin'             => 'Aċċess mhux imwettaq',
-'movenologintext'         => "Trid [[Special:Userlogin|tidħol]] bħalha utent reġistrat sabiex tkun tista' iċaqlaq din il-paġna.",
 'movenotallowed'          => "Inti m'għandhekx il-permessi meħtieġa sabiex iċaqlaq il-paġni fuq {{SITENAME}}.",
 'newtitle'                => 'Titlu ġdid:',
 'move-watch'              => 'Osserva din il-paġna',
 'movepagebtn'             => 'Ċaqlaq il-paġna',
 'pagemovedsub'            => 'Ċaqlieq irnexxa',
 'movepage-moved'          => '<big>\'\'\'"$1" ġie mċaqlaq għal "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'articleexists'           => "Paġna b'dak l-isem ġa teżisti, jew l-isem li għażilt mhux validu.
-Jekk jogħġbok daħħal isem ieħor.",
+'articleexists'           => "Diġà teżisti paġna b'dak l-isem, jew inkella l-isem li għażilt mhux validu.
+Jekk jogħġbok, agħżel isem ieħor.",
 'cantmove-titleprotected' => 'Ma tistax iċċaqlaq paġna hemmhekk, minħabba li t-titlu l-ġdid ġie protett milli jiġi maħluq.',
 'talkexists'              => "'''Il-Paġna stess iċċaqilqet b'suċċess, imma l-paġna tad-diskussjoni ma setgħatx tiġi mċaqilqa minħabba li waħda ġa teżisti b'dan it-titlu.
 Jekk jogħġbok agħqqad manwalment.'''",
@@ -1826,7 +1835,7 @@
 'revertmove'              => 'irkupra',
 'delete_and_move'         => 'Ħassar u ċaqlaq',
 'delete_and_move_text'    => '==Rikjesta ta\' tħassir==
-Il-Paġna tad-destinazzjoni "[[$1]]" ġa teżisti.
+Il-Paġna tad-destinazzjoni "[[:$1]]" ġa teżisti.
 Trid tħassara sabiex tkun tista\' tagħmel triq għal ċaqlieqa?',
 'delete_and_move_confirm' => 'Iva, ħassar il-paġna',
 'delete_and_move_reason'  => 'Imħassra sabiex tagħmel triq għal ċaqlieqa',
@@ -1837,6 +1846,7 @@
 'imagenocrossnamespace'   => "Ma tistax iċaqlaq fajl f'namespace mhux tal-fajls.",
 'imagetypemismatch'       => 'L-Estenżjoni l-ġdida tal-fajl ma taqbilx mat-tip tagħha.',
 'imageinvalidfilename'    => 'L-Isem tal-fajl destinat mhux validu',
+'fix-double-redirects'    => 'Aġġorna kwalunkwe rindirizz li jippunta lejn it-titlu l-oriġinali',
 
 # Export
 'export'            => 'Esporta l-paġni',
@@ -1862,9 +1872,9 @@
 'allmessagesdefault'        => 'Test predefinit',
 'allmessagescurrent'        => 'Test attwali',
 'allmessagestext'           => 'Din hija l-lista tal-messaġġi kollha tas-sistema disponibbli fin-namespace MedjaWiki:',
-'allmessagesnotsupportedDB' => "Il-Paġna ma tistax tintuża minħabba '''\$wgUseDatabaseMessages''' mhux attivata.",
-'allmessagesfilter'         => 'Filter fuq l-ismijiet tal-messaġġi:',
-'allmessagesmodified'       => 'Uri dawk biss modifikati',
+'allmessagesnotsupportedDB' => "Il-paġna ma tistax tintuża għax '''\$wgUseDatabaseMessages''' mhux attivat.",
+'allmessagesfilter'         => 'Filtru fuq l-ismijiet tal-messaġġi:',
+'allmessagesmodified'       => 'Uri biss dawk modifikati',
 
 # Thumbnails
 'thumbnail-more'           => 'Kabbar',
@@ -1883,8 +1893,8 @@
 Kull azzjonijiet ta' importazzjoni tal-transwiki jiġu reġistrati fil-[[Special:Log/import|log ta' importazzjoni]].",
 'import-interwiki-history'   => 'Kopja l-verżjonijiet tal-kronoloġija kollha għal din il-paġna',
 'import-interwiki-submit'    => 'Importa',
-'import-interwiki-namespace' => 'Transferixxi paġni għal ġo namespace:',
-'importtext'                 => "Jekk jogħġbok, esporta l-fajl tas-sit wiki t'oriġini bil-funżjoni Special:Export, salva fuq id-diska tiegħek u tellgħu hawn.",
+'import-interwiki-namespace' => 'Ittrasferixxi l-paġni fin-namespace:',
+'importtext'                 => 'Jekk jogħġbok, esporta l-fajl mis-sit wiki l-oriġini bil-funzjoni [[Special:Export]], salvah fuq id-diska tiegħek u tellgħu hawn.',
 'importstart'                => 'Paġni qegħdin jiġu importati...',
 'import-revision-count'      => '{{PLURAL:$1|reviżjoni|$1 reviżjonijiet}}',
 'importnopages'              => 'L-Ebda paġna li għanda tiġi importata.',
@@ -1893,7 +1903,7 @@
 'importcantopen'             => 'Impossibli tiftaħ il-fajl tal-importazzjoni',
 'importbadinterwiki'         => 'Link interwiki mhux tajjeb',
 'importnotext'               => 'Test vojt jew nieqes',
-'importsuccess'              => 'Importazzjoni rnexxa!',
+'importsuccess'              => 'L-Importazzjoni rnexxiet!',
 'importhistoryconflict'      => "Il-Kronoloġija fija verżjonijiet f'kunflitt (dan il-paġna setgħet tiġi ġiet importata qabel)",
 'importnosources'            => "Mhux definit sors ta' import transwiki; l-importazzjoni diretta tal-kronoloġija mhux attivata.",
 'importnofile'               => "L-Ebda fajl tal-importazzjoni itella'.",
@@ -1927,22 +1937,22 @@
 'tooltip-pt-logout'               => 'Oħroġ (logout)',
 'tooltip-ca-talk'                 => 'Diskussjoni dwar il-kontenut tal-paġna',
 'tooltip-ca-edit'                 => "Tista' tagħmel modifiki fuq din il-paġna. Jekk jogħġbok uża l-buttuna tal-previżjoni qabel ma tagħmel il-modifiki.",
-'tooltip-ca-addsection'           => "Żied kumment f'din id-diskussjoni.",
-'tooltip-ca-viewsource'           => "Din il-paġna hija protetta. Int tista' tara l-kodiċi sorġenti",
+'tooltip-ca-addsection'           => "Żid kumment f'din id-diskussjoni.",
+'tooltip-ca-viewsource'           => "Din il-paġna hija protetta. Tista' tara l-fonti tagħha.",
 'tooltip-ca-history'              => "Verżjonijiet preċedenti ta' din il-paġna",
-'tooltip-ca-protect'              => 'Protieġi din il-paġna',
+'tooltip-ca-protect'              => 'Ipproteġi din il-paġna',
 'tooltip-ca-delete'               => 'Ħassar din il-paġna',
 'tooltip-ca-undelete'             => "Irkupra l-modifiki magħmula f'din il-paġna qabel ma ġiet imħassra",
 'tooltip-ca-move'                 => 'Ċaqlaq din il-paġna',
-'tooltip-ca-watch'                => 'Żied din il-paġna fl-osservazzjonijiet speċjali tiegħek',
+'tooltip-ca-watch'                => "Żid din il-paġna mal-lista ta' osservazzjoni tiegħek",
 'tooltip-ca-unwatch'              => 'Neħħi din il-paġna mill-osservazzjonijiet speċjali tiegħek',
 'tooltip-search'                  => 'Fittex fil-{{SITENAME}}',
 'tooltip-search-go'               => 'Mur fil-paġna bit-titlu indikat, jekk teżisti',
 'tooltip-search-fulltext'         => 'Fittex it-test indikat fil-paġni',
-'tooltip-p-logo'                  => 'Paġna prinċipali',
-'tooltip-n-mainpage'              => 'Żur il-paġna prinċipali',
+'tooltip-p-logo'                  => 'Il-Paġna prinċipali',
+'tooltip-n-mainpage'              => 'Żur il-Paġna Prinċipali',
 'tooltip-n-portal'                => "Dwar il-proġett, x'tista' tagħmel, fejn tista' ssib l-affarijiet",
-'tooltip-n-currentevents'         => 'Sib aktar informazzjoni dwar avveniment kurrenti',
+'tooltip-n-currentevents'         => 'Sib aktar informazzjoni dwar il-ġrajjiet kurrenti',
 'tooltip-n-recentchanges'         => 'Il-Lista tal-modifiki riċenti fil-wiki.',
 'tooltip-n-randompage'            => 'Uri paġna kwalunkwe',
 'tooltip-n-help'                  => 'Il-Post fejn issir taf.',
@@ -1956,22 +1966,22 @@
 'tooltip-t-specialpages'          => 'Lista tal-paġni speċjali kollha',
 'tooltip-t-print'                 => "Verżjoni tal-ipprintjar ta' din il-paġna",
 'tooltip-t-permalink'             => 'Link permanenti għal din il-verżjoni tal-paġna',
-'tooltip-ca-nstab-main'           => 'Uri kontenut tal-paġna',
+'tooltip-ca-nstab-main'           => 'Uri l-kontenut tal-paġna',
 'tooltip-ca-nstab-user'           => 'Uri l-paġna tal-utent',
 'tooltip-ca-nstab-media'          => 'Uri l-paġna tal-medja',
 'tooltip-ca-nstab-special'        => "Din hija paġna speċjali, ma tistax tagħmel modifiki f'din il-paġna",
 'tooltip-ca-nstab-project'        => 'Uri l-paġna tal-proġett',
 'tooltip-ca-nstab-image'          => 'Uri l-paġna tal-fajl',
-'tooltip-ca-nstab-mediawiki'      => 'Uri messaġġi tas-sistema',
+'tooltip-ca-nstab-mediawiki'      => 'Uri l-messaġġ tas-sistema',
 'tooltip-ca-nstab-template'       => 'Uri t-template',
 'tooltip-ca-nstab-help'           => 'Uri l-paġna tal-għajnuna',
 'tooltip-ca-nstab-category'       => 'Uri l-paġna kategorika',
-'tooltip-minoredit'               => 'Marka din bħalha modifika żgħira',
+'tooltip-minoredit'               => 'Immarka din bħala modifika minuri',
 'tooltip-save'                    => 'Salva l-modifiki',
 'tooltip-preview'                 => 'Oħloq previżjoni tal-modifiki, jekk jogħġbok uża dan qabel ma twettaq dawn il-modifiki!',
 'tooltip-diff'                    => 'Uri liem modifiki għamilt fit-test.',
 'tooltip-compareselectedversions' => "Ara d-differenzi bejn iż-żewġ verżjonijiet magħżula ta' din il-paġna.",
-'tooltip-watch'                   => "Żid din il-paġna fil-lista t'osservazzjoni tiegħek",
+'tooltip-watch'                   => "Żid din il-paġna mal-lista ta' osservazzjoni tiegħek",
 'tooltip-recreate'                => "Erġa' oħloq din il-paġna minkejja li kienet ġiet imħassra",
 'tooltip-upload'                  => "Ibda tella'",
 
@@ -2004,11 +2014,11 @@
 
 # Attribution
 'anonymous'        => 'Utent(i) anonimi minn {{SITENAME}}',
-'siteuser'         => '{{SITENAME}} utent $1',
+'siteuser'         => '$1, utent tal-{{SITENAME}}',
 'lastmodifiedatby' => 'Din il-paġna ġiet modifikata l-aħħar fil-$2, $1 minn $3.', # $1 date, $2 time, $3 user
 'othercontribs'    => "Bażat fuq ix-xogħol ta' $1.",
 'others'           => 'oħrajn',
-'siteusers'        => '{{SITENAME}} utent(i) $1',
+'siteusers'        => '$1, utent(i) tal-{{SITENAME}}',
 'creditspage'      => 'Kredenzjali tal-paġna',
 'nocredits'        => "M'hemmx informazzjoni dwar kredenzjali f'din il-paġna.",
 
@@ -2025,7 +2035,7 @@
 'infosubtitle'   => 'Informazzjoni għal paġna',
 'numedits'       => "Numru ta' modifiki (paġna): $1",
 'numtalkedits'   => "Numru ta' modifiki (paġna tad-diskussjoni): $1",
-'numwatchers'    => "Numru ta' osservanti: $1",
+'numwatchers'    => "Numru ta' osservaturi: $1",
 'numauthors'     => "Numru ta' awturi distinti (paġna): $1",
 'numtalkauthors' => "Numru ta' awturi distinti (paġna tad-diskussjoni): $1",
 
@@ -2066,8 +2076,8 @@
 'filedelete-archive-read-only'    => 'L-Arkivju tad-direttorju "$1" ma jistax jinkiteb mill-webserver.',
 
 # Browsing diffs
-'previousdiff' => '← Differenza preċedenti',
-'nextdiff'     => 'Differenza suċċessiva →',
+'previousdiff' => "← Differenza ta' qabel",
+'nextdiff'     => 'Id-differenza li jmiss →',
 
 # Media information
 'mediawarning'         => "'''Twissija''': Dan il-fajl jista' jkun fih kodiċi malinja, jekk tagħżel li tiftħu jista' jagħmel ħsara fis-sistema informatika tiegħek.<hr />",
@@ -2081,10 +2091,10 @@
 'show-big-image'       => "Verżjoni b'risoluzzjoni sħiħa",
 'show-big-image-thumb' => '<small>Dimensjoni tal-previżjoni: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => "Gallerija ta' fajls ġodda",
 'imagelisttext'         => "Il-Lista t'hawn taħt ta' '''$1''' {{PLURAL:$1|fajl|fajls}} irranġati $2.",
-'newimages-summary'     => "Din il-paġna speċjali turi l-aħħar fajls li ġew mtella' riċentament",
+'newimages-summary'     => "Din il-paġna speċjali turi l-aħħar fajls li ġew mtella' riċentament.",
 'showhidebots'          => '($1 bots)',
 'noimages'              => "M'hawn xejn x'tara.",
 'ilsubmit'              => 'Fittex',
@@ -2095,18 +2105,18 @@
 'hours-abbrev' => 'S',
 
 # Bad image list
-'bad_image_list' => "Il-format huwa dan segwenti:
+'bad_image_list' => "Il-format huwa kif imiss:
 
-Jiġi konsidrat biss ikoni puntati (linji li jibdew b'*) biss.
+Jiġu kkunsidrati biss listi ppuntati (linji li jibdew b'*).
 L-ewwel link fil-linja hija link għal fajl ħażin.
-Il-Links suċċessivi fuq l-istess linja huma konsidrata eċċeżjoni. (paġni fejn il-fajl jista' jiġi rikjamat)",
+Il-links suċċessivi fuq l-istess linja huma kkunsidrati bħala eċċezzjonijiet, ċoè, paġni fejn il-fajl jista' jiġi rikjamat b'mod normali.",
 
 # Metadata
 'metadata'          => 'Metadata',
 'metadata-help'     => 'Dan il-fajl fih aktar informazzjoni, probabli miżjud minn kamera diġitali jew skanner użat sabiex joħolqu jew inkella sabiex jagħmlu diġitali. 
 Jekk il-fajl ġie modifikat mill-istat oriġinal, ftit dettalji mhux biżżejjed.',
-'metadata-expand'   => 'Uri dettalji estiż',
-'metadata-collapse' => 'Aħbi dettalji',
+'metadata-expand'   => 'Uri d-dettalji',
+'metadata-collapse' => 'Aħbi d-dettalji',
 'metadata-fields'   => "EXIF metadata mniżżel f'din il-lista tal-messaġġ se jiġu inkluż fil-veduta tal-paġna tal-istampa meta t-tabella tiġi murija fil-forma qasira. 
 Minħabba veduta predefinita ,l-oħrajn se jiġu moħbija. 
 * make
@@ -2373,7 +2383,7 @@
 
 # External editor support
 'edit-externally'      => "Modifika dan il-fajl b'użu ta' applikazzjoni estern",
-'edit-externally-help' => 'Għal aktar informazzjoni ara [http://meta.wikimedia.org/wiki/Help:External_editors l-istruzzjonijiet] (bl-ingliż).',
+'edit-externally-help' => 'Għal aktar informazzjoni ara [http://www.mediawiki.org/wiki/Manual:External_editors l-istruzzjonijiet] (bl-ingliż).',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'kollha',
@@ -2383,7 +2393,7 @@
 'monthsall'        => 'kollha',
 
 # E-mail address confirmation
-'confirmemail'             => 'Konferma l-indirizz tal-posta elettronika',
+'confirmemail'             => 'Ikkonferma l-indirizz tal-posta elettronika',
 'confirmemail_noemail'     => "Int m'għandhekx indirizz ta' posta elettronika valida fil-[[Special:Preferences|preferenzi tal-utent]].",
 'confirmemail_text'        => "{{SITENAME}} għandu bżonn li int tiverifika l-indirizz tal-posta elettronika tiegħek qabel ma tkun tista' tagħmel użu mill-faċċilitajiet tal-posta elettronika.
 Attiva l-buttuna t'hawn taħt sabiex tibgħat posta ta' konfermazzjoni fl-indirizz tiegħek.
@@ -2442,7 +2452,7 @@
 'recreate'            => "Erġa' oħloq",
 
 # HTML dump
-'redirectingto' => 'Rindirizzat għal [[$1]]...',
+'redirectingto' => 'Rindirizzat għal [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Ħassar il-''cache'' ta' din il-paġna?
@@ -2453,36 +2463,42 @@
 # AJAX search
 'searchcontaining' => "Fittex paġna li għandhom ''$1''.",
 'searchnamed'      => "Fittex għal paġna bl-isem ''$1''.",
-'articletitles'    => "Fittex għal paġni li jibdew bi ''$1''",
-'hideresults'      => 'Aħbi riżultati',
+'articletitles'    => "Fittex dawk il-paġni li jibdew b' ''$1''",
+'hideresults'      => 'Aħbi r-riżultati',
 'useajaxsearch'    => 'Uża tfittxija AJAX',
 
 # Separators for various lists, etc.
 'autocomment-prefix' => '-',
 
 # Multipage image navigation
-'imgmultipageprev' => '← paġna preċedenti',
-'imgmultipagenext' => 'paġna segwenti →',
+'imgmultipageprev' => "← il-paġna ta' qabel",
+'imgmultipagenext' => 'il-paġna li jmiss →',
 'imgmultigo'       => 'Mur',
 'imgmultigoto'     => 'Mur għal paġna $1',
 
 # Table pager
 'ascending_abbrev'         => 'axx',
 'descending_abbrev'        => 'dixx',
-'table_pager_next'         => 'Paġna suċċessiva',
-'table_pager_prev'         => 'Paġna preċedenti',
+'table_pager_next'         => 'Il-paġna li jmiss',
+'table_pager_prev'         => "Il-paġna ta' qabel",
 'table_pager_first'        => 'L-Ewwel paġna',
 'table_pager_last'         => 'L-Aħħar paġna',
 'table_pager_limit'        => "Uri $1 oġġett f'kull paġna",
 'table_pager_limit_submit' => 'Mur',
-'table_pager_empty'        => 'L-Ebda riżultat',
+'table_pager_empty'        => 'L-ebda riżultat',
 
 # Auto-summaries
 'autosumm-blank'   => 'Neħħi kull kontenut mill-paġna',
-'autosumm-replace' => "Paġna sostitwita ma' '$1'",
+'autosumm-replace' => "Il-paġna qed tiġi mibdula ma' '$1'",
 'autoredircomment' => 'Rindirizzat għal [[$1]]',
 'autosumm-new'     => 'Paġna ġdida: $1',
 
+# Size units
+'size-bytes'     => '$1 B',
+'size-kilobytes' => '$1 KB',
+'size-megabytes' => '$1 MB',
+'size-gigabytes' => '$1 GB',
+
 # Live preview
 'livepreview-loading' => 'Tniżżil fil-progress…',
 'livepreview-ready'   => 'Tniżżil… Lest!',
@@ -2491,18 +2507,18 @@
 'livepreview-error'   => 'Impossibli toħloq konnessjoni: $1 "$2". Uża previżjoni standard.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Modifiki aktar ġodda minn $1 sekondi jistgħu jkunu mhux inklużi fil-lista.',
-'lag-warn-high'   => "Minħabba l-aġġornament tas-server huwa bil-mod ħafna, il-modifiki fl-aħħar $1 sekondi ma jistgħux jiġu' inklużi fil-lista.",
+'lag-warn-normal' => 'It-tibdil li hu aktar riċenti minn $1 sekondi, jistgħu ma jiġux inklużi fil-lista.',
+'lag-warn-high'   => 'Minħabba l-aġġornament tas-server huwa bil-mod ħafna, il-modifiki fl-aħħar $1 sekondi ma jistgħux jiġu nklużi fil-lista.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => "Il-Lista ta' osservazzjoni speċjali fija {{PLURAL:$1|titlu|$1 titli}}, minbarra paġni tad-diskussjoni.",
-'watchlistedit-noitems'        => "Il-Lista t'osservazzjoni speċjali tiegħek ma fih l-ebda titlu.",
+'watchlistedit-noitems'        => "Il-lista ta' osservazzjoni tiegħek hija vojta.",
 'watchlistedit-normal-title'   => 'Modifika l-lista tal-osservazzjonijiet speċjali',
 'watchlistedit-normal-legend'  => 'Neħħi titli mil-lista tal-osservazzjonijiet speċjali',
 'watchlistedit-normal-explain' => "Titli tal-lista tal-osservazzjonijiet speċjali tiegħek huwa mogħrija hija taħt.
 Biex tneħħi titlu, għażel il-kaxxa ħdejja, u agħfas neħħi titli.
 Int tista' ukoll tagħmel fil-[[Special:Watchlist/raw|lista ta' format testwali]].",
-'watchlistedit-normal-submit'  => 'Ħassar Titli',
+'watchlistedit-normal-submit'  => 'Ħassar it-titli',
 'watchlistedit-normal-done'    => '{{PLURAL:$1|Titlu kien imħassar|$1 titli kienu mħassra}} mil-lista tal-osservazzjonijiet speċjali tiegħek:',
 'watchlistedit-raw-title'      => 'Modifiki osservazzjonijiet speċjali fil-forma testwali',
 'watchlistedit-raw-legend'     => 'Modifika osservazzjonijiet speċjali testwali',
@@ -2526,14 +2542,14 @@
 
 # Special:Version
 'version'                          => 'Verżjoni', # Not used as normal message but as header for the special page itself
-'version-extensions'               => 'Estenżjonijiet installati',
+'version-extensions'               => 'Estensjonijiet installati',
 'version-specialpages'             => 'Paġni speċjali',
 'version-parserhooks'              => 'Hook tal-parser',
 'version-variables'                => 'Varjabili',
 'version-other'                    => 'Oħrajn',
 'version-mediahandlers'            => 'Imradd tal-medja',
 'version-hooks'                    => 'Hook',
-'version-extension-functions'      => 'Funżjoni introdotti tal-estenżjoni',
+'version-extension-functions'      => 'Funzjonijiet tal-estensjoni',
 'version-parser-extensiontags'     => 'Tags magħrufa mill-parser introdott tal-estenżjoni',
 'version-parser-function-hooks'    => 'Hook għal funżjoni tal-parser',
 'version-skin-extension-functions' => 'Funżjoni marbut mall-aspett grafiku (skin) introdott mill-estenżjoni',
@@ -2545,7 +2561,7 @@
 'version-software-product'         => 'Prodott',
 'version-software-version'         => 'Verżjoni',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Post tal-fajl',
 'filepath-page'    => 'Fajl:',
 'filepath-submit'  => 'Post',
@@ -2560,7 +2576,7 @@
 
 Daħħal l-isem tal-fajl mingħajr il-prefiss \"{{ns:image}}:\".",
 'fileduplicatesearch-legend'   => 'Fittex għal duplikat',
-'fileduplicatesearch-filename' => 'L-Isem tal-fajl:',
+'fileduplicatesearch-filename' => 'Isem il-fajl:',
 'fileduplicatesearch-submit'   => 'Fittex',
 'fileduplicatesearch-info'     => '$1 × $2 pixel<br />Daqs tal-fajl: $3<br />tip MIME: $4',
 'fileduplicatesearch-result-1' => 'Il-Fajl "$1" m\'għandux duplikat eżatt.',
@@ -2573,7 +2589,7 @@
 * <span class="mw-specialpagerestricted">Paġni speċjali limitati.</span>',
 'specialpages-group-maintenance' => 'Rapporti tal-manteniment',
 'specialpages-group-other'       => 'Paġni speċjali oħrajn',
-'specialpages-group-login'       => 'Idħol / reġistra',
+'specialpages-group-login'       => 'Idħol / irreġistra',
 'specialpages-group-changes'     => 'L-Aħħar modifiki u reġistri',
 'specialpages-group-media'       => 'Fajls multimedjali - rapporti u tellgħar',
 'specialpages-group-users'       => 'Utenti u drittijiet',
@@ -2584,7 +2600,7 @@
 'specialpages-group-redirects'   => "Paġni speċjali ta' rindirizz",
 'specialpages-group-spam'        => 'Għodda kontra l-ispam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Paġna vojta',
 'intentionallyblankpage' => 'Din il-paġna tħalliet vojta ataposta',
 
Index: languages/messages/MessagesYi.php
===================================================================
--- languages/messages/MessagesYi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesYi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Jiddisch
+ * @author Teak
  * @author Yidel
+ * @author לערי ריינהארט
  * @author פוילישער
- * @author Siebrand
- * @author לערי ריינהארט
- * @author SPQRobin
- * @author Jon Harald Søby
- * @author Jiddisch
- * @author Teak
  */
 
 $fallback = 'he';
@@ -144,7 +141,7 @@
 'tog-watchcreations'          => 'לייג צו בלעטער וואס איך באשאף צו מיין אכטונג ליסטע',
 'tog-watchdefault'            => 'אויפפאסן אױטאָמאַטיש די ארטיקלן װאָס איך באַאַרבעט',
 'tog-watchmoves'              => 'לייג צו בלעטער וואס איך באוועג צו מיין אכטונג ליסטע',
-'tog-watchdeletion'           => 'לייגן בלעטער וואס איך מעקן אויס צו מיין אויפפאסונג ליסטע',
+'tog-watchdeletion'           => 'צולייגן בלעטער וואס איך מעק אויס צו מיין אויפפאסונג ליסטע',
 'tog-minordefault'            => "באגרעניץ אלע עדיט'ס ביי דיפאלט אלס קליין",
 'tog-previewontop'            => 'צײַג די "פֿאָרויסיגע װײַזונג" גלײַך בײַ דער ערשטער באַאַרבעטונג',
 'tog-previewonfirst'          => 'ווייזט פאראויסדיגע ווייזונג אינעם ערשטען ענדערונג',
@@ -327,8 +324,8 @@
 'jumptosearch'      => 'זוכן',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'            => 'איבער {{SITENAME}}',
-'aboutpage'            => 'Project:איבער',
+'aboutsite'            => 'וועגן {{SITENAME}}',
+'aboutpage'            => 'Project:וועגן',
 'bugreports'           => 'באג באריכטען',
 'bugreportspage'       => 'Project:באג באריכטן',
 'copyright'            => 'אינהאַלט איז עוועיליבל אונטער $1.',
@@ -400,7 +397,7 @@
 'nosuchaction'      => 'נישטא אזא אקציע',
 'nosuchactiontext'  => 'די אקציע ספעסיפיזירט דורך די URL איז נישט אנערקענט ביי דעם וויקי',
 'nosuchspecialpage' => 'נישטא אזא ספעציעלער בלאט',
-'nospecialpagetext' => 'איר האט געבעטן א נישט ריכטיגער סעפעציעלער בלאט. זעהט די [[Special:Specialpages|ספעציעלע בלעטער ליסטע]].',
+'nospecialpagetext' => 'איר האט געבעטן א נישט ריכטיגן סעפעציעלן בלאט. זעהט די [[Special:SpecialPages|{{int:specialpages}}]].',
 
 # General errors
 'error'                => 'פעלער',
@@ -477,6 +474,7 @@
 פארלאנג: $2',
 'viewsource'           => 'זעה מקור',
 'viewsourcefor'        => 'פאר $1',
+'actionthrottled'      => 'די אַקציע איז באַגרענעצט',
 'protectedpagetext'    => 'דער בלאט איז פארשפארט צו אפהאלטן ענדערונגן.',
 'viewsourcetext'       => 'איר קענט זעהן און קאפיען די מקור פון דעם בלאט:',
 'protectedinterface'   => 'דער בלאט איז שטעלט צו אינטערפעיס טעקסט פאר די סאפטוועיר, און איז פארשפארט פון איר צו קענען ענדערן, בלויז פאר די סיסאפס כדי צו פארמיידן וואנדאליזם.',
@@ -492,7 +490,7 @@
 'logouttitle'                => 'באנוצער ארויסלאגירן',
 'logouttext'                 => '<strong>האָסט זיך ארויסלאָגירט מיט הצלחה.</strong>',
 'welcomecreation'            => '== ברוך הבא, $1! ==
-אייער קאנטע איז באשאפן געווארן. נישט פארגעסן צו ענדערן אייערע {{SITENAME}} פרעפערענצן.',
+אייער קאנטע איז באשאפן געווארן. נישט פארגעסן צו ענדערן אייערע [[Special:Preferences|{{SITENAME}} פרעפֿערענצן]].',
 'loginpagetitle'             => 'באנוצער לאגירן',
 'yourname'                   => 'באַנוצער־נאָמען',
 'yourpassword'               => 'פאסווארט',
@@ -558,14 +556,14 @@
 'eauthentsent'               => 'א באשטעטיגונג אימעיל איז געשיקט געווארן צו די נאמינירטע אימעיל אדרעס. בעפאר סיי וואס אנדערע אימעיל ווערן געשיקט צו דעם אקאונט, וועסטו דארפן אויספילן די אנווייזונגען אין דיין אינבאקס כדי צו זיין זיכער אז די אקאונט איז טאקע דיינס.',
 'throttled-mailpassword'     => "א פאסווארט דערמאנונג איז שוין געשיקט געווארן, אין {{PLURAL:$1|דער לעצטער שעה|די לעצטע $1 שעה'ן}}. כדי צו פארמײַדן שלעכט באניצן, נאר איין פאסווארט דערמאנונג וועט געשיקט ווערן אין {{PLURAL:$1|א שעה |$1 שעה'ן}}.",
 'mailerror'                  => 'פעילער שיקענדיג מעיל: $1',
-'acct_creation_throttle_hit' => 'אנטשולדיגט, האסט שוין באשאפען $1 אקאונטס. קענסט מער נישט מאכן נאך.',
+'acct_creation_throttle_hit' => 'צום באַדױערן, איר האָט שױן באַשאַפֿן $1 קאָנטעס. איר קענט נישט מער שאַפֿן נײַע קאָנטעס.',
 'emailauthenticated'         => 'דיין אי-מעיל אדרעס איז באשטעטיגט געווארן דורך $1.',
 'emailnotauthenticated'      => 'דיין אי-מעיל אדרעס איז נאכנישט באשטעטיגט. קיין אי-מעיל וועט נישט געשיקט ווערן פון קיין איינע פון די פאלגענדע פישטערס.',
 'noemailprefs'               => 'ספעציפיר אן אי-מעיל אדרעס פאר די פיטשערס צו ארבייטן.',
 'emailconfirmlink'           => 'באשטעטיג דיין אי-מעיל אדרעס',
 'invalidemailaddress'        => 'די אי-מעיל אדרעס קען נישט אקצעפטירט ווערן ווי עס שיינט צו האבן אן אומ-ריכטיגע פארמאט. ביטע אריינלייגן א גוט-פארמאטירטער אדרעס אדער ליידיג אויס די פעלד.',
-'accountcreated'             => 'קאנטע באשאפען',
-'accountcreatedtext'         => 'די באנוצער קאנטע פאר $1 איז באשאפען געווארן.',
+'accountcreated'             => 'די קאָנטע איז באַשאַפֿן',
+'accountcreatedtext'         => 'די באניצער קאנטע פאר $1 איז באַשאַפֿן געווארן.',
 'loginlanguagelabel'         => 'שפראך: $1',
 
 # Password reset dialog
@@ -611,7 +609,7 @@
 'showpreview'               => 'פֿאָרױסדיגע װײַזונג',
 'showlivepreview'           => 'לעבעדיגע פאראויסדיגע ווייזונג',
 'showdiff'                  => 'ווײַז די ענדערונגן',
-'anoneditwarning'           => "'''ווארענונג:''' איר זענט נישט אריינלאגירט אין אייער אקאונט. אייער איי פי אדרעס וועט ווערן דאקומענטירט אין די בלאטס היסטאריע פון ענדערונגן. אויב זארגט איר זיך פאר פריוואטקייטן, ביעט טוט אייך אריינלאגירן אין אייער אקאונט.",
+'anoneditwarning'           => "'''ווארענונג:''' איר זענט נישט אריינלאגירט אין אייער קאנטע. אייער איי פי אדרעס וועט ווערן דאקומענטירט אין דעם בלאטס היסטאריע פון ענדערונגען. אויב זארגט איר זיך פאר פריוואטקייטן, ביטע טוט זיך אריינלאגירן.",
 'missingsummary'            => "'''דערמאנונג:''' איר האט נישט אויסגעפילט דעם קורץ ווארט אויפקלערונג אויף אייער עדיט. אויב וועט איר דרוקן נאכאמאל אויף  \"היט אפ דעם בלאט\", וועט אייער ענדערונג ווערן געהיטן אן דעם.",
 'missingcommenttext'        => 'ביטע שטעלט אריין א אנמערקונג פון אונטן.',
 'missingcommentheader'      => "'''דערמאנונג:''' איר האט נישט אריינגעשטעלט א טעמע/קעפל פאר דעם אנמערקונג. אויב וועט איר דרוקן נאכאמאל אויפן \"היט-אפ בלאט\", וועט אייער ענדערונג ווערן אפגעהיטן אן דעם.",
@@ -645,12 +643,8 @@
 'blockednoreason'           => 'קיין טעם נישט געגעבן',
 'blockedoriginalsource'     => "די טעקסט פון מקור פון '''$1''' ווערט געוויזן אונטן:",
 'blockededitsource'         => "די טעקסט פון '''אייערע ענדערונגן''' צו '''$1''' ווערט געוויזן אונטן:",
-'whitelistedittitle'        => 'אריינלאגירן פארלאנגט צו ענדערן',
+'whitelistedittitle'        => '[[Special:UserLogin|אריינלאגירן פֿארלאנגט]] צו ענדערן',
 'whitelistedittext'         => 'איר ברויכט צו $1 צו ענדערן בלעטער.',
-'whitelistreadtitle'        => 'אריינלאגירן פארלאנגט צו ליינען',
-'whitelistreadtext'         => 'איר ברויכט צו [[Special:Userlogin|אריינלאגירן]] צו ליינען בלעטער.',
-'whitelistacctitle'         => 'איר זענט נישט דערלויבט צו באשאפן א קאנטע',
-'whitelistacctext'          => "צו ווערן ערלויבט צו באשאפן קאנטעס אויף דער וויקי ברויכט איר [[Special:Userlogin|אריינלאגירן]] און האבן די ריכטיגע רשות'ן.",
 'confirmedittitle'          => 'איר דארפט באשטעטיגן אייער בליצפאסט אדרעס כדי צו רעדאקטירן',
 'confirmedittext'           => 'אויף אייך ליגט קודם די פליכט צו באשטעטיגן און אריינשטעלן אייער ריכטיגע אימעיל אדרעס באפארן ענדערן בלעטער. ביטע שרייבט און באשטעטיגט אייער אימעיל אדרעס דורך אייערע [[Special:Preferences|באנוצער פרעפערענצן]] .',
 'nosuchsectiontitle'        => 'נישטא אזא אפטיילונג',
@@ -659,10 +653,10 @@
 'loginreqlink'              => 'לאגירט אריין',
 'loginreqpagetext'          => 'איר מוזט $1 כדי צו זעהן אנדערע בלעטער.',
 'accmailtitle'              => 'פאסווארט געשיקט',
-'accmailtext'               => 'די פעסווארד פאר "$1" איז געשיקט געווארן צו $2.',
+'accmailtext'               => 'דאס פאַסווארט פאר "$1" איז געשיקט געוואָרן צו $2.',
 'newarticle'                => '(ניי)',
 'newarticletext'            => "'''דער בלאַט עקזיסטירט נאָך נישט!''' איר קענט יעצט שרײַבן אַ נײַעם אַרטיקל אין די אונטערשטע קעסטל. (זעהט דעם [[הילף:ווי צו שרייבן ווערטן|הילף בלאַט]] ווי אַזוי צו שרײַבן אַרטיקלען).",
-'anontalkpagetext'          => "----'''דאס איז א רעדן בלאט פון א אן אנינאנימער באנוצער וואס האט נאך נישט באשאפן קיין אקאונט אין די סיסטעם, אדער באנוצט זיך נישט דערמיט. דערוועגן, מוזן מיר זיך באנוצען מיט זיין איי פי אדרעס כדי אים צו אידענטיפיצירן. עס קען זיין אז עטליכע אנדערע נוצען אויך די איי פי אדרעס. אויב זענט איר א אנינאמע באנוצער וואס שפירט אז איר האט באקומען דעם מעסעזש אומזינסט, ביטע [[Special:Userlogin|באשאפט אן אקאונט אדער טויט זיך אריינלאגירן]] כדי צו פארמיידען דאס אין די עתיד זיך פארמישן מיט אנדערע אנינאמעס באנוצער. .'''",
+'anontalkpagetext'          => "----'''דאס איז א רעדן בלאט פון א אן אנאנימען באַניצער וואס האט נאך נישט באַשאַפֿן קיין קאנטע, אדער באניצט זיך נישט דערמיט. דערוועגן, מוזן מיר זיך באניצן מיט זיין IP אדרעס כדי אים צו אידענטיפיצירן. עס קען זיין אז עטלעכע אנדערע ניצן אויך דעם  IP אדרעס. אויב זענט איר אן אנאנימער באַניצער וואס שפירט אז איר האט באקומען מעלדונגען וואס זענען נישט שייך צו אייך, ביטע [[Special:UserLogin/signup|באַשאַפֿט א קאנטע]] אדער [[Special:UserLogin|טוט זיך אריינלאגירן]] כדי צו פארמיידן דאס אין די עתיד זיך פארמישן מיט אנדערע אנאנימע באַניצערס.'''",
 'noarticletext'             => 'עס איז דערווייל נישט פארהאן קיין שום טעקסט אין דעם בלאט, איר קענט [[Special:Search/{{PAGENAME}}|זוכן דעם בלאט טיטול]] אין אנדערע בלעטער אדער [{{fullurl:{{FULLPAGENAME}}|action=edit}} ענדערן דעם בלאט].',
 'userpage-userdoesnotexist' => 'באניצער קאנטע "$1" איז נישט אײַנגעשריבן. קוקט איבער צי איר ווילט שאפֿן/רעדאקטירן דעם בלאט.',
 'clearyourcache'            => "אכטונג:''' נאכן אויפֿהיטן, ברויכט איר אפשר נאך אריבערגיין דער בלעטערס קאש זיכרון (cache) צו זעהן די ענדערונגען
@@ -676,12 +670,12 @@
 'note'                      => '<strong>באמערקונג:</strong>',
 'previewnote'               => '<strong>דאס איז נאָר אין אַ פֿאָרויסיקע ווייזונג, דער אַרטיקל איז דערווייל נאָך נישט געהיט!</strong>',
 'previewconflict'           => 'די פאראויסדיגע ווייזונג רעפלעקטירט די טעקסט און די אויבערשטע טעקסט ענדערונג אפטיילונג וויאזוי דאס וועט אויסזעהן אויב וועט איר אויסוועילן צו דאס אפהיטן.',
-'session_fail_preview'      => "'''אנטשולדיגט! מען האט נישט געקענט פרצעסירן אייער ענדערונג צוליב א פארלוסט פון סעסיע דאטע. ביטע פרובירט נאכאמאל. אויב סארבייט נאך אלץ נישט, פרובירט ארויסלאגירן און זיך צוריק אריינלאגירן.",
+'session_fail_preview'      => "'''אנטשולדיגט! מען האט נישט געקענט פראצעסירן אייער ענדערונג צוליב א פארלוסט פון סעסיע דאטע. ביטע פרובירט נאכאמאל. אויב סארבייט נאך אלץ נישט, פרובירט [[Special:UserLogout| ארויסלאגירן]] און זיך צוריק אריינלאגירן.",
 'session_fail_preview_html' => "<strong>'''אנטשולדיגט! מיר קענען נישט פראצעסירן אייער ענדערונג צוליב א פארלוסט פון סעסיע דאטע.'''</strong>
 
-''ווייל די וויקי האט רויע HTML ערמעגליכט, די פאראויסיגע ווייזונג איז באהאלטן אלס א באווארענונג אנטקעגן JavaScript אטאקירונגן.''
+''ווייל די וויקי האט רויע HTML ערמעגליכט, די פאראויסיגע ווייזונג איז באהאלטן אלס א באווארענונג אנטקעגן JavaScript אטאקירונגען.''
 
-<strong>אויב דאס איז א כשר'ע רעדאקציע פרואוו, פרובירט נאכאמאל.</strong>",
+<strong>אויב דאס איז א כשר'ע רעדאקציע פרואוו, פרובירט נאכאמאל. אויב דאס גייט נאכאלץ נישט, פרובירט [[Special:UserLogout|ארויסלאגירן]] און ווידעראמאל אריינלאגירן. </strong>",
 'editing'                   => 'ענדערן $1',
 'editingsection'            => 'ענדערט $1 (אפטיילונג)',
 'editingcomment'            => 'ענדערט $1 (הערה)',
@@ -709,7 +703,7 @@
 'cascadeprotectedwarning'   => "'''ווארענונג:''' דער בלאט איז פארשפארט אז בלויז סיסאפן קענען אים ענדערן, וויבאלד ער איז איינגעשלאסן אין {{PLURAL:$1| דעם פאלגנדן בלאט, וואס איז|די פאלגנדע בלעטער, וואס זענען}} קאסקאד באשיצט:",
 'titleprotectedwarning'     => '<strong>אזהרה: דער בלאט איז פֿארשלאסן טא קענען נאר געוויסע באניצערס שאפֿן אים.</strong>',
 'templatesused'             => 'מוסטערן באנוצט אויף דעם בלאט:',
-'templatesusedpreview'      => 'מוסטערן באנוצער אין דעם פאראויסדיגע ווייזונג:',
+'templatesusedpreview'      => 'באַנוצטע מוסטערן אין דעם פֿאָראױסדיקע אױסקוק:',
 'templatesusedsection'      => 'מוסטערן באנוצט אין דעם אפטיילונג:',
 'template-protected'        => '(באשיצט)',
 'template-semiprotected'    => '(טיילווייז באשיצט)',
@@ -717,7 +711,7 @@
 'edittools'                 => '<!-- טעקסט דא וועט געוויזן ווערן אונטער ענדערן און ארויפלאדירן פארעמס. -->',
 'nocreatetitle'             => 'בלאט באשאפן באגרעניצט',
 'nocreatetext'              => 'די סייט האט באגרעניצט די מעגליכקייט צו באשאפן נייע בלעטער.
-איר קענט צוריקגיין און ענדערן די עקזיסטירנדע בלאט, אדער [[Special:Userlogin|לאגירט זיך אריין און באשאפט א קאנטע]].',
+איר קענט צוריקגיין און ענדערן די עקזיסטירנדע בלאט, אדער [[Special:UserLogin|לאגירט זיך אריין און באשאפט א קאנטע]].',
 'permissionserrors'         => 'ערלויבענישן פעילערס',
 'recreate-deleted-warn'     => "'''ווארענונג: איר שאפט א נייעם בלאט וואס איז שוין איינמאל געווארן אויסגעמעקט.'''
 
@@ -730,7 +724,8 @@
 'undo-summary' => 'זיי מבטל רי-ווערסיע $1 פון [[Special:Contributions/$2|$2]] ([[User talk:$2|רעדן]])',
 
 # Account creation failure
-'cantcreateaccounttitle' => 'מען קען נישט באשאפן אקאונט',
+'cantcreateaccounttitle' => 'מען קען נישט באשאפֿן קאנטע',
+'cantcreateaccount-text' => 'שאפֿן קאנטעס פון דעם IP אדרעס (<b>$1</b>) איז געווארן בלאקירט דורך [[User:$3|$3]]. די סיבה געגעבן פֿון $3 איז "$2".',
 
 # History pages
 'viewpagelogs'        => 'זעה לאגס פאר דעם בלאט',
@@ -749,6 +744,8 @@
 'last'                => 'לעצטע',
 'page_first'          => 'ערשט',
 'page_last'           => 'לעצט',
+'histlegend'          => 'פֿארגלייכן  אויסקלויב: צייכנט די קנעפלעך פֿון די ווערסיעס צו פֿארגלײַכן, און קלאפט  Enter אדער דאס קנעפל אונטן.<br />
+מקרא: (איצט) = אונטערשייד פֿון לויפֿיגער ווערסיע, (לעצט) = אונטערשייד פֿון פֿריערדיגער ווערסיע, מ = מינערדיקע רעדאקטירונג',
 'deletedrev'          => '[אויסגעמעקט]',
 'histfirst'           => 'ערשטע',
 'histlast'            => 'לעצטיגע',
@@ -800,6 +797,7 @@
 'suppressionlog' => 'באהאלטונגען לאג',
 
 # Diffs
+'history-title'           => 'רעוויזיע היסטאריע פֿון $1',
 'difference'              => '(אונטערשייד צווישן ווערסיעס)',
 'lineno'                  => 'שורה $1:',
 'compareselectedversions' => 'פארגלייך סעלעקטירטע ווערסיעס',
@@ -807,29 +805,34 @@
 'diff-multi'              => '({{PLURAL:$1|איין מיטלסטע ווערסיע |$1 מיטלסטע ווערסיעס}}  נישט געוויזן.)',
 
 # Search results
-'searchresults'         => 'זוכן רעזולטאטן',
-'searchresulttext'      => 'לערנען מער ווי צו זוכן אינעם {{SITENAME}} [[{{MediaWiki:Helppage}}|{{int:help}}]]',
-'searchsubtitle'        => '[[:$1]]',
-'searchsubtitleinvalid' => '$1דו האסט געזוכט פאר',
-'noexactmatch'          => 'דערווייל איז נאָך נישטאָ א בלאט מיט דעם טיטל.<br /> איר זײַט געלאדנט [[:$1|אויפשרייבן א נייעם בלאט]], אדער [[Project:בעטן ווערטן|בעטן פון פריינד]] זאלן זיי שרייבן.',
-'noexactmatch-nocreate' => 'נישטא קיין בלאט מיטן קעפל "$1".',
-'notitlematches'        => 'קיין שום בלאט האט נישט א צוגעפאסט קעפל',
-'prevn'                 => '$1 פריערדיגע',
-'nextn'                 => '$1 קומענדיגע',
-'viewprevnext'          => 'קוקט אויף ($1) ($2) ($3)',
-'search-suggest'        => 'צי האט איר געמיינט: $1',
-'searchall'             => 'אלץ',
-'showingresultstotal'   => "ווײַזן {{PLURAL:$3| רעזולטאט '''$1''' פֿון '''$3'''| רעזולטאטן '''$1 - $2''' פֿון '''$3'''}}",
-'powersearch'           => 'זוכן',
-'powersearch-redir'     => 'ווײַז ווײַטערפֿירונג בלעטער',
-'powersearch-field'     => 'זוך',
+'searchresults'            => 'זוכן רעזולטאטן',
+'searchresulttext'         => 'לערנען מער ווי צו זוכן אינעם {{SITENAME}} [[{{MediaWiki:Helppage}}|{{int:help}}]]',
+'searchsubtitle'           => '[[:$1]]',
+'searchsubtitleinvalid'    => '$1דו האסט געזוכט פאר',
+'noexactmatch'             => 'דערווייל איז נאָך נישטאָ א בלאט מיט דעם טיטל.<br /> איר זײַט געלאדנט [[:$1|אויפשרייבן א נייעם בלאט]], אדער [[Project:בעטן ווערטן|בעטן פון פריינד]] זאלן זיי שרייבן.',
+'noexactmatch-nocreate'    => 'נישטא קיין בלאט מיטן קעפל "$1".',
+'notitlematches'           => 'קיין שום בלאט האט נישט א צוגעפאסט קעפל',
+'prevn'                    => '$1 פריערדיגע',
+'nextn'                    => '$1 קומענדיגע',
+'viewprevnext'             => 'קוקט אויף ($1) ($2) ($3)',
+'search-section'           => '(אפטיילונג $1)',
+'search-suggest'           => 'צי האט איר געמיינט: $1',
+'search-interwiki-caption' => 'שוועסטער פראיעקטן',
+'search-interwiki-default' => '$1 רעזולטאטן:',
+'searchall'                => 'אלץ',
+'showingresultstotal'      => "ווײַזן {{PLURAL:$3| רעזולטאט '''$1''' פֿון '''$3'''| רעזולטאטן '''$1 - $2''' פֿון '''$3'''}}",
+'powersearch'              => 'זוכן',
+'powersearch-legend'       => 'ווײַטהאלטן זוכן',
+'powersearch-ns'           => 'זוכן אין נאמענטיילן:',
+'powersearch-redir'        => 'ווײַז ווײַטערפֿירונג בלעטער',
+'powersearch-field'        => 'זוך',
 
 # Preferences page
 'preferences'           => 'פרעפערענצן',
 'mypreferences'         => 'מיינע פרעפערענצן',
 'prefs-edits'           => 'צאל פון ענדערונגן:',
 'prefsnologin'          => 'נישט אריינלאגירט',
-'prefsnologintext'      => 'איר דארפט זיין [[Special:Userlogin|איינלאגירט]] כדי צו ענדערן באניצער פרעפֿערענצן.',
+'prefsnologintext'      => 'איר דארפט זיין [[Special:UserLogin|איינלאגירט]] כדי צו ענדערן באניצער פרעפֿערענצן.',
 'qbsettings-none'       => 'גארנישט',
 'qbsettings-fixedleft'  => 'קבוע לינקס',
 'qbsettings-fixedright' => 'קבוע רעכטס',
@@ -870,11 +873,13 @@
 'files'                 => 'פיילס',
 
 # User rights
-'userrights-user-editname' => 'לייגט אריין א באנוצער-נאמען:',
-'editusergroup'            => 'עדיט באנוצער גרופעס',
-'editinguser'              => "ענדערן באניצער רעכטן פון באניצער user '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
-'userrights-groupsmember'  => 'מיטגליד פון:',
-'userrights-reason'        => 'סיבה פארן ענדערונג:',
+'userrights-user-editname'    => 'לייגט אריין א באנוצער-נאמען:',
+'editusergroup'               => 'עדיט באנוצער גרופעס',
+'editinguser'                 => "ענדערן באניצער רעכטן פון באניצער user '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'userrights-groupsmember'     => 'מיטגליד פון:',
+'userrights-reason'           => 'סיבה פארן ענדערונג:',
+'userrights-changeable-col'   => 'גרופעס איר קענט ענדערן',
+'userrights-unchangeable-col' => 'גרופעס איר קענט נישט ענדערן',
 
 # Groups
 'group'            => 'גרופע:',
@@ -904,34 +909,41 @@
 'right-autoconfirmed' => 'רעדאקטירן האלב-געשיצטע בלעטער',
 'right-delete'        => 'מעקן בלעטער',
 
+# User rights log
+'rightslog'      => 'באַניצער רעכטן לאג',
+'rightslogentry' => 'געביטן די מיטגלידערשאַפֿט פֿאַר $1 פֿון $2 אויף $3',
+'rightsnone'     => '(גארנישט)',
+
 # Recent changes
-'nchanges'          => '{{PLURAL:$1|ענדערונג|$1 ענדערונגען}}',
-'recentchanges'     => 'לעצטע ענדערונגען',
-'rcnote'            => "אונטן {{PLURAL:$1|איז '''1''' ענדערונג|זײַנען די לעצטע '''$1''' ענדערונגען}} אין {{PLURAL:$2|דעם לעצטן טאג|די לעצטע $2 טעג}}, ביז $5, $4.",
-'rcnotefrom'        => "פֿאלגנד זענען די ענדערונגען זײַט '''$2''' (ביז '''$1''')",
-'rclistfrom'        => 'װײַז נײַע ענדערונגען זינט $1',
-'rcshowhideminor'   => '$1 מינדערדיגע ענדערונגן',
-'rcshowhidebots'    => '$1 באטס',
-'rcshowhideliu'     => '$1 אײַנגעשריבינע באַנוצערס',
-'rcshowhideanons'   => '$1 אַנאָנימע באַנוצערס',
-'rcshowhidepatr'    => '$1 נאכגעקוקטע עדיטס',
-'rcshowhidemine'    => '$1 מײַנע עדיטס',
-'rclinks'           => 'װײַזן די לעצטע $1 ענדערונגען אין די לעצטע $2 טעג.<br />$3',
-'diff'              => 'אונטערשייד',
-'hist'              => 'היסטאריע',
-'hide'              => 'באַהאַלטן',
-'show'              => 'ווייז',
-'minoreditletter'   => 'מ',
-'newpageletter'     => 'נ',
-'boteditletter'     => 'ב',
-'newsectionsummary' => '/* $1 */ נייע אפטיילונג',
+'nchanges'                          => '{{PLURAL:$1|ענדערונג|$1 ענדערונגען}}',
+'recentchanges'                     => 'לעצטע ענדערונגען',
+'rcnote'                            => "אונטן {{PLURAL:$1|איז '''1''' ענדערונג|זײַנען די לעצטע '''$1''' ענדערונגען}} אין {{PLURAL:$2|דעם לעצטן טאג|די לעצטע $2 טעג}}, ביז $5, $4.",
+'rcnotefrom'                        => "פֿאלגנד זענען די ענדערונגען זײַט '''$2''' (ביז '''$1''')",
+'rclistfrom'                        => 'װײַז נײַע ענדערונגען זינט $1',
+'rcshowhideminor'                   => '$1 מינדערדיגע ענדערונגן',
+'rcshowhidebots'                    => '$1 באטס',
+'rcshowhideliu'                     => '$1 אײַנגעשריבינע באַנוצערס',
+'rcshowhideanons'                   => '$1 אַנאָנימע באַנוצערס',
+'rcshowhidepatr'                    => '$1 פאַטראליטע ענדערונגען',
+'rcshowhidemine'                    => '$1 מײַנע עדיטס',
+'rclinks'                           => 'װײַזן די לעצטע $1 ענדערונגען אין די לעצטע $2 טעג.<br />$3',
+'diff'                              => 'אונטערשייד',
+'hist'                              => 'היסטאריע',
+'hide'                              => 'באַהאַלטן',
+'show'                              => 'ווייז',
+'minoreditletter'                   => 'מ',
+'newpageletter'                     => 'נ',
+'boteditletter'                     => 'ב',
+'number_of_watching_users_pageview' => '[{{PLURAL:$1|איין באַניצער פאַסט|$1 באַניצערס פאַסן}} אויף]',
+'newsectionsummary'                 => '/* $1 */ נייע אפטיילונג',
 
 # Recent changes linked
-'recentchangeslinked'         => 'פֿאַרבונדענע ענדערונגען',
-'recentchangeslinked-title'   => 'ענדערונגען פֿארבונדן מיט $1',
-'recentchangeslinked-summary' => "אט א רשימה פון נייע ענדערונגען צו בלעטער פארבונדן פון א ספעציפישן בלאט (אדער מיטגליד בלעטער פון א ספעציפישער קאטעגאריע).
+'recentchangeslinked'          => 'פֿאַרבונדענע ענדערונגען',
+'recentchangeslinked-title'    => 'ענדערונגען פֿארבונדן מיט $1',
+'recentchangeslinked-noresult' => 'נישט געווען קיין ענדערונגען אין פֿארבונדענע בלעטער אין דער תקופה.',
+'recentchangeslinked-summary'  => "אט א רשימה פון נייע ענדערונגען צו בלעטער פארבונדן פון א ספעציפישן בלאט (אדער מיטגליד בלעטער פון א ספעציפישער קאטעגאריע).
 בלעטער אויף [[Special:Watchlist|אייער אויפפאסונג ליסטע]] זענען געוויזן '''דיק'''.",
-'recentchangeslinked-page'    => 'בלאט נאמען:',
+'recentchangeslinked-page'     => 'בלאט נאמען:',
 
 # Upload
 'upload'          => 'בילדער/טעקעס אַרױפֿלאָדירן',
@@ -947,28 +959,29 @@
 'destfilename'    => 'ציל טעקע נאמען:',
 'watchthisupload' => 'פאס אויף דעם בלאט',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'טעקע',
 'imagelist'      => 'טעקע ליסטע',
 'imagelist_name' => 'נאמען',
 
 # Image description page
-'filehist'            => 'היסטאריע פֿון דער טעקע',
-'filehist-help'       => 'קליקט אויף א דאטע/צײַט צו זען דאס בילד אזוי ווי עס איז דעמאלסט געווען',
-'filehist-deleteall'  => 'אויסמעקן אלץ',
-'filehist-deleteone'  => 'אויסמעקן',
-'filehist-revert'     => 'צוריקגיין',
-'filehist-current'    => 'לויפיק',
-'filehist-datetime'   => 'דאטע/צײַט',
-'filehist-user'       => 'באניצער',
-'filehist-dimensions' => 'געמעסטן',
-'filehist-filesize'   => 'טעקע גרייס',
-'filehist-comment'    => 'באמערקונג',
-'imagelinks'          => 'פֿארבינדונגען',
-'linkstoimage'        => '{{PLURAL:$1|דער פאלגנדער בלאט ניצט|די פאלגנדע בלעטער ניצן}} דאס דאזיגע בילד:',
-'nolinkstoimage'      => 'נישטא קיין בלעטער וואס ניצן דאס דאזיגע בילד.',
-'noimage'             => "ס'איז נישטא א טעקע מיט דעם נאמען, איר קענט אבער $1.",
-'noimage-linktext'    => 'ארויפלאדן א טעקע',
+'filehist'                  => 'היסטאריע פֿון דער טעקע',
+'filehist-help'             => 'קליקט אויף א דאטע/צײַט צו זען דאס בילד אזוי ווי עס איז דעמאלסט געווען',
+'filehist-deleteall'        => 'אויסמעקן אלץ',
+'filehist-deleteone'        => 'אויסמעקן',
+'filehist-revert'           => 'צוריקגיין',
+'filehist-current'          => 'לויפיק',
+'filehist-datetime'         => 'דאטע/צײַט',
+'filehist-user'             => 'באניצער',
+'filehist-dimensions'       => 'געמעסטן',
+'filehist-filesize'         => 'טעקע גרייס',
+'filehist-comment'          => 'באמערקונג',
+'imagelinks'                => 'פֿארבינדונגען',
+'linkstoimage'              => '{{PLURAL:$1|דער פאלגנדער בלאט ניצט|די פאלגנדע בלעטער ניצן}} דאס דאזיגע בילד:',
+'nolinkstoimage'            => 'נישטא קיין בלעטער וואס ניצן דאס דאזיגע בילד.',
+'noimage'                   => "ס'איז נישטא א טעקע מיט דעם נאמען, איר קענט אבער $1.",
+'noimage-linktext'          => 'ארויפלאדן א טעקע',
+'uploadnewversion-linktext' => 'ארויפֿלאדן א נײַע ווערסיע פֿוו דער טעקע',
 
 # File reversion
 'filerevert-comment' => 'הערה:',
@@ -1019,6 +1032,8 @@
 'withoutinterwiki'        => 'בלעטער אן שפראך פֿארבינדונגען',
 'withoutinterwiki-submit' => 'ווײַז',
 
+'fewestrevisions' => 'בלעטער מיט די מינדערסטע רעוויזיעס',
+
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|בייט|בייטן}}',
 'nlinks'                  => '$1 {{PLURAL:$1|לינק|לינקען}}',
@@ -1029,6 +1044,7 @@
 'lonelypages'             => "פֿאר'יתומ'טע בלעטער",
 'uncategorizedpages'      => 'בלעטער אָן קאטעגאריעס',
 'uncategorizedcategories' => 'קאטעגאריעס וואס זענען נישט קאטעגאריזירט',
+'uncategorizedimages'     => 'אומקאטעגאריזירטע טעקעס',
 'unusedcategories'        => 'נישט געניצטע קאטעגאריעס',
 'unusedimages'            => 'נישט געניצטע טעקעס',
 'popularpages'            => 'פאפולערע בלעטער',
@@ -1060,40 +1076,45 @@
 'booksources'               => 'דרויסנדיגע ליטעראַטור ISBN',
 'booksources-search-legend' => 'זוכט פאר דערויסענדע ביכער מקורות',
 'booksources-go'            => 'גיי',
-'booksources-text'          => 'אונטען איז א ליסטע פון סייטס וואס פארקויפן נייע און גענוצטע ביכער און האבן אויך נאך אינפארמאציע איבער די ספרים וואס איר זוכט:',
+'booksources-text'          => 'אונטן איז א ליסטע פון סייטס וואס פֿארקויפֿן נייע און גענוצטע ביכער און האבן אויך נאך אינפֿארמאציע וועגן די ביכער וואס איר זוכט:',
 
 # Special:Log
-'specialloguserlabel'  => 'באנוצער:',
-'speciallogtitlelabel' => 'טיטול:',
+'specialloguserlabel'  => 'באַניצער:',
+'speciallogtitlelabel' => 'קעפל:',
+'log'                  => 'לאג-ביכער',
 'all-logs-page'        => 'אלע לאג-ביכער',
+'log-search-legend'    => 'זוך לאג ביכער',
+'log-search-submit'    => 'ווײַז',
 'alllogstext'          => 'קאמבאנירטע אויסלייג פון אלע לאגס פון{{grammar:תחילית|{{SITENAME}}}}.
 מען קען פארשמעלרן די אויסוואל דורך אויסוועלן די סארט לאג, באנוצער נאמען אדער אפעקטירטע בלעטער.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'אלע בלעטער',
 'alphaindexline'    => '$1 ביז $2',
 'nextpage'          => 'קומענדיגער בלאט ($1)',
 'prevpage'          => 'פֿריערדיגער בלאט ($1)',
 'allpagesfrom'      => 'ווייזן בלעטער אנגעהויבן פון:',
 'allarticles'       => 'אלע ארטיקלען',
-'allinnamespace'    => 'אלע בלעטער (נאמענטייל $1)',
+'allinnamespace'    => 'אלע בלעטער ($1 נאָמענטייל )',
 'allnotinnamespace' => 'אלע בלעטער (נישט אין נאמענטייל  $1)',
 'allpagesprev'      => 'פריערדיגע',
 'allpagesnext'      => 'נעקסט',
 'allpagessubmit'    => 'גיי',
 'allpagesprefix'    => 'בלעטער וואס זייער נאמען הייבט זיך אן מיט…:',
-'allpagesbadtitle'  => 'קעפל פון די געזוכטע בלאט איז געווען אומ-געזעצליך, ליידיג, אינעווייניגסטער וויקי לינק, אדער אינטער-וויקי פריפיקס. עס איז מעגליך אז עס אנטהאלט אותיות וואס מען קען נישט נוצען אין קעפלעך.',
-'allpages-bad-ns'   => '{{SITENAME}} האט נישט קיין נאמענטייל "$1".',
+'allpagesbadtitle'  => 'דער אײַנגעגעבענער נאָמען איז אומגילטיק: לײדיק, אַנטהאַלט אינטערװיקי. עס איז מעגליך אז ער אנטהאלט אותיות וואס מען קען נישט ניצן אין קעפלעך.',
+'allpages-bad-ns'   => '{{SITENAME}} האט נישט קיין נאָמענטייל "$1".',
 
 # Special:Categories
 'categories'         => 'קאַטעגאָריעס',
 'categoriespagetext' => 'די פאלגענדע קאַטעגאָריעס אנטהאלטן בלעטער אדער מעדיע.',
+'categoriesfrom'     => 'ווײַזן קאטעגאריעס אנהייבנדיג פֿון:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'ווײַז',
 'listusers-noresult' => 'קיין באניצער נישט געטראפֿן.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
+'listgrouprights'         => 'באַניצער גרופע רעכטן',
 'listgrouprights-group'   => 'גרופע',
 'listgrouprights-rights'  => 'רעכטן',
 'listgrouprights-members' => '(רשימה פֿון מיטגלידער)',
@@ -1101,7 +1122,7 @@
 # E-mail user
 'emailuser'       => 'אי-מעיל דעם באנוצער',
 'emailpage'       => "אי-מעיל'ט באנוצער.",
-'emailpagetext'   => 'אויב דער באנוצער האט אריינגעלייגט א גוטער אי-מעיל אדרעס אין זיינע באנוצער פרעפערענצן, וועט דער פארעם פון דא אונטען אים שיקן איין קאפי. די אי-מעיל אדרעסע פון אייך וואס איר האט אריינגעלייגט אין אייערע באנוצער פרעפערנעצן וועט זיך ווייזן כאילו דאס איז געקומען פון דארטן.',
+'emailpagetext'   => 'אויב דער באניצער האט אריינגעלייגט א גוטן ע-פאסט אדרעס אין זיינע באניצער פרעפערענצן, וועט דער פארעם פון דא אונטן אים שיקן איין בריוו. דער ע-פאסט אדרעס וואס איר האט אריינגעלייגט אין [[Special:Preferences| אייערע באניצער פרעפערנעצן]] וועט זיך ווייזן כאילו דאס איז געקומען פון דארטן, בכדי צו דערמעגלעכן א תשובה .',
 'defemailsubject' => 'אימעיל {{SITENAME}}',
 'noemailtitle'    => 'נישטא קיין אי-מעיל אדרעס',
 'noemailtext'     => 'דער באניצער האט נישט באשטימט קיין ע-פאסט אדרעס, אדער וויל נישט באקומען קיין ע-פאסט פון אנדערע באניצערס.',
@@ -1122,15 +1143,13 @@
 'nowatchlist'          => 'איר האט נישט קיין שום בלעטער אין אייער אויפפַּאסונג ליסטע.',
 'watchlistanontext'    => 'ביטע $1 כדי צו זעהן אדער ענדערן בלעטער פון אייער אויפפַּאסונג ליסטע.',
 'watchnologin'         => 'איר זענט נישט אריינגעסיינט',
-'watchnologintext'     => 'איר מוזט זיין אריינגעסיינט [[Special:Userlogin|אריינגעסיינט]] צו מאדיפיצירן אייער אויפפַּאסונג ליסטע.',
-'addedwatch'           => 'צוגעלייגט געוואָרן צום אויפפַּאסונג ליסטע',
-'addedwatchtext'       => "דער אַרטיקל \"[[:\$1]]\" איז צוגעלײגט געוואָרן צו דײַן [[Special:Watchlist|אויפפַּאסונג ליסטע]].
+'watchnologintext'     => 'איר מוזט זיין אריינגעסיינט [[Special:UserLogin|אריינגעסיינט]] צו מאדיפיצירן אייער אויפפַּאסונג ליסטע.',
+'addedwatch'           => 'דער בלאט איז צוגעלייגט געוואָרן צו דער אויפֿפַּאסונג ליסטע',
+'addedwatchtext'       => " דער בלאט \"[[:\$1]]\" איז צוגעלײגט געוואָרן צו אײַער[[Special:Watchlist|אויפפַּאסונג ליסטע]].
 
-ענדערונגן צו דעם בלאט און צו אירע פארבינדענע רעדן בלאט וועט זיין דא אויסגערעכענט.
-און די בלאט וועט זיין '''דיק''' [[Special:לעצטע ענדערונגן|ליסטע פון לעצטע ענדערונגן]] צו גרינגער מאכן דאס ארויסנעמען.
-
-אויב איר ווילט פטור ווערן דערפון פון אייער אויפפאסען ליסטע שפעטער קליקט, \"שטעלט אפ באוואכן\" אין די סיידבאר.",
-'removedwatch'         => 'אַראָפּגענומען געווארן פונעם אויפפַּאסונג ליסטע',
+ענדערונגען צו דעם בלאט און צו זײַן פארבינדענעם רעדן בלאט וועלן זײַן אויסגערעכענט דא.
+און די בלאט וועט זיין '''דיק''' [[Special:לעצטע ענדערונגן|ליסטע פון לעצטע ענדערונגן]] צו גרינגער מאכן דאס ארויסנעמען.",
+'removedwatch'         => 'אַראָפּגענומען געווארן פון דער אויפפַּאסונג ליסטע',
 'removedwatchtext'     => 'דער אַרטיקל "[[:$1]]" איז אָפּגעראַמעט געוואָרן פון אייער אױפֿפּאַסונג ליסטע',
 'watch'                => 'אױפֿפּאַסן',
 'watchthispage'        => 'טוט אױפֿפּאַסן דעם בלאט',
@@ -1184,39 +1203,55 @@
 {{fullurl:{{MediaWiki:Helppage}}}}',
 
 # Delete/protect/revert
-'deletepage'          => 'מעק אויס בלאט',
-'confirm'             => 'באשטעטיג',
-'excontent'           => 'אינהאלט געווען: "$1"',
-'excontentauthor'     => "אינהאלט געווען: '$1' (און דער איינציגסטער בארבייטער איז געווען '[[Special:Contributions/$2|$2]]')",
-'exbeforeblank'       => 'אינהאלט בעפארן אויסליידיגען איז געווען: "$1"',
-'exblank'             => 'בלאט איז געווען ליידיג',
-'delete-confirm'      => 'אויסמעקן $1',
-'delete-legend'       => 'אויסמעקן',
-'historywarning'      => 'אכטונג – איר גייט אויסמעקן א בלאט מיט א היסטאריע פֿון פֿריערדיגע ווערסיעס:',
-'confirmdeletetext'   => 'איר גייט איצט אויסמעקן א בלאט אדער א בילד, צוזאמן מיט איר גאנצע היסטאריע, פון די דאטעבאזע.
+'deletepage'                  => 'מעק אויס בלאט',
+'confirm'                     => 'באשטעטיג',
+'excontent'                   => 'אינהאלט געווען: "$1"',
+'excontentauthor'             => "אינהאלט געווען: '$1' (און דער איינציגסטער בארבייטער איז געווען '[[Special:Contributions/$2|$2]]')",
+'exbeforeblank'               => 'אינהאלט בעפארן אויסליידיגען איז געווען: "$1"',
+'exblank'                     => 'בלאט איז געווען ליידיג',
+'delete-confirm'              => 'אויסמעקן $1',
+'delete-legend'               => 'אויסמעקן',
+'historywarning'              => 'אכטונג – איר גייט אויסמעקן א בלאט מיט א היסטאריע פֿון פֿריערדיגע ווערסיעס:',
+'confirmdeletetext'           => 'איר גייט איצט אויסמעקן א בלאט אדער א בילד, צוזאמן מיט איר גאנצע היסטאריע, פון די דאטעבאזע.
 
 ביטע באשטעטיגט אז דאס איז טאקע אייער כוונה, אז איר פארשטייט פולערהייט די קאנסקווענסן פון אזא הארבע אקט, און אז דאס איז אין איינקלאנג מיטן פאליסי פון דעם סייט.',
-'actioncomplete'      => 'אקציע קאמפלעט',
-'deletedtext'         => '"<nowiki>$1</nowiki>" אויסגעמעקט. זעה $2 פאר רעקארד פון לעצטיגע אויסמעקונגען.',
-'deletedarticle'      => 'אויסגעמעקט "[[$1]]"',
-'dellogpage'          => 'אויסמעקונג לאג',
-'dellogpagetext'      => 'ווייטער איז א ליסטע פון די מערסט לעצטיגע אויסמעקונגען.',
-'deletionlog'         => 'אויסמעקונג לאג',
-'deletecomment'       => 'סיבה פארן אויסמעקן:',
-'rollback_short'      => 'אויפֿריכטן',
-'rollbacklink'        => 'צוריקדרייען',
-'cantrollback'        => 'מען קען נישט צוריקדרייען די ענדערונג – די לעצטער באטייליגער איז דער איינציגסטער באטייליגונג; פארט, קען מען אויסמעקן דעם בלאט.',
-'alreadyrolled'       => 'מען קעגן נישט צוריקדרייען די ענדערונג פון בלאט [[:$1]] דורך [[User:$2|$2]] ([[User talk:$2|רעדן]]); אן אנדערער האט שוין גענדערט אדער צוריקגעדרייט דעם בלאט
+'actioncomplete'              => 'די אַקציע אָט זיך דורכגעפֿירט',
+'deletedtext'                 => '"<nowiki>$1</nowiki>" אויסגעמעקט. זעה $2 פאר רעקארד פון לעצטיגע אויסמעקונגען.',
+'deletedarticle'              => 'אויסגעמעקט "[[$1]]"',
+'dellogpage'                  => 'אויסמעקונג לאג',
+'dellogpagetext'              => 'ווייטער איז א ליסטע פון די מערסט לעצטיגע אויסמעקונגען.',
+'deletionlog'                 => 'אויסמעקונג לאג',
+'deletecomment'               => 'סיבה פארן אויסמעקן:',
+'deletereasonotherlist'       => 'אנדער אורזאך',
+'rollback_short'              => 'אויפֿריכטן',
+'rollbacklink'                => 'צוריקדרייען',
+'cantrollback'                => 'מען קען נישט צוריקדרייען די ענדערונג – די לעצטער באטייליגער איז דער איינציגסטער באטייליגונג; פארט, קען מען אויסמעקן דעם בלאט.',
+'alreadyrolled'               => 'מען קעגן נישט צוריקדריין די לעצטע ענדערונג פון בלאט [[:$1]] דורך
+[[User:$2|$2]] ([[User talk:$2|רעדן]]| [[Special:Contributions/$2|{{int:contribslink}}]]); 
+אן אנדערער האט שוין געענדערט אדער צוריקגעדרייט דעם בלאט.
 
-דאס לעצטע ענדערונג איז געווען פון [[User:$3|$3]] ([[User talk:$3|רעדן]]).',
-'editcomment'         => "קורץ ווארט איז געווען: \"'''\$1'''\".", # only shown if there is an edit comment
-'revertpage'          => 'אויפֿגעריכט פון באַנוצער $2 צוריק צום לעצטע ווערסיע פון באַנוצער $1', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'protectlogpage'      => 'שיצן לאָג',
-'protect-level-sysop' => 'נאר סיסאפן',
-'restriction-type'    => 'ערלויבניש:',
+די לעצטע ענדערונג איז געווען פון [[User:$3|$3]] ([[User talk:$3|רעדן]]|[[Special:Contributions/$3|{{int:contribslink}}]]).',
+'editcomment'                 => "קורץ ווארט איז געווען: \"'''\$1'''\".", # only shown if there is an edit comment
+'revertpage'                  => 'אויפֿגעריכט פון באַנוצער $2 צוריק צום לעצטע ווערסיע פון באַנוצער $1', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'protectlogpage'              => 'שיצן לאָג',
+'protectcomment'              => 'הערה:',
+'protectexpiry'               => 'גייט אויס:',
+'protect_expiry_invalid'      => 'אויסגיין צײַט אומגילטיג.',
+'protect_expiry_old'          => 'שוין דערנאך דער אויסגיין צײַט.',
+'protect-unchain'             => 'אויפֿשליסן באוועגונג הרשאות',
+'protect-text'                => 'איר מעגט זען און ענדערן דעם שוץ ניווא דא פֿארן בלאט <strong><nowiki>$1</nowiki></strong>.',
+'protect-locked-blocked'      => 'איר קען נישט ענדערן דעם שוץ ניווא בעת ווען איר זענט בלאקירט.
+פֿאלגנד זענען די לויפֿיגע שטעלונגען פֿארן בלאט <strong>$1</strong>:',
+'protect-level-autoconfirmed' => 'בלאקירן נישט איינגעשריבענע באַניצערס',
+'protect-level-sysop'         => 'נאר סיסאפן',
+'protect-expiring'            => 'גייט אויס $1 (UTC)',
+'protect-cascade'             => 'שיץ בלעטער איינגעשלאסן אין דעם בלאט (קאסקאד שיץ)',
+'protect-cantedit'            => 'איר קען נישט ענדערן די שוץ ניוואען פֿון דעם בלאט, ווײַל איר האט נישט קיין רשות  צו רעדאקטירן אים.',
+'restriction-type'            => 'ערלויבניש:',
 
 # Undelete
-'cannotundelete' => 'צוריקשטעלונג איז דורכגעפאלן; עס איז מעגליך אז אן אנדערע האט דאס שוין צוריקגעשטעלט.',
+'cannotundelete'         => 'צוריקשטעלונג איז דורכגעפאלן; עס איז מעגליך אז אן אנדערע האט דאס שוין צוריקגעשטעלט.',
+'undelete-search-submit' => 'זוכן',
 
 # Namespace form on various pages
 'namespace'      => 'נאמענטייל:',
@@ -1233,17 +1268,25 @@
 
 'sp-contributions-newbies-sub' => 'פאר נייע קאנטעס',
 'sp-contributions-blocklog'    => 'בלאקירן לאג',
+'sp-contributions-submit'      => 'זוכן',
 
 # What links here
-'whatlinkshere'       => 'װאָס די אױף דאָס זײט פֿאַרבינדט',
-'whatlinkshere-title' => 'בלעטער וואס פארבינדן צו $1',
-'linklistsub'         => '(ליסטע פֿון פֿארבינדונגען)',
-'linkshere'           => "די פאלגנדע בלעטער פארבינדן צום בלאט '''[[:$1]]''':",
-'nolinkshere'         => "קיין שום בלאט פארבינדט נישט צו '''[[:$1]]'''.",
-'isredirect'          => 'ווײַטערפירן בלאט',
-'whatlinkshere-prev'  => '{{PLURAL:$1|פֿריערדיגער|$1 פֿריערדיגע}}',
-'whatlinkshere-next'  => '{{PLURAL:$1|קומענדיגער|$1 קומענדיגע}}',
-'whatlinkshere-links' => '→ פֿארבינדונגען',
+'whatlinkshere'            => 'װאָס פֿאַרבינדט דא',
+'whatlinkshere-title'      => 'בלעטער וואס פארבינדן צו $1',
+'whatlinkshere-page'       => 'בלאַט:',
+'linklistsub'              => '(ליסטע פֿון פֿארבינדונגען)',
+'linkshere'                => "די פאלגנדע בלעטער פארבינדן צום בלאט '''[[:$1]]''':",
+'nolinkshere'              => "קיין שום בלאט פארבינדט נישט צו '''[[:$1]]'''.",
+'isredirect'               => 'ווײַטערפירן בלאט',
+'istemplate'               => 'אײַנשליסן',
+'isimage'                  => 'ווײַזן א בילד',
+'whatlinkshere-prev'       => '{{PLURAL:$1|פֿריערדיגער|$1 פֿריערדיגע}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|קומענדיגער|$1 קומענדיגע}}',
+'whatlinkshere-links'      => '→ פֿארבינדונגען',
+'whatlinkshere-hideredirs' => '$1 ווײַטערפֿירונגען',
+'whatlinkshere-hidetrans'  => '$1 אַריבערשליסונגען',
+'whatlinkshere-hidelinks'  => '$1 פֿאַרבינדונגען',
+'whatlinkshere-hideimages' => '$1 בילדער פֿאַרבינדונגען',
 
 # Block/unblock
 'blockip'                  => 'באנוצער ארויסטרייבן',
@@ -1253,7 +1296,7 @@
 
 ביטע שרייבט ארויס קלאר וואס די וואנדאליזם באשטייט, און וועלכע בלאט ער האט וואנדאליזירט.',
 'ipbother'                 => 'אַנדער צײַט',
-'ipboptions'               => '15 מינוטן:15 minutes,
+'ipboptions'               => '15 מינוט:15 minutes,
 1 שעה:1 hour,
 2 שעהן:2 hours,
 1 טאָג:1 day,
@@ -1269,12 +1312,13 @@
 'badipaddress'             => 'נישט קיין גוטע אייפי אדרעס.',
 'blockipsuccesssub'        => 'בלאק איז דורכגפירט מיט סוקסעס',
 'blockipsuccesstext'       => 'באנוצער [[Special:Contributions/$1|$1]] <br />איז פארשפארט.
-זעהט די [[Special:Ipblocklist|ליסטע פון בלאקירטע באנוצער]] כדי צו זעהן די בלאקירונגן.',
+זעהט די [[Special:IPBlockList|ליסטע פון בלאקירטע באנוצער]] כדי צו זעהן די בלאקירונגן.',
 'ipblocklist'              => 'ליסטע פון בלאקירטע באניצערס',
+'ipblocklist-submit'       => 'זוכן',
 'blocklistline'            => '$1 $2 פארשפארט $3 ($4)',
 'infiniteblock'            => 'אויף אייביק',
 'anononlyblock'            => 'אנינאנימעס בלויז',
-'createaccountblock'       => 'אקאונט באשאף איז בלאקירט',
+'createaccountblock'       => 'קאנטע באשאפֿן בלאקירט',
 'emailblock'               => 'בליצפאסט בלאקירט',
 'ipblocklist-empty'        => 'בלאקירן ליסטע איז  ליידיג.',
 'blocklink'                => 'ארויסטרייבן',
@@ -1284,7 +1328,7 @@
 'blocklogpage'             => 'בלאקירן לאג',
 'blocklogentry'            => 'בלאקירט "[[$1]]" אויף אַ תקופה פון $2 $3',
 'blocklogtext'             => 'דאס איז א לאג בוך פון אלע בלאקירונגען און באפרייונגען פֿון באניצערס. איי פי אדרעסן וואס זענען בלאקירט אויטאמאטיש ווערן נישט אויסגערעכענט דא.
-זעט די איצטיגע [[Special:Ipblocklist|ליסטע פון בלאקירטע באניצערס]].',
+זעט די איצטיגע [[Special:IPBlockList|ליסטע פון בלאקירטע באניצערס]].',
 'unblocklogentry'          => 'באפֿרייט [[$1]]',
 'block-log-flags-anononly' => 'בלויז אנינאמע באנוצער',
 'block-log-flags-nocreate' => 'אקאונט באשאפען פארשפארט',
@@ -1300,17 +1344,19 @@
 'databasenotlocked' => 'די דאטעבאזע איז נישט פארשפארט.',
 
 # Move page
-'movepagetext'            => "זיך באניצן מיט דעם פארעם וועט פארענדערן דעם נאמען פון דעם בלאט, און וועט אריבערפירן זיין געשיכטע צום נייעם נאמען.
+'move-page'               => 'באַוועגן $1',
+'move-page-legend'        => 'באַוועגן בלאַט',
+'movepagetext'            => "זיך באניצן מיט דעם פֿארעם וועט פֿארענדערן דעם נאמען פֿון דעם בלאט, און וועט אריבערפֿירן זיין געשיכטע צום נייעם נאמען.
 
-דער אלטער קעפל וועט ווערן א א ווייטערפירן בלאט צום נייעם נאמען.
+דאס אלטע קעפל וועט ווערן א א ווייטערפֿירן בלאט צום נייעם נאמען.
 
-פארבינדונגען צום אלטן נאמען וועלן נישט ווערן געענדערט, דעריבער פארזיכערט אז עס איז נישטא קיין געטאפעלטע ווייטערפירונגען אדער צעבראכענע ווייטערפירונגען.
+פֿארבינדונגען צום אלטן נאמען וועלן נישט ווערן געענדערט, דעריבער פֿארזיכערט אז עס איז נישטא קיין [[Special:DoubleRedirects|געטאפלטע]] אדער [[Special:BrokenRedirects|צעבראכענע]] ווייטערפֿירונגען.
 
-איר זענט פאראנטווארטלעך זיכער מאכן אז אלע פארבינדונגען ווערן געריכטעט צו דער געהעריגער ריכטונג.
+איר זענט פֿאראנטווארטלעך זיכער מאכן אז אלע פֿארבינדונגען ווערן געריכטעט צו דער געהעריגער ריכטונג.
 
-אכטונג: דער בלאט וועט נישט ווערן אריבערגעפירט אויב עס איז שוין דא א בלאט אונטער דעם נייעם נאמען, אחוץ ווען ער איז ליידיג. אדער ער איז א ווייטערפירונג בלאט, און ער האט נישט קיין געשיכטע פון ענדערונגען. פשט דערפון, אז איר קענט איבערקערן א ווייטערפירונג וואס איר האט אט געמאכט בטעות, און איר קענט נישט אריבערשרייבן אן עקסיסטירענדן בלאט.
+אכטונג: דער בלאט וועט נישט ווערן אריבערגעפֿירט אויב עס איז שוין דא א בלאט אונטער דעם נייעם נאמען, אחוץ ווען ער איז ליידיג. אדער ער איז א ווייטערפֿירונג בלאט, און ער האט נישט קיין געשיכטע פון ענדערונגען. פשט דערפֿון, אז איר קענט איבערקערן א ווייטערפֿירונג וואס איר האט אט געמאכט בטעות, און איר קענט נישט אריבערשרייבן אן עקסיסטירנדן בלאט.
 
-'''ווארענונג:''' אזא ענדערונג קען זיין דראסטיש און נישט געווינטשען פאר א פאפולערן בלאט; ביטע פארזיכערט אז איר פארשטייט די ווייטגרייכענדע קאנסקווענסן צו דער אקציע בעפאר איר פירט דאס אויס.",
+'''ווארענונג:''' אזא ענדערונג קען זיין דראסטיש און נישט געווינטשען פאר א פאפולערן בלאט; ביטע פֿארזיכערט אז איר פֿארשטייט די ווייטגרייכנדע קאנסקווענסן צו דער אקציע בעפֿאר איר פֿירט דאס אויס.",
 'movearticle'             => 'באוועג בלאט:',
 'newtitle'                => 'צו נייעם קעפל:',
 'movepagebtn'             => 'באוועגן',
@@ -1318,32 +1364,38 @@
 'articleexists'           => 'א בלאט מיט דעם נאמען עקזיסטירט שוין, אדער די נאמען וואס איר האט אויסגעוועילט איז נישט געזעצליך.
 ביטע אויסוועילן אן אנדער נאמען.',
 'talkexists'              => "דער בלאט אליין איז באוועגט מיט דערפֿאלג, אבער דער רעדן בלאט האט מען נישט באוועגט ווײַל ס'איז שוין דא א בלאט מיט דעם זעלבן נאמען. זײַט אזוי גוט פֿאראייניגט זיי האנטלעך.",
-'movedto'                 => 'באַוועגנט צו',
+'movedto'                 => 'באַוועגט צו',
 'movetalk'                => 'באוועגט אסאסיצירטע רעדן בלאט',
 '1movedto2'               => '[[$1]] אריבערגעפירט צו [[$2]]',
-'1movedto2_redir'         => '[[$1]] באַוועגט צו [[$2]] אנשטאט רידיירעקט',
+'1movedto2_redir'         => '[[$1]] איז אַריבער צו [[$2]] אַנטשטאָט א ווײַטערפֿירונג',
 'movelogpage'             => 'באוועגן לאג',
 'revertmove'              => 'צוריקדרייען',
 'delete_and_move'         => 'אויסמעקן און באוועגן',
 'delete_and_move_text'    => '== אויסמעקן פארלאנגט ==
-די ציל באלט "[[$1]]" עקזיסטירט שוין. ווילט איר דאס אויסמעקן כדי צו ערמעגליכן דעם באוועגונג?',
+די ציל באלט "[[:$1]]" עקזיסטירט שוין. ווילט איר דאס אויסמעקן כדי צו ערמעגליכן דעם באוועגונג?',
 'delete_and_move_confirm' => 'יא, מעק אויס דעם בלאט',
 'delete_and_move_reason'  => 'אויסמעקן כדי צו קענען באוועגן',
 
 # Export
-'exporttext'      => "איר קענט עקפארטן די טעקסט און ענדערונג היסטאריע פון א פארטיקולער בלאט אדער פאר פון בלעטער ארומגענומען מיט אביסל XML. דאס קען ווערן אימפארטעט אין צו א אנדער וויקי נוצענדיג מעדיע-וויקי דורך
-די [[ספעציעל:אימפארט|אימפארט בלאט]].
+'export'            => 'עקספארטירן בלעטער',
+'exporttext'        => "איר קענט עקפארטן די טעקסט און ענדערונג היסטאריע פון א פארטיקולער בלאט אדער פאר פון בלעטער ארומגענומען מיט אביסל XML. דאס קען ווערן אימפארטעט אין צו א אנדער וויקי נוצנדיג מעדיע-וויקי דורך
+דעם [[ספעציעל:אימפארט|אימפארט בלאט]].
 
-צו עקספארטירן בלעטער, לייגט אריין די טיטול'ען אין די טעקסט באקס פון אונטן, איין טיטול פער ליין, און סעלעקטיר אויב דו דארפסט דעם ווערסיע, ווי אויך די אלטע ווערסיעס, מיט די בלאט היסטאריע ליין'ס, אדער בלויז די איצטיגע ווערסיע מיט די קורץ ווארט אינפארמאציע פונעם לעצטן ענדערונג.
+צו עקספארטירן בלעטער, לייגט אריין די טיטול'ען אין די טעקסט באקס פון אונטן, איין טיטול פער ליין, און סעלעקטיר אויב דו דארפסט דעם ווערסיע, ווי אויך די אלטע ווערסיעס, מיט די בלאט היסטאריע ליין'ס, אדער בלויז די איצטיגע ווערסיע מיט דער קורץ ווארט אינפארמאציע פון דער לעצטער ענדערונג.
 
-אין די לעצטער פאל קענט איר אויך נוצן א לינק, e.g. [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] פאר די בלאט {{MediaWiki:Mainpage}}.",
-'exportcuronly'   => 'רעכן אריין בלויז די איצטיגע רע-ווערסיע, נישט די פולער היסטאריע',
-'exportnohistory' => "----
+אין די לעצטער פאל קענט איר אויך נוצן א לינק, e.g. [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] פארן בלאט {{MediaWiki:Mainpage}}.",
+'exportcuronly'     => 'רעכן אריין בלויז די איצטיגע רע-ווערסיע, נישט די פולער היסטאריע',
+'exportnohistory'   => "----
 '''באמערקונג:''' עקספארטירן די פולער היסטאריע פון בלעטער דורך די פארעם איז געווארן אומ-ערמעגליכט צוליב פערפארמענס סיבות.",
+'export-submit'     => 'עקספארט',
+'export-addcattext' => 'צולייגן בלעטער פֿון דער קאַטעגאריע:',
+'export-addcat'     => 'צולייגן',
+'export-download'   => 'אויפֿהיטן אלס טעקע',
+'export-templates'  => 'אײַנשליסן מוסטערן',
 
 # Namespace 8 related
-'allmessages'               => 'סיסטעם מעסעזשעס',
-'allmessagesname'           => 'נאמען',
+'allmessages'               => 'סיסטעם מעלדונגען',
+'allmessagesname'           => 'נאָמען',
 'allmessagesdefault'        => 'דיפאלט טעקסט',
 'allmessagescurrent'        => 'איצטיגער טעקסט',
 'allmessagestext'           => 'אט דאס איז א ליסטע פון אלע סיסטעם מעלדונגען וואס זענען פאראן אין דעם  {{ns:mediawiki}}  נאמענטייל, וואס באדינען דעם אויפהאלט פונעם סייט.
@@ -1352,11 +1404,12 @@
 
 ביטע באזוכט [http://www.mediawiki.org/wiki/Localisation מעדיעוויקי לאקאליזאציע] און [http://translatewiki.net בעטאוויקי] אויב איר ווילט ביישטייערן צו דער גענערישער מעדיעוויקי לאקאליזאציע.',
 'allmessagesnotsupportedDB' => 'מען קען זיך נישט באניצן מיט דעם בלאט וויבאלד די $wgUseDatabseMessages איז געווארן בטל.',
-'allmessagesfilter'         => 'מעסעדזש נאמען פילטער:',
-'allmessagesmodified'       => 'ווייז נאר מאדיפיצירטע',
+'allmessagesfilter'         => 'מעלדונג נאמען פֿילטער:',
+'allmessagesmodified'       => 'ווײַזן נאר מאדיפֿיצירטע',
 
 # Thumbnails
 'thumbnail-more'           => 'פארגרעסער',
+'filemissing'              => 'טעקע פֿעלט',
 'thumbnail_error'          => 'גרײַז בײַם באשאפֿן דאס קליינבילד: $1',
 'djvu_page_error'          => 'DjVu בלאט ארויס פֿון גרייך',
 'djvu_no_xml'              => "מ'קען נישט באקומען דעם XML פֿאַר דער DjVu טעקע",
@@ -1364,12 +1417,25 @@
 'thumbnail_dest_directory' => "מ'קען נישט שאפֿן דעם ציל קארטאטעק",
 
 # Special:Import
-'import'                => 'אימפארטירן בלעטער',
-'importinterwiki'       => 'אריבערוויקי אימפארט',
-'importbadinterwiki'    => 'שלעכטע אינטערוויקי לינק',
-'importnotext'          => 'ליידיג אדער נישט קיין טעקסט',
-'importsuccess'         => '!אימפארט אדורכגעפירט מיט דערפאלג!',
-'importhistoryconflict' => 'קאנפליקטינג היסטאריע רעוויזיע עקזעסטירט (מעגליך אז די בלאט איז געווארן אימפארטעט שוין פון פריער)',
+'import'                     => 'אימפארטירן בלעטער',
+'importinterwiki'            => 'אריבערוויקי אימפארט',
+'import-interwiki-text'      => 'קלויבט אויס א וויקי און אן ארטיקל קעפל צו אימפארטירן.
+די דאטעס און די נעמען פון די רעדאקטארן וועט ווערן געהיטן.
+אלע צווישנוויקי אימפארט אקציעס ווערן פארשריבן אינעם   [[Special:Log/import|אימפארט לאג]].',
+'import-interwiki-history'   => 'קאפירן אלע היסטאריע ווערסיעס פאר דעם בלאט',
+'import-interwiki-submit'    => 'אימפארט',
+'import-interwiki-namespace' => 'אריבערפֿירן בלעטער אין נאמענטייל:',
+'importtext'                 => 'ביטע עקספארטירט די טעקע פון דער מקור וויקי ניצנדיג דאס [[Special:Export|עקספארט הילפמיטל]], שפייכלט איין אויף אייער הארטדיסק און לאדט אויף דא.',
+'importstart'                => 'אימפארטירט בלעטער…',
+'import-revision-count'      => '{{PLURAL:$1|איין ווערסיע|$1 ווערסיעס}}',
+'importnopages'              => 'נישטא קיין בלעטער צו אימפארטירן.',
+'importfailed'               => 'אימפארט דורכגעפֿאלן: <nowiki>$1</nowiki>',
+'importunknownsource'        => 'אומבאקאנטער  אימפארט טיפ',
+'importcantopen'             => 'נישט געקענט עפֿענען אימפארט טעקע',
+'importbadinterwiki'         => 'שלעכטע אינטערוויקי לינק',
+'importnotext'               => 'ליידיג אדער נישט קיין טעקסט',
+'importsuccess'              => '!אימפארט אדורכגעפירט מיט דערפאלג!',
+'importhistoryconflict'      => 'קאנפליקטינג היסטאריע רעוויזיע עקזעסטירט (מעגליך אז די בלאט איז געווארן אימפארטעט שוין פון פריער)',
 
 # Import log
 'importlogpage'             => 'אימפארט לאג',
@@ -1416,10 +1482,10 @@
 'tooltip-t-upload'                => 'לייגט ארויף פיילס און בילדער',
 'tooltip-t-specialpages'          => 'אלע ספעציעלע בלעטער',
 'tooltip-t-print'                 => 'דרוק ווערסיע פון דעם בלאט',
-'tooltip-ca-nstab-main'           => 'זעהט די אינהאלט בלאט',
+'tooltip-ca-nstab-main'           => 'זעט דעם אינהאַלט בלאַט',
 'tooltip-ca-nstab-user'           => 'זעט דעם באניצער בלאט',
 'tooltip-ca-nstab-media'          => 'קוקט אין די מידיע בלעטער',
-'tooltip-ca-nstab-special'        => "דאס איז א ספעציעלע בלאט, מ'קען איר נישט ענדערן",
+'tooltip-ca-nstab-special'        => "דאס איז א ספעציעלער בלאט, מ'קען אים נישט ענדערן",
 'tooltip-ca-nstab-project'        => 'זעהט די פראיעקט בלאט',
 'tooltip-ca-nstab-image'          => 'באקוקט דעם טעקע בלאט',
 'tooltip-ca-nstab-mediawiki'      => 'זעהט די סיסטעם מעסעזשעס',
@@ -1442,7 +1508,7 @@
 'common.js' => '/* אלע סקריפטן פון JavaScript דא געשריבן וועט לויפן פאר אלע באנוצער ווען זיי וועלן לאדירן דעם בלאט */',
 
 # Attribution
-'anonymous'        => 'אנינאנימעס באנוצער(ס) פון {{SITENAME}}',
+'anonymous'        => 'אַנאָנימע/ר באַניצער(ס) פֿון {{SITENAME}}',
 'lastmodifiedatby' => 'די לעצטע ענדערונג פון די בלאט איז געווען $2, $1 ביי $3.', # $1 date, $2 time, $3 user
 'othercontribs'    => 'באזירט אויף ארבעט פון $1.',
 'others'           => 'אנדערע',
@@ -1472,22 +1538,25 @@
 'show-big-image'       => 'בילד מיט דער גרעסטער רעזאלוציע',
 'show-big-image-thumb' => '<small>גרייס פון דער ווײַזונג: $1 × $2 פיקסעלן</small>',
 
-# Special:Newimages
-'newimages'         => 'גאַלעריע פֿון נײַע בילדער',
-'imagelisttext'     => 'פאלגנד א ליסטע פון {{PLURAL:$1|איין בילד|$1 בילדער}}, סארטירט $2:',
-'newimages-summary' => 'דער באזונדערער בלאט ווײַזט די לעצטע ארויפגעלאדענע טעקעס',
-'showhidebots'      => '($1 ראָבאָטן)',
-'noimages'          => 'נישטא קיין בילדער.',
-'ilsubmit'          => 'זוכן',
-'bydate'            => 'לויטן דאטום',
+# Special:NewImages
+'newimages'             => 'גאַלעריע פֿון נײַע בילדער',
+'imagelisttext'         => 'פאלגנד א ליסטע פון {{PLURAL:$1|איין בילד|$1 בילדער}}, סארטירט $2:',
+'newimages-summary'     => 'דער באזונדערער בלאט ווײַזט די לעצטע ארויפגעלאדענע טעקעס',
+'showhidebots'          => '($1 ראָבאָטן)',
+'noimages'              => 'נישטא קיין בילדער.',
+'ilsubmit'              => 'זוכן',
+'bydate'                => 'לויטן דאטום',
+'sp-newimages-showfrom' => 'באַװײַזן נײַע טעקעס פון־$2, $1',
 
 # Bad image list
-'bad_image_list' => 'דער פארמאט איז אזוי:
+'bad_image_list' => 'דער פֿאָרמאַט איז װי פֿאָלגנדיק:
 
-רק פריטי רשימה (שורות המתחילות עם *) נחשבים.
-הקישור הראשון בשורה חייב להיות קישור לתמונה שאין להציג.
-כל הקישורים הבאים באותה השורה נחשבים לחריגים, כלומר לדפים שבהם ניתן להציג את התמונה.',
+נאר חלקים פון אַ רשימה (שורות װעלכע הײבן זיך אָן מיט *) זײַנען אין באַטראַכט.
 
+דער ערשטער פֿאַרבינדונג אין אַ שורה מוז זײַן אַ פֿאַרבינדונג צו אַ שלעכטער טעקע.
+
+אַלע פֿאָלגנדיקע פֿאַרבינדונגען אין דער זעלבער שורה זײַנען גערעכנט װי אַן אױסנאַם, װי צום בײַשפּיל, בלעטער װעלכע די טעקע קען װערן געפֿאַלן אין קאָנטינואיטער.',
+
 # Metadata
 'metadata'          => 'מעטאדאטע',
 'metadata-help'     => 'די טעקע אנטהאלט נאך אינפֿארמאציע, אפשר פֿונעם דיגיטאלן אפאראט אדער סקענער וואס האט באשאפֿן דאס בילד.
@@ -1607,7 +1676,7 @@
 
 # External editor support
 'edit-externally'      => 'עדיט די פייל דורך א דערויסענדיגער אפליקאציע',
-'edit-externally-help' => 'זעהט די [http://meta.wikimedia.org/wiki/Help:External_editors סעטאפ אנווייזונגען] פאר מער אינפארמאציע.',
+'edit-externally-help' => 'זעהט די [http://www.mediawiki.org/wiki/Manual:External_editors סעטאפ אנווייזונגען] פאר מער אינפארמאציע.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'אַלע',
@@ -1681,11 +1750,48 @@
 'livepreview-loading' => 'לאדנדיג…',
 'livepreview-ready'   => 'לאדנדיג… גרייט!',
 
+# Watchlist editing tools
+'watchlisttools-edit' => 'זען און רעדאקטירן די אויפֿפאסונג ליסטע',
+'watchlisttools-raw'  => 'רעדאקטירן די רויע אויפֿפאסונג ליסטע',
+
+# Iranian month names
+'iranian-calendar-m1'  => 'פֿאַרוואַרדין',
+'iranian-calendar-m2'  => 'ארדיבעהעשט',
+'iranian-calendar-m3'  => 'כארדאַד',
+'iranian-calendar-m4'  => 'טיר',
+'iranian-calendar-m5'  => 'מארדאַד',
+'iranian-calendar-m6'  => 'שאַהריוואַר',
+'iranian-calendar-m7'  => 'מעהר',
+'iranian-calendar-m8'  => 'אַבאַן',
+'iranian-calendar-m9'  => 'אַזאַר',
+'iranian-calendar-m10' => 'דיי',
+'iranian-calendar-m11' => 'באַהמאַן',
+'iranian-calendar-m12' => 'עספֿאַנד',
+
 # Special:Version
 'version'              => 'ווערסיע', # Not used as normal message but as header for the special page itself
 'version-specialpages' => 'ספעציעלע בלעטער',
 
 # Special:SpecialPages
-'specialpages' => 'ספּעציעלע זײטן',
+'specialpages'                   => 'ספּעציעלע זײטן',
+'specialpages-note'              => '----
+* נארמאַלע ספעציעלע בלעטער.
+* <span class="mw-specialpagerestricted">באַגרענעצטע ספעציעלע בלעטער.</span>',
+'specialpages-group-maintenance' => 'אויפֿהאַלטונג באַריכטן',
+'specialpages-group-other'       => 'אַנדערע ספעציעלע בלעטער',
+'specialpages-group-login'       => 'ארײַנלאגירן / אײַנשרײַבן',
+'specialpages-group-changes'     => 'לעצטע ענדערונגען און לאג-ביכער',
+'specialpages-group-media'       => 'מעדיע באַריכטן און ארויפֿלאדן',
+'specialpages-group-users'       => 'באַניצערס און רעכטן',
+'specialpages-group-highuse'     => 'בלעטער וואס זענען געניצט אסאך',
+'specialpages-group-pages'       => 'ליסטעס פֿון בלעטער',
+'specialpages-group-pagetools'   => 'געצייג פֿאר בלעטער',
+'specialpages-group-wiki'        => 'וויקי דאַטן און געצייג',
+'specialpages-group-redirects'   => 'ווײַטערפֿירן ספעציעלע בלעטער',
+'specialpages-group-spam'        => 'ספאַם געצייג',
 
+# Special:BlankPage
+'blankpage'              => 'ליידיגער בלאַט',
+'intentionallyblankpage' => 'דער בלאַט איז ליידיג בכוונה',
+
 );
Index: languages/messages/MessagesUdm.php
===================================================================
--- languages/messages/MessagesUdm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesUdm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,6 +3,9 @@
  *
  * @ingroup Language
  * @file
+ *
+ * @author ОйЛ
+ * @author לערי ריינהארט
  */
 
 $fallback = 'ru';
@@ -35,27 +38,76 @@
 $messages = array(
 'linkprefix' => '/^(.*?)(„|«)$/sDu',
 
-'article' => 'Статья',
-'mytalk'  => 'викиавтор сярысь вераськон',
+'article'        => 'Статья',
+'qbspecialpages' => 'Панельёс',
+'mytalk'         => 'викиавтор сярысь вераськон',
 
-'history'       => 'Бамлэн историез',
-'history_short' => 'история',
-'edit'          => 'тупатыны',
+'help'             => 'Валэктонъёс',
+'history'          => 'Бамлэн историез',
+'history_short'    => 'история',
+'printableversion' => 'Печатламон версия',
+'permalink'        => 'Ӵапак та версиезлы линк',
+'edit'             => 'тупатыны',
+'delete'           => 'Быдтыны',
+'protect'          => 'Утьыны',
+'talk'             => 'Вераськон',
 
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'currentevents'        => 'Выль иворъёс',
+'currentevents-url'    => 'Project:Выль иворъёс',
+'helppage'             => 'Help:Валэктон',
+'mainpage'             => 'Кутскон бам',
+'mainpage-description' => 'Кутскон бам',
+
+'editsection' => 'тупатыны',
+
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-user' => 'викиавтор',
 
+# General errors
+'viewsource' => 'Кодзэ учкыны',
+
 # Login and logout pages
 'login'         => 'Википедие пырон',
+'logout'        => 'Кошкыны',
+'userlogout'    => 'Кошкыны',
 'createaccount' => 'выль вики-авторлэн регистрациез',
 
 # Preferences page
 'preferences' => 'настройкаос',
 
 # Recent changes
-'hist' => 'история',
+'recentchanges' => 'Выль тупатонъёс',
+'hist'          => 'история',
 
+# Recent changes linked
+'recentchangeslinked' => 'Герӟаськем тупатонъёс',
+
+# Upload
+'upload' => 'Файл поныны',
+
+# Random page
+'randompage' => 'Олокыӵе статья',
+
+# Miscellaneous special pages
+'move' => 'Мукет интые выжтыны',
+
+# Watchlist
+'watchlist' => 'Чаклано статьяос',
+'watch'     => 'Чаклано',
+'unwatch'   => 'Чакламысь дугдыны',
+
 # Contributions
 'mycontris' => 'мынам статьяосы',
 
+# What links here
+'whatlinkshere' => 'Татчы линкъёс',
+
+# Move page
+'movearticle'     => 'Статьяез мукет интые выжтыны',
+'delete_and_move' => 'Быдтыны но мукет интые выжтыны',
+
+# Special:SpecialPages
+'specialpages' => 'Ваньмыз панельёс',
+
 );
Index: languages/messages/MessagesFa.php
===================================================================
--- languages/messages/MessagesFa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author Roozbeh Pournader <roozbeh at gmail.com>
  * @author G - ג
- * @author Huji <huji.huji at gmail.com>
- * @author Gangleri
  * @author Huji
+ * @author Huji <huji.huji at gmail.com>
  * @author Mardetanha
+ * @author Roozbeh Pournader <roozbeh at gmail.com>
  * @author לערי ריינהארט
- * @author Siebrand
  */
 
 $skinNames = array(
@@ -786,13 +784,14 @@
 'summary-preview'                  => 'پیش‌نمایش خلاصه',
 'subject-preview'                  => 'پیش‌نمایش موضوع/عنوان',
 'blockedtitle'                     => 'کاربر بسته شد.',
-'blockedtext'                      => "'''نام کاربری یا نشانی IP شما بسته شده است.'''
+'blockedtext'                      => "<big>'''دسترسی نام کاربری یا نشانی اینترنتی شما بسته شده است.'''</big>
 
-این کار توسط $1 انجام شده‌است. دلیل داده‌شده این است:<br />''$2''<p>
+این کار توسط $1 انجام شده‌است.
+دلیل داده‌شده این است: $2''
 
 * شروع قطع دسترسی: $8
 * زمان پایان این قطع دسترسی: $6
-* کاربری که دسترسی‌اش قطع شده: $7
+* کاربری که قطع دسترسی‌اش مد نظر بوده: $7
 
 شما می‌توانید با $1 یا یکی از [[{{MediaWiki:Grouppage-sysop}}|مدیران]] تماس بگیرید و در این باره صحبت کنید.
 
@@ -800,10 +799,10 @@
 
 نشانی IP شما $3 و شماره قطع دسترسی شما $5 است. لطفاً این شماره‌ها را در کلیهٔ پرس‌وجوهایتان ذکر کنید.
 
-==نکته برای کاربران AOL==
-به خاطر اعمال تخریبی یک کاربر مشخص AOL، {{SITENAME}} معمولاً proxyهای AOL را می‌بندد. متأسفانه ممکن است تعداد زیادی از کاربران AOL از یک خادم proxy واحد استفاده کنند، و در نتیجه کاربران بی‌تقصیر AOL معمولاً ندانسته بسته می‌شوند. از دردسر ایجادشده عذر می‌خواهیم.
-
-اگر این اتفاق برای شما افتاد، لطفاً به یکی از مدیران از یک نشانی پست الکترونیکی AOL پیغام بفرستید. حتماً نشانی IP خود را مطابق آن چه بالاتر گفته شده در پیغامتان ذکر کنید.",
+شما می‌توانید با $1 یا یکی دیگر از [[{{MediaWiki:Grouppage-sysop}}|مدیران]] تماس بگیرید، تا در مورد این قطع دسترسی صحبت کنید.
+توجه کنید که برای ارسال پست الکترونیکی در ویکی، باید پست الکترونیکی خود را از طریق صفحهٔ [[Special:Preferences|تنظیمات]] فعال کرده باشید، و نیز، باید امکان استفاده از این ویژگی برای شما قطع نباشد.
+نشانی اینترنتی فعلی شما $3 است و شماره قطع دسترسی $5 است.
+لطفاً این شماره را در هر درخواستی که در این باره مطرح می‌کنید قید کنید.",
 'autoblockedtext'                  => "دسترسی نشانی اینترنتی (IP) شما قطع شده‌است، چرا که این نشانی اینترنتی توسط یک کاربر استفاده می‌شده که دسترسی او توسط $1 قطع گردیده‌است.
 علت ذکر شده چنین است:
 
@@ -811,22 +810,19 @@
 
 * شروع قطع دسترسی: $8
 * پایان قطع دسترسی: $6
+* کاربری که قطع دسترسی‌اش مد نظر بوده: $7
 
 شما می‌توانید با $1 یا یکی دیگر از [[{{MediaWiki:Grouppage-sysop}}|مدیران]] تماس بگیرید، تا در مورد این قطع دسترسی صحبت کنید.
 
 توجه کنید که برای ارسال پست الکترونیکی در ویکی، باید پست الکترونیکی خود را از طریق صفحهٔ [[Special:Preferences|تنظیمات]] فعال کرده باشید، و نیز، باید امکان استفاده از این ویژگی برای شما قطع نباشد.
 
-شماره قطع دسترسی شما $5 است. لطفاً این شماره را در هر درخواستی که در این باره مطرح می‌کنید قید کنید.",
+نشانی اینترنتی فعلی شما $3 است و شماره قطع دسترسی $5 است.
+لطفاً این شماره را در هر درخواستی که در این باره مطرح می‌کنید قید کنید.",
 'blockednoreason'                  => 'دلیلی مشخص نشده‌است',
 'blockedoriginalsource'            => "متن مبدأ '''$1''' در زیر نمایش داده شده است:",
 'blockededitsource'                => "متن '''ویرایش‌های شما''' در '''$1''' در زیر نشان داده شده‌است:",
 'whitelistedittitle'               => 'برای ویرایش باید به سیستم وارد شوید.',
 'whitelistedittext'                => 'برای ویرایش مقاله‌ها باید به سیستم شوید: $1.',
-'whitelistreadtitle'               => 'برای خواندن باید به سیستم وارد شوید',
-'whitelistreadtext'                => 'برای خواندن مقاله‌ها باید [[Special:Userlogin|به سیستم وارد شوید]].',
-'whitelistacctitle'                => 'شما مجاز نیستید حساب درست کنید.',
-'whitelistacctext'                 => 'برای ایجاد حساب در این ویکی باید [[Special:Userlogin|به سیستم وارد شوید]] و اجازه
-‌های مربوط به این کار را داشته باشید.',
 'confirmedittitle'                 => 'تأیید نشانی پست الکترونیکی، برای ویرایش، لازم است.',
 'confirmedittext'                  => 'شما باید، پیش از ویرایش صفحه‌ها، نشانی پست الکترونیکی خود را مشخص و تأیید کنید. لطفاً از طریق [[Special:Preferences|ترجیحات کاربر]] این کار را صورت دهید.',
 'nosuchsectiontitle'               => 'چنین بخشی وجود ندارد',
@@ -844,7 +840,7 @@
 بنابراین برای شناسایی‌اش مجبوریم از نشانی IP عددی استفاده کنیم.
 چنین نشانی‌های IPای ممکن است توسط چندین کاربر به شکل مشترک استفاده شود.
 اگر شما کاربر گمنامی هستید و تصور می‌کنید اظهار نظرات نامربوط به شما صورت گرفته است،
-لطفاً برای پیشگیری از اشتباه گرفته شدن با کاربران گمنام دیگر در آیند [[Special:Userlogin|حسابی ایجاد کنید یا به سیستم وارد شوید]].''",
+لطفاً برای پیشگیری از اشتباه گرفته شدن با کاربران گمنام دیگر در آیند [[Special:UserLogin|حسابی ایجاد کنید یا به سیستم وارد شوید]].''",
 'noarticletext'                    => 'در حال حاضر این صفحه متنی ندارد، شما می‌توانید [[Special:Search/{{PAGENAME}}|عنوان این صفحه را در صفحه‌های دیگر جستجو کنید]] یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} این صفحه را ویرایش کنید].',
 'userpage-userdoesnotexist'        => 'حساب کاربر «$1» ثبت نشده است. اطمینان حاصلی کنید که می‌خواهید این صفحه را ایجاد یا ویرایش کنید.',
 'clearyourcache'                   => "'''نکته:''' پس از ذخیره‌سازی ممکن است برای دیدن تغییرات نیاز باشد که حافظهٔ نهانی مرورگر خود را خالی کنید. '''موزیلا / فایرفاکس / Safari:'''  کلید '''Shift''' را نگه‌دارید و روی دکمهٔ '''Reload''' کلیک کنید، یا کلید‌های '''Ctrl-Shift-R''' را با هم فشار دهید (در رایانه‌های اپل مکینتاش کلید‌های '''Cmd-Shift-R''')؛ '''اینترنت اکسپلورر:''' کلید '''Ctrl''' نگه‌دارید و روی دکمهٔ '''Refresh''' کلیک‌ کنید، یا کلید‌های '''Ctrl-F5''' را با هم فشار دهید؛ '''Konqueror:''' روی دکمهٔ '''Reload''' کلیک کنید و یا کلید '''F5''' را فشار دهید؛ '''اُپرا:''' کاربران اُپرا ممکن است لازم باشد که بطور کامل حافظهٔ نهانی مرورگر را در منوی ''Tools&rarr;Preferences'' خالی کنند.",
@@ -902,7 +898,7 @@
 'hiddencategories'                 => 'این صفحه در {{PLURAL:$1|یک ردهٔ پنهان|$1 ردهٔ پنهان}} قرار دارد:',
 'edittools'                        => '<!-- متن این قسمت زیر صفحه‌های ویرایش و بارگذاری نشان داده می‌شود -->',
 'nocreatetitle'                    => 'ایجاد صفحه محدود شده‌است.',
-'nocreatetext'                     => 'این وبگاه قابلیت ایجاد صفحه‌های جدید را محدود کرده‌است. می‌توانید بازگردید و صفحه‌ای موجود را ویرایش کنید یا اینکه  [[Special:Userlogin|به سیستم وارد شوید یا حساب کاربری ایجاد کنید]].',
+'nocreatetext'                     => 'این وبگاه قابلیت ایجاد صفحه‌های جدید را محدود کرده‌است. می‌توانید بازگردید و صفحه‌ای موجود را ویرایش کنید یا اینکه  [[Special:UserLogin|به سیستم وارد شوید یا حساب کاربری ایجاد کنید]].',
 'nocreate-loggedin'                => 'شما اجازهٔ ایجاد صفحه‌های جدید در این ویکی را ندارید.',
 'permissionserrors'                => 'خطای سطح دسترسی',
 'permissionserrorstext'            => 'شما اجازهٔ انجام این کار را به {{PLURAL:$1|دلیل|دلایل}} زیر ندارید:',
@@ -1010,7 +1006,7 @@
 # Suppression log
 'suppressionlog'     => 'سیاههٔ فرونشانی',
 'suppressionlogtext' => 'در زیر فهرستی از آخرین حذف‌ها و قطع دسترسی‌هایی که حاوی محتوایی هستند که از مدیران پنهان شده‌اند را می‌بینید. 
-برای مشاهدهٔ فهرستی از قطع دسترسی‌های فعال [[Special:Ipblocklist|فهرست قطع‌دسترسی‌ها]] را ببینید.',
+برای مشاهدهٔ فهرستی از قطع دسترسی‌های فعال [[Special:IPBlockList|فهرست قطع‌دسترسی‌ها]] را ببینید.',
 
 # History merging
 'mergehistory'                     => 'ادغام تاریخچه صفحه‌ها',
@@ -1098,7 +1094,7 @@
 'mypreferences'            => 'ترجیحات من',
 'prefs-edits'              => 'تعداد ویرایش‌ها',
 'prefsnologin'             => 'به سیستم وارد نشده‌اید',
-'prefsnologintext'         => 'برای تنظیم ترجیحات کاربر باید [[Special:Userlogin|به سیستم وارد شوید]].',
+'prefsnologintext'         => 'برای تنظیم ترجیحات کاربر باید [[Special:UserLogin|به سیستم وارد شوید]].',
 'prefsreset'               => 'ترجیحات از حافظه میزان شد.',
 'qbsettings'               => 'تنظیمات نوار سریع',
 'qbsettings-none'          => 'نباشد',
@@ -1171,7 +1167,7 @@
 'userrights-reason'           => 'علت تغییر:',
 'userrights-no-interwiki'     => 'شما اجازه تغییر اختیارات کاربران دیگر ویکی‌ها را ندارید.',
 'userrights-nodatabase'       => 'پایگاه داده $1 وجود ندارد یا محلی نیست.',
-'userrights-nologin'          => 'شما باید با یک حساب کاربری دارای اختیار مدیریتی [[Special:Userlogin|به سیستم وارد شوید]] تا بتوانید اختیارات کاربران را تعیین کنید.',
+'userrights-nologin'          => 'شما باید با یک حساب کاربری دارای اختیار مدیریتی [[Special:UserLogin|به سیستم وارد شوید]] تا بتوانید اختیارات کاربران را تعیین کنید.',
 'userrights-notallowed'       => 'حساب کاربری شما اجازه تغییر اختیارات کاربری را ندارد.',
 'userrights-changeable-col'   => 'گروه‌هایی که می‌توانید تغییر دهید',
 'userrights-unchangeable-col' => 'گروه‌هایی که نمی‌توانید تغییر دهید',
@@ -1271,7 +1267,7 @@
 'rcshowhidebots'                    => 'ربات‌ها $1',
 'rcshowhideliu'                     => 'کاربران ثبت‌نام‌کرده $1',
 'rcshowhideanons'                   => 'کاربران ناشناس $1',
-'rcshowhidepatr'                    => 'ویرایش‌های گشتی $1',
+'rcshowhidepatr'                    => 'ویرایش‌های گشت‌خورده $1',
 'rcshowhidemine'                    => 'ویرایش‌های من $1',
 'rclinks'                           => 'نمایش آخرین $1 تغییر در $2 روز اخیر؛ $3',
 'diff'                              => 'تفاوت',
@@ -1302,12 +1298,12 @@
 'reupload'                    => 'بارگذاری دوباره',
 'reuploaddesc'                => 'بازگشت به فرم بارگذاری',
 'uploadnologin'               => 'به سیستم وارد نشده‌اید',
-'uploadnologintext'           => 'برای بار کردن پرونده‌ها باید [[Special:Userlogin|وارد سیستم شوید]].',
+'uploadnologintext'           => 'برای بار کردن پرونده‌ها باید [[Special:UserLogin|وارد سیستم شوید]].',
 'upload_directory_missing'    => 'شاخهٔ بارگذاری ($1) وجود ندارد و قابل ایجاد نیست.',
 'upload_directory_read_only'  => 'شاخهٔ بارگذاری ($1) از طرف کارگزار وب قابل نوشتن نیست.',
 'uploaderror'                 => 'خطا در بار کردن',
 'uploadtext'                  => "از فرم زیر برای بارگذاری کردن پرونده‌های جدید استفاده کنید. برای دیدن پرونده‌هایی که قبلاً بارگذاری شده‌اند به 
-[[Special:Imagelist|فهرست پرونده‌ها]] بروید. بارگذاری و حذف پرونده‌ها هم‌چنین در [[Special:Log/upload|سیاههٔ بارگذاری‌ها]] ثبت می‌شود.
+[[Special:ImageList|فهرست پرونده‌ها]] بروید. بارگذاری و حذف پرونده‌ها هم‌چنین در [[Special:Log/upload|سیاههٔ بارگذاری‌ها]] ثبت می‌شود.
 
 بعد از این که پرونده‌ای را بارگذاری کردید، به این سه شکل می‌توانید آن را در صفحه‌ها استفاده کنید:
 
@@ -1396,7 +1392,7 @@
 'upload_source_url'  => '(یک نشانی اینترنتی معتبر و قابل دسترسی برای عموم)',
 'upload_source_file' => '(پرونده‌ای در رایانهٔ شما)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'این صفحهٔ ویژه تمام پرونده‌های بارگذاری شده را نشان می‌دهد.
 به طور پیش‌فرض آخرین پرونده‌های بازگذاری شده بالاتر نمایش داده می‌شوند.
 کلیک کردن روی عنوان ستون‌ها باعث تغییر ترتیب نمایش پرونده‌ها می‌شود.',
@@ -1424,7 +1420,7 @@
 'imagelinks'                     => 'پیوند‌های تصویر',
 'linkstoimage'                   => '{{PLURAL:$1|صفحهٔ|صفحه‌های}} زیر به این تصویر پیوند {{PLURAL:$1|دارد|دارند}}:',
 'nolinkstoimage'                 => 'هیچ صفحه‌ای به این تصویر پیوند ندارد.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|پیوندهای دیگر]] به این پرونده را ببینید.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|پیوندهای دیگر]] به این پرونده را ببینید.',
 'redirectstofile'                => '{{PLURAL:$1|پروندهٔ|پرونده‌های}} زیر به این صفحه تغییر مسیر {{PLURAL:$1|می‌دهد|می‌دهند}}:',
 'duplicatesoffile'               => '{{PLURAL:$1|پروندهٔ|پرونده‌های}} زیر نسخهٔ تکراری این پرونده {{PLURAL:$1|است|هستند}}:',
 'sharedupload'                   => 'این پرونده یک بارگذاری اشتراکی است و ممکن است از طریق دیگر پروژه‌ها هم قابل دسترسی باشد.',
@@ -1520,8 +1516,10 @@
 این صفحه‌ها باید به جای آن به یک عنوان مناسب پیوند داشته باشند.<br />
 یک صفحه در صورتی که از الگویی که در [[MediaWiki:Disambiguationspage]] پیوند شده باشد در آن استفاده شده باشد به عنوان یک صفحهٔ ابهام‌زدایی در نظر گرفته می‌شود.",
 
-'doubleredirects'     => 'تغییرمسیرهای دوتایی',
-'doubleredirectstext' => 'هر سطر دربردارندهٔ پیوندهایی به تغییر مسیر اول و دوم و همچنین خط نخست متن تغییر مسیر دوم است. معمولاً صفحهٔ مقصد واقعی که نخستین تغییرمسیر باید به آن باشد به این گونه مشخص می‌شود.',
+'doubleredirects'            => 'تغییرمسیرهای دوتایی',
+'doubleredirectstext'        => 'هر سطر دربردارندهٔ پیوندهایی به تغییر مسیر اول و دوم و همچنین خط نخست متن تغییر مسیر دوم است. معمولاً صفحهٔ مقصد واقعی که نخستین تغییرمسیر باید به آن باشد به این گونه مشخص می‌شود.',
+'double-redirect-fixed-move' => '[[$1]] انتقال داده شده‌است، و در حال حاضر تغییر مسیری به [[$2]] است',
+'double-redirect-fixer'      => 'تعمیرکار تغییر مسیرها',
 
 'brokenredirects'        => 'تغییرمسیرهای خراب',
 'brokenredirectstext'    => 'تغییرمسیرهای زیر به یک صفحهٔ ناموجود پیوند دارند.',
@@ -1608,7 +1606,7 @@
 'logempty'             => 'مورد منطبق با منظور شما در سیاهه یافت نشد.',
 'log-title-wildcard'   => 'صفحه‌هایی را جستجو کن که عنوانشان با این عبارت آغاز می‌شود',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'همهٔ صفحه‌ها',
 'alphaindexline'    => '$1 تا $2',
 'nextpage'          => 'صفحهٔ بعد ($1)',
@@ -1631,12 +1629,12 @@
 'special-categories-sort-count' => 'مرتب کردن بر اساس تعداد',
 'special-categories-sort-abc'   => 'مرتب کردن الفبایی',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'نمایش کاربران با شروع از:',
 'listusers-submit'   => 'نمایش',
 'listusers-noresult' => 'هیچ کاربری یافت نشد.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'اختیارات گروه‌های کاربری',
 'listgrouprights-summary'  => 'فهرست زیر شامل گروه‌های کاربری تعریف شده در این ویکی و اختیارات داده شده به آن‌ها است.
 اطلاعات بیشتر در مورد هر یک از اختیارات را در [[{{MediaWiki:Listgrouprights-helppage}}]] بیابید.',
@@ -1647,7 +1645,7 @@
 
 # E-mail user
 'mailnologin'     => 'نشانی‌ای از فرستنده وجود ندارد.',
-'mailnologintext' => 'برای فرستادن پست الکترونیکی به کاربران دیگر باید [[Special:Userlogin|به سیستم وارد شوید]]
+'mailnologintext' => 'برای فرستادن پست الکترونیکی به کاربران دیگر باید [[Special:UserLogin|به سیستم وارد شوید]]
 و نشانی پست الکترونیکی معتبری در [[Special:Preferences|ترجیحات]]
 خود داشته باشید.',
 'emailuser'       => 'پست الکترونیکی به این کاربر',
@@ -1679,10 +1677,10 @@
 'nowatchlist'          => 'در فهرست پی‌گیریهای شما هیچ موردی نیست.',
 'watchlistanontext'    => 'برای مشاهده و ویرایش فهرست پی‌گیری‌های خود از $1 استفاده کنید.',
 'watchnologin'         => 'به سیستم وارد نشده‌اید',
-'watchnologintext'     => 'برای تغییر فهرست پی‌گیری‌هایتان باید [[Special:Userlogin|به سیستم وارد شوید]].',
+'watchnologintext'     => 'برای تغییر فهرست پی‌گیری‌هایتان باید [[Special:UserLogin|به سیستم وارد شوید]].',
 'addedwatch'           => 'به فهرست پی‌گیری‌ها اضافه شد',
 'addedwatchtext'       => "صفحهٔ «<nowiki>$1</nowiki>» به [[Special:Watchlist|فهرست پی‌گیری‌های]] شما اضافه شد.
-تغییرات این صفحه و صفحهٔ بحث متناظرش در آینده در اینجا فهرست خواهد شد. به‌علاوه، این صفحه، برای واضح‌تر دیده شدن در [[Special:Recentchanges|فهرست تغییرات اخیر]] به شکل <b>سیاه</b> خواهد آمد.
+تغییرات این صفحه و صفحهٔ بحث متناظرش در آینده در اینجا فهرست خواهد شد. به‌علاوه، این صفحه، برای واضح‌تر دیده شدن در [[Special:RecentChanges|فهرست تغییرات اخیر]] به شکل <b>سیاه</b> خواهد آمد.
 
 اگر بعداً می‌خواستید این صفحه از فهرست پی‌گیریهایتان برداشته شود، روی «'''توقف پی‌گیری'''» در بالای صفحه کلیک کنید.",
 'removedwatch'         => 'از فهرست پی‌گیری‌ها برداشته شد',
@@ -1757,6 +1755,7 @@
 'exbeforeblank'               => "محتوای صفحه قبل از خالی‌کردن '$1' بود.",
 'exblank'                     => 'صفحه خالی بود',
 'delete-confirm'              => 'حذف «$1»',
+'delete-backlink'             => '→ $1',
 'delete-legend'               => 'حذف',
 'historywarning'              => 'هشدار! صفحه‌ای که دارید حذف می‌کنید، تاریخچه‌ای دارد:',
 'confirmdeletetext'           => 'شما در حال حذف کردن یک صفحه یا تصویر از پایگاه‌ داده همراه با تمام تاریخچهٔ آن هستید. لطفاً این عمل را تأیید کنید و اطمینان حاصل کنید که عواقب این کار را می‌دانید و این عمل را مطابق با [[{{MediaWiki:Policy-url}}|سیاست‌ها]] انجام می‌دهید.',
@@ -1799,9 +1798,9 @@
 'protectlogpage'              => 'سیاههٔ_محافظت',
 'protectlogtext'              => 'در زیر فهرست قفل کردن‌ها/ازقفل‌درآوردن‌های صفحه‌ها آمده است.
 برای اطلاعات بیشتر به [[{{ns:project}}:سیاست حفاظت از صفحه‌ها]] مراجعه کنید.',
-'protectedarticle'            => '[[$1]] محافظت شد',
-'modifiedarticleprotection'   => 'وضعیت محافظت صفحهٔ [[$1]] تغییر داده شد',
-'unprotectedarticle'          => '[[$1]] از محافظت به در آمد',
+'protectedarticle'            => '«[[$1]]» را محافظت کرد',
+'modifiedarticleprotection'   => 'وضعیت محافظت «[[$1]]» را تغییر داد',
+'unprotectedarticle'          => '[[$1]] را از محافظت به در آورد',
 'protect-title'               => 'تغییر وضعیت محافظت «$1»',
 'protect-legend'              => 'تأیید حفاظت',
 'protectcomment'              => 'دلیل محافظت',
@@ -1909,7 +1908,7 @@
 
 # What links here
 'whatlinkshere'            => 'پیوندهای به این صفحه',
-'whatlinkshere-title'      => 'صفحه‌هایی که به $1 پیوند دارند',
+'whatlinkshere-title'      => 'صفحه‌هایی که به «$1» پیوند دارند',
 'whatlinkshere-page'       => 'صفحه:',
 'whatlinkshere-barrow'     => '&gt;',
 'linklistsub'              => '(فهرست پیوندها)',
@@ -1959,7 +1958,7 @@
 'badipaddress'                    => 'کاربری با این نام وجود ندارد.',
 'blockipsuccesssub'               => 'بستن با موفقیت انجام شد',
 'blockipsuccesstext'              => '«$1» بسته شده است.
-<br />برای بررسی بسته‌شدن‌ها، به [[Special:Ipblocklist|فهرست نشانی‌های IP و نام‌های کاربری بسته‌شده]] مراجعه کنید.',
+<br />برای بررسی بسته‌شدن‌ها، به [[Special:IPBlockList|فهرست نشانی‌های IP و نام‌های کاربری بسته‌شده]] مراجعه کنید.',
 'ipb-edit-dropdown'               => 'دلایل قطع دسترسی',
 'ipb-unblock-addr'                => 'بازکردن $1',
 'ipb-unblock'                     => 'بازکردن نام کاربری یا نشانی آی‌پی',
@@ -1971,7 +1970,7 @@
 'ipusubmit'                       => 'باز کردن این نشانی',
 'unblocked'                       => 'دسترسی [[User:$1|$1]] دوباره برقرار شد.',
 'unblocked-id'                    => 'قطع دسترسی شماره $1 خاتمه یافت',
-'ipblocklist'                     => 'فهرست نشانی‌های IP و نام‌های کاربری بسته‌شده',
+'ipblocklist'                     => 'نشانی‌های اینترنتی و نام‌های کاربری بسته‌شده',
 'ipblocklist-legend'              => 'جستجوی کاربر بسته شده',
 'ipblocklist-username'            => 'نام کاربری یا نشانی IP',
 'ipblocklist-submit'              => 'جستجو',
@@ -1992,7 +1991,7 @@
 'blocklogentry'                   => '«$1»  $2 بسته شد. $3',
 'blocklogtext'                    => 'این سیاهه‌ای از اعمال بستن و باز کردن کاربرها است. نشانی‌های IPی که به طور
 خودکار بسته شده‌اند فهرست نشده‌اند. برای فهرست محرومیت‌ها و بسته‌شدن‌های عملیاتی در لحظهٔ حاضر،
-به [[Special:Ipblocklist|فهرست IPهای بسته]] مراجعه کنید.',
+به [[Special:IPBlockList|فهرست IPهای بسته]] مراجعه کنید.',
 'unblocklogentry'                 => '«$1» باز شد',
 'block-log-flags-anononly'        => 'فقط کاربران گمنام',
 'block-log-flags-nocreate'        => 'قابلیت ایجاد حساب غیرفعال شد.',
@@ -2056,9 +2055,6 @@
 
 در این حالات، باید صفحه را بطور دستی انتقال داده و یا محتویات دو صفحه را با ویرایش ادغام کنید.",
 'movearticle'             => 'انتقال صفحه',
-'movenologin'             => 'به سیستم وارد نشده‌اید',
-'movenologintext'         => 'برای انتقال صفحه‌ها باید کاربر ثبت‌شده بوده و
-[[Special:Userlogin|به سیستم وارد شوید]].',
 'movenotallowed'          => 'شما اجازهٔ انتقال دادن صفحه‌ها در این ویکی را ندارید.',
 'newtitle'                => 'به عنوان جدید',
 'move-watch'              => 'پی‌گیری این صفحه',
@@ -2087,7 +2083,7 @@
 'delete_and_move'         => 'حذف و انتقال',
 'delete_and_move_text'    => '== نیاز به حذف ==
 
-مقاله‌ٔ مقصد «[[$1]]» وجود دارد. آیا می‌خواهید آن را حذف کنید تا انتقال ممکن شود؟',
+مقاله‌ٔ مقصد «[[:$1]]» وجود دارد. آیا می‌خواهید آن را حذف کنید تا انتقال ممکن شود؟',
 'delete_and_move_confirm' => 'بله، صفحه حذف شود',
 'delete_and_move_reason'  => 'حذف برای ممکن‌شدن انتقال',
 'selfmove'                => 'عناوین صفحهٔ مبداء و مقصد یکی است؛ انتقال صفحه به خودش ممکن نیست.',
@@ -2095,6 +2091,7 @@
 'imagenocrossnamespace'   => 'امکان انتقال تصویر به فضای نام غیر تصویر وجود ندارد',
 'imagetypemismatch'       => 'پسوند پرونده جدید با نوع آن سازگار نیست',
 'imageinvalidfilename'    => 'نام پروندهٔ هدف غیر مجاز است',
+'fix-double-redirects'    => 'به روز کردن تمامی تغییر مسیرهایی که به مقالهٔ اصلی اشاره می‌کنند',
 
 # Export
 'export'            => 'صدور صفحه‌ها',
@@ -2160,7 +2157,7 @@
 # Import log
 'importlogpage'                    => 'سیاههٔ واردکردن‌ها',
 'importlogpagetext'                => 'وارد کردن صفحه‌ها به همراه تارخچهٔ ویرایش آن‌ها از ویکی‌های دیگر',
-'import-logentry-upload'           => '[[$1]] از طریق بارگذاری پرونده، وارد شد.',
+'import-logentry-upload'           => '[[$1]] را از طریق بارگذاری پرونده وارد کرد',
 'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|نسخه|نسخه}}',
 'import-logentry-interwiki'        => '$1 تراویکی شد',
 'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|نسخه|نسخه}} از $2',
@@ -2282,10 +2279,11 @@
 'markedaspatrollederror-noautopatrol' => 'شما نمی‌توانید به تغییرات انجام شده توسط خودتان برچسب گشت بزنید.',
 
 # Patrol log
-'patrol-log-page' => 'سیاههٔ گشت',
-'patrol-log-line' => 'به $1 از $2 برچسب گشت زد $3',
-'patrol-log-auto' => '(خودکار)',
-'patrol-log-diff' => 'نسخه $1',
+'patrol-log-page'   => 'سیاههٔ گشت',
+'patrol-log-header' => 'این سیاهه‌ای از ویرایش‌های گشت‌خورده است.',
+'patrol-log-line'   => 'به $1 از $2 برچسب گشت زد $3',
+'patrol-log-auto'   => '(خودکار)',
+'patrol-log-diff'   => 'نسخه $1',
 
 # Image deletion
 'deletedrevision'                 => '$1 نسخهٔ حذف شدهٔ قدیمی',
@@ -2315,7 +2313,7 @@
 'show-big-image'       => 'تصویر با تفکیک‌پذیری بالاتر',
 'show-big-image-thumb' => '<small>اندازهٔ این پیش‌نمایش: &#8206;$1 × $2 پیکسل</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'گالری پرونده‌های جدید',
 'imagelisttext'         => 'در زیر فهرست $1 {{PLURAL:$1|تصویری|تصویری}} که $2 مرتب شده است آمده است.',
 'newimages-summary'     => 'این صفحهٔ ویژه آخرین پرونده‌های بارگذاری شده را نمایش می‌دهد',
@@ -2602,7 +2600,7 @@
 
 # External editor support
 'edit-externally'      => 'ویرایش این پرونده با استفاده از ویرایشگر خارجی',
-'edit-externally-help' => 'برای اطلاعات بیشتر [http://meta.wikimedia.org/wiki/Help:External_editors راهنمایی‌های تنظیمات] ویرایشگر خارجی را ببینید.',
+'edit-externally-help' => 'برای اطلاعات بیشتر [http://www.mediawiki.org/wiki/Manual:External_editors راهنمایی‌های تنظیمات] ویرایشگر خارجی را ببینید.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'همه',
@@ -2686,7 +2684,7 @@
 'recreate'            => 'بازایجاد',
 
 # HTML dump
-'redirectingto' => 'در حال تغییر مسیر به [[$1]]...',
+'redirectingto' => 'در حال تغییر مسیر به [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'پاک کردن نسخهٔ حافظهٔ نهانی (Cache) این صفحه را تأیید می‌کنید؟
@@ -2741,8 +2739,8 @@
 'livepreview-error'   => 'ارتباط به مشکل برخورد: $1 "$2" از پیش‌نمایش عادی استفاده کنید.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'ممکن است تغییرات تازه‌تر از $1 ثانیه در این فهرست نشان داده نشوند.',
-'lag-warn-high'   => 'ممکن است ، به خاطر پس‌افتادگی زیاد کارگزار دادگان، تغییرات تازه‌تر از $1 ثانیه، در این فهرست نشان داده نشده باشند.',
+'lag-warn-normal' => 'ممکن است تغییرات تازه‌تر از $1 {{PLURAL:$1|ثانیه|ثانیه}} در این فهرست نشان داده نشوند.',
+'lag-warn-high'   => 'ممکن است ، به خاطر پس‌افتادگی زیاد کارگزار دادگان، تغییرات تازه‌تر از $1 {{PLURAL:$1|ثانیه|ثانیه}}، در این فهرست نشان داده نشده باشند.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'فهرست پی‌گیری‌های شما شامل {{PLURAL:$1|$1 صفحه|$1 صفحه}} به جز صفحه‌های بحث است.',
@@ -2838,7 +2836,7 @@
 'version-software-product'         => 'محصول',
 'version-software-version'         => 'نسخه',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'مسیر پرونده',
 'filepath-page'    => 'پرونده:',
 'filepath-submit'  => 'مسیر',
@@ -2875,7 +2873,7 @@
 'specialpages-group-redirects'   => 'صفحه‌های ویژهٔ تغییر مسیر دهنده',
 'specialpages-group-spam'        => 'ابزارهای مرتبط با هرزنگاری',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'صفحهٔ خالی',
 'intentionallyblankpage' => 'این صفحه به طور عمدی خالی گذاشته شده و برای محک زدن سیستم و غیره به کار می‌رود.',
 
Index: languages/messages/MessagesUr.php
===================================================================
--- languages/messages/MessagesUr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesUr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author לערי ריינהארט
- * @author Wisesabre
- * @author Siebrand
  * @author Chris H
+ * @author Wisesabre
+ * @author לערי ריינהארט
  */
 
 $rtl = true;
@@ -255,14 +254,14 @@
 'showpreview'          => 'نمائش',
 'anoneditwarning'      => 'آپ {{SITENAME}} میں داخل نہیں ہوۓ لہذا آپکا IP پتہ اس صفحہ کے تاریخچہ ء ترمیم میں محفوظ ہوجاۓ گا۔',
 'summary-preview'      => 'نمائش خلاصہ',
-'whitelistedittext'    => 'ترمیم و تدوین کے لیۓ آپکا [[Special:Userlogin|داخل ہونا]] لا زمی ہے۔',
+'whitelistedittext'    => 'ترمیم و تدوین کے لیۓ آپکا [[Special:UserLogin|داخل ہونا]] لا زمی ہے۔',
 'loginreqtitle'        => 'داخلہ / اندراج لازم',
 'loginreqlink'         => 'داخلہ',
 'accmailtitle'         => 'کلمہ شناخت بھیج دیا گیا۔',
 'accmailtext'          => '"$1" کیلیۓ کلمہ شناخت $2 کو ارسال کردیا گیا۔',
 'newarticle'           => '(نیا)',
 'newarticletext'       => 'آپ ایک ایسے صفحے کے ربط تک آگۓ ہیں جو ابھی موجود نہیں۔ اگر آپ اس عنوان سے صفحہ بنانا چاہتے ہیں تو اپنا مضمون نیچے دیۓ گۓ احاطہ میں تحریر کیجیۓ اور محفوظ کردیجیۓ (مزید معلومات کیلیۓ معاونت کا صفحہ ملاحظہ کیجیۓ)۔ اگر آپ غلطی سے یہاں پہنچے ہیں تو واپسی کے لیۓ اپنے تصفحہ (براؤزر) کا بیک بٹن ٹک کیجیۓ۔',
-'anontalkpagetext'     => "----''یہ صفحہ ایک ایسے صارف کا ہے جنہوں نے یا تو اب تک اپنا کھاتا نہیں بنایا یا پھر وہ اسے استعمال نہیں کر رہے/ رہی ہیں۔ لہذا ہمیں انکی شناخت کے لیۓ ایک اعدادی آئی پی پتہ استعمال کرنا پڑرہا ہے۔ اس قسم کا آئی پی ایک سے زائد صارفین کے لیۓ مشترک بھی ہوسکتا ہے۔ اگر آپکی موجودہ حیثیت ایک گمنام صارف کی ہے اور آپ محسوس کریں کہ اس صفحہ پر آپکی جانب منسوب یہ بیان غیرضروری ہے تو براہ کرم [[Special:Userlogin|کھاتا بنائیے یا داخل نوشتہ (لاگ ان) ہوں]] تاکہ مستقبل میں آپکو، گمنام صارفین میں شمار کرنے سے پرہیز کیا جاسکے۔\"",
+'anontalkpagetext'     => "----''یہ صفحہ ایک ایسے صارف کا ہے جنہوں نے یا تو اب تک اپنا کھاتا نہیں بنایا یا پھر وہ اسے استعمال نہیں کر رہے/ رہی ہیں۔ لہذا ہمیں انکی شناخت کے لیۓ ایک اعدادی آئی پی پتہ استعمال کرنا پڑرہا ہے۔ اس قسم کا آئی پی ایک سے زائد صارفین کے لیۓ مشترک بھی ہوسکتا ہے۔ اگر آپکی موجودہ حیثیت ایک گمنام صارف کی ہے اور آپ محسوس کریں کہ اس صفحہ پر آپکی جانب منسوب یہ بیان غیرضروری ہے تو براہ کرم [[Special:UserLogin|کھاتا بنائیے یا داخل نوشتہ (لاگ ان) ہوں]] تاکہ مستقبل میں آپکو، گمنام صارفین میں شمار کرنے سے پرہیز کیا جاسکے۔\"",
 'note'                 => '<strong>نوٹ:</strong>',
 'previewnote'          => '<strong>یاد رکھیں، یہ صرف نمائش ہے ۔آپ کی ترامیم ابھی محفوظ نہیں کی گئیں۔</strong>',
 'editing'              => 'آپ "$1" میں ترمیم کر رہے ہیں۔',
@@ -367,7 +366,7 @@
 'reupload'          => 'زبراثقال مکرر',
 'reuploaddesc'      => 'زبراثقال ورقہ (فارم) کیجانب واپس۔',
 'uploadnologin'     => 'آپ داخل شدہ حالت میں نہیں',
-'uploadnologintext' => 'زبراثقال ملف (فائل اپ لوڈ) کے لیۓ آپکو  [[Special:Userlogin|داخل شدہ]] حالت میں ہونا لازم ہے۔',
+'uploadnologintext' => 'زبراثقال ملف (فائل اپ لوڈ) کے لیۓ آپکو  [[Special:UserLogin|داخل شدہ]] حالت میں ہونا لازم ہے۔',
 'uploadtext'        => "
 <big>'''یادآوری''': اگر آپ اپنی ملف (فائل) زبراثقال کرتے وقت ، خلاصہ کے خانے میں ،  درج ذیل دو باتوں کی وضاحت نہیں کرتے تو ملف کو حذف کیا جاسکتا ہے:</big>
 #ملف یا فائل کا '''مـاخـذ''' ، یعنی: 
@@ -381,7 +380,7 @@
 
 جب کوئی صارف مستقل ایسی ملف زبراثقال کرتا رہے کہ جس کے اجازہ کے بارے میں غلط بیانی کی گئی ہو یا وہ مستقل ایسے عکس زبراثقال کرتا رہے کہ جنکے بارے میں کوئی بیان تحریر نہ کیا گیا ہو تو ایسی صورت میں پابندی لگاۓ جانے کا قوی امکان موجود ہے۔ 
 
-مِلَف (فائل) بھیجنے کیلیے درج ذیل ورقہ (فارم) استعمال کیجیے، اگر آپ اب تک ارسال کردہ تصاویر کو دیکھنا یا تلاش کرنا چاہتے ہیں تو [[Special:Imagelist|ارسال کردہ تصاویر]] کے ربط پر جائیے۔ <br /> تمام ارسال و حذف کی گئی تصاویر کو [[Special:Log/upload|نوشتۂ منتقلی]] میں درج کر لیا جاتا ہے۔
+مِلَف (فائل) بھیجنے کیلیے درج ذیل ورقہ (فارم) استعمال کیجیے، اگر آپ اب تک ارسال کردہ تصاویر کو دیکھنا یا تلاش کرنا چاہتے ہیں تو [[Special:ImageList|ارسال کردہ تصاویر]] کے ربط پر جائیے۔ <br /> تمام ارسال و حذف کی گئی تصاویر کو [[Special:Log/upload|نوشتۂ منتقلی]] میں درج کر لیا جاتا ہے۔
 
 تصویر کی منتقلی کے بعد، اسکو کسی صفحہ پر رکھنے کیلیے مندرجہ ذیل صورت میں رمـز (کوڈ) استعمال کیجیۓ۔
 
@@ -414,7 +413,7 @@
 'destfilename'      => 'تعین شدہ اسم ملف:',
 'watchthisupload'   => 'یہ صفحہ زیر نظر کیجیۓ',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'فہرست فائل',
 
 # Image description page
@@ -482,7 +481,7 @@
 'speciallogtitlelabel' => 'عنوان:',
 'log'                  => 'نوشتہ جات',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'تمام صفحات',
 'nextpage'       => 'اگلا صفحہ ($1)',
 'prevpage'       => 'پچھلا صفحہ ($1)',
@@ -497,7 +496,7 @@
 'categoriespagetext' => 'مندرجہ ذیل زمرہ جات اس وکی میں موجود ہیں۔',
 
 # E-mail user
-'mailnologintext' => 'دیگر ارکان کو برقی خط ارسال کرنے کیلیۓ لازم ہے کہ آپ [[Special:Userlogin|داخل شدہ]] حالت میں ہوں اور آپ کی [[Special:Preferences|ترجیحات]] ایک درست برقی خط کا پتا درج ہو۔',
+'mailnologintext' => 'دیگر ارکان کو برقی خط ارسال کرنے کیلیۓ لازم ہے کہ آپ [[Special:UserLogin|داخل شدہ]] حالت میں ہوں اور آپ کی [[Special:Preferences|ترجیحات]] ایک درست برقی خط کا پتا درج ہو۔',
 'emailuser'       => 'صارف کو برقی خط لکھیں',
 'defemailsubject' => '{{SITENAME}} سے برقی خط',
 'noemailtext'     => 'اس صارف نے برقی خط کے لیے کوئی پتہ فراہم نہیں کیا، یا یہ چاہتا ہے کا اس سے کوئی صارف رابطہ نہ کرے۔',
@@ -609,7 +608,7 @@
 'delete_and_move'         => 'حذف اور منتقل',
 'delete_and_move_text'    => '==حذف شدگی لازم==
 
-منتقلی کے سلسلے میں انتخاب کردہ مضمون "[[$1]]" پہلے ہی موجود ہے۔ کیا آپ اسے حذف کرکے منتقلی کیلیۓ راستہ بنانا چاہتے ہیں؟',
+منتقلی کے سلسلے میں انتخاب کردہ مضمون "[[:$1]]" پہلے ہی موجود ہے۔ کیا آپ اسے حذف کرکے منتقلی کیلیۓ راستہ بنانا چاہتے ہیں؟',
 'delete_and_move_confirm' => 'ہاں، صفحہ حذف کر دیا جائے',
 'delete_and_move_reason'  => 'منتقلی کے سلسلے میں حذف',
 
@@ -639,7 +638,7 @@
 'previousdiff' => '> گذشتہ فرق',
 'nextdiff'     => '< اگلا فرق',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'    => 'نئی فائلوں کی گیلری',
 'showhidebots' => '($1 بوٹ)',
 'ilsubmit'     => 'تلاش',
@@ -659,7 +658,7 @@
 'deletedwhileediting' => 'انتباہ: آپ کے ترمیم شروع کرنے کے بعد یہ صفحہ حذف کیا جا چکا ہے!',
 
 # HTML dump
-'redirectingto' => 'کی جانب پلٹایا گیا [[$1]]...',
+'redirectingto' => 'کی جانب پلٹایا گیا [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'جی!',
Index: languages/messages/MessagesBcc.php
===================================================================
--- languages/messages/MessagesBcc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBcc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Mostafadaneshvar
- * @author Siebrand
  */
 
 $fallback = 'fa';
@@ -387,7 +386,7 @@
 'nosuchspecialpage' => 'نی چشین حاصین صفحه',
 'nospecialpagetext' => "<big>'''شما یک نامعتبرین صفحه حاصین درخواست کت.'''</big>
 
-یک لیستی چه معتبرین صفحات حاص در کپیت ته [[Special:Specialpages|{{int:specialpages}}]].",
+یک لیستی چه معتبرین صفحات حاص در کپیت ته [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'حطا',
@@ -417,7 +416,7 @@
 
 شی معمولای به وسیله ی یک تاریح گوشتگین تاریح یا لینک تاریح به یک صفحه که حذف بوتت پیش کیت.
 
-اگه شی دلیل نهنت، شما شاید یک باگی ته نرم افزار در گهتگ. لطفا په مدیر گزارش دهیت، ای URL یادداشت کینت.',
+اگه شی دلیل نهنت، شما شاید یک باگی ته نرم افزار در گهتگ. لطفا په مدیر گزارش دهیت،[[Special:ListUsers/sysop|administrator]]، ای URL یادداشت کینت.',
 'missingarticle-rev'   => '(بازبینی#: $1)',
 'missingarticle-diff'  => '(تفاوت: $1, $2)',
 'readonly_lag'         => 'دیتابیس اتوماتیک کبل بیت وهدی که سرورآن دیتابیس برده مستر بیت.',
@@ -477,7 +476,7 @@
 توجه بیت که لهتی صفحات شاید په داب هما وهدی که شما وراد بوتتیت پیش درگ بند تا وهدی که ذخیره بروزر وتی پاک کنیت.',
 'welcomecreation'            => '== وش آتکی،$1! ==
 شمی حساب شر بیت.
- مه شموشیت وتی {{SITENAME}} ترجیحات عوض کنیت',
+ مه شموشیت وتی [[Special:Preferences|{{SITENAME}} ترجیحات]] ترجیحات عوض کنیت',
 'loginpagetitle'             => 'ورود کاربر',
 'yourname'                   => 'نام کاربری',
 'yourpassword'               => 'کلمه رمز',
@@ -625,7 +624,7 @@
 'summary-preview'                  => 'خلاصه بازبینی',
 'subject-preview'                  => 'بازبین موضوع/سرخط',
 'blockedtitle'                     => 'کاربر محدود بوتت',
-'blockedtext'                      => "<big> شمی نام کاربری یا آی پی محدود بیتت.''''</big>
+'blockedtext'                      => "<big>'''شمی نام کاربری یا آی پی محدود بیتت.''''</big>
 
 محدودیت توسط $1 شر بوتت. دلیل داتت ''$2''.
 
@@ -643,22 +642,19 @@
 
 * شروع محدودیت:  $8
 * هلگ محدودیت: $6
+* لوتوکی محدوی بووک: $7
 
 شما شاید تماس گریت گون $1 یا یکی دگه چه [[{{MediaWiki:Grouppage-sysop}}|مدیران ]] په بحث درباره محدودیت.
 
 توجه بیت شما شاید چه ویژگی "ای کاربر ایمیل دیم دی" مه تونیت استفاده کینت مگر شی که یک معتبرین آدرس ایمیل ته وتی [[Special:Preferences|ترجیحات کاربر ]] ثبت کنیت و شما چه استفاده چه آیی محدود نه بیت.
 
-شمی شماره محدودیت $5.
+ مشی هنوکی ان آی پی $3 شمی شماره محدودیت $5
 لطفا ای شماره ته هر جوست و پرسی هور کنیت.',
 'blockednoreason'                  => 'هچ دلیلی دهگ نه بیته',
 'blockedoriginalsource'            => "منبع '''$1''' جهلآ پیش دراگ بیت:",
 'blockededitsource'                => "متن '''your edits'' به '''$1''' جهلآ پیش دارگ بیت:",
-'whitelistedittitle'               => 'په اصلاح کتن ورود نیازنت',
+'whitelistedittitle'               => 'په اصلاح کتن بایدن وارد سیستم بیت',
 'whitelistedittext'                => 'شما باید $1به اصلاح کتن صفحات.',
-'whitelistreadtitle'               => 'ورود نیازنت به وانگ',
-'whitelistreadtext'                => 'شما باید  [[Special:Userlogin|login]] به وانگ صفحات',
-'whitelistacctitle'                => 'شما نه تونیت حسابی شرکنیت',
-'whitelistacctext'                 => 'به اجازت بیگ په شرکتن حسابان ته {{SITENAME}} شما باید [[Special:Userlogin|log]] ته و مناسبین اجازت داشته بیت.',
 'confirmedittitle'                 => 'به اصلاح کتن تایید ایمیل نیازنت',
 'confirmedittext'                  => 'شما بایدن وتی آدرس ایمیل آ پیش چه اصلاح کتن صفحات تایید کنیت.
 لطفا وتی آدرس ایمیل آی چه طریق [[Special:Preferences|ترجحات کاربر]] تنظیم و معتبر کنیت.',
@@ -676,7 +672,7 @@
 اگر شما اشتباهی ادانیت ته وتی بروزر دکمه ''Back'' بجن.",
 'anontalkpagetext'                 => "----'' ای صفحه بحث انت په یک ناشناس کاربری که هنگت یک حسابی شر نه کتت یا آی ا ستفاده نه کتت. اچه ما بایدن آدرس آی پی عددی په پچاه آرگ آیی استفاده کنین.
 چوشن آدرس آی پی گون چندین کاربر استفاده بیت.
-اگه شما یک کاربر ناشناس ایت وی حس کنیت بی ربطین نظر مربوط شمی هست، لطفا [[Special:Userlogin|یک حسابی شرکن یا وارد بو]]  دان چه هور بییگ گون ناسناسین کاربران پرهیز بیت.''",
+اگه شما یک کاربر ناشناس ایت وی حس کنیت بی ربطین نظر مربوط شمی هست، لطفا [[Special:UserLogin|وارد بیت ]] یا [[Special:UserLogin/signup|حسابی شرکن]] دان چه هور بییگ گون ناسناسین کاربران پرهیز بیت.''",
 'noarticletext'                    => 'هنو هچ متنی ته ای صفحه نیست، شما تونیت  [[Special:Search/{{PAGENAME}}|گردگ په عنوان صفحه]]  ته دگه صفحات یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} ای صفحه اصلاح کن].',
 'userpage-userdoesnotexist'        => 'حساب کاربر "$1" ثبت نهنت. لطفا کنترل کنیت اگه شما لوٹیت ای صفحه یا شر/اصلاح کنیت.',
 'clearyourcache'                   => "'''توجه:''' بعد چه ذخیره کتن، شما شاید مجبور بیت چه وتی ذخیره ی بروزر رد بیت تا تغییرات بگندیت. '''Mozilla / Firefox / Safari:'' ''Shift'' جهل داریت همی وهدی که کلیک کنیت ''Reload'' یا بداریت ''Ctrl-Shift-R'' (''Cmd-Shift-R'' on Apple Mac);'''IE:''' ''Ctrl''  بداری وهدی که کلیک ''Refresh' یا 'Ctrl-F5''; '''Konqueror:''':  راحت کلیک کن دکمه ''Reload'' یا بدار ''F5''; '''Opera''' کاربر بایدن ته ''Tools→Preferences'' ذخیره پاک کنت.",
@@ -691,12 +687,12 @@
 تغییرات هنگت ذخیره نهنت. </strong>',
 'previewconflict'                  => 'ای بازبین متنء پیش داریت ته منطفه بالدی اصلاحی هنچوش که پیش دارگ بیت اگه شما انتخاب کنیت ذخیره',
 'session_fail_preview'             => '<strong>شرمنده! ما نه تونست شمی اصلاحء په خاطر گار کتن دیتا دیوان پردازش کنین.
-طلف دگه سعی کنیت. اگر هنگت کار نکنت یک بری در بیت و پیدا وارد بیت.</strong>',
+طلف دگه سعی کنیت. اگر هنگت کار نکنت یک بری [[Special:UserLogout|دربیت]] و پیدا وارد بیت.</strong>',
 'session_fail_preview_html'        => "<strong>شرمنده! ما نه تونست شمی اصلاحء په خاطر گار کتن دیتا دیوان پردازش کنین.</strong>
 
 ''په چی که {{SITENAME}} HTML هام فعالنت، بازبین په خاطر حملات JavaScript پناهنت.''
 
-<strong> اگر شی یک قانونی تلاش اصلاحنت، دگه کوشش کنیت. اگر هنگت کار نکنت یک بری در بیت و دگه وارد بیت.</strong>",
+<strong> اگر شی یک قانونی تلاش اصلاحنت، دگه کوشش کنیت. اگر هنگت کار نکنت یک بری [[Special:UserLogout|دربیت]] و دگه وارد بیت.</strong>",
 'token_suffix_mismatch'            => '<strong> شمی اصلاح رد بوت په چی که شمی کلاینت نویسگ کاراکترانی په هم جتت.
 اصلاح رد بوت داں چه هراب بیگ متن صفحه جلوگیری بیت.
 شی لهتی وهد پیش کت که شما چه یک هرابین سرویس پروکسی وبی استفاده کنیت.</strong>',
@@ -743,7 +739,7 @@
 'edittools'                        => '<strong>په کپی و پست کتن چه CTRL+V , CTRL+C استفاده کنیت.</strong>',
 'nocreatetitle'                    => 'شرکتن صفحه محدودنت',
 'nocreatetext'                     => '{{SITENAME}} شما را چه شرکتن نوکین صفحه منه کته.
-شما تونیت برگردیت و یک پیشگین صفحه ای اصلاح کنیت، یا [[Special:Userlogin|وارد بیت یان یک حسابی شرکنیت]].',
+شما تونیت برگردیت و یک پیشگین صفحه ای اصلاح کنیت، یا [[Special:UserLogin|وارد بیت یان یک حسابی شرکنیت]].',
 'nocreate-loggedin'                => 'شما را اجازت په شرکتن نوکین صفحات ته {{SITENAME}} نیست.',
 'permissionserrors'                => 'حطای اجازت',
 'permissionserrorstext'            => 'شما را اجازت په انجام آی نیست، په جهلیگین دلیل {{PLURAL:$1|دلیل|دلایل}}:',
@@ -768,7 +764,7 @@
 'undo-success' => 'اصلاح برگشت نه بیت. لطفا مقایسه جهلگینء کنترل کنیت په تایید شی که شی هما انت که شما لوٹیت، و بعدا تغغیرات جهلی په تمام کتن بر نگردگ اصلاح ذخیره کنیت.',
 'undo-failure' => 'اصلاح بر نرگردیت په خاطر تضاد میان اصلاحاتی',
 'undo-norev'   => 'اصلاح نه تونیت برگردیت په چی که آی وجود نهنت یا حذف بوتت.',
-'undo-summary' => 'بازبینی برگردین $1 گون [[Special:مشارکتان/$2|$2]] ([[User talk:$2|گپ]])',
+'undo-summary' => 'بازبینی برگردین $1 گون [[Special:مشارکتان/$2|$2]] ([[User talk:$2|گپ]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'نه نونیت حساب شرکنت',
@@ -861,7 +857,7 @@
 # Suppression log
 'suppressionlog'     => 'آمار توقیف',
 'suppressionlogtext' => 'جهلء یک لیست چه حذفیات و محدودیات من جمله پناهین محتوا چه مدیران سیستم هست.
-به چار [[Special:Ipblocklist|IP block list]] په لیست هنوکین عملی محدویت آن',
+به چار [[Special:IPBlockList|IP block list]] په لیست هنوکین عملی محدویت آن',
 
 # History merging
 'mergehistory'                     => 'چن و بند کن تاریح آن صفحهء',
@@ -903,7 +899,7 @@
 # Search results
 'searchresults'             => 'نتایج گردگ',
 'searchresulttext'          => 'په گیشترین اطلاعات گردگ باره {{SITENAME}}، بچار [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "شما گردگیت په '''[[:$1]]'''",
+'searchsubtitle'            => 'شما گردگیت په \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|کل صفحات شروع بنت گون "$1"]] | [[Special:WhatLinksHere/$1|کل صفحات که لینک انت په "$1"]])',
 'searchsubtitleinvalid'     => "شما گردگیت په '''$1'''",
 'noexactmatch'              => "'''صفحه ی گون عنوان نیست\"\$1\".'''
 شما تونیت [[:\$1|ای صفحه ی شرکنیت]].",
@@ -949,7 +945,7 @@
 'mypreferences'            => 'منی ترجیحات',
 'prefs-edits'              => 'تعداد اصلاحات:',
 'prefsnologin'             => 'وارد نهیت',
-'prefsnologintext'         => 'شما بایدن  [[Special:Userlogin|وارد بیت]]  په تنظیم کتن وتی ترجیحات',
+'prefsnologintext'         => 'شما بایدن  [[Special:UserLogin|وارد بیت]]  په تنظیم کتن وتی ترجیحات',
 'prefsreset'               => 'ترجیحات چه ذخیره ترینگ بوتنت.',
 'qbsettings'               => 'میله سریع',
 'qbsettings-none'          => 'هچ یک',
@@ -1025,7 +1021,7 @@
 'userrights-reason'           => 'دلیل په عوض کتن:',
 'userrights-no-interwiki'     => 'شما را اجازت نیست دان حقوق کاربر ته دگ ویکی آن اصلاح کنیت.',
 'userrights-nodatabase'       => 'دیتابیس $1  موجود نهنت یا محلی نهنت.',
-'userrights-nologin'          => 'شما باید [[Special:Userlogin|وارد بیت]]  گون حساب مدیریتی په مشخص کتن حقوق کاربر.',
+'userrights-nologin'          => 'شما باید [[Special:UserLogin|وارد بیت]]  گون حساب مدیریتی په مشخص کتن حقوق کاربر.',
 'userrights-notallowed'       => 'شمی حساب اجازت په مشخص کتن حقوق کاربر نیست.',
 'userrights-changeable-col'   => 'گروهانی که شما تونیت عوض کنیت',
 'userrights-unchangeable-col' => 'گروهانی که شما نه نونیت عوض کنیت',
@@ -1155,23 +1151,24 @@
 'reupload'                    => 'دگه آپلود',
 'reuploaddesc'                => 'کنسل آپلودء و ترر په فرم آپلود',
 'uploadnologin'               => 'وارد نهیت',
-'uploadnologintext'           => 'شما بایدن [[Special:Userlogin|واردبیت]] په آپلود کتن فایل.',
+'uploadnologintext'           => 'شما بایدن [[Special:UserLogin|واردبیت]] په آپلود کتن فایل.',
 'upload_directory_missing'    => 'مسیر آپلود ($1)  گارنت و گون وب سرور شر گنگ نه بیت.',
 'upload_directory_read_only'  => 'مسیر آپلود ($1)  قابل نوشتن گون وب سرور نهنت.',
 'uploaderror'                 => 'حطا آپلود',
 'uploadtext'                  => "چه جهلگین فرم په آپلود فایلان استفاده کنت.
-په دیستن یا گشتن پیشگین آپلودی فایلان برو  [[Special:Imagelist|لیست فایلان آپلودی]], آپلودان و حذفیات هنچو هستن ته [[Special:Log/upload|آمار آپلود]].
+په دیستن یا گشتن پیشگین آپلودی فایلان برو  [[Special:ImageList|لیست فایلان آپلودی]], آپلودان و حذفیات هنچو هستن ته [[Special:Log/upload|آمار آپلود]].
 
 په وارد کتن فایل ته یک صفحه ای، چه لینک ته فرم استفاده کن
-''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''' or
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' په مسیری لینک دهگ په فایل.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alt text]]</nowiki></tt>''' په استفاده چه نسخه کامل فایل
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alt text]]</nowiki></tt>''' په استفاده چه ۲۰۰ پیکسل پهنات ته یک جعبه ته چپ
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>'''  په مسیری لینک دهگ په فایل بی پیش دارگ فایل",
 'upload-permitted'            => 'مجازین نوع فایل:  $1.',
 'upload-preferred'            => 'ترجیحی نوع فایل:  $1.',
 'upload-prohibited'           => 'غیرمجازین نوع فایل:  $1.',
 'uploadlog'                   => 'آپلود آمار',
 'uploadlogpage'               => 'آپلود ورودان',
-'uploadlogpagetext'           => 'جهلء یک لیست چه نوکترین آپلودان قایل هست.',
+'uploadlogpagetext'           => 'جهلء یک لیست چه نوکترین آپلودان قایل هست.
+[[Special:NewImages|گالری نوکین فایلان]]',
 'filename'                    => 'نام فایل',
 'filedesc'                    => 'خلاصه',
 'fileuploadsummary'           => 'خلاصه:',
@@ -1256,11 +1253,11 @@
 'upload-proto-error-text' => 'آپلود دراین نیاز په URL آنی داریت که شروع بیت گون  <code>http://</code> یا <code>ftp://</code>.',
 'upload-file-error'       => 'حطا درونی',
 'upload-file-error-text'  => 'یک حطای درونی پیش اتک وهد شرکتن فایل موقت ته سرور.
-لطفا گون یک مدیر سیستم تماس گریت.',
+لطفا گون یک [[Special:ListUsers/sysop|مدیر]].تماس گریت.',
 'upload-misc-error'       => 'ناشناس حطا آپلود',
 'upload-misc-error-text'  => 'یک ناشناسین حطا وهد آپلود کتن پیش آتک.
 لطفا تایید کنیت که URL معتبرانت و دسترسی بیت و دگه سعی کنیت.
-اگر مشکل ادامه داشت، گون یک مدیر سیستمء تماس گریت.',
+اگر مشکل ادامه داشت، گون [[Special:ListUsers/sysop|مدیر]]ء تماس گریت.',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'نه تونیت په URL برسیت',
@@ -1277,7 +1274,7 @@
 'upload_source_url'  => '(یک متعبرین، عمومی دسترسی انت URL)',
 'upload_source_file' => '(یک فایل ته شمی کامپیوتر)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'ای حاصین صفحه کل آپلودی فایلانء پیش داریت.
 به طور پیش فرض اهری فایل آپلودی ته بالاد لیست پیش دارگ بیت.
 یک کلیکی بالاد ستون ترتیب عوض کنت.',
@@ -1305,7 +1302,7 @@
 'imagelinks'                     => 'لینکان',
 'linkstoimage'                   => 'جهلیگین {{PLURAL:$1|صفحه |$1 صفحات لینک}} پی ای فایل',
 'nolinkstoimage'                 => 'هچ صفحه ای نیست که به ای فایل لینک بوت.',
-'morelinkstoimage'               => 'View [[Special:Whatlinkshere/$1|گیشتر لینکان]]به ای فایل',
+'morelinkstoimage'               => 'View [[Special:WhatLinksHere/$1|گیشتر لینکان]]به ای فایل',
 'redirectstofile'                => 'جهلیگین {{PLURAL:$1|فایل غیر مستقیم بنت|$1 فایلان غیر مستقیم بنت.}} به ای فایل',
 'duplicatesoffile'               => 'جهلیگین {{PLURAL:$1|فایل یک کپی انت|$1 فایلان کپی انت}} چه هی فایل:',
 'sharedupload'                   => 'ای فایل یک مشترکین آپلودی فایلیت و شاید گون دگه پروژه یان استفاده بیت.',
@@ -1324,18 +1321,18 @@
 # File reversion
 'filerevert'                => 'ترین $1',
 'filerevert-legend'         => 'ترینگ فایل',
-'filerevert-intro'          => '<span class="plainlinks"> شما په ترینگء \'\'\'[[Media:$1|$1]]\'\'\' په  [$4 نسخه ای په داب چه $3, $2].</span>',
+'filerevert-intro'          => " شما په ترینگء '''[[Media:$1|$1]]''' په  [$4 نسخه ای په داب چه $3, $2].",
 'filerevert-comment'        => 'نظر:',
 'filerevert-defaultcomment' => 'تررت په نسخه په داب $2, $1',
 'filerevert-submit'         => 'تررگ',
-'filerevert-success'        => '<span class="plainlinks">\'\'[[Media:$1|$1]]\'\'\'  بدل بوتت په [$4 نسخه په داب چه $3, $2].</span>',
+'filerevert-success'        => "''[[Media:$1|$1]]'''  بدل بوتت په [$4 نسخه په داب چه $3, $2].",
 'filerevert-badversion'     => 'چه ای فایل پیشگین نسخه مکلی گون داتگین وهد نیست.',
 
 # File deletion
 'filedelete'                  => 'حذف $1',
 'filedelete-legend'           => 'حذف فایل',
 'filedelete-intro'            => "شما حذف کنگت ''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks"> شما په حذف کتن نسخه ای چه \'\'\'[[Media:$1|$1]]\'\'\' په داب چه [$4 $3, $2].</span>',
+'filedelete-intro-old'        => " شما په حذف کتن نسخه ای چه '''[[Media:$1|$1]]''' په داب چه [$4 $3, $2].",
 'filedelete-comment'          => 'دلیل په حذف:',
 'filedelete-submit'           => 'حذف',
 'filedelete-success'          => "'''$1''' حذف بوت.",
@@ -1391,7 +1388,7 @@
 شامل '''\$5''' اصلاح میانگین ته هر صفحه و  '''\$6''' دیستن ته هر اصلاح بیت.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] طولی انت '''\$7'''.",
-'userstatstext'          => "ادان {{PLURAL:$1هست '''1''' ثبت بوتگین[[Special:Listusers|کاربر]]|هستن '''$1''' ثبت نامی [[Special:Listusers|کابران]]}}, که چه آیء '''$2''' (یا'''$4%''') {{PLURAL:$2|داریت|دارنت}} $5 حقوقی.",
+'userstatstext'          => "ادان {{PLURAL:$1هست '''1''' ثبت بوتگین[[Special:ListUsers|کاربر]]|هستن '''$1''' ثبت نامی [[Special:ListUsers|کابران]]}}, که چه آیء '''$2''' (یا'''$4%''') {{PLURAL:$2|داریت|دارنت}} $5 حقوقی.",
 'statistics-mostpopular' => 'باز چار تگین صفحات',
 
 'disambiguations'      => 'صفحات رفع ابهام',
@@ -1400,8 +1397,10 @@
 شما بایدن په جاه آیی په یک مناسبین موضوعی لینک دهیت.<br />
 یک صفحه ای که په داب صفحه رفع ابهام چارگ بیت اگر آیء چه یک تمپلتی که لینک بیت چه [[MediaWiki:Disambiguationspage|صفحه رفع ابهام]] استفاده کنت.",
 
-'doubleredirects'     => 'دوبل غیر مستقیم',
-'doubleredirectstext' => 'ای صفحه لیست کنت صفحاتی که غیر مستقیم رونت په دگه صفحات. هر ردیف شامل لینکانی انت به اولی و دومی غیر مستقیم، و هدف دومی غیر مستقیم، که معمولا استفاده بیت "real" صفحه هدف، که بایدن اولی غیر مستقیم پیش داریت.',
+'doubleredirects'            => 'دوبل غیر مستقیم',
+'doubleredirectstext'        => 'ای صفحه لیست کنت صفحاتی که غیر مستقیم رونت په دگه صفحات. هر ردیف شامل لینکانی انت به اولی و دومی غیر مستقیم، و هدف دومی غیر مستقیم، که معمولا استفاده بیت "real" صفحه هدف، که بایدن اولی غیر مستقیم پیش داریت.',
+'double-redirect-fixed-move' => '[[$1]] انتقال دهگ بوتت، و الان تغییر مسیری په [[$2]] انت',
+'double-redirect-fixer'      => 'تعمیرکنوک غیر مستقیم',
 
 'brokenredirects'        => 'پروشتگین غیر مستقیمان',
 'brokenredirectstext'    => 'جهلیگین غیر مستقیم لینک بوتگن په صفحات نیستن:',
@@ -1488,7 +1487,7 @@
 'logempty'             => 'هچ آیتم هم دپ ته آمار',
 'log-title-wildcard'   => 'بگرد عناوین که گون ای متن شروع بنت',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'کل صفحات',
 'alphaindexline'    => '$1 په $2',
 'nextpage'          => 'صفحه ی بعدی ($1)',
@@ -1512,15 +1511,15 @@
 'special-categories-sort-count' => 'ترتیب په اساس شمار',
 'special-categories-sort-abc'   => 'ترتیب الفبی',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'پیشدار کابرانی که شروع بنت گون:',
 'listusers-submit'   => 'پیش دار',
 'listusers-noresult' => 'هچ کابری در گیزگ نه بوت.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'حقوق گروه کاربر',
 'listgrouprights-summary'  => 'جهلیگین یک لیستی چه گروهان کاربری تعریف بوتگین ته ای ویکی انت گون آیانی حق دسترسی آن همراهنت.
-گشیترین اطلاعات درباره هر حقی ته صفحه [[{{MediaWiki:Listgrouprights-helppage}}]] هستن.',
+ درباره هر حقی ته صفحه [[{{MediaWiki:Listgrouprights-helppage}}|گیشترین اطلاعات]] هستن.',
 'listgrouprights-group'    => 'گروه',
 'listgrouprights-rights'   => 'حقوق',
 'listgrouprights-helppage' => 'Help: حقوق گروه',
@@ -1528,11 +1527,11 @@
 
 # E-mail user
 'mailnologin'     => 'هچ آدرس دیم دهگ',
-'mailnologintext' => 'شما بایدن [[Special:Userlogin|وارد بیت]] و یک معتبرین آدرس ایمیلی داشته بیت ته وتی [[Special:Preferences|ترجیحات]] په دیم داتن ایمیل په دگه کاربران',
+'mailnologintext' => 'شما بایدن [[Special:UserLogin|وارد بیت]] و یک معتبرین آدرس ایمیلی داشته بیت ته وتی [[Special:Preferences|ترجیحات]] په دیم داتن ایمیل په دگه کاربران',
 'emailuser'       => 'په ای کابر ایمیل دیم دی',
 'emailpage'       => 'ایمیل کاربر',
 'emailpagetext'   => 'اگر ای کاربر یک معتبرین آدرس ایمیلی ته وتی ترجیحات کاربری وارد کتت،جهلگین فرم په آیء یک کوله ای دیم دنت.
-آدرس ایمیلی که شما وارد کتت ته وتی ترجیحات په داب آدرس  "From" پیش دارگ بیت، اچه گروک ایمیل تونیت پسوء دنت.',
+آدرس ایمیلی که شما وارد کتت ته [[Special:Preferences|وتی ترجیحات]] په داب آدرس  "From" پیش دارگ بیت، اچه گروک ایمیل تونیت پسوء دنت.',
 'usermailererror' => 'شی ایمیل حطا پیش داشت',
 'defemailsubject' => '{{SITENAME}} ایمیل',
 'noemailtitle'    => 'هچ آدرس ایمیل',
@@ -1555,12 +1554,12 @@
 'nowatchlist'          => 'شما را هچ چیزی ته وتی لیست چارگ نیست.',
 'watchlistanontext'    => 'لطفا  $1 په دیستن یا اصلاح ایتیمان ته وتی لیست چارگء',
 'watchnologin'         => 'وارد نه بی تگیت',
-'watchnologintext'     => 'شما بایدن  [[Special:Userlogin|وارد بیت]] په تغییر داتن وتی لیست چارگء',
+'watchnologintext'     => 'شما بایدن  [[Special:UserLogin|وارد بیت]] په تغییر داتن وتی لیست چارگء',
 'addedwatch'           => 'په لیست چارگ هور بوت',
 'addedwatchtext'       => 'صفحه  "[[:$1]]"  په شمی [[Special:Watchlist|watchlist]] هور بیت.
-دیمگی تغییرات په ای صفحه و آیاء صفحه گپ ادان لیست بنت، و صفحه پررنگ جاه کیت ته [[Special:Recentchanges|لیست نوکیت تغییرات]] په راحتر کتن شی که آی زورگ بیت.',
+دیمگی تغییرات په ای صفحه و آیاء صفحه گپ ادان لیست بنت، و صفحه پررنگ جاه کیت ته [[Special:RecentChanges|لیست نوکیت تغییرات]] په راحتر کتن شی که آی زورگ بیت.',
 'removedwatch'         => 'چه لیست چارگ زورگ بیت',
-'removedwatchtext'     => 'صفحه"[[:$1]]"  چه شمی لیست چارگ دربیت.',
+'removedwatchtext'     => 'صفحه"[[:$1]]"  چه [[Special:Watchlist|شمی لیست چارگ]]. دربیت.',
 'watch'                => 'به چار',
 'watchthispage'        => 'ای صفحه ی بچار',
 'unwatch'              => 'نه چارگ',
@@ -1662,7 +1661,7 @@
 'rollbackfailed'              => 'پشتررگ پروشت',
 'cantrollback'                => 'نه تونیت اصلاح برگردینیت؛
 آهری شرکت کننده فقط نویسوک ای صفحه انت.',
-'alreadyrolled'               => 'نه تونیت ترینیت اهری اصلاح چه  [[:$1]] گون  [[User:$2|$2]] ([[User talk:$2|گپ کن]]);
+'alreadyrolled'               => 'نه تونیت ترینیت اهری اصلاح چه  [[:$1]] گون  [[User:$2|$2]] ([[User talk:$2|گپ]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
 یکی دگه پیش تر صفحهء اصلاح کتت یا بری گردینت.
 
 آهری اصلاح توسط [[User:$3|$3]] ([[User talk:$3|گپ کن]]).',
@@ -1675,7 +1674,7 @@
 لطفا بجنیت "back" و صفحه ای که چه آیء اتکگیت دگه بار کنیت او راندء دگه تلاش کنیت.',
 'protectlogpage'              => 'ورودان حفاظت',
 'protectlogtext'              => 'جهلء یک لیستی چه هست چه صفحه پچ و بند کبلان.
-بچار [[Special:Protectedpages|لیست صفحات محافظتی]]  په لیستی محافظتات اجرای هنوکین صفحه',
+بچار [[Special:ProtectedPages|لیست صفحات محافظتی]]  په لیستی محافظتات اجرای هنوکین صفحه',
 'protectedarticle'            => 'محافظتی "[[$1]]"',
 'modifiedarticleprotection'   => 'عوض بوت سطح حفاظت په "[[$1]]"',
 'unprotectedarticle'          => 'بی حمایت  "[[$1]]"',
@@ -1794,8 +1793,9 @@
 
 # What links here
 'whatlinkshere'            => 'ای لینکی که ادا هست',
-'whatlinkshere-title'      => 'صفحاتی که لینگ بوتگنت په $1',
+'whatlinkshere-title'      => 'صفحاتی که لینگ بوتگنت په "$1"',
 'whatlinkshere-page'       => 'صفحه:',
+'whatlinkshere-barrow'     => '>',
 'linklistsub'              => '(لیست کل لینکان)',
 'linkshere'                => "جهلیگی صفحات لینک بوت '''[[:$1]]''':",
 'nolinkshere'              => "هچ لینک صفحه ای په '''[[:$1]]'''.",
@@ -1845,7 +1845,7 @@
 'badipaddress'                    => 'نامعتبر آدرس آی پی',
 'blockipsuccesssub'               => 'محدودیت موفق بوت',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] محدود بوتت..<br />
-بچار [[Special:Ipblocklist|لیست آی پی محدود]] په بازبینی محدودیتان.',
+بچار [[Special:IPBlockList|لیست آی پی محدود]] په بازبینی محدودیتان.',
 'ipb-edit-dropdown'               => 'اصلاح کن دلایل محدودیت',
 'ipb-unblock-addr'                => 'رفع محدودیت  $1',
 'ipb-unblock'                     => 'نام کاربری یا آدرس آی پی رفع محدودیت کن',
@@ -1878,7 +1878,7 @@
 'blocklogentry'                   => 'محدود بوته [[$1]] گون یک زمان انقاضای $2 $3',
 'blocklogtext'                    => 'شی یک آماری چه کاران محدود و رفع محدودیت چه ای کاربر انت.
 اتوماتیکی محدود بوتگین آدرس آی پی ادان لیست نهنت.
-بچار [[Special:Ipblocklist|لیست محدودیت آی پی]] په لیست هنوکین عملی محدودیتان و بند کتان.',
+بچار [[Special:IPBlockList|لیست محدودیت آی پی]] په لیست هنوکین عملی محدودیتان و بند کتان.',
 'unblocklogentry'                 => 'محدود نه کتن $1',
 'block-log-flags-anononly'        => 'ناشناس کابران فقط',
 'block-log-flags-nocreate'        => 'شرکتن حساب غیر فعال',
@@ -1919,7 +1919,7 @@
 'lockdbsuccesssub'    => 'دیتابیس کبل موفق بوت',
 'unlockdbsuccesssub'  => 'کبل دیتابیس زورگ بیت',
 'lockdbsuccesstext'   => 'دیتابیس کبلنت.<br />
-بزان که  [[Special:Unlockdb|کبل بزور]] بعد چه شی که شمی تعمیر کامل بوت.',
+بزان که  [[Special:UnlockDB|کبل بزور]] بعد چه شی که شمی تعمیر کامل بوت.',
 'unlockdbsuccesstext' => 'دیتابیس پچ بوتت/',
 'lockfilenotwritable' => 'فایل کبل دیتابیس نویسگی نهنت.
 په کبل و پچ کتن دیتابیس، ای قایل لازمت گون وب سرور نوشتن بیت.',
@@ -1931,7 +1931,7 @@
 'movepagetext'            => "استفاده چه جهلگی فرم یک صفحه ای نامی آ بدل کنت، کل تاریح آیآ په نوکین نام جاه په جاه کنت.
 گهنگین عنوان یک صفحه غیر مستقیمی په نوکین عنوان بیت.
 لینکان په کهنگین عوض نبنت;
-مطمین بیت په خاطر دوتای یا پرشتگین غیرمستقیمین.
+مطمین بیت په خاطر [[Special:DoubleRedirects|دوتایی]] یا [[Special:BrokenRedirects|پرشتگین غیر مستقیم]].
 شما مسولیت که مطمین بیت که لینکان ادامه دهنت روگ په جاهی که قرار برونت.
 
 توجه کینت صفحه جاه په جاه نه بیت اگه یک صفحه ای گون نوکین عنوان هست، مگر شی که آی هالیک بیت یا یک غیرمسقیم و پی سرین تاریح اصلاح می بیت. شی په ای معنی اینت که شما تونیت یک صفحه ای آ نامی بدل کینت که  آی نام په خطا عوض بیت و شما نه توینت یک صفحه ی نامی بازنویسی کنیت.
@@ -1944,8 +1944,6 @@
 شما جهلیگین باکس آ تیک مجنیت.
 ته ای موراد شما بایدن صفحه یا دسته جاه په جاه کنی و یا آیآ چن و بند کینت.",
 'movearticle'             => 'جاه په چاهی صفحه:',
-'movenologin'             => 'وارد نهیت',
-'movenologintext'         => 'شما بایدن یک ثبت نامی کاربری بیت و [[Special:Userlogin|وارد بیت]]په جاه په جاه کتن یک صفحه.',
 'movenotallowed'          => 'شما را اجازت به جاه په جاه کتن صفحات ته {{SITENAME}} نیست.',
 'newtitle'                => 'په نوکین عنوان:',
 'move-watch'              => 'این صفحه یا بچار',
@@ -1973,7 +1971,7 @@
 'revertmove'              => 'برگردینگ',
 'delete_and_move'         => 'حذف وجاه په جاه کن',
 'delete_and_move_text'    => '== حذف نیاز داریت په ==
-صفحه مبدا "[[$1]]"  که هنگت هستن.
+صفحه مبدا "[[:$1]]"  که هنگت هستن.
 آیا شما لوٹیت آیء حذف کنیت دان په حذف‌ آیء راهی شر بیت؟',
 'delete_and_move_confirm' => 'بله، صفحه حذف کن',
 'delete_and_move_reason'  => 'حذف بوت په شرکتن راه په جاه په جاه کتن',
@@ -1984,6 +1982,7 @@
 'imagenocrossnamespace'   => 'نه تونیت جاه په جاه کنت فایل په یا نام فضای غیر فایلی',
 'imagetypemismatch'       => 'نوکین فایل بند گون نوع آی هم دپ نهنت.',
 'imageinvalidfilename'    => 'فایل عکس هدف نام معتبر انت',
+'fix-double-redirects'    => 'په روچ کتن هر غیر مستقیمی که په مقاله اصلی اشاره کنت',
 
 # Export
 'export'            => 'خروج صفحات',
@@ -2031,7 +2030,7 @@
 'import-interwiki-history'   => 'کپی کن کل بازبینی آن تاریح په ای صفحه',
 'import-interwiki-submit'    => 'ورود',
 'import-interwiki-namespace' => 'ترانسفر صفحات په فضا نام',
-'importtext'                 => 'لطفا فایل چه منبع ویکی درگیز گون حاصین:خروج وسیله, ایء ته وتی دیسک ذخیره کن و ادان آپلود کن.',
+'importtext'                 => 'لطفا فایل چه منبع ویکی درگیز گون حاصین:[[Special:Export|وسیله درگیزگ]], ایء ته وتی دیسک ذخیره کن و ادان آپلود کن.',
 'importstart'                => 'وارد کنت صفحات...',
 'import-revision-count'      => '$1 {{PLURAL:$1|بازبینی|بازبینی ان}}',
 'importnopages'              => 'هچ صفحه ای په ورود.',
@@ -2182,10 +2181,11 @@
 'markedaspatrollederror-noautopatrol' => 'شما را اجازت نیست وتی تغییراتء په عنوان نظارت بیتگین نشان کنیت.',
 
 # Patrol log
-'patrol-log-page' => 'آمار نظارت',
-'patrol-log-line' => 'نشان هلگ بیتن $1 چه $2 نظارت $3',
-'patrol-log-auto' => '(اتوماتیک)',
-'patrol-log-diff' => 'ر$1',
+'patrol-log-page'   => 'آمار نظارت',
+'patrol-log-header' => 'شی آماری چه بازبینی آن گشتی انت.',
+'patrol-log-line'   => 'نشان هلگ بیتن $1 چه $2 نظارت $3',
+'patrol-log-auto'   => '(اتوماتیک)',
+'patrol-log-diff'   => 'ر$1',
 
 # Image deletion
 'deletedrevision'                 => 'قدیمی بازبینی $1 حذف بوت',
@@ -2214,7 +2214,7 @@
 'show-big-image'       => 'کل صفحه',
 'show-big-image-thumb' => '<small>اندازه ای بازبین:$1× $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'گالری نوکین فایلان',
 'imagelisttext'         => "جهل یک لیستی چه  '''$1''' {{PLURAL:$1|فایل|فایلان}} هست که ترتیبنت $2.",
 'newimages-summary'     => 'ای حاصین صفحه اهرین آپلود بوتگین فایلان پیشداریت',
@@ -2565,7 +2565,7 @@
 
 # External editor support
 'edit-externally'      => 'ای صفحه یا اصلاح کن گون یک درآین برنامه ای',
-'edit-externally-help' => 'په گیشترین اطلاعات بچار[http://meta.wikimedia.org/wiki/Help:External_editors setup instructions]',
+'edit-externally-help' => 'په گیشترین اطلاعات بچار[http://www.mediawiki.org/wiki/Manual:External_editors setup instructions]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'کل',
@@ -2639,7 +2639,7 @@
 'unit-pixel' => 'پیکس',
 
 # HTML dump
-'redirectingto' => 'دگه شرگنگنت په [[$1]]...',
+'redirectingto' => 'دگه شرگنگنت په [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'ذخیره ای صفحه پهک کنت؟
@@ -2693,8 +2693,8 @@
 'livepreview-error'   => 'پروش ته وصل بیگ :$1 "$2".  نرمال بازبینی سعی کن.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'تغییرات نوکتر چه $1  ثانیه انت شاید ته ای لیست پجاه می کاینت.',
-'lag-warn-high'   => 'په خاطر بازگین تاخیر سرور دیتابیس، تغییرات نوکتر چه  $1 ثانیه شایدن ته ای لیست پیش دارگ مه بنت.',
+'lag-warn-normal' => 'تغییرات نوکتر چه {{PLURAL:$1|ثانیه|ثانیه}} ثانیه انت شاید ته ای لیست پجاه می کاینت.',
+'lag-warn-high'   => 'خاطر بازگین تاخیر سرور دیتابیس، تغییرات نوکتر چه  {{PLURAL:$1|ثانیه|ثانیه}} شایدن ته ای لیست پیش دارگمه بنت.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'شمی لیست چارگ شامل  {{PLURAL:$1|1 عنوان|$1 عناوین}}, بجز صفحات گپ.',
@@ -2791,7 +2791,7 @@
 'version-software-product'         => 'محصول',
 'version-software-version'         => 'نسخه',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'مسیر فایل',
 'filepath-page'    => 'فایل:',
 'filepath-submit'  => 'مسیر',
@@ -2830,7 +2830,7 @@
 'specialpages-group-redirects'   => 'غیر مستقیم بیگنت صفحات حاصین',
 'specialpages-group-spam'        => 'وسایل اسپم',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'هالیکین صفحه',
 'intentionallyblankpage' => 'ای صفحه عمدا هالیک هلگ بوتت و په محک زتن ویا دگه چیز.',
 
Index: languages/messages/MessagesKu_latn.php
===================================================================
--- languages/messages/MessagesKu_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKu_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Bangin
- * @author Siebrand
  */
 
 $namespaceNames = array(
@@ -308,7 +307,7 @@
 'nosuchspecialpage' => 'Rûpeleke taybet bi vê rengê tune',
 'nospecialpagetext' => "<big>'''Rûpelê taybetî yê te xwastîyê tune ye.'''</big>
 
-Hemû rûpelên taybetî di [[Special:Specialpages|lîsteya rûpelên taybetî]] da werin dîtin.",
+Hemû rûpelên taybetî di [[Special:SpecialPages|lîsteya rûpelên taybetî]] da werin dîtin.",
 
 # General errors
 'error'                => 'Çewtî (Error)',
@@ -533,10 +532,6 @@
 'blockededitsource'         => "Nivîsarên '''guherandinên te''' di '''$1''' da tê wêşandan:",
 'whitelistedittitle'        => 'Ji bo guherandinê vê gotarê tu gireke xwe qeydbikê.',
 'whitelistedittext'         => 'Ji bo guherandina rûpelan, $1 pêwîst e.',
-'whitelistreadtitle'        => 'Ji xandinê vê gotarê tu gireke xwe qeydbikê',
-'whitelistreadtext'         => 'Ji bo xandinê vê gotarê tu gireke xwe [[Special:Userlogin|li vir]] qedybikê.',
-'whitelistacctitle'         => 'Tu nikanê xwe qeydbikê.',
-'whitelistacctext'          => "Ji bo qebûlkirina çêkirina account'an di {{SITENAME}}, tu gireke [[Special:Userlogin|têkevê]].",
 'confirmedittitle'          => 'Ji bo guherandinê, naskirina e-nameya te tê xastin.',
 'confirmedittext'           => 'Tu gireke adrêsa e-nameya xwe nasbikê berî tu rûpelan diguherînê. Xêra xwe adrêsa e-nameya ya xwe di [[Special:Preferences|tercihên xwe]] da binivisîne û nasbike.',
 'nosuchsectiontitle'        => 'Beşekî wisa tune ye',
@@ -551,7 +546,7 @@
 Ji bo alîkarî binêre: [[{{MediaWiki:Helppage}}|Alîkarî]].<br />
 Eger tu bi şaştî hatî, bizivire rûpela berê.",
 'anontalkpagetext'          => "----
-''Ev rûpela guftûgo ye ji bo bikarhênerên nediyarkirî ku hîn hesabekî xwe çênekirine an jî bikarnaînin. Ji ber vê yekê divê em wan bi navnîşana IP ya hejmarî nîşan bikin. Navnîşaneke IP dikare ji aliyê gelek kesan ve were bikaranîn. Heger tu bikarhênerekî nediyarkirî bî û bawerdikî ku nirxandinên bê peywend di der barê te de hatine kirin ji kerema xwe re [[Special:Userlogin|hesabekî xwe veke an jî têkeve]] da ku tu xwe ji tevlîheviyên bi bikarhênerên din re biparêzî.''",
+''Ev rûpela guftûgo ye ji bo bikarhênerên nediyarkirî ku hîn hesabekî xwe çênekirine an jî bikarnaînin. Ji ber vê yekê divê em wan bi navnîşana IP ya hejmarî nîşan bikin. Navnîşaneke IP dikare ji aliyê gelek kesan ve were bikaranîn. Heger tu bikarhênerekî nediyarkirî bî û bawerdikî ku nirxandinên bê peywend di der barê te de hatine kirin ji kerema xwe re [[Special:UserLogin|hesabekî xwe veke an jî têkeve]] da ku tu xwe ji tevlîheviyên bi bikarhênerên din re biparêzî.''",
 'noarticletext'             => 'Ev rûpel niha vala ye, tu dikarî [[Special:Search/{{PAGENAME}}|Di nav gotarên din de li "{{PAGENAME}}" bigere]] an [{{fullurl:{{FULLPAGENAME}}|action=edit}} vê rûpelê biguherînî].',
 'userpage-userdoesnotexist' => 'Account\'î bikarhêneran "$1" nehatîye qeydkirin. Xêra xwe seke ku tu dixazê vê rûpelê çêkê/biguherînê.',
 'clearyourcache'            => "'''Zanibe:''' Piştî tomarkirinê, tu gireke cache'a browser'î xwe dîsa wînê ji bo dîtina guherandinan. '''Mozilla / Firefor /Safari:''' Kepsa ''Shift'' bigre û li ''Reload'' xe, ya ''Ctrl-Shift-R'' bikepsîne (''Cmd-Shift-R'' li cem Apple Mac); '''IE:''' Kepsa ''Ctrl'' bigre û li ''Reload'' xe, ya li ''Ctrl-F5''; '''Konqueror:''' bes li ''Reload'' xe ya li kepsa ''F5'' xe; bikarhênerên '''Opera''' girekin belkî cache'a xwe tevda di bin ''Tools → Preferences'' da valabikin.",
@@ -681,7 +676,7 @@
 'mypreferences'      => 'Tercihên min',
 'prefs-edits'        => 'Hejmarê guherandinan:',
 'prefsnologin'       => 'Xwe qeyd nekir',
-'prefsnologintext'   => 'Tu gireke xwe [[Special:Userlogin|qeydbikê]] ji bo guherandina tercihên bikarhêneran.',
+'prefsnologintext'   => 'Tu gireke xwe [[Special:UserLogin|qeydbikê]] ji bo guherandina tercihên bikarhêneran.',
 'prefsreset'         => 'Tercih hatin şondakirin.',
 'qbsettings-none'    => 'Tune',
 'changepassword'     => 'Şîfre biguherîne',
@@ -728,7 +723,7 @@
 'userrights-reason'        => 'Sedemê guherandinê:',
 'userrights-no-interwiki'  => 'Mafên te ji bo guherandina mafên bikarhêneran di Wîkîyên din da tune ne.',
 'userrights-nodatabase'    => "Database'a $1 tune ye ya ne yê vir e.",
-'userrights-nologin'       => "Ji bo guherandina mafên bikarhêneran, tu gereke xwe bi account'eka koordînatorekî [[Special:Userlogin|qeydbikê]].",
+'userrights-nologin'       => "Ji bo guherandina mafên bikarhêneran, tu gereke xwe bi account'eka koordînatorekî [[Special:UserLogin|qeydbikê]].",
 'userrights-notallowed'    => "Account'a te mafê xwe tune ye ji bo guherandina mafên bikarhêneran.",
 
 # Groups
@@ -780,9 +775,9 @@
 'reupload'               => 'Dîsa barbike',
 'reuploaddesc'           => 'Barkirinê biskîne û dîsa here rûpela barkirinê.',
 'uploadnologin'          => 'Xwe qeyd nekir',
-'uploadnologintext'      => 'Ji bo barkirina wêneyan divê ku tu [[Special:Userlogin|têkevî]].',
+'uploadnologintext'      => 'Ji bo barkirina wêneyan divê ku tu [[Special:UserLogin|têkevî]].',
 'uploaderror'            => 'Şaşbûn bo barkirinê',
-'uploadtext'             => "Berê tu wêneyên nû bar bikî, ji bo dîtin an vedîtina wêneyên ku ji xwe hene binêre: [[Special:Imagelist|lîsteya wêneyên barkirî]]. Herwisa wêneyên ku hatine barkirin an jî jê birin li vir dikarî bibînî: [[Special:Log/upload|reşahîya barkirîyan]].
+'uploadtext'             => "Berê tu wêneyên nû bar bikî, ji bo dîtin an vedîtina wêneyên ku ji xwe hene binêre: [[Special:ImageList|lîsteya wêneyên barkirî]]. Herwisa wêneyên ku hatine barkirin an jî jê birin li vir dikarî bibînî: [[Special:Log/upload|reşahîya barkirîyan]].
 
 Yek ji lînkên jêr ji bo bikarhînana wêne an file'ê di gotarê de bikar bihîne:
 '''<nowiki>[[</nowiki>{{ns:image}}:File.jpg<nowiki>]]</nowiki>''',
@@ -840,7 +835,7 @@
 
 'license' => 'Lîsens:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Li navî wêneyê bigere:',
 'imagelist'             => 'Listeya wêneyan',
 'imagelist_date'        => 'Dem',
@@ -877,7 +872,7 @@
 'filedelete'                  => '$1 jêbibe',
 'filedelete-legend'           => 'Data jêbibe',
 'filedelete-intro'            => "Tu kê '''[[Media:$1|$1]]''' jêbibê.",
-'filedelete-intro-old'        => '<span class="plainlinks">Tu niha verzyona \'\'\'[[Media:$1|$1]]\'\'\' [$4 verzyon, ji $2, saet $3] jêdibê.</span>',
+'filedelete-intro-old'        => "Tu niha verzyona '''[[Media:$1|$1]]''' [$4 verzyon, ji $2, saet $3] jêdibê.",
 'filedelete-comment'          => 'Nivîs:',
 'filedelete-submit'           => 'Jêbibe',
 'filedelete-success'          => "'''$1''' hate jêbirin.",
@@ -920,7 +915,7 @@
 Ji ber wê di nîvî de her rûpel '''$5''' carî hatiye guherandin, û nîspeta dîtun û guherandinan '''$6''' e.
 
 Dirêjahîya [http://www.mediawiki.org/wiki/Manual:Job_queue ''job queue''] '''$7''' e.",
-'userstatstext' => "Li vir {{PLURAL:$1|[[Special:Listusers|bikarhênerekî]]|'''$1''' [[Special:Listusers|bikarhênerên]]}} qeydkirî {{PLURAL:$1|heye|hene}}, ji wan '''$2''' (an '''$4%''') qebûlkirinên $5 {{PLURAL:$2|birîye|birine}}.",
+'userstatstext' => "Li vir {{PLURAL:$1|[[Special:ListUsers|bikarhênerekî]]|'''$1''' [[Special:ListUsers|bikarhênerên]]}} qeydkirî {{PLURAL:$1|heye|hene}}, ji wan '''$2''' (an '''$4%''') qebûlkirinên $5 {{PLURAL:$2|birîye|birine}}.",
 
 'disambiguations'     => 'Rûpelên cudakirinê',
 'disambiguationspage' => 'Template:disambig',
@@ -986,7 +981,7 @@
 'logempty'             => 'Tişt di vir da tune.',
 'log-title-wildcard'   => 'Li sernavan bigere, yê bi vê destpêdikin',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Hemû rûpel',
 'alphaindexline'    => '$1 heta $2',
 'nextpage'          => 'Rûpela pêşî ($1)',
@@ -1008,13 +1003,13 @@
 'special-categories-sort-count' => 'hatîye rêzkirin li gorî hejmaran',
 'special-categories-sort-abc'   => 'hatîye rêzkirin li gorî alfabeyê',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Pêşêkê',
 'listusers-noresult' => 'Ne bikarhênerek hate dîtin.',
 
 # E-mail user
 'mailnologin'     => 'Navnîşan neşîne',
-'mailnologintext' => 'Te gireke xwe [[Special:Userlogin|qeydbikê]] û adrêsa e-nameyan di [[Special:Preferences|tercihên xwe]] da nivîsandibe ji bo şandina e-nameyan ji bikarhênerên din ra.',
+'mailnologintext' => 'Te gireke xwe [[Special:UserLogin|qeydbikê]] û adrêsa e-nameyan di [[Special:Preferences|tercihên xwe]] da nivîsandibe ji bo şandina e-nameyan ji bikarhênerên din ra.',
 'emailuser'       => 'Ji vê/î bikarhênerê/î re e-name bişîne',
 'emailpage'       => 'E-name bikarhêner',
 'defemailsubject' => '{{SITENAME}} e-name',
@@ -1035,12 +1030,12 @@
 'nowatchlist'          => 'Tiştek di lîsteya te ya şopandinê da tune ye.',
 'watchlistanontext'    => 'Ji bo sekirinê ya xeyrandinê lîsteya te ya şopandinê tu gireke xwe $1.',
 'watchnologin'         => 'Te xwe qeyd nekirîye.',
-'watchnologintext'     => 'Ji bo xeyrandinê lîsteya te ya şopandinê tu gireke xwe [[Special:Userlogin|qedy kiribe]].',
+'watchnologintext'     => 'Ji bo xeyrandinê lîsteya te ya şopandinê tu gireke xwe [[Special:UserLogin|qedy kiribe]].',
 'addedwatch'           => 'Hat îlawekirinî listeya şopandinê',
 'addedwatchtext'       => "Rûpela \"<nowiki>\$1</nowiki>\" çû ser [[Special:Watchlist|lîsteya te ya şopandinê]].
 Li dahatû de her guhartoyek li wê rûpelê û rûpela guftûgo ya wê were kirin li vir dêt nîşan dan,
 
-Li rûpela [[Special:Recentchanges|Guherandinên dawî]] jî ji bo hasan dîtina wê, ew rûpel bi '''Nivîsa estûr''' dê nîşan dayîn.
+Li rûpela [[Special:RecentChanges|Guherandinên dawî]] jî ji bo hasan dîtina wê, ew rûpel bi '''Nivîsa estûr''' dê nîşan dayîn.
 
 
 <p>Her dem tu bixwazî ew rûpel li nav lîsteya te ya şopandinê derbikî, li ser wê rûpelê, klîk bike \"êdî neşopîne\".</p>",
@@ -1263,7 +1258,7 @@
 'badipaddress'                => 'Bikarhêner bi vî navî tune',
 'blockipsuccesssub'           => 'Blok serkeftî',
 'blockipsuccesstext'          => '"$1" hat asteng kirin.
-<br />Bibîne [[Special:Ipblocklist|Lîsteya IP\'yan hatî asteng kirin]] ji bo lîsteya blokan.',
+<br />Bibîne [[Special:IPBlockList|Lîsteya IP\'yan hatî asteng kirin]] ji bo lîsteya blokan.',
 'ipb-edit-dropdown'           => 'Sedemên astengkirinê',
 'ipb-unblock-addr'            => 'Astengkirinê $1 rake',
 'ipb-unblock'                 => "Astengkirina bikarhênerekî ya adrêsa IP'yekê rake",
@@ -1293,7 +1288,7 @@
 'autoblocker'                 => 'Otomatîk hat bestin jiberku IP-ya we û ya "[[User:$1|$1]]" yek in. Sedem: "\'\'\'$2\'\'\'"',
 'blocklogpage'                => 'Reşahîya astengkirinê',
 'blocklogentry'               => '"[[$1]]" ji bo dema $2 $3 hatîye asteng kirin',
-'blocklogtext'                => "Ev reşahîyek ji astengkirinên û rakirina astengkirinên bikarhêneran ra ye. Adrêsên IP'yan, yê otomatîk hatine astengkirin, nehatine nivîsandin. [[Special:Ipblocklist|Lîsteya IP'yên astengkirî]] bibîne ji bo dîtina astengkirinên IP'yan.",
+'blocklogtext'                => "Ev reşahîyek ji astengkirinên û rakirina astengkirinên bikarhêneran ra ye. Adrêsên IP'yan, yê otomatîk hatine astengkirin, nehatine nivîsandin. [[Special:IPBlockList|Lîsteya IP'yên astengkirî]] bibîne ji bo dîtina astengkirinên IP'yan.",
 'unblocklogentry'             => 'astenga "$1" betalkir',
 'block-log-flags-anononly'    => 'bes bikarhênerên neqeydkirî',
 'block-log-flags-nocreate'    => "çêkirina account'an hatîye qedexekirin",
@@ -1318,9 +1313,6 @@
 
 Xêra xwe navî nuh û sedemê navgerandinê binivisîne.",
 'movearticle'             => 'Rûpelê bigerîne',
-'movenologin'             => 'Xwe qeyd nekir',
-'movenologintext'         => 'Tu dive bikarhênereke qeydkirî bî û [[Special:Userlogin|werî nav sîstemê]]
-da bikarî navê wê rûpelê biguherînî.',
 'movenotallowed'          => 'Tu nikanê navên gotarên {{SITENAME}} biguherînê.',
 'newtitle'                => 'Sernivîsa nû',
 'move-watch'              => 'Vê rûpelê bişopîne',
@@ -1338,7 +1330,7 @@
 'delete_and_move'         => 'Jêbibe û nav biguherîne',
 'delete_and_move_text'    => '== Jêbirin gireke ==
 
-Rûpela "[[$1]]" berê heye. Tu rast dixazê wê jêbibê ji bo navguherandinê ra?',
+Rûpela "[[:$1]]" berê heye. Tu rast dixazê wê jêbibê ji bo navguherandinê ra?',
 'delete_and_move_confirm' => 'Erê, wê rûpelê jêbibe',
 'delete_and_move_reason'  => 'Jêbir ji bo navguherandinê',
 
@@ -1514,7 +1506,7 @@
 'show-big-image'       => 'Mezînbûn',
 'show-big-image-thumb' => '<small>Mezinbûna vê pêşnîşandanê: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Pêşangeha wêneyên nû',
 'imagelisttext'         => "Jêr lîsteyek ji $1 file'an heye, duxrekirin $2.",
 'showhidebots'          => "($1 bot'an)",
@@ -1571,7 +1563,7 @@
 'recreate'            => 'Dîsa tomarbike',
 
 # HTML dump
-'redirectingto' => 'Redirect berve [[$1]] tê çêkirin...',
+'redirectingto' => 'Redirect berve [[:$1]] tê çêkirin...',
 
 # action=purge
 'confirm_purge'        => 'Bîra vê rûpelê jêbîbe ?
@@ -1622,7 +1614,7 @@
 'version'       => 'Verzîyon', # Not used as normal message but as header for the special page itself
 'version-other' => 'yên din',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Data:',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesFi.php
===================================================================
--- languages/messages/MessagesFi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author Nike
- * @author Crt
+ * @author Agony
  * @author Cimon Avaro
- * @author Siebrand
+ * @author Crt
+ * @author Jaakonam
  * @author Jack Phoenix
- * @author M.M.S.
+ * @author Nike
  * @author Str4nd
  * @author לערי ריינהארט
  */
@@ -536,7 +536,7 @@
 'logouttext'                 => 'Olet nyt kirjautunut ulos {{GRAMMAR:elative|{{SITENAME}}}}. Voit jatkaa {{GRAMMAR:genitive|{{SITENAME}}}} käyttöä nimettömänä, tai kirjautua uudelleen sisään.',
 'welcomecreation'            => '== Tervetuloa $1! ==
 Käyttäjätunnuksesi on luotu.
-Älä unohda virittää {{GRAMMAR:genitive|{{SITENAME}}}} asetuksiasi.',
+Älä unohda virittää {{GRAMMAR:genitive|{{SITENAME}}}} [[Special:Preferences|asetuksiasi]].',
 'loginpagetitle'             => 'Sisäänkirjautuminen',
 'yourname'                   => 'Käyttäjätunnus',
 'yourpassword'               => 'Salasana',
@@ -681,10 +681,6 @@
 'blockededitsource'                => 'Muokkauksesi sivuun ”$1”:',
 'whitelistedittitle'               => 'Sisäänkirjautuminen vaaditaan muokkaamiseen',
 'whitelistedittext'                => 'Sinun täytyy $1, jotta voisit muokata sivuja.',
-'whitelistreadtitle'               => 'Sisäänkirjautuminen vaaditaan lukemiseen',
-'whitelistreadtext'                => 'Sinun täytyy kirjautua [[Special:Userlogin|sisään]] lukeaksesi sivuja.',
-'whitelistacctitle'                => 'Sinun ei ole sallittu luoda tunnusta',
-'whitelistacctext'                 => 'Saadaksesi oikeudet luoda tunnus sinun täytyy kirjautua [[Special:Userlogin|sisään]] ja sinulla tulee olla asiaankuuluvat oikeudet.',
 'confirmedittitle'                 => 'Sähköpostin varmennus',
 'confirmedittext'                  => 'Et voi muokata sivuja, ennen kuin olet varmentanut sähköpostiosoitteesi. Voit tehdä varmennuksen [[Special:Preferences|asetussivulla]].',
 'nosuchsectiontitle'               => 'Pyydettyä osiota ei ole',
@@ -696,7 +692,7 @@
 'accmailtext'                      => "käyttäjän '''$1''' salasana on lähetetty osoitteeseen '''$2'''.",
 'newarticle'                       => '(uusi)',
 'newarticletext'                   => 'Linkki toi sivulle, jota ei vielä ole. Voit luoda sivun kirjoittamalla alla olevaan tilaan. Jos et halua luoda sivua, käytä selaimen paluutoimintoa.',
-'anontalkpagetext'                 => "----''Tämä on nimettömän käyttäjän keskustelusivu. Hän ei ole joko luonut itselleen käyttäjätunnusta tai ei käytä sitä. Siksi hänet tunnistetaan nyt numeerisella IP-osoitteella. Kyseinen IP-osoite voi olla useamman henkilön käytössä. Jos olet nimetön käyttäjä, ja sinusta tuntuu, että aiheettomia kommentteja on ohjattu sinulle, [[Special:Userlogin|luo itsellesi käyttäjätunnus tai kirjaudu sisään]] välttääksesi jatkossa sekaannukset muiden nimettömien käyttäjien kanssa.''",
+'anontalkpagetext'                 => "----''Tämä on nimettömän käyttäjän keskustelusivu. Hän ei ole joko luonut itselleen käyttäjätunnusta tai ei käytä sitä. Siksi hänet tunnistetaan nyt numeerisella IP-osoitteella. Kyseinen IP-osoite voi olla useamman henkilön käytössä. Jos olet nimetön käyttäjä, ja sinusta tuntuu, että aiheettomia kommentteja on ohjattu sinulle, [[Special:UserLogin|luo itsellesi käyttäjätunnus tai kirjaudu sisään]] välttääksesi jatkossa sekaannukset muiden nimettömien käyttäjien kanssa.''",
 'noarticletext'                    => "{{GRAMMAR:inessive|{{SITENAME}}}} ei ole tämän nimistä sivua.
 * Voit [[Special:Search/{{PAGENAME}}|etsiä sivun nimellä]] muilta sivuilta.
 * Voit kirjoittaa uuden sivun '''<span class=\"plainlinks\">[{{fullurl:{{FULLPAGENAME}}|action=edit}} {{PAGENAME}}]</span>.'''",
@@ -748,7 +744,7 @@
 'hiddencategories'                 => 'Tämä sivu kuuluu {{PLURAL:$1|seuraavaan piilotettuun luokkaan|seuraaviin piilotettuihin luokkiin}}:',
 'edittools'                        => '<!-- Tässä oleva teksti näytetään muokkauskentän alla. -->',
 'nocreatetitle'                    => 'Sivujen luominen on rajoitettu',
-'nocreatetext'                     => 'Et voi luoda uusia sivuja. Voit muokata olemassa olevia sivuja tai luoda [[Special:Userlogin|käyttäjätunnuksen]].',
+'nocreatetext'                     => 'Et voi luoda uusia sivuja. Voit muokata olemassa olevia sivuja tai luoda [[Special:UserLogin|käyttäjätunnuksen]].',
 'nocreate-loggedin'                => 'Sinulla ei ole oikeuksia luoda uusia sivuja {{GRAMMAR:genitive|{{SITENAME}}}}.',
 'permissionserrors'                => 'Puutteelliset oikeudet',
 'permissionserrorstext'            => 'Sinulla ei ole oikeuksia suorittaa toimintoa {{PLURAL:$1|seuraavasta|seuraavista}} syistä johtuen:',
@@ -857,7 +853,7 @@
 # Suppression log
 'suppressionlog'     => 'Häivitysloki',
 'suppressionlogtext' => 'Alla on lista uusimmista poistoista ja muokkausestoista, jotka sisältävät ylläpitäjiltä piilotettua materiaalia.
-[[Special:Ipblocklist|Muokkausestolistassa]] on tämänhetkiset muokkausestot.',
+[[Special:IPBlockList|Muokkausestolistassa]] on tämänhetkiset muokkausestot.',
 
 # History merging
 'mergehistory'                     => 'Yhdistä sivuhistoriat',
@@ -942,7 +938,7 @@
 'mypreferences'            => 'Asetukset',
 'prefs-edits'              => 'Muokkauksia',
 'prefsnologin'             => 'Et ole kirjautunut sisään.',
-'prefsnologintext'         => 'Sinun täytyy [[Special:Userlogin|kirjautua sisään]], jotta voisit muuttaa asetuksiasi.',
+'prefsnologintext'         => 'Sinun täytyy [[Special:UserLogin|kirjautua sisään]], jotta voisit muuttaa asetuksiasi.',
 'prefsreset'               => 'Asetukset on palautettu tallennetuista asetuksistasi.',
 'qbsettings'               => 'Pikavalikko',
 'qbsettings-none'          => 'Ei mitään',
@@ -1016,7 +1012,7 @@
 'userrights-reason'           => 'Kommentti',
 'userrights-no-interwiki'     => 'Sinulla ei ole lupaa muokata käyttöoikeuksia muissa wikeissä.',
 'userrights-nodatabase'       => 'Tietokantaa $1 ei ole tai se ei ole paikallinen.',
-'userrights-nologin'          => 'Sinun täytyy [[Special:Userlogin|kirjautua sisään]] ylläpitäjätunnuksella, jotta voisit muuttaa käyttöoikeuksia.',
+'userrights-nologin'          => 'Sinun täytyy [[Special:UserLogin|kirjautua sisään]] ylläpitäjätunnuksella, jotta voisit muuttaa käyttöoikeuksia.',
 'userrights-notallowed'       => 'Tunnuksellasi ei ole lupaa muuttaa käyttöoikeuksia.',
 'userrights-changeable-col'   => 'Ryhmät, joita voit muuttaa',
 'userrights-unchangeable-col' => 'Ryhmät, joita et voi muuttaa',
@@ -1145,11 +1141,11 @@
 'reupload'                    => 'Lähetä uudelleen',
 'reuploaddesc'                => 'Palaa lähetyslomakkeelle.',
 'uploadnologin'               => 'Et ole kirjautunut sisään',
-'uploadnologintext'           => 'Sinun pitää olla [[Special:Userlogin|kirjautuneena sisään]], jotta voisit tallentaa tiedostoja.',
+'uploadnologintext'           => 'Sinun pitää olla [[Special:UserLogin|kirjautuneena sisään]], jotta voisit tallentaa tiedostoja.',
 'upload_directory_missing'    => 'Tallennushakemisto $1 puuttuu, eikä palvelin pysty luomaan sitä.',
 'upload_directory_read_only'  => 'Palvelimella ei ole kirjoitusoikeuksia tallennushakemistoon ”<tt>$1</tt>”.',
 'uploaderror'                 => 'Tallennusvirhe',
-'uploadtext'                  => "Voit tallentaa tiedostoja alla olevalla lomakkeella. [[Special:Imagelist|Tiedostoluettelo]] sisältää listan tallennetuista tiedostoista. Tallennukset ja poistot kirjataan myös [[Special:Log/upload|tallennuslokiin]].
+'uploadtext'                  => "Voit tallentaa tiedostoja alla olevalla lomakkeella. [[Special:ImageList|Tiedostoluettelo]] sisältää listan tallennetuista tiedostoista. Tallennukset ja poistot kirjataan myös [[Special:Log/upload|tallennuslokiin]].
 
 Voit käyttää tiedostoja wikisivuilla seuraavilla tavoilla:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Tiedosto.jpg]]</nowiki>''',
@@ -1232,7 +1228,7 @@
 'upload_source_url'  => ' (julkinen verkko-osoite)',
 'upload_source_file' => ' (tiedosto tietokoneella)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Tämä toimintosivu näyttää kaikki tallennetut tiedostot. Viimeisin tallennettu tiedosto on listalla ensimmäisenä. Ryhmittelyperustetta voi vaihtaa napsauttamalla sarakenimeä.',
 'imagelist_search_for'  => 'Nimihaku',
 'imgfile'               => 'tiedosto',
@@ -1258,7 +1254,7 @@
 'imagelinks'                     => 'Viittaukset sivuilta',
 'linkstoimage'                   => '{{PLURAL:$1|Seuraavalta sivulta|$1 sivulla}} on linkki tähän tiedostoon:',
 'nolinkstoimage'                 => 'Tähän tiedostoon ei ole linkkejä miltään sivulta.',
-'morelinkstoimage'               => 'Näytä [[Special:Whatlinkshere/$1|lisää linkkejä]] tähän tiedostoon.',
+'morelinkstoimage'               => 'Näytä [[Special:WhatLinksHere/$1|lisää linkkejä]] tähän tiedostoon.',
 'redirectstofile'                => '{{PLURAL:$1|Seuraava tiedosto ohjaa|Seuraavat $1 tiedostoa ohjaavat}} tähän tiedostoon:',
 'duplicatesoffile'               => '{{PLURAL:$1|Seuraava tiedosto on tämän tiedoston kaksoiskappale|Seuraavat $1 tiedostoa ovat tämän tiedoston kaksoiskappaleita}}:',
 'sharedupload'                   => 'Tämä tiedosto on jaettu ja muut projektit saattavat käyttää sitä.',
@@ -1346,8 +1342,9 @@
 'disambiguationspage'  => 'Template:Täsmennyssivu',
 'disambiguations-text' => "Seuraavat artikkelit linkittävät ''täsmennyssivuun''. Täsmennyssivun sijaan niiden pitäisi linkittää asianomaiseen aiheeseen.<br />Sivua kohdellaan täsmennyssivuna jos se käyttää mallinetta, johon on linkki sivulta [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Kaksinkertaiset ohjaukset',
-'doubleredirectstext' => '<b>Huomio:</b> Tässä listassa saattaa olla virheitä. Yleensä kyseessä on sivu, jossa ensimmäisen #REDIRECT- tai #OHJAUS-komennon jälkeen on tekstiä.<br />Jokaisella rivillä on linkit ensimmäiseen ja toiseen ohjaukseen sekä toisen ohjauksen kohteen ensimmäiseen riviin, eli yleensä ”oikeaan” kohteeseen, johon ensimmäisen ohjauksen pitäisi osoittaa.',
+'doubleredirects'            => 'Kaksinkertaiset ohjaukset',
+'doubleredirectstext'        => '<b>Huomio:</b> Tässä listassa saattaa olla virheitä. Yleensä kyseessä on sivu, jossa ensimmäisen #REDIRECT- tai #OHJAUS-komennon jälkeen on tekstiä.<br />Jokaisella rivillä on linkit ensimmäiseen ja toiseen ohjaukseen sekä toisen ohjauksen kohteen ensimmäiseen riviin, eli yleensä ”oikeaan” kohteeseen, johon ensimmäisen ohjauksen pitäisi osoittaa.',
+'double-redirect-fixed-move' => '[[$1]] on siirretty, se on nyt ohjaus sivulle [[$2]]',
 
 'brokenredirects'        => 'Virheelliset ohjaukset',
 'brokenredirectstext'    => 'Seuraavat ohjaukset osoittavat sivuihin, joita ei ole olemassa.',
@@ -1433,7 +1430,7 @@
 'logempty'             => 'Ei tapahtumia lokissa.',
 'log-title-wildcard'   => 'Kohde alkaa merkkijonolla',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Kaikki sivut',
 'alphaindexline'    => '$1…$2',
 'nextpage'          => 'Seuraava sivu ($1)',
@@ -1456,12 +1453,12 @@
 'special-categories-sort-count' => 'järjestä koon mukaan',
 'special-categories-sort-abc'   => 'järjestä nimen mukaan',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Katkaisuhaku',
 'listusers-submit'   => 'Hae',
 'listusers-noresult' => 'Käyttäjiä ei löytynyt.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Käyttäjäryhmien oikeudet',
 'listgrouprights-summary'  => 'Tässä on lista {{GRAMMAR:genitive|{{SITENAME}}}} käyttäjäryhmistä ja niiden oikeudet.
 Lisätietoa yksittäisistä käyttäjäoikeuksista on [[{{MediaWiki:Listgrouprights-helppage}}|ohjesivulla]].',
@@ -1472,7 +1469,7 @@
 
 # E-mail user
 'mailnologin'     => 'Lähettäjän osoite puuttuu',
-'mailnologintext' => 'Sinun pitää olla [[Special:Userlogin|kirjautuneena sisään]] ja [[Special:Preferences|asetuksissasi]] pitää olla toimiva ja <strong>varmennettu</strong> sähköpostiosoite, jotta voit lähettää sähköpostia muille käyttäjille.',
+'mailnologintext' => 'Sinun pitää olla [[Special:UserLogin|kirjautuneena sisään]] ja [[Special:Preferences|asetuksissasi]] pitää olla toimiva ja <strong>varmennettu</strong> sähköpostiosoite, jotta voit lähettää sähköpostia muille käyttäjille.',
 'emailuser'       => 'Lähetä sähköpostia tälle käyttäjälle',
 'emailpage'       => 'Lähetä sähköpostia käyttäjälle',
 'emailpagetext'   => 'Jos tämä käyttäjä on antanut asetuksissaan kelvollisen sähköpostiosoitteen, alla olevalla lomakkeella voit lähettää yhden viestin hänelle. Omissa asetuksissasi annettu sähköpostiosoite näkyy sähköpostin lähettäjän osoitteena, jotta vastaanottaja voi vastata viestiin.',
@@ -1498,9 +1495,9 @@
 'nowatchlist'          => 'Tarkkailulistallasi ei ole sivuja.',
 'watchlistanontext'    => 'Sinun täytyy $1, jos haluat käyttää tarkkailulistaa.',
 'watchnologin'         => 'Et ole kirjautunut sisään',
-'watchnologintext'     => 'Sinun pitää [[Special:Userlogin|kirjautua sisään]], jotta voisit käyttää tarkkailulistaasi.',
+'watchnologintext'     => 'Sinun pitää [[Special:UserLogin|kirjautua sisään]], jotta voisit käyttää tarkkailulistaasi.',
 'addedwatch'           => 'Lisätty tarkkailulistalle',
-'addedwatchtext'       => "Sivu '''<nowiki>$1</nowiki>''' on lisätty [[Special:Watchlist|tarkkailulistallesi]]. Tulevaisuudessa sivuun ja sen keskustelusivuun tehtävät muutokset listataan täällä. Sivu on '''lihavoitu''' [[Special:Recentchanges|tuoreiden muutosten listassa]], jotta huomaisit sen helpommin. Jos haluat myöhemmin poistaa sivun tarkkailulistaltasi, napsauta linkkiä ''lopeta tarkkailu'' sivun reunassa.",
+'addedwatchtext'       => "Sivu '''<nowiki>$1</nowiki>''' on lisätty [[Special:Watchlist|tarkkailulistallesi]]. Tulevaisuudessa sivuun ja sen keskustelusivuun tehtävät muutokset listataan täällä. Sivu on '''lihavoitu''' [[Special:RecentChanges|tuoreiden muutosten listassa]], jotta huomaisit sen helpommin. Jos haluat myöhemmin poistaa sivun tarkkailulistaltasi, napsauta linkkiä ''lopeta tarkkailu'' sivun reunassa.",
 'removedwatch'         => 'Poistettu tarkkailulistalta',
 'removedwatchtext'     => "Sivu '''<nowiki>$1</nowiki>''' on poistettu tarkkailulistaltasi.",
 'watch'                => 'Tarkkaile',
@@ -1606,7 +1603,7 @@
 'rollback-success'            => 'Käyttäjän ”$1” tekemät muokkaukset kumottiin ja artikkeli palautettiin käyttäjän $2 versioon.',
 'sessionfailure'              => 'Istuntosi kanssa on ongelma. Muutosta ei toteutettu varotoimena sessionkaappauksien takia. Käytä selaimen paluutoimintoa ja päivitä sivu, jolta tulit, ja yritä uudelleen.',
 'protectlogpage'              => 'Suojausloki',
-'protectlogtext'              => 'Alla on loki sivujen suojauksista ja suojauksien poistoista. Luettelo tällä hetkellä suojatuista sivuista löytyy [[Special:Protectedpages|suojattuen sivujen luettelosta]].',
+'protectlogtext'              => 'Alla on loki sivujen suojauksista ja suojauksien poistoista. Luettelo tällä hetkellä suojatuista sivuista löytyy [[Special:ProtectedPages|suojattuen sivujen luettelosta]].',
 'protectedarticle'            => 'suojasi sivun $1',
 'modifiedarticleprotection'   => 'muutti sivun [[$1]] suojaustasoa',
 'unprotectedarticle'          => 'poisti suojauksen sivulta $1',
@@ -1760,7 +1757,7 @@
 'ipbwatchuser'                    => 'Tarkkaile tämän käyttäjän käyttäjä- ja keskustelusivua',
 'badipaddress'                    => 'IP-osoite on väärin muotoiltu.',
 'blockipsuccesssub'               => 'Esto onnistui',
-'blockipsuccesstext'              => "Käyttäjä tai IP-osoite '''$1''' on estetty.<br />Nykyiset estot löytyvät [[Special:Ipblocklist|estolistalta]].",
+'blockipsuccesstext'              => "Käyttäjä tai IP-osoite '''$1''' on estetty.<br />Nykyiset estot löytyvät [[Special:IPBlockList|estolistalta]].",
 'ipb-edit-dropdown'               => 'Muokkaa syitä',
 'ipb-unblock-addr'                => 'Poista käyttäjän $1 esto',
 'ipb-unblock'                     => 'Poista käyttäjän tai IP-osoitteen muokkausesto',
@@ -1790,7 +1787,7 @@
 'autoblocker'                     => 'Olet automaattisesti estetty, koska jaat IP-osoitteen käyttäjän $1 kanssa. Eston syy: $2.',
 'blocklogpage'                    => 'Estoloki',
 'blocklogentry'                   => 'esti käyttäjän tai IP-osoitteen $1. Eston kesto $2 $3',
-'blocklogtext'                    => 'Tämä on loki muokkausestoista ja niiden purkamisista. Automaattisesti estettyjä IP-osoitteita ei kirjata. Tutustu [[Special:Ipblocklist|estolistaan]] nähdäksesi listan tällä hetkellä voimassa olevista estoista.',
+'blocklogtext'                    => 'Tämä on loki muokkausestoista ja niiden purkamisista. Automaattisesti estettyjä IP-osoitteita ei kirjata. Tutustu [[Special:IPBlockList|estolistaan]] nähdäksesi listan tällä hetkellä voimassa olevista estoista.',
 'unblocklogentry'                 => 'poisti käyttäjältä $1 muokkauseston',
 'block-log-flags-anononly'        => 'vain kirjautumattomat käyttäjät',
 'block-log-flags-nocreate'        => 'tunnusten luonti estetty',
@@ -1848,8 +1845,6 @@
 
 Näissä tapauksissa sivut täytyy siirtää tai yhdistää käsin.",
 'movearticle'             => 'Siirrä sivu',
-'movenologin'             => 'Et ole kirjautunut sisään',
-'movenologintext'         => 'Sinun pitää olla rekisteröitynyt käyttäjä ja kirjautua sisään, jotta voisit siirtää sivun.',
 'movenotallowed'          => 'Sinulla ei ole oikeuksia siirtää sivuja {{GRAMMAR:genitive|{{SITENAME}}}}.',
 'newtitle'                => 'Uusi nimi sivulle',
 'move-watch'              => 'Tarkkaile tätä sivua',
@@ -1875,7 +1870,7 @@
 'movereason'              => 'Syy',
 'revertmove'              => 'kumoa',
 'delete_and_move'         => 'Poista kohdesivu ja siirrä',
-'delete_and_move_text'    => 'Kohdesivu [[$1]] on jo olemassa. Haluatko poistaa sen, jotta nykyinen sivu voitaisiin siirtää?',
+'delete_and_move_text'    => 'Kohdesivu [[:$1]] on jo olemassa. Haluatko poistaa sen, jotta nykyinen sivu voitaisiin siirtää?',
 'delete_and_move_confirm' => 'Poista sivu',
 'delete_and_move_reason'  => 'Sivu on siirron tiellä.',
 'selfmove'                => 'Lähde- ja kohdenimi ovat samat.',
@@ -1883,6 +1878,7 @@
 'imagenocrossnamespace'   => 'Tiedostoja ei voi siirtää pois tiedostonimiavaruudesta.',
 'imagetypemismatch'       => 'Uusi tiedostopääte ei vastaa tiedoston tyyppiä',
 'imageinvalidfilename'    => 'Kohdenimi on virheellinen',
+'fix-double-redirects'    => 'Päivitä kaikki tänne viittaavat ohjaukset ohjaamaan uudelle nimelle',
 
 # Export
 'export'            => 'Sivujen vienti',
@@ -2078,9 +2074,10 @@
 'markedaspatrollederror-noautopatrol' => 'Et voi merkitä omia muutoksiasi tarkastetuiksi.',
 
 # Patrol log
-'patrol-log-page' => 'Muutostentarkastusloki',
-'patrol-log-line' => 'merkitsi sivun $2 muutoksen $1 tarkastetuksi $3',
-'patrol-log-auto' => '(automaattinen)',
+'patrol-log-page'   => 'Muutostentarkastusloki',
+'patrol-log-header' => 'Tämä on loki tarkistetuista muutoksista.',
+'patrol-log-line'   => 'merkitsi sivun $2 muutoksen $1 tarkastetuksi $3',
+'patrol-log-auto'   => '(automaattinen)',
 
 # Image deletion
 'deletedrevision'                 => 'Poistettiin vanha versio $1',
@@ -2109,7 +2106,7 @@
 'show-big-image'       => 'Korkeatarkkuuksinen versio',
 'show-big-image-thumb' => '<small>Esikatselun koko: $1×$2 px</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Uudet tiedostot',
 'imagelisttext'         => 'Alla on {{PLURAL:$1|1 tiedosto|$1 tiedostoa}} lajiteltuna <strong>$2</strong>.',
 'newimages-summary'     => 'Tällä toimintosivulla on viimeisimmät tallennetut tiedostot.',
@@ -2451,7 +2448,7 @@
 'unit-pixel' => ' px',
 
 # HTML dump
-'redirectingto' => 'Ohjataan sivulle [[$1]]...',
+'redirectingto' => 'Ohjataan sivulle [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Poistetaanko tämän sivun välimuistikopiot?
@@ -2503,8 +2500,8 @@
 Yritä normaalia esikatselua.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Muutokset, jotka ovat uudempia kuin $1 sekuntia, eivät välttämättä näy tällä sivulla.',
-'lag-warn-high'   => 'Tietokannoilla on työjonoa. Muutokset, jotka ovat uudempia kuin $1 sekuntia, eivät välttämättä näy tällä sivulla.',
+'lag-warn-normal' => 'Muutokset, jotka ovat uudempia kuin $1 {{PLURAL:$1|sekunti|sekuntia}}, eivät välttämättä näy tällä sivulla.',
+'lag-warn-high'   => 'Tietokannoilla on työjonoa. Muutokset, jotka ovat uudempia kuin $1 {{PLURAL:$1|sekunti|sekuntia}}, eivät välttämättä näy tällä sivulla.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Tarkkailulistallasi on {{PLURAL:$1|yksi sivu|$1 sivua}} keskustelusivuja lukuun ottamatta.',
@@ -2552,7 +2549,7 @@
 'version-software-product'         => 'Tuote',
 'version-software-version'         => 'Versio',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Tiedoston osoite',
 'filepath-page'    => 'Tiedosto',
 'filepath-submit'  => 'Selvitä osoite',
@@ -2588,7 +2585,7 @@
 'specialpages-group-redirects'   => 'Ohjaavat toimintosivut',
 'specialpages-group-spam'        => 'Mainostenpoistotyökalut',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Tyhjä sivu',
 'intentionallyblankpage' => 'Tämä sivu on tarkoituksellisesti tyhjä.',
 
Index: languages/messages/MessagesUz.php
===================================================================
--- languages/messages/MessagesUz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesUz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Abdulla
- * @author Siebrand
  * @author Behzod Saidov <behzodsaidov@gmail.com>
  */
 
@@ -286,7 +285,7 @@
 'template-protected'     => '(himoyalangan)',
 'template-semiprotected' => '(yarim-himoyalangan)',
 'nocreatetext'           => 'Ushbu sayt yangi sahifa yaratishni taqiqlagan.
-Ortga qaytib, mavjud sahifani tahrirlashingiz yoki [[Special:Userlogin|tizimga kirishingiz]] mumkin.',
+Ortga qaytib, mavjud sahifani tahrirlashingiz yoki [[Special:UserLogin|tizimga kirishingiz]] mumkin.',
 'recreate-deleted-warn'  => "'''Diqqat: Siz avval yoʻqotilgan sahifani yana yaratmoqchisiz.'''
 
 Bu sahifani yaratishda davom etishdan avval uning nega avval yoʻqotilgani bilan qiziqib koʻring.
@@ -373,7 +372,7 @@
 'uploadlogpage' => 'Yuklash qaydlari',
 'uploadedimage' => '"[[$1]]" yuklandi',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Fayllar roʻyxati',
 
 # Image description page
@@ -411,7 +410,7 @@
 Bu bir sahifaga '''\$5''' tahrir va '''\$6''' koʻrish mos kelishini bildiradi.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Navbatdagi vazifalar] soni - '''\$7'''.",
-'userstatstext' => "Hozirda {{PLURAL:$1|'''1''' [[Special:Listusers|foydalanuvchi]]|'''$1''' [[Special:Listusers|foydalanuvchi]]}} roʻyxatdan oʻtgan, ulardan '''$2''' nafari (yoki '''$4%''') $5 huquqlariga egadir.",
+'userstatstext' => "Hozirda {{PLURAL:$1|'''1''' [[Special:ListUsers|foydalanuvchi]]|'''$1''' [[Special:ListUsers|foydalanuvchi]]}} roʻyxatdan oʻtgan, ulardan '''$2''' nafari (yoki '''$4%''') $5 huquqlariga egadir.",
 
 'disambiguationspage' => '{{ns:template}}:Disambig',
 
@@ -437,7 +436,7 @@
 'all-logs-page'     => 'Barcha qaydlar',
 'log-search-submit' => "O'tish",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Barcha sahifalar',
 'alphaindexline' => '$1 dan $2 ga',
 'nextpage'       => 'Keyingi sahifa ($1)',
@@ -461,7 +460,7 @@
 'watchlistfor'         => "('''$1''' uchun)",
 'nowatchlist'          => "Kuzatuv ro'yxatingizda hech narsa yo'q.",
 'addedwatch'           => "Kuzatuv ro'yxatiga qo'shildi",
-'addedwatchtext'       => "\"[[:\$1]]\" sahifasi sizning [[Special:Watchlist|kuzatuv ro'yxatingizga]] qo'shildi. Bu sahifada va unga mos munozara sahifasida bo'ladigan kelajakdagi o'zgarishlar bu yerda ro'yxatga olinadi, hamda bu sahifa topish qulay bo'lishi uchun [[Special:Recentchanges|yangi o'zgarishlar ro'yxati]]da '''qalin''' harflar bilan ko'rsatiladi.
+'addedwatchtext'       => "\"[[:\$1]]\" sahifasi sizning [[Special:Watchlist|kuzatuv ro'yxatingizga]] qo'shildi. Bu sahifada va unga mos munozara sahifasida bo'ladigan kelajakdagi o'zgarishlar bu yerda ro'yxatga olinadi, hamda bu sahifa topish qulay bo'lishi uchun [[Special:RecentChanges|yangi o'zgarishlar ro'yxati]]da '''qalin''' harflar bilan ko'rsatiladi.
 
 Agar siz bu sahifani kuzatuv ro'yxatingizdan o'chirmoqchi bo'lsangiz \"Kuzatmaslik\" yozuvini bosing.",
 'removedwatch'         => "Kuzatuv ro'yxatidan o'chirildi",
@@ -608,7 +607,7 @@
 'show-big-image'       => 'Asl hajmdagi tasvir',
 'show-big-image-thumb' => '<small>Ushbu koʻrinish oʻlchamlari: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Qidirish',
 
 # Metadata
@@ -617,7 +616,7 @@
 
 # External editor support
 'edit-externally'      => 'Bu faylni tashqi dasturiy ilovalar yordamida tahrirla',
-'edit-externally-help' => "Batafsil ma'lumotlar uchun [http://meta.wikimedia.org/wiki/Help:External_editors bu yerga] qarang.",
+'edit-externally-help' => "Batafsil ma'lumotlar uchun [http://www.mediawiki.org/wiki/Manual:External_editors bu yerga] qarang.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'Barchasi',
Index: languages/messages/MessagesBn.php
===================================================================
--- languages/messages/MessagesBn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Bellayet
  * @author Zaheen
- * @author Bellayet
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -68,8 +65,8 @@
 'tog-enotifrevealaddr'        => 'বিজ্ঞপ্তি মেইলে আমার ই-মেইল ঠিকানা প্রকাশ করা হোক',
 'tog-shownumberswatching'     => 'নজরদারী করছে, এমন ব্যবহারকারীর সংখ্যা দেখানো হোক',
 'tog-fancysig'                => 'আপনার স্বাক্ষরে স্বয়ংক্রিয়ভাবে সংযোগ দিতে না চাইলে টিক দিন',
-'tog-externaleditor'          => 'শুরুতেই বহিঃস্থ সম্পাদনা সরঞ্জাম ব্যবহার করা হোক',
-'tog-externaldiff'            => 'শুরুতেই বহিঃস্থ পার্থক্য ব্যবহার করা হোক',
+'tog-externaleditor'          => 'প্রাথমিক পছন্দ হিসেবে বহিঃস্থ সম্পাদক ব্যবহার করা হোক (কেবল দক্ষ ব্যবহারকারীদের জন্য, আপনার কম্পিউটারে বিশেষ সেটিংস প্রয়োজন)',
+'tog-externaldiff'            => 'প্রাথমিক পছন্দ হিসেবে বহিঃস্থ পার্থক্য ব্যবহার করা হোক (কেবল দক্ষ ব্যবহারকারীদের জন্য, আপনার কম্পিউটারে বিশেষ সেটিংস প্রয়োজন)',
 'tog-showjumplinks'           => '"ঝাঁপ দিন" বৈশিষ্ট্যের সংযোগ চালু করা হোক',
 'tog-uselivepreview'          => 'তাৎক্ষণিক প্রাকদর্শনের ক্ষমতা চালু করা হোক (জাভাস্ক্রিপ্ট) (পরীক্ষামূলক)',
 'tog-forceeditsummary'        => 'খালি সম্পাদনা সারাংশ প্রবেশ করানোর সময় আমাকে জানানো হোক',
@@ -310,7 +307,7 @@
 'nosuchspecialpage' => 'এমন কোন বিশেষ পাতা নেই',
 'nospecialpagetext' => "<big>'''আপনি একটি অবৈধ বিশেষ পাতা অনুরোধ করেছেন।'''</big>
 
-[[Special:Specialpages|{{int:specialpages}}]]-এ বৈধ বিশেষ পাতাগুলির একটি তালিকা পাবেন।",
+[[Special:SpecialPages|{{int:specialpages}}]]-এ বৈধ বিশেষ পাতাগুলির একটি তালিকা পাবেন।",
 
 # General errors
 'error'                => 'ত্রুটি',
@@ -537,10 +534,6 @@
 'blockededitsource'         => "'''$1''' এ '''আপনার সম্পাদনা''' করা লেখাগুলো নিচে দেখানো হল:",
 'whitelistedittitle'        => 'সম্পাদনা করতে লগ্‌-ইন করতে হবে',
 'whitelistedittext'         => 'পাতায় সম্পাদনা করতে আপশ্যই $1 করতে হবে।',
-'whitelistreadtitle'        => 'পড়ার জন্য লগ্‌-ইন করতে হবে',
-'whitelistreadtext'         => 'পাতাসমূহ পড়তে আপনাকে অবশই [[Special:Userlogin|লগ্‌-ইন]] করতে হবে।',
-'whitelistacctitle'         => 'আপনার অ্যাকাউন্ট তৈরি করার অনুমতি নাই',
-'whitelistacctext'          => '{{SITENAME}}-এ অ্যাকাউন্ট সৃষ্টি করতে চাইলে আপনাকে [[Special:Userlogin|লগ ইন]] করতে হবে এবং যথাযথ অনুমতি থাকতে হবে।',
 'confirmedittitle'          => 'সম্পাদনা করার জন্য ই-মেইল নিশ্চিতকরণ প্রয়োজন',
 'confirmedittext'           => 'কোন সম্পাদনা করার আগে আপনার ই-মেইল ঠিকানাটি অবশ্যই নিশ্চিত করতে হবে। দয়া করে আপনার ই-মেইল ঠিকানাটি [[Special:Preferences|ব্যবহারকারীর পছন্দতালিকায়]] ঠিকমত দিন।',
 'nosuchsectiontitle'        => 'এমন কোন অনুচ্ছেদ নাই',
@@ -552,10 +545,14 @@
 'accmailtext'               => '"$1"-এর শব্দচাবি(password) $2-এর কাছে পাঠানো হয়েছে৷',
 'newarticle'                => '(নতুন)',
 'newarticletext'            => 'এই নিবন্ধটি এখনো {{SITENAME}} এ সংযুক্ত হয়নি। আপনি চাইলে নীচের বক্সে বিষয়টি নিয়ে কিছু লিখে ও রক্ষা করে এই নিবন্ধটি শুরু করতে পারেন । যদি ভুলবশত এখানে এসে থাকেন তাহলে ব্রাউজারের ব্যাক বোতামে ক্লিক করে আগের পাতায় ফিরে যান।',
-'anontalkpagetext'          => "----''এটি একটি বেনামী ব্যবহারকারীর আলোচনা পাতা, যিনি এখনও কোন অ্যাকাউন্ট সৃষ্টি করেননি কিংবা তাঁর অ্যাকাউন্ট ব্যবহার করছেন না। আমরা তাই সাংখ্যিক আইপি ঠিকানা ব্যবহার করে তাঁকে শনাক্ত করছি। এরকম একটি আইপি ঠিকানা একাধিক ব্যবহারকারী অংশীদারী করতে পারেন। আপনি যদি একজন বেনামী ব্যবহারকারী হন, এবং যদি অনুভব করেন যে আপনার প্রতি অপ্রাসঙ্গিক মন্তব্য করা হয়েছে, অনুগ্রহ করে [[Special:Userlogin|একটি অ্যাকাউন্ট সৃষ্টি করুন বা অ্যাকাউন্টে প্রবেশ করুন]] যাতে অন্যান্য বেনামী ব্যবহারকারীদের সাথে ভবিষ্যত ভুল বোঝাবুঝি না হয়।''",
+'anontalkpagetext'          => "----''এটি একটি বেনামী ব্যবহারকারীর আলোচনা পাতা, যিনি এখনও কোন অ্যাকাউন্ট সৃষ্টি করেননি কিংবা তাঁর অ্যাকাউন্ট ব্যবহার করছেন না। আমরা তাই সাংখ্যিক আইপি ঠিকানা ব্যবহার করে তাঁকে শনাক্ত করছি। এরকম একটি আইপি ঠিকানা একাধিক ব্যবহারকারী অংশীদারী করতে পারেন। আপনি যদি একজন বেনামী ব্যবহারকারী হন, এবং যদি অনুভব করেন যে আপনার প্রতি অপ্রাসঙ্গিক মন্তব্য করা হয়েছে, অনুগ্রহ করে [[Special:UserLogin|একটি অ্যাকাউন্ট সৃষ্টি করুন বা অ্যাকাউন্টে প্রবেশ করুন]] যাতে অন্যান্য বেনামী ব্যবহারকারীদের সাথে ভবিষ্যত ভুল বোঝাবুঝি না হয়।''",
 'noarticletext'             => 'বর্তমানে এই পাতায় কোন টেক্সট নেই। আপনি চাইলে অন্যান্য পাতায় [[Special:Search/{{PAGENAME}}|এই শিরোনামটি অনুসন্ধান করতে পারেন]] কিংবা [{{fullurl:{{FULLPAGENAME}}|action=edit}} এই পাতাটি সম্পাদনা করতে পারেন]।',
 'userpage-userdoesnotexist' => '"$1" নামের কোন ব্যবহারকারী অ্যাকাউন্ট নিবন্ধিত হয়নি। অনুগ্রহ করে পরীক্ষা করে দেখুন আপনি এই পাতাটি সৃষ্টি/সম্পাদনা করতে চান কি না।',
-'clearyourcache'            => "'''লক্ষ্য করুন:''' আপনার পছন্দগুলো রক্ষা করার পর পরিবর্তনগুলো দেখার জন্য আপনাকে ব্রাউজারের ক্যাশ এড়াতে হতে পারে। '''মোজিলা/ফায়ারফক্স/সাফারি:''' শিফট কী চেপে ধরে রিলোড-এ ক্লিক করুন, কিংবা ''কন্ট্রোল-শিফট-R''(এপল ম্যাক-এ ''কমান্ড-শিফট-R'') একসাথে চাপুন; '''ইন্টারনেট এক্সপ্লোরার:''' ''কন্ট্রোল'' চেপে ধরে রিফ্রেশ-এ ক্লিক করুন, কিংবা ''কন্ট্রোল-F5'' চাপুন; '''কংকারার:''' কেবল রিলোড ক্লিক করলেই বা F5 চাপলেই চলবে; '''অপেরা''' ব্যবহারকারীদেরকে ''Tools→Preferences''-এ গিয়ে কাশ সম্পূর্ণ পরিষ্কার করে নিতে হতে পারে।",
+'clearyourcache'            => "'''লক্ষ্য করুন:আপনার পছন্দগুলো রক্ষা করার পর পরিবর্তনগুলো দেখার জন্য আপনাকে ব্রাউজারের ক্যাশ এড়াতে হতে পারে।''' 
+'''মোজিলা/ফায়ারফক্স/সাফারি:''' ''শিফট'' কী চেপে ধরে ''রিলোড''-এ ক্লিক করুন, কিংবা হয় ''কন্ট্রোল-F5'' অথবা ''কন্ট্রোল-R''(অ্যাপল ম্যাক-এ ''কমান্ড-R'') একসাথে চাপুন; 
+'''কংকারার:''' কেবল ''রিলোড'' ক্লিক করলেই বা ''F5'' চাপলেই চলবে; 
+'''অপেরা:''' ''Tools→Preferences''-এ গিয়ে ক্যাশ পরিষ্কার করে নিন;
+'''ইন্টারনেট এক্সপ্লোরার:''' ''কন্ট্রোল'' চেপে ধরে ''রিফ্রেশ''-এ ক্লিক করুন, কিংবা ''কন্ট্রোল-F5'' চাপুন।",
 'usercssjsyoucanpreview'    => '<strong>অণুসহায়িকা:</strong> "প্রাকদর্শন" বোতাম ব্যবহার করে আপনার নতুন সিএসএস/জাভাস্ক্রিপ্ট সংরক্ষণের আগে পরীক্ষা করে দেখুন।',
 'usercsspreview'            => "'''মনে রাখবেন আপনি আপনার ব্যবহারকারী সিএসএস শুধুই প্রাকদর্শন করছেন। এটা এখনও সংরক্ষণ করা হয়নি!'''",
 'userjspreview'             => "'''মনে রাখুন আপনি আপনার ব্যবহারকারী জাভাস্ক্রিপ্ট কেবলমাত্র পরীক্ষা/প্রাকদর্শন করছেন। এটা এখনও সংরক্ষণ করা হয়নি!'''",
@@ -605,7 +602,7 @@
 'template-semiprotected'    => '(অর্ধ-সুরক্ষিত)',
 'nocreatetitle'             => 'পাতা তৈরি নিয়ন্ত্রণ করা হয়েছে',
 'nocreatetext'              => '{{SITENAME}}-এ নতুন পাতা সৃষ্টি করার ক্ষমতা সীমাবদ্ধ করা হয়েছে।
-আপনি ফিরে গিয়ে ইতিমধ্যে বিদ্যমান কোন পাতা সম্পাদনা করতে পারেন, অথবা [[Special:Userlogin|অ্যাকাউন্টে প্রবেশ কিংবা অ্যাকাউন্ট সৃষ্টি করতে পারেন]]।',
+আপনি ফিরে গিয়ে ইতিমধ্যে বিদ্যমান কোন পাতা সম্পাদনা করতে পারেন, অথবা [[Special:UserLogin|অ্যাকাউন্টে প্রবেশ কিংবা অ্যাকাউন্ট সৃষ্টি করতে পারেন]]।',
 'nocreate-loggedin'         => 'আপনার এই উইকিতে নতুন পাতা তৈরির অনুমতি নাই।',
 'permissionserrors'         => 'অনুমতি ত্রুটিসমূহ',
 'permissionserrorstext'     => 'আপনার এটা করার অনুমতি নেই, নিচের {{PLURAL:$1|টি কারণের|টি কারণের}} জন্য:',
@@ -753,7 +750,7 @@
 'mypreferences'            => 'আমার পছন্দ',
 'prefs-edits'              => 'সম্পাদনার সংখ্যা:',
 'prefsnologin'             => 'আপনি লগ-ইন করেননি',
-'prefsnologintext'         => 'ব্যবহারকারীর পছন্দ ঠিক করতে আপনাকে অবশ্যই [[Special:Userlogin|লগ্‌-ইন]] থাকতে হবে।',
+'prefsnologintext'         => 'ব্যবহারকারীর পছন্দ ঠিক করতে আপনাকে অবশ্যই [[Special:UserLogin|লগ্‌-ইন]] থাকতে হবে।',
 'prefsreset'               => 'স্টোরেজ থেকে পছন্দগুলি আদি অবস্থায় ফেরত নেওয়া হয়েছে।',
 'qbsettings'               => 'কুইকবার',
 'qbsettings-none'          => 'কিছুই না',
@@ -821,7 +818,7 @@
 'userrights-reason'        => 'পরিবর্তনের কারণ:',
 'userrights-no-interwiki'  => 'আপনার অন্য উইকিতে ব্যবহারকারী অধিকার সম্পাদনা করার অনুমতি নেই।',
 'userrights-nodatabase'    => '$1 ডাটাবেজটির হয় কোন অস্তিত্ব নেই অথবা এটি স্থানীয় ডাটাবেজ নয়।',
-'userrights-nologin'       => 'ব্যবহারকারী অধিকার প্রযুক্ত করতে হলে আপনাকে কোন প্রশাসকের অ্যাকাউন্টে [[Special:Userlogin|প্রবেশ]] করতে হবে।',
+'userrights-nologin'       => 'ব্যবহারকারী অধিকার প্রযুক্ত করতে হলে আপনাকে কোন প্রশাসকের অ্যাকাউন্টে [[Special:UserLogin|প্রবেশ]] করতে হবে।',
 'userrights-notallowed'    => 'আপনার অ্যাকাউন্ট থেকে ব্যবহারকারী অধিকার প্রযুক্ত করার অনুমতি নেই।',
 
 # Groups
@@ -889,10 +886,10 @@
 'reupload'                    => 'পুনরায় আপলোড করা হোক',
 'reuploaddesc'                => 'আপলোড ফর্মে ফেরত যান।',
 'uploadnologin'               => 'আপনি লগ-ইন করেননি।',
-'uploadnologintext'           => 'আপলোড করতে হলে আপনাকে অবশ্যই আগে [[Special:Userlogin|লগ-ইন]] করতে হবে।',
+'uploadnologintext'           => 'আপলোড করতে হলে আপনাকে অবশ্যই আগে [[Special:UserLogin|লগ-ইন]] করতে হবে।',
 'upload_directory_read_only'  => 'আপলোড ডিরেক্টরিটি ($1) ওয়েবসার্ভার কর্তৃক লিখনযোগ্য নয়।',
 'uploaderror'                 => 'আপলোড এ সমস্যা হয়েছে',
-'uploadtext'                  => "ফাইল আপলোড করতে নিচের ফরমটি ব্যবহার করুন। পূর্বে আপলোড করা ফাইল দেখতে বা খুঁজতে হলে [[Special:Imagelist|পূর্বে আপলোড করা ফাইল এর তালিকা]] দেখুন। আপলোড করা ফাইল এর নাম  [[Special:Log/upload|আপলোডের ইতিহাস তালিকায়]] যোগ হয়ে থাকে।
+'uploadtext'                  => "ফাইল আপলোড করতে নিচের ফরমটি ব্যবহার করুন। পূর্বে আপলোড করা ফাইল দেখতে বা খুঁজতে হলে [[Special:ImageList|পূর্বে আপলোড করা ফাইল এর তালিকা]] দেখুন। আপলোড করা ফাইল এর নাম  [[Special:Log/upload|আপলোডের ইতিহাস তালিকায়]] যোগ হয়ে থাকে।
 
 কোনো নিবন্ধে ছবি যোগ করতে হলে নিচের উদাহরণ অনুযায়ী সংযোগ দিনঃ
 '''<nowiki>[[{{ns:image}}:file.jpg]]</nowiki>''',
@@ -973,7 +970,7 @@
 'upload_source_url'  => ' (একটি বৈধ, উন্মুক্ত URL)',
 'upload_source_file' => ' (আপনার কম্পিউটারের একটি ফাইল)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'ছবির নাম অনুসন্ধান:',
 'imgfile'               => 'ফাইল',
 'imagelist'             => 'ছবির তালিকা',
@@ -1008,18 +1005,18 @@
 # File reversion
 'filerevert'                => '$1 পূর্বাবস্থায় ফেরত নিন',
 'filerevert-legend'         => 'ফাইল পূর্বাবস্থায় ফেরত নিন',
-'filerevert-intro'          => '<span class="plainlinks">আপনি \'\'\'[[Media:$1|$1]]\'\'\' ফাইলটিকে [$3, $2 সময়ের $4 সংস্করণে] ফিরিয়ে নিচ্ছেন।</span>',
+'filerevert-intro'          => "আপনি '''[[Media:$1|$1]]''' ফাইলটিকে [$3, $2 সময়ের $4 সংস্করণে] ফিরিয়ে নিচ্ছেন।",
 'filerevert-comment'        => 'মন্তব্য:',
 'filerevert-defaultcomment' => '$2, $1 সংস্করণে ফেরত যাওয়া হল',
 'filerevert-submit'         => 'ফেরত যাওয়া হোক',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ফাইলটি  [$3, $2-এর $4 সংস্করণে] ফেরত নেওয়া হয়েছে।</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ফাইলটি  [$3, $2-এর $4 সংস্করণে] ফেরত নেওয়া হয়েছে।",
 'filerevert-badversion'     => 'প্রদত্ত তারিখ ও সময়ের জন্য এই ফাইলটির কোন স্থানীয় সংস্করণ নেই।',
 
 # File deletion
 'filedelete'             => '$1 মুছে ফেলা হোক',
 'filedelete-legend'      => 'ফাইল মুছে ফেলা হোক',
 'filedelete-intro'       => "আপনি '''[[Media:$1|$1]]''' ফাইলটি মুছে ফেলছেন।",
-'filedelete-intro-old'   => '<span class="plainlinks">আপনি \'\'\'[[Media:$1|$1]]\'\'\' ফাইলটির [$4 $3, $2] সংস্করণটি মুছে ফেলছেন।</span>',
+'filedelete-intro-old'   => "আপনি '''[[Media:$1|$1]]''' ফাইলটির [$4 $3, $2] সংস্করণটি মুছে ফেলছেন।",
 'filedelete-comment'     => 'মন্তব্য:',
 'filedelete-submit'      => 'মুছে ফেলা হোক',
 'filedelete-success'     => "'''$1''' মুছে ফেলা হয়েছে।",
@@ -1148,7 +1145,7 @@
 'logempty'             => 'মিলে যায় এমন কিছু লগে পাওয়া যায়নি।',
 'log-title-wildcard'   => 'এই টেক্সট দিয়ে শুরু হওয়া শিরোনামগুলি অনুসন্ধান করা হোক',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'সব পাতা',
 'alphaindexline'    => '$1 হতে $2',
 'nextpage'          => 'পরবর্তী পাতা ($1)',
@@ -1168,14 +1165,14 @@
 'categories'         => 'বিষয়শ্রেণীসমূহ',
 'categoriespagetext' => 'এ উইকিতে বর্তমান বিষয়শ্রেণীসমূহ:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'সেই সব ব্যবহারকারী দেখাও যাদের নাম এই অক্ষর দিয়ে শুরু:',
 'listusers-submit'   => 'দেখানো হোক',
 'listusers-noresult' => 'কোন ব্যবহারকারী খুঁজে পাওয়া যায়নি।',
 
 # E-mail user
 'mailnologin'     => 'প্রাপকের ঠিকানা নেই',
-'mailnologintext' => "অন্য ব্যবহারকারীদেরকে ই-মেইল পাঠাতে হলে আপনাকে অবশ্যই আগে [[Special:Userlogin|লগ-ইন]] করতে হবে এবং ''[[Special:Preferences|আপনার পছন্দ তালিকায়]] আপনার ই-মেইল ঠিকানাটি ঠিকমত দিতে হবে।",
+'mailnologintext' => "অন্য ব্যবহারকারীদেরকে ই-মেইল পাঠাতে হলে আপনাকে অবশ্যই আগে [[Special:UserLogin|লগ-ইন]] করতে হবে এবং ''[[Special:Preferences|আপনার পছন্দ তালিকায়]] আপনার ই-মেইল ঠিকানাটি ঠিকমত দিতে হবে।",
 'emailuser'       => 'ইমেইল করো',
 'emailpage'       => 'ব্যবহারকারীকে ই-মেইল করুন',
 'emailpagetext'   => 'যদি এই ব্যবহারকারীটি তার ব্যবহারকারী পছন্দগুলিতে কোন বৈধ ই-মেইল ঠিকানা প্রবেশ করিয়ে থাকেন, তাহলে নিচের ফর্মটি একটি মাত্র বার্তা পাঠাবে।
@@ -1201,12 +1198,12 @@
 'nowatchlist'          => 'আপনার নজরতালিকা খালি।',
 'watchlistanontext'    => 'আপনার নজরতালিকার আইটেমগুলি দেখতে বা সম্পাদনা করতে অনুগ্রহ করে $1।',
 'watchnologin'         => 'আপনি এখনও লগ-ইন করেননি।',
-'watchnologintext'     => 'আপনার নজর তালিকা পরিবর্তনের জন্য আপনাকে অবশ্যই অ্যাকাউন্টে [[Special:Userlogin|প্রবেশ করতে হবে]]।',
+'watchnologintext'     => 'আপনার নজর তালিকা পরিবর্তনের জন্য আপনাকে অবশ্যই অ্যাকাউন্টে [[Special:UserLogin|প্রবেশ করতে হবে]]।',
 'addedwatch'           => 'নজর তালিকায় যুক্ত হয়েছে',
 'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" পাতাটি আপনার [[Special:Watchlist|নজরতালিকা]]-তে যোগ করা হয়েছে৷
 
 ভবিষ্যতে এই পাতা ও এই পাতার সাথে সম্পর্কিত আলোচনা পাতায় সংঘটিত যাবতীয় পরিবর্তন এখানে তালিকাভুক্ত হবে৷
-এছাড়া [[Special:Recentchanges|সাম্প্রতিক পরিবর্তনসমূহ]]তালিকায় এই পাতাটিকে '''গাঢ়''' অক্ষরে দেখানো হবে যাতে আপনি সহজেই পাতাটি শনাক্ত করতে পারেন৷
+এছাড়া [[Special:RecentChanges|সাম্প্রতিক পরিবর্তনসমূহ]]তালিকায় এই পাতাটিকে '''গাঢ়''' অক্ষরে দেখানো হবে যাতে আপনি সহজেই পাতাটি শনাক্ত করতে পারেন৷
 
 পরবর্তীতে আপনি যদি পাতাটিকে আপনার নজরতালিকা থেকে সরিয়ে ফেলতে চান, তবে \"নজর সরিয়ে নিন\" ট্যাবটিতে ক্লিক করবেন৷",
 'removedwatch'         => 'নজর তালিকা থেকে সরিয়ে ফেলা হয়েছে',
@@ -1311,7 +1308,7 @@
 সেশন হাইজ্যাক প্রতিরোধের উপায় হিসেবে এই কাজটি বাতিল করা হয়েছে।
 অনুগ্রহ ব্রাউজারের "back" বোতাম চাপুন এবং যে পাতা থেকে এসেছিলেন, তা রিলোড করুন এবং আবার চেষ্টা করুন।',
 'protectlogpage'              => 'সুরক্ষা লগ্‌',
-'protectlogtext'              => 'নিচে পাতা বন্ধ ও খোলার একটি তালিকা দেয়া হল। বর্তমানে সক্রিয় পাতার সুরক্ষাগুলির তালিকা দেখতে [[Special:Protectedpages|সুরক্ষিত পাতার তালিকা]] দেখুন।',
+'protectlogtext'              => 'নিচে পাতা বন্ধ ও খোলার একটি তালিকা দেয়া হল। বর্তমানে সক্রিয় পাতার সুরক্ষাগুলির তালিকা দেখতে [[Special:ProtectedPages|সুরক্ষিত পাতার তালিকা]] দেখুন।',
 'protectedarticle'            => 'সুরক্ষিত "[[$1]]"',
 'modifiedarticleprotection'   => '"[[$1]]"-এর জন্য সুরক্ষার স্তর পরিবর্তন করা হয়েছে',
 'unprotectedarticle'          => '"[[$1]]"-এর সুরক্ষা সরিয়ে নেওয়া হয়েছে',
@@ -1459,7 +1456,7 @@
 'badipaddress'                => 'আইপি (IP) ঠিকানাটি অগ্রহনযোগ্য',
 'blockipsuccesssub'           => 'বাধা সফল',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] কে বাধা দেয়া হয়েছে
-<br />বাধা দেয়া পুনর্বিবেচনা করতে হলে [[Special:Ipblocklist|বাধা দেয়া আইপি ঠিকানার তালিকা]] দেখুন।',
+<br />বাধা দেয়া পুনর্বিবেচনা করতে হলে [[Special:IPBlockList|বাধা দেয়া আইপি ঠিকানার তালিকা]] দেখুন।',
 'ipb-edit-dropdown'           => 'বাধাদানের কারণ সম্পাদনা করুন',
 'ipb-unblock-addr'            => '$1-এর উপর থেকে বাধা তুলে নেওয়া হোক',
 'ipb-unblock'                 => 'ব্যবহারকারী বা আইপি ঠিকানার উপর থেকে বাধা তুলে নেওয়া হোক',
@@ -1489,7 +1486,7 @@
 'autoblocker'                 => 'আপনাকে স্বয়ংক্রিয়ভাবে বাধা দেওয়া হয়েছে, কারণ আপনার আইপি ঠিকানাটি সম্প্রতি "[[User:$1|$1]]" ব্যবহার করেছেন।   $1-কে বাধাদানের কারণ: "$2"',
 'blocklogpage'                => 'বাধা দানের লগ্‌',
 'blocklogentry'               => '[[$1]]এর উপর $2 $3 মেয়াদের জন্য নিষেধাজ্ঞা আরোপিত হয়েছে।',
-'blocklogtext'                => 'এটি ব্যবহারকারীদেরকে বাধা দানের বা বাধা তুলে নেওয়ার লগ। স্বয়ংক্রিয়ভাবে বাধাদানকৃত আইপি ঠিকানাগুলি এখানে তালিকাবদ্ধ করা হয়নি। বর্তমানে সক্রিয় নিষিদ্ধকরণ ও বাধাদানের তালিকার জন্য [[Special:Ipblocklist|আইপি বাধাদান তালিকা]] দেখুন।',
+'blocklogtext'                => 'এটি ব্যবহারকারীদেরকে বাধা দানের বা বাধা তুলে নেওয়ার লগ। স্বয়ংক্রিয়ভাবে বাধাদানকৃত আইপি ঠিকানাগুলি এখানে তালিকাবদ্ধ করা হয়নি। বর্তমানে সক্রিয় নিষিদ্ধকরণ ও বাধাদানের তালিকার জন্য [[Special:IPBlockList|আইপি বাধাদান তালিকা]] দেখুন।',
 'unblocklogentry'             => '$1-এর উপর বাধা তুলে নেয়া হয়েছে',
 'block-log-flags-anononly'    => 'কেবল বেনামী ব্যবহারকারীরা',
 'block-log-flags-nocreate'    => 'অ্যাকাউন্ট সৃষ্টি নিষ্ক্রিয় করা হয়েছে',
@@ -1524,7 +1521,7 @@
 'lockdbsuccesssub'    => 'ডাটাবেজ সফলভাবে বন্ধ করে দেওয়া হয়েছে',
 'unlockdbsuccesssub'  => 'ডাটাবেজ খুলে দেওয়া হয়েছে',
 'lockdbsuccesstext'   => 'ডাটাবেজ বন্ধ করা হয়েছে
-<br />আপনার রক্ষণাবেক্ষণ সম্পন্ন হবার পর [[Special:Unlockdb|ডাটাবেজ খুলে দিতে]] ভুলবেন না।',
+<br />আপনার রক্ষণাবেক্ষণ সম্পন্ন হবার পর [[Special:UnlockDB|ডাটাবেজ খুলে দিতে]] ভুলবেন না।',
 'unlockdbsuccesstext' => 'ডাটাবেজ খুলে দেওয়া হয়েছে।',
 'lockfilenotwritable' => 'ডাটাবেজ বন্ধ করার ফাইলটি লিখনযোগ্য নয়। ডাটাবেজ বন্ধ করতে বা খুলতে চাইলে ফাইলটিকে ওয়েব সার্ভার কর্তৃক লিখনযোগ্য হতে হবে।',
 'databasenotlocked'   => 'ডাটাবেজ বন্ধ নয়।',
@@ -1546,8 +1543,6 @@
 
 এসব ক্ষেত্রে আপনি চাইলে নিজের হাতে পাতাটিকে সরাতে বা একত্রীকরণ করতে পারেন।",
 'movearticle'             => 'যে পাতা সরিয়ে ফেলা হবে',
-'movenologin'             => 'অ্যাকাউন্টে প্রবেশ করা হয়নি',
-'movenologintext'         => 'কোন পাতা সরিয়ে ফেলতে চাইলে আপনাকে অবশ্যই একজন নিবন্ধিত ব্যবহারকারী হতে হবে ও অ্যাকাউন্টে [[Special:Userlogin|প্রবেশ]] করতে হবে।',
 'movenotallowed'          => 'আপনার {{SITENAME}}-তে পাতা সরানোর অনুমতি নেই।',
 'newtitle'                => 'এই নতুন শিরোনামে',
 'move-watch'              => 'এই পাতাটি নজরে রাখুন',
@@ -1567,7 +1562,7 @@
 'delete_and_move'         => 'মুছে ফেলা হোক ও সরানো হোক',
 'delete_and_move_text'    => '==মুছে ফেলা আবশ্যক==
 
-"[[$1]]" শিরোনামের গন্তব্য পাতাটি ইতিমধ্যেই বিদ্যমান। আপনি কি স্থানান্তর সফল করার জন্য পাতাটি মুছে দিতে চান?',
+"[[:$1]]" শিরোনামের গন্তব্য পাতাটি ইতিমধ্যেই বিদ্যমান। আপনি কি স্থানান্তর সফল করার জন্য পাতাটি মুছে দিতে চান?',
 'delete_and_move_confirm' => 'হ্যাঁ, পাতাটি মুছে ফেলা হোক',
 'delete_and_move_reason'  => 'স্থানান্তরের স্বার্থে মুছে ফেলা হয়েছে',
 'selfmove'                => 'উৎস ও গন্তব্য পাতা একই শিরোনামের; কোন পাতা একই শিরোনামের আরেক পাতায় সরানো যাবে না।',
@@ -1785,7 +1780,7 @@
 'show-big-image'       => 'পূর্ণ রেজোলিউশন',
 'show-big-image-thumb' => '<small>আকারের প্রাকদর্শন: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'নতুন ফাইলের গ্যালারি',
 'imagelisttext'         => 'নিচে $1টি ফাইলের একটি তালিকা $2 সাজিয়ে দেখানো হল।',
 'showhidebots'          => '($1 বট)',
@@ -2066,7 +2061,7 @@
 
 # External editor support
 'edit-externally'      => 'ফাইলটি অন্য কোন সফটওয়্যার দিয়ে সম্পাদনা করুন',
-'edit-externally-help' => 'আরও তথ্যের জন্য [http://meta.wikimedia.org/wiki/Help:External_editors সেটআপ নির্দেশমালা] দেখুন।',
+'edit-externally-help' => 'আরও তথ্যের জন্য [http://www.mediawiki.org/wiki/Manual:External_editors সেটআপ নির্দেশমালা] দেখুন।',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'সমস্ত',
@@ -2123,7 +2118,7 @@
 'recreate'            => 'পুনরায় তৈরি করো',
 
 # HTML dump
-'redirectingto' => '[[$1]] পাতায় পুনঃনির্দেশিত হচ্ছে...',
+'redirectingto' => '[[:$1]] পাতায় পুনঃনির্দেশিত হচ্ছে...',
 
 # action=purge
 'confirm_purge'        => 'এই পাতার ক্যাশে পরিষ্কার করতে চান?
@@ -2202,9 +2197,11 @@
 'unknown_extension_tag' => 'অজানা এক্সটেনশন ট্যাগ "$1"',
 
 # Special:Version
-'version' => 'সংস্করণ', # Not used as normal message but as header for the special page itself
+'version'                  => 'সংস্করণ', # Not used as normal message but as header for the special page itself
+'version-software-product' => 'পণ্য',
+'version-software-version' => 'সংস্করণ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'ফাইলের পাথ',
 'filepath-page'   => 'ফাইল:',
 'filepath-submit' => 'পথ',
@@ -2213,6 +2210,25 @@
 'fileduplicatesearch-submit' => 'অনুসন্ধান',
 
 # Special:SpecialPages
-'specialpages' => 'বিশেষ পাতাসমূহ',
+'specialpages'                   => 'বিশেষ পাতাসমূহ',
+'specialpages-note'              => '----
+* সাধারণ বিশেষ পাতাসমূহ।
+* <span class="mw-specialpagerestricted">সীমাবদ্ধ বিশেষ পাতাসমূহ।</span>',
+'specialpages-group-maintenance' => 'রক্ষণাবেক্ষণের কার্যবিবরণীসমূহ',
+'specialpages-group-other'       => 'অন্যান্য বিশেষ পাতাসমূহ',
+'specialpages-group-login'       => 'অ্যাকাউন্টে প্রবেশ',
+'specialpages-group-changes'     => 'সাম্প্রতিক পরিবর্তন ও লগসমূহ',
+'specialpages-group-media'       => 'মিডিয়া বিবরণী ও আপলোডসমূহ',
+'specialpages-group-users'       => 'ব্যবহারকারীবৃন্দ ও অধিকারসমূহ',
+'specialpages-group-highuse'     => 'অধিক ব্যবহৃত পাতাগুলি',
+'specialpages-group-pages'       => 'পাতার তালিকা',
+'specialpages-group-pagetools'   => 'পাতা সংক্রান্ত সরঞ্জাম',
+'specialpages-group-wiki'        => 'উইকি উপাত্ত এবং সরঞ্জামসমূহ',
+'specialpages-group-redirects'   => 'বিশেষ পাতাগুলি পুনর্নির্দেশ করা হচ্ছে',
+'specialpages-group-spam'        => 'স্প্যামরোধী হাতিয়ার',
 
+# Special:BlankPage
+'blankpage'              => 'খালি পাতা',
+'intentionallyblankpage' => 'এই পাতাটি ইচ্ছা করে খালি রাখা হয়েছে',
+
 );
Index: languages/messages/MessagesExt.php
===================================================================
--- languages/messages/MessagesExt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesExt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,6 @@
  * @file
  *
  * @author Better
- * @author Siebrand
- * @author M.M.S.
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -290,7 +286,7 @@
 'nosuchspecialpage' => 'Nu desisti tal páhina especial',
 'nospecialpagetext' => "<big>'''Nu desisti esa páhina especial.'''</big>
 
-Pueis alcuentral una lista colas páhinas especialis desistentis en [[Special:Specialpages]].",
+Pueis alcuentral una lista colas páhinas especialis desistentis en [[Special:SpecialPages]].",
 
 # General errors
 'error'                => 'Marru',
@@ -523,10 +519,6 @@
 'blockededitsource'                => "Embahu se muestra el testu '''las tus eicionis''' en '''$1''':",
 'whitelistedittitle'               => 'Es mestel rustrilsi pa eital',
 'whitelistedittext'                => 'Tiinis que $1 pa eital páhinas.',
-'whitelistreadtitle'               => 'Es mestel rustrilsi pa leyel',
-'whitelistreadtext'                => 'Ebis [[Special:Userlogin|rustrilti]] pa leyel páhinas.',
-'whitelistacctitle'                => 'Nu se te premiti crial denguna cuenta',
-'whitelistacctext'                 => 'Pa que se te premita crial cuentas nesti güiqui, ebis [[Special:Userlogin|rustrilti]] i tenel los premisus correspondientis.',
 'confirmedittitle'                 => 'Es mestel confirmal el tu email pa puel eital',
 'confirmedittext'                  => 'Ebis confirmal la tu direción d´email enantis d´eital páhinas. Pol favol, escrebi i compreba el tu email pol meyu las tus [[Special:Preferences|preferéncias d´usuáriu]].',
 'nosuchsectiontitle'               => 'Nu esa seción',
@@ -541,7 +533,7 @@
 Si quieis crial esti artículu, escribi nel cuairu d'embahu
 (si t'es mestel, mira la [[{{MediaWiki:Helppage}}|páhina d'ayua]]).
 Si nu quieis crial esti artículu, solu tiinis que pursal nel botón \"'''atrás'''\" del tu escrucaol.",
-'anontalkpagetext'                 => "----''Esta es la caraba dun usuáriu anónimu qu'entovia nu á criau una cuenta, u nu la gasta, asínque tenemus que usal la su direción IP pa ientificalu. Una mesma direción IP puei sel gastá pol varius usuárius, polo que si creis que s'án derihiu a tí con cosas que nu vinin a cuentu, pol favol [[Special:Userlogin|cria una cuenta]] pa evital huturus pobremas con otrus usuárius anónimus.''",
+'anontalkpagetext'                 => "----''Esta es la caraba dun usuáriu anónimu qu'entovia nu á criau una cuenta, u nu la gasta, asínque tenemus que usal la su direción IP pa ientificalu. Una mesma direción IP puei sel gastá pol varius usuárius, polo que si creis que s'án derihiu a tí con cosas que nu vinin a cuentu, pol favol [[Special:UserLogin|cria una cuenta]] pa evital huturus pobremas con otrus usuárius anónimus.''",
 'noarticletext'                    => 'Entovia nu ai dengún testu escrebiu nesta páhina, pueis [[Special:Search/{{PAGENAME}}|landeal el entítulu el artículu]] n´otras páhinas u [{{fullurl:{{FULLPAGENAME}}|action=edit}} eital ésta].',
 'userpage-userdoesnotexist'        => 'La cuenta d\'usuáriu "$1" nu está rustria. Pol favol, compreba que rialmenti quieis crial/eital esta páhina.',
 'clearyourcache'                   => "'''Nota:''' Aluspués d'emburacal el archivu, ebi gorvel a cargal la páhina pa vel los chambus. *'''Mozilla:''' Pursa ''ctrl-shift-r'' *'''Internet Explorer:''' Pursa ''ctrl-f5'' *'''Safari:''' Pursa ''cmd-shift-r'' *'''Konqueror:''' Pursa ''f5'' *'''Opera:''' Los usuárius d'Opera nesezitarás esborral totalmenti el caché en ''Herramientas→Preferéncias''.",
@@ -601,7 +593,7 @@
 'edittools'                        => '<!-- Esti testu apaicirá embahu los hormulárius d´eición i empuntu. -->',
 'nocreatetitle'                    => 'Criaeru e páhinas enlimitau',
 'nocreatetext'                     => 'Nu se premiti crial páhinas nuevas a usuárius anónimus.
-Pueis gorvel i eital anguna páhina ya desistenti, u [[Special:Userlogin|rustrilti]].',
+Pueis gorvel i eital anguna páhina ya desistenti, u [[Special:UserLogin|rustrilti]].',
 'nocreate-loggedin'                => 'Nu tienis premisu pa crial nuevas páhinas nesti güiqui.',
 'permissionserrors'                => 'Marrus colos premisus',
 'permissionserrorstext'            => 'Nu t´está premitiu hazel esu, {{PLURAL:$1|pola siguienti razón|polas siguientis razonis}}:',
@@ -702,7 +694,7 @@
 'logdelete-log-message'       => '$1 de $2 {{PLURAL:$2|eventu|eventus}}',
 
 # Suppression log
-'suppressionlogtext' => 'Embahu se muestra una lista colos esborraus i tarugus mas nuevus, encruyendu conteniu açonchau polos çahorilis. Guipai la [[Special:Ipblocklist|lista e tarugus a IP]] pa visoreal una lista colos tarugus ativus atualmenti.',
+'suppressionlogtext' => 'Embahu se muestra una lista colos esborraus i tarugus mas nuevus, encruyendu conteniu açonchau polos çahorilis. Guipai la [[Special:IPBlockList|lista e tarugus a IP]] pa visoreal una lista colos tarugus ativus atualmenti.',
 
 # History merging
 'mergehistory'                     => 'Uñifical el estorial las páhinas',
@@ -780,7 +772,7 @@
 'mypreferences'            => 'Las mis preferéncias',
 'prefs-edits'              => "Númiru d'eicionis:",
 'prefsnologin'             => "Nu t'alcuentras rustriu",
-'prefsnologintext'         => 'Ebis estal [[Special:Userlogin|rustriu]] pa chambal las tus preferéncias.',
+'prefsnologintext'         => 'Ebis estal [[Special:UserLogin|rustriu]] pa chambal las tus preferéncias.',
 'prefsreset'               => "S'an restaurau las preferéncias a los valoris pol defetu.",
 'qbsettings'               => 'Preferéncias la "Quickbar"',
 'qbsettings-none'          => 'Dengunu',
@@ -852,7 +844,7 @@
 'userrights-reason'           => 'Razón el chambu:',
 'userrights-no-interwiki'     => 'Nu tienis premisu pa eital los derechus los usuárius en otras güiquis.',
 'userrights-nodatabase'       => 'La basi e datus $1 nu desisti, u nu es local.',
-'userrights-nologin'          => "Ebis [[Special:Userlogin|rustrilti]] con una cuenta d'alministraol pa puel asinal derechus a los usuárius.",
+'userrights-nologin'          => "Ebis [[Special:UserLogin|rustrilti]] con una cuenta d'alministraol pa puel asinal derechus a los usuárius.",
 'userrights-notallowed'       => "Nu tienis los permisus nesezárius p'asinal derechus a los usuárius.",
 'userrights-changeable-col'   => 'Grupus que pueis chambal',
 'userrights-unchangeable-col' => 'Grupus que nu pueis chambal',
@@ -943,11 +935,11 @@
 'reupload'                    => 'Re-empuntal',
 'reuploaddesc'                => 'Cancelal el empuntu i gorvel al hormuláriu.',
 'uploadnologin'               => 'Nu estás rustriu',
-'uploadnologintext'           => 'Ebis estal [[Special:Userlogin|rustriu]]
+'uploadnologintext'           => 'Ebis estal [[Special:UserLogin|rustriu]]
 pa empuntal archivus.',
 'upload_directory_read_only'  => "Nu puei escrebilsi nel diretoriu d'empuntu ($1) el sirviol.",
 'uploaderror'                 => 'Marru d´empuntu',
-'uploadtext'                  => "Gasta el hormuláriu d'embahu pa empuntal archivus, pa vel u landeal imahin ya empuntás vaiti pala [[Special:Imagelist|lista d'archivus empuntaus]]. Tantu los archivus empuntaus cumu los esborraus se rustrin nel [[Special:Log/upload|rustrihu d'empuntu]].
+'uploadtext'                  => "Gasta el hormuláriu d'embahu pa empuntal archivus, pa vel u landeal imahin ya empuntás vaiti pala [[Special:ImageList|lista d'archivus empuntaus]]. Tantu los archivus empuntaus cumu los esborraus se rustrin nel [[Special:Log/upload|rustrihu d'empuntu]].
 
 P'añiil la imahin nuna páhina, gasta el atihu el hormuláriu
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1030,7 +1022,7 @@
 'upload_source_url'  => ' (una URL vália i acesibri)',
 'upload_source_file' => ' (un archivu nel tu ordinaol)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Esta páhina especial muestra tolos archivus empuntaus.
 Pol defetu los úrtimus archivus empuntaus se muestran ena parti arta la lista.
 Pursa nel entítulu la coluna pa chambal el ordin.',
@@ -1069,18 +1061,18 @@
 # File reversion
 'filerevert'                => 'Revertil $1',
 'filerevert-legend'         => 'Revertil archivu',
-'filerevert-intro'          => '<span class="plainlinks">Estás revirtiendu \'\'\'[[Media:$1|$1]]\'\'\' a la [$4 velsión del $3 a las $2].</span>',
+'filerevert-intro'          => "Estás revirtiendu '''[[Media:$1|$1]]''' a la [$4 velsión del $3 a las $2].",
 'filerevert-comment'        => 'Comentáriu:',
 'filerevert-defaultcomment' => 'Revertiu a la velsión de $2, $1',
 'filerevert-submit'         => 'Revertil',
-'filerevert-success'        => '<span class="plainlinks">S\'á revertiu \'\'\'[[Media:$1|$1]]\'\'\' a [$4 velsión de $3, $2].</span>',
+'filerevert-success'        => "S'á revertiu '''[[Media:$1|$1]]''' a [$4 velsión de $3, $2].",
 'filerevert-badversion'     => "Nu desisti denguna velsión local prévia d'esti archivu cola fecha aseñalá.",
 
 # File deletion
 'filedelete'                  => 'Esborral $1',
 'filedelete-legend'           => 'Esborral archivu',
 'filedelete-intro'            => "Estás esborrandu '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Estás esborrandu la velsón de \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $3 a las $2].</span>',
+'filedelete-intro-old'        => "Estás esborrandu la velsón de '''[[Media:$1|$1]]''' del [$4 $3 a las $2].",
 'filedelete-comment'          => 'Comentáriu:',
 'filedelete-submit'           => 'Esborral',
 'filedelete-success'          => "S´á esborrau '''$1'''.",
@@ -1135,7 +1127,7 @@
 Estu resurta un promeyu e '''\$5''' eicionis pol páhina, i '''\$6''' vesitas pol eición.
 
 El longol de la [http://www.mediawiki.org/wiki/Manual:Job_queue cola e tareas] es de '''\$7'''.",
-'userstatstext'          => "Ai {{PLURAL:$1|un [[Special:Listusers|usuáriu]] rustriu|'''$1''' [[Special:Listusers|usuárius]] rustrius}}, de los cualis,
+'userstatstext'          => "Ai {{PLURAL:$1|un [[Special:ListUsers|usuáriu]] rustriu|'''$1''' [[Special:ListUsers|usuárius]] rustrius}}, de los cualis,
 '''$2''' (un '''$4%''') {{PLURAL:$2|es|son}} $5.",
 'statistics-mostpopular' => 'Páhinas mas visoreás',
 
@@ -1222,7 +1214,7 @@
 'logempty'             => 'Nu desistin elementus con esas condicionis nel rustrihu.',
 'log-title-wildcard'   => 'Landeal entítulus qu´esmiencin con esti testu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tolas páhinas',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Siguienti páhina ($1)',
@@ -1243,12 +1235,12 @@
 'special-categories-sort-count' => 'ordenal pol cuenta',
 'special-categories-sort-abc'   => 'ordenal alfabeticamenti',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "Muestral usuárius qu'esmiencin pol:",
 'listusers-submit'   => 'Muestral',
 'listusers-noresult' => 'Nu s´alcuentró dengún usuáriu.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Derechus del grupu d'usuárius",
 'listgrouprights-group'    => 'Grupu',
 'listgrouprights-rights'   => 'Derechus',
@@ -1257,7 +1249,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nu envial direción',
-'mailnologintext' => 'Ebis estal [[Special:Userlogin|rutrau]]
+'mailnologintext' => 'Ebis estal [[Special:UserLogin|rutrau]]
 i tenel una direción d´email correta enas tus [[Special:Preferences|preferéncias]]
 pa envial correus a otrus usuárius.',
 'emailuser'       => 'Envial un email a esti usuáriu',
@@ -1285,11 +1277,11 @@
 'nowatchlist'          => 'La tu lista e seguimientu está vacia.',
 'watchlistanontext'    => 'Pa vel u eital las entrás ena tu lista e seguimientu es mestel $1.',
 'watchnologin'         => 'Nu estás rustriu',
-'watchnologintext'     => 'Ebis [[Special:Userlogin|abril la tu cuenta]] pa puel hazel chambus ena tu lista e seguimientu.',
+'watchnologintext'     => 'Ebis [[Special:UserLogin|abril la tu cuenta]] pa puel hazel chambus ena tu lista e seguimientu.',
 'addedwatch'           => 'Añiiu a la lista e seguimientu',
 'addedwatchtext'       => "S´á añiiu la páhina \"[[:\$1]]\" a la tu [[Special:Watchlist|lista e seguimientu]].
 Los huturus chambus de la páhina i ena su caraba se muestrarán aquí,
-i el su entítulu apaicirá en '''negrina''' ena [[Special:Recentchanges|lista d´úrtimus chambus]].
+i el su entítulu apaicirá en '''negrina''' ena [[Special:RecentChanges|lista d´úrtimus chambus]].
 
 Si quieis ehal de vehilal la páhina, pursa sobri \"Ehal de vehilal\".",
 'removedwatch'         => 'Esborrau e la lista e seguimientu',
@@ -1400,7 +1392,7 @@
 s'á cancelau l'ación solicitá. Pursa nel botón \"Atrás\" del
 tu escrucaol pa cargal otra vezi la páhina i güervi a ententalu.",
 'protectlogpage'              => 'Rustrihu e proteción',
-'protectlogtext'              => 'Embahu se muestra una lista cola proteción i desproteción la páhina. Pa mas enhormación, lei "[[Special:Protectedpages|Esta páhina está protehia]]".',
+'protectlogtext'              => 'Embahu se muestra una lista cola proteción i desproteción la páhina. Pa mas enhormación, lei "[[Special:ProtectedPages|Esta páhina está protehia]]".',
 'protectedarticle'            => '"[[$1]]" protehiu',
 'modifiedarticleprotection'   => 'chambau el nivel de proteción a "[[$1]]"',
 'unprotectedarticle'          => '"[[$1]]" esprotehiu',
@@ -1554,7 +1546,7 @@
 'badipaddress'                => 'Direción IP nu premitia',
 'blockipsuccesssub'           => 'Usuáriu atarugau!',
 'blockipsuccesstext'          => "La direción IP [[Special:Contributions/$1|$1]] á siu atarugá.
-<br />Consurta la [[Special:Ipblocklist|lista d'IP atarugás]] pa visoreal los tarugus.",
+<br />Consurta la [[Special:IPBlockList|lista d'IP atarugás]] pa visoreal los tarugus.",
 'ipb-edit-dropdown'           => 'Eital las razonis el tarugu',
 'ipb-unblock-addr'            => 'Desatarugal $1',
 'ipb-unblock'                 => 'Desatarugal un nombri d´usuáriu u direción IP',
@@ -1623,7 +1615,7 @@
 'lockdbsuccesssub'    => 'Tarugu la basi e datus ativu',
 'unlockdbsuccesssub'  => 'Esborrau el tarugu la basi e datus',
 'lockdbsuccesstext'   => 'La basi e datus á siu atarugá.
-<br />Alcuerdati d´[[Special:Unlockdb|esborral el tarugu]] cuandu aigas acabihau.',
+<br />Alcuerdati d´[[Special:UnlockDB|esborral el tarugu]] cuandu aigas acabihau.',
 'unlockdbsuccesstext' => "S'á desatarugau la basi e datus.",
 'lockfilenotwritable' => "El tarugu la basi e datus nu se puei sobriescribil. P'atarugual u desatarugal la basi e datus, esta ebi puel sel escrita pol sirviol web.",
 'databasenotlocked'   => 'La basi e datus nu está atarugá.',
@@ -1646,8 +1638,6 @@
 
 En dambus los dos chascus, si lo deseas, tendrás que movel u mestural la páhina manualmenti.",
 'movearticle'             => 'Movel páhina:',
-'movenologin'             => "Nu t'alcuentras rustriu",
-'movenologintext'         => 'Ebis estal rustriu i [[Special:Userlogin|entral ena tu cuenta]] pa movel una páhina.',
 'movenotallowed'          => 'Nu tiinis premisu pa mual páhinas nesti güiqui.',
 'newtitle'                => 'Nuevu entítulu:',
 'move-watch'              => 'Vehilal esta páhina',
@@ -1668,7 +1658,7 @@
 'delete_and_move'         => 'Esborral i movel',
 'delete_and_move_text'    => '==Es mestel esborral==
 
-Ya desisti la páhina "[[$1]]". Te petaria esborrala pa premitil el treslau?',
+Ya desisti la páhina "[[:$1]]". Te petaria esborrala pa premitil el treslau?',
 'delete_and_move_confirm' => 'Sí, esborral la páhina',
 'delete_and_move_reason'  => 'Esborrá pa premitil el treslau',
 'selfmove'                => "Los entítulus d'orihin i destinu son los mesmus. Nu es posibri movel una páhina sobri sí mesma..",
@@ -1880,7 +1870,7 @@
 'show-big-image'       => 'Resolución máisima',
 'show-big-image-thumb' => '<small>Grandol al previsoreal: $1 × $2 pixelis</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Correol d´archivus nuevus',
 'imagelisttext'         => "Embahu ai una lista con '''$1''' {{PLURAL:$1|archivu|archivus}} ordenaus $2.",
 'noimages'              => 'Nu ai ná pa vel.',
@@ -2115,7 +2105,7 @@
 
 # External editor support
 'edit-externally'      => 'Eital esti archivu gastandu una apricación esterna',
-'edit-externally-help' => 'Pa mas enhormación, lei las [http://meta.wikimedia.org/wiki/Help:External_editors istrucionis de configuración] (en ingrés).',
+'edit-externally-help' => 'Pa mas enhormación, lei las [http://www.mediawiki.org/wiki/Manual:External_editors istrucionis de configuración] (en ingrés).',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tó',
@@ -2186,7 +2176,7 @@
 'recreate'            => 'Gorvel a crial',
 
 # HTML dump
-'redirectingto' => 'Rederihiendu a [[$1]]...',
+'redirectingto' => 'Rederihiendu a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Esborral el caché desta páhina?
@@ -2287,7 +2277,7 @@
 'version-software-product'    => 'Proutu',
 'version-software-version'    => 'Velsión',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => "Ruta d'archivu",
 'filepath-page'    => 'Archivu:',
 'filepath-submit'  => 'Ruta',
Index: languages/messages/MessagesPnt.php
===================================================================
--- languages/messages/MessagesPnt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPnt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Consta
  * @author Sinopeus
- * @author Consta
- * @author Siebrand
  */
 
 $namespaceNames = array(
@@ -121,6 +120,7 @@
 'category-file-count-limited'    => "{{PLURAL:$1|Τ' αρχείον|$1 Τ' αρχεία}} αφκά καικά είν' σην κατηγορίαν.",
 'listingcontinuesabbrev'         => 'συνεχίζεται...',
 
+'about'          => 'Περί',
 'newwindow'      => "(ανοίγ' σ' άλλον παραθύρ)",
 'cancel'         => 'Χάτεμαν',
 'qbfind'         => 'Εύρον',
@@ -178,14 +178,17 @@
 'viewtalkpage'      => 'Τέρεν καλάτσεμα',
 'otherlanguages'    => "Σ' άλλα γλώσσας",
 'redirectedfrom'    => '(Έρτεν ασό $1)',
+'redirectpagesub'   => 'Σελίδαν διπλού σύνδεσμονος',
 'protectedpage'     => 'Ασπαλιζμένον σελίδαν',
 'jumpto'            => 'Δέβα σο:',
 'jumptonavigation'  => 'Πορπάτεμαν',
 'jumptosearch'      => 'Αράεμαν',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'            => 'Για το σάιτ {{SITENAME}}',
+'aboutsite'            => 'Περί {{SITENAME}}',
 'aboutpage'            => 'Project:Σχετικά',
+'bugreports'           => 'Αναφοράντας λαθίων',
+'bugreportspage'       => 'Project:Γραφέστεν',
 'copyrightpage'        => '{{ns:project}}:Δικαιώματα Πνευματή',
 'currentevents'        => 'Ατωριζνά γεγονότα',
 'currentevents-url'    => 'Project:Ατωριζνά γεγονότα',
@@ -223,7 +226,7 @@
 'nstab-special'   => 'Ειδικόν',
 'nstab-project'   => 'Σχετικά με',
 'nstab-image'     => 'Εικόναν',
-'nstab-mediawiki' => 'Μένεμα',
+'nstab-mediawiki' => 'Μένεμαν',
 'nstab-template'  => 'Πρότυπον',
 'nstab-help'      => 'Σελίδα βοήθειας',
 'nstab-category'  => 'Κατηγορίαν',
@@ -237,6 +240,9 @@
 'readonly'          => 'Βάση δογμενίων εν ασπαλιζμένον',
 'enterlockreason'   => "Βαλέστεν λόγον για τ' ασπάλιγμαν και ους πότε θα εν ασπαλιγμένον",
 'badarticleerror'   => "Ατή η ενέργειαν 'κ επορεί να ίνεται σ'ατήν τη σελίδαν.",
+'badtitle'          => 'Άχρηστον τίτλος',
+'badtitletext'      => "Το ψαλαφεμένον ο τίτλος τη σελίδας εν άκυρον, εύκαιρον για λανθασμένον διαγλωσσικόν σύνδεσμον.
+Εν δυνατόν και να έχ' έναν για πολλά γράμματα που 'κ ίνεται να κουλανεύκουνταν απές σε τίτλον.",
 'viewsource'        => 'Τέρεν κωδικόν',
 'viewsourcefor'     => 'για $1',
 'protectedpagetext' => "Ατή η σελίδαν εν ασπαλιγμένη και 'κ αλλάζεται.",
@@ -246,9 +252,10 @@
 'yourname'                => 'Όνεμα χρήστε:',
 'yourpassword'            => 'Σημάδι:',
 'yourpasswordagain'       => "Ξαν' γράψτεν το σημάδι:",
+'remembermypassword'      => "Αποθήκεμαν τη σημαδίμ σ' αβούτον τον υπολογιστήν",
 'login'                   => 'Εμπάτε',
 'nav-login-createaccount' => 'Εμπάτε / Ποίστεν λογαρίαν',
-'loginprompt'             => "Πρέπ' να έχετε ενεργοποιήσει τα cookies για εμπείτε σο {{SITENAME}}.",
+'loginprompt'             => "Πρέπ' ν' άφτετε τα cookies για εμπείτε σο {{SITENAME}}.",
 'userlogin'               => 'Εμπάτε / Ποίστεν λογαρίαν',
 'logout'                  => 'οξουκά',
 'userlogout'              => 'Οξουκά',
@@ -271,14 +278,35 @@
 Το γράψιμον ωρία ή ποίσον καινούρεον λογαρίαν.',
 'nosuchusershort'         => 'Αδά \'κ εχ\' χρήστεν με τ\' όνομα "<nowiki>$1</nowiki>".
 Το γράψιμονις ωρία.',
+'nouserspecified'         => "Πρέπ' να ψιλίζετε όνομαν.",
+'wrongpassword'           => "Το σημάδι 'κ εν σωστόν.
+Ποίστεν άλλο προσπάθειαν.",
+'wrongpasswordempty'      => 'Το σημάδι έτον εύκαιρον.
+Ποίστεν άλλο προσπάθειαν.',
+'passwordtooshort'        => "Το σημάδι εν πολλά μικρόν.
+Πρέπ' να εχ' {{PLURAL:$1|1 γράμμαν|$1 γράμματα}} κιαν. Το σημάδινεσουν πρέπ' να εν αλλέτερον ασόν όνομαν τη χρήστε.",
 'mailmypassword'          => 'Αποστολή κωδικού',
+'passwordremindertitle'   => 'Καινούρεον σημάδιν για {{SITENAME}}',
+'passwordremindertext'    => 'Κάποιος (ίσως εσείς, ασήν διεύθυνσην IP $1)
+εποίκεν ψαλαφίον να στείλκουμες έναν νέον σημάδιν για τον ιστοτόπον {{SITENAME}} ($4).
+Το σημάδιν για τον χρήστεν "$2" ατώρα εν "$3".
+Ατώρα εμπάτε σην σελίδαν και ποίστεν το σημάδινεσουν διαφορετικόν.
+
+Εάν το ψαλαφίον εποίκενατο άλλος για έχετε σο νούνεσουν αξάν το παλαιόν το σημάδινεσουν και το καινούρεον ξάι \'κ χρειάσκεται, επορείτε ν\' ανασπάλλετε το καινούρεον το σημάδιν με τ\' αβούτο το μένεμαν εντάμαν και να μεταχειρίσκεστε το παλαιόν το σημάδιν άμον ντ\' εφτάγατε ους οσήμερον.',
+'noemail'                 => '\'Κ εδώθεν e-mail address τη χρήστε "$1".',
+'passwordsent'            => 'Έναν καινούρεον σημάδιν επήγεν σο e-mail τη "$1".
+Άμον ντο παίρετ\' ατό, εμπάτε ξαν.',
+'eauthentsent'            => "Έναν μένεμαν confirmation e-mail επήγεν σην διεύθυνσην ντ' εδώκατε.
+Πριχού να πηγαίνει άλλον μένεμαν σ' αβούτεν τη λογαρίαν, θα φτάτεν ατά ντο γραφ' σο μένεμαν απές. Αέτς πα θα δεκνίζετε το e-mail ατό εν το τεσέτερον.",
 'accountcreated'          => 'Έντον η λογαρίαν',
 'createaccount-title'     => 'Δημιουργίαν λογαρίας για {{SITENAME}}',
 'loginlanguagelabel'      => 'Γλώσσαν: $1',
 
 # Edit page toolbar
-'bold_sample'     => 'Σκιρόν κείμενον',
-'bold_tip'        => 'Σκιρόν κείμενον',
+'bold_sample'     => 'Χοντρόν κείμενον',
+'bold_tip'        => 'Χοντρόν κείμενον',
+'italic_sample'   => 'Ψιλόν κείμενον',
+'italic_tip'      => 'Ψιλόν κείμενον',
 'link_sample'     => 'Τίτλος σύνδεσμονος',
 'link_tip'        => 'Εσωτερικόν σύνδεσμον',
 'extlink_sample'  => 'http://www.example.com τίτλος σύνδεσμονος',
@@ -305,62 +333,125 @@
 'showdiff'               => 'Αλλαγάς',
 'anoneditwarning'        => "'''Ωρίασων:''' 'Κ εποίκες τ' εσέβεμαν.
 Τ' IP ις θα γράφκεται και θα ελέπν' ατό σ' ιστορικόν τη σελίδας.",
+'summary-preview'        => 'Πρώτον τέρεμαν τη σύνοψης',
+'blockedtext'            => "<big>'''Τ' όνομαν ή το IP εσούν εκλείστεν.'''</big>
+
+Τ' ασπάλιγμαν εποίκενατο ο χρήστες $1.
+Έδωκεν την αιτίαν ''$2''.
+
+* Ασπάλιγμαν αχπάσκεται: $8
+* Ασπάλιγμαν τελείται: $6
+* Θα κλείσκεται ο χρήστες: $7
+
+Για το ασπάλιγμαν εμπορείτε να συντισένετε με τον $1 ή με τ' αλλτς τοι [[{{MediaWiki:Grouppage-sysop}}|διαχειριστάδες]].
+Για να γράφετε ελεκτρονικόν μένεμαν ('e-mail this user') βαλέστεν το τεσέτερον το σωστόν το e-mail address σα [[Special:Preferences|προτιμήσαι τη λογαρίας εσούν]]. Επεκεί 'κ θα είστουν ασπαλιγμένος για γράψιμον τη μενεματί.
+Τ' ατοριζνόν το IP εσούν εν $3, και το ID τη ασπαλιγματί εν #$5.
+Ποδεδίζουμε σας να γράφτε τα και τα δυο σο μένεμαν εσούν.",
+'autoblockedtext'        => "Το IP εσούν εκλείστεν αυτόματα επειδή μεταχειρίσκουτονατο άλλος χρήστες ντ' έτον ασπάλιγμένος ασόν χρήστεν $1.
+Έδωκεν την αιτίαν:
+
+:''$2''
+
+* Ασπάλιγμαν αχπάσκεται: $8
+* Ασπάλιγμαν τελείται: $6
+
+Για το ασπάλιγμαν επορείτε να συντισένετε με το χρήστεν $1 ή με τ' αλλτς τ' [[{{MediaWiki:Grouppage-sysop}}|administrators]]. Για να γράφετε ελεκτρονικόν μένεμαν ('e-mail this user') βαλέστεν το τεσέτερον το σωστόν το e-mail address σα [[Special:Preferences|προτιμήσαι τη λογαρίας εσούν]]. Εάν 'κ εν ασπαλιγμένον η χρήσηνατ, επορείτε να γράφετε μένεμαν. 
+
+Το ID τη ασπαλιγματίνεσουν εν $5.
+Ποδεδίζουμε σας να γράφτατο σο μένεμαν εσούν.",
+'blockednoreason'        => "'Κ εγράφτεν αιτίαν",
 'newarticle'             => '(Νέον)',
+'newarticletext'         => "Έρθατεν ασ' έναν σύνδεσμον σ' έναν εύκαιρον σελίδαν. 
+Για να εφτάτε τη σελίδαν, αρχινέστε γράψιμον σο χουτίν αφκά (δεαβάστεν τη [[{{MediaWiki:Helppage}}|σελίδαν βοήθειας]] και μαθέστεν κιάλλα).
+Εάν 'κ θέλετε ν' εφτάτε αβούτεν τη σελίδαν, πατήστε το κουμπίν το λεει '''οπίς''' και δεβάτεν οπίς απ' όθεν έρθατεν.",
+'noarticletext'          => "(Αβούτεν η σελίδαν 'κ εχ' κείμενον απές ακόμαν.)",
 'previewnote'            => "<strong>Ατό πα πρώτον τέρεμαν εν και μόνον.
 Τ' αλλαγάς 'κ εκρατέθαν!</strong>",
 'editing'                => 'Αλλαγήν $1',
 'editingsection'         => 'Αλλαγήν $1 (τμήμα)',
 'editingold'             => "<strong>ΩΡΙΑ: Εφτάτε αλλαγάς σε παλαιόν έκδοσην τη σελίδας. 
 Εάν θα κρατείτε ατά, ούλ' τ' επεκεί αλλαγάς θα χάνταν.</strong>",
+'copyrightwarning'       => "Ούλαι τα γραψίματα ασο {{SITENAME}} θα μεταχειρίσκουνταν άμον ντο λεει το $2 (τερέστεν και $1).
+Εάν 'κ θέλετε ατό να ίνεται, να μην εφτάτε το αποθήκεμαν.<br />
+Καμμίαν κι ανασπάλλετε: Αδακά 'κ εν ο τόπον για να θέκουμε γράψιμον ντ' έγραψαν αλλ. Βαλέστε άρθρα όνταν κατέχετε τα δικαιώματα πνευματί μαναχόν. 
+<strong>ΚΑΜΜΙΑΝ 'Κ ΘΕΚΕΤΕ ΓΡΑΨΙΜΟΝ ΑΔΑΚΑ ΟΝΤΕΣ 'Κ ΕΧΕΤΕ ΤΑ ΔΙΚΑΙΩΜΑΤΑ ΠΝΕΥΜΑΤΙ!</strong>",
+'longpagewarning'        => "<strong>ΩΡΙΑ: Αβούτεν η σελίδαν έχ' μέγεθος $1kb. Μερικά browser 'κ επορούν ν' επεξεργάσκουνταν σελίδας ντ' έχνε 32kb κιαν. Επορείτε να λύετε το πρόβλημαν αν εφτάτεν ατέναν μικρά κομμάται.</strong>",
 'templatesused'          => "Πρότυπα το μεταχειρίσκουνταν σ' αβούτεν την σελίδαν:",
+'templatesusedpreview'   => "Πρότυπα σ' αβούτον το πρώτον τέρεμαν:",
 'template-protected'     => '(ασπαλιγμένον)',
 'template-semiprotected' => '(ημψά-ασπαλιγμένον)',
+'nocreatetext'           => "Σο {{SITENAME}} περιορίσκουτον το ποίσεμα σελιδίων.
+'Πορείτε να κλώσκεστε οπίς και ν' αλλάζετε έναν παλαιόν σελίδαν ή να [[Special:UserLogin|εμπάτε ή να εφτάτε λογαρίαν]].",
+'recreate-deleted-warn'  => "'''Ωρία: Εφτάτε αξάν μίαν σελίδαν ντο νεβζινέθεν οψεκές.'''
 
+Ίσως εν καλλίον να μην εφτάτε τη σελίδαν.
+Τερέστεν για βοήθειαν και σ' αρχείον την αιτίαν για το σβήσιμον:",
+
 # History pages
 'viewpagelogs'        => "Τέρεν πρωτόκολλα γι' αβούτεν τη σελίδαν",
 'currentrev'          => 'Ατωριζνόν μορφήν',
 'revisionasof'        => 'Μορφήν τη $1',
 'revision-info'       => 'Έκδοση σα $1 ασόν/ασήν $2',
 'previousrevision'    => '←Παλαιόν μορφήν',
-'nextrevision'        => 'Κι άλλο καινούρεον έκδοση→',
-'currentrevisionlink' => 'Ατωριζνόν έκδοση',
-'cur'                 => 'τρέχουσα',
-'last'                => 'τελευταία',
-'page_first'          => 'πρώτη',
-'page_last'           => 'τελευταία',
+'nextrevision'        => 'Κι άλλο καινούρεον μορφήν→',
+'currentrevisionlink' => 'Ατωριζνόν μορφήν',
+'cur'                 => 'ατωριζνόν',
+'next'                => 'επόμενον',
+'last'                => 'υστερνόν',
+'page_first'          => 'πρώτον',
+'page_last'           => 'υστερνόν',
+'histlegend'          => 'Σύγκριμα διαφορίων: βαλέστεν τα μορφάς το θέλετε και τερέστεν τα διαφοράσατουν. Για να τερείτε τα διαφοράς, ποίστεν έναν κλικ σο πεδίον το λεει "Γαρσουλαεύτε...". <br />
+Πληροφορία: (ατωριζνόν) = διαφοράς με τ\' ατωριζνόν τη μορφήν,
+(υστερνόν) = διαφοράς με τ\' υστερνόν τη μορφήν, μ = μικρά διαφοράς.',
 'histfirst'           => "Ασ' όλεα παλαιόν",
 'histlast'            => "Ασ' όλεα καινούρ'",
+'historyempty'        => '(εύκαιρον)',
 
 # Revision feed
 'history-feed-item-nocomment' => '$1 σο $2', # user at time
 
 # Diffs
 'history-title'           => 'Ιστορικόν εκδοσίων για τη σελίδαν "$1"',
+'difference'              => '(Διαφορά μεταξύ τη μορφίων)',
 'lineno'                  => 'Γραμμή $1:',
-'compareselectedversions' => 'Γαρσουλαεύτε τα εκδώσεις',
+'compareselectedversions' => 'Γαρσουλαεύτε...',
 'editundo'                => 'αναίρεση',
+'diff-multi'              => "({{PLURAL:$1|Μίαν αλλαγήν|$1 αλλαγάς}} 'κ δεκνίζκουνταν.)",
 
 # Search results
-'noexactmatch' => "'''Η Βικιπαίδειαν 'κ εχ' σελίδαν με τ' όνεμαν \"\$1\".'''
-Εμπορείτε να [[:\$1|εφτάτε ατέν]].",
-'prevn'        => '$1 προηγουμένων',
-'nextn'        => '$1 επομένων',
-'viewprevnext' => 'Τέρεν ($1) ($2) ($3)',
-'powersearch'  => 'Αναλυτικόν αράεμαν',
+'noexactmatch'          => "'''Η Βικιπαίδειαν 'κ εχ' σελίδαν με τ' όνεμαν \"\$1\".'''
+Εμπορείτε να [[:\$1|εφτάτε ατέναν]].",
+'prevn'                 => '$1 προηγουμένων',
+'nextn'                 => '$1 επομένων',
+'viewprevnext'          => 'Τέρεν ($1) ($2) ($3)',
+'search-suggest'        => 'Γιαμ αραεύετε: $1',
+'search-interwiki-more' => '(πλέα)',
+'searchall'             => 'ούλαι',
+'powersearch'           => 'Αναλυτικόν αράεμαν',
 
 # Preferences page
-'preferences'   => 'Προτιμήσεις',
-'mypreferences' => "Τ' εμά τα προτιμήσεις",
+'preferences'   => 'Προτιμήσαι',
+'mypreferences' => "Τ' εμά τα προτιμήσαι",
 'retypenew'     => 'Γράψον ξαν το νέον σημάδιν:',
 
+'grouppage-sysop' => '{{ns:project}}:Διαχειριστάδες',
+
+# User rights log
+'rightslog' => 'Αρχείον δικαιωματίων',
+
 # Recent changes
+'nchanges'                       => '$1 {{PLURAL:$1|αλλαγή|αλλαγάς}}',
 'recentchanges'                  => 'Υστερνά αλλαγάς',
 'recentchanges-feed-description' => "Τ' ασ' όλεα καινούρεα αλλαγάς τη wiki ωρία σ' αβούτεν την περίληψην.",
+'rcnote'                         => "Αφκά {{PLURAL:$1|έχ' '''1''' αλλαγήν|έχ' τα '''$1''' τελευταία αλλαγάς}} τη {{PLURAL:$2|τελευταίας ημέρας|τελευταίων '''$2''' ημερίων}}, σα $5, $4.",
+'rcnotefrom'                     => "Αφκά καικά ευρίουνταν τ' αλλαγάς ασό <b>$2</b> (εμφάνιση <b>$1</b> αλλαγίων max).",
+'rclistfrom'                     => "Καινούρεα αλλαγάς ντ' εσκαλών'νε ασά $1",
 'rcshowhideminor'                => '$1 τα μικρά αλλαγάς',
 'rcshowhidebots'                 => '$1 bots',
 'rcshowhideliu'                  => '$1 χρήστες με λογαρίαν',
-'rcshowhideanons'                => '$1 αναγνώριμοι χρήστες',
-'rcshowhidemine'                 => "$1 τ' επεξεργασίων ιμ",
+'rcshowhideanons'                => "$1 τ' αναγνώριμους τοι χρήστς",
+'rcshowhidepatr'                 => "$1 αλλαγάς ντ' ωράουνταν",
+'rcshowhidemine'                 => "$1 τ' αλλαγάς ιμ",
 'rclinks'                        => "Δείξον τα $1 υστερνά τ' αλλαγάς α σα $2 υστερνά τα ημέρας<br />$3",
 'diff'                           => 'διαφορά',
 'hist'                           => 'ιστ.',
@@ -371,41 +462,66 @@
 'boteditletter'                  => 'b',
 
 # Recent changes linked
+'recentchangeslinked'          => 'Σχετικά αλλαγάς',
 'recentchangeslinked-title'    => 'Αλλαγάς τη "$1"',
 'recentchangeslinked-noresult' => "Σ' αβούτα τα σελίδας 'κ εγένταν αλλάγματα.",
+'recentchangeslinked-summary'  => "Αβούτος εν κατάλογον με τ' υστερνά τ' αλλαγάς σελιδίων με σύνδεσμον ασ' έναν συγκεκριμένον σελίδαν (για σε σελίδας συγκεκριμένου κατηγορίας).
+Τα σελίδας σον [[Special:Watchlist|κατάλογον ωριαγματί]] είν' '''σκηρά'''.",
 
 # Upload
 'upload'        => 'Φόρτωμα αρχείου',
 'uploadbtn'     => 'Φόρτωμα αρχείου',
+'uploadlogpage' => 'Αρχείον ανεβασματίων',
 'uploadedimage' => 'Εγέντον το φόρτωμαν τη "[[$1]]"',
 
+# Special:ImageList
+'imagelist' => 'Λίσταν εικονίων',
+
 # Image description page
-'filehist'            => 'Ιστορικό αρχείου',
-'filehist-help'       => "Εφτάτε κλικ σ' έναν ημερομηνίαν/ώραν απάν αέτς για να τερείτε πως έτον τ' αρχείον σ' εκείνεν την ώραν.",
-'filehist-current'    => 'υστερινά',
-'filehist-datetime'   => 'Ώραν/Ημερομ.',
-'filehist-user'       => 'Χρήστες',
-'filehist-dimensions' => 'Διαστάσεις',
-'filehist-filesize'   => 'Μέγεθος',
-'filehist-comment'    => 'Σχόλιον',
-'imagelinks'          => 'Σύνδεσμοι',
-'linkstoimage'        => "Ατά τα {{PLURAL:$1|σελίδαν δεκνίζ'|$1 σελίδας δεκνίζ'νε}} σην εικόναν:",
-'nolinkstoimage'      => "'Κ εχ σελίδας ντο δεκνίζνε σ' αβούτεν εικόναν.",
+'filehist'                  => 'Ιστορικό αρχείου',
+'filehist-help'             => "Εφτάτε κλικ σ' έναν ημερομηνίαν/ώραν απάν αέτς για να τερείτε πως έτον τ' αρχείον σ' εκείνεν την ώραν.",
+'filehist-current'          => 'υστερινά',
+'filehist-datetime'         => 'Ώραν/Ημερομ.',
+'filehist-user'             => 'Χρήστες',
+'filehist-dimensions'       => 'Διαστάσεις',
+'filehist-filesize'         => 'Μέγεθος',
+'filehist-comment'          => 'Σχόλιον',
+'imagelinks'                => 'Σύνδεσμοι',
+'linkstoimage'              => "Ατά τα {{PLURAL:$1|σελίδαν δεκνίζ'|$1 σελίδας δεκνίζ'νε}} σην εικόναν:",
+'nolinkstoimage'            => "'Κ εχ σελίδας ντο δεκνίζνε σ' αβούτεν εικόναν.",
+'sharedupload'              => "Αβούτον τ' αρχείον εφορτώθεν για κοινόν κουλάνεμαν κι εν δυνατόν να χρησιμοπισκάται και σ' άλλα έργα.",
+'noimage'                   => "Αρχείον με αείκον όνεμαν 'κ έχ', άμα επορείς να $1.",
+'noimage-linktext'          => "σκώσ' ατό",
+'uploadnewversion-linktext' => "Σκώσ' καινούραιον έκδοσην τ' αρχείου",
 
 # MIME search
 'mimesearch' => 'Αράεμαν MIME',
 
+# List redirects
+'listredirects' => 'Κατάλογον με διπλά συνδέσμ',
+
 # Unused templates
 'unusedtemplates' => "Πρότυπα ντο 'κ μεταχειρίσκουνταν",
 
 # Random page
 'randompage' => 'Τυχαίον σελίδα',
 
+# Random redirect
+'randomredirect' => 'Τυχαία διπλά συνδέσμ',
+
 # Statistics
 'statistics' => 'Στατιστικήν',
 
+'disambiguations' => 'Σελίδας εξηγησίων',
+
+'doubleredirects' => 'Περισσά διπλά συνδέσμ',
+
+'brokenredirects' => 'Τσακωμένα διπλά συνδέσμ',
+
 'withoutinterwiki' => "Σελίδας ντο κ' έχνε συνδέσμ",
 
+'fewestrevisions' => "Σελίδας με τ' ασόλων λιγότερα αλλαγάς.",
+
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
 'nlinks'                  => '$1 {{PLURAL:$1|σύνδεσμος|συνδέσμ}}',
@@ -419,7 +535,12 @@
 'unusedimages'            => "Εικόνας ντο κ' μεταχειρίσκουνταν",
 'wantedcategories'        => 'Κατηγορίας το θέλουμε',
 'wantedpages'             => 'Σελίδας το θέλουμε',
+'mostlinked'              => "Σελίδας με τ' ασόλων πλέα σελίδας ντο δεκνίζν' εκαικά.",
+'mostlinkedcategories'    => "Κατηγορίας με τ' ασόλων πλέα σελίδας ντο δεκνίζν' εκαικά.",
+'mostlinkedtemplates'     => "Πρότυπα με τ' ασόλων πλέα σελίδας ντο δεκνίζν' εκαικά",
 'mostcategories'          => "Σελίδας με τ' ασ' όλτς πολλά κατηγορίας",
+'mostimages'              => "Αρχεία με τ' ασόλων πλέα σελίδας ντο δεκνίζν' εκαικά",
+'mostrevisions'           => "Σελίδας με τ' ασόλων πλέα αλλαγάς",
 'prefixindex'             => 'Κατάλογος κατά πρόθεμαν',
 'shortpages'              => 'Μικρά σελίδας',
 'longpages'               => 'Τρανά σελίδας',
@@ -432,20 +553,25 @@
 'movethispage'            => "Άλλαξον τ' όνεμα τη σελίδας",
 
 # Book sources
+'booksources'               => 'Βιβλιογραφικά πηγάς',
 'booksources-search-legend' => 'Αράεμαν τη βιβλίων',
 'booksources-go'            => 'Δέβα',
 
 # Special:Log
 'specialloguserlabel'  => 'Χρήστες:',
 'speciallogtitlelabel' => 'Τίτλος:',
+'log'                  => 'Αρχεία',
+'all-logs-page'        => "Όλεα τ' αρχεία",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Όλεα τα σελίδας',
 'alphaindexline' => '$1 ους $2',
 'nextpage'       => 'Επόμενον σελίδα ($1)',
 'prevpage'       => 'Προηγούμενον σελίδα ($1)',
+'allpagesfrom'   => "Τέρεμαν σελιδίων ντ' εσκαλών'νε ασό:",
 'allarticles'    => 'Όλεα τα σελίδας',
 'allpagessubmit' => 'Δέβα',
+'allpagesprefix' => 'Τέρεμαν σελιδίων με πρόθεμαν:',
 
 # Special:Categories
 'categories'         => 'Κατηγορίας',
@@ -458,11 +584,14 @@
 'watchlist'            => "Σελίδας ντ' ωριάζω",
 'mywatchlist'          => "Σελίδας ντ' ωριάζω",
 'watchlistfor'         => "(για '''$1''')",
+'addedwatch'           => 'Εθέκεν σην λίσταν ωριαγματί',
+'addedwatchtext'       => "Η σελίδαν \"[[:\$1]]\" επήγεν σον [[Special:Watchlist|κατάλογον οριαγματί]] εσούν.
+Μελλούμενα αλλαγάς τ' ατεινές τη σελίδας θα γράφκουνταικεκά, και η σελίδαν θ' ευρίεται με γράμματα '''χοντρά''' σ' [[Special:RecentChanges|υστερνά τ' αλλαγάς]] για να τερείτετα καλίον.",
 'removedwatch'         => 'Αση λίσταν επάρθεν',
-'removedwatchtext'     => 'Η σελίδαν "[[:$1]]" νεβζινέθεν ασ\' τ\'εσόν τον κατάλογον.',
+'removedwatchtext'     => 'Η σελίδαν "[[:$1]]" νεβζινέθεν ασ\' [[Special:Watchlist|τ\'εσόν τον κατάλογον]].',
 'watch'                => 'Ωρίαγμαν',
 'watchthispage'        => 'Ωρίαν τη σελίδαν',
-'unwatch'              => 'Τέλος τη ωρίαγματη',
+'unwatch'              => "Τέλεμαν τ' ωριαγματί",
 'watchlist-details'    => '{{PLURAL:$1|$1 σελίδα|$1 σελίδας}} ωριάσκουνταν, θέγα τα σελίδας καλάτσεματι.',
 'wlshowlast'           => "Φανέρωμαν τ' υστερναίων $1 ωρίων $2 ημερίων $3",
 'watchlist-hide-bots'  => "Κρύψον τ' αλλαγάς τη bots",
@@ -474,23 +603,38 @@
 'unwatching' => "'κ ωριάζω...",
 
 # Delete/protect/revert
-'deletepage'              => 'Σβήσον τη σελίδαν',
-'actioncomplete'          => 'Η ενέργειαν ετελέθεν',
-'deletedarticle'          => 'νεβζινέθεν η "[[$1]]"',
-'dellogpage'              => "Κατάλογος με τ' ατά το νεβζίναν",
-'deletecomment'           => 'Λόγον για το σβήσιμο:',
-'deleteotherreason'       => 'Άλλον/αλλομίαν λόγον:',
-'deletereasonotherlist'   => 'Άλλον λόγον',
-'rollbacklink'            => 'φέρον ξαν σην υστερναίαν',
-'protectcomment'          => 'Σχόλιον:',
-'protect-unchain'         => 'Άνοιξον τα δικαιώματα ετεροχλάεματι',
-'protect-default'         => '(προεπιλεγμένον)',
-'protect-summary-cascade' => 'διαδοχικόν',
-'protect-expiring'        => 'λήγει στις $1 (UTC)',
-'protect-cascade'         => "Ασπάλιγμαν σελιδίων ντ' είν απές σ' αβούτεν σελίδαν (διαδοχικόν προστασίαν)",
-'protect-cantedit'        => "'Κι έχετε δικαίωμαν ν' αλλάζετε τ' επίπεδον ασπάλιγματι τ' ατεινές σελίδας.",
-'restriction-type'        => 'Δικαίωμαν:',
-'restriction-level'       => 'Επίπεδον περιορισμού:',
+'deletepage'                  => 'Σβήσον τη σελίδαν',
+'historywarning'              => "Ωρία: Η σελίδαν που θα σβήετε έχ' ιστορικόν:",
+'confirmdeletetext'           => "Είστουν σουμά σο σβήσεμαν είνος σελίδας και ούλ' τ' ιστορίασατς εντάμαν.
+Παρακαλούμε σας να δίτε το τελικόν τη βεβαίωσην το θέλετε να εφτάτε το σβήσεμαν, τ' εγροικάτε τα συνέπειας τ' ατεινές τη πράξης και τ' εφτάτ' ατεν με βάσην [[{{MediaWiki:Policy-url}}|τη πολιτικήν]].",
+'actioncomplete'              => 'Η ενέργειαν ετελέθεν',
+'deletedtext'                 => 'Το "<nowiki>$1</nowiki>" εσβήγανατο.
+Τερέστεν το $2 και δεαβάστεν για τα υστερνά τα σβησίματα.',
+'deletedarticle'              => 'νεβζινέθεν η "[[$1]]"',
+'dellogpage'                  => "Κατάλογος με τ' ατά ντ' εσβήγαν",
+'deletecomment'               => 'Λόγον για το σβήσιμο:',
+'deleteotherreason'           => 'Άλλον/αλλομίαν λόγον:',
+'deletereasonotherlist'       => 'Άλλον λόγον',
+'rollbacklink'                => 'φέρον ξαν σην υστερναίαν',
+'protectlogpage'              => 'Αρχείον ασπαλιγματίων',
+'protectcomment'              => 'Σχόλιον:',
+'protectexpiry'               => 'Τελείται:',
+'protect_expiry_invalid'      => "Ο χρόνος τελεματί 'κ εν σωστόν.",
+'protect_expiry_old'          => 'Ο χρόνος τελεματί πέρνιξον.',
+'protect-unchain'             => 'Άνοιξον τα δικαιώματα ετεροχλάεματι',
+'protect-text'                => "Αδά επορείτε να τερείτε και ν' αλλάζετε τ' επίπεδον τη προστασίας για τη σελίδαν <strong><nowiki>$1</nowiki></strong>.",
+'protect-locked-access'       => "Η λογαρίανεσουν 'κ έχ' το δικαίωμαν να αλλάζ' τ' ασπάλιγμαν τη σελίδας.
+Αδά έχ' τ' ατωριζνά τα νομς για τη σελίδαν <strong>$1</strong>:",
+'protect-default'             => '(προεπιλεγμένον)',
+'protect-fallback'            => 'Ψαλαφίον δικαιωματίων "$1"',
+'protect-level-autoconfirmed' => 'Ασπάλιγμαν χρηστίων θίχως λογαρίαν',
+'protect-level-sysop'         => 'Διαχειριστάδες μαναχόν',
+'protect-summary-cascade'     => 'διαδοχικόν',
+'protect-expiring'            => 'λήγει στις $1 (UTC)',
+'protect-cascade'             => "Ασπάλιγμαν σελιδίων ντ' είν απές σ' αβούτεν σελίδαν (διαδοχικόν προστασίαν)",
+'protect-cantedit'            => "'Κι έχετε δικαίωμαν ν' αλλάζετε τ' επίπεδον ασπάλιγματι τ' ατεινές σελίδας.",
+'restriction-type'            => 'Δικαίωμαν:',
+'restriction-level'           => 'Επίπεδον περιορισμού:',
 
 # Undelete
 'undeletebtn' => 'Ποίσον ξαν',
@@ -509,45 +653,90 @@
 'year'          => 'Ασή χρονίαν (και πριχού):',
 
 'sp-contributions-newbies-sub' => 'Για τα καινούρεα τοι λογαρίας',
+'sp-contributions-blocklog'    => 'Αρχείον ασπαλιγματίων',
 
 # What links here
 'whatlinkshere'       => "Ντο δεκνίζ' αδακές",
-'whatlinkshere-title' => 'Σελίδας ντο συνδέουν σο $1',
+'whatlinkshere-title' => 'Σελίδας ντο συνδέουν ση σελίδαν $1',
 'whatlinkshere-page'  => 'Σελίδαν:',
 'linklistsub'         => "(Κατάλογον με τοι συνδέσμ')",
 'linkshere'           => "Αβούτα τα σελίδας δεκνίζνε σο '''[[:$1]]''':",
 'nolinkshere'         => "'Κ ευρέθεν σελίδα το δεκνίζ' ση σελίδαν '''[[:$1]]'''.",
+'isredirect'          => 'σελίδαν διπλού σύνδεσμονος',
 'istemplate'          => 'ενσωμάτωση',
 'whatlinkshere-prev'  => '{{PLURAL:$1|προτεσνή|προτεσνά $1}}',
 'whatlinkshere-next'  => '{{PLURAL:$1|υστερνή|υστερναία $1}}',
 'whatlinkshere-links' => '← σύνδεσμοι',
 
 # Block/unblock
-'blocklink'    => 'ασπάλιγμαν',
-'contribslink' => "Δουλείαν ατ'",
+'blockip'       => 'Ασπάλιγμαν τη χρήστε',
+'ipboptions'    => '2 ώρας:2 hours,1 ημέρα:1 day,3 ημέρας:3 days,1 εβδομάδα:1 week,2 εβδομάδας:2 weeks,1 μήνα:1 month,3 μήνας:3 months,6 μήνας:6 months,1 χρόνο:1 year,αόριστα:infinite', # display1:time1,display2:time2,...
+'ipblocklist'   => "Λίσταν με τ' ασπαλιγμένα τα IP και τα λογαρίας",
+'blocklink'     => 'Ασπάλιγμαν',
+'unblocklink'   => 'άνοιγμαν ασπαλιγματί',
+'contribslink'  => "Δουλείαν ατ'",
+'blocklogpage'  => 'Αρχείον ασπαλιγματίων',
+'blocklogentry' => 'εσπάλισεν [[$1]] για $2 $3',
 
 # Move page
-'movearticle'  => 'Ετεροχλάεμαν σελίδας:',
-'newtitle'     => 'Νέον τίτλον:',
-'move-watch'   => 'Αβούτη τη σελίδαν ωρία',
-'movepagebtn'  => 'Ποίσον ετεροχλάεμαν τη σελίδαν',
-'pagemovedsub' => 'Ετερχλαεύτεν',
-'movedto'      => 'ετεροχλαεύτεν σο',
-'movetalk'     => 'Ετεροχλάεμαν τη σελίδας καλάτσεματι',
-'1movedto2'    => '[[$1]] ετερχλαεύτεν σο [[$2]]',
-'movereason'   => 'Λόγον:',
-'revertmove'   => 'επαναφορά',
+'movepagetext'            => "Εάν εφτάτε το ψαλαφίον αφκά θα δίτε άλλον όνομαν σ' έναν σελίδαν και θα παίρτεν τ' ιστορικόνατς εκαικά. Το παλαιόν η σελίδαν θα μεταβάλκεται σε σύνδεσμον σην καινούραιαν.
 
+Επορείτε να μεταβάλκετε τα συνδέσμαι που δεκνίζνε σο παλαιόν τη σελίδαν αυτόματα. Εάν 'κ φτάτε αέτς,
+ευρέστεν [[Special:DoubleRedirects|διπλά]] για [[Special:BrokenRedirects|τσακωμένα συνδέσμ]].
+Έχετ' ευθύνην τα παλαιά τα συνδέσμαι να δεκνίζνε σο σωστόν τη σελίδαν. 
+
+Η σελίδαν ''''κ θ' αλλάζ'''' τη θέσηνατς όντες έχ' άλλον σελίδαν με το νέον τ' όνεμαν. Εξαίρεσην εν τ' εύκαιρα τα σελίδας και τα συνδέσμαι, ντο 'κ έχνε ιστορικόν. 
+Επορείτε δηλαδή να παίρετε τη σελίδαν σ' όνομαν ντ' είχεν προτεσνά. Άμα 'κ επορείτε με το ετεροχλάεμαν να σβήετε άλλον σελίδαν. 
+
+'''ΩΡΙΑ!'''
+Αβούτεν η ενέργειαν επορεί να φέρει τρανά διαφοράς σ' έναν σελίδαν που δεβάζνε πολλοί. 
+Νουνίστενατο καλά πριχού να εφτάτε τ' άλλαγμαν τ' ονοματί.",
+'movepagetalktext'        => "Η σελίδαν καλατσεματί αυτόματα θα πηγαίν' εντάμαν, '''εξόν:'''
+*Έχ' άλλον σελίδαν καλατσεματί ντο 'κ εν εύκαιρον άμα έχ' το ίδιον τ' όνεμαν
+*θα ευκαιρώνετε το χουτίν αφκά.
+
+Εάν θέλετε να εφτάτε τα ένωμαν, να εφτάτε ατό με copy και paste.",
+'movearticle'             => 'Ετεροχλάεμαν σελίδας:',
+'newtitle'                => 'Νέον τίτλον:',
+'move-watch'              => 'Ωρίαγμαν τη σελίδας',
+'movepagebtn'             => 'Ετεροχλάεμαν σελίδας',
+'pagemovedsub'            => 'Ετερχλαεύτεν',
+'movepage-moved'          => '<big>\'\'\'"$1" επήγεν σο "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'articleexists'           => 'Σελίδαν με αήκον όνεμαν υπάρχει.
+Βαλέστεν άλλο όνεμαν.',
+'cantmove-titleprotected' => "'Κ επορείτε ν' εφτάτε σελίδαν με τ' αβούτον τ' όνεμαν επειδή εσπάλισανατο.",
+'talkexists'              => "'''Η σελίδαν ετερχλαεύτεν, άμα η σελίδαν καλατσεματί επέμνεν επειδή σο καινούρεον τίτλον έχ' άλλον.
+Ποίστεν τα ένα.'''",
+'movedto'                 => 'ετεροχλαεύτεν σο',
+'movetalk'                => 'Ετεροχλάεμαν τη σελίδας καλατσεματί',
+'1movedto2'               => '[[$1]] ετερχλαεύτεν σο [[$2]]',
+'1movedto2_redir'         => '[[$1]] ετερχλαεύτεν σο [[$2]] σε σύνδεσμον απάν',
+'movelogpage'             => 'Αρχείον ετεροχλαεματί',
+'movereason'              => 'Λόγον:',
+'revertmove'              => 'επαναφορά',
+
 # Export
-'export' => 'Εξαγωγήν σελίδιων',
+'export'            => 'Εξαγωγήν σελίδιων',
+'export-addcattext' => 'Βαλέστεν σελίδας ασήν κατηγορίαν:',
+'export-addcat'     => 'Βαλέστεν',
+'export-download'   => 'Αποθήκεμαν άμον αρχείον',
 
 # Namespace 8 related
-'allmessages' => 'Μενέματα σύστηματη',
+'allmessages'     => 'Μενέματα συστηματί',
+'allmessagesname' => 'Όνεμαν',
 
 # Thumbnails
 'thumbnail-more'  => 'Ποίσον κι άλλο τρανόν',
 'thumbnail_error' => 'Έντον λάθος ση δημιουργίαν τη μικρογραφίας: $1',
 
+# Special:Import
+'import'                  => 'Εισαγωγήν σελιδίων',
+'import-interwiki-submit' => 'Εισαγωγήν',
+'importstart'             => 'Εισαγωγή σελιδίων...',
+
+# Import log
+'importlogpage' => 'Αρχείον εισαγωγίων',
+
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => "Τ' εμόν η σελίδαν",
 'tooltip-pt-mytalk'               => "Σελίδαν με τ' εμά τα καλατσέματα",
@@ -569,6 +758,7 @@
 'tooltip-search'                  => 'Εύρον σο {{SITENAME}}',
 'tooltip-n-mainpage'              => 'Τερέστεν το αρχικόν τη σελίδαν',
 'tooltip-n-portal'                => 'Σχετικά με το Wiκi - πώς μπορείτε να εφτάτε γιαρτήμ, πού θα ευρίετε πράγματα',
+'tooltip-n-currentevents'         => "Εύρον άλλα πληροφορίας για τ' ατά ντ' ίντανε οψεκές.",
 'tooltip-n-recentchanges'         => "Κατάλογος με τ' υστερνά αλλαγάς σο wiki.",
 'tooltip-n-randompage'            => 'Κατά τύχην εύρον σελίδαν και δείξον ατέν',
 'tooltip-n-help'                  => "Αδά θα ευρίετε τα απαντήσεις ντ' αραεύετε.",
@@ -592,15 +782,20 @@
 'tooltip-watch'                   => "Βαλέστεν αβούτεν τη σελίδαν σην τ' εσέτερον λίσταν ωριάγματι",
 
 # Browsing diffs
-'nextdiff' => "Αϊτέστε σ' υστερναίον διαφορά →",
+'previousdiff' => '← Προτεσνόν διαφορά',
+'nextdiff'     => 'Άλλον διαφορά →',
 
 # Media information
-'file-nohires'   => "<small>'Κ εχ κι άλλο ψηλόν ανάλυσην.</small>",
-'show-big-image' => 'Τζιπ ψηλόν ανάλυση',
+'file-info-size'       => '($1 × $2 εικονοστοιχεία, μέγεθος αρχείου: $3, MIME τύπος: $4)',
+'file-nohires'         => "<small>'Κ εχ κι άλλο ψηλόν ανάλυσην.</small>",
+'svg-long-desc'        => "(Αρχείον SVG, κατ' όνομα $1 × $2 εικονοστοιχεία, μέγεθος αρχεί: $3)",
+'show-big-image'       => 'Τζιπ τρανόν ανάλυση',
+'show-big-image-thumb' => "<small>Μέγεθος τη πρώτ' τερεματί: $1 × $2 εικονοστοιχεία</small>",
 
-# Special:Newimages
-'ilsubmit' => 'Αράεμαν',
-'bydate'   => 'ημερομηνίας',
+# Special:NewImages
+'newimages' => 'Τερέστεν τα καινούρεα φωτογραφίας',
+'ilsubmit'  => 'Αράεμαν',
+'bydate'    => 'ημερομηνίας',
 
 # Bad image list
 'bad_image_list' => "Η σύνταξην εν αέτς:
@@ -610,8 +805,19 @@
 
 # Metadata
 'metadata'          => 'Μεταδογμένα',
+'metadata-help'     => "Αβούτον τ' αρχείον εχ' κιάλλα πληροφορίας, ίσως ασόν ψηφιακόν τη κάμεραν για το σαρωτήν το μεταχειρίσκουτον για να ίνεται.
+Τ' αρχείον αν έλλαξεν μορφήν, τα στοιχεία ίσως κ' είν' σωστά πλέον.",
 'metadata-expand'   => 'Δείξον τα λεπτομέρειας',
 'metadata-collapse' => 'Κρύψον τα λεπτομέρειας',
+'metadata-fields'   => "Τα πεδία μεταδογμενίων EXIF τ' έχ' σ' αβούτον το μένεμαν θ'
+ευρίεται σην σελίδαν εμφάνισης εικόνας όντες ο πίνακας μεταδογμενίων
+θα κρύφκεται. Τ' άλλα τα πεδία θα είναι κρυμμένα εξόν ντο κανονίσκουνταν αλλέτερα.
+* make
+* model
+* datetimeoriginal
+* exposuretime
+* fnumber
+* focallength", # Do not translate list items
 
 # EXIF tags
 'exif-imagewidth'                  => 'Πλάτος',
@@ -634,10 +840,16 @@
 'exif-whitepoint'                  => "Χρωματικόν προσδιορισμός τ' άσπρου",
 'exif-primarychromaticities'       => 'Πρωτεύοντες χρωματισμοί',
 
+# External editor support
+'edit-externally'      => "Αλλαγήν τ' αρχείου με προγράμματα ασα εξ μερέα",
+'edit-externally-help' => 'Τερέστεν τα [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] και θα ευρίετε κι άλλα γνώσιας.',
+
 # 'all' in various places, this might be different for inflected languages
-'watchlistall2' => 'ούλαι',
-'namespacesall' => 'όλεα',
-'monthsall'     => 'ούλαι',
+'recentchangesall' => 'ούλαι',
+'imagelistall'     => 'ούλαι',
+'watchlistall2'    => 'ούλαι',
+'namespacesall'    => 'ούλαι',
+'monthsall'        => 'ούλαι',
 
 # Multipage image navigation
 'imgmultigo' => 'Δέβα!',
@@ -646,7 +858,9 @@
 'table_pager_limit_submit' => 'Δέβα',
 
 # Watchlist editing tools
+'watchlisttools-view' => 'Τερέστεν σοβαρά αλλαγάς',
 'watchlisttools-edit' => 'Τέρεν κι άλλαξον κατάλογον ωρίαγματι',
+'watchlisttools-raw'  => 'Επεξεργαστείτε την πρωτογενή τη λίσταν ωριαγματί',
 
 # Special:Version
 'version' => 'Έκδοση', # Not used as normal message but as header for the special page itself
Index: languages/messages/MessagesBr.php
===================================================================
--- languages/messages/MessagesBr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,9 +6,6 @@
  *
  * @author Fulup
  * @author לערי ריינהארט
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -440,7 +437,7 @@
 'yourrealname'               => 'Anv gwir*',
 'yourlanguage'               => 'Yezh an etrefas&nbsp;',
 'yourvariant'                => 'Adstumm:',
-'yournick'                   => "Sinadur evit ar c'haozeadennoù (gant ~~~)",
+'yournick'                   => "Sinadur evit ar c'haozeadennoù",
 'badsig'                     => 'Direizh eo ho sinadur kriz; gwiriit ho palizennoù HTML.',
 'badsiglength'               => "Sinadur re hir.
 Dre ret e rank bezañ nebeutoc'h eget {{PLURAL:$1|arouezenn|arouezenn}} ennañ.",
@@ -573,10 +570,6 @@
 'blockededitsource'                => "Kavout a reot testenn ho '''kemmoù''' war '''$1''' a-is :",
 'whitelistedittitle'               => 'Ret eo bezañ luget evit skridaozañ',
 'whitelistedittext'                => "Ret eo deoc'h en em $1 evit gallout skridaozañ.",
-'whitelistreadtitle'               => 'Ret eo bezañ luget evit gallout lenn',
-'whitelistreadtext'                => 'Ret eo bezañ [[Special:Userlogin|luget]] evit gallout lenn ar pennadoù',
-'whitelistacctitle'                => "N'hoc'h ket aotreet da grouiñ ur gont",
-'whitelistacctext'                 => 'A-benn gallout krouiñ ur gont war ar Wiki-mañ e rankit bezañ [[Special:Userlogin|luget]] ha kaout an aotreoù rekis',
 'confirmedittitle'                 => "Ret eo kadarnaat e chomlec'h postel a-raok kemmañ pajennoù",
 'confirmedittext'                  => "Rankout a ri bezañ kadarnaet ho chomlec'h postel a-raok gellout degas kemmoù er pajennoù. Skrivit ha kadarnait ho chomlec'h postel en ho [[Special:Preferences|penndibaboù implijer]] mar plij.",
 'nosuchsectiontitle'               => "N'eus ket eus ar rann-mañ",
@@ -588,7 +581,7 @@
 'accmailtext'                      => 'Kaset eo bet ger-tremen « $1 » da $2.',
 'newarticle'                       => '(Nevez)',
 'newarticletext'                   => 'Skrivit amañ testenn ho pennad.',
-'anontalkpagetext'                 => "---- ''Homañ eo ar bajenn gaozeal evit un implijer(ez) dianv n'eus ket c'hoazh krouet kont ebet pe na implij ket anezhi. Setu perak e rankomp ober gant ar chomlec'h IP niverel evit disklêriañ anezhañ/i. Gallout a ra ur chomlec'h a seurt-se bezañ rannet etre meur a implijer(ez). Ma'z oc'h un implijer(ez) dianv ha ma stadit ez eus bet kaset deoc'h kemennadennoù na sellont ket ouzhoc'h, gallout a rit [[Special:Userlogin|krouiñ ur gont pe en em lugañ]] kuit a vagañ muioc'h a gemmesk.",
+'anontalkpagetext'                 => "---- ''Homañ eo ar bajenn gaozeal evit un implijer(ez) dianv n'eus ket c'hoazh krouet kont ebet pe na implij ket anezhi. Setu perak e rankomp ober gant ar chomlec'h IP niverel evit disklêriañ anezhañ/i. Gallout a ra ur chomlec'h a seurt-se bezañ rannet etre meur a implijer(ez). Ma'z oc'h un implijer(ez) dianv ha ma stadit ez eus bet kaset deoc'h kemennadennoù na sellont ket ouzhoc'h, gallout a rit [[Special:UserLogin|krouiñ ur gont pe en em lugañ]] kuit a vagañ muioc'h a gemmesk.",
 'noarticletext'                    => "N'eus evit poent tamm skrid ebet war ar bajenn-mañ, gallout a rit [[Special:Search/{{PAGENAME}}|klask an titl anezhañ]] war pajennoù all pe [{{fullurl:{{FULLPAGENAME}}|action=edit}} kemmañ ar bajenn diouzhtu].",
 'userpage-userdoesnotexist'        => 'N\'eo ket enrollet ar gont "$1". Merkit ma fell deoc\'h krouiñ/kemmañ ar bajenn-mañ.',
 'clearyourcache'                   => "'''Notenn :''' Goude bezañ enrollet ho pajenn e rankot freskaat krubuilh ho merdeer a-bennn gwelet ar c'hemmoù : '''Mozilla / Firefox / Safari : ''' dalc'hit ''Pennlizherenn'' en ur glikañ war ''Adkargañ'', pe pouezañ war ''Ctrl-F5'' pe ''Ctrl-R'' (''Command-R'' war ur Macintosh); '''Konqueror: '''klikañ war ''Adkargañ'' pe pouezañ war ''F5;'' '''Opera:''' riñsañ ar grubuilh e ''Ostilhoù → Penndibaboù;'' '''Internet Explorer:''' derc'hel ''Ctrl'' en ur glikañ war ''Freskaat,'' pe pouezañ war ''Ctrl-F5.''",
@@ -643,7 +636,7 @@
 'edittools'                        => '<!-- Diskouezet e vo an destenn kinniget amañ dindan ar sternioù kemmañ ha kargañ. -->',
 'nocreatetitle'                    => "Strishaet eo bet ar c'hrouiñ pajennoù",
 'nocreatetext'                     => 'Strishaet eo bet an tu da grouiñ pajennoù nevez war {{SITENAME}}.
-Gallout a rit mont war-gil ha degas kemmoù en ur bajenn zo anezhi dija, pe [[Special:Userlogin|en em enrollañ ha krouiñ ur gont]].',
+Gallout a rit mont war-gil ha degas kemmoù en ur bajenn zo anezhi dija, pe [[Special:UserLogin|en em enrollañ ha krouiñ ur gont]].',
 'nocreate-loggedin'                => "N'oc'h ket aotreet da grouiñ pajennoù nevez war {{SITENAME}}.",
 'permissionserrors'                => 'Fazioù Aotre',
 'permissionserrorstext'            => "N'oc'h ket aotreet d'ober kement-mañ evit {{PLURAL:$1|an abeg-mañ|an abegoù-mañ}} :",
@@ -763,7 +756,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Marilh diverkañ',
-'suppressionlogtext' => 'A-is emañ roll an diverkadennoù hag ar stankadennoù diwezhañ enno an adweladennoù kuzhet ouzh ar verourien. Gwelet [[Special:Ipblocklist|roll an IPoù stanket]] evit kaout roll ar stankadennoù ha forbannadennoù e talvoud evit poent.',
+'suppressionlogtext' => 'A-is emañ roll an diverkadennoù hag ar stankadennoù diwezhañ enno an adweladennoù kuzhet ouzh ar verourien. Gwelet [[Special:IPBlockList|roll an IPoù stanket]] evit kaout roll ar stankadennoù ha forbannadennoù e talvoud evit poent.',
 
 # History merging
 'mergehistory'                     => 'Kendeuziñ istor ur bajenn',
@@ -846,7 +839,7 @@
 'mypreferences'            => 'penndibaboù',
 'prefs-edits'              => 'Niver a gemmoù :',
 'prefsnologin'             => 'Diluget',
-'prefsnologintext'         => "ret eo deoc'h bezañ [[Special:Userlogin|luget]] evit kemm ho tibaboù implijer.",
+'prefsnologintext'         => "ret eo deoc'h bezañ [[Special:UserLogin|luget]] evit kemm ho tibaboù implijer.",
 'prefsreset'               => 'Adlakaet eo bet ar penndibaboù diouzh ar stumm bet enrollet.',
 'qbsettings'               => 'Personelaat ar varrenn ostilhoù',
 'qbsettings-none'          => 'Hini ebet',
@@ -920,7 +913,7 @@
 'userrights-reason'           => 'Abeg kemmañ :',
 'userrights-no-interwiki'     => "N'oc'h ket aotreet da gemmañ ar gwirioù implijer war wikioù all.",
 'userrights-nodatabase'       => "N'eus ket eus an diaz titouroù $1 pe n'eo ket lec'hel.",
-'userrights-nologin'          => "Ret eo deoc'h [[Special:Userlogin|bezañ enrollet]] gant ur gont merour a-benn reiñ gwirioù implijer.",
+'userrights-nologin'          => "Ret eo deoc'h [[Special:UserLogin|bezañ enrollet]] gant ur gont merour a-benn reiñ gwirioù implijer.",
 'userrights-notallowed'       => "N'eo ket aotreet ho kont da reiñ gwirioù implijer.",
 'userrights-changeable-col'   => "Ar strolladoù a c'hallit cheñch",
 'userrights-unchangeable-col' => "Ar strolladoù n'hallit ket cheñch",
@@ -1016,12 +1009,12 @@
 'reupload'                    => 'Eilañ adarre',
 'reuploaddesc'                => "Distreiñ d'ar furmskrid.",
 'uploadnologin'               => 'diluget',
-'uploadnologintext'           => "ret eo deoc'h bezañ [[Special:Userlogin|luget]]
+'uploadnologintext'           => "ret eo deoc'h bezañ [[Special:UserLogin|luget]]
 evit eilañ restroù war ar servijer.",
 'upload_directory_read_only'  => "N'hall ket ar servijer skrivañ e renkell ar c'hargadennoù ($1).",
 'uploaderror'                 => 'Fazi',
 'uploadtext'                  => "Grit gant ar furmskrid a-is evit enporzhiañ skeudennoù.
-Evit sellet pe klask skeudennoù bet enporzhiet a-raok sellit ouzh [[Special:Imagelist|roll ar skeudennoù eilet war ar servijer]]. Kavet e vo ar skeudennoù enporzhiet pe diverket war [[Special:Log/upload|marilh ar pajennoù enporzhiet]] ivez.
+Evit sellet pe klask skeudennoù bet enporzhiet a-raok sellit ouzh [[Special:ImageList|roll ar skeudennoù eilet war ar servijer]]. Kavet e vo ar skeudennoù enporzhiet pe diverket war [[Special:Log/upload|marilh ar pajennoù enporzhiet]] ivez.
 
 Evit enklozañ ar skeudenn en ur pennad, lakait er pennad-se ul liamm skrivet evel-henn :
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:anv_ar_restr.jpg]]</nowiki>''' pe
@@ -1120,7 +1113,7 @@
 'upload_source_url'  => " (Un URL reizh a c'hall bezañ tizhet gant an holl)",
 'upload_source_file' => " (ur restr war hoc'h urzhiataer)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Diskouez a ra ar bajenn zibar-mañ an holl restroù bet enporzhiet.
 Dre ziouer e teu ar restroù enporzhiet da ziwezhañ e laez ar roll.
 Klikañ war penn ar bann a cheñch an urzh kinnig.',
@@ -1162,18 +1155,18 @@
 # File reversion
 'filerevert'                => 'Disteuler $1',
 'filerevert-legend'         => 'Disteuler ar restr',
-'filerevert-intro'          => "<span class=\"plainlinks\">Emaoc'h o tistreiñ '''[[Media:\$1|\$1]]''' d'ar [stumm \$4 eus \$3, \$2].</span>",
+'filerevert-intro'          => "Emaoc'h o tistreiñ '''[[Media:$1|$1]]''' d'ar [stumm $4 eus $3, $2].",
 'filerevert-comment'        => 'Notenn :',
 'filerevert-defaultcomment' => 'Distroet da stumm $2, $1',
 'filerevert-submit'         => 'Disteuler',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'Distroet eo bet [[Media:$1|$1]]\'\'\' da [stumm $4 an $3, $2].</span>',
+'filerevert-success'        => "'''Distroet eo bet [[Media:$1|$1]]''' da [stumm $4 an $3, $2].",
 'filerevert-badversion'     => "N'eus stumm lec'hel kent ebet eus ar restr-mañ d'ar mare spisaet.",
 
 # File deletion
 'filedelete'                  => 'Diverkañ $1',
 'filedelete-legend'           => 'Diverkañ ar restr',
 'filedelete-intro'            => "O tiverkañ '''[[Media:$1|$1]]''' emaoc'h.",
-'filedelete-intro-old'        => '<span class="plainlinks">Emaoc\'h o tiverkañ stumm \'\'\'[[Media:$1|$1]]\'\'\' eus [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Emaoc'h o tiverkañ stumm '''[[Media:$1|$1]]''' eus [$4 $3, $2].",
 'filedelete-comment'          => 'Notenn :',
 'filedelete-submit'           => 'Diverkañ',
 'filedelete-success'          => "Diverket eo bet '''$1'''.",
@@ -1228,7 +1221,7 @@
 Sed a ra e-tro '''\$5''' kemm dre bajenn ha '''\$6''' selladenn evit pep kemm.
 
 Hirder al [http://www.mediawiki.org/wiki/Manual:Job_queue lostennad labour] zo par da '''\$7'''.",
-'userstatstext'          => "{{PLURAL:$1|'''1''' [[Special:Listusers|implijer]] enrollet|'''$1''' [[Special:Listusers|implijer]] enrollet}} zo; en o zouez ez eus '''$2''' (pe '''$4%''') {{PLURAL:$2|gant|gant}} gwirioù $5.",
+'userstatstext'          => "{{PLURAL:$1|'''1''' [[Special:ListUsers|implijer]] enrollet|'''$1''' [[Special:ListUsers|implijer]] enrollet}} zo; en o zouez ez eus '''$2''' (pe '''$4%''') {{PLURAL:$2|gant|gant}} gwirioù $5.",
 'statistics-mostpopular' => 'Pajennoù muiañ sellet',
 
 'disambiguations'      => 'Pajennoù digejañ',
@@ -1321,7 +1314,7 @@
 'logempty'             => 'Goullo eo istor ar bajenn-mañ.',
 'log-title-wildcard'   => 'Klask an titloù a grog gant an destenn-mañ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'An holl bajennoù',
 'alphaindexline'    => '$1 da $2',
 'nextpage'          => "Pajenn war-lerc'h ($1)",
@@ -1343,12 +1336,12 @@
 'special-categories-sort-count' => 'Urzhiañ dre gont',
 'special-categories-sort-abc'   => 'urzh al lizherenneg',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Diskouez anv an implijerien adal :',
 'listusers-submit'   => 'Diskouez',
 'listusers-noresult' => "N'eus bet kavet implijer ebet.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Gwirioù ar strolladoù implijer',
 'listgrouprights-summary'  => 'War ar bajenn-mañ ez eus ur roll eus ar strolladoù implijer termenet war ar wiki-mañ, gant ar gwirioù moned stag outo.',
 'listgrouprights-group'    => 'Strollad',
@@ -1358,7 +1351,7 @@
 
 # E-mail user
 'mailnologin'     => "Chomlec'h ebet",
-'mailnologintext' => "Ret eo deoc'h bezañ [[Special:Userlogin|luget]]
+'mailnologintext' => "Ret eo deoc'h bezañ [[Special:UserLogin|luget]]
 ha bezañ merket ur chomlec'h postel reizh en ho [[Special:Preferences|penndibaboù]]
 evit gallout kas ur postel d'un implijer all.",
 'emailuser'       => "Kas ur postel d'an implijer-mañ",
@@ -1386,11 +1379,11 @@
 'nowatchlist'          => "N'eus pennad ebet en ho rollad evezhiañ.",
 'watchlistanontext'    => "Ret eo deoc'h $1 evit gwelet pe kemmañ an elfennoù zo en ho rollad evezhiañ.",
 'watchnologin'         => 'Diluget',
-'watchnologintext'     => "Ret eo deoc'h bezañ [[Special:Userlogin|luget]]
+'watchnologintext'     => "Ret eo deoc'h bezañ [[Special:UserLogin|luget]]
 evit kemmañ ho roll.",
 'addedwatch'           => "Ouzhpennet d'ar roll",
 'addedwatchtext'       => 'Ouzh ho [[Special:Watchlist|rollad evezhiañ]] eo bet ouzhpennet ar bajenn "[[:$1]]".
-Kemmoù da zont ar bajenn-mañ ha re ar bajenn gaozeal stag outi a vo rollet amañ hag e teuio ar bajenn <b>e tev</b> er [[Special:Recentchanges|roll kemmoù diwezhañ]] evit bezañ gwelet aesoc\'h ganeoc\'h.
+Kemmoù da zont ar bajenn-mañ ha re ar bajenn gaozeal stag outi a vo rollet amañ hag e teuio ar bajenn <b>e tev</b> er [[Special:RecentChanges|roll kemmoù diwezhañ]] evit bezañ gwelet aesoc\'h ganeoc\'h.
 
 Evit tennañ ar bajenn-mañ a-ziwar ho rollad evezhiañ. klikit war "Paouez da evezhiañ" er framm merdeiñ.',
 'removedwatch'         => 'Lamet a-ziwar ar rollad evezhiañ',
@@ -1503,7 +1496,7 @@
 Nullet eo bet an ober-mañ a-benn en em wareziñ diouzh an tagadennoù preizhañ.
 Klikit war "kent" hag adkargit ar bajenn oc\'h deuet drezi; goude klaskit en-dro.',
 'protectlogpage'              => 'Log_gwareziñ',
-'protectlogtext'              => 'Kavit a-is ur roll pajennoù gwarezet ha diwarezet. Sellet ouzh ar [[Special:Protectedpages|roll ar pajennoù gwarezet]] evit kaout roll ar pajennoù gwarezet bremañ.',
+'protectlogtext'              => 'Kavit a-is ur roll pajennoù gwarezet ha diwarezet. Sellet ouzh ar [[Special:ProtectedPages|roll ar pajennoù gwarezet]] evit kaout roll ar pajennoù gwarezet bremañ.',
 'protectedarticle'            => 'en/he deus gwarezet [[$1]]',
 'modifiedarticleprotection'   => 'Kemmañ live gwareziñ "[[$1]]"',
 'unprotectedarticle'          => 'en/he deus diwarezet [[$1]]',
@@ -1660,7 +1653,7 @@
 'badipaddress'                => "Kamm eo ar chomlec'h IP.",
 'blockipsuccesssub'           => 'Stankadenn deuet da benn vat',
 'blockipsuccesstext'          => 'Stanket eo bet chomlec\'h IP "$1".
-<br />Gallout a rit sellet ouzh ar [[Special:Ipblocklist|bajenn-mañ]] evit gwelet roll ar chomlec\'hioù IP stanket.',
+<br />Gallout a rit sellet ouzh ar [[Special:IPBlockList|bajenn-mañ]] evit gwelet roll ar chomlec\'hioù IP stanket.',
 'ipb-edit-dropdown'           => 'Kemmañ an abegoù stankañ',
 'ipb-unblock-addr'            => 'Distankañ $1',
 'ipb-unblock'                 => "Distankañ un implijer pe ur chomlec'h IP",
@@ -1690,7 +1683,7 @@
 'autoblocker'                 => 'Emstanket rak rannañ a rit ur chomlec\'h IP gant "$1". Abeg : "$2".',
 'blocklogpage'                => 'Log stankañ',
 'blocklogentry'               => 'stanket "[[$1]]" e-pad $2 $3',
-'blocklogtext'                => "Setu roud stankadennoù ha distankadennoù an implijerien. N'eo ket bet rollet ar chomlec'hioù IP bet stanket outo ent emgefre. Sellet ouzh [[Special:Ipblocklist|roll an implijerien stanket]] evit gwelet piv zo stanket e gwirionez.",
+'blocklogtext'                => "Setu roud stankadennoù ha distankadennoù an implijerien. N'eo ket bet rollet ar chomlec'hioù IP bet stanket outo ent emgefre. Sellet ouzh [[Special:IPBlockList|roll an implijerien stanket]] evit gwelet piv zo stanket e gwirionez.",
 'unblocklogentry'             => 'distanket "$1"',
 'block-log-flags-anononly'    => 'implijerien dizanv hepken',
 'block-log-flags-nocreate'    => 'berzet eo krouiñ kontoù',
@@ -1748,8 +1741,6 @@
 
 En degouezh-se e rankot adenvel pe gendeuziñ ar bajenn c'hwi hoc'h-unan ma karit.",
 'movearticle'             => "Dilec'hiañ ar pennad",
-'movenologin'             => 'Diluget',
-'movenologintext'         => 'Evit adenvel ur pennad e rankit bezañ [[Special:Userlogin|luget]] evel un implijer enrollet.',
 'movenotallowed'          => "N'oc'h ket aotreet da zilec'hiañ pajennoù war {{SITENAME}}.",
 'newtitle'                => 'anv nevez',
 'move-watch'              => 'Evezhiañ ar bajenn-mañ',
@@ -1771,7 +1762,7 @@
 'delete_and_move'         => 'Diverkañ ha sevel adkas',
 'delete_and_move_text'    => "==Ezhomm diverkañ==
 
-Savet eo ar pennad tal \"[[\$1]]\" c'hoazh.
+Savet eo ar pennad tal \"[[:\$1]]\" c'hoazh.
 Diverkañ anezhañ a fell deoc'h ober evit reiñ lec'h d'an adkas ?",
 'delete_and_move_confirm' => 'Ya, diverkañ ar bajenn',
 'delete_and_move_reason'  => "Diverket evit ober lec'h d'an adkas",
@@ -2000,10 +1991,10 @@
 'show-big-image'       => 'Pizhder leun',
 'show-big-image-thumb' => '<small>Ment ar rakweladenn-mañ : $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Roll ar skeudennoù nevez',
 'imagelisttext'         => 'Setu ur roll $1 skeudenn rummet $2.',
-'newimages-summary'     => 'Diskouez a ra ar bajenn zibar-mañ roll ar restroù diwezhañ bet enporzhiet',
+'newimages-summary'     => 'Diskouez a ra ar bajenn zibar-mañ roll ar restroù diwezhañ bet enporzhiet.',
 'showhidebots'          => '($1 bot)',
 'noimages'              => 'Netra da welet.',
 'ilsubmit'              => 'Klask',
@@ -2282,7 +2273,7 @@
 
 # External editor support
 'edit-externally'      => 'Kemmañ ar restr-mañ dre un arload diavaez',
-'edit-externally-help' => "Gwelet skoazell an [http://meta.wikimedia.org/wiki/Help:External_editors arloadoù diavaez] a-benn gouzout hiroc'h.",
+'edit-externally-help' => "Gwelet skoazell an [http://www.mediawiki.org/wiki/Manual:External_editors arloadoù diavaez] a-benn gouzout hiroc'h.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'an holl',
@@ -2350,7 +2341,7 @@
 'recreate'            => 'Adkrouiñ',
 
 # HTML dump
-'redirectingto' => "Oc'h adkas da [[$1]]...",
+'redirectingto' => "Oc'h adkas da [[:$1]]...",
 
 # action=purge
 'confirm_purge'        => 'Spurjañ krubuilh ar bajenn-mañ?
@@ -2462,7 +2453,7 @@
 'version-software-product'         => 'Produ',
 'version-software-version'         => 'Stumm',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Hent moned ur restr',
 'filepath-page'    => 'Restr :',
 'filepath-submit'  => 'Hent moned',
Index: languages/messages/MessagesGan.php
===================================================================
--- languages/messages/MessagesGan.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGan.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,9 +6,6 @@
  *
  * @author Symane
  * @author Vipuser
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $fallback = 'zh-hant';
@@ -284,7 +281,7 @@
 'nosuchspecialpage' => '冇有箇隻特殊頁',
 'nospecialpagetext' => "<big>'''倷要求嗰特殊頁冇有用。'''</big>
 
-[[Special:Specialpages]]上尋得到用得上嗰特殊頁。",
+[[Special:SpecialPages]]上尋得到用得上嗰特殊頁。",
 
 # General errors
 'error'                => '錯誤',
@@ -493,10 +490,6 @@
 'blockededitsource'         => "底下係倷對'''$1'''嗰'''編輯'''內容:",
 'whitelistedittitle'        => '登入後才編得正',
 'whitelistedittext'         => '起先倷要$1才編得正箇頁。',
-'whitelistreadtitle'        => '登入後才眵得正',
-'whitelistreadtext'         => '起先倷要[[Special:Userlogin|登入]] 才眵得正箇頁。',
-'whitelistacctitle'         => '倷伓可以開帳戶',
-'whitelistacctext'          => '到箇隻{{SITENAME}}站點開帳戶嗰時間倷起首要[[Special:Userlogin|登入]]同到提供有關許可。',
 'confirmedittitle'          => 'email確認後才編得正',
 'confirmedittext'           => '確認嘞email才能編寫箇頁。麻煩用[[Special:Preferences|參數設置]]設置同確認倷嗰email。',
 'nosuchsectiontitle'        => '冇箇隻段落',
@@ -508,7 +501,7 @@
 'accmailtext'               => "'$1'嗰密碼發到$2嘞。",
 'newarticle'                => '(新)',
 'newarticletext'            => '倷連到嗰頁面伓存在。要新開箇隻頁面，倷能到下底嗰方框編寫內容（細節請望[[Help:説明|説明]]）。要係倷伓係特試來到箇首，按吖瀏覽器嗰“返回”即可。',
-'anontalkpagetext'          => "---- ''箇係匿名用戶嗰討論頁，話伓定佢哈冇開隻帳戶。別人單用得正IP地址同佢聯繫。箇隻IP地址可能有好幾隻用戶共用。如果倷係匿名用戶，覺得箇頁嗰內容同倷冇關，歡迎去[[Special:Userlogin|開隻新帳戶或登入]]，省得同別嗰匿名用戶扤混來。''",
+'anontalkpagetext'          => "---- ''箇係匿名用戶嗰討論頁，話伓定佢哈冇開隻帳戶。別人單用得正IP地址同佢聯繫。箇隻IP地址可能有好幾隻用戶共用。如果倷係匿名用戶，覺得箇頁嗰內容同倷冇關，歡迎去[[Special:UserLogin|開隻新帳戶或登入]]，省得同別嗰匿名用戶扤混來。''",
 'noarticletext'             => '眼下箇頁哈冇內容，倷可以到別嗰頁面[[Special:Search/{{PAGENAME}}|尋吖箇頁嗰標題]]或[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} 編寫箇頁]。',
 'clearyourcache'            => "'''注意:''' 保存之後, 倷要清吥瀏覽器嗰緩存才眵得正改嗰內容。 '''Mozilla / Firefox / Safari:''' 按到 ''Shift'' 接到按''刷新''(或按吖''Ctrl-Shift-R''，到蘋果Mac上按''Cmd-Shift-R'')；'''IE:''' 按到 ''Ctrl''接到按''刷新''，或按吖''Ctrl-F5''；'''Konqueror:''' 單只要按 ''刷新''；'''Opera:''' 用戶要到 ''工具-設置'' 完全嗰清除緩存。",
 'usercssjsyoucanpreview'    => "<strong>提示:</strong> 存到前請用'望吖起'來測吖倷嗰新CSS/JS 。",
@@ -563,7 +556,7 @@
 'template-semiprotected'    => '(半保護)',
 'edittools'                 => '<!--箇首嗰文本會到下底嗰編輯同上傳列表裡坨顯示。 -->',
 'nocreatetitle'             => '新建頁面拕限制',
-'nocreatetext'              => '箇隻網站限制新建頁面嗰功能。倷可以回頭去編輯有嘞嗰頁面，或者[[Special:Userlogin|登入或新開帳戶]]。',
+'nocreatetext'              => '箇隻網站限制新建頁面嗰功能。倷可以回頭去編輯有嘞嗰頁面，或者[[Special:UserLogin|登入或新開帳戶]]。',
 'nocreate-loggedin'         => '倷到 {{SITENAME}} 冇權新開頁面。',
 'permissionserrors'         => '許可權錯誤',
 'permissionserrorstext'     => '根據底下嗰{{PLURAL:$1|原因|原因}}，倷冇許可權去扤:',
@@ -694,7 +687,7 @@
 'mypreferences'            => '偶嗰參數設置',
 'prefs-edits'              => '編輯數:',
 'prefsnologin'             => '哈冇登入',
-'prefsnologintext'         => '倷要[[Special:Userlogin|登入]]後才設得正個人參數。',
+'prefsnologintext'         => '倷要[[Special:UserLogin|登入]]後才設得正個人參數。',
 'prefsreset'               => '參數已經拕重新設過。',
 'qbsettings'               => '快捷導航條',
 'qbsettings-none'          => '冇',
@@ -826,11 +819,11 @@
 'reupload'                    => '上傳過',
 'reuploaddesc'                => '返回上傳列表。',
 'uploadnologin'               => '冇登入',
-'uploadnologintext'           => '倷要[[Special:Userlogin|登入]]再上傳得正檔案。',
+'uploadnologintext'           => '倷要[[Special:UserLogin|登入]]再上傳得正檔案。',
 'upload_directory_read_only'  => '上傳目錄($1)伓存在或冇寫入許可權。',
 'uploaderror'                 => '上傳出錯',
 'uploadtext'                  => "用下底嗰表格上傳檔案。
-要眵或要尋先前上傳嗰圖像請去[[Special:Imagelist|圖像列表]]，上傳同刪除會記到[[Special:Log/upload|上傳日誌]]裡度。
+要眵或要尋先前上傳嗰圖像請去[[Special:ImageList|圖像列表]]，上傳同刪除會記到[[Special:Log/upload|上傳日誌]]裡度。
 
 要係想扻文件到頁面，用得正下底嗰方式連結:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -904,7 +897,7 @@
 'upload_source_url'  => '(一隻有效嗰，公開嗰 URL)',
 'upload_source_file' => '(倷電腦嗰一隻檔案)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => '按媒體名字尋:',
 'imgfile'               => '檔案',
 'imagelist'             => '檔案列表',
@@ -939,18 +932,18 @@
 # File reversion
 'filerevert'                => '恢復$1',
 'filerevert-legend'         => '恢復檔案',
-'filerevert-intro'          => '<span class="plainlinks">眼下倷在恢復\'\'\'[[Media:$1|$1]]\'\'\'到[$4 於$2 $3嗰版本]。</span>',
+'filerevert-intro'          => "眼下倷在恢復'''[[Media:$1|$1]]'''到[$4 於$2 $3嗰版本]。",
 'filerevert-comment'        => '說明:',
 'filerevert-defaultcomment' => '恢復到嘞$1, $2嗰版本',
 'filerevert-submit'         => '恢復',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'恢復到嘞[$4 於$2 $3嗰版本]。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''恢復到嘞[$4 於$2 $3嗰版本]。",
 'filerevert-badversion'     => '箇隻檔案所提供嗰時間標記並冇早先嗰本地版本。',
 
 # File deletion
 'filedelete'                  => '刪吥 $1',
 'filedelete-legend'           => '刪吥檔案',
 'filedelete-intro'            => "倷正刪吥'''[[Media:$1|$1]]'''。",
-'filedelete-intro-old'        => '<span class="plainlinks">倷正刪吥\'\'\'[[Media:$1|$1]]\'\'\'到[$4 $2 $3]嗰版本。</span>',
+'filedelete-intro-old'        => "倷正刪吥'''[[Media:$1|$1]]'''到[$4 $2 $3]嗰版本。",
 'filedelete-comment'          => '說明:',
 'filedelete-submit'           => '刪吥',
 'filedelete-success'          => "'''$1'''刪吥嘞。",
@@ -1003,7 +996,7 @@
 平均每頁有'''$5'''道瀏覽，同到'''$6'''回編輯。
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] 嗰長度係'''$7'''。",
-'userstatstext'          => "網站有'''$1'''隻註冊[[Special:Listusers|用戶]]，其中 '''$2''' (或 '''$4%''') 有$5許可權。",
+'userstatstext'          => "網站有'''$1'''隻註冊[[Special:ListUsers|用戶]]，其中 '''$2''' (或 '''$4%''') 有$5許可權。",
 'statistics-mostpopular' => '眵嗰人最多嗰頁面',
 
 'disambiguations'      => '扤清楚頁',
@@ -1088,7 +1081,7 @@
 'logempty'             => '日誌中冇符合嗰項目。',
 'log-title-wildcard'   => '尋吖箇隻字開頭嗰標題',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '所有嗰頁面',
 'alphaindexline'    => '$1到$2',
 'nextpage'          => '下頁($1)',
@@ -1108,14 +1101,14 @@
 'categories'         => '頁面分類',
 'categoriespagetext' => '下底嗰分類包到頁面或係媒體文件。',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '顯示噉樣用戶條件:',
 'listusers-submit'   => '顯示',
 'listusers-noresult' => '尋伓到用戶。',
 
 # E-mail user
 'mailnologin'     => '冇email地址',
-'mailnologintext' => '倷要[[Special:Userlogin|登入]] 起同到倷嗰[[Special:Preferences|參數設置]] 有隻有效嗰email才發得正email到別嗰用戶。',
+'mailnologintext' => '倷要[[Special:UserLogin|登入]] 起同到倷嗰[[Special:Preferences|參數設置]] 有隻有效嗰email才發得正email到別嗰用戶。',
 'emailuser'       => '發email到箇隻用戶',
 'emailpage'       => '發email到用戶',
 'emailpagetext'   => '要係箇隻用戶到佢嗰參數設置頁填哩有效嗰email位置，下底嗰表格會寄隻信息到箇隻用戶。
@@ -1141,9 +1134,9 @@
 'nowatchlist'          => '倷嗰監視列表什哩都冇有。',
 'watchlistanontext'    => '請$1眵吖或改吖倷嗰監視列表。',
 'watchnologin'         => '冇登入',
-'watchnologintext'     => '倷要[[Special:Userlogin|登入]]起才改得正倷嗰監視列表。',
+'watchnologintext'     => '倷要[[Special:UserLogin|登入]]起才改得正倷嗰監視列表。',
 'addedwatch'           => '加到嘞監視列表',
-'addedwatchtext'       => "頁面\"[[:\$1]]\" 加到嘞倷嗰[[Special:Watchlist|監視列表]]。箇頁同佢嗰討論頁嗰全部改動以後都會列到許首，佢會用'''粗體''' 列到[[Special:Recentchanges|最近更改]]讓倷更加容易識別。 倷以後要係拿佢到監視列表刪卟佢嗰話，就到導航條點吖「莫眏到」。",
+'addedwatchtext'       => "頁面\"[[:\$1]]\" 加到嘞倷嗰[[Special:Watchlist|監視列表]]。箇頁同佢嗰討論頁嗰全部改動以後都會列到許首，佢會用'''粗體''' 列到[[Special:RecentChanges|最近更改]]讓倷更加容易識別。 倷以後要係拿佢到監視列表刪卟佢嗰話，就到導航條點吖「莫眏到」。",
 'removedwatch'         => '莫眏到',
 'removedwatchtext'     => '頁面"<nowiki>$1</nowiki>"到倷嗰監視列表刪卟嘞。',
 'watch'                => '眏到',
@@ -1237,7 +1230,7 @@
 
 請按吖“後退”再試過囉！',
 'protectlogpage'              => '保護日誌',
-'protectlogtext'              => '下底係頁面鎖定同到解除鎖定嗰列表。請望下[[Special:Protectedpages|保護頁面列表]]來監察目前嗰頁面保護情況。',
+'protectlogtext'              => '下底係頁面鎖定同到解除鎖定嗰列表。請望下[[Special:ProtectedPages|保護頁面列表]]來監察目前嗰頁面保護情況。',
 'protectedarticle'            => '保護正嘞“[[$1]] ”',
 'modifiedarticleprotection'   => '改變嘞“[[$1]] ” 嗰保護等級',
 'unprotectedarticle'          => '撤銷保護“[[$1]] ”',
@@ -1379,7 +1372,7 @@
 'ipbhidename'                 => '封鎖日誌、活躍封鎖列表同用戶列表裡頭弆到用戶名',
 'badipaddress'                => 'IP位置伓對。',
 'blockipsuccesssub'           => '封鎖正嘞',
-'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]封卟嘞。 <br />望吖[[Special:Ipblocklist|拕封IP列表]]來審過封鎖。',
+'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]封卟嘞。 <br />望吖[[Special:IPBlockList|拕封IP列表]]來審過封鎖。',
 'ipb-edit-dropdown'           => '編寫封鎖原因',
 'ipb-unblock-addr'            => '解封$1',
 'ipb-unblock'                 => '解封用戶名或IP地址',
@@ -1409,7 +1402,7 @@
 'autoblocker'                 => '倷同"[[$1]]"共用一隻IP，故係倷也拕自動鎖到嘞。$1封鎖嗰緣故係"$2"。',
 'blocklogpage'                => '封鎖日誌',
 'blocklogentry'               => '[[$1]]拕封到$3 ，結束時間到$2',
-'blocklogtext'                => '箇係用戶封鎖同解封操作嗰日誌。拕自動封鎖嗰IP冇列出。請參看[[Special:Ipblocklist|拕封IP地址列表]]。',
+'blocklogtext'                => '箇係用戶封鎖同解封操作嗰日誌。拕自動封鎖嗰IP冇列出。請參看[[Special:IPBlockList|拕封IP地址列表]]。',
 'unblocklogentry'             => '[[$1]] 拕解封嘞',
 'block-log-flags-anononly'    => '單限制匿名用戶',
 'block-log-flags-nocreate'    => '禁止箇隻IP/用戶新開帳戶',
@@ -1464,8 +1457,6 @@
 *倷伓選下底嗰選擇方塊。
 噉倷就非要手工移動或合併頁面。",
 'movearticle'             => '換動頁面:',
-'movenologin'             => '冇登入',
-'movenologintext'         => '倷要係登記用戶接到[[Special:Userlogin|登入]]後才移動得正頁面。',
 'movenotallowed'          => '倷到{{SITENAME}}冇權移動頁面。',
 'newtitle'                => '新標題:',
 'move-watch'              => '眏到箇頁',
@@ -1485,7 +1476,7 @@
 'delete_and_move'         => '刪除跟到移動',
 'delete_and_move_text'    => '==需要刪除==
 
-目標文章"[[$1]]"存在嘞。為到移動佢，倷要刪卟舊頁面？',
+目標文章"[[:$1]]"存在嘞。為到移動佢，倷要刪卟舊頁面？',
 'delete_and_move_confirm' => '係嗰，刪卟箇頁',
 'delete_and_move_reason'  => '為到移動刪卟佢',
 'selfmove'                => '原始標題同目標標題一樣，一隻頁面移伓正到佢自家。',
@@ -1712,7 +1703,7 @@
 'show-big-image'       => '完整解析度',
 'show-big-image-thumb' => '<small>箇幅縮略圖嗰解析度: $1 × $2 像素</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新建圖像畫廊',
 'imagelisttext'         => '底下係按$2排列嗰$1隻檔案列表。',
 'showhidebots'          => '($1機器人)',
@@ -1994,7 +1985,7 @@
 
 # External editor support
 'edit-externally'      => '用外部程式來編輯箇隻檔案',
-'edit-externally-help' => '請參看[http://meta.wikimedia.org/wiki/Help:External_editors 設置步驟]瞭解別嗰內容。',
+'edit-externally-help' => '請參看[http://www.mediawiki.org/wiki/Manual:External_editors 設置步驟]瞭解別嗰內容。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全部',
@@ -2049,7 +2040,7 @@
 'recreate'            => '重建',
 
 # HTML dump
-'redirectingto' => '重定向到[[$1]]...',
+'redirectingto' => '重定向到[[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '想清卟箇頁嗰緩存?
@@ -2139,7 +2130,7 @@
 'version-software'                 => '裝正嗰軟件',
 'version-software-version'         => '版本',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => '文件路徑',
 'filepath-page'   => '文件：',
 'filepath-submit' => '路徑',
Index: languages/messages/MessagesMai.php
===================================================================
--- languages/messages/MessagesMai.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMai.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author Ggajendra
- * @author Siebrand
- * @author SPQRobin
  */
 
 $fallback = 'hi';
@@ -15,10 +13,14 @@
 # User preference toggles
 'tog-underline'           => 'लिंककेँ रेखांकित करू:',
 'tog-highlightbroken'     => 'टूटल श्रृंखला <a href="" class="new">एना देखाऊ</a> (आकि फेर: एना देखाऊ<a href="" class="internal">?</a>).',
+'tog-justify'             => 'सुगढ़ बनाऊ',
 'tog-hideminor'           => 'सन्निकट परिवर्त्तनमे छोट परिवर्त्तन नुकाऊ',
+'tog-extendwatchlist'     => 'ध्यानसूचीमे सभ परिवर्तन देखाऊ',
 'tog-usenewrc'            => 'बढ़ल सन्निकट परिवर्त्तन (जावास्क्रीप्ट)',
+'tog-numberheadings'      => 'शीर्षक स्वयं-क्रमांकित करू',
 'tog-showtoolbar'         => 'संपादन ओजारपेटी देखाऊ (जावास्क्रीप्ट)',
-'tog-editsection'         => '[संपादित करू] श्रृंखक़्ला द्वारा विभाग संपादनक आज्ञा दिअ',
+'tog-editondblclick'      => 'दू बेर क्लीक कए पन्ना संपादित करू (जावास्क्रीप्ट)',
+'tog-editsection'         => '[संपादित करू] श्रृंखला द्वारा विभाग संपादनक आज्ञा दिअ',
 'tog-showtoc'             => 'अनुक्रम देखाऊ (जाहि पृष्ठ पर तीनसँ बेशी विभाग होए)',
 'tog-editwidth'           => 'सँपादन पेटी पूर्ण चौरस देखाऊ',
 'tog-watchdefault'        => 'हमर संपादित पृष्ठ हमर साकांक्ष सूचीमे देखाऊ',
@@ -124,8 +126,9 @@
 'site-atom-feed'  => '$1 अणु फीड',
 
 # Login and logout pages
-'userlogin'  => 'लॉग इन / खेसरा बनाऊ',
-'userlogout' => 'फेर आयब',
+'nav-login-createaccount' => 'सदस्य लॉग इन',
+'userlogin'               => 'लॉग इन / खेसरा बनाऊ',
+'userlogout'              => 'फेर आयब',
 
 # Edit page toolbar
 'bold_sample'     => 'गँहीर लेखन',
@@ -158,6 +161,7 @@
 एतय अहाँ ईहो सप्पत खाइत छी जी ई अहाँक अपन रचना छी आकि अहाँ एकरा कोनो सार्वजनिक डोमेन किंवा ओह्ने कोनो मँगनीक संदर्भ-स्थलसँ कॉपी कएने छी। 
 < दृढ़> सर्वाधिकार सुरक्षित कार्य एतय नहि दी।!</दृढ़>',
 'templatesusedpreview' => 'एहि पूर्वप्रदर्शनमे प्रयुक्त मास्टरफाइल:',
+'template-protected'   => '(सुरक्षित)',
 
 # History pages
 'revisionasof'     => 'अंतिम परिवर्त्तन  $1',
@@ -170,7 +174,8 @@
 'editundo' => 'असंपादन',
 
 # Search results
-'powersearch' => 'त्वरित खोज',
+'noexactmatch' => "'''\"\$1\" नामसँ कोनो लेख नहि अछि।''' अहाँ ई लेख [[:\$1|बना सकैत छी]]।",
+'powersearch'  => 'त्वरित खोज',
 
 # Preferences page
 'preferences'   => 'विकल्प',
@@ -178,7 +183,7 @@
 
 # Recent changes
 'nchanges'        => '$1 {{PLURAL:$1|परिवर्त्तन|परिवर्त्तन}}',
-'rcnote'          => "नीचाँ {{PLURAL:$1|अछि '''1''' परिवर्त्तन|अंतिम अछि '''$1''' परिवर्त्तन}} अंतमे {{PLURAL:$2|दिन|'''$2''' दिन}}, केँ $3.",
+'rcnote'          => "नीचाँ $3 तक पहिलुका {{PLURAL:$2|'''१''' दिनमे भेल|'''$2''' दिनमे भेल}} अंतिम $1 बदलाव {{PLURAL:$1|देल अछि|देल अछि}}।",
 'rcshowhideminor' => '$1 अल्प संपादन',
 'rclinks'         => 'देखाऊ अंतिम $1 परिवर्त्तन अंतिम $2 दिनमे<br />$3',
 'diff'            => 'अंतर',
@@ -189,7 +194,8 @@
 'boteditletter'   => 'ब',
 
 # Recent changes linked
-'recentchangeslinked' => 'संबंधित परिवर्त्तन',
+'recentchangeslinked'       => 'संबंधित परिवर्त्तन',
+'recentchangeslinked-title' => '"$1" मे भेल परिवर्तन',
 
 # Upload
 'upload'        => 'फाइल अपलोड करू',
@@ -210,7 +216,7 @@
 # Special:Log
 'all-logs-page' => 'सभटा लॉग',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 to $2',
 
 # Watchlist
Index: languages/messages/MessagesSah.php
===================================================================
--- languages/messages/MessagesSah.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSah.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Bert Jickty
  * @author HalanTul
- * @author Bert Jickty
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -41,8 +38,8 @@
 'tog-enotifrevealaddr'        => 'Мин почтам аадырыһын биллэриилэргэ көрдөр',
 'tog-shownumberswatching'     => 'Сирэйи кэтээн көрөр дьон ахсаанын көрдөр',
 'tog-fancysig'                => 'Көннөрү илии баттааһын (ыйынньыга суох)',
-'tog-externaleditor'          => 'Атын этиллибэтэҕинэ тас эрэдээктэри туһан',
-'tog-externaldiff'            => 'Атын этиллибэтэҕинэ версиялары тэҥниир тас программаны туһан',
+'tog-externaleditor'          => 'Атын этиллибэтэҕинэ тас эрэдээктэри туһан (билэр дьоҥҥо аналлаах)',
+'tog-externaldiff'            => 'Атын этиллибэтэҕинэ версиялары тэҥниир тас программаны туһан (билэр дьоҥҥо аналлаах)',
 'tog-showjumplinks'           => '"Манна бар" ыйынньыктары көрдөр',
 'tog-uselivepreview'          => 'Тутатына хайдах буоларын көрүү (JavaScript, тургутуу быһыытынан)',
 'tog-forceeditsummary'        => 'Тугу уларыппытым туһунан суруйбатахпына сэрэт',
@@ -254,6 +251,7 @@
 'youhavenewmessagesmulti' => '$1, саҥа суруктар кэллилэр',
 'editsection'             => 'уларыт',
 'editold'                 => 'уларыт',
+'viewsourceold'           => 'исходнигын көрүү',
 'editsectionhint'         => '$1 секцияны уларыт',
 'toc'                     => 'Ис хоһооно',
 'showtoc'                 => 'көрдөр',
@@ -286,7 +284,7 @@
 'nosuchaction'      => 'Маннык дьайыы суох',
 'nosuchactiontext'  => 'Бу URL-га баар дьайыыны биики бырагырааммата кыайан аахпата',
 'nosuchspecialpage' => 'Маннык анал сирэй суох',
-'nospecialpagetext' => 'Аналлаах сирэйи сыыһа көрдөөтүҥ,  [[Special:Specialpages|манна]] аналлаах сирэйдэр испииһэктэрин булуоххун сөп.',
+'nospecialpagetext' => 'Аналлаах сирэйи сыыһа көрдөөтүҥ,  [[Special:SpecialPages|манна]] аналлаах сирэйдэр испииһэктэрин булуоххун сөп.',
 
 # General errors
 'error'                => 'Алҕас',
@@ -310,6 +308,14 @@
 'enterlockreason'      => 'Уларытыыны бобуу төрүөтүн уонна төһө өр бобулларын ый.',
 'readonlytext'         => 'Билии олоҕор билигин саҥа киллэриилэр уонна атын уларытыылар бобуллубуттар, бука былааннаммыт көрүү-истии үлэлэр буолалларыттан.
 Ону боппут сүрүннээччи маннык сурук хаалларбыт: $1',
+'missing-article'      => 'Көрдөөбүт тиэкиһиҥ манна көстүбэтэ: «$1» $2.
+
+Маннык үксүн сотуллубут сирэй историятыгар тиэрдэр эргэрбит сигэнииттэн тахсааччы. 
+
+Атын биричиинэ дии саныыр буоллаххына бырагыраамма сыыһата буолуон сөп.
+Оччоҕо [[Special:ListUsers/sysop|администраатарга]] биллэрэриҥ буоллар (URLын умнаайаҕын).',
+'missingarticle-rev'   => '(#-с торум: $1)',
+'missingarticle-diff'  => '(Уратыта: $1, $2)',
 'readonly_lag'         => 'Билии олоҕун хос сиэрбэрдэрэ сүрүн сиэрбэри кытта мэнэйдэһэр кэмнэригэр билии олоҕо хатанна',
 'internalerror'        => 'Ис алҕас (внутренняя ошибка)',
 'internalerror_info'   => 'Ис алҕас: $1',
@@ -349,12 +355,19 @@
 'titleprotected'       => "Бу бас тыл оҥоһулларын [[User:$1|$1]] боппут.
 Төрүөтэ - ''$2''",
 
+# Virus scanner
+'virus-badscanner'     => 'Сатаммата. Вирус сканера биллибэтэ: <i>$1</i>',
+'virus-scanfailed'     => 'скан сыыһата (куода $1)',
+'virus-unknownscanner' => 'биллибэт антивирус:',
+
 # Login and logout pages
 'logouttitle'                => 'Тахсыы',
-'logouttext'                 => "'''Эн систематтан таҕыстыҥ.''' Билигин ааккынан буолбакка IP-аадырыһынан эрэ көстөҕүн. Аата суох үлэлиэххин сөп, эбэтэр саҥаттан урукку ааккынан дуу, атын аатынан дуу киириэххин сөп. Сорох сирэйдэр өссө даҕаны эйигин ааккынан көрдөрүөхтэрин сөп, ону суох гыныаххын баҕардаххына интэриниэт көрдөрөөччүҥ кээһин ыраастаа.",
+'logouttext'                 => '<strong>Эн систематтан таҕыстыҥ.</strong> 
+
+{{SITENAME}} саайка билигин ааккынан буолбакка IP-аадырыһынан эрэ көстөҕүн. Аата суох үлэлиэххин сөп, эбэтэр саҥаттан урукку ааккынан дуу, атын аатынан дуу [[Special:UserLogin|киириэххин]] сөп. Сорох сирэйдэр өссө даҕаны эйигин ааккынан көрдөрүөхтэрин сөп, ону суох гыныаххын баҕардаххына интэриниэт көрдөрөөччүҥ кээһин ыраастаа.',
 'welcomecreation'            => '== Нөрүөн нөргүй, $1! ==
 Эн манна бэлиэтэнниҥ.
-{{SITENAME}}-ҕа бэйэҥ туруорууларгын уларытаргын умнума.',
+[[Special:Preferences|{{SITENAME}} туруорууларын]] бэйэҕэр сөп түбэһэр гына уларытаргын умнума.',
 'loginpagetitle'             => 'Аатыҥ',
 'yourname'                   => 'Кыттааччы аатыҥ:',
 'yourpassword'               => 'Киирии тыла:',
@@ -365,7 +378,7 @@
 'loginproblem'               => '<span style="color:red">Эн аатыҥ ылыныллыбата.</span> Өссө суруйан көр!',
 'login'                      => 'Киир',
 'nav-login-createaccount'    => 'Киир / бэлиэтэн',
-'loginprompt'                => '{{SITENAME}}-га киирэргэ «cookies» туттары көҥүллээ.',
+'loginprompt'                => '[[Special:UserLogin|{{SITENAME}} саайтыгар киирэргэ ]] «cookies» туттары көҥүллээ.',
 'userlogin'                  => 'Киир / бэлиэтэн',
 'logout'                     => 'Таҕыс',
 'userlogout'                 => 'Таҕыс',
@@ -381,6 +394,7 @@
 'youremail'                  => 'E-mail-ыҥ:',
 'username'                   => 'Бэлиэтэммит аатыҥ:',
 'uid'                        => 'Кыттааччы ID-та:',
+'prefs-memberingroups'       => 'Бу {{PLURAL:$1|бөлөххө|бөлөхтөргө}} киирэр:',
 'yourrealname'               => 'Докумуонунан аатыҥ:',
 'yourlanguage'               => 'Омугуҥ тыла:',
 'yourvariant'                => 'Барыйаан:',
@@ -403,7 +417,8 @@
 'nouserspecified'            => 'Кыттааччы аатын киллэриэхтээххин.',
 'wrongpassword'              => 'Киирии тылыҥ сыыһалаах. Өссө киллэрэн көр.',
 'wrongpasswordempty'         => 'Киирии тылгын суруйбатаххын. Өссө киирэн көр.',
-'passwordtooshort'           => 'Киллэрбит паролуҥ сатаммат бэлиэлэрдээх эбэтэр наһаа кылгас. Кырата $1 бэлиэлээх буолуохтаах уонна кыттааччы аатын кытта биир буолуо суохтаах.',
+'passwordtooshort'           => 'Киирии тылыҥ сатаммат бэлиэлэрдээх эбэтэр наһаа кылгас. 
+Кырата $1 {{PLURAL:$1|1 бэлиэлээх|$1 бэлиэлээх}} буолуохтаах уонна кыттааччы аатын кытта биир буолуо суохтаах.',
 'mailmypassword'             => 'Саҥа киирии тылла ыыттар',
 'passwordremindertitle'      => '{{SITENAME}} киирии тылын санатыы',
 'passwordremindertext'       => 'Ким эрэ (баҕар эн буолуо бу IP-аадырыстан: $1), {{SITENAME}} ($4) киирии тылын саҥаттан ыытыҥ диэбит.
@@ -418,7 +433,8 @@
 онон киирии тылы өйдөтөр кыах эмиэ суох.',
 'eauthentsent'               => 'Быстах кэмҥэ туттуллар киирии тыл саҥа кыттааччы эл. почтатыгар ыытылынна.
 Бу аадырыс эйиэнэ буоларын бигэргэтэргэ өссө тугу гыныахтааҕыҥ туһунан сурукка кэпсэниллэр.',
-'throttled-mailpassword'     => 'Киирии тылы өйдөтөр система бутэһик $1 чаас иһигэр номнуо туттуллубут. Киирии тылы $1 чаас иһигэр биирдэ эрэ ыйытыахха сөп.',
+'throttled-mailpassword'     => 'Киирии тылы өйдөтөр систиэма бүтэһик {{PLURAL:$1|чаас|$1 чаас}} иһигэр туттулла сылдьыбыт. 
+Киирии тылы {{PLURAL:$1|чааска|$1 чааска}} биирдэ эрэ ыйытыахха сөп.',
 'mailerror'                  => 'Сурук ыытарга алҕас таҕыста: $1',
 'acct_creation_throttle_hit' => 'Эн номнуо $1 экаунт оҥорбуккун. Онон өссө оҥорор кыаҕыҥ суох.',
 'emailauthenticated'         => 'Эн почтаҥ аадырыһа бу аакка сурулла сылдьар: $1.',
@@ -472,145 +488,161 @@
 'hr_tip'          => 'Туора сурааһын (наһаа элбэхтик туттума)',
 
 # Edit pages
-'summary'                   => 'Уларытыыҥ ис хоһооно',
-'subject'                   => 'Тиэмэтэ/бас тыла',
-'minoredit'                 => 'Бу суолтата суох уларытыы',
-'watchthis'                 => 'Бу сирэйи кэтээн көрөргө',
-'savearticle'               => 'Уларытыыны бигэргэтии',
-'preview'                   => 'Эрдэ көрүү',
-'showpreview'               => 'Уларытыах иннинэ көрүү',
-'showlivepreview'           => 'Түргэнник эрдэ көрүү',
-'showdiff'                  => 'Уларытыылар',
-'anoneditwarning'           => "'''Болҕой:''' Системаҕа киирбэтэххин. Онон аатыҥ оннугар IP аадаырыһыҥ бу сирэй историятыгар киириэ.",
-'missingsummary'            => "'''Санатыы:''' Уларыппытыҥ кылгас быһаарыытын суруйбатаххын. Уларытыыны бигэргэттэххинэ улартытыыҥ хос быһаарыыта суох барыа.",
-'missingcommenttext'        => 'Манна хос быһаарыыны суруй.',
-'missingcommentheader'      => "'''Санатыы:''' Хос быһаарыы аатын суруйбатаххын. Бигэргэттэххинэ быһаарыыҥ аата суох барыа.",
-'summary-preview'           => 'Хос быһаарыыны көрүү',
-'subject-preview'           => 'Аатын көрүү',
-'blockedtitle'              => 'Кыттааччы уларытар кыаҕа быһылынна',
-'blockedtext'               => "<big>'''Эн аатыҥ эбэтэр IP-аадырыһыҥ бобулуннулар.'''</big>
+'summary'                          => 'Уларытыыҥ ис хоһооно',
+'subject'                          => 'Тиэмэтэ/бас тыла',
+'minoredit'                        => 'Бу суолтата суох уларытыы',
+'watchthis'                        => 'Бу сирэйи кэтээн көрөргө',
+'savearticle'                      => 'Уларытыыны бигэргэтии',
+'preview'                          => 'Эрдэ көрүү',
+'showpreview'                      => 'Уларытыах иннинэ көрүү',
+'showlivepreview'                  => 'Түргэнник эрдэ көрүү',
+'showdiff'                         => 'Уларытыылар',
+'anoneditwarning'                  => "'''Болҕой:''' Системаҕа киирбэтэххин. Онон аатыҥ оннугар IP аадаырыһыҥ бу сирэй историятыгар киириэ.",
+'missingsummary'                   => "'''Санатыы:''' Уларыппытыҥ кылгас быһаарыытын суруйбатаххын. Уларытыыны бигэргэттэххинэ улартытыыҥ хос быһаарыыта суох барыа.",
+'missingcommenttext'               => 'Манна хос быһаарыыны суруй.',
+'missingcommentheader'             => "'''Санатыы:''' Хос быһаарыы аатын суруйбатаххын. Бигэргэттэххинэ быһаарыыҥ аата суох барыа.",
+'summary-preview'                  => 'Хос быһаарыыны көрүү',
+'subject-preview'                  => 'Аатын көрүү',
+'blockedtitle'                     => 'Кыттааччы уларытар кыаҕа быһылынна',
+'blockedtext'                      => "<big>'''Эн аатыҥ эбэтэр IP-аадырыһыҥ бобулуннулар.'''</big>
 
-Администратор $1 бопто. Төрүөтэ: ''«$2»''.
+Боппут киһи $1. 
+Төрүөтэ: ''«$2»''.
 
 *Бобуллубут: $8
-*Бобуу болдьоҕо $6
+*Бобуу болдьоҕо: $6
 *Бобулунна: $7
 
-Эн $1 диэн киһиэхэ эбэтэр атын [[{{MediaWiki:Grouppage-sysop}}|администраторга]] суруйан быһаарсыаххын сөп.
-Болҕой, өскө регистрацияламматах буоллаххына, эбэтэр эл. аадырыскын [[Special:Preferences|манна]] бигэргэппэтэх буоллаххына, эбэтэр сурук суруйарыҥ бобуллубут буоллаҕына администраторга суруйар кыаҕыҥ суох.
-Эн IP-аадырыһыҥ — $3, бобуу идентификатора — #$5. Ону суруккар киллэрээр.",
-'autoblockedtext'           => "Эн IP-аадырыскын ким эрэ бу бырайыакка кыттара бобуллубут киһи туһана сылдьыбыт, онон бу IP-аадырыс бобуулаах. Боппут администратор  ($1) ол төрүөтүн маннык суруйбут:
+Эн $1 диэн киһиэхэ эбэтэр атын [[{{MediaWiki:Grouppage-sysop}}|администраатарга]] суруйан быһаарсыаххын сөп.
+Болҕой, өскө регистрацияламматах буоллаххына, эбэтэр эл. аадырыскын [[Special:Preferences|бигэргэппэтэх]] буоллаххына, эбэтэр сурук суруйарыҥ бобуллубут буоллаҕына администраатарга суруйар кыаҕыҥ суох.
+Эн IP-аадырыһыҥ — $3, бобуу нүөмэрэ — #$5. 
+Ону суруккар киллэрээр.",
+'autoblockedtext'                  => "Эн IP-аадырыскын ханнык эрэ бу бырайыакка кыттара бобуллубут киһи туһана сылдьыбыт, онон бу IP-аадырыс бобуулаах. Боппут администраатар ($1) ол төрүөтүн маннык суруйбут:
 
 :''$2''
 
 *Бобуллубут: $8
 *Бобуу болдьоҕо: $6
+*Бобулунна: $7
 
-Эн $1 диэн киһиэхэ эбэтэр атын [[{{MediaWiki:Grouppage-sysop}}|администраторга]] сурук суруйан быһаарсыаххын сөп.
+Эн $1 диэн киһиэхэ эбэтэр атын [[{{MediaWiki:Grouppage-sysop}}|администраатарга]] сурук суруйан быһаарсыаххын сөп.
 
-Болҕой, өскө регистрацияламматах буоллаххына, эбэтэр эл. аадырыскын [[Special:Preferences|манна]] бигэргэппэтэх буоллаххына, эбэтэр сурук суруйарыҥ бобуллубут буоллаҕына администраторга суруйар кыаҕыҥ суох.
+Болҕой, өскө регистрацияламматах буоллаххына, эбэтэр эл. аадырыскын [[Special:Preferences|бигэргэппэтэх]]  буоллаххына, эбэтэр сурук суруйарыҥ бобуллубут буоллаҕына администраатарга суруйар кыаҕыҥ суох.
 
-Бу бобуу нүөмэрэ — $5. Ону суруккар киллэрээр.",
-'blockednoreason'           => 'биир да биричиинэ сөп түбэспэт',
-'blockedoriginalsource'     => "Манна бу сирэй '''$1''' көрдөрүлүннэ:",
-'blockededitsource'         => "Манна '''$1''' сирэйгэ '''эн уларытыыларыҥ''' көрдөрүлүннулэр:",
-'whitelistedittitle'        => 'Уларытарга киириэххин наада',
-'whitelistedittext'         => 'Улатыаххын баҕарар буоллаххына маны $1 гын.',
-'whitelistreadtitle'        => 'Ааҕарга ааккын ааттаа',
-'whitelistreadtext'         => 'Маны ааҕарга [[Special:Userlogin|бэйэҕин билиһиннэриэххин]] наада.',
-'whitelistacctitle'         => 'Бэйэҕин билиһиннэрэр кыаҕыҥ суох эбит',
-'whitelistacctext'          => 'Бу {{SITENAME}} саайтыгар бэйэҕин билиһиннэриэххин эбэтэр аат иҥэриниэххин баҕарар буоллаххына [[Special:Userlogin|манна]] киирэн бэйэҥ тускунан суруй.',
-'confirmedittitle'          => 'Эл. почтаҥ аадырыһын бигэргэт',
-'confirmedittext'           => 'Уларытарга эл. почтаҥ аадырыһын бигэргэтиэхтээххин. Бастаан [[Special:Preferences|манна]] киирэн бэйэн ааккын уонна эл. почтаҕын суруй. Онтон эл. аадырыскын бигэргэт.',
-'nosuchsectiontitle'        => 'Маннык раздел суох',
-'nosuchsectiontext'         => 'Эн эппит сирэйиҥ суох. $1 диэн сирэй суох буолан, уларытыыгын ханна да эбэр кыах суох.',
-'loginreqtitle'             => 'Бэйэҕин билиһиннэр',
-'loginreqlink'              => 'Ааккын эт',
-'loginreqpagetext'          => 'Атын сирэйдэри көрөргө маны оҥоруохтааххын: $1.',
-'accmailtitle'              => 'Киирии тыл ыытылынна.',
-'accmailtext'               => '"$1" киирии тыла манна $2 ыытылынна.',
-'newarticle'                => '(Саҥа ыстатыйа)',
-'newarticletext'            => 'Эн суох сирэйгэ киирэ сатаатыҥ.
+IP-аадырыһыҥ $3, бобуу нүөмэрэ — #$5. 
+Ону суруккар киллэрээр.",
+'blockednoreason'                  => 'биир да биричиинэ сөп түбэспэт',
+'blockedoriginalsource'            => "Манна бу сирэй '''$1''' көрдөрүлүннэ:",
+'blockededitsource'                => "Манна '''$1''' сирэйгэ '''эн уларытыыларыҥ''' көрдөрүлүннулэр:",
+'whitelistedittitle'               => 'Уларытарга [[Special:UserLogin|киириэххин]] наада',
+'whitelistedittext'                => 'Улатыаххын баҕарар буоллаххына маны $1 гын.',
+'confirmedittitle'                 => 'Эл. почтаҥ аадырыһын бигэргэт',
+'confirmedittext'                  => 'Уларытарга эл. почтаҥ аадырыһын бигэргэтиэхтээххин. Бастаан [[Special:Preferences|манна]] киирэн бэйэн ааккын уонна эл. почтаҕын суруй. Онтон эл. аадырыскын бигэргэт.',
+'nosuchsectiontitle'               => 'Маннык раздел суох',
+'nosuchsectiontext'                => 'Эн эппит сирэйиҥ суох. $1 диэн сирэй суох буолан, уларытыыгын ханна да эбэр кыах суох.',
+'loginreqtitle'                    => 'Бэйэҕин билиһиннэр',
+'loginreqlink'                     => 'Ааккын эт',
+'loginreqpagetext'                 => 'Атын сирэйдэри көрөргө маны оҥоруохтааххын: $1.',
+'accmailtitle'                     => 'Киирии тыл ыытылынна.',
+'accmailtext'                      => '"$1" киирии тыла манна $2 ыытылынна.',
+'newarticle'                       => '(Саҥа ыстатыйа)',
+'newarticletext'                   => 'Эн суох сирэйгэ киирэ сатаатыҥ.
 Маннык ааттаах саҥа ыстатыйаны оҥорор буоллаххына, аллара баар түннүккэ суруй
 (сиһ. [[{{MediaWiki:Helppage}}|көмөнү]] көрүөххүн сөп).
 Өскө манна сыыһа киирбит буоллаххына интэриниэтиҥ бырагыраамматын "төнүн" диэххин сөп.',
-'anontalkpagetext'          => "----''Бу аатын эппэтэх кыттааччы ырытар сирэйэ.
+'anontalkpagetext'                 => "----''Бу аатын эппэтэх кыттааччы ырытар сирэйэ.
 IP-аадырыһа эрэ көстөр.
-Биир IP-аадырыс хас да киһиэхэ бэриллиэн сөп. Өскө атын киһиэхэ суруллубут суругу алҕас туппут буоллаххына, бэйэҥ [[Special:Userlogin|ааккын билиһиннэр]], оччоҕо кэлин да булкуур тахсыа суоҕа.''",
-'noarticletext'             => 'Билигин бу сирэй кураанах. Бу аат атын ыстатыйалга туттулларын [[Special:Search/{{PAGENAME}}|булуоххутун сөп]] эбэтэр маннык ааттаах [{{fullurl:{{FULLPAGENAME}}|action=edit}} саҥа ыстатыйаны суруйуоххутун] сөп.',
-'userpage-userdoesnotexist' => '"$1" аат бэлиэтэммэтэх. Бу сирэйи оҥорор/уларытар баҕалааххын дуо?',
-'clearyourcache'            => "'''Болҕой:''' Уларыппыт сирэйгин сөпкө көрөргө интэриниэт бырагыраамматын кээһин ыраастаа: '''Mozilla / Firefox''': ''Ctrl+Shift+R'', '''IE:''' ''Ctrl+F5'', '''Safari''': ''Cmd+Shift+R'', '''Konqueror''': ''F5'', '''Opera''': ''Tools→Preferences'' меню нөҥүө.",
-'usercssjsyoucanpreview'    => '<strong>Көмө:</strong> Саҥа css- эбэтэр js-билэни тургутуоххун баҕардаххына эрдэ көрөр тимэҕи баттаа.',
-'usercsspreview'            => "'''Умнума: бу CSS тургутуута эрэ, уларыппытыҥ бигэргэтиллэ илик!'''",
-'userjspreview'             => "'''Умнума: бу JavaScript тургутуутэ эрэ, уларыппытыҥ бигэргэтиллэ илик!'''",
-'userinvalidcssjstitle'     => "'''Болҕой:''' Бу тиэмэ «$1» суох. Кыттааччы .css и .js сирэйдэрэ кыра буукубаннан суруллуохтаахтар, холобур «{{ns:user}}:Ньургун/monobook.css», маннык буолуо суохтаах «{{ns:user}}:Ньургун/Monobook.css».",
-'updated'                   => '(Саҥардылынна)',
-'note'                      => '<strong>Хос быһаарыы:</strong>',
-'previewnote'               => '<strong>Бу көрүү эрэ; уларытыылар бигэргэтиллэ иликтэр!</strong>',
-'previewconflict'           => 'Этот предварительный просмотр отражает текст в верхнем окне редактирования так, как он будет выглядеть, если вы решите записать его.',
-'session_fail_preview'      => '<strong>Сиэрбэр сессия идентификаторын сүтэрэн кэбиһэн эн уларытыыгын кыайан киллэрбэтэ.
-Өссө холонон көр. Олох сатамматаҕына биикиттэн тахсан баран өссө киирэн көрөөр.</strong>',
-'session_fail_preview_html' => "<strong>Сессия дааннайдарын сүтэрэн сиэрбэр эн уларытыыгын киллэрбэтэ.</strong>
+Биир IP-аадырыс хас да киһиэхэ бэриллиэн сөп. Өскө атын киһиэхэ суруллубут суругу алҕас туппут буоллаххына, бэйэҥ [[Special:UserLogin/signup|ааккын билиһиннэр]] эбэтэр [[Special:UserLogin|киир]], оччоҕо кэлин да булкуур тахсыа суоҕа.''",
+'noarticletext'                    => 'Билигин бу сирэй кураанах. Бу аат атын ыстатыйалга туттулларын [[Special:Search/{{PAGENAME}}|булуоххутун сөп]] эбэтэр маннык ааттаах [{{fullurl:{{FULLPAGENAME}}|action=edit}} саҥа ыстатыйаны суруйуоххутун] сөп.',
+'userpage-userdoesnotexist'        => '"$1" аат бэлиэтэммэтэх. Бу сирэйи оҥорор/уларытар баҕалааххын дуо?',
+'clearyourcache'                   => "'''Болҕой - Уларыппыт сирэйгин сөпкө көрөргө интэриниэт бырагыраамматын кээһин ыраастаа.''' '''Mozilla / Firefox / Safari:''' ''Shift'' кнопканы тутан туран ''Reload'' баттаа, эбэтэр ''Ctrl-F5'', ''Ctrl-R'' дуу (Macintosh-ка ''Command-R'') баттаа; '''Konqueror: ''' ''Reload'' ''F5'' эбэтэр баттаа;
+'''Opera:''' кээһин ыраастыырга манна ''Tools → Preferences'' киир; '''Internet Explorer:''' ''Ctrl'' тутан туран ''Refresh'' баттаа, эбэтэр ''Ctrl-F5'' баттаа.",
+'usercssjsyoucanpreview'           => '<strong>Көмө:</strong> Саҥа css- эбэтэр js-билэни тургутуоххун баҕардаххына эрдэ көрөр тимэҕи баттаа.',
+'usercsspreview'                   => "'''Умнума: бу CSS тургутуута эрэ, уларыппытыҥ бигэргэтиллэ илик!'''",
+'userjspreview'                    => "'''Умнума: бу JavaScript тургутуутэ эрэ, уларыппытыҥ бигэргэтиллэ илик!'''",
+'userinvalidcssjstitle'            => "'''Болҕой:''' Бу тиэмэ «$1» суох. Кыттааччы .css и .js сирэйдэрэ кыра буукубаннан суруллуохтаахтар, холобур «{{ns:user}}:Ньургун/monobook.css», маннык буолуо суохтаах «{{ns:user}}:Ньургун/Monobook.css».",
+'updated'                          => '(Саҥардылынна)',
+'note'                             => '<strong>Хос быһаарыы:</strong>',
+'previewnote'                      => '<strong>Бу көрүү эрэ; уларытыылар бигэргэтиллэ иликтэр!</strong>',
+'previewconflict'                  => 'Этот предварительный просмотр отражает текст в верхнем окне редактирования так, как он будет выглядеть, если вы решите записать его.',
+'session_fail_preview'             => '<strong>Сиэрбэр сессия идентификаторын сүтэрэн кэбиһэн эн уларытыыгын кыайан киллэрбэтэ.
+Өссө холонон көр. 
+Олох сатамматаҕына биикиттэн [[Special:UserLogout|тахсан]] баран өссө киирэн көрөөр.</strong>',
+'session_fail_preview_html'        => "<strong>Сессия дааннайдарын сүтэрэн кэбиһэн сиэрбэр эн уларытыыгын киллэрбэтэ.</strong>
 
-''Бу {{SITENAME}} саайта ыраас HTML тылы көҥүллүүр буолан JavaScript көмөтүнэн атаака буолун сөп, онон эрдэ көрдөрүү араарыллыбыт.''
+''{{SITENAME}} ыраас HTML тылы көҥүллүүр буолан JavaScript туһананнар куһаҕаны оҥоруохтарын сөп, онон эрдэ көрдөрүү араарыллыбыт.''
 
-<strong>Өскө бу уларытыы туох да куһаҕаны аҕалыа диэбэт буоллаххына өссө биирдэ боруобалаа. Ол сатамматаҕына тахсан баран өссө киирэн көрөөр.</strong>",
-'token_suffix_mismatch'     => '<strong>Эн уларытыыҥ киирбэтэ, тоҕо диэтэххэ эн бырагырааммаҥ сорох сурук бэлиэлэрин сыыһа көрөр эбит.
+<strong>Өскө бу уларытыы туох да куһаҕаны аҕалыа диэбэт буоллаххына өссө биирдэ боруобалаа. Ол сатамматаҕына [[Special:UserLogout|тахсан баран]] өссө киирэн көрөөр.</strong>",
+'token_suffix_mismatch'            => '<strong>Эн уларытыыҥ киирбэтэ, тоҕо диэтэххэ эн бырагырааммаҥ сорох сурук бэлиэлэрин сыыһа көрөр эбит.
 Ыстатыйаны буорту гынымаары уларытыыҥ ылыныллыбата.
 Итинник сыыһалар үксүн прокси-сиэрбэрдэри туһаннахха тахсааччылар.</strong>',
-'editing'                   => 'Уларытыы $1',
-'editingsection'            => 'Уларытыы $1 (раздел)',
-'editingcomment'            => 'Уларытыы $1 (ырытыы)',
-'editconflict'              => 'Уларытыы мөккүөрэ: $1',
-'explainconflict'           => "Ыстатыйаны көннөрө олордоххутуна ким эрэ эмиэ бу ыстатыйаны көннөрбүт.
+'editing'                          => 'Уларытыы $1',
+'editingsection'                   => 'Уларытыы $1 (раздел)',
+'editingcomment'                   => 'Уларытыы $1 (ырытыы)',
+'editconflict'                     => 'Уларытыы мөккүөрэ: $1',
+'explainconflict'                  => "Ыстатыйаны көннөрө олордоххутуна ким эрэ эмиэ бу ыстатыйаны көннөрбүт.
 Үөһээҥи түннүккэ \"Уларытыыны бигэргэт\" тимэҕи баттаатахха киириэхтээх барыл сурулунна.
 Алларааҥы түннүккэ эн барылыҥ көстөр.
 Бэйэҥ уларытыыгын киллэриэххин баҕарар буоллаххына аллараттан үөһээҥи түннүккэ уларытыыларгын көһөр.
 \"Уларытыыны бигэргэт\" баттаатаххына үөһээҥи '''эрэ''' тиэкис хаалыаҕа.",
-'yourtext'                  => 'Тиэкиһиҥ',
-'storedversion'             => 'Суруллубут барыл',
-'nonunicodebrowser'         => '<strong>СЭРЭТИИ: Интэриниэтиҥ бырагырааммата Юникод кодировканы билиммэт эбит. Ыстатыйаны уларытаргар ASCII-тан атын бэлиэлэр шестнадцатиричнай кодка уларытыллыахтара.</strong>',
-'editingold'                => '<strong>СЭРЭТИИ: Эргэрбит барылы көннөрө олороҕун.
+'yourtext'                         => 'Тиэкиһиҥ',
+'storedversion'                    => 'Суруллубут барыл',
+'nonunicodebrowser'                => '<strong>СЭРЭТИИ: Интэриниэтиҥ бырагырааммата Юникод кодировканы билиммэт эбит. Ыстатыйаны уларытаргар ASCII-тан атын бэлиэлэр шестнадцатиричнай кодка уларытыллыахтара.</strong>',
+'editingold'                       => '<strong>СЭРЭТИИ: Эргэрбит барылы көннөрө олороҕун.
 Уларытыыны киллэрдэххинэ кэнники уларытыылар суох буолуохтара.</strong>',
-'yourdiff'                  => 'Уратылар',
-'copyrightwarning'          => 'Болҕой, манна оҥоһуллубут эбиилэр уонна уларытыылар $2 лицензиялаахтар (сиһ. маны көр $1). Өскө эн ыстатыйаларыҥ көҥүл тарҕаналларын уонна туһаныллалларын баҕарбат буоллаххына манна суруйума.<br />
+'yourdiff'                         => 'Уратылар',
+'copyrightwarning'                 => 'Болҕой, манна оҥоһуллубут эбиилэр уонна уларытыылар $2 лицензиялаахтар (сиһ. маны көр $1). Өскө эн ыстатыйаларыҥ көҥүл тарҕаналларын уонна туһаныллалларын баҕарбат буоллаххына манна суруйума.<br />
 Эбиитин манна суруйар матырыйаалгын эбэтэр бэйэҥ суруйуохтааххын, эбэтэр көҥүл туһаныллары уонна көҥүл уларытары көҥүллүүр сиртэн ылбыт буолуохтааххын.
 <strong>КИМ ЭРЭ БАС БИЛЭР МАТЫРЫЙААЛЫН КИНИТТЭН КӨҤҮЛЭ СУОХ МАННА УГУМА!</strong>',
-'copyrightwarning2'         => 'Болҕой, эн суруйбут матырыйаалгын ким баҕарар уларытар уонна суох гынар бырааптаах. Суруйбуккун уларыталларын сөбүлээбэт буоллаххына манна суруйума.<br />
+'copyrightwarning2'                => 'Болҕой, эн суруйбут матырыйаалгын ким баҕарар уларытар уонна суох гынар бырааптаах. Суруйбуккун уларыталларын сөбүлээбэт буоллаххына манна суруйума.<br />
 Эбиитин манна суруйдаххына, уларытыы ааптара мин буолабын, эбэтэр көҥүл туһанары уонна уларытары көҥүллүүр сиртэн ыллым диэн бигэргэтэҕин (маны көр $1).<br /> <strong>КИМ ЭРЭ БАС БИЛИИТИН МАННА КИНИТТЭН КӨҤҮЛЭ СУОХ УГУМА!</strong>',
-'longpagewarning'           => '<strong>СЭРЭТИИ: Бу сирэй ыйааһына $1 килобайт.
+'longpagewarning'                  => '<strong>СЭРЭТИИ: Бу сирэй ыйааһына $1 килобайт.
 Сорох интэриниэт бырагырааммаларыгар 32 КБ ыйааһыҥҥа чугаһыыр сирэйдэр үчүгэйдик көстүбэттэр.
 Онон бука диэн бу сирэйи кыра сирэйдэргэ хайытар туһунан толкуйдааҥ.</strong>',
-'longpageerror'             => '<strong>ERROR: The text you have submitted is $1 kilobytes
+'longpageerror'                    => '<strong>ERROR: The text you have submitted is $1 kilobytes
 long, which is longer than the maximum of $2 kilobytes. It cannot be saved.</strong>
 <strong>АЛҔАС: Суруйар кэрчиккит $1 килобайт ыйааһыннаах, онтуккут көҥүллэммит $2 килобайты куоһарар. Маннык хаалар кыаҕа суох</strong>',
-'readonlywarning'           => '<strong>СЭРЭТИИ: Сиэрбэргэ техническай үлэ бара турар, онон киллэрбит уларытыыларыҥ тута хаалар кыахтара суох.
+'readonlywarning'                  => '<strong>СЭРЭТИИ: Сиэрбэргэ техническай үлэ бара турар, онон киллэрбит уларытыыларыҥ тута хаалар кыахтара суох.
 Билигин уларытыыгын бэйэҥ диискэҕэр хаалларан баран, кэлин манна уган биэриэххин сөп.</strong>',
-'protectedpagewarning'      => '<strong>СЭРЭТИИ:  Бу сирэй хатанан турар, администратордар эрэ уларытар кыахтаахтар.</strong>',
-'semiprotectedpagewarning'  => "'''Биллэрии:''' Бу сирэй хатанан турар, ааттарын билиһиннэрбит эрэ кыттааччылар уларытар кыахтаахтар.",
-'cascadeprotectedwarning'   => "'''Сэрэтии:''' Бу сирэйи \"админстратордар\" бөлөххө киирэр кыттааччылар эрэ уларытар кыахтаахтар, тоҕо диэтэххэ сирэй маннык каскаднай көмүскэллээх сирэйдэр бөлөхтөрүгэр киирэр:",
-'titleprotectedwarning'     => '<strong>СЭРЭТИИ:  Бу сирэйи уларытар бобуллубут, аҕыйах эрэ киһи уларытыан сөп.</strong>',
-'templatesused'             => 'Манна туттуллубут халыыптар:',
-'templatesusedpreview'      => 'Манна туттуллубут халыыптар:',
-'templatesusedsection'      => 'Манна туттуллубут халыыптар:',
-'template-protected'        => '(хатаммыт)',
-'template-semiprotected'    => '(хатаммыт аҥардаах)',
-'edittools'                 => '<!-- Манна суруллубут сурук уларытыы уонна эбии пуормаларын анныгар суруллуо. -->',
-'nocreatetitle'             => 'Сирэй оҥорор хааччахтаммыт',
-'nocreatetext'              => '{{SITENAME}} саайтыгар саҥа сирэйи оҥорор хааччахтанар.
-Баар сирэйи уларытыаххын сөп, эбэтэр [[Special:Userlogin|манна  бэлиэтэниэххин эбэтэр атын аатынан киириэххин сөп]].',
-'nocreate-loggedin'         => 'Эн бу {{SITENAME}} саайтыгар саҥа сирэйи оҥорор кыаҕыҥ өссө суох.',
-'permissionserrors'         => 'Көҥүллээһин моһуогурда',
-'permissionserrorstext'     => 'Маны оҥорор кыаҕыҥ суох, {{PLURAL:$1|төрүтэ|төрүттэрэ}}:',
-'recreate-deleted-warn'     => "'''Болҕой: сотулубут сирэйи төттөрү оҥорон эрэҕин.'''
+'protectedpagewarning'             => '<strong>СЭРЭТИИ:  Бу сирэй хатанан турар, администратордар эрэ уларытар кыахтаахтар.</strong>',
+'semiprotectedpagewarning'         => "'''Биллэрии:''' Бу сирэй хатанан турар, ааттарын билиһиннэрбит эрэ кыттааччылар уларытар кыахтаахтар.",
+'cascadeprotectedwarning'          => "'''Сэрэтии:''' Бу сирэйи \"админстратордар\" бөлөххө киирэр кыттааччылар эрэ уларытар кыахтаахтар, тоҕо диэтэххэ сирэй маннык каскаднай көмүскэллээх сирэйдэр бөлөхтөрүгэр киирэр:",
+'titleprotectedwarning'            => '<strong>СЭРЭТИИ:  Бу сирэйи уларытар бобуллубут, аҕыйах эрэ киһи уларытыан сөп.</strong>',
+'templatesused'                    => 'Манна туттуллубут халыыптар:',
+'templatesusedpreview'             => 'Манна туттуллубут халыыптар:',
+'templatesusedsection'             => 'Манна туттуллубут халыыптар:',
+'template-protected'               => '(хатаммыт)',
+'template-semiprotected'           => '(хатаммыт аҥардаах)',
+'hiddencategories'                 => 'Бу сирэй кистэммит {{PLURAL:$1|1 категорияҕа|$1 категорияларга}} киирэр:',
+'edittools'                        => '<!-- Манна суруллубут сурук уларытыы уонна эбии пуормаларын анныгар суруллуо. -->',
+'nocreatetitle'                    => 'Сирэй оҥорор хааччахтаммыт',
+'nocreatetext'                     => '{{SITENAME}} саайтыгар саҥа сирэйи оҥорор хааччахтанар.
+Баар сирэйи уларытыаххын сөп, эбэтэр [[Special:UserLogin|манна  бэлиэтэниэххин эбэтэр атын аатынан киириэххин сөп]].',
+'nocreate-loggedin'                => 'Эн бу {{SITENAME}} саайтыгар саҥа сирэйи оҥорор кыаҕыҥ өссө суох.',
+'permissionserrors'                => 'Көҥүллээһин моһуогурда',
+'permissionserrorstext'            => 'Маны оҥорор кыаҕыҥ суох, {{PLURAL:$1|төрүтэ|төрүттэрэ}}:',
+'permissionserrorstext-withaction' => 'Бу дьайыыны ($2) оҥорор кыаҕыҥ суох.  {{PLURAL:$1|Биричиинэтэ|Биричиинэлэрэ}}:',
+'recreate-deleted-warn'            => "'''Болҕой: сотулубут сирэйи төттөрү оҥорон эрэҕин.'''
 
 Толкуйдаан баран оҥор. Аллара сотуулар сурунааллара көрдөрүлүннэ.",
 
+# Parser/template warnings
+'expensive-parserfunction-warning'        => 'Болҕой. Бу сирэй наһаа элбэх көмпүүтэри ноҕуруускалыыр ресурсаларга сигэнэр.
+
+Сигэнии ахсаана мантан тахсыа суохтаах - $2, билигин ахсаана - $1.',
+'expensive-parserfunction-category'       => 'Көмпүүтэри ноҕуруускалыыр ресурсаларга наһаа элбэхтик сигэнэр сирэйдэр',
+'post-expand-template-inclusion-warning'  => 'Болҕой: Киллэрэр халыыптарыҥ ыйааһыннара наһаа улахан.
+Онон сорох халыыптар киллэриллиэхтэрэ суоҕа.',
+'post-expand-template-inclusion-category' => 'Киллэриллибит халыыптарын ыйааһына сиэри таһынан барбыт сирэйдэр',
+'post-expand-template-argument-warning'   => 'Болҕой. Бу сирэйгэ баар халыып биир эбэтэр элбэх наһаа улахан ыйааһыннаах толоруллар аргуменнаах эбит.
+Оннук аргуменнар толоруллубатылар.',
+'post-expand-template-argument-category'  => 'Толоруллубатах (көтүтүллүбүт) аргуменнаах сирэйдэр',
+
 # "Undo" feature
 'undo-success' => 'Правка может быть отменена. Пожалуйста, просмотрите сравнение версий, чтобы убедиться, что это именно те изменения, которые вас интересуют, и нажмите «Записать страницу», чтобы изменения вступили в силу.',
 'undo-failure' => 'Уларытыы төннөр кыаҕа суох. Ыккардынааҕы көннөрүүлэр бэйэ бэйэлэригэр сөп түбэспэттэр.',
 'undo-norev'   => 'Бу көннөрүү сотуллар кыаҕа суох, тоҕо диэтэххэ ончу суох эбэтэр номнуо сотуллубут.',
-'undo-summary' => '[[Special:Contributions/$2|$2]] кыттааччы ([[User talk:$2|ырытыы]]) $1 нүөмэрдээх уларытыытын сотон оннугар туһэрэргэ.',
+'undo-summary' => '[[Special:Contributions/$2|$2]] кыттааччы ([[User talk:$2|ырытыы]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]]) $1 нүөмэрдээх уларытыытын сотон оннугар түһэрэргэ.',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Саҥа ааты киллэрэр сатаммат',
@@ -672,12 +704,12 @@
 
 {{SITENAME}} администратордара кистэммит суруктары көрөр уонна сотуллубуту төттөрү төннөрөр кыахтаахтар
 (эбии хааччахтааһын турбатах буоллаҕына).',
-'revdelete-legend'            => 'Хааччахтааһын',
+'revdelete-legend'            => 'Хааччахтары туруоруу:',
 'revdelete-hide-text'         => 'Сирэй бу торумун кистээ',
 'revdelete-hide-name'         => 'Дьайыыны уонна дьайыы сыалын кистээ.',
 'revdelete-hide-comment'      => 'Ырытыыны кистээ',
 'revdelete-hide-user'         => 'Ааппын/IP-бын көрдөрүмэ',
-'revdelete-hide-restricted'   => 'Бу хааччахтааһыны администратордарга эмиэ тутун',
+'revdelete-hide-restricted'   => 'Бу хааччахтааһыннары администраатардарга эмиэ туттарга',
 'revdelete-suppress'          => 'Бу суругу администратордартан эмиэ кистээ',
 'revdelete-hide-image'        => 'Билэ иһин кистээ',
 'revdelete-unsuppress'        => 'Төннөрүллүбүт торумнартан хааччахтааһыны ылан кэбиһэргэ',
@@ -687,11 +719,24 @@
 'logdelete-logentry'          => '[[$1]] дьайыы көстүүтэ уларыйда',
 'revdelete-success'           => "'''Торум көстүүтэ сөпкө уларыйда.'''",
 'logdelete-success'           => "'''Дьайыы көстүүтэ сөпкө уларыйда.'''",
+'revdel-restore'              => 'Көстүүтүн уларытыы',
 'pagehist'                    => 'Историятын сирэйэ',
 'deletedhist'                 => 'Сотуллубут история',
 'revdelete-content'           => 'иһинээҕитэ',
+'revdelete-summary'           => 'уларытыылар туһунан',
 'revdelete-uname'             => 'аата',
+'revdelete-restricted'        => 'хааччахтааһын администраатардарга сыһыаннаах',
+'revdelete-unrestricted'      => 'хааччахтааһын админстраатардартан уһулунна',
+'revdelete-hid'               => 'кистэммит $1',
+'revdelete-unhid'             => 'аһыллыбыт $1',
+'revdelete-log-message'       => '$2 аналлаах $1 {{PLURAL:$2|торум|торумнар}}',
+'logdelete-log-message'       => '$2 аналлаах (сыһыаннаах) $1 {{PLURAL:$2|түбэлтэ|түбэлтэлэр}}',
 
+# Suppression log
+'suppressionlog'     => 'Кистээһин сурунаала',
+'suppressionlogtext' => 'Аллара соторутааҥҥы сотуулар уонна хааччахтааһыннар тиһиктэрэ бэриллэр (администраатардарга көстүбэт сээкэйдэр эмиэ).
+Билигин баар хааччахтар тиһиктэрин көрөргө [[Special:IPBlockList|IP хааччахтааһынын тиһигэр]] киир.',
+
 # History merging
 'mergehistory'                     => 'Силбэһии сирэйин хронологията',
 'mergehistory-header'              => 'Бу сирэй биир ыстатыйа (сирэй) хас да барылын биир саҥа барыл гына оҥорорго аналлаах.
@@ -710,6 +755,8 @@
 'mergehistory-no-destination'      => 'Баар буолуохтаах $1 сирэй суох.',
 'mergehistory-invalid-source'      => 'Источнигыҥ сөптөөх ааттаах буолуохтаах.',
 'mergehistory-invalid-destination' => 'Сирэй сөптөөх ааттаах буолуохтаах.',
+'mergehistory-autocomment'         => '[[:$1]] манна [[:$2]] көһүүтэ (көһөрүү)',
+'mergehistory-comment'             => '[[:$1]] манна [[:$2]] көһүүтэ. Быһаарыы: $3',
 
 # Merge log
 'mergelog'           => 'Силбэһиилэр сурунааллара',
@@ -728,7 +775,7 @@
 # Search results
 'searchresults'             => 'Булулунна',
 'searchresulttext'          => 'Көрдөөһүн туһунан сиһилии ааҕыаххын баҕардаххына [[{{MediaWiki:Helppage}}|маны]] көр.',
-'searchsubtitle'            => 'По запросу «[[:$1]]»',
+'searchsubtitle'            => 'Эн [[:$1]] көмөтүнэн ([[Special:Prefixindex/$1|"$1" саҕаланар сирэйдэри ]] | [[Special:WhatLinksHere/$1|"$1" сигэнэр сирэйдэри]]) көрдөөбүтүҥ',
 'searchsubtitleinvalid'     => 'По запросу «$1»',
 'noexactmatch'              => "'''«\$1» ааттаах сирэй суох.''' <span style=\"display: block; margin: 1.5em 2em\"> [[:\$1|Саҥа сирэйи оҥорорго]]</span>",
 'noexactmatch-nocreate'     => "'''Маннык ааттаах: \"\$1\" сирэй суох.'''",
@@ -741,19 +788,28 @@
 'nextn'                     => 'аныгыскы $1',
 'viewprevnext'              => 'Көр ($1) ($2) ($3).',
 'search-result-size'        => '$1 ({{PLURAL:$2|1 тыл|$2 тыл}})',
+'search-result-score'       => 'Релевантноһа: $1%',
+'search-redirect'           => '(утаарыы $1)',
+'search-section'            => '($1 сиэксийэ)',
+'search-suggest'            => 'Баҕар маннык диэри гыммытыҥ буолуо: $1',
 'search-interwiki-caption'  => 'Уруулуу бырайыактар',
+'search-interwiki-default'  => '$1 түмүгэ:',
+'search-interwiki-more'     => '(өссө)',
 'search-mwsuggest-enabled'  => 'этиилэрдээх',
 'search-mwsuggest-disabled' => 'этиилэрэ суох',
 'search-relatedarticle'     => 'Сигэнэр',
+'mwsuggest-disable'         => 'AJAX этэн биэриилэрин араар',
 'searchrelated'             => 'сибээстэммит',
 'searchall'                 => 'бары',
 'showingresults'            => 'Манна {{PLURAL:$1|түмүк|түмүктэр}} {{PLURAL:$1|көрдөрүлүннэ|көрдөрүлүннүлэр}} <strong>$1</strong> , мантан саҕалаан №&nbsp;<strong>$2</strong>.',
 'showingresultsnum'         => 'Манна {{PLURAL:$3|түмүк|түмүктэр}} {{PLURAL:$3|көрдөрөлүннэ|көрдөрүлүннүлэр}} <strong>$3</strong>, мантан саҕалаан №&nbsp;<strong>$2</strong>.',
-'nonefound'                 => 'Уопсай тыллары туһаннахха көрдүүр сирэйгитин булуо суоххутун сөп - холобур "эмиэ" иҥин диэн тыллар индексацияламматтар. Аны көрдөөбүт тылларгыт барыта эрэ баар буоллахтарына сирэй көстөр.',
+'showingresultstotal'       => "Аллара {{PLURAL:$3|'''$3''' '''$1''' түмүк|'''$3''' '''$1 - $2''' түмүк}} көрдөрүлүннэ",
+'nonefound'                 => "'''Болҕой:''' Анаан эппэтэххэ көрдөөһүн аат сорох далларыгар эрэ көрдүүр. Бу сыһыарыыны ''all:'' тутуннаххына аат туох баар далларыгар барытыгар (холобур, кыттаачылар ырыытыыларыгар, халыыптарга иҥин) көрдүөҕэ.",
 'powersearch'               => 'Бу бөлөхтөргө көрдөө',
 'powersearch-legend'        => 'Дириҥэтэн көрдөөһүн',
 'powersearch-ns'            => 'Аат далыгар көрдөө:',
 'powersearch-redir'         => 'Утаарыылар испииһэктэрэ',
+'powersearch-field'         => 'Көрдөөһүн',
 'search-external'           => 'Тастан көрдөөһүн',
 'searchdisabled'            => '{{SITENAME}} көрдүүр тэрилэ араарыллыбыт. Атын көрдүүр системаларынан наадыйар сирэйдэргитин көрдөтүөххүтүн сөп. Ол гынан баран поисковик кээһигэр баар торум эргэрбит буолуон сөп.',
 
@@ -762,7 +818,7 @@
 'mypreferences'            => 'Туруорууларым',
 'prefs-edits'              => 'Көннөрүү ахсаана:',
 'prefsnologin'             => 'Ааккын эппэтиҥ',
-'prefsnologintext'         => 'Эн [[Special:Userlogin|ааккын эттэххинэ]] эрэ кыттаачы настройкатын уларытар кыахтаныаҥ.',
+'prefsnologintext'         => 'Эн [[Special:UserLogin|ааккын эттэххинэ]] эрэ кыттаачы настройкатын уларытар кыахтаныаҥ.',
 'prefsreset'               => 'Саҥа киирэргэ баар туруоруулар төнүннүлэр.',
 'qbsettings'               => 'Навигация панела',
 'qbsettings-none'          => 'Көрдөрүмэ',
@@ -805,7 +861,7 @@
 'contextchars'             => 'Строкааҕа контекст бэлиэлэрин ахсаана:',
 'stub-threshold'           => '<a href="#" class="stub">омооннорго ыйынньыктары</a> оҥоруу боруога:',
 'recentchangesdays'        => 'Хас хонук иһинэн уларытыылары көрдөрөргө:',
-'recentchangescount'       => 'Бүтэһиктэн саҕалаан хас уларытыыны көрдөрөргө:',
+'recentchangescount'       => 'Историяларга уонна регистрация сурунаалларыгар көрдөрүллэр саҥа уларытыылар ахсааннара:',
 'savedprefs'               => 'Эн туруорууларыҥ олохтоннулар.',
 'timezonelegend'           => 'Чаһыы пуойаһа',
 'timezonetext'             => '¹Эн бириэмэҥ сиэрбэр (Гринвич, UTC) бириэмэтиттэн хас чаас уратылааҕын киллэр.',
@@ -814,6 +870,8 @@
 'servertime'               => 'Сиэрбэр бириэмэтэ',
 'guesstimezone'            => 'Интэриниэтиҥ бырагыраамматыттан ылан толор',
 'allowemail'               => 'Атын кыттааччылартан сурук тутары көҥүллүүргэ',
+'prefs-searchoptions'      => 'Көрдөөһүн туруоруулара',
+'prefs-namespaces'         => 'Аат дала',
 'defaultns'                => 'Чопчу ыйыллыбатаҕына бу ааттар быыстарыгар көрдүүргэ:',
 'default'                  => 'чопчу ыйыллыбатаҕына маннык',
 'files'                    => 'Билэлэр',
@@ -827,10 +885,14 @@
 'userrights-editusergroup'    => 'Кыттааччы бөлөхтөрүн уларытарга',
 'saveusergroups'              => 'Кыттааччы бөлөхтөрүн бигэргэт',
 'userrights-groupsmember'     => 'Бу бөлөхтөргө киирэр:',
+'userrights-groups-help'      => 'Бу киһи киирэр бөлөхтөрүн уларытыаххын сөп:
+* Бөлөх аатын таһыгар бэлиэ турар буоллаҕына бу кыттааччы бу бөлөххө киирэр.
+* Бэлиэ суох буоллаҕына - кыттааччы бөлөххө киирбэт
+* Маннык бэлиэ * кыттааччы бөлөххө киирэрин/киирбэтин уларытар кыаҕыҥ суоҕун көрдөрөр.',
 'userrights-reason'           => 'Уларытыы төрүөтэ:',
 'userrights-no-interwiki'     => 'Атын биикилэргэ кыттааччылар бырааптарын уларытар быраабыҥ суох.',
 'userrights-nodatabase'       => '$1 билэ тиһигэ (олоҕо, база данных) суох эбэтэр локальнай буолбатах.',
-'userrights-nologin'          => 'Эн дьон бырааптарын уларытаргар администратор быһыытынан [[Special:Userlogin|бэлиэтэниэхтээххин]].',
+'userrights-nologin'          => 'Эн дьон бырааптарын уларытаргар администратор быһыытынан [[Special:UserLogin|бэлиэтэниэхтээххин]].',
 'userrights-notallowed'       => 'Бэлиэтэммит ааккынан атын кыттааччы быраабын уларытар кыаҕыҥ суох.',
 'userrights-changeable-col'   => 'Эн уларытар кыахтаах бөлөхтөрүҥ',
 'userrights-unchangeable-col' => 'Бу бөлөхтөрү уларытар кыаҕыҥ суох',
@@ -860,22 +922,56 @@
 'grouppage-suppress'      => '{{ns:project}}:Алҕас',
 
 # Rights
-'right-read'           => 'Сирэйдэри көрүү',
-'right-edit'           => 'Сирэйдэри уларытыы',
-'right-createpage'     => 'Сирэйдэри оҥоруу (ырытыы сирэйдэрин кытта холбуу)',
-'right-createtalk'     => 'Ырытыы сирэйдэрин оҥоруу',
-'right-createaccount'  => 'Саҥа кыттааччыны бэлиэтээһин',
-'right-minoredit'      => 'Уларытыыны кыра суолталаах курдук бэлиэтээ',
-'right-upload'         => 'Билэлэри киллэр',
-'right-reupload'       => 'Баар билэни саҥаттан суруттар',
-'right-delete'         => 'Сирэйдэри сотуу',
-'right-bigdelete'      => 'Уһун историялаах сирэйдэри сотуу',
-'right-deleterevision' => 'Сирэй сорох торумнарын сотуу уонна хат киллэрии',
-'right-browsearchive'  => 'Сотуллубут сирэйдэри көрдөөһүн',
-'right-undelete'       => 'Сотуллубут сирэйи хат киллэрии',
-'right-editinterface'  => 'Кыттааччы интерфейсын уларытыы',
-'right-import'         => 'Атын биикиттэн сирэйдэри киллэрии',
-'right-userrights'     => 'Кытааччылар бырааптарын барытын уларытыы',
+'right-read'                 => 'Сирэйдэри көрүү',
+'right-edit'                 => 'Сирэйдэри уларытыы',
+'right-createpage'           => 'Сирэйдэри оҥоруу (ырытыы сирэйдэрин кытта холбуу)',
+'right-createtalk'           => 'Ырытыы сирэйдэрин оҥоруу',
+'right-createaccount'        => 'Саҥа кыттааччыны бэлиэтээһин',
+'right-minoredit'            => 'Уларытыыны кыра суолталаах курдук бэлиэтээ',
+'right-move'                 => 'Сирэйдэр ааттарын уларытыы',
+'right-move-subpages'        => 'Сирэйдэр ааттарын иһигэр киирэр сирэйдэри кытта уларытыы',
+'right-suppressredirect'     => 'Аатын уларытарга урукку ааттан утаарыы сирэй кыайан оҥоһуллубат',
+'right-upload'               => 'Билэлэри киллэр',
+'right-reupload'             => 'Баар билэни саҥаттан суруттар',
+'right-reupload-own'         => 'Билэлэри суруттарбыт киһи бэйэтэ иккистээн суруттарыыта',
+'right-reupload-shared'      => 'Уопсай ыскылаат билэлэрин локальнай ыскылаат билэлэринэн уларытыы',
+'right-upload_by_url'        => 'URL аадырыстан билэлэри киллэрии',
+'right-purge'                => 'Кээһи бигэргэтэр сирэйэ суох ыраастааһын',
+'right-autoconfirmed'        => 'Аҥардара (сорҕото) көмүскэммит сирэйдэри уларытыы',
+'right-bot'                  => 'аптамаат быһыытынан ааҕыллар',
+'right-nominornewtalk'       => 'Ырытыы сирэйдэригэр кыра көннөрүүлэр суох буоллахтарына саҥа этии эрэсиимэ холбонор',
+'right-apihighlimits'        => 'API-запростарга үрдүк лимиити туттуу',
+'right-writeapi'             => 'API-ны туттуу',
+'right-delete'               => 'Сирэйдэри сотуу',
+'right-bigdelete'            => 'Уһун историялаах сирэйдэри сотуу',
+'right-deleterevision'       => 'Сирэй сорох торумнарын сотуу уонна хат киллэрии',
+'right-deletedhistory'       => 'Сотуллубут тиэкиһи көрөөһүнэ суох сотуу историятын көрүү',
+'right-browsearchive'        => 'Сотуллубут сирэйдэри көрдөөһүн',
+'right-undelete'             => 'Сотуллубут сирэйи хат киллэрии',
+'right-suppressrevision'     => 'Администраатардартан кистэммит сирэйдэри көрүү уонна урукку барылларыгар төннөрүү',
+'right-suppressionlog'       => 'Атын дьон сурунаалларын көрүү',
+'right-block'                => 'Атын кыттааччылар уларыталларын бобуу',
+'right-blockemail'           => 'Эл. суругу ыытары бобуу',
+'right-hideuser'             => 'Кыттааччы аатын бобуу уонна кистээһин',
+'right-ipblock-exempt'       => 'IP хааччахтааһынын, аптамаатынан уонна диапазоннары хааччахтааһыны тумнуу',
+'right-proxyunbannable'      => 'Прокси аптааматынан хааччахтааһынын тумнуу',
+'right-protect'              => 'Сирэйдэр көмүскэллэрин таһымын уонна көмүскэммит сирэйдэри уларытыы',
+'right-editprotected'        => 'Көмүскэллээх сирэйдэри уларытыыы (каскаднай көмүскэллэрэ суох буоллаҕына)',
+'right-editinterface'        => 'Кыттааччы интерфейсын уларытыы',
+'right-rollback'             => 'Кыттааччы оҥорбут көннөрүүлэрин талыллыбыт биир сирэйгэ суох гыныы',
+'right-markbotedits'         => 'Төннөрүллэр көннөрүүлэри робот уларытыытын курдук бэлиэтээһин',
+'right-noratelimit'          => 'Нуорманнан хааччахтааһын суох',
+'right-import'               => 'Атын биикиттэн сирэйдэри киллэрии',
+'right-importupload'         => 'Билэлэри суруйуу нөҥүө сирэйдэри киллэрии (импорт)',
+'right-patrol'               => 'Уларытыылары ботуруулламмыт курдук бэлиэтээһин',
+'right-autopatrol'           => 'Уларытыылар ботуруулламмыт курдук аптамаатынан бэлиэтэнэллэр',
+'right-patrolmarks'          => 'Кэнники уларытыыларга бэрэбиэркэлэммиттэрин туһунан бэлиэлэри көрүү',
+'right-unwatchedpages'       => 'Кэтэммэт сирэйдэр тиһиктэрин көрүү',
+'right-trackback'            => 'Trackback ыытыы',
+'right-mergehistory'         => 'Сирэйдэр историяларын холбооһун',
+'right-userrights'           => 'Кытааччылар бырааптарын барытын уларытыы',
+'right-userrights-interwiki' => 'Атын биики-саайтарга кыттааччылар бырааптарын уларытыы',
+'right-siteadmin'            => 'Билэ тиһигэр (database) киирэри бобуу уонна көҥүллээһин',
 
 # User rights log
 'rightslog'      => 'Кыттаачы бырааптарын сурунаала',
@@ -888,7 +984,7 @@
 'recentchanges'                     => 'Кэнники уларытыылар',
 'recentchangestext'                 => 'Манна хаһан киирибитинэн сааһыланан {{SITENAME}} кэнники уларыытыылара сурулуннулар.',
 'recentchanges-feed-description'    => 'Бу ботуокка биики бүтэһик уларыйыыларын кэтииргэ.',
-'rcnote'                            => "Бу $3 кэмҥэ '''$2''' хонук иһинэн бүтэһик '''$1''' уларыйыылар.",
+'rcnote'                            => "{{PLURAL:$2|хонук|'''$2''' хонуктар}} иһинэн бүтэһик {{PLURAL:$1|'''1''' уларыйыы|'''$1''' уларыйыылар}}, $5, $4.",
 'rcnotefrom'                        => "Мантан '''$2''' маныаха '''$1''' дылы уларыыйылар көрдөрүлүннүлэр.",
 'rclistfrom'                        => 'Мантан $1 уларыйыылары көрдөр',
 'rcshowhideminor'                   => '$1 кыра уларыйыы',
@@ -916,6 +1012,7 @@
 'recentchangeslinked-noresult' => 'Сигэммит сирэйдэргэ этиллибит кэмҥэ уларытыылар оҥоһуллубатылар.',
 'recentchangeslinked-summary'  => "Бу анал сирэйгэ сигэнэр сирэйдэр бүтэһик уларыйыылара көһүннүлэр. [[Special:Watchlist|Кэтэнэр сирэйдэр]] '''модьу бичигинэн''' бэлиэтэннилэр.",
 'recentchangeslinked-page'     => 'Сирэй аата:',
+'recentchangeslinked-to'       => 'Төттөрүтүн, ыйыллыбыт сирэйгэ сигэнэр сирэйдэри көрдөр',
 
 # Upload
 'upload'                      => 'Билэни киллэр',
@@ -923,22 +1020,24 @@
 'reupload'                    => 'Хат киллэр',
 'reuploaddesc'                => 'Тохтот уонна киллэрии форматыгар төнүн',
 'uploadnologin'               => 'Биикигэ ааккын билиһиннэрбэтиҥ',
-'uploadnologintext'           => 'Билэлэри киллэрэргэ манна [[Special:Userlogin|бэлиэтэниэххэ]] наада',
+'uploadnologintext'           => 'Билэлэри киллэрэргэ манна [[Special:UserLogin|бэлиэтэниэххэ]] наада',
+'upload_directory_missing'    => 'Суруйуу паапката ($1) суох, ону ааһан сиэрбэр ону бэйэтэ оҥорор кыаҕа суох.',
 'upload_directory_read_only'  => '($1) директорияҕа сиэрбэр билэни суруйар кыаҕа суох.',
 'uploaderror'                 => 'Билэ суруллубата',
 'uploadtext'                  => "Бу форманы туһанан сиэрбэргэ билэлэри суруйуоххун сөп.
-Урут суруллубут билэлэри көрөргө манна тиий: [[Special:Imagelist|ойуулар испииһэктэрэ]].<br /> Билэлэри суруйуу уонна сотуу устуоруйата [[Special:Log/upload|манна]] көстөр.
+Урут суруллубут билэлэри көрөргө манна тиий: [[Special:ImageList|ойуулар тиһиктэрэ]]. Билэлэри суруйуу уонна иккистээн суруйуу устуоруйата [[Special:Log/upload|манна]], сотуу устуоруйата [[Special:Log/delete|манна]] көстөллөр.
 
 Ойууну ыстатыйаҕа киллэрэргэ маннык суруйуллар:
-*'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-*'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|хос быһаарыы]]</nowiki>''' эбэтэр
-*'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' - билэҕэ быһа сигэнэргэ.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' ойуу хайдах баарынан (кыччаппакка)
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|хос быһаарыы]]</nowiki></tt>''' 200 пииксэл кэтиттээх аллараа өттүгэр быһаарыы суруктаах экран хаҥас кырыытыгар сыстар ойуу
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' - ойууну бэйэтин көрдөрбөккө сигэтин эрэ көрдөрүү.",
 'upload-permitted'            => 'Көҥүллэммит билэ көрүҥнэрэ: $1.',
 'upload-preferred'            => 'Маннык билэ көрүҥнэрин туһанар ордук: $1.',
 'upload-prohibited'           => 'Маннык билэ көрүҥнэрэ бобуллубуттар: $1.',
 'uploadlog'                   => 'уларытыы устуоруйата',
 'uploadlogpage'               => 'Уларытыы устуоруйата',
-'uploadlogpagetext'           => 'Манна бүтэһик уларытыылар исппиһэктэрэ көстөр (UTC).',
+'uploadlogpagetext'           => 'Манна бүтэһик уларытыылар тиһиктэрэ көстөр.
+Өссө [[Special:NewImages|саҥа билэлэр]] тиһиктэрин көрүөххүн сөп.',
 'filename'                    => 'Билэ аата',
 'filedesc'                    => 'Быһаарыы',
 'fileuploadsummary'           => 'Быһаарыы:',
@@ -951,14 +1050,18 @@
 'illegalfilename'             => '«$1» билэ аата аакка туттуллубат бэлиэлэрдээх. Уларыт уонна өссө киллэрэн көр.',
 'badfilename'                 => 'Билэ аата маннык буолла: "$1".',
 'filetype-badmime'            => 'MIME-типтээх "$1" билэлэр кыайан манна суруллубаттар.',
-'filetype-unwanted-type'      => "'''\".\$1\"''' — билэ оччо сөбүлэммэт көрүҥэ. Маннык көрүҥнэри туһанар ордук: \$2.",
-'filetype-banned-type'        => "'''\".\$1\"''' — билэ бобуллубут көрүҥэ. Көнүллэммит билэ көрүҥнэрэ: \$2.",
+'filetype-unwanted-type'      => "'''\".\$1\"''' — билэ оччо сөбүлэммэт көрүҥэ. 
+Маннык {{PLURAL:\$3|көрүҥү|көрүҥнэри}} туһанар ордук: \$2.",
+'filetype-banned-type'        => "'''\".\$1\"''' — билэ бобуллубут көрүҥэ.
+Көҥүллэммит билэ {{PLURAL:\$3|көрүҥэ|көрүҥнэрэ}}: \$2.",
 'filetype-missing'            => 'Билэ расширенията суох (холобур ".jpg").',
 'large-file'                  => 'Манна $1 байт аннынан ыйааһыннаах ойуулары туттар ордук (эн суруйбут билэҥ $2 байтаах).',
 'largefileserver'             => 'Билэ ыйааһына көҥүллэммиттэн ордук.',
 'emptyfile'                   => 'Суруйбут билэҥ арааһа кураанах быһылаах. Баҕар билэ аатын сыыһа суруйбутуҥ буолаарай. Өссө төгүл көр.',
 'fileexists'                  => 'Инник ааттаах билэ бэлиэр баар эбит, ону уларытыаххын саарбахтыыр буоллаххына - маны көр <strong><tt>$1</tt></strong>.',
-'filepageexists'              => 'Маннык ааттаах сирэй (ойуу буолбатах) номнуо баар, тугу гынаргын чуолкай билбэт буоллаххына уларытыаҥ иннинэ бука диэн маны <strong><tt>$1</tt></strong> көр.',
+'filepageexists'              => 'Бу билэни быһаарар сирэй номнуо оҥоһуллубут <strong><tt>$1</tt></strong>, ол гынан баран маннык ааттаах сирэй суох.
+Киллэрбит быһаарыыҥ быһаарыы сирэйигэр тахсыа суоҕа.
+Саҥа быһаарыыны эбэр буоллаххына илиигинэн уларытыаххын наада.',
 'fileexists-extension'        => 'Майгынныыр ааттаах билэ баар:<br />
 Эн суруйбут билэҥ аата: <strong><tt>$1</tt></strong><br />
 Уруккуттан баар билэ аата: <strong><tt>$2</tt></strong><br />
@@ -968,6 +1071,7 @@
 'file-thumbnail-no'           => 'Билэ аата мантан саҕаланар <strong><tt>$1</tt></strong>. Арааһа ойуу кыра куоппуйата быһыылаах (миниатюра). Бу ойуу толору барыйаана баар буоллаҕына ону манна суруй, эбэтэр аатын уларыт.',
 'fileexists-forbidden'        => 'Маннык ааттаах ойуу баар, төннөн атыннык ааттаа. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Маннык ааттаах ойуу уопсай ыскылаакка баар эбит. Төннөн атыннык ааттаа. [[Image:$1|thumb|center|$1]]',
+'file-exists-duplicate'       => 'Бу билэ атын {{PLURAL:$1|билэ дубликаата|билэлэр дубликааттара}} буолар:',
 'successfulupload'            => 'Сатанна',
 'uploadwarning'               => 'Сэрэтии',
 'savefile'                    => 'Билэни суруттарыы',
@@ -1005,9 +1109,12 @@
 'upload-proto-error'      => 'Сыыһа боротокуол',
 'upload-proto-error-text' => 'Ыраахтан суруттарарга маннык аадырыстар наадалар: <code>http://</code> эбэтэр <code>ftp://</code>.',
 'upload-file-error'       => 'Ис сыыһа',
-'upload-file-error-text'  => 'Быстах кэмҥэ оҥоһуллар билэни суруйууга туох эрэ моһол таҕыста.  Админы кытта сибээстэс.',
+'upload-file-error-text'  => 'Быстах кэмҥэ оҥоһуллар билэни суруйууга туох эрэ моһол таҕыста.
+[[Special:ListUsers/sysop|Администраатары]] кытта сибээстэс.',
 'upload-misc-error'       => 'Сурутуу биллибэт моһоллонно',
-'upload-misc-error-text'  => 'Сурутуу биллибэт моһоллонно. Аадырыһы сөпкө суруйбуккун көр уонна өссө биирдэ боруобалаа. Бу хатыланнаҕына админы кытта сибээстэс.',
+'upload-misc-error-text'  => 'Сурутуу биллибэт моһоллонно.
+Аадырыһы сөпкө суруйбуккун көр уонна өссө биирдэ боруобалаа.
+Бу хатыланнаҕына [[Special:ListUsers/sysop|администраатары]] кытта сибээстэс.',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Бу URL-га кыайан тахсыбата',
@@ -1021,7 +1128,10 @@
 'upload_source_url'  => ' (сөптөөх URL, ким баҕарбыт киирэр сирэ)',
 'upload_source_file' => ' (билэ компьютергар баар)',
 
-# Special:Imagelist
+# Special:ImageList
+'imagelist-summary'     => 'Бу анал сирэй киллэриллибит билэлэри барытын көрдөрөр.
+Соторутааҕыта киллэриллибиттэр үөһэ сылдьаллар.
+Колонка баһын баттаатаххына наардааһын бэрээдэгэ уларыйар.',
 'imagelist_search_for'  => 'Миэдьийэни (ойууну) аатынан көрдөтүү:',
 'imgfile'               => 'билэ',
 'imagelist'             => 'Билэлэр',
@@ -1035,7 +1145,7 @@
 'filehist'                       => 'Билэ устуоруйата',
 'filehist-help'                  => 'Ыйын-күнүн/кэмин баттаа, оччотооҕуга баар буолбут.',
 'filehist-deleteall'             => 'барытын сот',
-'filehist-deleteone'             => 'маны сот',
+'filehist-deleteone'             => 'сотуу',
 'filehist-revert'                => 'төттөрү',
 'filehist-current'               => 'билиҥҥи',
 'filehist-datetime'              => 'Күнэ-ыйа/Кэмэ',
@@ -1044,13 +1154,18 @@
 'filehist-filesize'              => 'Билэ кээмэйэ',
 'filehist-comment'               => 'Хос быһаарыы',
 'imagelinks'                     => 'Ыйынньыктар',
-'linkstoimage'                   => 'Бу билэҕэ маннык атын сирэйдэр сигэнэллэр:',
+'linkstoimage'                   => 'Бу билэҕэ маннык атын {{PLURAL:$1|сирэй сигэнэр|$1 сирэйдэр сигэнэллэр}}:',
 'nolinkstoimage'                 => 'Атын сирэйдэр бу билэҕэ сигэммэттэр.',
+'morelinkstoimage'               => 'Бу билэҕэ [[Special:WhatLinksHere/$1|атын сигэлэри]] көрөргө.',
+'redirectstofile'                => 'Билэҕэ бу {{PLURAL:$1|билэттэн сигэ олохтоммут|$1 билэлэртэн сигэлэр олохтоммуттар}}:',
+'duplicatesoffile'               => 'Бу билэ {{PLURAL:$1|дубликаата манна көстөр|$1 дубликаата манна көстөллөр}}:',
 'sharedupload'                   => 'Бу билэ хас да бырайыак туһанар ыскылаатыгар сытар.',
 'shareduploadwiki'               => 'Эбиитин мантан ааҕыаххын сөп $1.',
-'shareduploadwiki-desc'          => '$1 туһунан аллара көһүннэ.',
+'shareduploadwiki-desc'          => 'Уопсай ыскылааттан $1 туһунан аллара көһүннэ.',
 'shareduploadwiki-linktext'      => 'Билэни хос быһаарар сирэй',
+'shareduploadduplicate'          => 'Бу билэ уопсай ыскылаакка сытар $1 дубликаата.',
 'shareduploadduplicate-linktext' => 'атын билэ',
+'shareduploadconflict'           => 'Бу билэ аата уопсай ыскылаакка сытар $1 билэ аатын кытта сөп түбэһэр.',
 'shareduploadconflict-linktext'  => 'атын билэ',
 'noimage'                        => 'Маннык ааттаах билэ суох эбит, маны гыныаххын сөп $1.',
 'noimage-linktext'               => 'итини суруттар',
@@ -1060,18 +1175,18 @@
 # File reversion
 'filerevert'                => 'Төннөр $1',
 'filerevert-legend'         => 'Билэни төннөр',
-'filerevert-intro'          => '<span class="plainlinks">Эн бу билэни  \'\'\'[[Media:$1|$1]]\'\'\'  [$4 торумҥа от $3, $2] төннөрөҕүн.</span>',
+'filerevert-intro'          => "Эн бу билэни  '''[[Media:$1|$1]]'''  [$4 торумҥа от $3, $2] төннөрөҕүн.",
 'filerevert-comment'        => 'Хос быһаарыы:',
 'filerevert-defaultcomment' => 'Торумҥа төннүү $2, $1',
 'filerevert-submit'         => 'Төннөрүү',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' бу торумҥа төннөрүлүннэ [$4 торум Filetype-missingот $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' бу торумҥа төннөрүлүннэ [$4 торум Filetype-missingот $3, $2].",
 'filerevert-badversion'     => 'Бу билэ этиллибит күҥҥэ-ыйга/кэмҥэ оҥоһуллубут урукку торума суох.',
 
 # File deletion
 'filedelete'                  => 'Сот: $1',
 'filedelete-legend'           => 'Билэни сот',
 'filedelete-intro'            => "Маны сотон эрэҕин '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Манна баар [$4 $3, $2]  \'\'\'[[Media:$1|$1]]\'\'\' торумнара сотулуннулар.</span>',
+'filedelete-intro-old'        => "Манна баар [$4 $3, $2]  '''[[Media:$1|$1]]''' торумнара сотулуннулар.",
 'filedelete-comment'          => 'Быһаарыыта:',
 'filedelete-submit'           => 'Сотуу',
 'filedelete-success'          => "'''$1''' сотулунна.",
@@ -1122,7 +1237,7 @@
 {{SITENAME}} туруоҕуттан барыта '''$3''' сирэй көрөөһүнэ буолбут уонна '''$4''' сирэй уларытыыта. Онон ортотунан ыллахха биир сирэйгэ '''$5''' уларытыы уонна '''$6''' көрүү тиксэр.
 
 Величина [http://www.mediawiki.org/wiki/Manual:Job_queue очереди заданий] составляет '''$7'''.",
-'userstatstext'          => "'''$1''' бэлиэтэммит [[Special:Listusers|кыттааччы]] баарыттан '''$2''' (эбэтэр '''$4%''') $2 $5 бырааптаах",
+'userstatstext'          => "'''$1''' бэлиэтэммит [[Special:ListUsers|кыттааччы]] баарыттан '''$2''' (эбэтэр '''$4%''') $2 $5 бырааптаах",
 'statistics-mostpopular' => 'Саамай элбэхтик көрүллэр ыстатыйалар',
 
 'disambiguations'      => 'Элбэх суолталаах өйдөбүллэр сирэйдэрэ',
@@ -1163,6 +1278,7 @@
 'popularpages'            => 'Элбэх киһи көрөр сирэйдэрэ',
 'wantedcategories'        => 'Көрдөнүллэр категориялар',
 'wantedpages'             => 'Көрдөнүллэр сирэйдэр',
+'missingfiles'            => 'Суох билэлэр',
 'mostlinked'              => 'Саамай элбэх сирэй сигэнэр сирэйдэрэ',
 'mostlinkedcategories'    => 'Саамай элбэх сирэй сигэнэр категориялара',
 'mostlinkedtemplates'     => 'Саамай элбэхтик туттуллар халыыптар',
@@ -1175,6 +1291,7 @@
 'deadendpages'            => 'Dead-end (Бүтэй) сирэйдэр',
 'deadendpagestext'        => 'Бу ыстатыйалар {{SITENAME}} саайтын атын сирэйдэригэр сигэммэттэр.',
 'protectedpages'          => 'Көмүскэммит ыстатыйалар',
+'protectedpages-indef'    => 'Болдьоҕо суох эрэ көмүскэллэр',
 'protectedpagestext'      => 'Бу ыстатыйалар аатын уларытартан уонна көннөрөртөн көмүскэммиттэр',
 'protectedpagesempty'     => 'Билигин этиллибит параметрдаах көмүскэниллибит ыстатыйалар суохтар.',
 'protectedtitles'         => 'Көмүскэммит ааттар',
@@ -1190,8 +1307,10 @@
 'unusedcategoriestext'    => 'Манна көрдөрүллүбүт категория сирэйдэрэ ыстатыйата эбэтэр атын категорията суохтар.',
 'notargettitle'           => 'Сыала суох',
 'notargettext'            => 'Көрөөрү гыммыт сирэйгин уонна кыттааччыгын эппэтиҥ.',
+'nopagetitle'             => 'Маннык сирэй суох',
 'pager-newer-n'           => '{{PLURAL:$1|саҥа 1|саҥа $1}}',
 'pager-older-n'           => '{{PLURAL:$1|аҕа 1|аҕа $1}}',
+'suppress'                => 'Кистээһин',
 
 # Book sources
 'booksources'               => 'Кинигэлэр источниктара',
@@ -1210,7 +1329,7 @@
 'logempty'             => 'Сурунаалга сөп түбэһэр элэмиэннэр суохтар.',
 'log-title-wildcard'   => 'Бу сурук бэлиэлэриттэн (буукубалартан) саҕаланар ааттары бул',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Сирэйдэр барыта',
 'alphaindexline'    => 'мантан $1 манна $2',
 'nextpage'          => 'Аныгыскы сирэй ($1)',
@@ -1229,26 +1348,30 @@
 # Special:Categories
 'categories'                    => 'Категориялар',
 'categoriespagetext'            => 'Бу категориялар истэригэр сирэйдэр эбэтэр медия-билэлэр бааллар.',
+'categoriesfrom'                => 'Мантан саҕаланар категориялары көрдөр:',
 'special-categories-sort-count' => 'ахсаанынан бэрээдэктээһин',
 'special-categories-sort-abc'   => 'алпабыытынан бэрээдэктээһин',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Мантан саҕалаан кыттааччылары көрдөр:',
 'listusers-submit'   => 'Көрдөр',
 'listusers-noresult' => 'Кыттааччылар булуллубатылар.',
 
-# Special:Listgrouprights
-'listgrouprights-group'   => 'Бөлөх',
-'listgrouprights-members' => '(кыттар дьон испииһэгэ)',
+# Special:ListGroupRights
+'listgrouprights'          => 'Кыттааччылар бөлөхтөрүн бырааптара',
+'listgrouprights-group'    => 'Бөлөх',
+'listgrouprights-rights'   => 'Бырааптар',
+'listgrouprights-helppage' => 'Help:Бөлөхтөр бырааптара',
+'listgrouprights-members'  => '(кыттар дьон испииһэгэ)',
 
 # E-mail user
 'mailnologin'     => 'Аадырыһа суох',
-'mailnologintext' => 'Атын кыттааччылары кытта e-mail көмөтүнэн суруйсуоххун баҕарар буоллаххына бэйэҕин [[Special:Userlogin|билиһиннэриэхтээххин]]  уонна e-mail аадырыскын [[Special:Preferences|туруорууларгар]] суруйуохтааххын.',
+'mailnologintext' => 'Атын кыттааччылары кытта e-mail көмөтүнэн суруйсуоххун баҕарар буоллаххына бэйэҕин [[Special:UserLogin|билиһиннэриэхтээххин]]  уонна e-mail аадырыскын [[Special:Preferences|туруорууларгар]] суруйуохтааххын.',
 'emailuser'       => 'Кыттааччыга сурук',
 'emailpage'       => 'Кыттааччыга E-mail ыыт',
 'emailpagetext'   => 'Бу кыттааччы бэйэтин туруорууларыгар эл. аадырыһын суруйбут буоллаҕына
 аллараа баар форманы толорон сурук ыытыаххын сөп.
-Эн туруорууларгар баар аадырыһыҥ суруккар киириэҕэ,
+Эн [[Special:Preferences|туруорууларгар]] баар бэйэҥ аадырыһыҥ ол суруккар киириэҕэ,
 онон туппут киһи хардарар кыахтаныа.',
 'usermailererror' => 'Сурук кыайан барбата:',
 'defemailsubject' => '{{SITENAME}} эл. почтата',
@@ -1272,10 +1395,10 @@
 'nowatchlist'          => 'Эн кэтиир сирэйдэриҥ суохтар.',
 'watchlistanontext'    => 'Кэтэбилиҥ сирэйин көрөргөр эбэтэр уларытаргар маны оҥор: $1.',
 'watchnologin'         => 'Бэйэҕин билиһиннэр',
-'watchnologintext'     => 'Бэйэҕин [[Special:Userlogin|билиһиннэрдэххинэ]] кэтэбил сирэйгин уларытыаххын сөп.',
+'watchnologintext'     => 'Бэйэҕин [[Special:UserLogin|билиһиннэрдэххинэ]] кэтэбил сирэйгин уларытыаххын сөп.',
 'addedwatch'           => 'Кэтэбилгэ киирдэ',
 'addedwatchtext'       => '«[[:$1]]» сирэй [[Special:Watchlist|кэтэбилгэ]] киирдэ.
-Сирэй уларытыылара бүгүҥҥүттэн манна көстөр буолуохтара, эбиитин [[Special:Recentchanges|саҥа уларытыылар испииһэктэригэр]] модьу бичигинэн бэлиэтэнэн көстүөхтэрэ.',
+Сирэй уларытыылара бүгүҥҥүттэн манна көстөр буолуохтара, эбиитин [[Special:RecentChanges|саҥа уларытыылар испииһэктэригэр]] модьу бичигинэн бэлиэтэнэн көстүөхтэрэ.',
 'removedwatch'         => 'Кэтэбилтэн сотулунна',
 'removedwatchtext'     => '"[[:$1]]" сирэй бу күнтэн кэтэбилгэ суох.',
 'watch'                => 'Кэтээ',
@@ -1283,6 +1406,7 @@
 'unwatch'              => 'Кэтээмэ',
 'unwatchthispage'      => 'Кэтиири тохтот',
 'notanarticle'         => 'Бу ыстатыйа буолбатах',
+'notvisiblerev'        => 'Торум сотуллубут',
 'watchnochange'        => 'Кэтиир сирэйдэргиттэн этиллибит кэмҥэ биир да уларыйбатах.',
 'watchlist-details'    => '$1 сирэй, ырытыы сирэйдэрин аахпатахха.',
 'wlheader-enotif'      => '* эл. почтанан биллэрии холбоммут.',
@@ -1354,6 +1478,7 @@
 'deletedtext'                 => '«<nowiki>$1</nowiki>» сотуллубут.
 Бүтэһик сотуулар испииһэктэрин манна: $2 көр.',
 'deletedarticle'              => '"[[$1]]" сотуллубут',
+'suppressedarticle'           => '"[[$1]]" кистээбит',
 'dellogpage'                  => 'Сотуу испииһэгэ',
 'dellogpagetext'              => 'Манна кэнники сотуулар испииһэктэрэ көстөр.',
 'deletionlog'                 => 'сотуу испииһэгэ',
@@ -1366,24 +1491,24 @@
 ** ааптар быраабын күөмчүлээһин
 ** Алдьатыы (Вандализм)',
 'delete-edit-reasonlist'      => 'Сотуу төрүөтүн уларытыы',
-'delete-toobig'               => 'Бу сирэй уларытыыларын историята уһун, хас да ($1) хат көрүүлэрдээх. Маннык сирэйдэри сотор хааччахтанар, тоҕо диэххэ алҕас {{SITENAME}} алдьаныан сөп.',
-'delete-warning-toobig'       => 'Бу сирэй уларыылара уһун историялаах, хас да ($1) хат көрүүлэрдээх. Маны соттоххуна, {{SITENAME}} билэтин тиһигин алдьатыан сөп; салгыыр буоллаххына сэрэнэн үлэлээ.',
+'delete-toobig'               => 'Бу сирэй уларытыыларын историята уһун, хас да ($1) {{PLURAL:$1|хат көрүүлээх|хат көрүүлэрдээх}}. Маннык сирэйдэри сотор хааччахтанар, тоҕо диэххэ алҕас {{SITENAME}} алдьаныан сөп.',
+'delete-warning-toobig'       => 'Бу сирэй уларыылара уһун историялаах, хас да ($1) {{PLURAL:$1|хат көрүүлээх|хат көрүүлэрдээх}}. Маны соттоххуна, {{SITENAME}} билэтин тиһигин алдьатыан сөп; салгыыр буоллаххына сэрэнэн үлэлээ.',
 'rollback'                    => 'Уруккутугар төннөр',
 'rollback_short'              => 'Төннөрүү',
 'rollbacklink'                => 'төннөр',
 'rollbackfailed'              => 'Төннөрөргө моһуок үөскээтэ',
 'cantrollback'                => 'Төннөрөр кыах суох; бүтэһик көннөрүүнү оҥорбут киһи бу сирэй соҕотох ааптара буолар.',
-'alreadyrolled'               => 'Бүтэһик [[User:$2|$2]] ([[User talk:$2|Ырытыы]]) оҥорбут [[:$1]] уларытыыларын төннөрөр кыах суох;
+'alreadyrolled'               => 'Бүтэһик [[User:$2|$2]] ([[User talk:$2|Ырытыы]] | [[Special:Contributions/$2|{{int:contribslink}}]]) оҥорбут [[:$1]] уларытыыларын төннөрөр кыах суох;
 ким эрэ атын номнуо бу сирэйи уларыппыт эбэтэр уруккутун төннөрбүт.
 
-Кэнники уларытыыны [[User:$3|$3]] ([[User talk:$3|Ырытыы]]) оҥорбут.',
+Кэнники уларытыыны [[User:$3|$3]] ([[User talk:$3|Ырытыы]] | [[Special:Contributions/$3|{{int:contribslink}}]]) оҥорбут.',
 'editcomment'                 => 'Уларытыыны маннык быһаарбыттар: "<i>$1</i>".', # only shown if there is an edit comment
-'revertpage'                  => '([[User_talk:$2|обсуждение]]) көннөрүүлэрэ: [[{{ns:special}}:Contributions/$2|$2]] бу торумҥа: [[User:$1|$1]] төннөрүлүннүлэр', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'revertpage'                  => '([[User_talk:$2|Ырытыы]]) көннөрүүлэрэ: [[Special:Contributions/$2|$2]] бу торумҥа: [[User:$1|$1]] төннөрүлүннүлэр', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '$1 көннөрүүлэр бу торумҥа төннөрүлүннүлэр: $2.',
 'sessionfailure'              => 'Арааһа туох эрэ сатаммата, дьайыыҥ оҥоһуллубата. Браузергар "Төнүн" тимэҕи баттаа уонна бу иннинээҕи сирэйгин иккистээн киллэрэн көр.',
 'protectlogpage'              => 'Харысхал сурунаала (көннөрүүттэн көмүскэммит билэлэр испииһэктэрэ)',
 'protectlogtext'              => 'Манна ыстатыйалары уларытыыттан көмүскээһин уонна ол көмүскэли суох оҥоруу устуоруйата суруллубут.
-Эн өссө [[Special:Protectedpages|билигин уларытыллыбат сирэйдэр]] испииһэктэрин көрүөххүн сөп.',
+Эн өссө [[Special:ProtectedPages|билигин уларытыллыбат сирэйдэр]] испииһэктэрин көрүөххүн сөп.',
 'protectedarticle'            => '"[[$1]]" сирэй уларытыллыбат',
 'modifiedarticleprotection'   => '"[[$1]]" сирэй уларытыытын таһыма уларыйда',
 'unprotectedarticle'          => '"[[$1]]": уларытыыны хааччахтааһын суох оҥоһулунна',
@@ -1420,6 +1545,7 @@
 'restriction-edit'   => 'Уларытыы',
 'restriction-move'   => 'Аатын уларытыы',
 'restriction-create' => 'Ай',
+'restriction-upload' => 'Киллэрии',
 
 # Restriction levels
 'restriction-level-sysop'         => 'Кытаанах көмүскэл (харысхал)',
@@ -1439,9 +1565,8 @@
 'undeletehistory'              => 'Сирэйи төннөрдөххүнэ бары торумнара уонна уларытыытын устуоруйата барыта төннөрүллүө.
 Сотуллубутун кэннэ маннык ааттаах атын сирэй оҥоһуллубут түбэлтэтигэр төннөрүллүбүт торумнар уларытыы сурунаалыгар саҥа суруктар иннилэригэр суруллуохтара, оттон кэлиҥҥи торум аптамаатынан сотуллуо суоҕа.
 Болҕой, туох баар хааччахтар төннөрүү кэнниттэн суох буолаллар.',
-'undeleterevdel'               => 'Бүтэһик торуму сотор буоллаҕына сотуллубут торум урукку оннугар төннөрүллүө суоҕа.
-Оннук буолар түбэлтэтигэр эн бүтэһик торумнары бэлиэтээмэ.
-Сорох торумнары көрөр кыаҕыҥ суох буоллаҕына ол торумнары төннөрөр кыаҕыҥ суох.',
+'undeleterevdel'               => 'Бу дьайыы сирэй эбэтэр билэ бүтэһик торумун сороҕун сотор кыахтаах буоллаҕына, оҥоһуллуо суоҕа.
+Оннук түбэлтэҕэ эн бэлиэни устуохтааххын, эбэтэр бүтэһик сотуллубут торумнары көрдөрүөхтээххин.',
 'undeletehistorynoadmin'       => 'Ыстатыйа сотуллубут.
 Сотуу төрүөтэ уонна ыстатыйаны суруйбут кыттааччылар испииһэктэрэ манна көрдөрүлүннэ.
 Сотуллубут ыстатыйа ис хоһоонун админнар эрэ көрүөхтэрин сөп.',
@@ -1498,7 +1623,7 @@
 
 # What links here
 'whatlinkshere'            => 'Манна сигэнэллэр',
-'whatlinkshere-title'      => 'Сирэй манна сигэнэр $1',
+'whatlinkshere-title'      => 'Сирэй манна сигэнэр "$1"',
 'whatlinkshere-page'       => 'Сирэй:',
 'linklistsub'              => '(Ыйынньыктар испииһэктэрэ)',
 'linkshere'                => "'''[[:$1]]''' билэҕэ манна көрдөрүллүбүт сирэйдэр сигэнэллэр:",
@@ -1547,7 +1672,7 @@
 'badipaddress'                => 'IP аадырыһа сыыһа',
 'blockipsuccesssub'           => 'Тохтотулунна',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|«$1»]] бобуллубут/тохтотуллубут.<br />
-[[Special:Ipblocklist|Бобуллубут IP-лар испииһэктэрин]] көр.',
+[[Special:IPBlockList|Бобуллубут IP-лар испииһэктэрин]] көр.',
 'ipb-edit-dropdown'           => 'Бобуу биричиинэтин уларыт',
 'ipb-unblock-addr'            => '$1 бобуутун суох гын',
 'ipb-unblock'                 => 'Кыттаачыны эбэтэр IP-ны бобуллубуттар испииһэктэриттэн таһаар',
@@ -1558,7 +1683,7 @@
 'ipusubmit'                   => 'Бу IP-га уларытар быраабын төннөр',
 'unblocked'                   => '[[User:$1|$1]] хааччахтаныыта уһулунна',
 'unblocked-id'                => '$1 хааччахтаныыта уһулунна',
-'ipblocklist'                 => 'Хааччахтаммыт/бобуллубут IP-лар уонна кыттааччылар',
+'ipblocklist'                 => 'Бобуллубут IP-лар уонна кыттааччылар',
 'ipblocklist-legend'          => 'Хааччахтаммыт/бобуллубут кыттааччыны көрдөөһүн',
 'ipblocklist-username'        => 'Кыттааччы аата эбэтэр IP-та:',
 'ipblocklist-submit'          => 'Бул',
@@ -1579,7 +1704,7 @@
 'blocklogentry'               => '[[$1]] хааччахтаата, болдьоҕо: $2 $3',
 'blocklogtext'                => 'Кыттааччылары хааччахтааһын уонна ол хааччахтааһыннарын суох гыныы сурунаала.
 Аптамаатынан хааччахтаммыт IP-лар манна көстүбэттэр.
-[[Special:Ipblocklist|Билигин баар хааччахтаныылар испииһэктэрин]] көр.',
+[[Special:IPBlockList|Билигин баар хааччахтаныылар испииһэктэрин]] көр.',
 'unblocklogentry'             => '$1 хааччахтааһыны уһулла',
 'block-log-flags-anononly'    => 'ааттамматах кыттааччылар эрэ',
 'block-log-flags-nocreate'    => 'саҥа бэлиэтэнии бобуллубут',
@@ -1614,7 +1739,7 @@
 'lockdbsuccesssub'    => 'Билии олоҕун (Database) уларытыы бобулунна',
 'unlockdbsuccesssub'  => 'Билии олоҕун (Database) уларытыы көҥүллэннэ',
 'lockdbsuccesstext'   => 'Билии олоҕун (database) уларытар бобулунна.
-<br />Үлэлээн бүттэххинэ [[Special:Unlockdb|уларытары көҥүллүүргүн]] умнума.',
+<br />Үлэлээн бүттэххинэ [[Special:UnlockDB|уларытары көҥүллүүргүн]] умнума.',
 'unlockdbsuccesstext' => 'Билии олоҕун (database) уларытар көҥүллэннэ.',
 'lockfilenotwritable' => 'Бобуу билэтигэр суруйар кыаҕыҥ суох. БД уларытары көҥүллүүргэ эбэтэр боборго веб-сервер бу билэни уларытар бырааптаах буолуохтаах.',
 'databasenotlocked'   => 'БД уларытааһын бобуллубата.',
@@ -1625,11 +1750,11 @@
 Бу түбэлтэҕэ уларытыы сурунаала саҥа сиргэ көһөр.
 Урукку аат саҥа сирэйгэ утаарар сирэйгэ кубулуйар.
 Урукку аакка ыйынньыктар уларыйбаттар; 
-бука диэн хос ыйынньыктар уонна быстыбыт сигэниилэр баалларын-суохтарын көр.
-Сиэр быһыытынан эн  ыйынньыктар сөпкө сигэнэллэрин ситиһиэхтээххин.
+бука диэн [[Special:DoubleRedirects|хос ыйынньыктар]] уонна [[Special:BrokenRedirects|быстыбыт сигэниилэр]] баалларын-суохтарын көр.
+Сиэр быһыытынан ыйынньыктар сөпкө сигэнэллэрин эн ситиһиэхтээххин.
 
-Өскө маннык ааттаах сирэй номнуо баар эбит буоллаҕына сирэй аата '''уларыйыа суоҕа''' (кураанах эбэтэр утаарар сирэй буолбатах буоллаҕына).
-Ол аата эн сирэй аатын сыыһа уларыппыт буоллаххына төттөрү урукку аатыгар төннөрүөххүн сөп, ол гынан баран баар сирэйи алҕас сотор кыаҕыҥ суох.
+Өскө маннык ааттаах сирэй номнуо баар буоллаҕына сирэй аата '''уларыйыа суоҕа''', арай ол сирэй кураанах эбэтэр утаарар сирэй буолбатах буоллаҕына.
+Ол аата эн сирэй аатын сыыһа уларыппыт буоллаххына төттөрү урукку аатыгар төннөрүөххүн сөп гынан баран баар сирэйи алҕас сотор кыаҕыҥ суох.
 
 '''СЭРЭТИИ!'''
 Сирэй аатын уларытыы улахан уонна эрдэттэн өйдөммөтөх содуллаах буолуон сөп.
@@ -1640,13 +1765,12 @@
 
 Ити түгэннэргэ сирэйдэри бэйэҥ көһөрүөхтээххин эбэтэр холбуохтааххын.',
 'movearticle'             => 'Бу аатын уларыт:',
-'movenologin'             => 'Ааккын билиһиннэрбэтэххин',
-'movenologintext'         => 'Эн аакын [[Special:Userlogin|билиһиннэрдэххинэ]] эрэ сирэй аатын уларытар кыахтаныаҥ.',
 'movenotallowed'          => '{{SITENAME}} саайтыгар сирэй аатын уларытар кыаҕыҥ суох.',
 'newtitle'                => 'Саҥа аата:',
 'move-watch'              => 'Кэтээн көрөргө',
 'movepagebtn'             => 'Аатын уларыт',
 'pagemovedsub'            => 'Аата уларыйда',
+'movepage-moved'          => '<big>\'\'\'"$1" сирэй аата маннык буолла "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Маннык ааттаах сирэй баар, эбэтэр
 маннык аат көҥүллэммэт эбит.
 Атын аатта таларгар көрдөһөбүт.',
@@ -1663,12 +1787,15 @@
 'delete_and_move'         => 'Суох гын уонна аатын уларыт',
 'delete_and_move_text'    => '==Сотуохха наада==
 
-Маннык ааттаах сирэй [[$1|«$1»]] бэлиэр баар. Эн ону суох гынан баран аатын уларытаары гынаҕын дуо?',
+Маннык ааттаах сирэй [[:$1|«$1»]] бэлиэр баар. Эн ону суох гынан баран аатын уларытаары гынаҕын дуо?',
 'delete_and_move_confirm' => 'Сөп, бу сирэйи суох гын',
 'delete_and_move_reason'  => 'Аатын уларытаары сотулунна',
 'selfmove'                => 'Аатын уларытар сатаммат. Эргэ уонна саҥа аата биирдэр.',
 'immobile_namespace'      => 'Аатын уларытар сатаммат. Саҥа дуу эргэ дуу аата аналлаах (служебнай) тыллаах эбит.',
+'imagenocrossnamespace'   => 'Ойууга атын аат далыттан аат биэрэр сатаммат',
 'imagetypemismatch'       => 'Билэ саҥа расширенията тиибигэр сөп түбэспэт',
+'imageinvalidfilename'    => 'Билэ аата сыыһалаах',
+'fix-double-redirects'    => 'Утаарыылары урукку ааттарыгар төннөр',
 
 # Export
 'export'            => 'Сирэйдэри таска таһаарааһын (export)',
@@ -1719,7 +1846,7 @@
 'import-interwiki-history'   => 'Сирэй туох баар историятын көһөрөргө',
 'import-interwiki-submit'    => 'Импортаа',
 'import-interwiki-namespace' => 'Сирэйдэри бу namespace-ка көһөрөргө:',
-'importtext'                 => 'Сирэйи Special:Export үнүстүрүмүөн көмөтүнэн экспортаа, онтон билэни диискэҕэ суруй, онтон манна көһөр.',
+'importtext'                 => 'Сирэйи [[Special:Export|экспорт үнүстүрүмүөнүн]] көмөтүнэн экспортаа. Билэни бэйэҥ көмпүүтэргэр суруй, онтон манна көһөр.',
 'importstart'                => 'Сирэйдэри импортааһын...',
 'import-revision-count'      => '$1 {{PLURAL:$1|торум|торумнар}}',
 'importnopages'              => 'Импортка аналлаах сирэй суох.',
@@ -1891,7 +2018,7 @@
 'mediawarning'         => "'''Сэрэтии''': бу билэ систиэмэни алдьатар куһаҕан бырагыраамма куодун илдьэ сылдьар буолуон сөп. <hr />",
 'imagemaxsize'         => 'Ойуу туһунан сирэй ойууларын бу кээмэйгэ дылы кыччат:',
 'thumbsize'            => 'Кыра ойуу (миниатюра) кээмэйэ:',
-'widthheightpage'      => '$1×$2, $3 сирэй',
+'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|сирэй|сирэй}}',
 'file-info'            => '(билэ кээмэйэ: $1, MIME тиибэ: $2)',
 'file-info-size'       => '($1 × $2 пииксэл, билэ кээмэйэ: $3, MIME тиибэ: $4)',
 'file-nohires'         => '<small>Бу ойуу маннааҕар улахан торума суох.</small>',
@@ -1899,10 +2026,10 @@
 'show-big-image'       => 'Ойуу бэйэтин толору кээмэйэ',
 'show-big-image-thumb' => '<small>Хачайдыах иннинэ көрүү кээмэйэ: $1 × $2 пииксэл</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Саҥа билэлэр галереялара',
 'imagelisttext'         => "Манна {{PLURAL:$1|билэ|билэлэр}} испииһэктэрэ ('''$1''') көстөр, суортаммыт: $2.",
-'newimages-summary'     => 'Бу анал сирэй киллэриллибит билэлэр испииһэктэрин көрдөрөр',
+'newimages-summary'     => 'Бу анал сирэй киллэриллибит билэлэр испииһэктэрин көрдөрөр.',
 'showhidebots'          => '($1 робот)',
 'noimages'              => 'Ойуу суох.',
 'ilsubmit'              => 'Көрдөт',
@@ -2186,7 +2313,7 @@
 
 # External editor support
 'edit-externally'      => 'Бу билэни таһынааҕы бырагыраамма көмөтүнэн уларытарга',
-'edit-externally-help' => 'Сиһилии бу ыйынньыгынан баран көр: [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions].',
+'edit-externally-help' => 'Сиһилии бу ыйынньыгынан баран көр: [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'бары',
@@ -2251,7 +2378,7 @@
 'recreate'            => 'Саҥаттан оҥоруу',
 
 # HTML dump
-'redirectingto' => '[[$1]] сирэйгэ көһөрүү...',
+'redirectingto' => '[[:$1]] сирэйгэ көһөрүү...',
 
 # action=purge
 'confirm_purge'        => 'Бу сирэй кээһин сотоору гынаҕын дуо?
@@ -2299,8 +2426,8 @@
 'livepreview-error'   => 'Холбоммото: $1 "$2". Көннөрү инники көрүүнү туһан.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => '$1 сөкүүндэ иһинэн оҥоһуллубут уларытыылар манна көстүө суохтарын сөп.',
-'lag-warn-high'   => 'Синхронизация лаппа хойутуур буолан кэнники $1 сөкүүндэ иһинэн оҥоһуллубут уларытыылар манна көстүө суохтарын сөп.',
+'lag-warn-normal' => '$1 {{PLURAL:$1|сөкүүндэ|сөкүүндэ}} иһинэн оҥоһуллубут уларытыылар манна көстүө суохтарын сөп.',
+'lag-warn-high'   => 'Синхронизация лаппа хойутуур буолан кэнники $1 {{PLURAL:$1|сөкүүндэ|сөкүүндэ}} иһинэн оҥоһуллубут уларытыылар манна көстүө суохтарын сөп.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Эн кэтиир испииһэгиҥ $1 пууннаах, ырытыы сирэйэ ааҕыллыбата.',
@@ -2350,7 +2477,7 @@
 'version-software-product'         => 'Бородуукта',
 'version-software-version'         => 'Барыл (торум)',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Билэ суола',
 'filepath-page'    => 'Билэ:',
 'filepath-submit'  => 'Суол',
@@ -2372,6 +2499,9 @@
 
 # Special:SpecialPages
 'specialpages'                   => 'Анал сирэйдэр',
+'specialpages-note'              => '----
+* Көннөрү анал сирэйдэр.
+* <span class="mw-specialpagerestricted">Киирэргэ хааччахтардаах анал сирэйдэр.</span>',
 'specialpages-group-maintenance' => 'Техническэй отчуоттар',
 'specialpages-group-other'       => 'Атын аналлаах сирэйдэр',
 'specialpages-group-login'       => 'Киирии / бэлиэтэнии',
@@ -2379,5 +2509,14 @@
 'specialpages-group-media'       => 'Медиа отчуоттар уонна киллэриилэр',
 'specialpages-group-users'       => 'Кыттааччылар уонна бырааптара',
 'specialpages-group-highuse'     => 'Элбэхтик туттуллар сирэйдэр',
+'specialpages-group-pages'       => 'Сирэйдэр тиһиктэрэ',
+'specialpages-group-pagetools'   => 'Сирэйдэр үнүстүрүмүөннэрэ',
+'specialpages-group-wiki'        => 'Wiki дааннайдара уонна үнүстүрүмүөннэр',
+'specialpages-group-redirects'   => 'Утаарар аналлаах сирэйдэр',
+'specialpages-group-spam'        => 'Спаамы утары үнүстүрүмүөннэр',
 
+# Special:BlankPage
+'blankpage'              => 'Кураанах сирэй',
+'intentionallyblankpage' => 'Бу сирэй соруйан кураанах хаалларыллыбыт',
+
 );
Index: languages/messages/MessagesNo.php
===================================================================
--- languages/messages/MessagesNo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,23 +4,20 @@
  * @ingroup Language
  * @file
  *
- * @author Jon Harald Søby
- * @author Kph
- * @author Siebrand
- * @author לערי ריינהארט
- * @author Stigmj
- * @author H92
- * @author M.M.S.
+ * @author Boivie
  * @author Eirik
- * @author SPQRobin
- * @author Jóna Þórunn
  * @author EivindJ
  * @author Finnrind
- * @author Boivie
+ * @author H92
+ * @author Jon Harald Søby
+ * @author Jóna Þórunn
+ * @author Kph
+ * @author Kph-no
+ * @author Max sonnelid
  * @author Samuelsen
+ * @author Stigmj
  * @author Teak
- * @author Max sonnelid
- * @author Kph-no
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -295,7 +292,7 @@
 'newwindow'      => '(åpner i nytt vindu)',
 'cancel'         => 'Avbryt',
 'qbfind'         => 'Finn',
-'qbbrowse'       => 'Søk',
+'qbbrowse'       => 'Bla gjennom',
 'qbedit'         => 'Rediger',
 'qbpageoptions'  => 'Sideinnstillinger',
 'qbpageinfo'     => 'Sideinformasjon',
@@ -441,7 +438,7 @@
 'nosuchaction'      => 'Funksjonen finnes ikke',
 'nosuchactiontext'  => 'MediaWiki-programvaren kjenner ikke igjen funksjonen som er spesifisert i URL-en.',
 'nosuchspecialpage' => 'En slik spesialside finnes ikke',
-'nospecialpagetext' => 'Du ba om en ugyldig spesialside; en liste over gyldige spesialsider finnes på [[Special:Specialpages|{{int:specialpages}}]].',
+'nospecialpagetext' => 'Du ba om en ugyldig spesialside; en liste over gyldige spesialsider finnes på [[Special:SpecialPages|{{int:specialpages}}]].',
 
 # General errors
 'error'                => 'Feil',
@@ -462,7 +459,7 @@
 De vanligste grunnene til denne feilen er en lenke til en diff mellom forskjellige versjoner eller lenker til en gammel versjon av en side som har blitt slettet.
 
 Om det ikke er tilfellet kan du ha funnet en feil i programvaren.
-Rapporter gjerne problemet til en administrator, angi da adressen til siden.',
+Rapporter gjerne problemet til en [[Special:ListUsers/sysop|administrator]], angi da adressen til siden.',
 'missingarticle-rev'   => '(versjon $1)',
 'missingarticle-diff'  => '(diff: $1, $2)',
 'readonly_lag'         => 'Databasen er automatisk skrivebeskyttet så slavetjenerne kan ta igjen mestertjeneren',
@@ -511,11 +508,13 @@
 
 # Login and logout pages
 'logouttitle'                => 'Logg ut',
-'logouttext'                 => '<strong>Du er nå logget ut.</strong><br />
-Du kan fortsette å bruke {{SITENAME}} anonymt, eller logge inn igjen som samme eller annen bruker.',
+'logouttext'                 => '<strong>Du er nå logget ut.</strong>
+
+Du kan fortsette å bruke {{SITENAME}} anonymt, eller [[Special:UserLogin|logge inn igjen]] som samme eller annen bruker.
+Merk at noen sider kan vise at du fortsatt er logget inn fram til du tømmer mellomlageret i nettleseren.',
 'welcomecreation'            => '==Velkommen, $1!==
 Brukerkontoen din har blitt opprettet.
-Ikke glem å endre innstillingene dine.',
+Ikke glem å endre [[Special:Preferences|innstillingene]] dine.',
 'loginpagetitle'             => 'Logg inn',
 'yourname'                   => 'Brukernavn:',
 'yourpassword'               => 'Passord:',
@@ -526,7 +525,7 @@
 'loginproblem'               => '<strong>Du ble ikke logget inn.</strong><br />Prøv igjen!',
 'login'                      => 'Logg inn',
 'nav-login-createaccount'    => 'Logg inn eller registrer deg',
-'loginprompt'                => 'Du må ha slått på cookies for å logge in på {{SITENAME}}.',
+'loginprompt'                => 'Du må ha slått på informasjonskapsler for å [[Special:UserLogin|logge in på {{SITENAME}}]].',
 'userlogin'                  => 'Logg inn eller registrer deg',
 'logout'                     => 'Logg ut',
 'userlogout'                 => 'Logg ut',
@@ -651,7 +650,10 @@
 * Blokkeringen utgår: $6
 * Blokkering ment på: $7
 
-Du kan kontakte $1 eller en annen [[{{MediaWiki:Grouppage-sysop}}|administrator]] for å diskutere blokkeringen. Du kan ikke bruke «E-post til denne brukeren»-funksjonen med mindre du har oppgitt en gyldig e-postadresse i [[Special:Preferences|innstillingene dine]] og du ikke er blokkert fra å sende e-post. Din nåværende IP-adresse er $3, og blokkerings-ID-en er #$5. Vennligst ta med begge disse ved henvendelser.",
+Du kan kontakte $1 eller en annen [[{{MediaWiki:Grouppage-sysop}}|administrator]] for å diskutere blokkeringen.
+Du kan ikke bruke «E-post til denne brukeren»-funksjonen med mindre du har oppgitt en gyldig e-postadresse i [[Special:Preferences|innstillingene dine]] og du ikke er blokkert fra å sende e-post.
+Din nåværende IP-adresse er $3, og blokkerings-ID-en er #$5.
+Vennligst ta all denne informasjonen ved henvendelser.",
 'autoblockedtext'                  => "Din IP-adresse har blitt automatisk blokkert fordi den ble brukt av en annen bruker som ble blokkert av $1.
 Den oppgitte grunnen var:
 
@@ -659,21 +661,19 @@
 
 * Blokkeringen begynte: $8
 * Blokkeringen utgår: $6
+* Blokkeringen er ment for: $7
 
 Du kan kontakte $1 eller en av de andre [[{{MediaWiki:Grouppage-sysop}}|administratorene]] for å diskutere blokkeringen.
 
 Merk at du ikke kan bruke «E-post til denne brukeren»-funksjonen med mindre du har registrert en gyldig e-postadresse i [[Special:Preferences|innstillingene dine]].
 
-Din blokkerings-ID er $5. Vennligst ta med denne ID-en i din forespørsel.",
+Din IP-adresse er $3, og blokkerings-ID-en er #$5.
+Vennligst ta med all denne informasjonen ved henvendelser.",
 'blockednoreason'                  => 'ingen grunn gitt',
 'blockedoriginalsource'            => "Kildekoden til '''$1''' vises nedenfor:",
 'blockededitsource'                => "Kildekoden '''dine endringer''' på '''$1''' vises nedenfor:",
-'whitelistedittitle'               => 'Du må logge inn for å redigere',
+'whitelistedittitle'               => 'Du må [[Special:UserLogin|logge inn]] for å redigere',
 'whitelistedittext'                => 'Du må $1 for å redigere artikler.',
-'whitelistreadtitle'               => 'Du må logge inn for å kunne lese',
-'whitelistreadtext'                => 'Du må [[Special:Userlogin|logge inn]] for å lese artikler.',
-'whitelistacctitle'                => 'Du har ikke adgang til å opprette en konto',
-'whitelistacctext'                 => 'For å få adgang til å opprette kontoer på {{SITENAME}} må du [[Special:Userlogin|logge inn]] og ha riktige rettigheter.',
 'confirmedittitle'                 => 'E-postbekreftelse nødvendig før du kan redigere',
 'confirmedittext'                  => 'Du må bekrefte e-postadressen din før du kan redigere sider. Vennligst oppgi og bekreft e-postadressen din via [[Special:Preferences|innstillingene dine]].',
 'nosuchsectiontitle'               => 'Ingen slik seksjon',
@@ -686,7 +686,10 @@
 'newarticle'                       => '(Ny)',
 'newarticletext'                   => "Du fulgte en lenke til en side som ikke finnes ennå. For å opprette siden, start å skrive i boksen nedenfor (se [[{{MediaWiki:Helppage}}|hjelpesiden]] for mer informasjon). Om du kom hit ved en feil, bare trykk på nettleserens '''tilbake'''-knapp.",
 'anontalkpagetext'                 => "----
-''Dette er en diskusjonsside for en uregistrert bruker som ikke har opprettet konto eller ikke er logget inn. Vi er derfor nødt til å bruke den numeriske IP-adressen til å identifisere ham eller henne. En IP-adresse kan være delt mellom flere brukere. Hvis du er en uregistrert bruker og synes at du har fått irrelevante kommentarer på en slik side, [[Special:Userlogin|logg på]] så vi unngår framtidige forvekslinger med andre uregistrerte brukere.''",
+''Dette er en diskusjonsside for en uregistrert bruker som ikke har opprettet konto eller ikke er logget inn.
+Vi er derfor nødt til å bruke den numeriske IP-adressen til å identifisere ham eller henne.
+En IP-adresse kan være delt mellom flere brukere.
+Hvis du er en uregistrert bruker og synes at du har fått irrelevante kommentarer på en slik side, [[Special:UserLogin/signup|opprett en konto]] eller [[Special:UserLogin|logg inn]] så vi unngår framtidige forvekslinger med andre uregistrerte brukere.''",
 'noarticletext'                    => 'Det er ikke noe tekst på denne siden. Du kan [[Special:Search/{{PAGENAME}}|søke etter siden]] i andre sider, eller [{{fullurl:{{FULLPAGENAME}}|action=edit}} redigere siden].',
 'userpage-userdoesnotexist'        => 'Brukerkontoen «$1» er ikke registrert. Sjekk om du ønsker å opprette/redigere denne siden.',
 'clearyourcache'                   => "'''Merk:''' Etter lagring vil det kanskje være nødvendig at nettleseren sletter mellomlageret sitt for at endringene skal tre i kraft. '''Mozilla og Firefox:''' trykk ''Ctrl-Shift-R'', '''Internet Explorer:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-Shift-R'' i engelskspråklig versjon, ''Cmd-Alt-E'' i norskspråklig versjon, '''Konqueror og Opera:''' ''F5''.",
@@ -698,12 +701,12 @@
 'note'                             => '<strong>Merk:</strong>',
 'previewnote'                      => '<strong>Dette er bare en forhåndsvisning; endringer har ikke blitt lagret!</strong>',
 'previewconflict'                  => 'Slik vil teksten i redigeringsvinduet se ut dersom du lagrer den.',
-'session_fail_preview'             => '<strong>Beklager! Klarte ikke å lagre redigeringen din. Prøv igjen. Om det fortsetter å gå galt, prøv å logge ut og så inn igjen.</strong>',
+'session_fail_preview'             => '<strong>Beklager! Klarte ikke å lagre redigeringen din. Prøv igjen. Om det fortsetter å gå galt, prøv å [[Special:UserLogout|logge ut]] og så inn igjen.</strong>',
 'session_fail_preview_html'        => "<strong>Beklager! Klarte ikke å lagre redigeringen din på grunn av tap av øktdata.</strong>
 
 ''Fordi {{SITENAME}} har rå HTML slått på, er forhåndsvisningen skjult for å forhindre JavaScript-angrep.''
 
-<strong>Om dette er et legitimt redigeringsforsøk, prøv igjen. Om det da ikke fungerer, prøv å logge ut og logge inn igjen.</strong>",
+<strong>Om dette er et legitimt redigeringsforsøk, prøv igjen. Om det da ikke fungerer, prøv å [[Special:UserLogout|logge ut]] og logge inn igjen.</strong>",
 'token_suffix_mismatch'            => '<strong>Redigeringen din har blitt avvist fordi klienten din ikke hadde punktasjonstegn i redigeringsteksten. Redigeringen har blitt avvist for å hindre ødeleggelse av artikkelteksten. Dette forekommer av og til når man bruker vevbaserte anonyme proxytjenester.</strong>',
 'editing'                          => 'Redigerer $1',
 'editingsection'                   => 'Redigerer $1 (seksjon)',
@@ -742,7 +745,7 @@
 'hiddencategories'                 => 'Skjulte kategorier denne siden er medlem av{{PLURAL:$1|:|:}}',
 'edittools'                        => '<!-- Teksten her vil vises under redigerings- og opplastingsboksene. -->',
 'nocreatetitle'                    => 'Sideoppretting er begrenset',
-'nocreatetext'                     => '{{SITENAME}} har begrensede muligheter for oppretting av nye sider. Du kan gå tilbake og redigere en eksisterende side, eller [[Special:Userlogin|logge inn eller opprette en ny konto]].',
+'nocreatetext'                     => '{{SITENAME}} har begrensede muligheter for oppretting av nye sider. Du kan gå tilbake og redigere en eksisterende side, eller [[Special:UserLogin|logge inn eller opprette en ny konto]].',
 'nocreate-loggedin'                => 'Du har ikke tillatelse til å opprette sider på {{SITENAME}}.',
 'permissionserrors'                => 'Tilgangsfeil',
 'permissionserrorstext'            => 'Du har ikke tillatelse til å utføre dette, av følgende {{PLURAL:$1|grunn|grunner}}:',
@@ -767,7 +770,7 @@
 'undo-success' => 'Redigeringen kan omgjøres. Sjekk sammenligningen under for å bekrefte at du vil gjøre dette, og lagre endringene for å fullføre omgjøringen.',
 'undo-failure' => 'Redigeringen kunne ikke omgjøres på grunn av konflikterende etterfølgende redigeringer.',
 'undo-norev'   => 'Redigeringen kunne ikke fjernes fordi den ikke eksisterer eller ble slettet',
-'undo-summary' => 'Fjerner revisjon $1 av [[Special:Contributions/$2]] ([[User talk:$2|Brukerdiskusjon:$2]])',
+'undo-summary' => 'Fjerner revisjon $1 av [[Special:Contributions/$2]] ([[User talk:$2|diskusjon]] | [[Special:Contributions/$2|{{int:contribsilnk}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Kan ikke opprette konto',
@@ -854,7 +857,7 @@
 # Suppression log
 'suppressionlog'     => 'Sidefjerningslogg',
 'suppressionlogtext' => 'Nedenfor er en liste over sider og blokkeringer med innhold skjult fra administratorer.
-Se [[Special:Ipblocklist|blokkeringslisten]] for oversikten over nåværende blokkeringer.',
+Se [[Special:IPBlockList|blokkeringslisten]] for oversikten over nåværende blokkeringer.',
 
 # History merging
 'mergehistory'                     => 'Flett sidehistorikker',
@@ -894,7 +897,7 @@
 # Search results
 'searchresults'             => 'Søkeresultater',
 'searchresulttext'          => 'For mer informasjon om søking i {{SITENAME}}, se [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => 'Du søkte på «[[$1]]».',
+'searchsubtitle'            => "Du søkte på '''[[:$1]]''' ([[Special:Prefixindex/$1|alle sider som begynner med «$1»]] | [[Special:WhatLinksHere/$1|alle sider som lenker til «$1»]])",
 'searchsubtitleinvalid'     => 'For forespørsel "$1"',
 'noexactmatch'              => "'''Det er ingen side med tittelen «$1».''' Du kan [[:$1|opprette siden]].",
 'noexactmatch-nocreate'     => "'''Det er ingen side med tittelen «$1».'''",
@@ -937,7 +940,7 @@
 'mypreferences'            => 'Innstillinger',
 'prefs-edits'              => 'Antall redigeringer:',
 'prefsnologin'             => 'Ikke logget inn',
-'prefsnologintext'         => 'Du må være [[Special:Userlogin|logget inn]] for å endre brukerinnstillingene.',
+'prefsnologintext'         => 'Du må være [[Special:UserLogin|logget inn]] for å endre brukerinnstillingene.',
 'prefsreset'               => 'Brukerinnstillingene er tilbakestilt.',
 'qbsettings'               => 'Brukerinnstillinger for hurtigmeny.',
 'qbsettings-none'          => 'Ingen',
@@ -997,25 +1000,26 @@
 'files'                    => 'Filer',
 
 # User rights
-'userrights'                  => 'Brukerrettighetskontroll', # Not used as normal message but as header for the special page itself
-'userrights-lookup-user'      => 'Ordne brukergrupper',
-'userrights-user-editname'    => 'Skriv inn et brukernavn:',
-'editusergroup'               => 'Endre brukergrupper',
-'editinguser'                 => "Endrer brukerrettighetene til '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
-'userrights-editusergroup'    => 'Rediger brukergrupper',
-'saveusergroups'              => 'Lagre brukergrupper',
-'userrights-groupsmember'     => 'Medlem av:',
-'userrights-groups-help'      => 'Du kan endre hvilke grupper denne brukeren er medlem av.
+'userrights'                     => 'Brukerrettighetskontroll', # Not used as normal message but as header for the special page itself
+'userrights-lookup-user'         => 'Ordne brukergrupper',
+'userrights-user-editname'       => 'Skriv inn et brukernavn:',
+'editusergroup'                  => 'Endre brukergrupper',
+'editinguser'                    => "Endrer brukerrettighetene til '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'userrights-editusergroup'       => 'Rediger brukergrupper',
+'saveusergroups'                 => 'Lagre brukergrupper',
+'userrights-groupsmember'        => 'Medlem av:',
+'userrights-groups-help'         => 'Du kan endre hvilke grupper denne brukeren er medlem av.
 * En avkrysset boks betyr at brukeren er medlem av gruppen.
 * En uavkrysset boks betyr at brukeren ikke er medlem av gruppen.
 * En * betyr at du ikke kan fjerne gruppemedlemskapet når du har lagt det til, eller vice versa.',
-'userrights-reason'           => 'Endringsgrunn:',
-'userrights-no-interwiki'     => 'Du har ikke tillatelse til å endre brukerrettigheter på andre wikier.',
-'userrights-nodatabase'       => 'Databasen $1 finnes ikke, eller er ikke lokal.',
-'userrights-nologin'          => 'Du må [[Special:Userlogin|logge inn]] med en administratorkonto for å endre brukerrettigheter.',
-'userrights-notallowed'       => 'Kontoen din har ikke tillatelse til å endre brukerrettigheter.',
-'userrights-changeable-col'   => 'Grupper du kan endre',
-'userrights-unchangeable-col' => 'Grupper du ikke kan endre',
+'userrights-reason'              => 'Endringsgrunn:',
+'userrights-no-interwiki'        => 'Du har ikke tillatelse til å endre brukerrettigheter på andre wikier.',
+'userrights-nodatabase'          => 'Databasen $1 finnes ikke, eller er ikke lokal.',
+'userrights-nologin'             => 'Du må [[Special:UserLogin|logge inn]] med en administratorkonto for å endre brukerrettigheter.',
+'userrights-notallowed'          => 'Kontoen din har ikke tillatelse til å endre brukerrettigheter.',
+'userrights-changeable-col'      => 'Grupper du kan endre',
+'userrights-unchangeable-col'    => 'Grupper du ikke kan endre',
+'userrights-irreversible-marker' => '$1 *',
 
 # Groups
 'group'               => 'Gruppe:',
@@ -1027,12 +1031,12 @@
 'group-suppress'      => 'Sidefjernere',
 'group-all'           => '(alle)',
 
-'group-user-member'          => 'Bruker',
-'group-autoconfirmed-member' => 'Autobekreftet bruker',
+'group-user-member'          => 'bruker',
+'group-autoconfirmed-member' => 'autobekreftet bruker',
 'group-bot-member'           => 'robot',
 'group-sysop-member'         => 'administrator',
 'group-bureaucrat-member'    => 'byråkrat',
-'group-suppress-member'      => 'Sidefjerner',
+'group-suppress-member'      => 'revisjonsfjerner',
 
 'grouppage-user'          => '{{ns:project}}:Brukere',
 'grouppage-autoconfirmed' => '{{ns:project}}:Autobekreftede brukere',
@@ -1143,23 +1147,24 @@
 'reupload'                    => 'Last opp fil igjen',
 'reuploaddesc'                => 'Avbryt opplasting og gå tilbake til opplastingsskjemaet',
 'uploadnologin'               => 'Ikke logget inn',
-'uploadnologintext'           => 'Du må være [[Special:Userlogin|loggett inn]] for å kunne laste opp filer.',
+'uploadnologintext'           => 'Du må være [[Special:UserLogin|loggett inn]] for å kunne laste opp filer.',
 'upload_directory_missing'    => 'Oppplastingsmappen ($1) mangler og kunne ikke opprettes av tjeneren.',
 'upload_directory_read_only'  => 'Opplastingsmappa ($1) er ikke skrivbar for tjeneren.',
 'uploaderror'                 => 'Feil under opplasting av fil',
-'uploadtext'                  => "Bruk skjemaet under for å laste opp filer. For å se eller søke i tidligere opplastede filer, gå til [[Special:Imagelist|listen over filer]]. Opplastinger lagres også i [[Special:Log/upload|opplastingsloggen]].
+'uploadtext'                  => "Bruk skjemaet nedenfor for å laste opp filer.
+For å se eller søke i eksisterende filer, gå til [[Special:ImageList|listen over filer]]. Opplastinger lagres også i [[Special:Log/upload|opplastingsloggen]].
 
 For å inkludere en fil på en side, bruk en slik lenke:
-*'''<nowiki>[[</nowiki>{{ns:image}}:Filnavn.jpg<nowiki>]]</nowiki>'''
-*'''<nowiki>[[</nowiki>{{ns:image}}:Filnavn.png|Alternativ tekst<nowiki>]]</nowiki>'''
-For å lenke direkte til filen, skriv:
-*'''<nowiki>[[</nowiki>{{ns:media}}:Filnavn.ogg<nowiki>]]</nowiki>'''",
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}:Filnavn.jpg<nowiki>]]</nowiki></tt>''' for å bruke bildet i opprinnelig form
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}:Filnavn.png|200px|thumb|left|Alternativ tekst<nowiki>]]</nowiki></tt>''' for å bruke bildet med en bredde på 200&nbsp;piksler, venstrestilt og med «Alternativ tekst» som beskrivelse
+*'''<tt><nowiki>[[</nowiki>{{ns:media}}:Filnavn.ogg<nowiki>]]</nowiki></tt>''' for å lenke direkte til filen uten å vise den",
 'upload-permitted'            => 'Tillatte filtyper: $1.',
 'upload-preferred'            => 'Foretrukne filtyper: $1',
 'upload-prohibited'           => 'Forbudte filtyper: $1.',
 'uploadlog'                   => 'opplastingslogg',
 'uploadlogpage'               => 'Opplastingslogg',
-'uploadlogpagetext'           => 'Her er en liste over de siste opplastede filene.',
+'uploadlogpagetext'           => 'Her er en liste over de siste opplastede filene.
+Se [[Special:NewImages|galleriet over nye filer]] for en mer visuell visning',
 'filename'                    => 'Filnavn',
 'filedesc'                    => 'Beskrivelse',
 'fileuploadsummary'           => 'Beskrivelse:',
@@ -1230,9 +1235,11 @@
 'upload-proto-error'      => 'Gal protokoll',
 'upload-proto-error-text' => 'Fjernopplasting behøver adresser som begynner med <code>http://</code> eller <code>ftp://</code>.',
 'upload-file-error'       => 'Intern feil',
-'upload-file-error-text'  => 'En intern feil oppsto under forsøk på å lage en midlertidig fil på tjeneren. Vennligst kontakt en systemadministrator.',
+'upload-file-error-text'  => 'En intern feil oppsto under forsøk på å lage en midlertidig fil på tjeneren. Vennligst kontakt en [[Special:ListUsers/sysop|administrator]].',
 'upload-misc-error'       => 'Ukjent opplastingsfeil',
-'upload-misc-error-text'  => 'En ukjent feil forekom under opplastingen. Vennligst bekreft at adressen er gyldig og tilgjengelig, og prøv igjen. Om problemet fortsetter, kontakt en systemadministrator.',
+'upload-misc-error-text'  => 'En ukjent feil forekom under opplastingen.
+Bekreft at adressen er gyldig og tilgjengelig, og prøv igjen.
+Om problemet fortsetter, kontakt en [[Special:ListUsers/sysop|administrator]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Kunne ikke nå adressen',
@@ -1246,7 +1253,7 @@
 'upload_source_url'  => ' (en gyldig, offentlig tilgjengelig adresse)',
 'upload_source_file' => ' (en fil på din datamaskin)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Denne spesialsiden viser alle opplastede filer. De sist opplastede filene vises på toppen som standard. Klikk på en kolonneoverskrift for å endre sorteringsmetode.',
 'imagelist_search_for'  => 'Søk etter filnavn:',
 'imgfile'               => 'fil',
@@ -1272,10 +1279,10 @@
 'imagelinks'                     => 'Lenker',
 'linkstoimage'                   => 'Følgende {{PLURAL:$1|side|$1 sider}} har lenker til denne fila:',
 'nolinkstoimage'                 => 'Det er ingen sider som bruker denne fila.',
-'morelinkstoimage'               => 'Vis [[Special:Whatlinkshere/$1|flere lenker]] til denne filen.',
+'morelinkstoimage'               => 'Vis [[Special:WhatLinksHere/$1|flere lenker]] til denne filen.',
 'redirectstofile'                => 'Følgende {{PLURAL:$1|fil er en omdirigering|filer er omdirigeringer}} til denne filen:',
 'duplicatesoffile'               => 'Følgende {{PLURAL:$1|fil er en dublett|filer er dubletter}} av denne filen:',
-'sharedupload'                   => 'Denne fila deles av andre prosjekter.',
+'sharedupload'                   => 'Denne filen er en delt opplasting og kan brukes av andre prosjekter.',
 'shareduploadwiki'               => 'Se $1 for mer informasjon.',
 'shareduploadwiki-desc'          => 'Beskrivelsen som vist på dens $1 vises nedenfor.',
 'shareduploadwiki-linktext'      => 'filbeskrivelsesside',
@@ -1291,18 +1298,18 @@
 # File reversion
 'filerevert'                => 'Tilbakestill $1',
 'filerevert-legend'         => 'Tilbakestill fil',
-'filerevert-intro'          => '<span class="plainlinks">Du tilbakestiller \'\'\'[[Media:$1|$1]]\'\'\' til [$4 versjonen à $2, $3].</span>',
+'filerevert-intro'          => "Du tilbakestiller '''[[Media:$1|$1]]''' til [$4 versjonen à $2, $3].",
 'filerevert-comment'        => 'Kommentar:',
 'filerevert-defaultcomment' => 'Tilbakestilte til versjonen à $1, $2',
 'filerevert-submit'         => 'Tilbakestill',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ble tilbakestilt til [$4 versjonen à $2, $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ble tilbakestilt til [$4 versjonen à $2, $3].",
 'filerevert-badversion'     => 'Det er ingen tidligere lokal versjon av denne filen med det gitte tidstrykket.',
 
 # File deletion
 'filedelete'                  => 'Slett $1',
 'filedelete-legend'           => 'Slett fil',
 'filedelete-intro'            => "Du sletter '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Du sletter versjonen av \'\'\'[[Media:$1|$1]]\'\'\' à [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Du sletter versjonen av '''[[Media:$1|$1]]''' à [$4 $3, $2].",
 'filedelete-comment'          => 'Slettingsårsak:',
 'filedelete-submit'           => 'Slett',
 'filedelete-success'          => "'''$1''' ble slettet.",
@@ -1362,8 +1369,10 @@
 De burde i stedet lenke til en passende innholdsside.<br />
 En side anses om en pekerside om den inneholder en mal som det lenkes til fra [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Doble omdirigeringer',
-'doubleredirectstext' => "'''NB:''' Denne listen kan inneholde gale resultater. Det er som regel fordi siden inneholder ekstra tekst under den første <tt>#redirect</tt>.<br />Hver linje inneholder lenker til den første og den andre omdirigeringen, og den første linjen fra den andre omdirigeringsteksten. Det gir som regel den «riktige» målartikkelen, som den første omdirigeringen skulle ha pekt på.",
+'doubleredirects'            => 'Doble omdirigeringer',
+'doubleredirectstext'        => "'''NB:''' Denne listen kan inneholde gale resultater. Det er som regel fordi siden inneholder ekstra tekst under den første <tt>#redirect</tt>.<br />Hver linje inneholder lenker til den første og den andre omdirigeringen, og den første linjen fra den andre omdirigeringsteksten. Det gir som regel den «riktige» målartikkelen, som den første omdirigeringen skulle ha pekt på.",
+'double-redirect-fixed-move' => '[[$1]] har blitt flyttet, og er nå en omdirigering til [[$2]]',
+'double-redirect-fixer'      => 'Omdirigeringsfikser',
 
 'brokenredirects'        => 'Brutte omdirigeringer',
 'brokenredirectstext'    => 'Følgende omdirigeringer peker til ikkeeksisterende sider.',
@@ -1448,7 +1457,7 @@
 'logempty'             => 'Ingen elementer i loggen.',
 'log-title-wildcard'   => 'Søk i titler som starter med denne teksten',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle sider',
 'alphaindexline'    => '$1 til $2',
 'nextpage'          => 'Neste side ($1)',
@@ -1471,14 +1480,15 @@
 'special-categories-sort-count' => 'soter etter antall',
 'special-categories-sort-abc'   => 'sorter alfabetisk',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Vis brukere fra og med:',
 'listusers-submit'   => 'Vis',
 'listusers-noresult' => 'Ingen bruker funnet.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rettigheter for brukergrupper',
-'listgrouprights-summary'  => 'Følgende er en liste over brukergrupper som er definert på denne wikien, og hvilke rettigheter de har. Mer informasjon om de enkelte rettighetstypene kan finnes [[{{MediaWiki:Listgrouprights-helppage}}|her]].',
+'listgrouprights-summary'  => 'Følgende er en liste over brukergrupper som er definert på denne wikien, og hvilke rettigheter de har.
+Mer informasjon om de enkelte rettighetstypene kan finnes [[{{MediaWiki:Listgrouprights-helppage}}|her]].',
 'listgrouprights-group'    => 'Gruppe',
 'listgrouprights-rights'   => 'Rettigheter',
 'listgrouprights-helppage' => 'Help:Grupperettigheter',
@@ -1486,10 +1496,11 @@
 
 # E-mail user
 'mailnologin'     => 'Ingen avsenderadresse',
-'mailnologintext' => 'Du må være [[Special:Userlogin|logget inn]] og ha en gyldig e-postadresse satt i [[Special:Preferences|brukerinnstillingene]] for å sende e-post til andre brukere.',
+'mailnologintext' => 'Du må være [[Special:UserLogin|logget inn]] og ha en gyldig e-postadresse satt i [[Special:Preferences|brukerinnstillingene]] for å sende e-post til andre brukere.',
 'emailuser'       => 'E-post til denne brukeren',
 'emailpage'       => 'E-post til bruker',
-'emailpagetext'   => 'Hvis denne brukeren har oppgitt en gyldig e-postadresse i sine innstillinger, vil dette skjemaet sende en enkelt beskjed. Den e-postadressen du har satt i innstillingene dine vil dukke opp i «fra»-feltet på denne e-posten, så mottakeren er i stand til å svare.',
+'emailpagetext'   => 'Hvis denne brukeren har oppgitt en gyldig e-postadresse i sine innstillinger, vil dette skjemaet sende en enkelt beskjed.
+Den e-postadressen du har satt i [[Special:Preferences|innstillingene dine]] vil dukke opp i «fra»-feltet på denne e-posten, så mottakeren er i stand til å svare.',
 'usermailererror' => 'E-postobjekt returnerte feilen:',
 'defemailsubject' => 'E-post fra {{SITENAME}}',
 'noemailtitle'    => 'Ingen e-postadresse',
@@ -1512,13 +1523,13 @@
 'nowatchlist'          => 'Du har ingenting i overvåkningslisten.',
 'watchlistanontext'    => 'Vennligst $1 for å vise eller redigere sider på overvåkningslisten din.',
 'watchnologin'         => 'Ikke logget inn',
-'watchnologintext'     => 'Du må være [[Special:Userlogin|logget inn]] for å kunne endre overvåkningslisten.',
+'watchnologintext'     => 'Du må være [[Special:UserLogin|logget inn]] for å kunne endre overvåkningslisten.',
 'addedwatch'           => 'Lagt til overvåkningslisten.',
-'addedwatchtext'       => "Siden «<nowiki>$1</nowiki>» er lagt til [[Special:Watchlist|overvåkningslisten]]. Fremtidige endringer til denne siden og den tilhørende diskusjonssiden blir listet opp her, og siden vil fremstå '''uthevet''' i [[Special:Recentchanges|listen over de siste endringene]] for å gjøre det lettere å finne den.
+'addedwatchtext'       => "Siden «[[:$1]]» er lagt til [[Special:Watchlist|overvåkningslisten]]. Fremtidige endringer til denne siden og den tilhørende diskusjonssiden blir listet opp her, og siden vil fremstå '''uthevet''' i [[Special:RecentChanges|listen over de siste endringene]] for å gjøre det lettere å finne den.
 
 Hvis du senere vil fjerne siden fra overvåkningslisten, klikk «Avslutt overvåkning» på den aktuelle siden.",
 'removedwatch'         => 'Fjernet fra overvåkningslisten',
-'removedwatchtext'     => 'Siden «[[:$1]]» er fjernet fra overvåkningslisten din.',
+'removedwatchtext'     => 'Siden «[[:$1]]» er fjernet fra [[Special:Watchlist|overvåkningslisten din]].',
 'watch'                => 'Overvåk',
 'watchthispage'        => 'Overvåk denne siden',
 'unwatch'              => 'Avslutt overvåkning',
@@ -1613,13 +1624,15 @@
 'rollbacklink'                => 'tilbakestill',
 'rollbackfailed'              => 'Kunne ikke tilbakestille',
 'cantrollback'                => 'Kan ikke fjerne redigering; den siste brukeren er den eneste forfatteren.',
-'alreadyrolled'               => 'Kan ikke fjerne den siste redigeringen på [[$1]] av [[User:$2|$2]] ([[User talk:$2|diskusjon]]); en annen har allerede redigert siden eller fjernet redigeringen. Den siste redigeringen er foretatt av [[User:$3|$3]] ([[User talk:$3|diskusjon]]).',
+'alreadyrolled'               => 'Kan ikke fjerne den siste redigeringen på [[$1]] av [[User:$2|$2]] ([[User talk:$2|diskusjon]] | [[Special:Contributions/$2|{{int:contribslink}}]]); en annen har allerede redigert siden eller fjernet redigeringen.
+
+Den siste redigeringen ble foretatt av [[User:$3|$3]] ([[User talk:$3|diskusjon]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => "Redigeringskommentaren var: «''$1''»", # only shown if there is an edit comment
 'revertpage'                  => 'Tilbakestilte endring av [[Special:Contributions/$2|$2]] ([[User talk:$2|diskusjon]]) til siste versjon av [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Tilbakestilte endringer av $1; endret til siste versjon av $2.',
 'sessionfailure'              => "Det ser ut til å være et problem med innloggingen din, og den ble avbrutt av sikkerhetshensyn. Trykk ''Tilbake'' i nettleseren din, oppdater siden og prøv igjen.",
 'protectlogpage'              => 'Låsingslogg',
-'protectlogtext'              => 'Her er en liste over sider som er blitt beskyttet eller har fått fjernet beskyttelsen. Se [[Special:Protectedpages|listen over låste sider]] for en liste over nåværende låste sider.',
+'protectlogtext'              => 'Her er en liste over sider som er blitt beskyttet eller har fått fjernet beskyttelsen. Se [[Special:ProtectedPages|listen over låste sider]] for en liste over nåværende låste sider.',
 'protectedarticle'            => 'låste [[$1]]',
 'modifiedarticleprotection'   => 'endret beskyttelsesnivå for «[[$1]]»',
 'unprotectedarticle'          => 'åpnet [[$1]]',
@@ -1724,7 +1737,7 @@
 
 # What links here
 'whatlinkshere'            => 'Lenker hit',
-'whatlinkshere-title'      => 'Sider som lenker til $1',
+'whatlinkshere-title'      => 'Sider som lenker til «$1»',
 'whatlinkshere-page'       => 'Side:',
 'linklistsub'              => '(Liste over lenker)',
 'linkshere'                => "Følgende sider lenker til '''[[:$1]]''':",
@@ -1772,7 +1785,7 @@
 'ipbwatchuser'                    => 'Overvåk brukerens brukerside og diskusjonsside',
 'badipaddress'                    => 'Ugyldig IP-adresse.',
 'blockipsuccesssub'               => 'Blokkering utført',
-'blockipsuccesstext'              => 'IP-adressen «$1» er blokkert. Se [[Special:Ipblocklist|blokkeringslisten]] for alle blokkeringer.',
+'blockipsuccesstext'              => 'IP-adressen «$1» er blokkert. Se [[Special:IPBlockList|blokkeringslisten]] for alle blokkeringer.',
 'ipb-edit-dropdown'               => 'Rediger blokkeringsgrunner',
 'ipb-unblock-addr'                => 'Avblokker $1',
 'ipb-unblock'                     => 'Avblokker et brukernavn eller en IP-adresse',
@@ -1783,7 +1796,7 @@
 'ipusubmit'                       => 'Opphev blokkeringen av denne adressen',
 'unblocked'                       => '[[User:$1|$1]] ble avblokkert',
 'unblocked-id'                    => 'Blokkering $1 ble fjernet',
-'ipblocklist'                     => 'Liste over blokkerte IP-adresser og brukere',
+'ipblocklist'                     => 'Blokkerte IP-adresser og brukere',
 'ipblocklist-legend'              => 'Finn en blokkert bruker',
 'ipblocklist-username'            => 'Brukernavn eller IP-adresse:',
 'ipblocklist-submit'              => 'Søk',
@@ -1802,7 +1815,7 @@
 'autoblocker'                     => 'Du ble automatisk blokkert fordi du deler IP-adresse med «[[User:$1|$1]]». Grunnen som ble gitt til at «$1» ble blokkert var: «$2».',
 'blocklogpage'                    => 'Blokkeringslogg',
 'blocklogentry'                   => 'blokkerte «[[$1]]» med en varighet på $2 $3',
-'blocklogtext'                    => 'Dette er en logg som viser hvilke brukere som har blitt blokkert og avblokkert. Automatisk blokkerte IP-adresser vises ikke. Se [[Special:Ipblocklist|blokkeringslisten]] for en liste over IP-adresser som er blokkert akkurat nå.',
+'blocklogtext'                    => 'Dette er en logg som viser hvilke brukere som har blitt blokkert og avblokkert. Automatisk blokkerte IP-adresser vises ikke. Se [[Special:IPBlockList|blokkeringslisten]] for en liste over IP-adresser som er blokkert akkurat nå.',
 'unblocklogentry'                 => 'opphevet blokkeringen av $1',
 'block-log-flags-anononly'        => 'kun uregistrerte brukere',
 'block-log-flags-nocreate'        => 'kontooppretting slått av',
@@ -1843,7 +1856,7 @@
 'locknoconfirm'       => 'Du har ikke bekreftet handlingen.',
 'lockdbsuccesssub'    => 'Databasen er nå låst',
 'unlockdbsuccesssub'  => 'Databasen er nå lås opp',
-'lockdbsuccesstext'   => 'Databasen er låst.<br />Husk å [[Special:Unlockdb|låse den opp]] når du er ferdig med vedlikeholdet.',
+'lockdbsuccesstext'   => 'Databasen er låst.<br />Husk å [[Special:UnlockDB|låse den opp]] når du er ferdig med vedlikeholdet.',
 'unlockdbsuccesstext' => 'Databasen er låst opp.',
 'lockfilenotwritable' => 'Kan ikke skrive til databasen. For å låse eller åpne databasen, må denne kunne skrives til av tjeneren.',
 'databasenotlocked'   => 'Databasen er ikke låst.',
@@ -1853,8 +1866,9 @@
 'move-page-legend'        => 'Flytt side',
 'movepagetext'            => "Når du bruker skjemaet under, vil du få omdøpt en side og flyttet hele historikken til det nye navnet.
 Den gamle tittelen blir en omdirigeringsside til den nye tittelen.
-Lenker til den gamle tittelen blir ikke endret.
-Eventuelle omdirigeringer blir brutt.
+Du kan oppdatere omdirigeringer som peker til den originale tittelen automatisk.
+Om du velger å ikke gjøre det, sjekk at flyttingen ikke skaper noen [[Special:Doubleredirects|doble]] eller [[Special:Brokenredirects|ødelagte omdirigeringer]].
+Du er ansvarlig for at lenker fortsetter å peke til de sidene de er ment å peke til.
 
 Legg merke til at siden '''ikke''' kan flyttes hvis det allerede finnes en side med den nye tittelen, med mindre den siden er tom eller er en omdirigering uten noen historikk.
 Det betyr at du kan flytte en side tilbake dit den kom fra hvis du gjør en feil.
@@ -1868,8 +1882,6 @@
 
 I disse tilfellene er du nødt til å flytte eller flette sammen siden manuelt.",
 'movearticle'             => 'Flytt side:',
-'movenologin'             => 'Ikke logget inn',
-'movenologintext'         => 'Du må være registrert bruker og være [[Special:Userlogin|logget på]] for å flytte en side.',
 'movenotallowed'          => 'Du har ikke tillatelse til å flytte sider på {{SITENAME}}.',
 'newtitle'                => 'Ny tittel',
 'move-watch'              => 'Overvåk denne siden',
@@ -1895,7 +1907,7 @@
 'revertmove'              => 'tilbakestill',
 'delete_and_move'         => 'Slett og flytt',
 'delete_and_move_text'    => '==Sletting nødvendig==
-Målsiden «[[$1]]» finnes allerede. Vil du slette den så denne siden kan flyttes dit?',
+Målsiden «[[:$1]]» finnes allerede. Vil du slette den så denne siden kan flyttes dit?',
 'delete_and_move_confirm' => 'Ja, slett siden',
 'delete_and_move_reason'  => 'Slettet grunnet flytting',
 'selfmove'                => 'Kilde- og destinasjonstittel er den samme; kan ikke flytte siden.',
@@ -1903,6 +1915,7 @@
 'imagenocrossnamespace'   => 'Kan ikke flytte bilder til andre navnerom enn bildenavnerommet',
 'imagetypemismatch'       => 'Den nye filendelsen tilsvarer ikke filtypen',
 'imageinvalidfilename'    => 'Målnavnet er ugyldig',
+'fix-double-redirects'    => 'Oppdater omdirigeringer som fører til den gamle tittelen',
 
 # Export
 'export'            => 'Eksportsider',
@@ -1948,7 +1961,7 @@
 'import-interwiki-history'   => 'Kopier all historikk for denne siden',
 'import-interwiki-submit'    => 'Importer',
 'import-interwiki-namespace' => 'Flytt sidene til navnerommet:',
-'importtext'                 => 'Importer fila fra kildewikien med Special:Export-verktøyet, lagre den på den egen datamaskin, og last den opp hit.',
+'importtext'                 => 'Importer fila fra kildewikien med [[Special:Export|eksporteringsverktøyet]], lagre den på den egen datamaskin, og last den opp hit.',
 'importstart'                => 'Importerer sider&nbsp;…',
 'import-revision-count'      => '({{PLURAL:$1|Én revisjon|$1 revisjoner}})',
 'importnopages'              => 'Ingen sider å importere.',
@@ -2040,12 +2053,26 @@
 'tooltip-upload'                  => 'Start opplasting',
 
 # Stylesheets
-'common.css'   => '/* CSS plassert i denne fila vil gjelde for alle utseender. */',
-'monobook.css' => '/* rediger denne filen for å tilpasse Monobook-skinnet for hele siden */',
+'common.css'      => '/* CSS plassert i denne fila vil gjelde for alle utseender. */',
+'standard.css'    => '/* CSS i denne fila vil gjelde alle som bruker drakta Standard */',
+'nostalgia.css'   => '/* CSS i denne fila vil gjelde alle som bruker drakta Nostalgia */',
+'cologneblue.css' => '/* CSS i denne fila vil gjelde alle som bruker drakta Kølnerblå */',
+'monobook.css'    => '/* CSS i denne fila vil gjelde alle som bruker drakta Monobook */',
+'myskin.css'      => '/* CSS i denne fila vil gjelde alle som bruker drakta Myskin */',
+'chick.css'       => '/* CSS i denne fila vil gjelde alle som bruker drakta Chick */',
+'simple.css'      => '/* CSS i denne fila vil gjelde alle som bruker drakta Simple */',
+'modern.css'      => '/* CSS i denne fila vil gjelde alle som bruker drakta Modern */',
 
 # Scripts
-'common.js'   => '/* All JavaScript i denne fila vil bli lastet for alle brukere på hver side. */',
-'monobook.js' => '/* Javascript herfra lastes for brukere som bruker utseendet Monobook */',
+'common.js'      => '/* Javascript i denne fila vil gjelde for alle drakter. */',
+'standard.js'    => '/* Javascript i denne fila vil gjelde for brukere av drakta Standard */',
+'nostalgia.js'   => '/* Javascript i denne fila vil gjelde for brukere av drakta Nostalgia */',
+'cologneblue.js' => '/* Javascript i denne fila vil gjelde for brukere av drakta Kølnerblå */',
+'monobook.js'    => '/* Javascript i denne fila vil gjelde for brukere av drakta Monobook */',
+'myskin.js'      => '/* Javascript i denne fila vil gjelde for brukere av drakta Myskin */',
+'chick.js'       => '/* Javascript i denne fila vil gjelde for brukere av drakta Chick */',
+'simple.js'      => '/* Javascript i denne fila vil gjelde for brukere av drakta Simple */',
+'modern.js'      => '/* Javascript i denne fila vil gjelde for brukere av drakta Modern */',
 
 # Metadata
 'nodublincore'      => 'Dublin Core RDF-metadata er slått av på denne tjeneren.',
@@ -2098,9 +2125,10 @@
 'markedaspatrollederror-noautopatrol' => 'Du kan ikke merke dine egne endringer som godkjente.',
 
 # Patrol log
-'patrol-log-page' => 'Godkjenningslogg',
-'patrol-log-line' => 'merket $1 av $2 godkjent $3',
-'patrol-log-auto' => '(automatisk)',
+'patrol-log-page'   => 'Godkjenningslogg',
+'patrol-log-header' => 'Dette er en logg over patruljerte sideversjoner.',
+'patrol-log-line'   => 'merket $1 av $2 godkjent $3',
+'patrol-log-auto'   => '(automatisk)',
 
 # Image deletion
 'deletedrevision'                 => 'Slettet gammel revisjon $1.',
@@ -2129,7 +2157,7 @@
 'show-big-image'       => 'Full oppløsning',
 'show-big-image-thumb' => '<small>Størrelse på denne forhåndsvisningen: $1 × $2 piksler</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galleri over nye filer',
 'imagelisttext'         => "Dete er en liste med '''$1''' {{PLURAL:$1|fil|filer}} sortert $2.",
 'newimages-summary'     => 'Denne spesialsiden viser de sist opplastede filene.',
@@ -2139,6 +2167,9 @@
 'bydate'                => 'etter dato',
 'sp-newimages-showfrom' => 'Vis nye filer fra og med $2 $1',
 
+# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
+'hours-abbrev' => 't',
+
 # Bad image list
 'bad_image_list' => 'Formatet er slik:
 
@@ -2412,7 +2443,7 @@
 
 # External editor support
 'edit-externally'      => 'Rediger denne fila med et eksternt program',
-'edit-externally-help' => 'Se [http://meta.wikimedia.org/wiki/Help:External_editors oppsettsinstruksjonene] for mer informasjon.',
+'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors oppsettsinstruksjonene] for mer informasjon.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alle',
@@ -2474,7 +2505,7 @@
 'recreate'            => 'Gjenopprett',
 
 # HTML dump
-'redirectingto' => 'Omdirigerer til [[$1]]&nbsp;…',
+'redirectingto' => 'Omdirigerer til [[:$1]]&nbsp;…',
 
 # action=purge
 'confirm_purge'        => "Vil du slette tjenerens mellomlagrede versjon (''cache'') av denne siden? $1",
@@ -2597,7 +2628,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Versjon',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Filsti',
 'filepath-page'    => 'Fil:',
 'filepath-submit'  => 'Sti',
@@ -2634,7 +2665,7 @@
 'specialpages-group-redirects'   => 'Omdirigerende spesialsider',
 'specialpages-group-spam'        => 'Spamverktøy',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Tom side',
 'intentionallyblankpage' => 'Denne siden er tom med vilje',
 
Index: languages/messages/MessagesHsb.php
===================================================================
--- languages/messages/MessagesHsb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHsb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,11 +6,8 @@
  *
  * @author Dundak
  * @author Michawiki
- * @author Siebrand
  * @author Tlustulimu
  * @author לערי ריינהארט
- * @author M.M.S.
- * @author SPQRobin
  */
 
 $fallback = 'de';
@@ -388,7 +385,7 @@
 'nosuchspecialpage' => 'Tuta specialna strona njeeksistuje.',
 'nospecialpagetext' => "<big>'''Tuta specialna strona wikiju njeeksistuje.'''</big>
 
-Lisćina płaćiwych specialnych stronow hodźi so pod [[Special:Specialpages|Lis´cina specialnych stronow]] namakać.",
+Lisćina płaćiwych specialnych stronow hodźi so pod [[Special:SpecialPages|Lis´cina specialnych stronow]] namakać.",
 
 # General errors
 'error'                => 'Zmylk',
@@ -414,12 +411,12 @@
 'readonlytext'         => 'Datowa banka je tuchwilu za nowe zapiski a druhe změny zawrjena, najskerje wothladowanskich dźěłow dla; po jich zakónčenju budźe wšitko zaso normalne.
 
 Administrator, kiž je datowu banku zawrěł, je jako přičinu podał: $1',
-'missing-article'      => 'Datowa banka njenamaka tekst strony z mjenom "$1" $2, kotryž dyrbhał so namakać.
+'missing-article'      => 'Datowa banka njenamaka tekst strony z mjenom "$1" $2, kotryž dyrbjał so namakać.
 
 To so zwjetša zawinuje, hdyž so njepłaćiwa změna abo zapisk stawiznow na stronu wotkazuje, kotraž bu wušmórnjena.
 
-Jeli to njetrjechi, sy najskerje programowu zmóku w softwarje namakał.
-Zdźěl to prošu admininistratorej podawajo wotpowědny URL.',
+Jeli to njetrjechi, sy najskerje programowu zmólku w softwarje namakał.
+Zdźěl to prošu [[Special:ListUsers/sysop|admininistratorej]] podawajo wotpowědny URL.',
 'missingarticle-rev'   => '(Wersijowe čisło: $1)',
 'missingarticle-diff'  => '(Rozdźěl: $1, $2)',
 'readonly_lag'         => 'Datowa banka bu awtomatisce zawrjena, mjeztym zo pospytuja wotwisne serwery datowych bankow  hłowny serwer docpěć',
@@ -474,7 +471,7 @@
 Móžeš {{GRAMMAR:akuzatiw|{{SITENAME}}}} nětko anonymnje dale wužiwać abo so ze samsnym abo druhim wužiwarskim mjenom zaso přizjewić. Wobkedźbuj zo so někotre strony dale jewja kaž by hišće přizjewjeny był doniž pufrowak swojeho wobhladowaka njewuprózdnješ.',
 'welcomecreation'            => '== Witaj, $1! ==
 
-Twoje konto bu wutworjene. Njezabudź swoje nastajenja za {{GRAMMAR:akuzatiw|{{SITENAME}}}} změnić.',
+Twoje konto bu wutworjene. Njezabudź swoje nastajenja za [[Special:Preferences|{{GRAMMAR:akuzatiw|{{SITENAME}}}}]] změnić.',
 'loginpagetitle'             => 'Přizjewjenje',
 'yourname'                   => 'Wužiwarske mjeno',
 'yourpassword'               => 'Hesło',
@@ -635,10 +632,6 @@
 'blockededitsource'                => 'Tekst <b>twojich změnow</b> strony <b>$1</b> so tu pokazuje:',
 'whitelistedittitle'               => 'Za wobdźěłowanje je přizjewjenje trěbne.',
 'whitelistedittext'                => 'Dyrbiš so $1, zo by strony wobdźěłować móhł.',
-'whitelistreadtitle'               => 'Za čitanje je přizjewjenje trěbne.',
-'whitelistreadtext'                => 'Dyrbiš so [[Special:Userlogin|přizjewić]], zo by strony čitać móhł.',
-'whitelistacctitle'                => 'Njesměš konto wutworić',
-'whitelistacctext'                 => 'Zo by konta we {{SITENAME}} wutworjeć směł, dyrbiš so [[Special:Userlogin|přizjewić]] a trěbne dowolnosće měć.',
 'confirmedittitle'                 => 'Twoja e-mejlowa adresa dyrbi so wobkrućić, prjedy hač móžeš strony wobdźěłować.',
 'confirmedittext'                  => 'Dyrbiš swoju e-mejlowu adresa wobkrućić, prjedy hač móžeš strony wobdźěłować. Prošu zapodaj a wobkruć swoju e-mejlowu adresu we [[Special:Preferences|wužiwarskich nastajenjach]].',
 'nosuchsectiontitle'               => 'Wotrězk njeeksistuje',
@@ -650,7 +643,7 @@
 'accmailtext'                      => 'Hesło za wužiwarja "$1" bu na adresu $2 pósłane.',
 'newarticle'                       => '(Nowy nastawk)',
 'newarticletext'                   => 'Sy wotkaz k stronje slědował, kotraž hišće njeeksistuje. Zo by stronu wutworił, wupjelń slědowace tekstowe polo (hlej [[{{MediaWiki:Helppage}}|stronu pomocy]] za dalše informacije). Jeli sy zmylnje tu, klikń prosće na tłóčatko <b>Wróćo</b> we swojim wobhladowaku.',
-'anontalkpagetext'                 => "---- ''To je diskusijna strona za anonymneho wužiwarja, kiž hišće konto wutworił njeje abo je njewužiwa. Dyrbimy tohodla numerisku IP-adresu wužiwać, zo bychmy jeho/ju identifikowali. Tajka IP-adresa hodźi so wot wjacorych wužiwarjow zhromadnje wužiwać. Jeli sy anonymny wužiwar a měniš, zo buchu irelewantne komentary k tebi pósłane, [[Special:Userlogin|wutwor konto abo přizjew so]], zo by přichodnu šmjatańcu wobešoł.''",
+'anontalkpagetext'                 => "---- ''To je diskusijna strona za anonymneho wužiwarja, kiž hišće konto wutworił njeje abo je njewužiwa. Dyrbimy tohodla numerisku IP-adresu wužiwać, zo bychmy jeho/ju identifikowali. Tajka IP-adresa hodźi so wot wjacorych wužiwarjow zhromadnje wužiwać. Jeli sy anonymny wužiwar a měniš, zo buchu irelewantne komentary k tebi pósłane, [[Special:UserLogin|wutwor konto abo přizjew so]], zo by přichodnu šmjatańcu wobešoł.''",
 'noarticletext'                    => 'Tuchwilu tuta strona žadyn tekst njewobsahuje, móžeš jeje titul w druhich stronach [[Special:Search/{{PAGENAME}}|pytać]] abo [{{fullurl:{{FULLPAGENAME}}|action=edit}} stronu wobdźěłać].',
 'userpage-userdoesnotexist'        => 'Wužiwarske konto „$1“ njeje zregistrowane. Prošu pruwuj, hač chceš tutu stronu woprawdźe wutworić/wobdźěłać.',
 'clearyourcache'                   => '<b>Kedźbu:</b> Po składowanju dyrbiš snano pufrowak swojeho wobhladowaka wuprózdnić, <b>Mozilla/Firefox/Safari:</b> tłóč na <i>Umsch</i> kliknjo na <i>Znowa</i> abo tłóč <i>Strg-Umsch-R</i> (<i>Cmd-Shift-R</i> na Apple Mac); <b>IE:</b> tłóč <i>Strg</i> kliknjo na symbol <i>Aktualisieren</i> abo tłóč <i>Strg-F5</i>; <b>Konqueror:</b>: Klikń jenož na tłóčatko <i>Erneut laden</i> abo tłoč  <i>F5</i>; Wužiwarjo <b>Opery</b> móža swój pufrowak dospołnje  w <i>Tools→Preferences</i> wuprózdnić.',
@@ -707,7 +700,7 @@
 'hiddencategories'                 => 'Tuta strona je čłon w {{PLURAL:$1|1 schowanej kategoriji|$1 schowanymaj kategorijomaj|$1 schowanych kategorijach|$1 schowanych kategorijach}}:',
 'edittools'                        => '<!-- Tutón tekst so spody wobdźěłowanskich a nahrawanskich formularow pokazuje. -->',
 'nocreatetitle'                    => 'Wutworjenje stron je wobmjezowane.',
-'nocreatetext'                     => 'Na {{GRAMMAR:Lokatiw|{{SITENAME}}}} bu wutworjenje nowych stronow wobmjezowane. Móžeš wobstejace strony wobdźěłać abo [[Special:Userlogin|so přizjewić abo wužiwarske konto wutworić]].',
+'nocreatetext'                     => 'Na {{GRAMMAR:Lokatiw|{{SITENAME}}}} bu wutworjenje nowych stronow wobmjezowane. Móžeš wobstejace strony wobdźěłać abo [[Special:UserLogin|so přizjewić abo wužiwarske konto wutworić]].',
 'nocreate-loggedin'                => 'Nimaš prawo, zo by nowe strony w tutym wikiju wutworił.',
 'permissionserrors'                => 'Woprawnjenske zmylki',
 'permissionserrorstext'            => 'Nimaš prawo, zo by tutu akciju wuwjedł. {{PLURAL:$1|Přičina|Přičiny}}:',
@@ -731,7 +724,7 @@
 'undo-success' => 'Wersija je so wuspěšnje wotstroniła. Prošu přepruwuj deleka w přirunanskim napohledźe, hač twoja změna bu přewzata a klikń potom na „Składować”, zo by změnu składował.',
 'undo-failure' => '<span class="error">Wobdźěłanje njehodźeše so wotstronić, dokelž wotpowědny wotrězk bu mjeztym změnjeny.</span>',
 'undo-norev'   => 'Změna njeda so cofnyć, dokelž njeeksistuje abo bu wušmórnjena.',
-'undo-summary' => 'Wersija $1 wužiwarja [[Special:Contributions/$2|$2]] ([[User talk:$2|diskusija]]) bu wotstronjena.',
+'undo-summary' => 'Změna $1 [[Special:Contributions/$2|$2]] ([[User talk:$2|diskusija]]) bu cofnjena.',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Wužiwarske konto njeda so wutworić.',
@@ -815,7 +808,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Protokol potłóčenjow',
-'suppressionlogtext' => 'Deleka je lisćina wušmórnjenjow a zablokowanjow, inkluziwnje wobsaha schowaneho wot administratorow. Hlej [[Special:Ipblocklist|Lisćina zablokowanjow IP]] za lisćinu tuchwilnych zablokowanjow.',
+'suppressionlogtext' => 'Deleka je lisćina wušmórnjenjow a zablokowanjow, inkluziwnje wobsaha schowaneho wot administratorow. Hlej [[Special:IPBlockList|Lisćina zablokowanjow IP]] za lisćinu tuchwilnych zablokowanjow.',
 
 # History merging
 'mergehistory'                     => 'Stawizny stronow zjednoćić',
@@ -855,7 +848,7 @@
 # Search results
 'searchresults'             => 'Pytanske wuslědki',
 'searchresulttext'          => 'Za dalše informacije wo pytanju {{GRAMMAR:genitiw|{{SITENAME}}}}, hlej [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => 'Sy naprašowanje za „[[:$1|$1]]“ stajił.',
+'searchsubtitle'            => 'Sy za \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|wšěmi stronami, kotrež započinaja so z "$1"]] | [[Special:WhatLinksHere/$1|wšěmi stronami, kotrež na "$1" wotkazuja]]) pytal.',
 'searchsubtitleinvalid'     => 'Sy naprašowanje za „$1“ stajił.',
 'noexactmatch'              => "'''Strona z titulom \"\$1\" njeeksistuje.'''
 Móžeš [[:\$1|tutu stronu wutworić]].",
@@ -899,7 +892,7 @@
 'mypreferences'            => 'moje nastajenja',
 'prefs-edits'              => 'Ličba změnow:',
 'prefsnologin'             => 'Njepřizjewjeny',
-'prefsnologintext'         => 'Dyrbiš [[Special:Userlogin|přizjewjeny]] być, zo by nastajenja postajić móhł.',
+'prefsnologintext'         => 'Dyrbiš [[Special:UserLogin|přizjewjeny]] być, zo by nastajenja postajić móhł.',
 'prefsreset'               => 'Nastajenja su so ze składa wróćo stajili. Twoje změnjenja njejsu so składowali.',
 'qbsettings'               => 'Pobóčna lajsta',
 'qbsettings-none'          => 'Žane',
@@ -972,7 +965,7 @@
 'userrights-reason'           => 'Přičina:',
 'userrights-no-interwiki'     => 'Nimaš prawo wužiwarske prawa w druhich wikijach změnić.',
 'userrights-nodatabase'       => 'Datowa banka $1 njeeksistuje abo lokalna njeje.',
-'userrights-nologin'          => 'Dyrbiš so z admininstratorowym kontom [[Special:Userlogin|přizjewić]], zo by wužiwarske prawa změnił.',
+'userrights-nologin'          => 'Dyrbiš so z admininstratorowym kontom [[Special:UserLogin|přizjewić]], zo by wužiwarske prawa změnił.',
 'userrights-notallowed'       => 'Twoje konto nima trěbne prawa, zo by wužiwarske prawa přidźělił.',
 'userrights-changeable-col'   => 'Skupiny, kotrež móžeš změnić',
 'userrights-unchangeable-col' => 'Skupiny, kotrež njemóžeš změnić',
@@ -1103,12 +1096,12 @@
 'reupload'                    => 'Znowa nahrać',
 'reuploaddesc'                => 'Nahraće přetorhnyć a so k nahrawanskemu formularej wróćić.',
 'uploadnologin'               => 'Njepřizjewjeny',
-'uploadnologintext'           => 'Dyrbiš [[Special:Userlogin|přizjewjeny]] być, zo by dataje nahrawać móhł.',
+'uploadnologintext'           => 'Dyrbiš [[Special:UserLogin|přizjewjeny]] być, zo by dataje nahrawać móhł.',
 'upload_directory_missing'    => 'Zapis nahraćow ($1) faluje a njeda so přez webserwer wutworić.',
 'upload_directory_read_only'  => 'Nahrawanski zapis ($1) njehodźi so přez webserwer popisować.',
 'uploaderror'                 => 'Zmylk při nahrawanju',
 'uploadtext'                  => "Wužij formular deleka, zo by nowe dataje nahrał.
-Zo by prjedy nahrate dataje wobhladał abo pytał dźi k [[Special:Imagelist|lisćinje nahratych datajow]], nahraća a wušmórnjenja so tež w [[Special:Log/upload|protokolu nahraćow]] protokoluja.
+Zo by prjedy nahrate dataje wobhladał abo pytał dźi k [[Special:ImageList|lisćinje nahratych datajow]], nahraća a wušmórnjenja so tež w [[Special:Log/upload|protokolu nahraćow]] protokoluja.
 
 Zo by dataju do strony zapřijał, wužij wotkaz we formje
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Dataja.jpg]]</nowiki>''',
@@ -1119,7 +1112,8 @@
 'upload-prohibited'           => 'Zakazane datajowe typy: $1.',
 'uploadlog'                   => 'Protokol nahraćow',
 'uploadlogpage'               => 'Protokol nahraćow',
-'uploadlogpagetext'           => 'Deleka je lisćina naposledk nahratych datajow.',
+'uploadlogpagetext'           => 'Deleka je lisćina najnowšich nahratych datajow.
+Hlej [[Special:NewImages|galeriju nowych datajow]] za wizuelny přehlad.',
 'filename'                    => 'Mjeno dataje',
 'filedesc'                    => 'Zjeće',
 'fileuploadsummary'           => 'Zjeće:',
@@ -1210,7 +1204,7 @@
 'upload_source_url'  => ' (płaćiwy, zjawnje docpějomny URL)',
 'upload_source_file' => ' (dataja na twojim ličaku)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Tuta specialna strona naliči wšě nahrate dataje. Standardnje so naposlědk nahrate dateje cyle horjeka pokazuja. Kliknjo na nadpisma stołpikow móžeš sortěrowanje wobroćić abo po druhich kriterijach rjadować.',
 'imagelist_search_for'  => 'Za mjenom wobraza pytać:',
 'imgfile'               => 'dataja',
@@ -1236,7 +1230,7 @@
 'imagelinks'                     => 'Wotkazy',
 'linkstoimage'                   => '{{PLURAL:$1|Slědowaca strona wotkazuje|Slědowacej $1 stronje wotkazujetej|Slědowace $1 strony wotkazuja|Slědowacych $1 stronow wotkazuje}} na tutu dataju:',
 'nolinkstoimage'                 => 'Njejsu strony, kotrež na tutu dataju wotkazuja.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Dalše wotkazy]] k tutej dataji wobhladać.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Dalše wotkazy]] k tutej dataji wobhladać.',
 'redirectstofile'                => '{{PLURAL:$1|Slědowaca dataja pósrednja|Slědowacej $1 pósrědnjatej|Slědowace $1 posrědnjaju|Slěddowacych $1 pósrědnja}} k toś tej dataji dalej:',
 'duplicatesoffile'               => '{{PLURAL:$1|Slědowaca dataja je duplikat|Slědowacej $1 dataji stej duplikata|Slědowace $1 dataje su duplikaty|Slědowacych $1 duplikatow je duplikaty}} tuteje dataje:',
 'sharedupload'                   => 'Tuta dataja je zhromadne nahraće a móže so přez druhe projekty wužiwać.',
@@ -1255,18 +1249,18 @@
 # File reversion
 'filerevert'                => 'Wersiju $1 cofnyć',
 'filerevert-legend'         => 'Dataju wróćo stajeć',
-'filerevert-intro'          => '<span class="plainlinks">Stajiš dataju \'\'\'[[Media:$1|$1]]\'\'\' na [$4 wersiju wot $2, $3 hodź.] wróćo.</span>',
+'filerevert-intro'          => "Stajiš dataju '''[[Media:$1|$1]]''' na [$4 wersiju wot $2, $3 hodź.] wróćo.",
 'filerevert-comment'        => 'Přičina:',
 'filerevert-defaultcomment' => 'wróćo stajene na wersiju wot $1, $2 hodź.',
 'filerevert-submit'         => 'Cofnyć',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' bu na [$4 wersiju wot $2, $3 hodź.] wróćo stajeny.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' bu na [$4 wersiju wot $2, $3 hodź.] wróćo stajeny.",
 'filerevert-badversion'     => 'W zapodatym času žana wersija dataje njeje.',
 
 # File deletion
 'filedelete'                  => '„$1“ wušmórnyć',
 'filedelete-legend'           => 'Wušmórnju dataju',
 'filedelete-intro'            => "Wušmórnješ '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Wušmórnješ wersiju \'\'\'[[Media:$1|$1]]\'\'\' wot [$4 wot $2, $3 hodź].</span>',
+'filedelete-intro-old'        => "Wušmórnješ wersiju '''[[Media:$1|$1]]''' wot [$4 wot $2, $3 hodź].",
 'filedelete-comment'          => 'Přičina:',
 'filedelete-submit'           => 'Wušmórnyć',
 'filedelete-success'          => "Strona '''„$1“''' bu wušmórnjena.",
@@ -1319,15 +1313,16 @@
 Běše dohromady '''$3''' {{PLURAL:$3|wobhladanje|wobhladani|wobhladanja|wobhladanjow}} stronow a '''$4''' {{PLURAL:$4|změna|změnje|změny|změnow}} stronow, wot toho zo bu {{SITENAME}} připrawjeny. Bě to přerěznje '''$5''' {{PLURAL:$5|změna|změnje|změny|změnow}} na stronu a '''$6''' {{PLURAL:$6|wobhladanje|wobhladani|wobhladanja|wobhladanjow}} na změnu.
 
 Dołhosć [http://www.mediawiki.org/wiki/Manual:Job_queue rynka nadawkow] je '''$7'''.",
-'userstatstext'          => "{{PLURAL:$1|Je '''1''' [[Special:Listusers|wužiwar]] zregistrowany|Staj '''$1''' [[Special:Listusers|wužiwarjej]] zregistrowanej|Su '''$1''' [[Special:Listusers|wužiwarjo]] zregistrowani|Je '''$1''' [[Special:Listusers|wužiwarjow]] zregistrowanych}}, '''$2''' (abo '''$4%''') z nich {{PLURAL:$2|je|staj|su|je}} $5.",
+'userstatstext'          => "{{PLURAL:$1|Je '''1''' [[Special:ListUsers|wužiwar]] zregistrowany|Staj '''$1''' [[Special:ListUsers|wužiwarjej]] zregistrowanej|Su '''$1''' [[Special:ListUsers|wužiwarjo]] zregistrowani|Je '''$1''' [[Special:ListUsers|wužiwarjow]] zregistrowanych}}, '''$2''' (abo '''$4%''') z nich {{PLURAL:$2|je|staj|su|je}} $5.",
 'statistics-mostpopular' => 'Najhusćišo wopytowane strony',
 
 'disambiguations'      => 'Rozjasnjenja wjacezmyslnosće',
 'disambiguationspage'  => 'Template:Wjacezmyslnosć',
 'disambiguations-text' => "Slědowace strony na '''rozjasnjenje wjacezmyslnosće''' wotkazuja. Měli město toho na poprawnu stronu wotkazać.<br />Strona so jako rozjasnjenje wjacezmyslnosće zarjaduje, jeli předłohu wužiwa, na kotruž so wot [[MediaWiki:Disambiguationspage]] wotkazuje.",
 
-'doubleredirects'     => 'Dwójne daleposrědkowanja',
-'doubleredirectstext' => 'Kóžda rjadka wobsahuje wotkazy k prěnjemu a druhemu daleposrědkowanju kaž tež k prěnjej lince druheho daleposrědkowanja, kotraž zwjetša woprawdźity cil strony podawa, na kotryž prěnje daleposrědkowanje měło pokazać.',
+'doubleredirects'            => 'Dwójne daleposrědkowanja',
+'doubleredirectstext'        => 'Kóžda rjadka wobsahuje wotkazy k prěnjemu a druhemu daleposrědkowanju kaž tež k prěnjej lince druheho daleposrědkowanja, kotraž zwjetša woprawdźity cil strony podawa, na kotryž prěnje daleposrědkowanje měło pokazać.',
+'double-redirect-fixed-move' => '[[$1]] bu přesunjeny, je nětko daleposrědkowanje do [[$2]]',
 
 'brokenredirects'        => 'Skóncowane daleposrědkowanja',
 'brokenredirectstext'    => 'Slědowace daleposrědkowanja wotkazuja na njeeksistowace strony:',
@@ -1412,7 +1407,7 @@
 'logempty'             => 'Žane wotpowědowace zapiski w protokolu.',
 'log-title-wildcard'   => 'Titul započina so z …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Wšě nastawki',
 'alphaindexline'    => '$1 do $2',
 'nextpage'          => 'přichodna strona ($1)',
@@ -1435,12 +1430,12 @@
 'special-categories-sort-count' => 'Po ličbje sortěrować',
 'special-categories-sort-abc'   => 'Alfabetisce sortěrować',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Započinajo z:',
 'listusers-submit'   => 'Pokazać',
 'listusers-noresult' => 'Njemóžno wužiwarjow namakać. Prošu wobkedźbuj, zo so mało- abo wulkopisanje na wotprašowanje wuskutkuje.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Prawa wužiwarskeje skupiny',
 'listgrouprights-summary'  => 'Slěduje lisćina wužiwarskich skupinow na tutej wikiji z jich wotpowědnymi přistupnymi prawami. Přidatne informacije wo jednotliwych prawach móžeš [[{{MediaWiki:Listgrouprights-helppage}}|tu namakać]].',
 'listgrouprights-group'    => 'Skupina',
@@ -1450,7 +1445,7 @@
 
 # E-mail user
 'mailnologin'     => 'Njejsy přizjewjeny.',
-'mailnologintext' => 'Dyrbiš [[Special:Userlogin|přizjewjeny]] być a płaćiwu e-mejlowu adresu w swojich [[Special:Preferences|nastajenjach]] měć, zo by druhim wužiwarjam mejlki pósłać móhł.',
+'mailnologintext' => 'Dyrbiš [[Special:UserLogin|přizjewjeny]] być a płaćiwu e-mejlowu adresu w swojich [[Special:Preferences|nastajenjach]] měć, zo by druhim wužiwarjam mejlki pósłać móhł.',
 'emailuser'       => 'Wužiwarjej mejlku pósłać',
 'emailpage'       => 'Wužiwarjej mejlku pósłać',
 'emailpagetext'   => 'Jeli tutón wužiwar je płaćiwu e-mejlowu adresu w swojich nastajenjach zapodał, budźe formular deleka mejlku słać.
@@ -1477,10 +1472,10 @@
 'nowatchlist'          => 'Nimaš žane strony w swojich wobkedźbowankach.',
 'watchlistanontext'    => 'Dyrbiš so $1, zo by swoje wobkedźbowanki wobhladać abo wobdźěłać móhł.',
 'watchnologin'         => 'Njejsy přizjewjeny.',
-'watchnologintext'     => 'Dyrbiš [[Special:Userlogin|přizjewjeny]] być, zo by swoje wobkedźbowanki změnić móhł.',
+'watchnologintext'     => 'Dyrbiš [[Special:UserLogin|přizjewjeny]] być, zo by swoje wobkedźbowanki změnić móhł.',
 'addedwatch'           => 'Strona bu wobkedźbowankam přidata.',
 'addedwatchtext'       => "Strona [[:$1]] bu k twojim [[Special:Watchlist|wobkedźbowankam]] přidata.
-Přichodne změny tuteje strony a přisłušneje diskusijneje strony budu so tam nalistować a strona so '''w tučnym pismje''' w [[Special:Recentchanges|lisćinje aktualnych změnach]] zjewi, zo by so wosnadniło ju wubrać.
+Přichodne změny tuteje strony a přisłušneje diskusijneje strony budu so tam nalistować a strona so '''w tučnym pismje''' w [[Special:RecentChanges|lisćinje aktualnych změnach]] zjewi, zo by so wosnadniło ju wubrać.
 
 Jeli chceš stronu pozdźišo ze swojich wobkedźbowankow wotstronić, klikń na rajtark „njewobkedźbować” horjeka na tutej stronje.",
 'removedwatch'         => 'Strona bu z wobkedźbowankow wotstronjena',
@@ -1591,7 +1586,7 @@
 'sessionfailure'              => 'Zda so, zo je problem z twojim přizjewjenjom; tuta akcija bu wěstosće dla přećiwo zadobywanju do posedźenja znjemóžniła. Prošu klikń na "Wróćo" a začitaj stronu, z kotrejež přińdźeš, znowa; potom spytaj hišće raz.',
 'protectlogpage'              => 'Protokol škita',
 'protectlogtext'              => 'To je protokol škitanych stronow a zběhnjenja škita.
-Hlej [[Special:Protectedpages|tutu specialnu stronu]] za lisćinu škitanych stron.',
+Hlej [[Special:ProtectedPages|tutu specialnu stronu]] za lisćinu škitanych stron.',
 'protectedarticle'            => 'je stronu [[$1]] škitał',
 'modifiedarticleprotection'   => 'je škit strony [[$1]] změnił',
 'unprotectedarticle'          => 'je škit strony [[$1]] zběhnył',
@@ -1747,7 +1742,7 @@
 'badipaddress'                    => 'Njepłaćiwa IP-adresa',
 'blockipsuccesssub'               => 'Zablokowanje wuspěšne',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] bu zablokowany.
-<br />Hlej [[Special:Ipblocklist|lisćinu blokowanjow IP]], zo by zablokowanjow pruwował.',
+<br />Hlej [[Special:IPBlockList|lisćinu blokowanjow IP]], zo by zablokowanjow pruwował.',
 'ipb-edit-dropdown'               => 'přičiny zablokowanjow wobdźěłać',
 'ipb-unblock-addr'                => 'zablokowanje wužiwarja „$1“ zběhnyć',
 'ipb-unblock'                     => 'zablokowanje wužiwarja abo IP-adresy zběhnyć',
@@ -1758,7 +1753,7 @@
 'ipusubmit'                       => 'Zablokowanje zběhnyć',
 'unblocked'                       => 'Blokowanje wužiwarja [[User:$1|$1]] zběhnjene',
 'unblocked-id'                    => 'Blokowanje ID $1 bu zběhnjene.',
-'ipblocklist'                     => 'Lisćina zablokowanych IP-adresow a wužiwarskich mjenow',
+'ipblocklist'                     => 'Zablokowane IP-adresy a wužiwarske mjena',
 'ipblocklist-legend'              => 'Pytanje za zablokowanym wužiwarjom',
 'ipblocklist-username'            => 'Wužiwarske mjeno abo IP-adresa:',
 'ipblocklist-submit'              => 'Pytać',
@@ -1777,7 +1772,7 @@
 'autoblocker'                     => 'Awtomatiske blokowanje, dokelž twoja IP-adresa bu njedawno wot wužiwarja „[[User:$1|$1]]” wužita. Přičina, podata za blokowanje $1, je: "$2"',
 'blocklogpage'                    => 'Protokol zablokowanjow',
 'blocklogentry'                   => 'je wužiwarja [[$1]] zablokował z časom spadnjenja $2 $3',
-'blocklogtext'                    => 'To je protokol blokowanja a wotblokowanja wužiwarjow. Awtomatisce blokowane IP-adresy so njenalistuja. Hlej [[Special:Ipblocklist|lisćinu zablokowanych IP-adresow]] za lisćinu tuchwilnych wuhnaćow a zablokowanjow.',
+'blocklogtext'                    => 'To je protokol blokowanja a wotblokowanja wužiwarjow. Awtomatisce blokowane IP-adresy so njenalistuja. Hlej [[Special:IPBlockList|lisćinu zablokowanych IP-adresow]] za lisćinu tuchwilnych wuhnaćow a zablokowanjow.',
 'unblocklogentry'                 => 'zablokowanje wužiwarja $1 bu zběhnjene',
 'block-log-flags-anononly'        => 'jenož anonymnych',
 'block-log-flags-nocreate'        => 'wutworjenje wužiwarskich kontow znjemóžnjene',
@@ -1813,7 +1808,7 @@
 'lockdbsuccesssub'    => 'Datowa banka bu wuspěšnje zamknjena.',
 'unlockdbsuccesssub'  => 'Datowa banka bu wuspěšnje wotamknjena.',
 'lockdbsuccesstext'   => 'Datowa banka bu zamknjena.
-<br />Njezabudź [[Special:Unlockdb|wotzamknyć]], po tym zo wothladowanje je sčinjene.',
+<br />Njezabudź [[Special:UnlockDB|wotzamknyć]], po tym zo wothladowanje je sčinjene.',
 'unlockdbsuccesstext' => 'Datowa banka bu wotamknjena.',
 'lockfilenotwritable' => 'Do dataje zamknjenja datoweje banki njeda so zapisować. Za zamknjenje abo wotamknjenje datoweje banki dyrbi webowy serwer pisanske prawo měć.',
 'databasenotlocked'   => 'Datajowa banka zamknjena njeje.',
@@ -1832,8 +1827,6 @@
 
 W tutych padach dyrbiš stronu manuelnje přesunyć abo zaměšeć, jeli sej to přeješ.',
 'movearticle'             => 'Stronu přesunyć',
-'movenologin'             => 'Njejsy přizjewjeny.',
-'movenologintext'         => 'Dyrbiš zregistrowany wužiwar a [[Special:Userlogin|přizjewjeny]] być, zo by stronu přesunyć móhł.',
 'movenotallowed'          => 'Nimaš w tutym wikiju prawo, zo by strony přesunył.',
 'newtitle'                => 'pod nowe hesło',
 'move-watch'              => 'Stronu wobkedźbować',
@@ -1860,7 +1853,7 @@
 'delete_and_move'         => 'wušmórnyć a přesunyć',
 'delete_and_move_text'    => '== Wušmórnjenje trěbne ==
 
-Cilowa strona „[[$1]]” hižo eksistuje. Chceš ju wušmórnyć, zo by so přesunjenje zmóžniło?',
+Cilowa strona „[[:$1]]” hižo eksistuje. Chceš ju wušmórnyć, zo by so přesunjenje zmóžniło?',
 'delete_and_move_confirm' => 'Haj, stronu wušmórnyć.',
 'delete_and_move_reason'  => 'Strona bu wušmórnjena, zo by so přesunjenje zmóžniło.',
 'selfmove'                => 'Žórłowy a cilowy titl stej samsnej; strona njehodźi so na sebje samu přesunyć.',
@@ -1868,6 +1861,7 @@
 'imagenocrossnamespace'   => 'Wobraz njeda so do druheho mjenoweho ruma hač wobraz přesunyć',
 'imagetypemismatch'       => 'Nowa dataja swojemu typej njewotpowěduje',
 'imageinvalidfilename'    => 'Mjeno ciloweje dataje je njepłaćiwe',
+'fix-double-redirects'    => 'Daleposrědkowanja aktualizować, kotrež na prěnjotny titul pokazuja',
 
 # Export
 'export'            => 'Strony eksportować',
@@ -1911,7 +1905,7 @@
 'import-interwiki-history'   => 'Wšě wersije ze stawiznow tuteje strony kopěrować',
 'import-interwiki-submit'    => 'Importować',
 'import-interwiki-namespace' => 'Strony importować do mjenoweho ruma:',
-'importtext'                 => 'Prošu eksportuj dataju ze žórłoweho wikija wužiwajo stronu Special:Export, składuj ju na swoju tačel a nahraj ju sem.',
+'importtext'                 => 'Prošu eksportuj dataju ze žórłoweho wikija z pomocu [[Special:Export|Strony eksportować]]. Składuj ju na swojim ličaku a nahraj ju sem.',
 'importstart'                => 'Importuju…',
 'import-revision-count'      => '$1 {{PLURAL:$1|wersija|wersiji|wersije|wersijow}}',
 'importnopages'              => 'Žane strony za importowanje.',
@@ -2061,10 +2055,11 @@
 'markedaspatrollederror-noautopatrol' => 'Njesměš swoje změny jako přepruwowane woznamjenjeć.',
 
 # Patrol log
-'patrol-log-page' => 'Protokol přepruwowanjow',
-'patrol-log-line' => 'je $1 strony $2 jako přepruwowanu markěrował $3.',
-'patrol-log-auto' => '(awtomatisce)',
-'patrol-log-diff' => 'wersiju $1',
+'patrol-log-page'   => 'Protokol přepruwowanjow',
+'patrol-log-header' => 'To je protokol dohladowanych wersijow.',
+'patrol-log-line'   => 'je $1 strony $2 jako přepruwowanu markěrował $3.',
+'patrol-log-auto'   => '(awtomatisce)',
+'patrol-log-diff'   => 'wersiju $1',
 
 # Image deletion
 'deletedrevision'                 => 'Stara wersija $1 wušmórnjena',
@@ -2094,7 +2089,7 @@
 'show-big-image'       => 'Wersija z wyšim rozeznaćom',
 'show-big-image-thumb' => '<small>Wulkosć miniaturki: $1 × $2 pikselow</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Nowe dataje',
 'imagelisttext'         => "Deleka je lisćina '''$1''' {{PLURAL:$1|dataje|datajow|datajow|datajow}}, kotraž je po $2 sortěrowana.",
 'newimages-summary'     => 'Tuta specialna strona naliči aktualnje nahrate wobrazy a druhe dataje.',
@@ -2374,7 +2369,7 @@
 
 # External editor support
 'edit-externally'      => 'Dataju z eksternym programom wobdźěłać',
-'edit-externally-help' => 'Hlej [http://meta.wikimedia.org/wiki/Help:External_editors pokiwy za instalaciju] za dalše informacije.',
+'edit-externally-help' => 'Hlej [http://www.mediawiki.org/wiki/Manual:External_editors pokiwy za instalaciju] za dalše informacije.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'wšě',
@@ -2431,7 +2426,7 @@
 'recreate'            => 'Znowa wutworić',
 
 # HTML dump
-'redirectingto' => 'Posrědkuju k stronje [[$1]]',
+'redirectingto' => 'Posrědkuju k stronje [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Pufrowak strony wuprózdnić? $1',
@@ -2534,7 +2529,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Wersija',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Datajowy puć',
 'filepath-page'    => 'Dataja:',
 'filepath-submit'  => 'Puć',
@@ -2572,7 +2567,7 @@
 'specialpages-group-redirects'   => 'Daleposrědkowace specialne strony',
 'specialpages-group-spam'        => 'Spamowe nastroje',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Prózdna strona',
 'intentionallyblankpage' => 'Tuta strona je z wotpohladom prózdna.',
 
Index: languages/messages/MessagesFy.php
===================================================================
--- languages/messages/MessagesFy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
+ * @author Maartenvdbent
  * @author Pyt
  * @author Snakesteuben
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Maartenvdbent
  */
 
 $skinNames = array(
@@ -372,10 +370,10 @@
 <p>$1</p>',
 'missing-article'      => 'Yn de database is gjin ynhâld oantroffen foar de side "$1" dy\'t der wol wêze moatte soe ($2). 
 
-Dat kin foarkomme as Jo in ferâldere ferwizing nei it ferskil tusken twa ferzjes fan in side folgje of in ferzje opfreegje dy\'t fuorthelle is.
+Dat kin foarkomme as Jo in ferâldere ferwizing nei it ferskil tusken twa ferzjes fan in side folgje of in ferzje opfreegje dy\'t wiske is.
 
 As dat net sa is, hawwe Jo faaks in fout yn \'e software fûn.
-Meitsje dêr melding fan by in systeembehearder fan {{SITENAME}} en neam dêrby de URL fan dizze side.',
+Meitsje dêr melding fan by in [[Special:ListUsers/sysop|systeembehearder]] fan {{SITENAME}} en neam dêrby de URL fan dizze side.',
 'missingarticle-rev'   => '(ferzjenûmer: $1)',
 'missingarticle-diff'  => '(Feroaring: $1, $2)',
 'readonly_lag'         => 'De database is automatysk beskoattele wylst de ûndergeskikte databaseservers syngronisearje mei de haadserver.',
@@ -424,14 +422,15 @@
 
 # Login and logout pages
 'logouttitle'                => 'Ofmelde',
-'logouttext'                 => "<strong>Jo binne no ôfmeld.</strong><br />
+'logouttext'                 => "<strong>Jo binne no ôfmeld.</strong>
+
 Jo kinne de {{SITENAME}} fierders anonym brûke,
-of jo op 'e nij oanmelde ûnder deselde of in oare namme.
+of jo op 'e [[Special:UserLogin|nij oanmelde]] ûnder deselde of in oare namme.
 Mûglik wurdt noch in tal siden werjûn as wiene Jo oanmeld, oant Jo de cache fan Jo browser leegje.",
 'welcomecreation'            => '<h2>Wolkom, $1!</h2><p>Jo ynstellings bin oanmakke.
 Ferjit net se oan jo foarkar oan te passen.',
 'loginpagetitle'             => 'Oanmelde',
-'yourname'                   => 'Jo brûkersnamme',
+'yourname'                   => 'Jo brûkersnamme:',
 'yourpassword'               => 'Jo wachtwurd',
 'yourpasswordagain'          => 'Jo wachtwurd (nochris)',
 'remembermypassword'         => 'Oare kear fansels oanmelde.',
@@ -590,10 +589,6 @@
 'blockededitsource'                => "Hjir ûnder stiet de tekst fan '''jo bewurkings''' oan '''$1''':",
 'whitelistedittitle'               => 'Foar bewurkjen is oanmelden ferplichte',
 'whitelistedittext'                => 'Jo moatte $1 om siden te bewurkjen.',
-'whitelistreadtitle'               => 'Foar lêstagong is oanmelden ferplichte',
-'whitelistreadtext'                => '[[Special:Userlogin|Meld jo oan]] foar lêstagong ta siden.',
-'whitelistacctitle'                => 'Jo kinnne gjin brûker registreareje',
-'whitelistacctext'                 => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze en de krekte rjochten hawwe om brûkers oan te meitsjen yn {{SITENAME}}.',
 'confirmedittitle'                 => 'Netpostbefêstiging frege foar bewurkjen',
 'confirmedittext'                  => "Jo moatte jo e-mailadres befêstichje foar't jo siden feroarje kinne. Fier in e-mailedres yn by jo [[Special:Preferences|ynstellings]] en befêstichje it.",
 'nosuchsectiontitle'               => 'Dizze subkop bestiet net',
@@ -608,8 +603,7 @@
 Om sels tekst te meistjsen kinne jo dy gewoan yntype in dit bewurkingsfjild
 ([[{{MediaWiki:Helppage}}|Mear ynformaasje oer bewurkjen]].)
 Oars kinne jo tebek mei de tebek-knop fan jo blêder.",
-'anontalkpagetext'                 => "----
-''Dit is de oerlisside fan in ûnbekinde brûker; in brûker dy't him/har net oanmeld hat. Om't der gjin namme bekend is, wurdt it Ynternet-adres brûkt om oan te jaan wa. Mar faak is it sa dat sa'n adres net altyd troch deselde persoan brûkt wurdt. As jo it idee hawwe dat jo as ûnbekinde brûker opmerkings foar in oar krije, dan kinne jo jo [[Special:Userlogin|oanmelde]], sadat jo allinnich opmerkings foar josels krije.''",
+'anontalkpagetext'                 => "----''Dit is de oerlisside fan in ûnbekende meidogger; in meidogger dy't him/har net oanmeld hat. Om't der gjin namme bekend is, wurdt it Ynternet-adres brûkt om oan te jaan wa. Mar faak is it sa dat sa'n adres net altyd troch deselde persoan brûkt wurdt. As jo it idee hawwe dat jo as ûnbekende meidogger opmerkings foar in oar krije, dan kinne jo [[Special:UserLogin/signup|in meidogger namme oanmeitsje]], of jo [[Special:UserLogin|oanmelde]], sadat jo allinnich opmerkings foar josels krije.''",
 'noarticletext'                    => 'Der stjit noch gjin tekst op dizze side. Jo kinne
 [[Special:Search/{{PAGENAME}}|hjirboppe nei dy tekst sykje]], of [{{fullurl:{{FULLPAGENAME}}|action=edit}} de side skriuwe].',
 'userpage-userdoesnotexist'        => 'Jo bewurkje in brûkersside fan in brûker dy\'t net bestiet (brûker "$1").
@@ -626,7 +620,7 @@
 'previewnote'                      => '<strong>Tink der om dat dizze side noch net fêstlein is!</strong>',
 'previewconflict'                  => 'Dizze side belanget allinich it earste bewurkingsfjild oan.',
 'session_fail_preview'             => "<strong>Spitich! Jo bewurking is net ferwurke, om't de sessygegevens ferlern gien binne.
-Besykje it nochris. As it dan noch net slagget, meld jo dan ôf en wer oan.</strong>",
+Besykje it nochris. As it dan noch net slagget, [[Special:UserLogout|meld jo dan ôf]] en wer oan.</strong>",
 'token_suffix_mismatch'            => "<strong>Jo bewurking is wegere om't jo blêder de lêstekens yn it bewurkingstoken ûnkrekt behannele hat.
 De bewurking is wegere om skeinen fan 'e sidetekst tefoaren te kommen.
 Dat bart soms as der in webbasearre proxytsjinst brûkt wurdt dy't flaters befettet.</strong>",
@@ -666,7 +660,7 @@
 {{PLURAL:$1|kategory|kategoryen}}:',
 'nocreatetitle'                    => 'It oanmeitsjen fan siden is beheind',
 'nocreatetext'                     => '{{SITENAME}} hat de mûglikheid beheind om nije siden te meitsjen.
-Jo kinne al besteande siden feroarje of jo kinne [[Special:Userlogin|jo oanmelde of in brûker oanmeitsje]].',
+Jo kinne al besteande siden feroarje of jo kinne [[Special:UserLogin|jo oanmelde of in brûker oanmeitsje]].',
 'nocreate-loggedin'                => 'Jo kinne gjin nije siden meitsje op {{SITENAME}}.',
 'permissionserrors'                => 'Flaters yn rjochten',
 'permissionserrorstext'            => 'Jo hawwe gjin rjochtem dit te dwaan om de folgjende {{PLURAL:$1|reden|redenen}}:',
@@ -684,7 +678,10 @@
 'post-expand-template-argument-category'  => "Siden dy't missende sjabloaneleminten befetsje",
 
 # "Undo" feature
+'undo-success' => 'De feroaring kin werom set wurde. Kontrolearje de ferliking hjirûnder om wis te wêzen dat jo dit feroarje wolle en druk dan op fêstlizze om it werom setten troch te fieren.',
 'undo-failure' => 'De feroaring kin net ûngedien makke wurde fanwege oare stridige bewurkings.',
+'undo-norev'   => 'De feroaring kin werom set wurde, omdat it net bestiet of is wiske.',
+'undo-summary' => 'Werom sette fan ferzje $1 fan [[Special:Contributions/$2|$2]] ([[User talk:$2|Oerlis]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Registrearjen is mislearre.',
@@ -711,10 +708,52 @@
 'deletedrev'          => '[fuorthelle]',
 'histfirst'           => 'Aldste',
 'histlast'            => 'Nijste',
+'historysize'         => '({{PLURAL:$1|1 byte|$1 bytes}})',
+'historyempty'        => '(leech)',
 
 # Revision feed
+'history-feed-title'          => 'Sideskiednis',
+'history-feed-description'    => 'Sideskiednis foar dizze side op de wiki',
 'history-feed-item-nocomment' => '$1 op $2', # user at time
 
+# Revision deletion
+'rev-deleted-comment'     => '(opmerking wiske)',
+'rev-deleted-user'        => '(meidoggernamme wiske)',
+'rev-delundel'            => 'sjen litte/ferbergje',
+'revisiondelete'          => 'Wiskje/weromsette ferzjes',
+'revdelete-nooldid-title' => 'Gjin doelferzje',
+'revdelete-selected'      => 'Spesifisearre {{PLURAL:$2|ferzje|ferzjes}} fan [[:$1]]:',
+'logdelete-selected'      => '{{PLURAL:$1|keazen lochboekregel|keazen lochboekregels}}:',
+'revdelete-hide-user'     => 'Meidoggernamme/IP fan de meidogger ferskûlje',
+'revdelete-hide-image'    => 'Triem ynhâld ferskûlje',
+'pagehist'                => 'Sideskiednis',
+'deletedhist'             => 'Wiske skiednis',
+'revdelete-content'       => 'ynhâld',
+'revdelete-uname'         => 'meidoggernamme',
+'revdelete-unhid'         => '$1 net mear ferburgen',
+'revdelete-log-message'   => '$1 foar $2 {{PLURAL:$2|ferzje|ferzjes}}',
+'logdelete-log-message'   => '$1 foar $2 {{PLURAL:$2|lochboekregel|lochboekregels}}',
+
+# History merging
+'mergehistory'                     => 'Skiednis fan kombinearjen',
+'mergehistory-box'                 => 'Ferzjes fan twa siden kombinearje:',
+'mergehistory-from'                => 'Triemnamme boarne:',
+'mergehistory-into'                => 'Bestimmingside:',
+'mergehistory-go'                  => "Besjen bewurkings dy't kombinearre wurde kinne",
+'mergehistory-submit'              => 'Kombinearje ferzjes',
+'mergehistory-empty'               => 'Gjin ferzjes kinne kombinearren wurde.',
+'mergehistory-success'             => 'Kombinearjen slagge fan $3 {{PLURAL:$3|ferzje|ferzjes}} fan [[:$1]] no [[:$2]].',
+'mergehistory-fail'                => 'It is net mooglik de skiednis te kombinearje; kontrolearje nochris de side en tiidparameters.',
+'mergehistory-no-source'           => 'Boarneside $1 bestiet net.',
+'mergehistory-no-destination'      => 'Doelside $1 bestiet net.',
+'mergehistory-invalid-source'      => 'De titel fan de boarneside moet jildich wêze.',
+'mergehistory-invalid-destination' => 'De titel fan de doelside moet jildich wêze.',
+'mergehistory-autocomment'         => '[[:$1]] kombinearre mei [[:$2]]',
+'mergehistory-comment'             => '[[:$1]] kombinearre mei [[:$2]]: $3',
+
+# Merge log
+'pagemerge-logentry' => '[[$1]] kombinearre mei [[$2]] (maksimaal $3 ferzjes)',
+
 # Diffs
 'history-title'           => 'Skiednis fan "$1"',
 'difference'              => '(Ferskil tusken ferzjes)',
@@ -724,34 +763,54 @@
 'diff-multi'              => '({{PLURAL:$1|Ien tuskenlizzende ferzje wurdt|$1 tuskenlizzende ferzjes wurde}} net sjen litten.)',
 
 # Search results
-'searchresults'         => 'Sykresultaat',
-'searchresulttext'      => '[[{{MediaWiki:Helppage}}|{{int:help}}]]; Ynformaasje oer it sykjen troch de {{SITENAME}}.',
-'searchsubtitle'        => 'Foar fraach "[[:$1]]"',
-'searchsubtitleinvalid' => 'Foar fraach "$1"',
-'noexactmatch'          => "'''Der is gjin side mei krekt de titel \"\$1\".'''
+'searchresults'             => 'Sykresultaat',
+'searchresulttext'          => 'Lês foar mear ynformaasje oer it sykjen yn de {{SITENAME}} de [[{{MediaWiki:Helppage}}|{{int:help}}]].',
+'searchsubtitle'            => 'Foar fraach "[[:$1]]"',
+'searchsubtitleinvalid'     => 'Foar fraach "$1"',
+'noexactmatch'              => "'''Der is gjin side mei krekt de titel \"\$1\".'''
 Jo kinne de [[:\$1|side oanmeitsje]].",
-'titlematches'          => 'Titels',
-'notitlematches'        => 'Gjin titels',
-'textmatches'           => 'Siden',
-'notextmatches'         => 'Gjin siden',
-'prevn'                 => 'foarige $1',
-'nextn'                 => 'folgende $1',
-'viewprevnext'          => '($1) ($2) ($3) besjen.',
-'showingresults'        => '<b>$1</b> resultaten fan <b>$2</b> ôf.',
-'showingresultsnum'     => '<b>$3</b> resultaten fan <b>$2</b> ôf.',
-'nonefound'             => 'As der gjin resultaten binne, tink der dan om dat der <b>net</b> socht
+'noexactmatch-nocreate'     => "'''Der is gjin side mei krekt de titel \"\$1\".'''",
+'titlematches'              => 'Titels',
+'notitlematches'            => 'Gjin titels',
+'textmatches'               => 'Siden',
+'notextmatches'             => 'Gjin siden',
+'prevn'                     => 'foarige $1',
+'nextn'                     => 'folgende $1',
+'viewprevnext'              => '($1) ($2) ($3) besjen.',
+'search-result-size'        => '$1 ({{PLURAL:$2|1 wurd|$2 wurden}})',
+'search-result-score'       => 'Relevante: $1%',
+'search-redirect'           => '(trochferwizing $1)',
+'search-section'            => '(seksje $1)',
+'search-suggest'            => 'Bedoele jo: $1',
+'search-interwiki-caption'  => 'Susterprojekten',
+'search-interwiki-default'  => '$1 resultaten:',
+'search-interwiki-more'     => '(mear)',
+'search-mwsuggest-enabled'  => 'mei suggestjes',
+'search-mwsuggest-disabled' => 'gjin suggestjes',
+'search-relatedarticle'     => 'Besibbe',
+'searchrelated'             => 'besibbe',
+'searchall'                 => 'alle',
+'showingresults'            => "{{PLURAL:$1|'''1''' resultaat|'''$1''' resultaten}} fan #'''$2''' ôf.",
+'showingresultsnum'         => "{{PLURAL:$3|'''1''' resultaat|'''$3''' resultaten}} fan #'''$2''' ôf.",
+'showingresultstotal'       => "It binne hjirûnder  {{PLURAL:$3|resultaat '''$1''' fan '''$3'''|resultaten '''$1 - $2''' fan '''$3'''}}",
+'nonefound'                 => 'As der gjin resultaten binne, tink der dan om dat der <b>net</b> socht
 wurde kin om wurden as "it" en "in", om\'t dy net byhâlden wurde, en dat as der mear
 wurden syke wurde, allinnich siden fûn wurde wêr\'t <b>alle</b> worden op fûn wurde.',
-'powersearch'           => 'Sykje',
-'searchdisabled'        => "<p>Op it stuit stjit it trochsykjen fan tekst net oan, om't de
+'powersearch'               => 'Sykje',
+'powersearch-legend'        => 'Sykje',
+'powersearch-ns'            => 'Sykje op nammeromten:',
+'powersearch-field'         => 'Sykje op',
+'search-external'           => 'Ekstern sykjen',
+'searchdisabled'            => "<p>Op it stuit stjit it trochsykjen fan tekst net oan, om't de
 tsjinner it net oankin. Mei't we nije apparatuer krije wurdt it nei alle gedanken wer
 mooglik. Foar now kinne jo sykje fia Google:</p>",
 
 # Preferences page
 'preferences'              => 'Ynstellings',
 'mypreferences'            => 'Myn foarkarynstellings',
+'prefs-edits'              => 'Tal bewurkings:',
 'prefsnologin'             => 'Net oanmeld',
-'prefsnologintext'         => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze om jo ynstellings te feroarjen.',
+'prefsnologintext'         => 'Jo moatte [[Special:UserLogin|oanmeld]] wêze om jo ynstellings te feroarjen.',
 'prefsreset'               => "De ynstellings binne tebek set sa't se fêstlein wienen.",
 'qbsettings'               => 'Menu',
 'qbsettings-none'          => 'Ut',
@@ -770,6 +829,15 @@
 'math_unknown_function'    => 'Unbekinde funksje',
 'math_lexing_error'        => 'Unbekind wurd',
 'math_syntax_error'        => 'Sinboufout',
+'math_bad_tmpdir'          => 'De tydlike formulepad kin net skreaun of makke wêze.',
+'math_bad_output'          => 'De formulepad kin net skreaun of makke wêze.',
+'math_notexvc'             => 'It programma texvc net fûn; sjoch math/README te ynstallearjen.',
+'prefs-personal'           => 'Persoanlike gegevens',
+'prefs-rc'                 => 'Koartlyn feroare',
+'prefs-watchlist'          => 'Folchlist',
+'prefs-watchlist-days'     => 'Oantal dagen yn folchlist sjen litte:',
+'prefs-watchlist-edits'    => 'Tal wizigings om sjen te litten yn de útwreide folchlist:',
+'prefs-misc'               => 'Ferskaat',
 'saveprefs'                => 'Ynstellings fêstlizze',
 'resetprefs'               => 'Ynstellings tebek sette',
 'oldpassword'              => 'Ald wachtwurd',
@@ -782,108 +850,166 @@
 'resultsperpage'           => 'Treffers de side',
 'contextlines'             => 'Rigels ynhâld de treffer:',
 'contextchars'             => 'Tekens fan de ynhâld de rigel:',
+'recentchangesdays'        => 'Dagen om sjen te litten yn Koartlyn feroare:',
 'recentchangescount'       => "Nûmer of titels op 'Koarts feroare'",
 'savedprefs'               => 'Jo ynstellings binne fêstlein.',
+'timezonelegend'           => 'Tiidsône',
 'timezonetext'             => 'Jou it tal fan oeren dat jo tiidsône ferskilt fan UTC (Greenwich).',
 'localtime'                => 'Jo tiidsône',
 'timezoneoffset'           => 'Ferskil',
 'servertime'               => 'UTC',
 'guesstimezone'            => 'Freegje de blêder',
 'allowemail'               => 'Netpost fan oare meidoggers tastean',
+'prefs-searchoptions'      => 'Sykje-ynstellings',
+'prefs-namespaces'         => 'Nammeromten',
 'defaultns'                => "Nammeromten dy't normaal trochsocht wurde:",
+'default'                  => 'standert',
+'files'                    => 'Triemen',
 
 # User rights
-'userrights'  => 'Behear fan meidoggerrjochten', # Not used as normal message but as header for the special page itself
-'editinguser' => "Bewurkje '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'userrights'                  => 'Behear fan meidoggerrjochten', # Not used as normal message but as header for the special page itself
+'userrights-lookup-user'      => 'Behear fan meidoggerrjochten',
+'userrights-user-editname'    => 'Meidoggernamme:',
+'editusergroup'               => 'Wizigje meidoggerrjochten',
+'editinguser'                 => "Bewurkje meidoggerrjochten fan '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'userrights-editusergroup'    => 'Wizigje meidoggerrjochten',
+'saveusergroups'              => 'Meidoggerrjochten fêstlizze',
+'userrights-groupsmember'     => 'Sit yn group:',
+'userrights-reason'           => 'Utlis foar wizigjen:',
+'userrights-no-interwiki'     => "Jo hawwe gjin rjochten om meidoggerrjochten op oare wiki's te wizigjen.",
+'userrights-nologin'          => 'Jo moatte jo [[Special:UserLogin|oanmelde]] as rjochtenútfurder om rjochten fan meidoggers wizigje te kinnen.',
+'userrights-notallowed'       => 'Jo hawwe gjin rjochten om rjochten fan meidoggers te wizigjen.',
+'userrights-changeable-col'   => "Groepen dy't jo beheare kinne",
+'userrights-unchangeable-col' => "Groepen dy't jo net beheare kinne",
 
-'grouppage-sysop' => '{{ns:project}}:Behearders',
+# Groups
+'group'            => 'Groep:',
+'group-user'       => 'Meidoggers',
+'group-bot'        => 'Bots',
+'group-sysop'      => 'Behearders',
+'group-bureaucrat' => 'Rjochtenútfurders',
+'group-all'        => '(alle)',
 
+'group-user-member'       => 'Meidogger',
+'group-bot-member'        => 'Bot',
+'group-sysop-member'      => 'Behearder',
+'group-bureaucrat-member' => 'Rjochtenútfurder',
+
+'grouppage-user'       => '{{ns:project}}:Meidoggers',
+'grouppage-bot'        => '{{ns:project}}:Bots',
+'grouppage-sysop'      => '{{ns:project}}:Behearders',
+'grouppage-bureaucrat' => '{{ns:project}}:Rjochtenútfurders',
+
+# Rights
+'right-read'                 => 'Siden sjen',
+'right-edit'                 => 'Siden bewurkjen',
+'right-createpage'           => 'Siden oanmeitsjen (net oerlissiden)',
+'right-createtalk'           => 'Oerlissiden oanmeitsjen',
+'right-minoredit'            => 'Bydragen markearje as tekstwiziging',
+'right-move'                 => 'Siden werneamen',
+'right-upload'               => 'Triemmen oanbieden',
+'right-reupload'             => 'In besteande triem oerskriuwen',
+'right-upload_by_url'        => 'Triemen oanbieden fia in URL',
+'right-delete'               => 'Siden wiskjen',
+'right-bigdelete'            => 'Wiskjen siden mei grutte skiednis',
+'right-deleterevision'       => 'Spesifisearre ferzjes fan siden wiskjen',
+'right-importupload'         => 'Ymportearjen siden fan in triemoanbied',
+'right-userrights'           => 'Alle meidoggerrjochten bywurkje',
+'right-userrights-interwiki' => "Wizigje meidoggerrjochten fan meidoggers yn oare wiki's",
+
 # User rights log
-'rightslog' => 'Brûkersrjochte-lochboek',
+'rightslog'      => 'Brûkersrjochte-lochboek',
+'rightslogtext'  => 'Hjirûnder binne de wizigjen fan meidoggerrjochten.',
+'rightslogentry' => 'groep is feroare foar meidogger $1 fan $2 no $3',
+'rightsnone'     => '(gjin)',
 
 # Recent changes
-'nchanges'                       => '$1 {{PLURAL:$1|bewurking|bewurkings}}',
-'recentchanges'                  => 'Koarts feroare',
-'recentchangestext'              => 'De lêste feroarings fan de {{SITENAME}}.',
-'recentchanges-feed-description' => 'Mei dizze feed kinne jo de nijste feroarings yn dizze wiki besjen.',
-'rcnote'                         => 'Dit binne de lêste <strong>$1</strong> feroarings yn de lêste <strong>$2</strong> dagen.',
-'rcnotefrom'                     => 'Dit binne de feroarings sûnt <b>$2</b> (maksimaal <b>$1</b>).',
-'rclistfrom'                     => 'Jou nije feroarings, begjinnende mei $1',
-'rcshowhideminor'                => 'lytse feroarings $1',
-'rcshowhidebots'                 => 'bots $1',
-'rcshowhideliu'                  => 'oanmelde brûkers $1',
-'rcshowhideanons'                => 'anonime brûkers $1',
-'rcshowhidepatr'                 => 'kontrolearre bewurkings $1',
-'rcshowhidemine'                 => 'myn bewurkings $1',
-'rclinks'                        => 'Jou $1 nije feroarings yn de lêste $2 dagen; $3 tekstwiziging',
-'diff'                           => 'ferskil',
-'hist'                           => 'skiednis',
-'hide'                           => 'gjin',
-'show'                           => 'al',
-'minoreditletter'                => 'T',
-'newpageletter'                  => 'N',
-'boteditletter'                  => 'b',
+'nchanges'                          => '$1 {{PLURAL:$1|bewurking|bewurkings}}',
+'recentchanges'                     => 'Koarts feroare',
+'recentchangestext'                 => 'De lêste feroarings fan de {{SITENAME}}.',
+'recentchanges-feed-description'    => 'Mei dizze feed kinne jo de nijste feroarings yn dizze wiki besjen.',
+'rcnote'                            => "Dit {{PLURAL:$1|is de lêste feroaring|binne de lêste '''$1''' feroarings}} yn de lêste {{PLURAL:$2|dei|'''$2''' dagen}}, fan $4 $5.",
+'rcnotefrom'                        => 'Dit binne de feroarings sûnt <b>$2</b> (maksimaal <b>$1</b>).',
+'rclistfrom'                        => 'Jou nije feroarings, begjinnende mei $1',
+'rcshowhideminor'                   => 'lytse feroarings $1',
+'rcshowhidebots'                    => 'bots $1',
+'rcshowhideliu'                     => 'oanmelde brûkers $1',
+'rcshowhideanons'                   => 'anonime brûkers $1',
+'rcshowhidepatr'                    => 'kontrolearre bewurkings $1',
+'rcshowhidemine'                    => 'myn bewurkings $1',
+'rclinks'                           => 'Jou $1 nije feroarings yn de lêste $2 dagen; $3 tekstwiziging',
+'diff'                              => 'ferskil',
+'hist'                              => 'skiednis',
+'hide'                              => 'gjin',
+'show'                              => 'al',
+'minoreditletter'                   => 'T',
+'newpageletter'                     => 'N',
+'boteditletter'                     => 'b',
+'number_of_watching_users_pageview' => '[$1 folgjende {{PLURAL:$1|meidogger|meidoggers}}]',
+'rc_categories'                     => 'Alline kategoryen (skiede mei in "|")',
+'newsectionsummary'                 => '/* $1 */ nije seksje',
 
 # Recent changes linked
 'recentchangeslinked'          => 'Folgje keppelings',
 'recentchangeslinked-title'    => 'Feroarings yn ferbân mei "$1"',
 'recentchangeslinked-noresult' => "Der hawwe gjin bewurkings yn 'e bedoelde perioade west op'e siden dy't hjirwei linke wurde.",
-'recentchangeslinked-summary'  => "Dizze spesjale side lit de lêste bewurkings sjen op siden dy't linke wurde fan dizze side ôf. Siden dy't op [[Special:Watchlist|jo folchlist]] steane, wurde '''tsjûk''' werjûn.",
+'recentchangeslinked-summary'  => "Dizze spesjale side lit de lêste bewurkings sjen op siden dy't keppele wurde fan in spesifisearre side ôf (of fan in spesifisearre Kategory ôf). Siden dy't op [[Special:Watchlist|jo folchlist]] steane, wurde '''tsjûk''' werjûn.",
+'recentchangeslinked-page'     => 'Sidenamme:',
 
 # Upload
-'upload'            => 'Bied bestân oan',
-'uploadbtn'         => 'Bied bestân oan',
-'reupload'          => "Op 'e nij oanbiede",
-'reuploaddesc'      => 'Werom nei oanbied-side.',
-'uploadnologin'     => 'Net oanmelde',
-'uploadnologintext' => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze om in bestân oanbieden te kinnen.',
-'uploaderror'       => 'Oanbied-fout',
-'uploadtext'        => "'''STOP!''' Lês ear't jo eat oanbiede
-de regels foar ôfbyldbrûk foar de {{SITENAME}}.
+'upload'                     => 'Bied bestân oan',
+'uploadbtn'                  => 'Bied bestân oan',
+'reupload'                   => "Op 'e nij oanbiede",
+'reuploaddesc'               => 'Werom nei oanbied-side.',
+'uploadnologin'              => 'Net oanmelde',
+'uploadnologintext'          => 'Jo moatte [[Special:UserLogin|oanmeld]] wêze om in bestân oanbieden te kinnen.',
+'upload_directory_read_only' => 'De webserver kin net skriuwe yn de oanbiedpad ($1).',
+'uploaderror'                => 'Oanbied-fout',
+'uploadtext'                 => "Om't nije triemmen oan te bieden, brûke jo de ûndersteande fekjes. Earder oanbeane triemmen, kinne jo fine op de [[Special:ImageList|list of oanbeane ôfbylden]].
+Wat oanbean en wat wiske wurdt, wurdt delskreaun yn it [[Special:Log/upload|lochboek]].
 
-Earder oanbeane ôfbylden, kinne jo fine op de
-[[Special:Imagelist|list of oanbeane ôfbylden]].
-Wat oanbean en wat wiske wurdt, wurdt delskreaun yn it
-[[Special:Log/delete|lochboek]].
+Om de triem yn in side op te nimmen, meitsje jo dêr sa'n keppeling:
+*'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:jo_foto.jpg]]</nowiki>''',
+*'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:jo_logo.png|omskriuwing]]</nowiki>''', of
+*'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:jo_lûd.ogg]]</nowiki>''', foar direkt keppeling fan mediatriemmen dy't gjin ôfbylden binne.",
+'upload-prohibited'          => 'Ferbouden triemtypes: $1.',
+'uploadlog'                  => 'oanbied log',
+'uploadlogpage'              => 'Oanbied_log',
+'uploadlogpagetext'          => 'Liste fan de lêst oanbeane bestannen.
+(Tiid oanjûn as UTC).',
+'filename'                   => 'Bestânsnamme',
+'filedesc'                   => 'Omskriuwing',
+'fileuploadsummary'          => 'Gearfetting:',
+'filestatus'                 => 'Auteursrjochtensituaasje:',
+'filesource'                 => 'Boarne:',
+'uploadedfiles'              => 'Oanbeane bestannen',
+'ignorewarning'              => 'Negearje de warskôging en lis triem dochs fêst.',
+'ignorewarnings'             => 'Negearje warskôgings',
+'minlength1'                 => 'Triemnammen moatte minstens út ien teken bestean.',
+'badfilename'                => 'De ôfbyldnamme is feroare nei "$1".',
+'successfulupload'           => 'Oanbieden slagge.',
+'uploadwarning'              => 'Oanbied waarskôging',
+'savefile'                   => 'Lis bestân fêst',
+'uploadedimage'              => ' "[[$1]]" oanbean',
+'uploaddisabled'             => 'Sorry, op dizze tsjinner kin net oanbean wurde.',
+'sourcefilename'             => 'Triemnamme boarne:',
+'destfilename'               => 'Triemnamme om op te slaan:',
+'watchthisupload'            => 'Folgje dizze side',
+'filename-bad-prefix'        => 'De namme fan de triem dy\'t jo oanbied begjint mei <strong>"$1"</strong>, dit wiist op in namme dy\'t automatysk troch in digitale kamera oanmakke wurdt. Feroarje de namme as jo wolle yn ien dy\'t in omskriuwing jout fan de triem.',
 
-Om't nije ôfbylden oan te bieden, kieze jo in bestân út sa't dat
-normaal is foar jo blêder en bestjoersysteem.
-Dan jouwe jo oan jo gjin auteursrjocht skeine troch it oanbieden.
-Mei \"Bied oan\" begjinne jo dan it oanbieden.
-Dit kin efkes duorje as jo Ynternet-ferbining net sa flug is.
+'license' => 'Lisinsje:',
 
-Foar de bestânsfoarm wurdt foto's JPEG oanret, foar tekenings ensfh. PNG, en foar
-lûden OGG. Brûk in dúdlike bestânsnamme, sa't in oar ek wit wat it is.
-
-Om it ôfbyld yn in side op te nimmen, meitsje jo dêr sa'n keppeling:<br />
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:jo_foto.jpg|omskriuwing]]</nowiki>''' of
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:jo_logo.png|omskriuwing]]</nowiki>''';
-en foar lûden '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:jo_lûd.ogg]]</nowiki>'''.
-
-Tink derom dat oaren bewurkje kinne wat jo oanbiede, as dat better is foar de {{SITENAME}},
-krekt's sa't dat foar siden jildt, en dat jo útsletten wurde kinne as jo misbrûk
-meitsje fan it systeem..",
-'uploadlog'         => 'oanbied log',
-'uploadlogpage'     => 'Oanbied_log',
-'uploadlogpagetext' => 'Liste fan de lêst oanbeane bestannen.
-(Tiid oanjûn as UTC).',
-'filename'          => 'Bestânsnamme',
-'filedesc'          => 'Omskriuwing',
-'uploadedfiles'     => 'Oanbeane bestannen',
-'badfilename'       => 'De ôfbyldnamme is feroare nei "$1".',
-'successfulupload'  => 'Oanbieden slagge.',
-'uploadwarning'     => 'Oanbied waarskôging',
-'savefile'          => 'Lis bestân fêst',
-'uploadedimage'     => ' "[[$1]]" oanbean',
-'uploaddisabled'    => 'Sorry, op dizze tsjinner kin net oanbean wurde.',
-
-# Special:Imagelist
+# Special:ImageList
+'imgfile'        => 'triem',
 'imagelist'      => 'Ofbyld list',
 'imagelist_name' => 'Namme',
 
 # Image description page
 'filehist'                  => 'Triemskiednis',
 'filehist-help'             => "Klik op in datum/tiid om de triem te sjen sa't er doedestiids wie.",
+'filehist-deleteall'        => 'wiskje alles',
+'filehist-deleteone'        => 'wiskje dizze',
+'filehist-revert'           => 'werom sette',
 'filehist-current'          => 'rinnend',
 'filehist-datetime'         => 'Datum/tiid',
 'filehist-user'             => 'Brûker',
@@ -898,6 +1024,22 @@
 'noimage-linktext'          => 'oplade',
 'uploadnewversion-linktext' => 'In nije ferzje fan dizze triem oplade',
 
+# File reversion
+'filerevert'         => '$1 weromsette',
+'filerevert-legend'  => 'Triem weromsette',
+'filerevert-comment' => 'Oanmerking:',
+'filerevert-submit'  => 'werom sette',
+
+# File deletion
+'filedelete'                  => 'Wiskje $1',
+'filedelete-legend'           => 'Wiskje triem',
+'filedelete-intro-old'        => "Jo wiskje de ferzje fan '''[[Media:$1|$1]]''' fan [$4 $3, $2].",
+'filedelete-comment'          => 'Reden foar it wiskjen:',
+'filedelete-submit'           => 'Wiskje',
+'filedelete-success'          => "'''$1''' is wiske.",
+'filedelete-otherreason'      => 'Oare/eventuele reden:',
+'filedelete-reason-otherlist' => 'Oare reden',
+
 # MIME search
 'mimesearch' => 'Sykje op MIME-type',
 
@@ -908,7 +1050,8 @@
 'listredirects' => 'List fan trochferwizings',
 
 # Unused templates
-'unusedtemplates' => 'Net brûkte sjabloanen',
+'unusedtemplates'    => 'Net brûkte sjabloanen',
+'unusedtemplateswlh' => 'oare keppelings',
 
 # Random page
 'randompage' => 'Samar in side',
@@ -920,46 +1063,50 @@
 'statistics'    => 'Statistyk',
 'sitestats'     => 'Side statistyk',
 'userstats'     => 'Brûker statistyk',
-'sitestatstext' => "It tal fan siden in de {{SITENAME}} is: <b>$2</b>.<br />
-(Oerlissiden, siden oer de {{SITENAME}}, oare bysûndere siden, stobben en trochferwizings yn de databank binne dêrby net meiteld.)<br />
-It tal fan siden in de databank is: <b>$1</b>.
+'sitestatstext' => "It {{PLURAL:$1|is '''1''' side|binne '''$1''' siden}} yn de databank.
+Oerlissiden, siden oer de {{SITENAME}}, stobben, trochferwizings, en oare bysûndere siden, binne dêrby meiteld. Sûnder dizze siden, it {{PLURAL:$2|is '''1''' side|binne '''$2''' siden}} mei materiaal en ynhâld. 
 
-'''$8''' files have been uploaded.
+'''$8''' {{PLURAL:$8|triem wurdt|triemmen wurde}} al oanbied.
 
-Der is <b>$3</b> kear in side opfrege, en <b>$4</b> kear in side bewurke, sûnt it programma bywurke is (15 oktober 2002). Dat komt yn trochslach del op <b>$5</b> kear bewurke de side, en <b>$6</b> kear opfrege de bewurking.
+Der {{PLURAL:$3|is '''1''' sidelêzing|binne '''$3''' sidelêzings}}, en '''$4''' {{PLURAL:$4|bewurking|bewurkings}} sûnt {{SITENAME}} begûnen. Dat komt yn trochslach del op '''$5''' bewurkings per side, en '''$6''' lêzings per bewurking.  
 
-The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''$7'''.",
-'userstatstext' => 'It tal fan registreare brûkers is <b>$1</b>.
-It tal fan behearders dêrfan is: <b>$2</b>.',
+De lingte fan de [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] is '''$7'''.",
+'userstatstext' => "It tal fan registrearre meidoggers is '''{{PLURAL:$1|1|$1}}'''.
+It tal fan meidoggers dêrfan mei $5rjochten is '''{{PLURAL:$2|1|$2}}''' (of '''{{PLURAL:$4|1|$4}}''').",
 
 'disambiguations'      => 'Trochverwizings',
 'disambiguationspage'  => 'Project:trochferwizing',
-'disambiguations-text' => 'Dizze siden binne keppele fia in [[MediaWiki:Disambiguationspage]].
-Se soenen mei de side sels keppele wurde moatte.<br />
-(Allinnich siden út deselde nammeromte binne oanjûn.)',
+'disambiguations-text' => "De ûndersteande siden keppelje mei in '''Betsjuttingssiden'''.
+Se soenen mei de side sels keppele wurde moatte.<br /> In side wurdt sjoen as betsjuttingssiden, as de side ien berjocht fan [[MediaWiki:Disambiguationspage]] brûkt.",
 
-'doubleredirects'     => 'Dûbele trochverwizings',
+'doubleredirects'     => 'Dûbele trochferwizings',
 'doubleredirectstext' => '<b>Let op!</b> Der kinne missen yn dizze list stean!
 Dat komt dan ornaris troch oare keppelings ûnder de "#REDIRECT".<br />
 Eltse rigel jout keppelings nei de earste en twadde trochverwizing, en dan de earste regel fan
 de twadde trochferwizing, wat it "echte" doel wêze moat.',
 
-'brokenredirects'     => 'Misse trochferwizings',
-'brokenredirectstext' => "Dizze trochferwizings ferwize nei siden dy't der net binne.",
+'brokenredirects'        => 'Misse trochferwizings',
+'brokenredirectstext'    => "Dizze trochferwizings ferwize nei siden dy't der net binne.",
+'brokenredirects-edit'   => '(bewurkje)',
+'brokenredirects-delete' => '(wiskje)',
 
-'withoutinterwiki' => 'Siden sûnder links nei oare talen',
+'withoutinterwiki'        => 'Siden sûnder links nei oare talen',
+'withoutinterwiki-submit' => 'Sjen litte',
 
 'fewestrevisions' => 'Siden mei de minste bewurkings',
 
 # Miscellaneous special pages
-'nbytes'                  => '$1 byte',
-'nlinks'                  => '$1 keer keppele',
+'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
+'ncategories'             => '$1 {{PLURAL:$1|kategory|kategoryen}}',
+'nlinks'                  => '$1 {{PLURAL:$1|keppeling|keppelings}}',
 'nmembers'                => '$1 {{PLURAL:$1|ynskriuwing|ynskriuwings}}',
-'nviews'                  => '$1 kear sjoen',
+'nrevisions'              => '$1 {{PLURAL:$1|ferzje|ferzjes}}',
+'nviews'                  => '{{PLURAL:$1|1 kear|$1 kear}} sjoen',
+'specialpage-empty'       => 'Gjin resultaten foar dit rapport.',
 'lonelypages'             => 'Lossteande siden',
 'uncategorizedpages'      => 'Net-kategorisearre siden',
 'uncategorizedcategories' => 'Net-kategorisearre kategoryen',
-'uncategorizedimages'     => 'Net-kategorisearre ôfbyldings',
+'uncategorizedimages'     => 'Net-kategorisearre triemen',
 'uncategorizedtemplates'  => 'Net-kategorisearre sjabloanen',
 'unusedcategories'        => 'Net-brûkte kategoryen',
 'unusedimages'            => 'Lossteande ôfbylden',
@@ -970,23 +1117,26 @@
 'mostlinkedcategories'    => "Kategoryen dêr't it meast nei ferwiisd wurdt",
 'mostlinkedtemplates'     => 'Meast brûkte sjabloanen',
 'mostcategories'          => 'Siden mei de measte kategoryen',
-'mostimages'              => 'Meast brûkte ôfbyldings',
+'mostimages'              => 'Meast brûkte triemmen',
 'mostrevisions'           => 'Siden mei de measte bewurkings',
 'prefixindex'             => 'Alle siden neffens foarheaksel',
 'shortpages'              => 'Koarte siden',
 'longpages'               => 'Lange siden',
 'deadendpages'            => 'Siden sûnder links',
 'protectedpages'          => 'Befeilige siden',
+'protectedpagestext'      => 'De neikommende siden binne skoattele foar werneamen of wizigjen',
 'listusers'               => 'Brûkerlist',
 'newpages'                => 'Nije siden',
+'newpages-username'       => 'Meidoggernamme:',
 'ancientpages'            => 'Alde siden',
 'move'                    => 'Ferskowe nei oare namme',
-'movethispage'            => 'Move this side',
+'movethispage'            => 'Werneam dizze side',
 'unusedimagestext'        => '<p>Tink derom dat ore web sides lykas fan de oare
 parten fan it meartaliche projekt mei in keppeling nei in direkte URL nei
 an ôfbyld makke hawwe kinne. Dan wurde se noch brûke, mar stean al in dizze list.',
 'notargettitle'           => 'Gjin side',
 'notargettext'            => 'Jo hawwe net sein oer hokfoar side jo dit witte wolle.',
+'pager-older-n'           => '{{PLURAL:$1|1 âlder|$1 âlder}}',
 
 # Book sources
 'booksources' => 'Boekynformaasje',
@@ -998,8 +1148,9 @@
 'all-logs-page'        => 'Alle lochboeken',
 'alllogstext'          => 'Kombinearre loch de {{SITENAME}}.
 Jo kinne it oersjoch beheine troch in loch, in meidoggernamme of in side oan te jaan.',
+'logempty'             => 'Gjin treffers yn it loch.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle siden',
 'alphaindexline'    => "$1 oan't $2",
 'nextpage'          => 'Folgjende side ($1)',
@@ -1017,15 +1168,24 @@
 'categories'         => 'Kategoryen',
 'categoriespagetext' => 'Dizze wiki hat de neikommende kategoryen:',
 
+# Special:ListUsers
+'listusersfrom'    => 'Lit meidoggers sjen fanôf:',
+'listusers-submit' => 'Sjen litte',
+
+# Special:ListGroupRights
+'listgrouprights-group'  => 'Groep',
+'listgrouprights-rights' => 'Rjochten',
+
 # E-mail user
 'mailnologin'     => 'Gjin adres beskikber',
-'mailnologintext' => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze, en in jildich e-postadres [[Special:Preferences|ynsteld]] hawwe, om oan oare brûkers e-post stjoere te kinnen.',
+'mailnologintext' => 'Jo moatte [[Special:UserLogin|oanmeld]] wêze, en in jildich e-postadres [[Special:Preferences|ynsteld]] hawwe, om oan oare brûkers e-post stjoere te kinnen.',
 'emailuser'       => 'Skriuw dizze brûker',
-'emailpage'       => 'E-post nei brûker',
+'emailpage'       => 'E-post nei meidogger',
 'emailpagetext'   => "As dizze brûker in jildich e-postadres in ynsteld hat,
 dan kinne jo ien berjocht ferstjoere.
 It e-postadres dat jo ynsteld hawwe wurdt brûkt as de ôfstjoerder, sa't de ûntfanger
 antwurdzje kin.",
+'defemailsubject' => 'E-post fan {{SITENAME}}',
 'noemailtitle'    => 'Gjin e-postadres',
 'noemailtext'     => 'Dizze brûker had gjin jildich e-postadres ynsteld,
 of hat oanjaan gjin post fan oare brûkers krije te wollen.',
@@ -1043,9 +1203,9 @@
 'watchlistfor'         => "(foar '''$1''')",
 'nowatchlist'          => 'Jo hawwe gjin siden op jo folchlist.',
 'watchnologin'         => 'Not oanmeld in',
-'watchnologintext'     => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze om jo folchlist te feroarjen.',
+'watchnologintext'     => 'Jo moatte [[Special:UserLogin|oanmeld]] wêze om jo folchlist te feroarjen.',
 'addedwatch'           => 'Oan folchlist tafoege',
-'addedwatchtext'       => "De side \"'''[[:\$1]]'''\" is tafoege oan jo [[Special:Watchlist|folchlist]]. Bewurkings fan dizze side en oerlisside wurde yn de takomst op jo folchlist oanjûn. Hja wurde foar jo ek '''fet''' printe op [[Special:Recentchanges|Koartlyn feroare]].
+'addedwatchtext'       => "De side \"'''[[:\$1]]'''\" is tafoege oan jo [[Special:Watchlist|folchlist]]. Bewurkings fan dizze side en oerlisside wurde yn de takomst op jo folchlist oanjûn. Hja wurde foar jo ek '''fet''' printe op [[Special:RecentChanges|Koartlyn feroare]].
 
 At jo letter in side net mear folgje wolle, dan brûke jo op dy side de keppeling \"Ferjit dizze side.\" Jo [[Special:Watchlist|folchlist]] hat ek in keppeling \"Jo folchlist bewurkje,\" foar at jo mear as ien side \"ferjitte\" wolle.",
 'removedwatch'         => 'Net mear folgje',
@@ -1056,12 +1216,12 @@
 'unwatchthispage'      => 'Ferjit dizze side',
 'notanarticle'         => 'Dit kin net folge wurde.',
 'watchnochange'        => "Fan de siden dy't jo folgje is der yn dizze perioade net ien feroare.",
-'watchlist-details'    => 'Jo folchlist hat $1 siden (oerlissiden net meiteld).',
+'watchlist-details'    => 'Jo folchlist hat {{PLURAL:$1|$1 side|$1 siden}}, oerlissiden net meiteld.',
 'watchmethod-recent'   => 'Koarts feroare ...',
 'watchmethod-list'     => 'Folge ...',
-'watchlistcontains'    => 'Jo folgje op it stuit $1 siden.',
+'watchlistcontains'    => 'Jo folgje op it stuit $1 {{PLURAL:$1|side|siden}}.',
 'iteminvalidname'      => 'Misse namme: "$1" ...',
-'wlnote'               => 'Dit binne de lêste <strong>$1</strong> feroarings yn de lêste <strong>$2</strong> oeren.',
+'wlnote'               => "Dit {{PLURAL:$1|is de lêste feroaring|binne de lêste '''$1''' feroarings}} yn de lêste {{PLURAL:$2|oer|'''$2''' oeren}}.",
 'wlshowlast'           => 'Lêste $1 oeren, $2 dagen sjen litte ($3)',
 'watchlist-hide-bots'  => 'Botbewurkings ferskûlje',
 'watchlist-hide-own'   => 'Myn bewurkings ferskûlje',
@@ -1071,15 +1231,42 @@
 'watching'   => "Dwaande mei op'e folchlist te setten ...",
 'unwatching' => "Dwaande mei fan'e folchlist ôf te heljen ...",
 
-'changed' => 'feroare',
-'created' => 'oanmakke',
+'enotif_newpagetext' => 'Dit is in nije side.',
+'changed'            => 'feroare',
+'created'            => 'oanmakke',
+'enotif_body'        => 'Bêste $WATCHINGUSERNAME,
 
+De {{SITENAME}}side \'$PAGETITLE\' is op $PAGEEDITDATE $CHANGEDORCREATED troch meidogger $PAGEEDITOR; 
+sjoch $PAGETITLE_URL foar de aktuele ferzje.
+
+$NEWPAGE
+
+Gearfetting: $PAGESUMMARY $PAGEMINOREDIT
+
+Foar oerlis mei meidogger $PAGEEDITOR:
+- netpost: $PAGEEDITOR_EMAIL
+- wiki: $PAGEEDITOR_WIKI
+
+Fierdere meldings wurde jo net tastjoerd, oant jo de side lêzen hawwe. Op jo folchlist kinne jo op \'e nij meldings foar al jo folge siden freegje.
+
+                 Jo freonlike {{SITENAME}}-meldingssysteem.
+
+-- 
+Gean nei {{fullurl:{{ns:special}}:Watchlist/edit}}
+om jo folchlistynstellings te feroarjen.
+
+Reaksjes en fierdere help:
+{{fullurl:{{MediaWiki:Helppage}}}}',
+
 # Delete/protect/revert
 'deletepage'                  => 'Wisk side',
 'confirm'                     => 'Befêstigje',
 'excontent'                   => "ynhâld wie: '$1'",
+'excontentauthor'             => "ynhâld wie: '$1' (en de ienige bewurker wie: '[[Special:Contributions/$2|$2]]')",
 'exbeforeblank'               => "foar de tekst wiske wie, wie dat: '$1'",
 'exblank'                     => 'side wie leech',
+'delete-confirm'              => '"$1" wiskje',
+'delete-legend'               => 'Wiskje',
 'historywarning'              => "Waarskôging: De side dy't jo wiskje wolle hat skiednis:",
 'confirmdeletetext'           => 'Jo binne dwaande mei it foar altyd wiskjen fan in side
 of ôfbyld, tegearre mei alle skiednis, út de databank.
@@ -1088,7 +1275,7 @@
 'actioncomplete'              => 'Dien',
 'deletedtext'                 => '"<nowiki>$1</nowiki>" is wiske.
 Sjoch "$2" foar in list fan wat resint wiske is.',
-'deletedarticle'              => '"$1" is wiske',
+'deletedarticle'              => '"[[$1]]" is wiske',
 'dellogpage'                  => 'Wisk_loch',
 'dellogpagetext'              => 'Dit is wat der resint wiske is.
 (Tiden oanjûn as UTC).',
@@ -1097,7 +1284,12 @@
 'deletecomment'               => 'Reden foar it wiskjen',
 'deleteotherreason'           => 'Oare/eventuele reden:',
 'deletereasonotherlist'       => 'Oare reden',
+'deletereason-dropdown'       => '*Faak-brûkte redenen
+** Frege troch de skriuwer
+** Skeining fan auteursrjocht
+** Fandalisme',
 'rollback'                    => 'Feroarings tebeksette',
+'rollback_short'              => 'Werom sette',
 'rollbacklink'                => 'feroaring tebeksette',
 'rollbackfailed'              => 'Feroaring tebeksette net slagge',
 'cantrollback'                => "Disse feroaringt kin net tebek set, om't der mar ien skriuwer is.",
@@ -1107,8 +1299,13 @@
 
 De lêste feroaring wie fan [[User:$3|$3]] ([[User talk:$3|Oerlis]]).',
 'editcomment'                 => 'De gearfetting wie: "<i>$1</i>".', # only shown if there is an edit comment
-'revertpage'                  => 'Tebek set ta de ferzje fan "$1"', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'revertpage'                  => 'Feroarings werom set fan [[Special:Contributions/$2|$2]] ([[User talk:$2|Oerlis]]) nei de lêste ferzje fan [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'rollback-success'            => 'Feroarings werom set fan $1; werom set nei de lêste ferzje fan $2.',
 'protectlogpage'              => 'Befeiligingslochboek',
+'protectlogtext'              => 'Hjirûnder wurdt it skoattele en frijjaan fan siden oanjûn. 
+Sjoch [[Special:ProtectedPages|Skoattele side]] foar mear ynformaasje.',
+'protectedarticle'            => '"[[$1]]" skoattele',
+'unprotectedarticle'          => 'joech "[[$1]]" frij',
 'protect-legend'              => 'Befeiliging befêstigje',
 'protectcomment'              => 'Oanmerkings:',
 'protectexpiry'               => 'Doer:',
@@ -1129,21 +1326,44 @@
 'protect-cantedit'            => "Jo kinne it befeiligingsnivo fan dizze side net feroarje, om't jo gjin rjochten hawwe om it te bewurkjen.",
 'restriction-type'            => 'Rjochten:',
 'restriction-level'           => 'Beheiningsnivo:',
+'minimum-size'                => 'Min. grutte',
+'maximum-size'                => 'Max. grutte:',
+'pagesize'                    => '(bytes)',
 
 # Restrictions (nouns)
+'restriction-edit'   => 'Wizigje',
+'restriction-move'   => 'Werneam',
 'restriction-create' => 'Oanmeitsje',
 
+# Restriction levels
+'restriction-level-sysop'         => 'folslein skoattele',
+'restriction-level-autoconfirmed' => 'skoattele foar anonymen',
+'restriction-level-all'           => "alle nivo's",
+
 # Undelete
-'undelete'          => 'Side werom set',
-'undeletepage'      => 'Side besjen en werom sette',
-'undeletepagetext'  => 'Dizze siden binne wiske, mar sitte noch yn it argyf en kinne weromset wurde.
+'undelete'                => 'Side werom set',
+'undeletepage'            => 'Side besjen en werom sette',
+'viewdeletedpage'         => 'Wiske siden besjen',
+'undeletepagetext'        => 'Dizze siden binne wiske, mar sitte noch yn it argyf en kinne weromset wurde.
 (It argyf kin út en troch leechmeitsje wurde.)',
-'undeleterevisions' => '$1 ferzjes in it argyf',
-'undeletehistory'   => 'Soenen jo dizze side weromsette, dan wurde alle ferzjes weromset as part
+'undelete-fieldset-title' => 'Ferzjes werom sette',
+'undeleteextrahelp'       => "Om in side hielendal werom te setten, lit alle seleksjefakjes iepen en klik '''''Weromsette'''''. Om in bepaalde ferzje werom te setten, klik de fakjes dy't mei de ferzjes oerienkomme, en klik '''''Weromsette'''''. Klik '''''Leechmeitsje''''' om it kommentaar fjild ensafuorthinne leech te meitsjen.",
+'undeleterevisions'       => '$1 {{PLURAL:$1|ferzje|ferzjes}} in it argyf',
+'undeletehistory'         => 'Soenen jo dizze side weromsette, dan wurde alle ferzjes weromset as part
 fan de skiednis. As der in nije side is mei dizze namme, dan wurd de hjoeddeise ferzje <b>net</b>
 troch de lêste ferzje út dy weromsette skiednis ferfangen.',
-'undeletebtn'       => 'Weromset!',
-'undeletedarticle'  => '"$1" weromset',
+'undelete-revision'       => 'Wiske ferzje fan $1 (op $2) fan $3:',
+'undelete-nodiff'         => 'Gjin eardere ferzje fûn.',
+'undeletebtn'             => 'Weromset!',
+'undeletelink'            => 'werom sette',
+'undeletereset'           => 'Leechmeitsje',
+'undeletecomment'         => 'Utlis foar weromsetten:',
+'undeletedarticle'        => '"$1" weromset',
+'undelete-header'         => 'Sjoch [[Special:Log/delete|de wiskloch]] foar resint wiske siden.',
+'undelete-search-box'     => 'Sykje wiske siden',
+'undelete-search-prefix'  => "Lit siden sjen dy't begjinne mei:",
+'undelete-search-submit'  => 'Sykje',
+'undelete-no-results'     => 'Gjin oerienkommende siden fûn yn it wisk argyf.',
 
 # Namespace form on various pages
 'namespace'      => 'Nammerûmte:',
@@ -1161,47 +1381,74 @@
 
 'sp-contributions-newbies-sub' => 'Foar nijlingen',
 'sp-contributions-blocklog'    => 'Blokkearlochboek',
+'sp-contributions-search'      => 'Sykje nei bydragen',
+'sp-contributions-username'    => 'IP Adres of meidoggernamme:',
+'sp-contributions-submit'      => 'Sykje',
 
 # What links here
-'whatlinkshere'       => 'Wat is hjirmei keppele',
-'whatlinkshere-title' => "Siden dy't ferwize nei $1",
-'whatlinkshere-page'  => 'Side:',
-'linklistsub'         => '(List fan keppelings)',
-'linkshere'           => 'Dizze siden binne hjirmei keppele:',
-'nolinkshere'         => 'Gjinien side is hjirmei keppele!',
-'isredirect'          => 'trochverwizing',
-'istemplate'          => 'ynfoege as sjabloan',
-'whatlinkshere-prev'  => '{{PLURAL:$1|foargeande|foargeande $1}}',
-'whatlinkshere-next'  => '{{PLURAL:$1|folgjende|folgjende $1}}',
-'whatlinkshere-links' => '← links dêrnei ta',
+'whatlinkshere'            => 'Wat is hjirmei keppele',
+'whatlinkshere-title'      => 'Siden dy\'t ferwize nei "$1"',
+'whatlinkshere-page'       => 'Side:',
+'linklistsub'              => '(List fan keppelings)',
+'linkshere'                => "Dizze siden binne keppele oan '''[[:$1]]''':",
+'nolinkshere'              => "Der binne gjin siden oan '''[[:$1]]''' keppele.",
+'nolinkshere-ns'           => "Gjin siden yn de keazen nammeromte keppelje nei '''[[:$1]]'''.",
+'isredirect'               => 'trochferwizing',
+'istemplate'               => 'ynfoege as sjabloan',
+'isimage'                  => 'byld keppeling',
+'whatlinkshere-prev'       => '{{PLURAL:$1|foargeande|foargeande $1}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|folgjende|folgjende $1}}',
+'whatlinkshere-links'      => '← links dêrnei ta',
+'whatlinkshere-hideredirs' => '$1 trochferwizings',
+'whatlinkshere-hidetrans'  => '$1 trânsklúzjes',
+'whatlinkshere-hidelinks'  => '$1 keppelings',
 
 # Block/unblock
-'blockip'            => 'Slút brûker út',
-'blockip-legend'     => 'Slút brûker út',
-'blockiptext'        => "Brûk dizze fjilden om in brûker fan skriuwtagong út te sluten.
+'blockip'             => 'Slút brûker út',
+'blockip-legend'      => 'Slút brûker út',
+'blockiptext'         => "Brûk dizze fjilden om in brûker fan skriuwtagong út te sluten.
 Dit soe allinnich omwillens fan fandalisme dwaan wurde moatte, sa't de
 [[{{MediaWiki:Policy-url}}|útslut-rie]] it oanjout.
 Meld de krekte reden! Begelyk, neam de siden dy't oantaaste waarden.",
-'ipaddress'          => 'Brûkernamme of Ynternet-adres',
-'ipbreason'          => 'Reden',
-'ipbsubmit'          => 'Slut dizze brûker út',
-'ipboptions'         => '15 minuten:15 min,1 oere:1 hour,2 oeren:2 hours,6 oeren:6 hours,12 oeren:12 hours,1 dei:1 day,3 dagen:3 days,1 wike:1 week,2 wiken:2 weeks,1 moanne:1 month,3 moanne:3 months,6 moanne:6 months,1 jier:1 year,ûnbeheind:infinite', # display1:time1,display2:time2,...
-'badipaddress'       => 'Dy brûker bestiet net',
-'blockipsuccesssub'  => 'Utsluting slagge',
-'blockipsuccesstext' => 'Brûker [[Special:Contributions/$1|$1]] is útsletten.<br />
-(List fan [[Special:Ipblocklist|útslette brûkers]].)',
-'unblockip'          => 'Lit brûker der wer yn',
-'unblockiptext'      => 'Brûk dizze fjilden om in brûker wer skriuwtagong te jaan.',
-'ipusubmit'          => 'Lit dizze brûker der wer yn',
-'ipblocklist'        => 'List fan útsletten Ynternet-adressen en brûkersnammen',
-'blocklistline'      => '"$3", troch "$2" op $1 ($4)',
-'blocklink'          => 'slut út',
-'unblocklink'        => 'lit yn',
-'contribslink'       => 'bydragen',
-'autoblocker'        => 'Jo wiene útsletten om\'t jo ynternet-adres oerienkomt mei dat fan "[[User:$1|$1]]". Foar it útsluten fan dy meidogger waard dizze reden jûn: "$2".',
-'blocklogpage'       => 'Blokkearlochboek',
-'blocklogentry'      => 'blokkearre "[[$1]]" foar de doer fan $2 $3',
-'blocklogtext'       => 'Dit is in loch fan it útsluten en talitten fan meidoggers. Fansels útsletten net-adressen binne net opnaam. Sjoch de [[Special:Ipblocklist|útsletlist]] foar de no jildende utslettings.',
+'ipaddress'           => 'Brûkernamme of Ynternet-adres',
+'ipadressorusername'  => 'IP Adres of meidoggernamme:',
+'ipbexpiry'           => 'Ferrint nei:',
+'ipbreason'           => 'Reden',
+'ipbreasonotherlist'  => 'Oare reden',
+'ipbanononly'         => 'Slút allinich anonyme meidoggers út',
+'ipbcreateaccount'    => 'Blokkearje it oanmeitsjen fan in nij profyl',
+'ipbenableautoblock'  => "Automatysk de lêste IP adressen útslute dy't troch dizze meidogger brûkt binne.",
+'ipbsubmit'           => 'Slut dizze brûker út',
+'ipbother'            => 'In oare tiid:',
+'ipboptions'          => '15 minuten:15 min,1 oere:1 hour,2 oeren:2 hours,6 oeren:6 hours,12 oeren:12 hours,1 dei:1 day,3 dagen:3 days,1 wike:1 week,2 wiken:2 weeks,1 moanne:1 month,3 moanne:3 months,6 moanne:6 months,1 jier:1 year,ûnbeheind:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'      => 'oare tiid',
+'ipbotherreason'      => 'Oare/eventuele reden:',
+'badipaddress'        => 'Dy brûker bestiet net',
+'blockipsuccesssub'   => 'Utsluting slagge',
+'blockipsuccesstext'  => 'Brûker [[Special:Contributions/$1|$1]] is útsletten.<br />
+(List fan [[Special:IPBlockList|útslette brûkers]].)',
+'ipb-unblock-addr'    => 'Lit $1 yn',
+'ipb-unblock'         => 'Lit in meidogger of IP-adres yn',
+'ipb-blocklist-addr'  => 'Besteande útsluting foar $1 besjen',
+'ipb-blocklist'       => 'Besteande útslutings besjen',
+'unblockip'           => 'Lit brûker der wer yn',
+'unblockiptext'       => 'Brûk dizze fjilden om in brûker wer skriuwtagong te jaan.',
+'ipusubmit'           => 'Lit dizze brûker der wer yn',
+'ipblocklist'         => 'List fan útsletten Ynternet-adressen en brûkersnammen',
+'ipblocklist-submit'  => 'Sykje',
+'blocklistline'       => '"$3", troch "$2" op $1 ($4)',
+'infiniteblock'       => 'trochgeand',
+'blocklink'           => 'slut út',
+'unblocklink'         => 'lit yn',
+'contribslink'        => 'bydragen',
+'autoblocker'         => 'Jo wiene útsletten om\'t jo ynternet-adres oerienkomt mei dat fan "[[User:$1|$1]]". Foar it útsluten fan dy meidogger waard dizze reden jûn: "$2".',
+'blocklogpage'        => 'Blokkearlochboek',
+'blocklogentry'       => 'blokkearre "[[$1]]" foar de doer fan $2 $3',
+'blocklogtext'        => 'Dit is in loch fan it útsluten en talitten fan meidoggers. Fansels útsletten net-adressen binne net opnaam. Sjoch de [[Special:IPBlockList|útsletlist]] foar de no jildende utslettings.',
+'ipb_expiry_invalid'  => 'Tiid fan ferrinnen is net goed.',
+'ipb_already_blocked' => '"$1" is al útsluten',
+'ipb_cant_unblock'    => 'Flater: It útsluten fan ID $1 kin net fûn wurde. It is miskien al net mear útsluten.',
+'proxyblocksuccess'   => 'Dien.',
 
 # Developer tools
 'lockdb'              => "Meitsje de database 'Net-skriuwe'",
@@ -1225,8 +1472,9 @@
 'unlockdbsuccesstext' => 'De {{SITENAME}} databank is skriuwber makke.',
 
 # Move page
-'move-page-legend' => 'Werneam side',
-'movepagetext'     => "Dit werneamt in side, mei alle sideskiednis.
+'move-page'               => 'Werneam  $1',
+'move-page-legend'        => 'Werneam side',
+'movepagetext'            => "Dit werneamt in side, mei alle sideskiednis.
 De âlde titel wurdt in trochferwizing nei de nije.
 Keppelings mei de âlde side wurde net feroare;
 gean sels nei of't der dûbele of misse ferwizings binne.
@@ -1235,34 +1483,45 @@
 De side wurdt '''net''' werneamt as der al in side mei dy namme is, útsein as it in side
 sûnder skiednis is en de side leech is of in trochferwizing is. Sa kinne jo in side
 daalks weromneame as jo in flater meitsje, mar jo kinne in oare side net oerskriuwe.",
-'movepagetalktext' => "As der in oerlisside by heart, dan bliuwt dy oan de side keppele, '''útsein''':
+'movepagetalktext'        => "As der in oerlisside by heart, dan bliuwt dy oan de side keppele, '''útsein''':
 *De nije sidenamme yn in oare nammeromte is,
 *Der keppele oan de nije namme al in net-lege oerlisside is, of
 *Jo dêr net foar kieze.
 
 In dizze gefallen is it oan jo hoe't jo de oerlisside werneame of ynfoegje wolle.",
-'movearticle'      => 'Werneam side',
-'movenologin'      => 'Net oameld',
-'movenologintext'  => 'Jo moatte [[Special:Userlogin|oanmeld]] wêze om in side wer te neamen.',
-'newtitle'         => 'As nij titel',
-'move-watch'       => 'Dizze side folgje',
-'movepagebtn'      => 'Werneam side',
-'pagemovedsub'     => 'Werneamen slagge',
-'articleexists'    => 'In side mei dy namme bestiet al of de sidenamme is ûnjildich.
+'movearticle'             => 'Werneam side',
+'newtitle'                => 'As nij titel',
+'move-watch'              => 'Dizze side folgje',
+'movepagebtn'             => 'Werneam side',
+'pagemovedsub'            => 'Werneamen slagge',
+'movepage-moved'          => '<big>\'\'\'"$1" hjit no "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'articleexists'           => 'In side mei dy namme bestiet al of de sidenamme is ûnjildich.
 Kies in  oare sidenamme a.j.w.',
-'talkexists'       => "It werneamen op sich is slagge, mar de eardere oerlisside is
+'talkexists'              => "It werneamen op sich is slagge, mar de eardere oerlisside is
 net mear keppele om't der foar de nije namme el al in oerlisside wie.
 Gearfoegje de oerlissiden hânmjittig.",
-'movedto'          => 'werenamd as',
-'movetalk'         => 'Derby hearrende oerlisside ferskowe',
-'1movedto2'        => '[[$1]] ferskood nei [[$2]]',
-'1movedto2_redir'  => '[[$1]] ferskood nei [[$2]], wat in synonym wie',
-'movelogpage'      => 'Lochboek fan ferskode siden',
-'movereason'       => 'Reden:',
-'revertmove'       => 'tebekdraaie',
+'movedto'                 => 'werenamd as',
+'movetalk'                => 'Derby hearrende oerlisside ferskowe',
+'movepage-page-moved'     => 'De side $1 is werneamd nei $2.',
+'1movedto2'               => '[[$1]] ferskood nei [[$2]]',
+'1movedto2_redir'         => '[[$1]] ferskood nei [[$2]], wat in synonym wie',
+'movelogpage'             => 'Lochboek fan ferskode siden',
+'movelogpagetext'         => 'Dit is in list fan feroare titels.',
+'movereason'              => 'Reden:',
+'revertmove'              => 'werom sette',
+'delete_and_move'         => 'Wiskje en werneam',
+'delete_and_move_text'    => '== Wiskjen nedich ==
+De doelside "[[:$1]]" is der al. Moat dy wiske wurde om plak te meitsjen foar it werneamen?',
+'delete_and_move_confirm' => 'Ja, wiskje de side',
+'delete_and_move_reason'  => 'Wiske om plak te meitsjen foar in werneamde side',
+'immobile_namespace'      => "De nije titel is yn in nammeromte dêr't gjin siden oan tafoege wurde kinne.",
 
 # Export
-'export' => 'Eksportearje',
+'export'           => 'Eksportearje',
+'export-submit'    => 'Eksportearje',
+'export-addcat'    => 'Tafoegje',
+'export-download'  => 'Fêstlizze as triem',
+'export-templates' => 'Tafoegje berjochten',
 
 # Namespace 8 related
 'allmessages'         => 'Alle wikiberjochten',
@@ -1276,10 +1535,29 @@
 
 # Thumbnails
 'thumbnail-more'  => 'Grutter',
+'filemissing'     => 'Triem net fûn',
 'thumbnail_error' => 'Flater by it oanmeitsjen fan thumbnail: $1',
 
+# Special:Import
+'import'                  => 'Importearje siden',
+'import-interwiki-submit' => 'Ymportearje',
+'importstart'             => 'Siden oan it ymportearjen ...',
+'import-revision-count'   => '$1 {{PLURAL:$1|ferzje|ferzjes}}',
+'importnopages'           => 'Gjin siden te ymportearjen.',
+'importfailed'            => 'Ymport fout: <nowiki>$1</nowiki>',
+'importcantopen'          => 'De ymporttriem koe net iepenen wurde.',
+'importbadinterwiki'      => 'Ferkearde ynterwikiferwizing',
+'importnotext'            => 'Leech of gjin tekst',
+'importsuccess'           => 'Ymport slagge!',
+'importnofile'            => 'Gjin ymporttriem is oanbeane.',
+'import-noarticle'        => 'Gjin side te ymportearjen!',
+'import-nonewrevisions'   => 'Alle ferzjes wurde al ymportearre.',
+'xml-error-string'        => '$1 op regel $2, kolom $3 (byte $4): $5',
+
 # Import log
-'importlogpage' => 'Ymportlochboek',
+'importlogpage'                    => 'Ymportlochboek',
+'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|ferzje|ferzjes}}',
+'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|ferzje|ferzjes}} fan $2',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Myn brûkersside',
@@ -1299,6 +1577,7 @@
 'tooltip-ca-watch'                => 'Dizze side oan myn folchside tafoegje',
 'tooltip-ca-unwatch'              => 'Dizze side fan myn folchlist ôfhelje',
 'tooltip-search'                  => '{{SITENAME}} trochsykje',
+'tooltip-p-logo'                  => 'Haadside',
 'tooltip-n-mainpage'              => 'Gean nei de haadside',
 'tooltip-n-portal'                => "Oer it projekt: wat'st dwaan kinst, wêr'st dingen fine kinst.",
 'tooltip-n-currentevents'         => 'Eftergrûnynformaasje oer rinnende saken.',
@@ -1325,7 +1604,15 @@
 
 # Attribution
 'anonymous' => 'Anonime meidogger(s) fan {{SITENAME}}',
+'siteuser'  => '{{SITENAME}} meidogger $1',
+'siteusers' => '{{SITENAME}} meidogger(s) $1',
 
+# Spam protection
+'spamprotectiontext' => "De side dy't jo fêstlizze woene is blokkearre troch in spam filter. Dit wurdt wierskynlik feroarsake troch in ferwizing nei in ekstern webstee.",
+
+# Info page
+'infosubtitle' => 'Ynformaasje foar side',
+
 # Math options
 'mw_math_png'    => 'Altiten as PNG ôfbyldzje',
 'mw_math_simple' => 'HTML foar ienfâldiche formules, oars PNG',
@@ -1334,27 +1621,41 @@
 'mw_math_modern' => 'Oanbefelle foar resinte blêders',
 'mw_math_mathml' => 'MathML',
 
+# Patrolling
+'markaspatrolleddiff'                 => 'Markearje as kontroleare',
+'markaspatrolledtext'                 => 'Markearje dizze side as kontrolearre',
+'markedaspatrolled'                   => 'Markearre as kontrolearre',
+'markedaspatrolledtext'               => 'De selektearre ferzje is markearre as kontrolearre.',
+'markedaspatrollederror'              => 'Kin net as kontrolearre markearre wurde',
+'markedaspatrollederrortext'          => "Jo moatte in ferzje oanjaan dy't jo as kontrolearre markearje.",
+'markedaspatrollederror-noautopatrol' => 'Jo meie jo eigen bewurkings net sels markearre.',
+
 # Browsing diffs
 'previousdiff' => '← Foargeande feroaring',
 'nextdiff'     => 'Folgjende feroaring →',
 
 # Media information
+'imagemaxsize'         => 'Behein ôfmjittings fan ôfbyld op beskriuwingsside ta:',
+'thumbsize'            => 'Mjitte fan miniatueren:',
+'file-info'            => '(triemgrutte: $1, MIME-type: $2)',
 'file-info-size'       => '($1 × $2 pixel, triemgrutte: $3, MIME type: $4)',
 'file-nohires'         => '<small>Gjin hegere resolúsje beskikber.</small>',
 'svg-long-desc'        => '(SVG-triem, nominaal $1 × $2 pixels, triemgrutte: $3)',
 'show-big-image'       => 'Hegere resolúsje',
 'show-big-image-thumb' => '<small>Grutte fan dizze ôfbylding: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Nije ôfbyldings',
-'imagelisttext' => 'Dit is in list fan $1 ôfbylden, op $2.',
+'imagelisttext' => "Dit is in list fan '''$1''' {{PLURAL:$1|triem|triemen}}, op $2.",
+'showhidebots'  => '(Bots $1)',
+'noimages'      => 'Neat te sjen.',
 'ilsubmit'      => 'Sykje',
 'bydate'        => 'datum',
 
 # Bad image list
 'bad_image_list' => "De opmaak is as folget:
 
-Allinne rigels fan in list dy't begjinne mei * wurde ferwurke. De earste link op in rigel moat in link wêze nei in net winske ôfbylding.
+Allinne rigels fan in list (rigels dy't begjinne mei *) wurde ferwurke. De earste link op in rigel moat in link wêze nei in net winske ôfbylding.
 Alle folgjende links dy't op deselde rigel steane, wurde behannele as útsûndering, lykas bygelyks siden dêr't de ôfbylding yn'e tekst opnommen is.",
 
 # Metadata
@@ -1370,19 +1671,59 @@
 * fnumber
 * focallength', # Do not translate list items
 
+# EXIF tags
+'exif-imagedescription'    => 'Ofbylding titel',
+'exif-make'                => 'Kamera makker',
+'exif-artist'              => 'Auteur',
+'exif-makernote'           => 'Opmerkings fan makker',
+'exif-usercomment'         => 'Opmerkings',
+'exif-relatedsoundfile'    => 'Besibbe audiotriem',
+'exif-exposuretime-format' => '$1 sek ($2)',
+'exif-gpsdatestamp'        => 'GPS-datum',
+
+'exif-unknowndate' => 'Datum ûnbekend',
+
+'exif-orientation-1' => 'Normaal', # 0th row: top; 0th column: left
+
+'exif-exposureprogram-0' => 'Net bepaald',
+'exif-exposureprogram-2' => 'Normaal programma',
+
+'exif-subjectdistance-value' => '$1 meter',
+
+'exif-meteringmode-0' => 'Unbekend',
+
+'exif-lightsource-0' => 'Unbekend',
+
+'exif-customrendered-0' => 'Normale ferwurking',
+
+'exif-scenecapturetype-0' => 'Standert',
+
+'exif-gaincontrol-0' => 'Gjin',
+
+'exif-contrast-0' => 'Normaal',
+
+'exif-saturation-0' => 'Normaal',
+
+'exif-sharpness-0' => 'Normaal',
+
+'exif-subjectdistancerange-0' => 'Unbekend',
+
 # External editor support
 'edit-externally'      => 'Dizze triem bewurkje mei in ekstern programma',
-'edit-externally-help' => 'Sjoch de [http://meta.wikimedia.org/wiki/Help:External_editors ynstel-hantlieding] foar mear ynformaasje.',
+'edit-externally-help' => 'Sjoch de [http://www.mediawiki.org/wiki/Manual:External_editors ynstel-hantlieding] foar mear ynformaasje.',
 
 # 'all' in various places, this might be different for inflected languages
-'watchlistall2' => 'alles',
-'namespacesall' => 'alle',
-'monthsall'     => 'alle',
+'recentchangesall' => 'alle',
+'imagelistall'     => 'alle',
+'watchlistall2'    => 'alles',
+'namespacesall'    => 'alle',
+'monthsall'        => 'alle',
 
 # E-mail address confirmation
 'confirmemail'            => 'Befêstigjen netpostadres',
 'confirmemail_text'       => '{{SITENAME}} freget dat jo jo netpostadres befêstigje eart jo hjir netpost brûke. Brûk de knop hjirûnder om josels in befêstigingskoade ta te stjoeren op it adres dat jo opjûn hawwe. Iepenje de koade dan yn jo blêder om te befêstigjen dat jo netpostadres jildich is.',
 'confirmemail_send'       => 'Stjoer in befêstigingskoade',
+'confirmemail_sent'       => 'Befêstiginskoade tastjoerd.',
 'confirmemail_sendfailed' => 'De befêstiginskoade koe net stjoerd wurde. Faaks stean der ferkearde tekens yn it netpostadres.
 
 Berjocht: $1',
@@ -1409,6 +1750,9 @@
 : ''$2''
 Wolle jo de side wier op 'e nij skriuwe?",
 
+# HTML dump
+'redirectingto' => 'Synonym foar [[:$1]]...',
+
 # Auto-summaries
 'autosumm-blank'   => 'Alle ynhâld fan de side weismiten',
 'autosumm-replace' => "Side ferfong mei '$1'",
@@ -1418,18 +1762,56 @@
 # Live preview
 'livepreview-loading' => 'Ynlade...',
 
+# Watchlist editor
+'watchlistedit-raw-titles' => 'Siden:',
+'watchlistedit-raw-added'  => '{{PLURAL:$1|1 side is|$1 siden binne}} tafoege:',
+
 # Watchlist editing tools
 'watchlisttools-view' => 'Folchlist besjen',
 'watchlisttools-edit' => 'Folchlist besjen en bewurkje',
 'watchlisttools-raw'  => 'Rûge folchlist bewurkje',
 
 # Special:Version
-'version' => 'Programmatuerferzje', # Not used as normal message but as header for the special page itself
+'version'                  => 'Programmatuerferzje', # Not used as normal message but as header for the special page itself
+'version-version'          => 'Ferzje',
+'version-license'          => 'Lisinsje',
+'version-software-product' => 'Produkt',
+'version-software-version' => 'Ferzje',
 
-# Special:Filepath
-'filepath' => 'Triempad',
+# Special:FilePath
+'filepath'        => 'Triempad',
+'filepath-page'   => 'Triem:',
+'filepath-submit' => 'Pad',
 
+# Special:FileDuplicateSearch
+'fileduplicatesearch'          => 'Sykje op duplikaten',
+'fileduplicatesearch-legend'   => 'Sykje op duplikaten',
+'fileduplicatesearch-filename' => 'Triemnamme:',
+'fileduplicatesearch-submit'   => 'Sykje',
+'fileduplicatesearch-info'     => '$1 × $2 pixel<br />Triemgrutte: $3<br />MIME-type: $4',
+'fileduplicatesearch-result-1' => 'De triem "$1" hat gjin duplikaten.',
+'fileduplicatesearch-result-n' => 'De triem "$1" hat {{PLURAL:$2|1 duplikaat|$2 duplikaten}}.',
+
 # Special:SpecialPages
-'specialpages' => 'Bysûndere siden',
+'specialpages'                   => 'Bysûndere siden',
+'specialpages-note'              => '----
+* Normale bysûndere siden.
+* <span class="mw-specialpagerestricted">Beheinde bysûndere siden.</span>',
+'specialpages-group-maintenance' => 'Underhâld siden',
+'specialpages-group-other'       => 'Oare bysûndere siden',
+'specialpages-group-login'       => 'Oanmelde',
+'specialpages-group-changes'     => 'Koartlyn feroare en lochs',
+'specialpages-group-media'       => 'Oanbieden en oare triemsiden',
+'specialpages-group-users'       => 'Meidoggers en rjochten',
+'specialpages-group-highuse'     => "Siden dy't in protte brûkt wurde",
+'specialpages-group-pages'       => 'List fan siden',
+'specialpages-group-pagetools'   => 'Sidehelpmiddels',
+'specialpages-group-wiki'        => 'Wikigegevens en -helpmiddels',
+'specialpages-group-redirects'   => 'Trochferwizende bysûndere siden',
+'specialpages-group-spam'        => 'Spamhelpmiddels',
 
+# Special:BlankPage
+'blankpage'              => 'Side is leech',
+'intentionallyblankpage' => 'Dizze side is bewust leech lizzen en wurdt brûkt foar benchmarks, ensfh.',
+
 );
Index: languages/messages/MessagesVi.php
===================================================================
--- languages/messages/MessagesVi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesVi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,23 +4,21 @@
  * @ingroup Language
  * @file
  *
- * @author Vinhtantran
- * @author Minh Nguyen
- * @author Siebrand
- * @author לערי ריינהארט
- * @author SPQRobin
- * @author Trần Thế Trung
- * @author Nguyễn Thanh Quang
- * @author Mxn
  * @author Apple
  * @author Arisa
  * @author DHN
+ * @author Minh Nguyen
+ * @author Mxn
  * @author Neoneurone
+ * @author Nguyễn Thanh Quang
  * @author Thaisk
  * @author Tmct
+ * @author Trần Thế Trung
  * @author Tttrung
  * @author Vietbio
+ * @author Vinhtantran
  * @author Vương Ngân Hà
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -426,12 +424,12 @@
 'readonlytext'         => 'Cơ sở dữ liệu hiện đã bị khóa không nhận trang mới và các điều chỉnh khác, có lẽ để bảo trì cơ sở dữ liệu định kỳ, một thời gian ngắn nữa nó sẽ trở lại bình thường.
 
 Người quản lý khóa nó đã đưa ra lời giải thích sau: $1',
-'missing-article'      => 'Cơ sở dữ liệu không tìm thấy văn bản của một trang mà lẽ ra phải thấy, trang "$1" $2.
+'missing-article'      => 'Cơ sở dữ liệu không tìm thấy văn bản của trang lẽ ra phải có, trang      Normal   0               false   false   false      EN-US   X-NONE   X-NONE                                                     MicrosoftInternetExplorer4                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     “$1” $2.
 
-Điều này thường xảy ra do liên kết khác biệt phiên bản hoặc lịch sử có liên kết đến một trang đã bị xóa.
+Điều này thường xảy ra do nhấn vào liên kết khác biệt phiên bản đã quá lâu hoặc liên kết lịch sử của một trang đã bị xóa.
 
-Nếu trường hợp này không phải như vậy, có thể bạn đã gặp phải một lỗi trong phần mềm.
-Xin hãy báo nó cho một bảo quản viên, trong đó ghi lại địa chỉ URL.',
+Nếu không phải lý do trên, có thể bạn đã gặp phải một lỗi của phần mềm.
+Xin hãy báo nó cho một [[Special:ListUsers/sysop|bảo quản viên]], trong đó ghi lại địa chỉ URL.',
 'missingarticle-rev'   => '(số phiên bản: $1)',
 'missingarticle-diff'  => '(Khác: $1, $2)',
 'readonly_lag'         => 'Cơ sở dữ liệu bị khóa tự động trong khi các máy chủ cập nhật thông tin của nhau.',
@@ -480,11 +478,12 @@
 
 # Login and logout pages
 'logouttitle'                => 'Đăng xuất',
-'logouttext'                 => "<strong>Bạn đã đăng xuất.</strong><br />
-Bạn có thể tiếp tục dùng {{SITENAME}} một cách vô danh, hoặc bạn có thể đăng nhập lại dưới tên người dùng này hoặc tên người dùng khác. Xin lưu ý rằng một vài trang có thể vẫn hiển thị như bạn còn đăng nhập cho đến khi bạn xóa vùng nhớ đệm (''cache'') của trình duyệt.",
+'logouttext'                 => "<strong>Bạn đã đăng xuất.</strong>
+
+Bạn có thể tiếp tục dùng {{SITENAME}} một cách vô danh, hoặc bạn có thể [[Special:UserLogin|đăng nhập lại]] dưới cùng tên người dùng này hoặc một tên người dùng khác. Xin lưu ý rằng một vài trang có thể vẫn hiển thị như khi bạn còn đăng nhập, cho đến khi bạn xóa vùng nhớ đệm (''cache'') của trình duyệt.",
 'welcomecreation'            => '== Chào mừng, $1! ==
-
-Tài khoản của bạn đã mở. Đừng quên thay đổi tùy chọn cá nhân của bạn tại {{SITENAME}}.',
+Tài khoản của bạn đã mở.
+Đừng quên thay đổi [[Special:Preferences|tùy chọn cá nhân của bạn tại {{SITENAME}}]].',
 'loginpagetitle'             => 'Đăng nhập',
 'yourname'                   => 'Tên người dùng:',
 'yourpassword'               => 'Mật khẩu',
@@ -613,39 +612,38 @@
 'blockedtitle'                     => 'Thành viên bị cấm',
 'blockedtext'                      => "<big>'''Tên người dùng hoặc địa chỉ IP của bạn đã bị cấm.'''</big>
 
-Người thực hiện cấm là $1. Lý do được cung cấp là ''$2''.
+Người thực hiện cấm là $1.
+Lý do được cung cấp là ''$2''.
 
 * Bắt đầu cấm: $8
 * Kết thúc cấm: $6
-* Người bị cấm: $7
+* Mục tiêu cấm: $7
 
-Bạn có thể liên lạc với $1 hoặc một [[{{MediaWiki:Grouppage-sysop}}|người quản lý]] khác để thảo luận về việc cấm.
-Bạn không thể sử dụng tính năng “gửi thư cho người này” trừ khi bạn đã đăng ký một địa chỉ thư điện tử hợp lý trong [[Special:Preferences|tùy chọn tài khoản]] và bạn không bị khóa chức năng đó.
+Bạn có thể liên hệ với $1 hoặc một [[{{MediaWiki:Grouppage-sysop}}|bảo quản viên]] khác để thảo luận về việc cấm.
+Bạn không thể sử dụng tính năng “gửi thư cho người này” trừ khi bạn đã đăng ký một địa chỉ thư điện tử hợp lệ trong [[Special:Preferences|tùy chọn tài khoản]] và bạn không bị khóa chức năng đó.
 Địa chỉ IP hiện tại của bạn là $3, và mã số cấm là #$5.
-Xin hãy ghi kèm theo một trong hai hoặc cả hai vào các yêu cầu của bạn.",
-'autoblockedtext'                  => "Địa chỉ IP của bạn đã bị tự động cấm vì một người nào đó đã sử dụng nó, và người đó đã bị $1 cấm.
+Xin hãy ghi kèm tất cả các thông tin trên vào thư yêu cầu của bạn.",
+'autoblockedtext'                  => "Địa chỉ IP của bạn đã bị tự động cấm vì một người nào đó đã sử dụng nó, $1 là thành viên đã thực hiện cấm.
 Lý do được cung cấp là:
 
 :''$2''
 
-* Thời điểm bắt đầu cấm: $8
-* Thời điểm kết thúc cấm: $6
+* Bắt đầu cấm: $8
+* Kết thúc cấm: $6
+* Mục tiêu cấm: $7
 
-Bạn có thể liên lạc với $1 hoặc một trong số các
-[[{{MediaWiki:Grouppage-sysop}}|quản lý]] khác để thảo luận về việc cấm.
+Bạn có thể liên hệ với $1 hoặc một trong số các
+[[{{MediaWiki:Grouppage-sysop}}|bảo quản viên]] khác để thảo luận về việc cấm.
 
-Chú ý rằng bạn sẽ không dùng được chức năng “gửi thư cho người này” trừ khi bạn đã đăng ký một địa chỉ thư điện tử đúng trong [[Special:Preferences|tùy chọn]] và chức năng đó không bị cấm.
+Chú ý rằng bạn sẽ không dùng được chức năng “gửi thư cho người này” trừ khi bạn đã đăng ký một địa chỉ thư điện tử hợp lệ trong [[Special:Preferences|tùy chọn]] và bạn không bị cấm dùng chức năng đó.
 
-Mã số cấm của bạn là $5. Xin hãy ghi kèm mã số này trong những yêu cầu của bạn.",
+Địa chỉ IP hiện tại của bạn là $3, mã số cấm là $5.
+Xin hãy ghi kèm tất cả các chi tiết trên vào thư yêu cầu của bạn.",
 'blockednoreason'                  => 'không đưa ra lý do',
 'blockedoriginalsource'            => "Mã nguồn của '''$1''':",
 'blockededitsource'                => "Các '''sửa đổi của bạn''' ở '''$1''':",
 'whitelistedittitle'               => 'Cần đăng nhập để sửa trang',
 'whitelistedittext'                => 'Bạn phải $1 để sửa trang.',
-'whitelistreadtitle'               => 'Cần đăng nhập để đọc nội dung',
-'whitelistreadtext'                => 'Bạn cần [[Special:Userlogin|đăng nhập]] để đọc nội dung.',
-'whitelistacctitle'                => 'Bạn không được phép mở tài khoản.',
-'whitelistacctext'                 => 'Bạn cần [[Special:Userlogin|đăng nhập]] để mở tài khoản và phải có quyền tương ứng tại {{SITENAME}}.',
 'confirmedittitle'                 => 'Cần xác nhận địa chỉ thư điện tử trước khi sửa đổi',
 'confirmedittext'                  => 'Bạn cần phải xác nhận địa chỉ thư điện tử trước khi được sửa đổi trang. Xin hãy đặt và xác nhận địa chỉ thư điện tử của bạn dùng trang [[Special:Preferences|tùy chọn]].',
 'nosuchsectiontitle'               => 'Không có mục nào như vậy',
@@ -657,7 +655,10 @@
 'accmailtext'                      => 'Mật khẩu của “$1” đã được gửi đến $2.',
 'newarticle'                       => '(Mới)',
 'newarticletext'                   => "Bạn đi đến đây từ một liên kết đến một trang chưa tồn tại. Để tạo trang, hãy bắt đầu gõ vào ô bên dưới (xem [[{{MediaWiki:Helppage}}|trang trợ giúp]] để có thêm thông tin). Nếu bạn đến đây do nhầm lẫn, chỉ cần nhấn vào nút '''Back''' trên trình duyệt của bạn.",
-'anontalkpagetext'                 => "----''Đây là trang thảo luận của một thành viên vô danh chưa tạo tài khoản hoặc có nhưng không đăng nhập. Do đó chúng ta phải dùng một dãy số gọi là địa chỉ IP để xác định anh/chị ta. Một địa chỉ IP như vậy có thể có nhiều người cùng dùng chung. Nếu bạn là một thành viên vô danh và cảm thấy rằng có những lời bàn luận không thích hợp đang nhắm vào bạn, xin hãy [[Special:Userlogin|tạo tài khoản hoặc đăng nhập]] để tránh sự nhầm lẫn về sau với những thành viên vô danh khác.''",
+'anontalkpagetext'                 => "----''Đây là trang thảo luận của một thành viên vô danh chưa tạo tài khoản hoặc có tài khoản nhưng không đăng nhập.
+Do đó chúng ta phải dùng một dãy số gọi là địa chỉ IP để xác định anh/chị ta.
+Một địa chỉ IP như vậy có thể có nhiều người cùng dùng chung.
+Nếu bạn là một thành viên vô danh và cảm thấy rằng có những lời bàn luận không thích hợp đang nhắm vào bạn, xin hãy [[Special:UserLogin/signup|tạo tài khoản]] hoặc [[Special:UserLogin|đăng nhập]] để tránh sự nhầm lẫn về sau với những thành viên vô danh khác.''",
 'noarticletext'                    => 'Trang này hiện chưa có gì, bạn có thể [[Special:Search/{{PAGENAME}}|tìm kiếm tựa trang]] tại các trang khác hoặc [{{fullurl:{{FULLPAGENAME}}|action=edit}} sửa đổi trang này].',
 'userpage-userdoesnotexist'        => 'Tài khoản mang tên “$1” chưa được đăng ký. Xin hãy kiểm tra lại nếu bạn muốn tạo/sửa trang này.',
 'clearyourcache'                   => "'''Ghi chú - Sau khi lưu trang, có thể bạn sẽ phải xóa bộ nhớ đệm của trình duyệt để xem các thay đổi.''' '''Mozilla / Firefox / Safari:''' giữ phím ''Shift'' trong khi nhấn ''Reload'', hoặc nhấn tổ hợp ''Ctrl-F5'' hay ''Ctrl-R'' (''Command-R'' trên Macintosh); '''Konqueror:''': nhấn nút ''Reload'' hoặc nhấn ''F5''; '''Opera:''' xóa bộ nhớ đệm trong ''Tools → Preferences''; '''Internet Explorer:''' giữ phím ''Ctrl'' trong khi nhấn ''Refresh'', hoặc nhấn tổ hợp ''Ctrl-F5''.",
@@ -675,7 +676,8 @@
 
 ''Do {{SITENAME}} cho phép dùng mã HTML, trang xem thử được giấu đi để đề phòng bị tấn công bằng JavaScript.''
 
-<strong>Nếu sửa đổi này là đúng đắn, xin hãy thử lần nữa. Nếu vẫn không thành công, bạn hãy thử đăng xuất và đăng nhập lại.</strong>",
+<strong>Nếu sửa đổi này là đúng đắn, xin hãy thử lần nữa. 
+Nếu vẫn không thành công, bạn hãy thử [[Special:UserLogout|đăng xuất]] rồi đăng nhập lại.</strong>",
 'token_suffix_mismatch'            => '<strong>Sửa đổi của bạn bị hủy bỏ vì trình duyệt của bạn lẫn lộn các ký tự dấu trong số hiệu
 sửa đổi. Việc hủy bỏ này nhằm tránh nội dung trang bị hỏng.
 Điều này thường xảy ra khi bạn sử dụng một dịch vụ proxy vô danh trên web có vấn đề.</strong>',
@@ -715,7 +717,7 @@
 'edittools'                        => '<!-- Văn bản dưới đây sẽ xuất hiện phía dưới mẫu sửa đổi và tải lên. -->',
 'nocreatetitle'                    => 'Khả năng tạo trang bị hạn chế',
 'nocreatetext'                     => '{{SITENAME}} đã hạn chế khả năng tạo trang mới.
-Bạn có thể quay trở lại và sửa đổi các trang đã có, hoặc [[Special:Userlogin|đăng nhập hoặc tạo tài khoản]].',
+Bạn có thể quay trở lại và sửa đổi các trang đã có, hoặc [[Special:UserLogin|đăng nhập hoặc tạo tài khoản]].',
 'nocreate-loggedin'                => 'Bạn không có quyền tạo trang mới trên {{SITENAME}}.',
 'permissionserrors'                => 'Không có quyền thực hiện',
 'permissionserrorstext'            => 'Bạn không có quyền thực hiện thao tác đó, vì {{PLURAL:$1|lý do|lý do}}:',
@@ -741,7 +743,7 @@
 'undo-success' => 'Các sửa đổi có thể được lùi lại. Xin hãy kiểm tra phần so sánh bên dưới để xác nhận lại những gì bạn muốn làm, sau đó lưu thay đổi ở dưới để hoàn tất việc lùi lại sửa đổi.',
 'undo-failure' => 'Sửa đổi không thể phục hồi vì đã có những sửa đổi mới ở sau.',
 'undo-norev'   => 'Sửa đổi không thể hồi phục vì nó không tồn tại hoặc đã bị xóa.',
-'undo-summary' => 'Đã lùi lại sửa đổi $1 của [[Special:Contributions/$2|$2]] ([[User talk:$2|thảo luận]])',
+'undo-summary' => 'Đã lùi lại sửa đổi $1 của [[Special:Contributions/$2|$2]] ([[User talk:$2|Thảo luận]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Không có thể mở tài khoản',
@@ -835,7 +837,7 @@
 # Suppression log
 'suppressionlog'     => 'Nhật trình giấu',
 'suppressionlogtext' => 'Dưới đây là danh sách các tác vụ xóa và cấm liên quan đến nội dung mà các quản lý không nhìn thấy. 
-Xem [[Special:Ipblocklist|danh sách các IP bị cấm]] để xem danh sách các tác vụ cấm chỉ và cấm thông thường hiện nay.',
+Xem [[Special:IPBlockList|danh sách các IP bị cấm]] để xem danh sách các tác vụ cấm chỉ và cấm thông thường hiện nay.',
 
 # History merging
 'mergehistory'                     => 'Trộn lịch sử trang',
@@ -875,7 +877,7 @@
 # Search results
 'searchresults'             => 'Kết quả tìm kiếm',
 'searchresulttext'          => 'Để biết thêm chi tiết về tìm kiếm tại {{SITENAME}}, xem [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "Tìm '''[[:$1]]'''",
+'searchsubtitle'            => "Bạn đã tìm '''[[:$1]]''' ([[Special:Prefixindex/$1|tất cả các trang bắt đầu bằng “$1”]] | [[Special:WhatLinksHere/$1|tất cả các trang liên kết đến “$1”]])",
 'searchsubtitleinvalid'     => "Tìm '''$1'''",
 'noexactmatch'              => "'''Trang “$1” không tồn tại.''' Bạn có thể [[:$1|tạo trang này]].",
 'noexactmatch-nocreate'     => "'''Không có trang nào có tên “$1”.'''",
@@ -918,7 +920,7 @@
 'mypreferences'            => 'Tùy chọn',
 'prefs-edits'              => 'Số lần sửa đổi:',
 'prefsnologin'             => 'Chưa đăng nhập',
-'prefsnologintext'         => 'Bạn phải [[Special:Userlogin|đăng nhập]] để thiết lập tùy chọn cá nhân.',
+'prefsnologintext'         => 'Bạn phải [[Special:UserLogin|đăng nhập]] để thiết lập tùy chọn cá nhân.',
 'prefsreset'               => 'Các tùy chọn cá nhân đã được mặc định lại.',
 'qbsettings'               => 'Thanh công cụ',
 'qbsettings-none'          => 'Không có',
@@ -992,7 +994,7 @@
 'userrights-reason'           => 'Lý do thay đổi:',
 'userrights-no-interwiki'     => 'Bạn không có quyền thay đổi quyền hạn của thành viên tại các wiki khác.',
 'userrights-nodatabase'       => 'Cơ sở dữ liệu $1 không tồn tại hoặc nằm ở bên ngoài.',
-'userrights-nologin'          => 'Bạn phải [[Special:Userlogin|đăng nhập]] vào một tài khoản có quyền quản lý để gán quyền cho thành viên.',
+'userrights-nologin'          => 'Bạn phải [[Special:UserLogin|đăng nhập]] vào một tài khoản có quyền quản lý để gán quyền cho thành viên.',
 'userrights-notallowed'       => 'Tài khoản của bạn không có quyền gán quyền cho thành viên.',
 'userrights-changeable-col'   => 'Những nhóm bạn có thể thay đổi',
 'userrights-unchangeable-col' => 'Những nhóm bạn không thể thay đổi',
@@ -1122,23 +1124,25 @@
 'reupload'                    => 'Tải lại',
 'reuploaddesc'                => 'Hủy tác vụ tải và quay lại mẫu tải tập tin lên',
 'uploadnologin'               => 'Chưa đăng nhập',
-'uploadnologintext'           => 'Bạn phải [[Special:Userlogin|đăng nhập]] để tải tập tin lên.',
+'uploadnologintext'           => 'Bạn phải [[Special:UserLogin|đăng nhập]] để tải tập tin lên.',
 'upload_directory_missing'    => 'Thư mục tải lên ($1) không có hoặc máy chủ web không thể tạo được.',
 'upload_directory_read_only'  => 'Máy chủ không thể sửa đổi thư mục tải lên ($1) được.',
 'uploaderror'                 => 'Lỗi khi tải lên',
-'uploadtext'                  => "Hãy sử dụng mẫu sau để tải tập tin.
-Để xem hoặc tìm kiếm những hình ảnh đã được tải lên trước đây, xin mời xem [[Special:Imagelist|danh sách các tập tin đã tải lên]];
-việc tải lên và xóa đi cũng được ghi lại trong [[Special:Log/upload|nhật trình tải lên]].
+'uploadtext'                  => "Hãy sử dụng mẫu sau để tải tập tin lên.
+Để xem hoặc tìm kiếm những hình ảnh đã được tải lên trước đây, xin mời xem [[Special:ImageList|danh sách các tập tin đã tải lên]]. 
+việc tải lên và tải lên lại được ghi lại trong [[Special:Log/upload|nhật trình tải lên]],  việc xóa đi được ghi trong [[Special:Log/delete|nhật trình xóa]].
 
-Để đưa hình vào trang, hãy dùng một liên kết theo dạng '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Tập tin.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Tập tin.png|văn bản thay thế]]</nowiki>''' hoặc
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Tập tin.ogg]]</nowiki>''' để trực tiếp liên kết đến tập tin.",
+Để đưa tập tin vào trang, hãy dùng liên kết có một trong các dạng sau:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Tập tin.jpg]]</nowiki></tt>''' để phiên bản đầy đủ của tập tin
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Tập tin.png|200px|nhỏ|trái|văn bản thay thế]]</tt></nowiki>''' để dùng hình đã được co lại còn 200 pixel chiều rộng đặt trong một hộp ở lề bên trái với 'văn bản thay thế' dùng để mô tả
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Tập tin.ogg]]</nowiki>''' để liên kết trực tiếp đến tập tin mà không hiển thị nó",
 'upload-permitted'            => 'Các định dạng tập tin được phép tải lên: $1.',
 'upload-preferred'            => 'Các định dạng tập tin nên dùng: $1.',
 'upload-prohibited'           => 'Các định dạng tập tin bị cấm: $1.',
 'uploadlog'                   => 'nhật trình tải lên',
 'uploadlogpage'               => 'Nhật trình tải lên',
-'uploadlogpagetext'           => 'Danh sách các tập tin đã tải lên, theo  giờ máy chủ (UTC).',
+'uploadlogpagetext'           => 'Dưới đây là danh sách các tập tin đã tải lên gần nhất.
+Xem [[Special:NewImages|trang trưng bày các tập tin mới]] để xem trực quan hơn.',
 'filename'                    => 'Tên tập tin:',
 'filedesc'                    => 'Miêu tả:',
 'fileuploadsummary'           => 'Tóm lược:',
@@ -1211,9 +1215,12 @@
 'upload-proto-error'      => 'Giao thức sai',
 'upload-proto-error-text' => 'Phải đưa vào URL bắt đầu với <code>http://</code> hay <code>ftp://</code> để tải lên tập tin từ trang web khác.',
 'upload-file-error'       => 'Lỗi nội bộ',
-'upload-file-error-text'  => 'Có lỗi nội bộ khi tạo ra tập tin tạm trên máy chủ. Xin hãy liên lạc với người quản lý hệ thống.',
+'upload-file-error-text'  => 'Có lỗi nội bộ khi tạo tập tin tạm trên máy chủ.
+Xin hãy liên hệ với một [[Special:ListUsers/sysop|bảo quản viên]].',
 'upload-misc-error'       => 'Có lỗi lạ khi tải lên',
-'upload-misc-error-text'  => 'Có lỗi lạ khi tải lên.  Xin hãy xác nhận lại địa chỉ URL có đúng và có thể truy cập được không rồi thử lại lần nữa.  Nếu vẫn còn bị lỗi, xin hãy liên lạc với người quản lý hệ thống.',
+'upload-misc-error-text'  => 'Có lỗi lạ khi tải lên.
+Xin hãy xác nhận lại địa chỉ URL là hợp lệ và có thể truy cập được không rồi thử lại lần nữa.
+Nếu vẫn còn bị lỗi, xin hãy liên hệ với một [[Special:ListUsers/sysop|bảo quản viên]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Không thể truy cập URL',
@@ -1227,7 +1234,7 @@
 'upload_source_url'  => ' (địa chỉ URL đúng, có thể truy cập)',
 'upload_source_file' => ' (tập tin trên máy của bạn)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Trang đặc biệt này liệt kê các tập tin được tải lên.
 Theo mặc định, các tập tin mới nhất được xếp vào đầu danh sách.
 Hãy nhấn chuột vào tiêu đề cột để thay đổi thứ tự sắp xếp.',
@@ -1255,7 +1262,7 @@
 'imagelinks'                     => 'Liên kết',
 'linkstoimage'                   => '{{PLURAL:$1|Trang|$1 trang}} sau có liên kết đến tập tin này:',
 'nolinkstoimage'                 => 'Không có trang nào chứa liên kết đến hình.',
-'morelinkstoimage'               => 'Xem [[Special:Whatlinkshere/$1|thêm liên kết]] đến tập tin này.',
+'morelinkstoimage'               => 'Xem [[Special:WhatLinksHere/$1|thêm liên kết]] đến tập tin này.',
 'redirectstofile'                => '{{PLURAL:$1|Tập tin|$1 tập tin}} sau chuyển hướng đến tập tin này:',
 'duplicatesoffile'               => '{{PLURAL:$1|Tập tin sau|$1 tập tin sau}} là bản sao của tập tin này:',
 'sharedupload'                   => 'Tập tin này được tải lên để dùng chung và có thể dùng ở các dự án khác.',
@@ -1274,18 +1281,18 @@
 # File reversion
 'filerevert'                => 'Lùi lại phiên bản của $1',
 'filerevert-legend'         => 'Lùi lại tập tin',
-'filerevert-intro'          => '<span class="plainlinks">Bạn đang lùi \'\'\'[[Media:$1|$1]]\'\'\' về [$4 phiên bản lúc $3, $2].</span>',
+'filerevert-intro'          => "Bạn đang lùi '''[[Media:$1|$1]]''' về [$4 phiên bản lúc $3, $2].",
 'filerevert-comment'        => 'Lý do:',
 'filerevert-defaultcomment' => 'Đã lùi về phiên bản lúc $2, $1',
 'filerevert-submit'         => 'Lùi lại',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' đã được lùi về [$4 phiên bản lúc $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' đã được lùi về [$4 phiên bản lúc $3, $2].",
 'filerevert-badversion'     => 'Không tồn tại phiên bản trước đó của tập tin tại thời điểm trên.',
 
 # File deletion
 'filedelete'                  => 'Xóa $1',
 'filedelete-legend'           => 'Xóa tập tin',
 'filedelete-intro'            => "Bạn đang xóa '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Bạn đang xóa phiên bản của \'\'\'[[Media:$1|$1]]\'\'\' vào lúc [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Bạn đang xóa phiên bản của '''[[Media:$1|$1]]''' vào lúc [$4 $3, $2].",
 'filedelete-comment'          => 'Lý do:',
 'filedelete-submit'           => 'Xóa',
 'filedelete-success'          => "'''$1''' đã bị xóa.",
@@ -1338,15 +1345,17 @@
 Đã có tổng cộng '''$3''' lần truy cập, và '''$4''' sửa đổi từ khi {{SITENAME}} được khởi tạo. Như vậy trung bình có '''$5''' sửa đổi tại mỗi trang, và '''$6''' lần truy cập trên mỗi sửa đổi.
 
 Độ dài của [http://www.mediawiki.org/wiki/Manual:Job_queue hàng đợi việc] là '''$7'''.",
-'userstatstext'          => "Có '''$1''' [[Special:Listusers|thành viên]] đã đăng ký tài khoản, trong số đó có '''$2''' thành viên (chiếm '''$4%''' trên tổng số) {{PLURAL:$2||}} là $5.",
+'userstatstext'          => "Có '''$1''' [[Special:ListUsers|thành viên]] đã đăng ký tài khoản, trong số đó có '''$2''' thành viên (chiếm '''$4%''' trên tổng số) {{PLURAL:$2||}} là $5.",
 'statistics-mostpopular' => 'Các trang được xem nhiều nhất',
 
 'disambiguations'      => 'Trang định hướng',
 'disambiguationspage'  => 'Template:disambig',
 'disambiguations-text' => "Các trang này có liên kết đến một '''trang định hướng'''. Nên sửa các liên kết này để chỉ đến một trang đúng nghĩa hơn.<br />Các trang định hướng là trang sử dụng những tiêu bản được liệt kê ở [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Đổi hướng kép',
-'doubleredirectstext' => 'Trang này liệt kê các trang chuyển hướng đến một trang chuyển hướng khác. Mỗi hàng có chứa các liên kết đến trang chuyển hướng thứ nhất và thứ hai, cũng như mục tiêu của trang chuyển hướng thứ hai, thường chỉ tới trang đích “thực sự”, là nơi mà trang chuyển hướng đầu tiên nên trỏ đến.',
+'doubleredirects'            => 'Đổi hướng kép',
+'doubleredirectstext'        => 'Trang này liệt kê các trang chuyển hướng đến một trang chuyển hướng khác. Mỗi hàng có chứa các liên kết đến trang chuyển hướng thứ nhất và thứ hai, cũng như mục tiêu của trang chuyển hướng thứ hai, thường chỉ tới trang đích “thực sự”, là nơi mà trang chuyển hướng đầu tiên nên trỏ đến.',
+'double-redirect-fixed-move' => '[[$1]] đã được đổi tên, giờ nó là trang đổi hướng đến [[$2]]',
+'double-redirect-fixer'      => 'Người sửa trang đổi hướng',
 
 'brokenredirects'        => 'Đổi hướng sai',
 'brokenredirectstext'    => 'Các trang đổi hướng sau đây liên kết đến một trang không tồn tại.',
@@ -1432,7 +1441,7 @@
 'logempty'             => 'Không có mục nào khớp với từ khóa.',
 'log-title-wildcard'   => 'Tìm các tựa trang bắt đầu bằng các chữ này',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tất cả các trang',
 'alphaindexline'    => '$1 đến $2',
 'nextpage'          => 'Trang sau ($1)',
@@ -1455,15 +1464,15 @@
 'special-categories-sort-count' => 'xếp theo số trang',
 'special-categories-sort-abc'   => 'xếp theo vần',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Hiển thị thành viên bắt đầu từ:',
 'listusers-submit'   => 'Liệt kê',
 'listusers-noresult' => 'Không thấy thành viên.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Nhóm thành viên',
 'listgrouprights-summary'  => 'Dưới đây là danh sách nhóm thành viên được định nghĩa tại wiki này, với mức độ truy cập của từng nhóm.
-Thông tin thêm về từng nhóm có thể xem tại [[{{MediaWiki:Listgrouprights-helppage}}|đây]].',
+Có [[{{MediaWiki:Listgrouprights-helppage}}|thông tin thêm]] về từng nhóm riêng biệt.',
 'listgrouprights-group'    => 'Nhóm',
 'listgrouprights-rights'   => 'Khả năng',
 'listgrouprights-helppage' => 'Help:Khả năng của nhóm thành viên',
@@ -1471,10 +1480,11 @@
 
 # E-mail user
 'mailnologin'     => 'Không có địa chỉ gửi thư',
-'mailnologintext' => 'Bạn phải [[Special:Userlogin|đăng nhập]] và khai báo một địa chỉ thư điện tử hợp lệ trong phần [[Special:Preferences|tùy chọn cá nhân]] thì mới gửi được thư cho người khác.',
+'mailnologintext' => 'Bạn phải [[Special:UserLogin|đăng nhập]] và khai báo một địa chỉ thư điện tử hợp lệ trong phần [[Special:Preferences|tùy chọn cá nhân]] thì mới gửi được thư cho người khác.',
 'emailuser'       => 'Gửi thư cho người này',
 'emailpage'       => 'Gửi thư',
-'emailpagetext'   => 'Nếu người này đã cung cấp địa chỉ thư điện tử hợp lệ tại tùy chọn cá nhân, biểu mẫu dưới đây sẽ cho bạn gửi thư. Địa chỉ thư điện tử của bạn sẽ xuất hiện trong phần địa chỉ “Người gửi” của bức thư, do đó người nhận sẽ có thể trả lời lại bạn.',
+'emailpagetext'   => 'Nếu người dùng này đã cung cấp địa chỉ thư điện tử hợp lệ tại tùy chọn cá nhân, mẫu dưới đây sẽ cho bạn gửi thư.
+Địa chỉ thư điện tử mà bạn đã cung cấp trong [[Special:Preferences|tùy chọn cá nhân của mình]] sẽ xuất hiện trong phần địa chỉ “Người gửi” của bức thư, do đó người nhận sẽ có thể trả lời lại bạn.',
 'usermailererror' => 'Lỗi gửi thư:',
 'defemailsubject' => 'thư gửi từ {{SITENAME}}',
 'noemailtitle'    => 'Không có địa chỉ nhận thư',
@@ -1497,9 +1507,9 @@
 'nowatchlist'          => 'Danh sách theo dõi của bạn không có gì.',
 'watchlistanontext'    => 'Xin hãy $1 để xem hay sửa đổi các trang được theo dõi.',
 'watchnologin'         => 'Chưa đăng nhập',
-'watchnologintext'     => 'Bạn phải [[Special:Userlogin|đăng nhập]] mới sửa đổi được danh sách theo dõi.',
+'watchnologintext'     => 'Bạn phải [[Special:UserLogin|đăng nhập]] mới sửa đổi được danh sách theo dõi.',
 'addedwatch'           => 'Đã thêm vào danh sách theo dõi',
-'addedwatchtext'       => 'Trang “<nowiki>$1</nowiki>” đã được cho vào [[Special:Watchlist|danh sách theo dõi]]. Những sửa đổi đối với trang này và trang thảo luận của nó sẽ được liệt kê, và được <b>tô đậm</b> trong [[Special:Recentchanges|danh sách các thay đổi mới]].
+'addedwatchtext'       => 'Trang “<nowiki>$1</nowiki>” đã được cho vào [[Special:Watchlist|danh sách theo dõi]]. Những sửa đổi đối với trang này và trang thảo luận của nó sẽ được liệt kê, và được <b>tô đậm</b> trong [[Special:RecentChanges|danh sách các thay đổi mới]].
 
 Nếu bạn muốn cho trang này ra khỏi danh sách theo dõi, nhấn vào "Ngừng theo dõi" ở trên.',
 'removedwatch'         => 'Đã ra khỏi danh sách theo dõi',
@@ -1605,15 +1615,15 @@
 'rollbacklink'                => 'phục hồi',
 'rollbackfailed'              => 'Không phục hồi được',
 'cantrollback'                => 'Không lùi sửa đổi được; người viết trang cuối cùng là tác giả duy nhất của trang này.',
-'alreadyrolled'               => 'Không thể phục hồi phiên bản của [[User:$2|$2]] ([[User talk:$2|Thảo luận]]) tại [[:$1]]; ai đó đã sửa đổi hoặc phục hồi rồi.
+'alreadyrolled'               => 'Không thể phục hồi các sửa đổi cuối của [[User:$2|$2]] ([[User talk:$2|Thảo luận]] | [[Special:Contributions/$2|{{int:contribslink}}]]); ai đó đã thực hiện sửa đổi hoặc phục hồi rồi.
 
-Sửa đổi lần cuối bởi [[User:$3|$3]] ([[User talk:$3|Thảo luận]]).',
+Sửa đổi cuối cùng tại trang được thực hiện bởi [[User:$3|$3]] ([[User talk:$3|Thảo luận]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Tóm lược sửa đổi: “<i>$1</i>”.', # only shown if there is an edit comment
 'revertpage'                  => 'Đã lùi sửa đổi của [[Special:Contributions/$2|$2]] ([[User talk:$2|Thảo luận]]) đến phiên bản của [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Đã hủy sửa đổi của $1; quay về phiên bản trước của $2.',
 'sessionfailure'              => 'Dường như có trục trặc với phiên đăng nhập của bạn; thao tác này đã bị hủy để tránh việc cướp quyền đăng nhập. Xin hãy nhấn nút “Back”, tải lại trang đó, rồi thử lại.',
 'protectlogpage'              => 'Nhật trình khóa',
-'protectlogtext'              => 'Dưới đây là danh sách các thao tác khóa và mở khóa trang. Xem [[Special:Protectedpages|danh sách các trang bị khóa]] để xem danh sách các trang hiện thời đang bị khóa.',
+'protectlogtext'              => 'Dưới đây là danh sách các thao tác khóa và mở khóa trang. Xem [[Special:ProtectedPages|danh sách các trang bị khóa]] để xem danh sách các trang hiện thời đang bị khóa.',
 'protectedarticle'            => 'đã khóa “[[$1]]”',
 'modifiedarticleprotection'   => 'đã đổi mức khóa cho “[[$1]]”',
 'unprotectedarticle'          => 'đã mở khóa cho “[[$1]]”',
@@ -1712,7 +1722,7 @@
 'blanknamespace' => '(Chính)',
 
 # Contributions
-'contributions' => 'Đóng góp',
+'contributions' => 'Đóng góp của thành viên',
 'mycontris'     => 'Đóng góp của tôi',
 'contribsub2'   => 'Của $1 ($2)',
 'nocontribs'    => 'Không tìm thấy thay đổi nào khớp với yêu cầu.',
@@ -1729,7 +1739,7 @@
 
 # What links here
 'whatlinkshere'            => 'Các liên kết đến đây',
-'whatlinkshere-title'      => 'Các trang liên kết đến $1',
+'whatlinkshere-title'      => 'Các trang liên kết đến “$1”',
 'whatlinkshere-page'       => 'Trang:',
 'linklistsub'              => '(Danh sách liên kết)',
 'linkshere'                => "Các trang sau liên kết đến '''[[:$1]]''':",
@@ -1784,7 +1794,7 @@
 'badipaddress'                    => 'Địa chỉ IP không hợp lệ',
 'blockipsuccesssub'               => 'Cấm thành công',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] đã bị cấm.
-<br />Xem lại những lần cấm tại [[Special:Ipblocklist|danh sách cấm]].',
+<br />Xem lại những lần cấm tại [[Special:IPBlockList|danh sách cấm]].',
 'ipb-edit-dropdown'               => 'Sửa đổi lý do cấm',
 'ipb-unblock-addr'                => 'Bỏ cấm $1',
 'ipb-unblock'                     => 'Bỏ cấm thành viên hay địa chỉ IP',
@@ -1795,7 +1805,7 @@
 'ipusubmit'                       => 'Bỏ cấm',
 'unblocked'                       => '[[User:$1|$1]] đã hết bị cấm',
 'unblocked-id'                    => '$1 đã hết bị cấm',
-'ipblocklist'                     => 'Danh sách cấm',
+'ipblocklist'                     => 'Địa chỉ IP và tên người dùng bị cấm',
 'ipblocklist-legend'              => 'Tìm một thành viên bị cấm',
 'ipblocklist-username'            => 'Tên thành viên hoặc địa chỉ IP:',
 'ipblocklist-submit'              => 'Tìm kiếm',
@@ -1814,7 +1824,7 @@
 'autoblocker'                     => 'Bạn bị tự động cấm vì địa chỉ IP của bạn vừa rồi đã được “$1” sử dụng. Lý do đưa ra cho việc cấm $1 là: ”$2”',
 'blocklogpage'                    => 'Nhật trình cấm',
 'blocklogentry'                   => 'đã cấm [[$1]] với thời hạn là $2 $3',
-'blocklogtext'                    => 'Đây là nhật trình ghi lại những lần cấm và bỏ cấm. Các địa chỉ IP bị cấm tự động không được liệt kê ở đây. Xem thêm [[Special:Ipblocklist|danh sách cấm]] để có danh sách cấm và cấm hẳn hiện tại.',
+'blocklogtext'                    => 'Đây là nhật trình ghi lại những lần cấm và bỏ cấm. Các địa chỉ IP bị cấm tự động không được liệt kê ở đây. Xem thêm [[Special:IPBlockList|danh sách cấm]] để có danh sách cấm và cấm hẳn hiện tại.',
 'unblocklogentry'                 => 'đã bỏ cấm “$1”',
 'block-log-flags-anononly'        => 'chỉ cấm thành viên vô danh',
 'block-log-flags-nocreate'        => 'cấm mở tài khoản',
@@ -1852,7 +1862,7 @@
 'lockdbsuccesssub'    => 'Đã khóa cơ sở dữ liệu thành công.',
 'unlockdbsuccesssub'  => 'Đã mở khóa cơ sở dữ liệu thành công',
 'lockdbsuccesstext'   => 'Cơ sở dữ liệu đã bị khóa.
-<br />Nhớ [[Special:Unlockdb|mở khóa]] sau khi bảo trì xong.',
+<br />Nhớ [[Special:UnlockDB|mở khóa]] sau khi bảo trì xong.',
 'unlockdbsuccesstext' => 'Cơ sở dữ liệu đã được mở khóa.',
 'lockfilenotwritable' => 'Tập tin khóa của cơ sở dữ liệu không cho phép ghi. Để khóa hay mở khóa cơ sở dữ liệu, máy chủ web phải có khả năng ghi tập tin.',
 'databasenotlocked'   => 'Cơ sở dữ liệu không bị khóa.',
@@ -1862,15 +1872,15 @@
 'move-page-legend'        => 'Di chuyển trang',
 'movepagetext'            => "Dùng mẫu dưới đây để đổi tên một trang, di chuyển tất cả lịch sử của nó sang tên mới.
 Tên cũ sẽ trở thành trang đổi hướng sang tên mới.
-Các liên kết đến trang cũ sẽ không thay đổi;
-hãy nhớ kiểm tra các đổi hướng kép hoặc đổi hướng sai.
+Bạn có thể cập nhật tự động các trang đổi hướng đến tên cũ.
+Nếu bạn chọn không cập nhật, hãy nhớ kiểm tra [[Special:DoubleRedirects|đổi hướng kép]] hoặc [[Special:BrokenRedirects|đổi hướng đến trang không tồn tại]].
 Bạn phải chịu trách nhiệm đảm bảo các liên kết đó tiếp tục trỏ đến nơi chúng cần đến.
 
-Chú ý rằng trang sẽ '''không''' bị di chuyển nếu đã có một trang tại tên mới, trừ khi nó rỗng hoặc là trang đổi hướng và không có lịch sử sửa đổi.
+Chú ý rằng trang sẽ '''không''' bị di chuyển nếu đã có một trang tại tên mới, trừ khi nó rỗng hoặc là trang đổi hướng và không có lịch sử sửa đổi trước đây.
 Điều này có nghĩa là bạn có thể đổi tên trang lại như cũ nếu bạn có nhầm lẫn, và bạn không thể ghi đè lên một trang đã có sẵn.
 
 '''CẢNH BÁO!'''
-Việc làm này có thể dẫn đến sự thay đổi mạnh mẽ và không lường trước đối với các trang phổ biến;
+Việc làm này có thể dẫn đến sự thay đổi mạnh mẽ và không lường trước đối với các trang dễ nhìn thấy;
 xin hãy chắc chắn rằng bạn đã nhận thức được những hệ lụy của nó trước khi thực hiện.",
 'movepagetalktext'        => "Trang thảo luận đi kèm sẽ được tự động di chuyển theo '''trừ khi''':
 *Đã tồn tại một trang thảo luận không trống tại tên mới, hoặc
@@ -1878,14 +1888,12 @@
 
 Trong những trường hợp đó, bạn phải di chuyển hoặc hợp nhất trang theo kiểu thủ công nếu muốn.",
 'movearticle'             => 'Di chuyển trang:',
-'movenologin'             => 'Chưa đăng nhập',
-'movenologintext'         => 'Bạn phải là thành viên đã đăng ký và [[Special:Userlogin|đăng nhập]] mới di chuyển trang được.',
 'movenotallowed'          => 'Bạn không có quyền di chuyển trang trong {{SITENAME}}.',
 'newtitle'                => 'Tên mới',
 'move-watch'              => 'Theo dõi trang này',
 'movepagebtn'             => 'Di chuyển trang',
 'pagemovedsub'            => 'Di chuyển thành công',
-'movepage-moved'          => "<big>'''“.$1” đã được di chuyển đến “.$2”'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => "<big>'''“$1” đã được di chuyển đến “$2”'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Đã có một trang với tên đó, hoặc tên bạn chọn không hợp lệ.
 Xin hãy chọn tên khác.',
 'cantmove-titleprotected' => 'Bạn không thể đổi tên trang, vì tên trang mới đã bị khóa không cho tạo mới',
@@ -1907,7 +1915,7 @@
 'delete_and_move'         => 'Xóa và đổi tên',
 'delete_and_move_text'    => '==Cần xóa==
 
-Trang với tên “[[$1]]” đã tồn tại. Bạn có muốn xóa nó để dọn chỗ di chuyển tới tên này không?',
+Trang với tên “[[:$1]]” đã tồn tại. Bạn có muốn xóa nó để dọn chỗ di chuyển tới tên này không?',
 'delete_and_move_confirm' => 'Xóa trang để đổi tên',
 'delete_and_move_reason'  => 'Xóa để có chỗ đổi tên',
 'selfmove'                => 'Tên mới giống tên cũ; không đổi tên một trang thành chính nó.',
@@ -1915,6 +1923,7 @@
 'imagenocrossnamespace'   => 'Không được di chuyển tập tin ra khỏi không gian tên Tập tin',
 'imagetypemismatch'       => 'Phần mở rộng trong tên tập tin mới không hợp dạng của tập tin',
 'imageinvalidfilename'    => 'Tên tập tin đích không hợp lệ',
+'fix-double-redirects'    => 'Cập nhật tất cả các trang đổi hướng chỉ đến tựa đề cũ',
 
 # Export
 'export'            => 'Xuất các trang',
@@ -1962,7 +1971,8 @@
 'import-interwiki-history'   => 'Sao chép tất cả các phiên bản cũ của trang này',
 'import-interwiki-submit'    => 'Nhập trang',
 'import-interwiki-namespace' => 'Chuyển các trang vào không gian tên:',
-'importtext'                 => 'Xin hãy xuất tập tin từ wiki nguồn sử dụng tính năng Special:Export, lưu nó vào máy của bạn rồi tải nó lên đây.',
+'importtext'                 => 'Xin hãy xuất tập tin từ wiki nguồn sử dụng [[Special:Export|tính năng xuất]].
+Lưu nó vào máy tính của bạn rồi tải nó lên đây.',
 'importstart'                => 'Đang nhập các trang…',
 'import-revision-count'      => '$1 {{PLURAL:$1|phiên bản|phiên bản}}',
 'importnopages'              => 'Không có trang để nhập vào.',
@@ -2112,10 +2122,11 @@
 'markedaspatrollederror-noautopatrol' => 'Bạn không được đánh dấu tuần tra vào sửa đổi của bạn.',
 
 # Patrol log
-'patrol-log-page' => 'Nhật ký tuần tra',
-'patrol-log-line' => 'đánh dấu tuần tra vào phiên bản $1 của $2 $3',
-'patrol-log-auto' => '(tự động)',
-'patrol-log-diff' => 'bản $1',
+'patrol-log-page'   => 'Nhật ký tuần tra',
+'patrol-log-header' => 'Đây là nhật trình tuần tra phiên bản.',
+'patrol-log-line'   => 'đánh dấu tuần tra vào phiên bản $1 của $2 $3',
+'patrol-log-auto'   => '(tự động)',
+'patrol-log-diff'   => 'bản $1',
 
 # Image deletion
 'deletedrevision'                 => 'Đã xóa phiên bản cũ $1',
@@ -2144,7 +2155,7 @@
 'show-big-image'       => 'Độ phân giải tối đa',
 'show-big-image-thumb' => '<small>Kích thước xem thử: $1 × $2 điểm ảnh</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Trang trưng bày hình ảnh mới',
 'imagelisttext'         => "Dưới đây là danh sách '''$1''' {{PLURAL:$1|tập tin|tập tin}} xếp theo $2.",
 'newimages-summary'     => 'Trang đặc biệt này hiển thị các tập tin được tải lên gần đây nhất.',
@@ -2427,7 +2438,7 @@
 
 # External editor support
 'edit-externally'      => 'Sửa bằng phần mềm bên ngoài',
-'edit-externally-help' => '* Xem thêm [http://meta.wikimedia.org/wiki/Help:External_editors hướng dẫn bằng tiếng Anh]',
+'edit-externally-help' => '* Xem thêm [http://www.mediawiki.org/wiki/Manual:External_editors hướng dẫn bằng tiếng Anh]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tất cả',
@@ -2499,7 +2510,7 @@
 'recreate'            => 'Tạo ra lại',
 
 # HTML dump
-'redirectingto' => 'Đang đổi hướng đến [[$1]]…',
+'redirectingto' => 'Đang đổi hướng đến [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Làm sạch vùng nhớ đệm của trang này?
@@ -2598,7 +2609,7 @@
 'version-software-product'         => 'Phần mềm',
 'version-software-version'         => 'Phiên bản',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Đường dẫn tập tin',
 'filepath-page'    => 'Tập tin:',
 'filepath-submit'  => 'Hiển thị tập tin',
@@ -2636,7 +2647,7 @@
 'specialpages-group-redirects'   => 'Đang đổi hướng trang đặc biệt',
 'specialpages-group-spam'        => 'Công cụ chống spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Trang trắng',
 'intentionallyblankpage' => 'Trang này được chủ định để trắng',
 
Index: languages/messages/MessagesSma.php
===================================================================
--- languages/messages/MessagesSma.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSma.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,11 +1,10 @@
 <?php
-/** Southern Sami (Åarjelsaemien gïele)
+/** Southern Sami (Åarjelsaemien)
  *
  * @ingroup Language
  * @file
  *
  * @author M.M.S.
- * @author Siebrand
  */
 
 $messages = array(
@@ -115,7 +114,7 @@
 'protectthispage'  => 'Vaarjelidh dïhte bielie',
 'newpage'          => 'Orre bielie',
 'talkpage'         => 'Dïjveldidh dïhte bielie',
-'talkpagelinktext' => 'Dïjveldeme',
+'talkpagelinktext' => 'Digkiedimmie',
 'specialpage'      => 'Joekoelaakan Bielie',
 'personaltools'    => 'Persjovne dïrregeh',
 'articlepage'      => 'Vuesehte artihkle bielie',
@@ -138,7 +137,7 @@
 'jumptosearch'     => 'ohtsedh',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'            => '{{SITENAME}} bïjre',
+'aboutsite'            => '{{SITENAME}}en bïjre',
 'aboutpage'            => 'Project:Bïjre',
 'bugreports'           => 'Bug reektehtse',
 'bugreportspage'       => 'Project:Bug reektehtse',
@@ -163,7 +162,7 @@
 'youhavenewmessages'  => 'Datne åtna $1 ($2).',
 'newmessageslink'     => 'orre bïjre',
 'newmessagesdifflink' => 'minngemes värrhtoedimmie',
-'editsection'         => 'sjiehtedh',
+'editsection'         => 'sjïehtedh',
 'editold'             => 'värrhtoedimmie',
 'editsectionhint'     => 'Sektiovne sjiehtedh: $1',
 'toc'                 => 'Sisvege',
@@ -297,7 +296,7 @@
 'template-protected'     => '(vaarjeleme)',
 'template-semiprotected' => '(lehkie-vaarjelidh)',
 'nocreatetext'           => '{{SITENAME}} åtna gaertjiedidh nuepieh ahte skaepede orre bielieh.
-Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:Userlogin|logge sïjse jallh skaepede nuhtjien]].',
+Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge sïjse jallh skaepede nuhtjien]].',
 
 # History pages
 'viewpagelogs'        => 'Vuesehte loggeh ihke dïhte bielie',
@@ -414,7 +413,7 @@
 
 'license' => 'Liseense',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for' => 'Ohtsedh ihke guvvie nomme:',
 'imgfile'              => 'guvvie',
 'imagelist'            => 'Guvvie lästoe',
@@ -460,7 +459,7 @@
 'statistics'    => 'Statistiike',
 'sitestats'     => '{{SITENAME}} statistiike',
 'userstats'     => 'Nuhtjien statistiike',
-'userstatstext' => "Dïhte {{PLURAL:$1|lea '''1''' registreered [[Special:Listusers|nuhtjien]]|lea '''$1''' registreered [[Special:Listusers|nuhtjienh]]}},  jih
+'userstatstext' => "Dïhte {{PLURAL:$1|lea '''1''' registreered [[Special:ListUsers|nuhtjien]]|lea '''$1''' registreered [[Special:ListUsers|nuhtjienh]]}},  jih
 '''$2''' (jallh '''$4%''') {{PLURAL:$2|åtna|åtnah}} $5 reahkta.",
 
 'disambiguations' => 'Disambirgusjovne bielieh',
@@ -520,9 +519,9 @@
 'all-logs-page'        => 'Gaajhke loggeh',
 'log-search-submit'    => 'Vaadtsa',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Gaajhke bielieh',
-'alphaindexline' => '$1 gåajkoe $2',
+'alphaindexline' => '$1 ... $2',
 'nextpage'       => 'Minngebe bielie ($1)',
 'prevpage'       => 'Övtebe bielie ($1)',
 'allpagesfrom'   => 'Vuesehte bielieh goh aelkedh meatan:',
@@ -535,7 +534,7 @@
 # Special:Categories
 'categories' => 'Karegorijeh',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Vuesehte',
 
 # E-mail user
@@ -785,7 +784,7 @@
 'show-big-image'       => 'Dïeves stoerre',
 'show-big-image-thumb' => '<small>Stoerre ihke dïhte vuesiehtidh: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Gallerije dejstie orre baalkah',
 'ilsubmit'  => 'Ohtsedh',
 
@@ -839,7 +838,7 @@
 
 # External editor support
 'edit-externally'      => 'Värrhtoedimmie dïhte baalka meatan ehksteerne applikasjovne',
-'edit-externally-help' => 'Vuajna [http://meta.wikimedia.org/wiki/Help:External_editors instalasjovne instruksjovne] ihke vielie bïevnesh.',
+'edit-externally-help' => 'Vuajna [http://www.mediawiki.org/wiki/Manual:External_editors instalasjovne instruksjovne] ihke vielie bïevnesh.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'gaajhke',
Index: languages/messages/MessagesTt_cyrl.php
===================================================================
--- languages/messages/MessagesTt_cyrl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTt_cyrl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Ерней
  * @author Himiq Dzyu
- * @author Siebrand
- * @author Jon Harald Søby
+ * @author Ерней
  */
 
 $fallback = 'ru';
@@ -289,7 +287,7 @@
 'nosuchspecialpage' => 'Андый махсус бит юк',
 'nospecialpagetext' => "<big>'''Сез сорый торган махсус бит юк.'''</big>
 
-[[Special:Specialpages|Махсус битләр исемлеге]] кара.",
+[[Special:SpecialPages|Махсус битләр исемлеге]] кара.",
 
 # General errors
 'error'                => 'Хата',
@@ -497,8 +495,6 @@
 'blockededitsource'      => "Бит «$1» '''үзгәртүегез''' тексты аска күрсәткән.",
 'whitelistedittitle'     => 'Үзгәртү өчен керү кирәк',
 'whitelistedittext'      => 'Сез битләрне үзгәртү өчен $1 тиеш.',
-'whitelistreadtitle'     => 'Уку өчен керү кирәк',
-'whitelistacctitle'      => 'Сездә хисап ясау хокукы юк',
 'nosuchsectiontitle'     => 'Андый секция юк',
 'loginreqtitle'          => 'Керү кирәк',
 'loginreqlink'           => 'керү',
@@ -512,7 +508,7 @@
 Әгәр сез бу бит ялгышлык белән ачса идегез, гади браузерыгызның '''артка''' кнопкасына басыгыз.",
 'anontalkpagetext'       => "----''Бу хисапланмаган да хисапланган исем белән кергән кулланучы фикер алышу бите.
 Аны билгеләү өчен IP-адрес файдалый.
-Әгәр сез аноним кулланучы һәм сез, сезгә күндерелмәгән хәбәрләр алдыгыз, дип саныйсыз (бер IP-адрес күп кулланучы өчен була ала), зинһар, [[Special:Userlogin|системага керегез]], киләчәктә аңлашмау теләмәсәгез.''",
+Әгәр сез аноним кулланучы һәм сез, сезгә күндерелмәгән хәбәрләр алдыгыз, дип саныйсыз (бер IP-адрес күп кулланучы өчен була ала), зинһар, [[Special:UserLogin|системага керегез]], киләчәктә аңлашмау теләмәсәгез.''",
 'noarticletext'          => "Хәзер бу биттә текст юк. Сез [[Special:Search/{{PAGENAME}}|аның башы башка мәкаләләрдә таба]] яки '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} андый баш белән бит ясый]''' аласыз.",
 'clearyourcache'         => "'''Искәрмә:''' Битне саклаудан соң төзәтмәләр күрү өчен күзәтүчегезнең кэшын буш итегез.
 '''Mozilla / Firefox''': ''Ctrl+Shift+R'', '''Safari''': ''Cmd+Shift+R'', '''IE:''' ''Ctrl+F5'', '''Konqueror''': ''F5'', '''Opera''': ''Tools→Preferences'' сайлагында.",
@@ -585,7 +581,7 @@
 'mypreferences'         => 'Көйләнмәләрем',
 'prefs-edits'           => 'Үзгәртүләр исәбе:',
 'prefsnologin'          => 'Кермәгәнсез',
-'prefsnologintext'      => 'Кулланучы көйләнмәләрене үзгәртү өчен, сез [[Special:Userlogin|керергә]] тиешсез.',
+'prefsnologintext'      => 'Кулланучы көйләнмәләрене үзгәртү өчен, сез [[Special:UserLogin|керергә]] тиешсез.',
 'qbsettings'            => 'Күчешләр аслыгы',
 'qbsettings-none'       => 'Күрсәтмәскә',
 'changepassword'        => 'Серсүзне алыштырырга',
@@ -669,7 +665,7 @@
 'uploadlogpage' => 'Йөкләү журналы',
 'uploadedimage' => '«[[$1]]» йөкләнгән',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'             => 'Сүрәтләр исемлеге',
 'imagelist_date'        => 'Вакыт',
 'imagelist_name'        => 'Ат',
@@ -764,7 +760,7 @@
 'log-search-legend'    => 'Журналларны эзләү',
 'log-search-submit'    => 'Башкару',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Барлык битләр',
 'alphaindexline' => '$1 дан $2 гача',
 'nextpage'       => 'Чираттагы бит ($1)',
@@ -781,7 +777,7 @@
 'special-categories-sort-count' => 'исәп буенча тәртипләү',
 'special-categories-sort-abc'   => 'әлифба буенча тәртипләү',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Күрсәтергә',
 'listusers-noresult' => 'Кулланучыларны табылмады.',
 
@@ -997,7 +993,7 @@
 'show-big-image'       => 'Тулы ачыклык',
 'show-big-image-thumb' => '<small>Алдан карау зурлыгы: $1 × $2 нокта</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Яңа сүрәтләр җыелмасы',
 
 # Metadata
Index: languages/messages/MessagesZh.php
===================================================================
--- languages/messages/MessagesZh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,9 +1,9 @@
 <?php
-/**
- * Chinese (中文)
+/** Chinese (中文)
  *
  * @ingroup Language
  * @file
+ *
  */
 
 # Stub message file for converter code "zh"
Index: languages/messages/MessagesCa.php
===================================================================
--- languages/messages/MessagesCa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,22 +4,20 @@
  * @ingroup Language
  * @file
  *
- * @author Toniher
- * @author SMP
- * @author Martorell
- * @author Siebrand
- * @author Pasqual (ca)
  * @author Iradigalesc
- * @author לערי ריינהארט
  * @author Jordi Roqué
  * @author Juanpabl
- * @author Spacebirdy
- * @author Vriullop
- * @author Jon Harald Søby
+ * @author Martorell
  * @author McDutchie
+ * @author Pasqual (ca)
+ * @author Paucabot
  * @author Pérez
- * @author SPQRobin
+ * @author SMP
  * @author Smeira
+ * @author Spacebirdy
+ * @author Toniher
+ * @author Vriullop
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -432,7 +430,7 @@
 'nosuchaction'      => 'No es reconeix aquesta operació',
 'nosuchactiontext'  => "El programari wiki que fa servir {{SITENAME}} no reconeix l'operació especificada per l'adreça URL",
 'nosuchspecialpage' => 'No es troba la pàgina especial que busqueu',
-'nospecialpagetext' => 'La pàgina especial que demaneu no és vàlida. Vegeu la llista de pàgines especials en [[Special:Specialpages]].',
+'nospecialpagetext' => 'La pàgina especial que demaneu no és vàlida. Vegeu la llista de pàgines especials en [[Special:SpecialPages]].',
 
 # General errors
 'error'                => 'Error',
@@ -681,10 +679,6 @@
 'blockededitsource'                => "El text de les vostres edicions a '''$1''' es mostra a continuació:",
 'whitelistedittitle'               => 'Cal iniciar una sessió per a poder editar',
 'whitelistedittext'                => 'Heu de $1 per editar pàgines.',
-'whitelistreadtitle'               => "Heu d'iniciar una sessió per a llegir-ho",
-'whitelistreadtext'                => "Heu d'[[Special:Userlogin|identificar-vos]] per a llegir les pàgines.",
-'whitelistacctitle'                => 'No teniu permisos per a crear un compte',
-'whitelistacctext'                 => "Per estar autoritzat a crear comptes al projecte {{SITENAME}} heu d'[[Special:Userlogin|identificar-vos]] i tenir els permisos apropiats.",
 'confirmedittitle'                 => "Cal una confirmació de l'adreça electrònica per a poder editar",
 'confirmedittext'                  => "Heu de confirmar la vostra adreça electrònica abans de poder editar pàgines. Definiu i valideu la vostra adreça electrònica a través de les vostres [[Special:Preferences|preferències d'usuari]].",
 'nosuchsectiontitle'               => 'No hi ha cap secció',
@@ -699,7 +693,7 @@
 Per a crear-la, comenceu a escriure en l'espai de sota
 (vegeu l'[[{{MediaWiki:Helppage}}|ajuda]] per a més informació).
 Si sou ací per error, simplement cliqueu al botó «Enrere» del vostre navegador.",
-'anontalkpagetext'                 => "----''Aquesta és la pàgina de discussió d'un usuari anònim que encara no ha creat un compte o que no fa servir el seu nom registrat. Per tant, hem de fer servir la seua adreça IP numèrica per a identificar-lo. Una adreça IP pot ser compartida per molts usuaris. Si sou un usuari anònim, i trobeu que us han adreçat comentaris inoportuns, si us plau, [[Special:Userlogin|creeu-vos un compte]] per a evitar futures confusions amb altres usuaris anònims.''",
+'anontalkpagetext'                 => "----''Aquesta és la pàgina de discussió d'un usuari anònim que encara no ha creat un compte o que no fa servir el seu nom registrat. Per tant, hem de fer servir la seua adreça IP numèrica per a identificar-lo. Una adreça IP pot ser compartida per molts usuaris. Si sou un usuari anònim, i trobeu que us han adreçat comentaris inoportuns, si us plau, [[Special:UserLogin|creeu-vos un compte]] per a evitar futures confusions amb altres usuaris anònims.''",
 'noarticletext'                    => 'En aquest moment no hi ha text en aquesta pàgina. Podeu [[Special:Search/{{PAGENAME}}|cercar-ne el títol]] en altres pàgines o [{{fullurl:{{FULLPAGENAME}}|action=edit}} començar a escriure-hi].',
 'userpage-userdoesnotexist'        => "Atenció: El compte d'usuari «$1» no està registrat. En principi no hauríeu de crear ni editar aquesta pàgina.",
 'clearyourcache'                   => "'''Nota:''' Després de desar, heu de posar al dia la memòria cau del vostre navegador per veure els canvis. '''Mozilla / Firefox / Safari:''' Premeu ''Shift'' mentre cliqueu ''Actualitza'' (Reload), o premeu ''Ctrl+F5'' o ''Ctrl+R'' (''Cmd+R'' en un Mac Apple); '''Internet Explorer:''' premeu ''Ctrl'' mentre cliqueu ''Actualitza'' (Refresh), o premeu ''Ctrl+F5''; '''Konqueror:''': simplement cliqueu el botó ''Recarregar'' (Reload), o premeu ''F5''; '''Opera''' haureu d'esborrar completament la vostra memòria cau (caché) a ''Tools→Preferences''.",
@@ -759,7 +753,7 @@
 'edittools'                        => "<!-- Es mostrarà als formularis d'edició i de càrrega el text que hi haja després d'aquesta línia. -->",
 'nocreatetitle'                    => "S'ha limitat la creació de pàgines",
 'nocreatetext'                     => "El projecte {{SITENAME}} ha restringit la possibilitat de crear noves pàgines.
-Podeu editar les planes ja existents o bé [[Special:Userlogin|entrar en un compte d'usuari]].",
+Podeu editar les planes ja existents o bé [[Special:UserLogin|entrar en un compte d'usuari]].",
 'nocreate-loggedin'                => 'No teniu permisos per a crear pàgines noves a la {{SITENAME}}.',
 'permissionserrors'                => 'Error de permisos',
 'permissionserrorstext'            => 'No teniu permisos per a fer-ho, {{PLURAL:$1|pel següent motiu|pels següents motius}}:',
@@ -877,7 +871,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Registre de supressió',
-'suppressionlogtext' => 'A continuació hi ha una llista de les eliminacions i bloquejos que impliquen un contingut amagat als administradors. Vegeu la [[Special:Ipblocklist|llista de bloquejos]] per a consultar la llista de bandejos i bloquejos actualment en curs.',
+'suppressionlogtext' => 'A continuació hi ha una llista de les eliminacions i bloquejos que impliquen un contingut amagat als administradors. Vegeu la [[Special:IPBlockList|llista de bloquejos]] per a consultar la llista de bandejos i bloquejos actualment en curs.',
 
 # History merging
 'mergehistory'                     => 'Fusiona els historials de les pàgines',
@@ -960,7 +954,7 @@
 'mypreferences'            => 'Preferències',
 'prefs-edits'              => "Nombre d'edicions:",
 'prefsnologin'             => 'No heu iniciat cap sessió',
-'prefsnologintext'         => "Heu d'haver [[Special:Userlogin|entrat]] per seleccionar preferències d'usuari.",
+'prefsnologintext'         => "Heu d'haver [[Special:UserLogin|entrat]] per seleccionar preferències d'usuari.",
 'prefsreset'               => "Les preferències han estat respostes des d'emmagatzematge.",
 'qbsettings'               => 'Preferències de "Quickbar"',
 'qbsettings-none'          => 'Cap',
@@ -1034,7 +1028,7 @@
 'userrights-reason'           => 'Motiu del canvi:',
 'userrights-no-interwiki'     => "No teniu permisos per a editar els permisos d'usuari d'altres wikis.",
 'userrights-nodatabase'       => 'La base de dades $1 no existeix o no és local.',
-'userrights-nologin'          => "Heu [[Special:Userlogin|d'iniciar una sessió]] amb un compte d'administrador per a poder assignar permisos d'usuari.",
+'userrights-nologin'          => "Heu [[Special:UserLogin|d'iniciar una sessió]] amb un compte d'administrador per a poder assignar permisos d'usuari.",
 'userrights-notallowed'       => "El vostre compte no té permisos per a assignar permisos d'usuari.",
 'userrights-changeable-col'   => 'Grups que podeu canviar',
 'userrights-unchangeable-col' => 'Grups que no podeu canviar',
@@ -1164,13 +1158,13 @@
 'reupload'                    => 'Carrega de nou',
 'reuploaddesc'                => 'Torna al formulari per apujar.',
 'uploadnologin'               => 'No heu iniciat una sessió',
-'uploadnologintext'           => "Heu d'[[Special:Userlogin|iniciar una sessió]]
+'uploadnologintext'           => "Heu d'[[Special:UserLogin|iniciar una sessió]]
 per a penjar-hi fitxers.",
 'upload_directory_missing'    => "No s'ha trobat el directori de càrrega ($1) i tampoc no ha pogut ser creat pel servidor web.",
 'upload_directory_read_only'  => 'El servidor web no pot escriure al directori de càrrega ($1)',
 'uploaderror'                 => "S'ha produït un error en l'intent de carregar",
 'uploadtext'                  => "Feu servir el formulari de sota per a carregar fitxers.
-Per a visualitzar o cercar fitxers que s'hagen carregat prèviament, aneu a la [[Special:Imagelist|llista de fitxers carregats]]. Les càrregues i les destruccions es registren en el [[Special:Log/upload|registre de càrregues]].
+Per a visualitzar o cercar fitxers que s'hagen carregat prèviament, aneu a la [[Special:ImageList|llista de fitxers carregats]]. Les càrregues i les destruccions es registren en el [[Special:Log/upload|registre de càrregues]].
 
 Per a incloure una imatge en una pàgina, feu un enllaç de la forma
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fitxer.jpg]]</nowiki>''';
@@ -1255,7 +1249,7 @@
 'upload_source_url'  => ' (un URL vàlid i accessible públicament)',
 'upload_source_file' => ' (un fitxer en el vostre ordinador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Aquesta pàgina especial mostra tots els fitxers carregats.
 Per defecte, els darrers en ser carregats apareixen al principi de la llista.
 Clicant al capdamunt de les columnes podeu canviar-ne l'ordenació.",
@@ -1283,7 +1277,7 @@
 'imagelinks'                     => 'Enllaços a la imatge',
 'linkstoimage'                   => '{{PLURAL:$1|La següent pàgina enllaça|Les següents pàgines enllacen}} a aquesta imatge:',
 'nolinkstoimage'                 => 'No hi ha pàgines que enllacin aquesta imatge.',
-'morelinkstoimage'               => 'Visualitza [[Special:Whatlinkshere/$1|més enllaços]] que porten al fitxer.',
+'morelinkstoimage'               => 'Visualitza [[Special:WhatLinksHere/$1|més enllaços]] que porten al fitxer.',
 'redirectstofile'                => '{{PLURAL:$1|El fitxer següent redirigeix cap aquest fitxer|Els següents $1 fitxers redirigeixen cap aquest fitxer:}}',
 'duplicatesoffile'               => "{{PLURAL:$1|Aquest fitxer és un duplicat de|A continuació s'indiquen els $1 duplicats d'aquest fitxer:}}",
 'sharedupload'                   => 'Aquest fitxer està compartit i poden utilitzar-lo altres projectes.',
@@ -1302,18 +1296,18 @@
 # File reversion
 'filerevert'                => 'Reverteix $1',
 'filerevert-legend'         => 'Reverteix el fitxer',
-'filerevert-intro'          => '<span class="plainlinks">Esteu revertint \'\'\'[[Media:$1|$1]]\'\'\' a la [$4 versió de  $3, $2].</span>',
+'filerevert-intro'          => "Esteu revertint '''[[Media:$1|$1]]''' a la [$4 versió de  $3, $2].",
 'filerevert-comment'        => 'Comentari:',
 'filerevert-defaultcomment' => "S'ha revertit a la versió com de $2, $1",
 'filerevert-submit'         => 'Reverteix',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ha estat revertit a la [$4 versió de $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ha estat revertit a la [$4 versió de $3, $2].",
 'filerevert-badversion'     => "No hi ha cap versió local anterior d'aquest fitxer amb la marca horària que es proporciona.",
 
 # File deletion
 'filedelete'                  => 'Suprimeix $1',
 'filedelete-legend'           => 'Suprimeix el fitxer',
 'filedelete-intro'            => "Esteu eliminant '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Esteu eliminant la versió de \'\'\'[[Media:$1|$1]]\'\'\' com de [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Esteu eliminant la versió de '''[[Media:$1|$1]]''' com de [$4 $3, $2].",
 'filedelete-comment'          => 'Comentari:',
 'filedelete-submit'           => 'Suprimeix',
 'filedelete-success'          => "'''$1''' s'ha eliminat.",
@@ -1379,9 +1373,11 @@
 Per això, caldria que enllacessin al tema apropiat.<br />
 Una pàgina es tracta com de desambiguació si utilitza una plantilla que està enllaçada a [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redireccions dobles',
-'doubleredirectstext' => '<b>Atenció:</b> aquest llistat pot contenir falsos positius. Això normalment significa que hi ha text addicional amb enllaços sota el primer #REDIRECT.<br />
+'doubleredirects'            => 'Redireccions dobles',
+'doubleredirectstext'        => '<b>Atenció:</b> aquesta llista pot contenir falsos positius. Això normalment significa que hi ha text addicional amb enllaços sota el primer #REDIRECT.<br />
 Cada fila conté enllaços a la segona i tercera redirecció, així com la primera línia de la segona redirecció, la qual cosa dóna normalment l\'article "real", al que el primer redirecció hauria d\'apuntar.',
+'double-redirect-fixed-move' => "S'ha reanomenat [[$1]], ara és una redirecció a [[$2]]",
+'double-redirect-fixer'      => 'Supressor de dobles redireccions',
 
 'brokenredirects'        => 'Redireccions rompudes',
 'brokenredirectstext'    => 'Les següents redireccions enllacen a pàgines inexistents:',
@@ -1467,7 +1463,7 @@
 'logempty'             => 'No hi ha cap coincidència en el registre.',
 'log-title-wildcard'   => 'Cerca els títols que comencin amb aquest text',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Totes les pàgines',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Pàgina següent ($1)',
@@ -1490,12 +1486,12 @@
 'special-categories-sort-count' => 'ordena per recompte',
 'special-categories-sort-abc'   => 'ordena alfabèticament',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostra usuaris començant per:',
 'listusers-submit'   => 'Mostra',
 'listusers-noresult' => "No s'han trobat coincidències de noms d'usuaris. Si us plau, busqueu també amb variacions per majúscules i minúscules.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Drets dels grups d'usuaris",
 'listgrouprights-summary'  => "A continuació hi ha una llista dels grups d'usuaris definits al wiki, així com dels seus drets d'accés associats.
 Trobareu més informació d'aquest drets individuals [[{{MediaWiki:Listgrouprights-helppage}}|aquí]].",
@@ -1506,7 +1502,7 @@
 
 # E-mail user
 'mailnologin'     => "No enviïs l'adreça",
-'mailnologintext' => "Heu d'haver [[Special:Userlogin|entrat]]
+'mailnologintext' => "Heu d'haver [[Special:UserLogin|entrat]]
 i tenir una direcció electrònica vàlida en les vostres [[Special:Preferences|preferències]]
 per enviar un correu electrònic a altres usuaris.",
 'emailuser'       => 'Envia un missatge de correu electrònic a aquest usuari',
@@ -1541,12 +1537,12 @@
 'nowatchlist'          => 'No teniu cap element en el vostre llistat de seguiment.',
 'watchlistanontext'    => 'Premeu $1 per a visualitzar o editar elements de la vostra llista de seguiment.',
 'watchnologin'         => 'No heu iniciat la sessió',
-'watchnologintext'     => "Heu d'[[Special:Userlogin|entrar]]
+'watchnologintext'     => "Heu d'[[Special:UserLogin|entrar]]
 per modificar el vostre llistat de seguiment.",
 'addedwatch'           => "S'ha afegit la pàgina a la llista de seguiment",
 'addedwatchtext'       => "S'ha afegit la pàgina «[[:$1]]» a la vostra [[Special:Watchlist|llista de seguiment]].
 
-Els canvis futurs que tinguin lloc en aquesta pàgina i la seua corresponent discussió sortiran en la vostra [[Special:Watchlist|llista de seguiment]]. A més la pàgina estarà ressaltada '''en negreta''' dins la [[Special:Recentchanges|llista de canvis recents]] perquè pugueu adonar-vos-en amb més facilitat dels canvis que tingui.
+Els canvis futurs que tinguin lloc en aquesta pàgina i la seua corresponent discussió sortiran en la vostra [[Special:Watchlist|llista de seguiment]]. A més la pàgina estarà ressaltada '''en negreta''' dins la [[Special:RecentChanges|llista de canvis recents]] perquè pugueu adonar-vos-en amb més facilitat dels canvis que tingui.
 
 Si voleu deixar de vigilar la pàgina, cliqueu sobre l'enllaç de «Desatén» de la barra lateral.",
 'removedwatch'         => "S'ha tret de la llista de seguiment",
@@ -1630,7 +1626,7 @@
 'deletedarticle'              => 'eliminat "[[$1]]"',
 'suppressedarticle'           => "s'ha suprimit «[[$1]]»",
 'dellogpage'                  => "Registre d'eliminació",
-'dellogpagetext'              => 'Davall hi ha un llistat dels esborraments més recents.',
+'dellogpagetext'              => 'Davall hi ha una llista dels esborraments més recents.',
 'deletionlog'                 => "Registre d'esborrats",
 'reverted'                    => 'Invertit amb una revisió anterior',
 'deletecomment'               => 'Motiu per a ser esborrat:',
@@ -1660,7 +1656,7 @@
 'rollback-success'            => "Edicions revertides de $1; s'ha canviat a la darrera versió de $2.",
 'sessionfailure'              => 'Sembla que hi ha problema amb la vostra sessió; aquesta acció ha estat anulada en prevenció de pirateig de sessió. Si us plau, pitgueu "Torna", i recarregueu la pàgina des d\'on veniu, aleshores intenteu-lo de nou.',
 'protectlogpage'              => 'Registre de protecció',
-'protectlogtext'              => 'Aquest és el registre de proteccions i desproteccions. Vegeu la [[Special:Protectedpages|llista de pàgines protegides]] per a la llista de les pàgines que actualment tenen alguna protecció.',
+'protectlogtext'              => 'Aquest és el registre de proteccions i desproteccions. Vegeu la [[Special:ProtectedPages|llista de pàgines protegides]] per a la llista de les pàgines que actualment tenen alguna protecció.',
 'protectedarticle'            => 'protegit «[[$1]]»',
 'modifiedarticleprotection'   => "s'ha canviat el nivell de protecció «[[$1]]»",
 'unprotectedarticle'          => '«[[$1]]» desprotegida',
@@ -1831,7 +1827,7 @@
 'badipaddress'                    => "L'adreça IP no té el format correcte.",
 'blockipsuccesssub'               => "S'ha blocat amb èxit",
 'blockipsuccesstext'              => 'L\'usuari "[[Special:Contributions/$1|$1]]" ha estat blocat.
-<br />Vegeu la [[Special:Ipblocklist|llista d\'IP blocades]] per revisar els bloquejos.',
+<br />Vegeu la [[Special:IPBlockList|llista d\'IP blocades]] per revisar els bloquejos.',
 'ipb-edit-dropdown'               => 'Edita les raons per a blocar',
 'ipb-unblock-addr'                => 'Desbloca $1',
 'ipb-unblock'                     => 'Desbloca un usuari o una adreça IP',
@@ -1862,7 +1858,7 @@
 'autoblocker'                     => 'Heu estat blocat perquè compartiu adreça IP amb «$1». Motiu: «$2»',
 'blocklogpage'                    => 'Registre de bloquejos',
 'blocklogentry'                   => "s'ha blocat «[[$1]]» per a un període de $2 $3",
-'blocklogtext'                    => "Això és una relació de accions de bloqueig i desbloqueig. Les adreces IP bloquejades automàticament no apareixen. Vegeu la [[Special:Ipblocklist|llista d'usuaris actualment bloquejats]].",
+'blocklogtext'                    => "Això és una relació de accions de bloqueig i desbloqueig. Les adreces IP bloquejades automàticament no apareixen. Vegeu la [[Special:IPBlockList|llista d'usuaris actualment bloquejats]].",
 'unblocklogentry'                 => 'desbloquejat $1',
 'block-log-flags-anononly'        => 'només els usuaris anònims',
 'block-log-flags-nocreate'        => "s'ha desactivat la creació de comptes",
@@ -1888,7 +1884,7 @@
 'lockdb'              => 'Bloca la base de dades',
 'unlockdb'            => 'Desbloca la base de dades',
 'lockdbtext'          => "Blocant la base de dades s'anul·larà la capacitat de tots els
-usuaris d'editar pàgines, canviar les preferències, editar els llistats de seguiments, i
+usuaris d'editar pàgines, canviar les preferències, editar la llista de seguiment, i
 altres canvis que requereixen canvis en la base de dades.
 Confirmeu que això és el que intenteu fer, i sobretot no us oblideu
 de desblocar la base de dades quan acabeu el manteniment.",
@@ -1904,7 +1900,7 @@
 'lockdbsuccesssub'    => "S'ha bloquejat la base de dades",
 'unlockdbsuccesssub'  => "S'ha eliminat el bloqueig de la base de dades",
 'lockdbsuccesstext'   => "S'ha bloquejat la base de dades.<br />
-Recordeu-vos de [[Special:Unlockdb|treure el bloqueig]] quan hàgiu acabat el manteniment.",
+Recordeu-vos de [[Special:UnlockDB|treure el bloqueig]] quan hàgiu acabat el manteniment.",
 'unlockdbsuccesstext' => "S'ha desbloquejat la base de dades del projecte {{SITENAME}}.",
 'lockfilenotwritable' => 'No es pot modificar el fitxer de la base de dades de bloquejos. Per a blocar o desblocar la base de dades, heu de donar-ne permís de modificació al servidor web.',
 'databasenotlocked'   => 'La base de dades no està bloquejada.',
@@ -1930,9 +1926,6 @@
 
 En aquests casos, haureu de traslladar o fusionar la pàgina manualment si ho desitgeu.",
 'movearticle'             => 'Reanomena la pàgina',
-'movenologin'             => "No sou a dins d'una sessió",
-'movenologintext'         => "Heu de ser un usuari registrat i estar [[Special:Userlogin|dintre d'una sessió]]
-per reanomenar una pàgina.",
 'movenotallowed'          => 'No teniu permís per a moure pàgines al projecte {{SITENAME}}.',
 'newtitle'                => 'A títol nou',
 'move-watch'              => 'Vigila aquesta pàgina',
@@ -1962,7 +1955,7 @@
 'delete_and_move'         => 'Elimina i trasllada',
 'delete_and_move_text'    => "==Cal l'eliminació==
 
-La pàgina de destinació, «[[$1]]», ja existeix. Voleu eliminar-la per a fer lloc al trasllat?",
+La pàgina de destinació, «[[:$1]]», ja existeix. Voleu eliminar-la per a fer lloc al trasllat?",
 'delete_and_move_confirm' => 'Sí, esborra la pàgina',
 'delete_and_move_reason'  => "S'ha eliminat per a permetre el reanomenament",
 'selfmove'                => "Els títols d'origen i de destinació coincideixen: no és possible de reanomenar una pàgina a si mateixa.",
@@ -1970,6 +1963,7 @@
 'imagenocrossnamespace'   => 'No es pot moure la imatge a un espai de noms on no li correspon',
 'imagetypemismatch'       => 'La nova extensió de fitxer no coincideix amb el seu tipus',
 'imageinvalidfilename'    => 'El nom de fitxer indicat no és vàlid',
+'fix-double-redirects'    => "Actualitza també redireccions que apuntin a l'article original",
 
 # Export
 'export'            => 'Exporta les pàgines',
@@ -2164,9 +2158,10 @@
 'markedaspatrollederror-noautopatrol' => 'No podeu marcar les vostres pròpies modificacions com a supervisades.',
 
 # Patrol log
-'patrol-log-page' => 'Registre de supervisió',
-'patrol-log-line' => "s'ha marcat la versió $1 de $2 com a supervisat $3",
-'patrol-log-auto' => '(automàtic)',
+'patrol-log-page'   => 'Registre de supervisió',
+'patrol-log-header' => 'Això és un registre de les revisions patrullades.',
+'patrol-log-line'   => "s'ha marcat la versió $1 de $2 com a supervisat $3",
+'patrol-log-auto'   => '(automàtic)',
 
 # Image deletion
 'deletedrevision'                 => "S'ha eliminat la revisió antiga $1.",
@@ -2195,16 +2190,19 @@
 'show-big-image'       => 'Imatge en màxima resolució',
 'show-big-image-thumb' => "<small>Mida d'aquesta previsualització: $1 × $2 píxels</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria de nous fitxers',
 'imagelisttext'         => "Llista {{PLURAL:$1|d'un sol fitxer|de '''$1''' fitxers ordenats $2}}.",
-'newimages-summary'     => 'Aquesta pàgina especial mostra els darrers fitxers carregats',
+'newimages-summary'     => 'Aquesta pàgina especial mostra els darrers fitxers carregats.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Res per veure.',
 'ilsubmit'              => 'Cerca',
 'bydate'                => 'per data',
 'sp-newimages-showfrom' => 'Mostra fitxers nous des del $1 a les $2',
 
+# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
+'minutes-abbrev' => 'min',
+
 # Bad image list
 'bad_image_list' => "El format ha de ser el següent:
 
@@ -2480,7 +2478,7 @@
 
 # External editor support
 'edit-externally'      => 'Edita aquest fitxer fent servir una aplicació externa',
-'edit-externally-help' => 'Vegeu les [http://meta.wikimedia.org/wiki/Help:External_editors instruccions de configuració] per a més informació.',
+'edit-externally-help' => 'Vegeu les [http://www.mediawiki.org/wiki/Manual:External_editors instruccions de configuració] per a més informació.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tots',
@@ -2554,7 +2552,7 @@
 'recreate'            => 'Torna a crear',
 
 # HTML dump
-'redirectingto' => "S'està redirigint a [[$1]]...",
+'redirectingto' => "S'està redirigint a [[:$1]]...",
 
 # action=purge
 'confirm_purge'        => "Voleu buidar la memòria cau d'aquesta pàgina?
@@ -2601,8 +2599,8 @@
 Proveu-ho amb la previsualització normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Els canvis més nous de $1 segons podrien no mostrar-se a la llista.',
-'lag-warn-high'   => 'A causa de la lenta resposta del servidor de base de dades, els canvis més nous de $1 segons potser no es mostren aquesta llista.',
+'lag-warn-normal' => 'Els canvis més nous de $1 {{PLURAL:$1|segon|segons}} podrien no mostrar-se a la llista.',
+'lag-warn-high'   => 'A causa de la lenta resposta del servidor de base de dades, els canvis més nous de $1 {{PLURAL:$1|segon|segons}} potser no es mostren aquesta llista.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'La vostra llista de seguiment conté {{PLURAL:$1|1 títol|$1 títols}}, excloent-ne les pàgines de discussió.',
@@ -2652,7 +2650,7 @@
 'version-software-product'         => 'Producte',
 'version-software-version'         => 'Versió',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Camí del fitxer',
 'filepath-page'    => 'Fitxer:',
 'filepath-submit'  => 'Camí',
@@ -2691,7 +2689,7 @@
 'specialpages-group-redirects'   => 'Pàgines especials de redirecció',
 'specialpages-group-spam'        => 'Eines de spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pàgina en blanc',
 'intentionallyblankpage' => 'Pàgina intencionadament en blanc',
 
Index: languages/messages/MessagesCe.php
===================================================================
--- languages/messages/MessagesCe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
+ * @author Chechenka
  * @author Girdi
  * @author Mega programmer
- * @author Chechenka
  */
 
 $fallback = 'ru';
@@ -202,7 +200,7 @@
 'upload'   => 'Чуоза Файл',
 'filename' => 'файл цIе',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Файли цІе',
 'imagelist_user' => 'юзер',
 
@@ -221,7 +219,7 @@
 # Special:Log
 'specialloguserlabel' => 'Юзер:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Массо таптараш',
 'allarticles'    => 'Массо таптараш',
 'allpagessubmit' => 'кхочушде',
@@ -285,7 +283,7 @@
 # Media information
 'show-big-image' => 'Доккха де сурт',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Керла файлаш галерей',
 
 'exif-scenetype-1' => 'Сурт сфотографировано напрямую',
Index: languages/messages/MessagesWar.php
===================================================================
--- languages/messages/MessagesWar.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesWar.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Harvzsf
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -201,7 +199,7 @@
 'upload'    => 'Pagkarga hin file',
 'uploadbtn' => 'Igkarga an file',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_date' => 'Pitsa',
 'imagelist_name' => 'Ngaran',
 
@@ -233,7 +231,7 @@
 # Special:Log
 'log-search-submit' => 'Kadto-a',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Ngatanan nga mga pakli',
 'allarticles'    => 'Ngatanan nga mga artikulo',
 'allpagesprev'   => 'Naha-una',
@@ -262,7 +260,7 @@
 # Block/unblock
 'ipblocklist-submit' => 'Bilnga',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Bilnga',
 
 # Multipage image navigation
Index: languages/messages/MessagesGd.php
===================================================================
--- languages/messages/MessagesGd.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGd.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
- * @author לערי ריינהארט
- * @author Sionnach
  * @author Raymond
+ * @author Sionnach
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -131,29 +129,28 @@
 'headline_tip'    => 'Ceann-loidhne ìre 2',
 
 # Edit pages
-'summary'           => 'Geàrr-chùnntas',
-'subject'           => 'Cuspair/ceann-loidhne',
-'minoredit'         => 'Seo mùthadh beag',
-'watchthis'         => 'Cùm sùil air an aithris seo',
-'savearticle'       => 'Sàbhail duilleag',
-'preview'           => 'Roi-shealladh',
-'showpreview'       => 'Nochd roi-shealladh',
-'showdiff'          => 'Seall atharrachaidhean',
-'blockedtitle'      => 'Tha an cleachdair air a bhacadh',
-'whitelistacctitle' => 'Chan eil cead agaibh cùnntas a chruthachadh',
-'accmailtitle'      => 'Facal-faire air a chur.',
-'accmailtext'       => "Tha am facal-faire aig '$1' air a chur ri $2.",
-'newarticle'        => '(Ùr)',
-'noarticletext'     => '(Chan eil teacsa anns an duilleig seo a-nis)',
-'updated'           => '(Nua-dheasaichte)',
-'previewnote'       => '<strong>Cuimhnichibh nach e ach roi-shealladh a tha seo, agus chan eil e air a shàbhaladh fhathast!</strong>',
-'editing'           => "A'deasaicheadh $1",
-'editconflict'      => 'Mì-chòrdadh deasachaidh: $1',
-'explainconflict'   => "Tha cuideigin eile air an duilleig seo a mhùthadh o'n thòisich sibh fhèin a dheasaicheadh. Tha am bocsa teacsa shuas a'nochdadh na duilleig mar a tha e an dràsda. Tha na mùthaidhean agaibhse anns a'bhocsa shios. Feumaidh sibh na mùthaidhean agaibh a choimeasgachadh leis an teacsa làithreach. Cha tèid <b>ach an teacsa shuas</b> a shàbhaladh an uair a bhriogas sibh \"Sàbhail duilleag\".<p>",
-'yourtext'          => 'An teacsa agaibh',
-'storedversion'     => 'Lethbhreac taisgte',
-'editingold'        => "<strong>RABHADH: Tha sibh a'deasaicheadh lethbhreac sean-aimsireil na duilleig seo. Ma shàbhalas sibh e, bithidh uile na mùthaidhean dèanta as dèidh an lethbhreac seo air chall.</strong>",
-'yourdiff'          => 'Caochlaidhean',
+'summary'         => 'Geàrr-chùnntas',
+'subject'         => 'Cuspair/ceann-loidhne',
+'minoredit'       => 'Seo mùthadh beag',
+'watchthis'       => 'Cùm sùil air an aithris seo',
+'savearticle'     => 'Sàbhail duilleag',
+'preview'         => 'Roi-shealladh',
+'showpreview'     => 'Nochd roi-shealladh',
+'showdiff'        => 'Seall atharrachaidhean',
+'blockedtitle'    => 'Tha an cleachdair air a bhacadh',
+'accmailtitle'    => 'Facal-faire air a chur.',
+'accmailtext'     => "Tha am facal-faire aig '$1' air a chur ri $2.",
+'newarticle'      => '(Ùr)',
+'noarticletext'   => '(Chan eil teacsa anns an duilleig seo a-nis)',
+'updated'         => '(Nua-dheasaichte)',
+'previewnote'     => '<strong>Cuimhnichibh nach e ach roi-shealladh a tha seo, agus chan eil e air a shàbhaladh fhathast!</strong>',
+'editing'         => "A'deasaicheadh $1",
+'editconflict'    => 'Mì-chòrdadh deasachaidh: $1',
+'explainconflict' => "Tha cuideigin eile air an duilleig seo a mhùthadh o'n thòisich sibh fhèin a dheasaicheadh. Tha am bocsa teacsa shuas a'nochdadh na duilleig mar a tha e an dràsda. Tha na mùthaidhean agaibhse anns a'bhocsa shios. Feumaidh sibh na mùthaidhean agaibh a choimeasgachadh leis an teacsa làithreach. Cha tèid <b>ach an teacsa shuas</b> a shàbhaladh an uair a bhriogas sibh \"Sàbhail duilleag\".<p>",
+'yourtext'        => 'An teacsa agaibh',
+'storedversion'   => 'Lethbhreac taisgte',
+'editingold'      => "<strong>RABHADH: Tha sibh a'deasaicheadh lethbhreac sean-aimsireil na duilleig seo. Ma shàbhalas sibh e, bithidh uile na mùthaidhean dèanta as dèidh an lethbhreac seo air chall.</strong>",
+'yourdiff'        => 'Caochlaidhean',
 
 # History pages
 'nohistory'  => 'Chan eil eachdraidh deasachaidh aig an duilleig seo.',
@@ -222,7 +219,7 @@
 'fileexists'    => 'Tha faidhle leis an ainm seo ann cheana; nach faigh sibh cinnt air <strong><tt>$1</tt></strong> gu bheil sibh ag iarraidh atharrachadh.',
 'savefile'      => 'Sàbhail faidhle',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Liosta nan ìomhaigh',
 
 # Random page
@@ -254,7 +251,7 @@
 'move'                    => 'Gluais',
 'movethispage'            => 'Caraich an duilleag seo',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Duilleagan uile',
 'nextpage' => 'An ath dhuilleag ($1)',
 
@@ -273,7 +270,7 @@
 'watchlist'          => 'Mo fhaire',
 'nowatchlist'        => 'Chan eil altan air ur faire.',
 'addedwatch'         => 'Cuirte ri coimheadlìosta',
-'addedwatchtext'     => "Tha an duilleag \"[[:\$1]]\" cuirte ri [[Special:Watchlist|ur faire]] agaibh.  Ri teachd, bith chuir an àireamh an-sin mùthadhan na duilleag sin agus a'dhuilleag \"Talk\", agus bith a'dhuilleag '''tromte''' anns an [[Special:Recentchanges|lìosta nan mùthadhan ùra]] a dh'fhurasdaich i a sheall.
+'addedwatchtext'     => "Tha an duilleag \"[[:\$1]]\" cuirte ri [[Special:Watchlist|ur faire]] agaibh.  Ri teachd, bith chuir an àireamh an-sin mùthadhan na duilleag sin agus a'dhuilleag \"Talk\", agus bith a'dhuilleag '''tromte''' anns an [[Special:RecentChanges|lìosta nan mùthadhan ùra]] a dh'fhurasdaich i a sheall.
 
 Ma bu toil leibh a dhubh a'dhuilleag as ur faire agaibh nas fadalache, cnap air \"Caisg a' coimhead\" air an taobh-colbh.",
 'watchthispage'      => 'Cùm sùil air an dhuilleag seo',
@@ -320,7 +317,7 @@
 'badipaddress'       => "Chan eil an seòladh IP aig a'cleachdair seo iomchaidh",
 'blockipsuccesssub'  => 'Shoirbhich bacadh',
 'blockipsuccesstext' => "Tha [[Special:Contributions/$1|$1]] air a bhacadh.
-<br />Faic [[Special:Ipblocklist|Liosta nan IP baicte]] na bacaidhean a dh'ath-sgrùdadh.",
+<br />Faic [[Special:IPBlockList|Liosta nan IP baicte]] na bacaidhean a dh'ath-sgrùdadh.",
 'unblockip'          => 'Neo-bhac cleachdair',
 'ipusubmit'          => 'Neo-bhac an seòladh seo',
 'ipblocklist'        => 'Liosta seòlaidhean IP agus ainmean-cleachdair air am bacadh',
@@ -371,7 +368,7 @@
 'infosubtitle' => 'Fiosrachadh air duilleig',
 'numwatchers'  => 'Aireamh luchd-faire: $1',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Rannsaich',
 'bydate'   => 'air ceann-latha',
 
Index: languages/messages/MessagesRuq_cyrl.php
===================================================================
--- languages/messages/MessagesRuq_cyrl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRuq_cyrl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Макѕе
  * @author Кумулај Маркус
+ * @author Макѕе
  * @author Приетен тев
- * @author Siebrand
  */
 
 $fallback = 'mk';
@@ -242,7 +241,7 @@
 # Book sources
 'booksources' => 'Сурсе де цајрћи',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Тоатс пажи',
 'alphaindexline' => '$1 во $2',
 'allarticles'    => 'Тоат пажи',
Index: languages/messages/MessagesNov.php
===================================================================
--- languages/messages/MessagesNov.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNov.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Malafaya
- * @author SPQRobin
  * @author nov.wikipedia.org sysops
  */
 
@@ -212,7 +211,7 @@
 'preferences'       => 'Preferos',
 'mypreferences'     => 'Men preferos',
 'prefsnologin'      => 'Non ensignatat',
-'prefsnologintext'  => 'Vu mus es [[Special:Userlogin|ensignatat]] por determina useren preferos.',
+'prefsnologintext'  => 'Vu mus es [[Special:UserLogin|ensignatat]] por determina useren preferos.',
 'prefs-rc'          => 'Resenti chanjos',
 'searchresultshead' => 'Sercha',
 
@@ -237,7 +236,7 @@
 'fileuploadsummary' => 'Resume:',
 'watchthisupload'   => 'Observa disi pagine',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Sercha imaje nome:',
 'imagelist_name'        => 'Nome',
 'imagelist_user'        => 'Usere',
@@ -283,7 +282,7 @@
 # Special:Log
 'specialloguserlabel' => 'Usere:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Omni pagines',
 'alphaindexline'    => '$1 a $2',
 'allarticles'       => 'Omni artikles',
@@ -304,7 +303,7 @@
 'watchnologin'    => 'Non ensignatat',
 'addedwatch'      => 'Adit a observa-liste',
 'addedwatchtext'  => "Li pagine \"[[:\$1]]\" ha bli adi a vun [[Special:Watchlist|observa-liste]].
-Futuri chanjos a disi pagine e lun asosiati Parla-pagine sal bli lista tilok, e li pagine sal apari '''diki''' in li [[Special:Recentchanges|liste de resenti chanjos]] por ke on trova lu plu fasilim.
+Futuri chanjos a disi pagine e lun asosiati Parla-pagine sal bli lista tilok, e li pagine sal apari '''diki''' in li [[Special:RecentChanges|liste de resenti chanjos]] por ke on trova lu plu fasilim.
 
 Si vu voli plu tardim ekarta li pagine fro vun observa-liste, klikta \"Desobserva\" in li lateral kolumne.",
 'watch'           => 'Observa',
@@ -351,7 +350,6 @@
 
 # Move page
 'movearticle'             => 'Mova pagine',
-'movenologin'             => 'Non ensignatat',
 'move-watch'              => 'Observa disi pagine',
 'movedto'                 => 'movat a',
 '1movedto2'               => '[[$1]] movat a [[$2]]',
@@ -377,7 +375,7 @@
 # Info page
 'infosubtitle' => 'Informatione pri pagine',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Sercha',
 'bydate'   => 'segun date',
 
Index: languages/messages/MessagesGl.php
===================================================================
--- languages/messages/MessagesGl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,14 +5,11 @@
  * @file
  *
  * @author Alma
- * @author Toliño
+ * @author Lameiro
  * @author Prevert
+ * @author Toliño
  * @author Xosé
- * @author Siebrand
- * @author Lameiro
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -314,7 +311,7 @@
 'nosuchspecialpage' => 'Non existe esa páxina especial',
 'nospecialpagetext' => "<big>'''Pediu unha páxina especial que non está recoñecida polo wiki.'''</big>
 
-Pode atopar unha listaxe coas páxinas especiais válidas en [[Special:Specialpages]].",
+Pode atopar unha listaxe coas páxinas especiais válidas en [[Special:SpecialPages]].",
 
 # General errors
 'error'                => 'Erro',
@@ -570,10 +567,6 @@
 'blockededitsource'                => "O texto das '''súas edicións''' en '''$1''' móstrase a continuación:",
 'whitelistedittitle'               => 'Cómpre rexistrarse para poder editar',
 'whitelistedittext'                => 'Ten que $1 para poder editar páxinas.',
-'whitelistreadtitle'               => 'Cómpre rexistrarse para poder ler',
-'whitelistreadtext'                => 'Tense que [[Special:Userlogin|rexistrar]] para poder ler artigos.',
-'whitelistacctitle'                => 'Non se lle permite crear unha conta',
-'whitelistacctext'                 => 'Para que se lle permita crear contas en {{SITENAME}} cómpre [[Special:Userlogin|rexistrarse]] e contar cos permisos apropiados.',
 'confirmedittitle'                 => 'Requírese confirmar o enderezo electrónico para editar',
 'confirmedittext'                  => 'Debe confirmar o enderezo electrónico antes de comezar a editar. Por favor configure e valide o enderezo electrónico mediante as [[Special:Preferences|preferencias de usuario]].',
 'nosuchsectiontitle'               => 'Non existe tal sección',
@@ -587,7 +580,7 @@
 'newarticletext'                   => "Seguiu unha ligazón a unha páxina que aínda non existe.
 Para crear a páxina, comece a escribir na caixa de embaixo (vexa a [[{{MediaWiki:Helppage}}|páxina de axuda]] para máis información).
 Se chegou aquí por erro, simplemente prema no botón '''atrás''' do seu navegador.",
-'anontalkpagetext'                 => "---- ''Esta é a páxina de conversa dun usuario anónimo que aínda non creou unha conta ou que non a usa. Polo tanto, empregamos o enderezo IP para a súa identificación. Este enderezo IP pódeno compartir varios usuarios distintos. Se vostede pensa que foron dirixidos contra a súa persoa comentarios inadecuados, por favor [[Special:Userlogin|cree unha conta]] para evitar futuras confusións con outros usuarios anónimos.''",
+'anontalkpagetext'                 => "---- ''Esta é a páxina de conversa dun usuario anónimo que aínda non creou unha conta ou que non a usa. Polo tanto, empregamos o enderezo IP para a súa identificación. Este enderezo IP pódeno compartir varios usuarios distintos. Se vostede pensa que foron dirixidos contra a súa persoa comentarios inadecuados, por favor [[Special:UserLogin|cree unha conta]] para evitar futuras confusións con outros usuarios anónimos.''",
 'noarticletext'                    => 'Actualmente non existe texto nesta páxina. Pode [[Special:Search/{{PAGENAME}}|procurar polo título desta páxina]] noutras páxinas ou [{{fullurl:{{FULLPAGENAME}}|action=edit}} editala].',
 'userpage-userdoesnotexist'        => 'A conta do usuario "$1" non está rexistrada. Comprobe se desexa crear/editar esta páxina.',
 'clearyourcache'                   => "'''Nota: despois de gravar cómpre limpar a memoria caché do seu navegador para ver os cambios.''' '''Mozilla / Firefox / Safari:''' prema ''Maiúsculas'' á vez que en ''Recargar'', ou prema en ''Ctrl-F5'' ou ''Ctrl-R'' (''Command-R'' nos Macintosh); '''Konqueror: '''faga clic en ''Recargar'' ou prema en ''F5''; '''Opera:''' limpe a súa memoria caché en ''Ferramentas → Preferencias''; '''Internet Explorer:''' prema ''Ctrl'' ao tempo que fai clic en ''Refrescar'', ou prema ''Ctrl-F5''.",
@@ -652,7 +645,7 @@
 'edittools'                        => '<!-- O texto que apareza aquí mostrarase por debaixo dos formularios de edición e envío. -->',
 'nocreatetitle'                    => 'Limitada a creación de páxinas',
 'nocreatetext'                     => '{{SITENAME}} ten restrinxida a posibilidade de crear páxinas novas.
-Pode volver atrás e editar unha páxina que xa existe ou, se non, [[Special:Userlogin|rexistrarse ou crear unha conta de acceso]].',
+Pode volver atrás e editar unha páxina que xa existe ou, se non, [[Special:UserLogin|rexistrarse ou crear unha conta de acceso]].',
 'nocreate-loggedin'                => 'Non dispón de permiso para crear páxinas novas en {{SITENAME}}.',
 'permissionserrors'                => 'Erros de permisos',
 'permissionserrorstext'            => 'Non dispón de permiso para facelo por {{PLURAL:$1|esta razón|estas razóns}}:',
@@ -774,7 +767,7 @@
 # Suppression log
 'suppressionlog'     => 'Rexistro de supresión',
 'suppressionlogtext' => 'Embaixo amósase unha listaxe coas eliminacións e cos bloqueos recentes, que inclúen contido oculto dos administradores.
-Vexa a [[Special:Ipblocklist|listaxe de enderezos IP bloqueados]] para comprobar as prohibicións e os bloqueos vixentes.',
+Vexa a [[Special:IPBlockList|listaxe de enderezos IP bloqueados]] para comprobar as prohibicións e os bloqueos vixentes.',
 
 # History merging
 'mergehistory'                     => 'Fusionar historiais das páxinas',
@@ -859,7 +852,7 @@
 'mypreferences'            => 'As miñas preferencias',
 'prefs-edits'              => 'Número de edicións:',
 'prefsnologin'             => 'Non está dentro do sistema',
-'prefsnologintext'         => 'Debe estar [[Special:Userlogin|dentro do sistema]] para modificar as preferencias de usuario.',
+'prefsnologintext'         => 'Debe estar [[Special:UserLogin|dentro do sistema]] para modificar as preferencias de usuario.',
 'prefsreset'               => 'As preferencias foron postas cos valores orixinais.',
 'qbsettings'               => 'Opcións da barra rápida',
 'qbsettings-none'          => 'Ningunha',
@@ -933,7 +926,7 @@
 'userrights-reason'           => 'Razón para a modificación:',
 'userrights-no-interwiki'     => 'Non dispón de permiso para editar dereitos de usuarios noutros wikis.',
 'userrights-nodatabase'       => 'A base de datos $1 non existe ou non é local.',
-'userrights-nologin'          => 'Ten que [[Special:Userlogin|rexistrarse]] cunta conta de administrador para asignar dereitos de usuario.',
+'userrights-nologin'          => 'Ten que [[Special:UserLogin|rexistrarse]] cunta conta de administrador para asignar dereitos de usuario.',
 'userrights-notallowed'       => 'A súa conta non dispón de permiso para asignar dereitos de usuario.',
 'userrights-changeable-col'   => 'Os grupos que pode cambiar',
 'userrights-unchangeable-col' => 'Os grupos que non pode cambiar',
@@ -1063,12 +1056,12 @@
 'reupload'                    => 'Volver cargar',
 'reuploaddesc'                => 'Cancelar a carga e voltar ao formulario de carga',
 'uploadnologin'               => 'Non está dentro do sistema',
-'uploadnologintext'           => 'Ha de [[Special:Userlogin|entrar no sistema]] para poder subir ficheiros.',
+'uploadnologintext'           => 'Ha de [[Special:UserLogin|entrar no sistema]] para poder subir ficheiros.',
 'upload_directory_missing'    => 'Falta o directorio de carga ($1) e non pode ser creado polo servidor da páxina web.',
 'upload_directory_read_only'  => 'Non se pode escribir no directorio de subida ($1) do servidor web.',
 'uploaderror'                 => 'Erro ao cargar',
 'uploadtext'                  => "Use o formulario de embaixo para enviar ficheiros.
-Para ver ou procurar imaxes enviadas con anterioridade vaia á [[Special:Imagelist|listaxe de ficheiros enviados]]; os envíos e as eliminacións tamén se rexistran no [[Special:Log/upload|rexistro de carga]].
+Para ver ou procurar imaxes enviadas con anterioridade vaia á [[Special:ImageList|listaxe de ficheiros enviados]]; os envíos e as eliminacións tamén se rexistran no [[Special:Log/upload|rexistro de carga]].
 
 Para incluír un ficheiro na páxina, use unha ligazón do seguinte xeito:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Ficheiro.jpg]]</nowiki>''',
@@ -1171,7 +1164,7 @@
 'upload_source_url'  => ' (un URL válido, accesíbel publicamente)',
 'upload_source_file' => ' (un ficheiro no seu ordenador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Esta páxina especial amosa todos os ficheiros cargados.
 Por omisión, os ficheiros enviados máis recentemente aparecen no alto da listaxe.
 Premendo nunha cabeceira da columna cambia a ordenación.',
@@ -1199,7 +1192,7 @@
 'imagelinks'                     => 'Ligazóns da imaxe',
 'linkstoimage'                   => '{{PLURAL:$1|A seguinte páxina liga|As seguintes $1 páxinas ligan}} con esta imaxe:',
 'nolinkstoimage'                 => 'Ningunha páxina liga con este ficheiro.',
-'morelinkstoimage'               => 'Ver [[Special:Whatlinkshere/$1|máis ligazóns]] cara a este ficheiro.',
+'morelinkstoimage'               => 'Ver [[Special:WhatLinksHere/$1|máis ligazóns]] cara a este ficheiro.',
 'redirectstofile'                => '{{PLURAL:$1|O seguinte ficheiro redirixe|Os seguintes $1 ficheiros redirixen}} cara a este:',
 'duplicatesoffile'               => '{{PLURAL:$1|O seguinte ficheiro é un duplicado|Os seguintes $1 ficheiros son duplicados}} destoutro:',
 'sharedupload'                   => 'Este ficheiro é un envío compartido e pode ser usado por outros proxectos.',
@@ -1218,18 +1211,18 @@
 # File reversion
 'filerevert'                => 'Desfacer $1',
 'filerevert-legend'         => 'Reverter ficheiro',
-'filerevert-intro'          => '<span class="plainlinks">Vai volver \'\'\'[[Media:$1|$1]]\'\'\' á [$4 versión de $3, $2].</span>',
+'filerevert-intro'          => "Vai volver '''[[Media:$1|$1]]''' á [$4 versión de $3, $2].",
 'filerevert-comment'        => 'Comentario:',
 'filerevert-defaultcomment' => 'Volveuse á versión de $2, $1',
 'filerevert-submit'         => 'Reverter',
-'filerevert-success'        => '<span class="plainlinks">Reverteuse \'\'\'[[Media:$1|$1]]\'\'\' á [$4 versión de $3, $2].</span>',
+'filerevert-success'        => "Reverteuse '''[[Media:$1|$1]]''' á [$4 versión de $3, $2].",
 'filerevert-badversion'     => 'Non existe unha versión local anterior deste ficheiro coa data e hora indicadas.',
 
 # File deletion
 'filedelete'                  => 'Eliminar $1',
 'filedelete-legend'           => 'Eliminar o ficheiro',
 'filedelete-intro'            => "Vai eliminar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Vai eliminar a versión de \'\'\'[[Media:$1|$1]]\'\'\' de [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Vai eliminar a versión de '''[[Media:$1|$1]]''' de [$4 $3, $2].",
 'filedelete-comment'          => 'Comentario:',
 'filedelete-submit'           => 'Eliminar',
 'filedelete-success'          => "Eliminouse '''$1'''.",
@@ -1285,7 +1278,7 @@
 Isto resulta nunha media de '''\$5''' edicións por páxina e '''\$6''' visionados por edición.
 
 A lonxitude da [http://www.mediawiki.org/wiki/Manual:Job_queue cola de traballos] é de '''\$7'''.",
-'userstatstext'          => "Hai {{PLURAL:$1|'''1''' [[Special:Listusers|usuario]] rexistrado|'''$1''' [[Special:Listusers|usuarios]] rexistrados}}, dos cales '''$2''' (ou '''$4%''') {{PLURAL:$2|ten|teñen}} dereitos de $5.",
+'userstatstext'          => "Hai {{PLURAL:$1|'''1''' [[Special:ListUsers|usuario]] rexistrado|'''$1''' [[Special:ListUsers|usuarios]] rexistrados}}, dos cales '''$2''' (ou '''$4%''') {{PLURAL:$2|ten|teñen}} dereitos de $5.",
 'statistics-mostpopular' => 'Páxinas máis vistas',
 
 'disambiguations'      => 'Páxinas de homónimos',
@@ -1294,8 +1287,10 @@
 No canto de ligar cos homónimos deben apuntar cara á páxina apropiada.<br />
 Unha páxina trátase como páxina de homónimos cando nela se usa un modelo que está ligado desde a [[MediaWiki:Disambiguationspage|páxina de homónimos]].",
 
-'doubleredirects'     => 'Redireccións dobres',
-'doubleredirectstext' => 'Esta páxina contén as páxinas que redirixen cara a outras páxinas de redirección. Cada ringleira contén ligazóns cara á primeira e segunda redireccións, e tamén á primeira liña da segunda redirección, que é usualmente o artigo "real", á que a primeira redirección debería apuntar.',
+'doubleredirects'            => 'Redireccións dobres',
+'doubleredirectstext'        => 'Esta páxina contén as páxinas que redirixen cara a outras páxinas de redirección. Cada ringleira contén ligazóns cara á primeira e segunda redireccións, e tamén á primeira liña da segunda redirección, que é usualmente o artigo "real", á que a primeira redirección debería apuntar.',
+'double-redirect-fixed-move' => 'A páxina "[[$1]]" foi movida, agora é unha redirección cara a "[[$2]]"',
+'double-redirect-fixer'      => 'Amañador de redireccións',
 
 'brokenredirects'        => 'Redireccións rotas',
 'brokenredirectstext'    => 'Estas redireccións ligan cara a unha páxina que non existe:',
@@ -1381,7 +1376,7 @@
 'logempty'             => 'Non se atopou ningún ítem relacionado no rexistro.',
 'log-title-wildcard'   => 'Procurar os títulos que comecen con este texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Todas as páxinas',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Páxina seguinte ($1)',
@@ -1404,12 +1399,12 @@
 'special-categories-sort-count' => 'ordenar por número',
 'special-categories-sort-abc'   => 'ordenar alfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostrar os usuarios comezando por:',
 'listusers-submit'   => 'Amosar',
 'listusers-noresult' => 'Non se atopou ningún usuario. Comprobe tamén as variantes con maiúsculas e minúsculas.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Dereitos dun usuario segundo o seu grupo',
 'listgrouprights-summary'  => 'A seguinte listaxe mostra os grupos de usuario definidos neste wiki, cos seus dereitos de acceso asociados.
 Se quere máis información acerca dos dereitos individuais pode atopala [[{{MediaWiki:Listgrouprights-helppage}}|aquí]].',
@@ -1420,7 +1415,7 @@
 
 # E-mail user
 'mailnologin'     => 'Non existe enderezo para o envío',
-'mailnologintext' => 'Debe estar [[Special:Userlogin|dentro do sistema]] e ter un enderezo de correo electrónico válido nas súas [[Special:Preferences|preferencias]] para enviar correos electrónicos a outros usuarios.',
+'mailnologintext' => 'Debe estar [[Special:UserLogin|dentro do sistema]] e ter un enderezo de correo electrónico válido nas súas [[Special:Preferences|preferencias]] para enviar correos electrónicos a outros usuarios.',
 'emailuser'       => 'Enviar un correo electrónico a este usuario',
 'emailpage'       => 'Enviar un correo electrónico a un usuario',
 'emailpagetext'   => 'Este formulario serve para enviar unha única mensaxe de correo no caso de que este usuario teña configurado un enderezo electrónico válido nas súas preferencias de usuario. Para que o receptor da mensaxe poida responder no campo "De" visualízase o enderezo que vostede incluíu nas súas propias preferencias.',
@@ -1446,10 +1441,10 @@
 'nowatchlist'          => 'Non ten ítems na súa listaxe de vixilancia.',
 'watchlistanontext'    => 'Faga o favor de $1 no sistema para ver ou editar os ítems da súa listaxe de vixilancia.',
 'watchnologin'         => 'Non accedeu ao sistema',
-'watchnologintext'     => 'Para modificar a súa listaxe de vixilancia debe estar [[Special:Userlogin|rexistrado]].',
+'watchnologintext'     => 'Para modificar a súa listaxe de vixilancia debe estar [[Special:UserLogin|rexistrado]].',
 'addedwatch'           => 'Engadido á listaxe de vixilancia',
 'addedwatchtext'       => "A páxina \"[[:\$1]]\" foi engadida á súa [[Special:Watchlist|listaxe de vixilancia]].
-Os cambios futuros nesta páxina e na súa páxina de conversa asociada serán listados alí, e a páxina aparecerá en '''negra''' na [[Special:Recentchanges|listaxe de cambios recentes]] para facer máis sinxela a súa sinalización.",
+Os cambios futuros nesta páxina e na súa páxina de conversa asociada serán listados alí, e a páxina aparecerá en '''negra''' na [[Special:RecentChanges|listaxe de cambios recentes]] para facer máis sinxela a súa sinalización.",
 'removedwatch'         => 'Quitado da listaxe de vixilancia',
 'removedwatchtext'     => 'A páxina "[[:$1]]" foi eliminada da súa listaxe de vixilancia.',
 'watch'                => 'Vixiar',
@@ -1561,7 +1556,7 @@
 volveuse á última edición, feita por $2.',
 'sessionfailure'              => 'Parece que hai un problema co rexistro da súa sesión; esta acción cancelouse como precaución fronte ao secuestro de sesións. Prema no botón "atrás", volva cargar a páxina da que proviña e ténteo de novo.',
 'protectlogpage'              => 'Rexistro de protección',
-'protectlogtext'              => 'Abaixo móstrase unha lista dos bloqueos e desbloqueos de páxinas. Vexa a [[Special:Protectedpages|listaxe de páxinas protexidas]] para unha listaxe coas proteccións de páxinas establecidas neste momento.',
+'protectlogtext'              => 'Abaixo móstrase unha lista dos bloqueos e desbloqueos de páxinas. Vexa a [[Special:ProtectedPages|listaxe de páxinas protexidas]] para unha listaxe coas proteccións de páxinas establecidas neste momento.',
 'protectedarticle'            => 'protexeu "[[$1]]"',
 'modifiedarticleprotection'   => 'modificou o nivel de protección de "[[$1]]"',
 'unprotectedarticle'          => 'desprotexeu "[[$1]]"',
@@ -1725,7 +1720,7 @@
 'badipaddress'                    => 'O enderezo IP non é válido',
 'blockipsuccesssub'               => 'Bloqueo con éxito',
 'blockipsuccesstext'              => 'O enderezo IP [[Special:Contributions/$1|$1]] foi bloqueado.<br />
-Olle a [[Special:Ipblocklist|listaxe de IP bloqueados]] para revisalo.',
+Olle a [[Special:IPBlockList|listaxe de IP bloqueados]] para revisalo.',
 'ipb-edit-dropdown'               => 'Editar as razóns do bloqueo',
 'ipb-unblock-addr'                => 'Desbloquear $1',
 'ipb-unblock'                     => 'Desbloquear usuario ou enderezo IP',
@@ -1755,7 +1750,7 @@
 'autoblocker'                     => 'Autobloqueado porque "[[User:$1|$1]]" usou recentemente este enderezo IP. O motivo do bloqueo de $1 é: "$2".',
 'blocklogpage'                    => 'Rexistro de bloqueos',
 'blocklogentry'                   => 'bloqueou a "[[$1]]" cun tempo de duración de $2 $3',
-'blocklogtext'                    => 'Este é o rexistro das accións de bloqueo e desbloqueo de usuarios. Non se listan os enderezos IP bloqueados automaticamente. Para ver a listaxe de bloqueos vixentes revise esta [[Special:Ipblocklist|listaxe]].',
+'blocklogtext'                    => 'Este é o rexistro das accións de bloqueo e desbloqueo de usuarios. Non se listan os enderezos IP bloqueados automaticamente. Para ver a listaxe de bloqueos vixentes revise esta [[Special:IPBlockList|listaxe]].',
 'unblocklogentry'                 => 'desbloqueou a "$1"',
 'block-log-flags-anononly'        => 'só usuarios anónimos',
 'block-log-flags-nocreate'        => 'desactivada a creación de contas de usuario',
@@ -1792,7 +1787,7 @@
 'lockdbsuccesssub'    => 'A base de datos foi fechada con éxito',
 'unlockdbsuccesssub'  => 'Quitouse a protección da base de datos',
 'lockdbsuccesstext'   => 'A base de datos foi bloqueada.
-<br />Lembre [[Special:Unlockdb|eliminar o bloqueo]] unha vez completado o seu mantemento.',
+<br />Lembre [[Special:UnlockDB|eliminar o bloqueo]] unha vez completado o seu mantemento.',
 'unlockdbsuccesstext' => 'A base de datos foi desbloqueada.',
 'lockfilenotwritable' => 'Non se pode escribir no ficheiro de bloqueo da base de datos. Para bloquear ou desbloquear a base de datos, o servidor web ten que poder escribir neste ficheiro.',
 'databasenotlocked'   => 'A base de datos non está bloqueada.',
@@ -1816,8 +1811,6 @@
 
 Nestes casos, terá que mover ou mesturar a páxina manualmente se o desexa.",
 'movearticle'             => 'Mover esta páxina:',
-'movenologin'             => 'Non está dentro do sistema',
-'movenologintext'         => 'Debe ser un usuario rexistrado e estar [[Special:Userlogin|dentro do sistema]] para mover unha páxina.',
 'movenotallowed'          => 'Non ten permiso para mover páxinas en {{SITENAME}}.',
 'newtitle'                => 'Ao novo título:',
 'move-watch'              => 'Vixiar esta páxina',
@@ -1845,7 +1838,7 @@
 'delete_and_move'         => 'Borrar e mover',
 'delete_and_move_text'    => '==Precísase borrar==
 
-O artigo de destino "[[$1]]" xa existe. Quéreo eliminar para facer sitio para mover?',
+O artigo de destino "[[:$1]]" xa existe. Quéreo eliminar para facer sitio para mover?',
 'delete_and_move_confirm' => 'Si, borrar a páxina',
 'delete_and_move_reason'  => 'Eliminado para facer sitio para mover',
 'selfmove'                => 'O título de orixe e o de destino é o mesmo; non se pode mover unha páxina sobre si mesma.',
@@ -1853,6 +1846,7 @@
 'imagenocrossnamespace'   => 'Non se pode mover o ficheiro a un espazo de nomes que non o admite',
 'imagetypemismatch'       => 'A nova extensión do fiheiro non coincide co seu tipo',
 'imageinvalidfilename'    => 'O nome da imaxe é inválido',
+'fix-double-redirects'    => 'Actualizar calquera redirección que apunte cara ao título orixinal',
 
 # Export
 'export'            => 'Exportar páxinas',
@@ -2081,10 +2075,10 @@
 'show-big-image'       => 'Imaxe na máxima resolución',
 'show-big-image-thumb' => '<small>Tamaño desta presentación da imaxe: $1 × $2 píxeles</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galería de imaxes novas',
 'imagelisttext'         => "Abaixo amósase unha listaxe de '''$1''' {{PLURAL:$1|ficheiro|ficheiros}} ordenados $2.",
-'newimages-summary'     => 'Esta páxina especial amosa os ficheiros cargados máis recentemente',
+'newimages-summary'     => 'Esta páxina especial amosa os ficheiros cargados máis recentemente.',
 'showhidebots'          => '($1 os bots)',
 'noimages'              => 'Non hai imaxes para ver.',
 'ilsubmit'              => 'Procurar',
@@ -2367,7 +2361,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar este ficheiro cunha aplicación externa',
-'edit-externally-help' => 'Vexa as seguintes [http://meta.wikimedia.org/wiki/Help:External_editors instrucións] <small>(en inglés)</small> para máis información.',
+'edit-externally-help' => 'Vexa as seguintes [http://www.mediawiki.org/wiki/Manual:External_editors instrucións] <small>(en inglés)</small> para máis información.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'todos',
@@ -2433,7 +2427,7 @@
 'recreate'            => 'Recrear',
 
 # HTML dump
-'redirectingto' => 'Redirixindo a [[$1]]...',
+'redirectingto' => 'Redirixindo a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Está seguro de que desexa limpar a memoria caché desta páxina?
@@ -2533,7 +2527,7 @@
 'version-software-product'         => 'Produto',
 'version-software-version'         => 'Versión',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Ruta do ficheiro',
 'filepath-page'    => 'Ficheiro:',
 'filepath-submit'  => 'Ruta',
@@ -2572,7 +2566,7 @@
 'specialpages-group-redirects'   => 'Páxinas de redirección especiais',
 'specialpages-group-spam'        => "Ferramentas contra o ''spam''",
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Baleirar a páxina',
 'intentionallyblankpage' => 'Esta páxina foi baleirada intencionadamente',
 
Index: languages/messages/MessagesSa.php
===================================================================
--- languages/messages/MessagesSa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -98,7 +98,7 @@
 # Book sources
 'booksources-go' => 'प्रस्थानम्',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'सर्व लेखा',
 
 # E-mail user
Index: languages/messages/MessagesAng.php
===================================================================
--- languages/messages/MessagesAng.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAng.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,7 @@
  * @file
  *
  * @author JJohnson
- * @author SPQRobin
  * @author Wōdenhelm
- * @author Siebrand
  */
 
 $messages = array(
@@ -247,9 +245,6 @@
 'showpreview'            => 'Forescēawian',
 'whitelistedittitle'     => 'Inmeldunge behófod tó ádihtenne',
 'whitelistedittext'      => 'Þu scealt $1 tó ádihtenne trametas.',
-'whitelistreadtitle'     => 'Inmeldunge behōfod tō rǣdenne',
-'whitelistacctitle'      => 'Þē nis ālīefed tō settenne hordcleofan',
-'whitelistacctext'       => 'Tō bēonne gelīefed tō settenne hordcleofan in þissum Wici, þu scealt [[Special:Userlogin|inmeldian]] and habban þā gerādlican geþafunga.',
 'loginreqlink'           => 'inmeldian',
 'loginreqpagetext'       => 'Þū scealt $1 tō scēawienne view ōðre trametas.',
 'accmailtitle'           => 'Gelēafnesword gesended.',
@@ -368,7 +363,7 @@
 
 'nolicense' => 'Nǣnne gecorenne',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Sēcan biliþnaman:',
 'imagelist'             => 'Biliþgetalu',
 'imagelist_date'        => 'Tælmearc',
@@ -438,7 +433,7 @@
 'log'                  => 'Cranicas',
 'log-search-submit'    => 'Gān',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Trametas',
 'alphaindexline' => '$1 tō $2',
 'nextpage'       => 'Nīehsta tramet ($1)',
@@ -452,7 +447,7 @@
 'categories'         => 'Floccas',
 'categoriespagetext' => 'Þā folgendan floccas standaþ in þǣm wici.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-noresult' => 'Nǣnne brūcend gefundenne.',
 
 # E-mail user
@@ -601,7 +596,7 @@
 'imagemaxsize' => 'Settan biliðu on biliþgemearcungtrametum tō:',
 'thumbsize'    => 'Þumannæglmicelnes:',
 
-# Special:Newimages
+# Special:NewImages
 'imagelisttext' => 'Under is getalu $1 biliða gedæfted $2.',
 'noimages'      => 'Nāht tō sēonne.',
 'ilsubmit'      => 'Sēcan',
@@ -679,7 +674,7 @@
 'scarytranscludetoolong' => '[URL is tō lang; sarig]',
 
 # HTML dump
-'redirectingto' => 'Edlǣdeþ tō [[$1]]...',
+'redirectingto' => 'Edlǣdeþ tō [[:$1]]...',
 
 # AJAX search
 'searchnamed' => "Sēcan gewritu genemnodu ''$1''.",
Index: languages/messages/MessagesTt_latn.php
===================================================================
--- languages/messages/MessagesTt_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTt_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author לערי ריינהארט
- * @author Siebrand
  * @author Albert Fazlî
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -309,9 +308,6 @@
 'showpreview'        => 'Qarap alu...',
 'blockedtitle'       => 'Qullanuçı tíıldı',
 'whitelistedittitle' => 'Üzgärtü öçen, kerü täläp itelä',
-'whitelistreadtitle' => 'Uqu öçen kerü täläp itelä',
-'whitelistreadtext'  => 'Bitlärne uqu öçen, säxifägä isem belän [[Special:Userlogin|keräse]].',
-'whitelistacctitle'  => 'Siña xísap yasaw tíılğan',
 'loginreqtitle'      => 'Kerergä Kiräk',
 'loginreqlink'       => 'keräse',
 'accmailtitle'       => 'Sersüz künderelde.',
@@ -415,7 +411,7 @@
 'reupload'          => 'Qabat yökläw',
 'reuploaddesc'      => 'Yökläw bitenä qaytu.',
 'uploadnologin'     => 'Kermädeñ',
-'uploadnologintext' => 'Birem yökläw öçen, säxifägä isem belän [[Special:Userlogin|keräse]].',
+'uploadnologintext' => 'Birem yökläw öçen, säxifägä isem belän [[Special:UserLogin|keräse]].',
 'uploaderror'       => 'Yökläw xatası',
 'uploadlog'         => 'yökläw könlege',
 'uploadlogpage'     => 'Yökläw_könlege',
@@ -435,7 +431,7 @@
 'uploaddisabled'    => 'Ğafu it, yökläw sünderelgän kileş tora.',
 'uploadcorrupt'     => 'Bu birem yä üze watıq, yä quşımtası yaraqsız. Birem tikşerüdän soñ qabat yöklä zínhar.',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'   => 'fayl',
 'imagelist' => 'Räsem tezmäse',
 
@@ -502,7 +498,7 @@
 'log'           => 'Köndelikler',
 'all-logs-page' => 'Barlıq köndelik',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'     => 'Bar bitlär',
 'nextpage'     => 'Kiläse bit ($1)',
 'prevpage'     => 'Ötken bet ($1)',
@@ -512,7 +508,7 @@
 'categories'         => 'Cíıntıqlar',
 'categoriespagetext' => "Bu wiki'dä kiläse cíıntıqlar bar.",
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Körset',
 
 # E-mail user
@@ -532,7 +528,7 @@
 'mywatchlist'      => 'Saqtezmäm',
 'nowatchlist'      => 'Saqtezmäñdä kertemnär yuq.',
 'watchnologin'     => 'Kermädeñ',
-'watchnologintext' => 'Saqtezmäñ üzgärtü öçen, säxifägä isem belän [[Special:Userlogin|keräse]].',
+'watchnologintext' => 'Saqtezmäñ üzgärtü öçen, säxifägä isem belän [[Special:UserLogin|keräse]].',
 'addedwatch'       => 'Saqtezmägä quşıldı',
 'removedwatch'     => 'Saqtezmädän salındı',
 'removedwatchtext' => '«[[:$1]]» atlı bit saqtezmäñnän töşerelde.',
@@ -624,7 +620,6 @@
 # Move page
 'move-page-legend' => 'Bit küçerü',
 'movearticle'      => 'Küçeräse bit',
-'movenologin'      => 'Kermädeñ',
 'newtitle'         => 'Yaña başlıq',
 'movepagebtn'      => 'Küçer bitne',
 'pagemovedsub'     => 'Küçerü uñışlı uzdı',
@@ -702,7 +697,7 @@
 # Media information
 'show-big-image' => 'Towlı ölçemi',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Ezläw',
 'bydate'   => 'waqıt buyınça',
 
Index: languages/messages/MessagesSe.php
===================================================================
--- languages/messages/MessagesSe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,11 +5,8 @@
  * @file
  *
  * @author Skuolfi
- * @author לערי ריינהארט
- * @author Siebrand
- * @author SPQRobin
  * @author Teak
- * @author Jon Harald Søby
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -387,9 +384,6 @@
 'blockededitsource'        => 'Du rievdadusat siidui ”$1”:',
 'whitelistedittitle'       => 'Fertet čálligoahtit sisa ovdalgo sáhtat rievdadit siiddu',
 'whitelistedittext'        => 'Don fertet $1, ovdalgo sáhtat rievdadit siidduid.',
-'whitelistreadtitle'       => 'Don fertet leat čálligoahtán sisa ovdalgo sáhtat lohkat dán siiddu.',
-'whitelistreadtext'        => 'Don fertet čálligoahtit [[Special:Userlogin|sisa]] ovdalgo sáhtat lohkat siidduid.',
-'whitelistacctitle'        => 'Dus ii leat vuoigatvuohta ráhkadit dovddaldaga',
 'confirmedittitle'         => 'E-poastačujuhusa sihkarastin',
 'confirmedittext'          => 'It sáhte rievdadit siiddu ovdalgo leat sihkarastan iežat e-poastačujuhusa. Sáhtat sihkarastit [[Special:Preferences|ásahussiidduin]].',
 'nosuchsectiontitle'       => 'Diekkár oassi ii dihtto',
@@ -501,7 +495,7 @@
 'mypreferences'            => 'Ásahusat',
 'prefs-edits'              => 'Rievdadusaid mearri:',
 'prefsnologin'             => 'It leat čálligoahtán sisa.',
-'prefsnologintext'         => 'Don fertet [[Special:Userlogin|čálligoahtit sisa]], ovdalgo sáhtat rievdadit du ásahusaid.',
+'prefsnologintext'         => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], ovdalgo sáhtat rievdadit du ásahusaid.',
 'prefsreset'               => 'Ásahusat leat máhcajuvvon vurkeduvvon ásahusain.',
 'qbsettings-none'          => 'Ii maidige',
 'qbsettings-fixedleft'     => 'Teaksta mielde, gurut',
@@ -611,7 +605,7 @@
 'reupload'           => 'Sádde ođđasit',
 'reuploaddesc'       => 'Máhca sáddenskovvái.',
 'uploadnologin'      => 'It leat čálligoahtán sisa',
-'uploadnologintext'  => 'Don fertet leat [[Special:Userlogin|čálligoahtán sisa]], ovdalgo sáhtát vurket fiillaid.',
+'uploadnologintext'  => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]], ovdalgo sáhtát vurket fiillaid.',
 'uploaderror'        => 'Vurkenfeaila',
 'uploadlog'          => 'Fiilalogga',
 'uploadlogpage'      => 'Fiilalogga',
@@ -654,7 +648,7 @@
 'upload_source_url'  => ' (almmolaš URL-čujuhus)',
 'upload_source_file' => ' (fiila dihtoris)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Nammaohcan',
 'imgfile'               => 'fiila',
 'imagelist'             => 'Fiilalogahallan',
@@ -689,18 +683,18 @@
 # File reversion
 'filerevert'                => 'Fiilla $1 máhcaheapmi',
 'filerevert-legend'         => 'Fiilla máhcaheapmi',
-'filerevert-intro'          => '<span class="plainlinks">Leat máhcaheami fiilla \'\'\'[[Media:$1|$1]]\'\'\' [$4 veršuvdnii, mii ráhdaduvvui $2 diibmu $3].</span>',
+'filerevert-intro'          => "Leat máhcaheami fiilla '''[[Media:$1|$1]]''' [$4 veršuvdnii, mii ráhdaduvvui $2 diibmu $3].",
 'filerevert-comment'        => 'Sivva',
 'filerevert-defaultcomment' => 'Máhcahuvvui veršuvdnii, mii ráhkaduvvui $1 diibmu $2',
 'filerevert-submit'         => 'Máhcat',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' lea máhcahvvon [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' lea máhcahvvon [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
 'filerevert-badversion'     => 'Fiillas ii leat ráhkaduvvon veršuvdna dalle.',
 
 # File deletion
 'filedelete'           => 'Sihko $1',
 'filedelete-legend'    => 'Sihko fiilla',
 'filedelete-intro'     => "Don leat sihkomin '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old' => '<span class="plainlinks">Don leat sihkomin veršuvdna \'\'\'[[Media:$1|$1]]\'\'\'  [$4 $3, $2].</span>',
+'filedelete-intro-old' => "Don leat sihkomin veršuvdna '''[[Media:$1|$1]]'''  [$4 $3, $2].",
 'filedelete-comment'   => 'Kommeanta:',
 'filedelete-submit'    => 'Sihko',
 'filedelete-success'   => "'''$1''' lea sihkojuvvon.",
@@ -809,7 +803,7 @@
 'logempty'             => 'Eai dáhpáhusat loggas.',
 'log-title-wildcard'   => 'Mearri álgá mearkkaiguin',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Buot siiddut',
 'alphaindexline'    => '$1…$2',
 'nextpage'          => 'Čuovvovaš siidu ($1)',
@@ -827,13 +821,13 @@
 'categories'         => 'Luohkát',
 'categoriespagetext' => '{{GRAMMAR:inessive|{{SITENAME}}}} lea čuovvovaš luohkát:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Oza',
 'listusers-noresult' => 'Geavaheaddjit eai dihtton. Dárkis maid sierra bustávasturrodagat.',
 
 # E-mail user
 'mailnologin'     => 'Sáddejeaddji čujuhus váilo',
-'mailnologintext' => 'Don fertet leat [[Special:Userlogin|čálligoahtán sisa]] ja du [[Special:Preferences|ásahusain]] ferte leat gelbbolaš ja <strong>sihkarastojuvvon</strong> e-poastačujuhus, ovdalgo sáhtat sáddet e-poasta eará geavaheddjiide.',
+'mailnologintext' => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]] ja du [[Special:Preferences|ásahusain]] ferte leat gelbbolaš ja <strong>sihkarastojuvvon</strong> e-poastačujuhus, ovdalgo sáhtat sáddet e-poasta eará geavaheddjiide.',
 'emailuser'       => 'Čále e-poastta geavaheaddjái',
 'emailpage'       => 'Sádde e-poastta geavaheaddjái',
 'emailpagetext'   => 'Jus dát geavaheaddji lea lasihin iežaset ásahusaide gelbbolaš e-poastačujuhusa, vuolábeale skoviin sáhtat sáddet sunnje ovtta sáni. Iežat ásahusaide lasihuvvon e-poastačujuhus oidno sáddejeaddji dieđuin, vai vuostáiváldi sáhttá vástidit.',
@@ -858,9 +852,9 @@
 'nowatchlist'          => 'Du čuovvunlisttus eai leat siiddut.',
 'watchlistanontext'    => 'Don fertet $1, jus hálidat geavahit čuovvunlisttu.',
 'watchnologin'         => 'It leat čálligoahtán sisa',
-'watchnologintext'     => 'Don fertet [[Special:Userlogin|čálligoahtit sisa]], jus hálidat geavahit du čuovvunlisttu.',
+'watchnologintext'     => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], jus hálidat geavahit du čuovvunlisttu.',
 'addedwatch'           => 'Lasihuvvon čuovvunlistui',
-'addedwatchtext'       => "Siidu '''<nowiki>$1</nowiki>''' lea lasihuvvon [[Special:Watchlist|čuovvunlisttui]]. Boahtevuođas siiddu ja siiddu ságastallansiiddu rievdadusat almmuhuvvo dáppe. Siidu lea '''buidon''' [[Special:Recentchanges|varas rievdadusat -listtus]], vai fuomašat dan álkit. Jus hálidat heaiti čuovvumis dan siiddu, deaddil liŋkka ''heaite čuovvumis'' siiddu ravddas.",
+'addedwatchtext'       => "Siidu '''<nowiki>$1</nowiki>''' lea lasihuvvon [[Special:Watchlist|čuovvunlisttui]]. Boahtevuođas siiddu ja siiddu ságastallansiiddu rievdadusat almmuhuvvo dáppe. Siidu lea '''buidon''' [[Special:RecentChanges|varas rievdadusat -listtus]], vai fuomašat dan álkit. Jus hálidat heaiti čuovvumis dan siiddu, deaddil liŋkka ''heaite čuovvumis'' siiddu ravddas.",
 'removedwatch'         => 'Sihkojuvvon čuovvunlisttus',
 'removedwatchtext'     => "Siidu '''<nowiki>$1</nowiki>''' lea sihkojuvvon du čuovvunlisttus.",
 'watch'                => 'Čuovo',
@@ -1031,7 +1025,7 @@
 'ipbotherreason'       => 'Eará sivva',
 'badipaddress'         => 'IP-čujuhus lea boastut.',
 'blockipsuccesssub'    => 'Easttan lihkosmuvai',
-'blockipsuccesstext'   => "Geavaheaddji dahje IP-čujuhus '''$1''' lea eston.<br />Dálá easttut gávdnot [[Special:Ipblocklist|easttolisttus]].",
+'blockipsuccesstext'   => "Geavaheaddji dahje IP-čujuhus '''$1''' lea eston.<br />Dálá easttut gávdnot [[Special:IPBlockList|easttolisttus]].",
 'ipb-edit-dropdown'    => 'Rievdat siivaid',
 'ipb-unblock-addr'     => 'Sihko geavaheaddji $1 estema',
 'ipb-unblock'          => 'Sihko geavaheaddji dahje IP-čujuhusa rievdadaneasttu',
@@ -1055,7 +1049,6 @@
 # Move page
 'move-page-legend'        => 'Sirdde siiddu',
 'movearticle'             => 'Sirdde siiddu',
-'movenologin'             => 'It leat čálligoahtán sisa',
 'newtitle'                => 'Ođđa namma siidui',
 'move-watch'              => 'Čuovo dán siiddu',
 'movepagebtn'             => 'Sirdde siiddu',
@@ -1175,7 +1168,7 @@
 # Media information
 'widthheightpage' => '$1×$2, $3 siiddut',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Ođđa govat',
 'imagelisttext'         => "Vuolábealde lea '''$1''' fiilla ordnejuvvon $2.",
 'ilsubmit'              => 'Oza',
@@ -1261,7 +1254,7 @@
 'recreate' => 'Álggat ođđasit',
 
 # HTML dump
-'redirectingto' => 'Ođđasitstivrejuvvo siidui [[$1]]...',
+'redirectingto' => 'Ođđasitstivrejuvvo siidui [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Sihko',
Index: languages/messages/MessagesCu.php
===================================================================
--- languages/messages/MessagesCu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author ОйЛ
  * @author Svetko
- * @author SPQRobin
- * @author Siebrand
  * @author Wolliger Mensch
+ * @author ОйЛ
  */
 
 $separatorTransformTable = array(
@@ -237,11 +235,14 @@
 'savearticle'    => 'съхранѥ́ниѥ',
 'loginreqlink'   => 'Въниди',
 'newarticle'     => '(но́въ)',
-'clearyourcache' => '<big>НАРОЧИ́ТО:</big> По съхранѥ́нии мо́жєши обити́ своѥго́ съмотри́ла съхра́нъ да ви́дѣлъ би мѣ́нꙑ ⁙ Mozilla ли Firefox ли Safari ли жьмꙑ́и Shift а мꙑ́шиѭ жьми́ Reload и́ли жьми́ Ctrl-Shift-R (Cmd-Shift-R вън Apple Mac) ⁙ IE ли жьмꙑ́и Ctrl а мꙑ́шиѭ жьми́ Refresh и́ли жьми́ Ctrl-F5 ⁙ Konqueror ли жьми́ кро́мѣ Reload и́ли F5 ⁙ О́пєрꙑ по́льꙃєватєльмъ мо́жєть бꙑ́ти ноужда́ пльнѣ пони́чьжити и́хъ съмотри́ла съхра́нъ въ Tools > Preferences',
+'clearyourcache' => '<big>НАРОЧИ́ТО:</big> По съхранѥ́нии мо́жєши обити́ своѥго́ съмотри́ла съхра́нъ да ви́дѣлъ би мѣ́нꙑ ⁙ Mozilla ли Firefox ли Safari ли жьмꙑ́и Shift а мꙑ́шиѭ жьми́ Reload и́ли жьми́ Ctrl-Shift-R (Cmd-Shift-R вън Apple Mac)  ⁙ Konqueror ли жьми́ кро́мѣ Reload и́ли F5 ⁙ О́пєрꙑ по́льꙃєватєльмъ мо́жєть бꙑ́ти ноужда́ пльнѣ пони́чьжити и́хъ съмотри́ла съхра́нъ въ Tools > Preferences ⁙ IE ли жьмꙑ́и Ctrl а мꙑ́шиѭ жьми́ Refresh и́ли жьми́ Ctrl-F5',
 'note'           => '<strong>НАРОЧИ́ТО:</strong>',
 'editing'        => 'исправлѥ́ниѥ: $1',
+'templatesused'  => 'сѥѩ страни́цѧ с҄и обраꙁьци́ по́льꙃоуѭтъ сѧ сѫ́тъ :',
 
 # History pages
+'cur'          => 'нꙑ҃н',
+'last'         => 'пс҃лд',
 'historyempty' => '(поу́сто)',
 
 # Revision feed
@@ -251,6 +252,7 @@
 'revdelete-uname' => 'по́льꙃєватєлꙗ и́мѧ',
 
 # Search results
+'searchresults'            => 'иска́ниꙗ ито́гъ',
 'search-result-size'       => '$1 ({{PLURAL:$2|$2 сло́во|$2 сло́ва|$2 словє́съ}})',
 'search-interwiki-caption' => 'ро́дьствьна опꙑтьствова́ниꙗ',
 'searchall'                => 'вьсꙗ́',
@@ -286,6 +288,7 @@
 'recentchanges'   => 'послѣ́дьнѩ мѣ́нꙑ',
 'rcshowhideminor' => '$1 ма́лꙑ мѣ́нꙑ',
 'rcshowhidebots'  => '$1 аѵтома́тъ',
+'diff'            => 'ра҃ꙁн',
 'hist'            => 'їс҃т',
 'hide'            => 'съкрꙑи',
 'minoreditletter' => 'м҃л',
@@ -298,10 +301,12 @@
 # Upload
 'upload'          => 'положє́ниѥ дѣ́ла',
 'uploadbtn'       => 'положє́ниѥ дѣ́ла',
+'uploadlog'       => 'дѣ́лъ положє́ниꙗ їсторі́ꙗ',
+'uploadlogpage'   => 'дѣ́лъ положє́ниꙗ їсторі́ꙗ',
 'uploadedimage'   => '⁖ [[$1]] ⁖ положє́нъ ѥ́стъ',
 'watchthisupload' => 'си страни́цѧ блюдє́ниѥ',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'дѣ́ло',
 'imagelist_name' => 'и́мѧ',
 'imagelist_user' => 'по́льꙃєватєл҄ь',
@@ -349,9 +354,10 @@
 
 # Special:Log
 'specialloguserlabel' => 'по́льꙃєватєл҄ь:',
+'log'                 => 'їсторі́ѩ',
 'log-search-submit'   => 'прѣиди́',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'вьсѩ́ страни́цѧ',
 'alphaindexline' => 'о́тъ $1 до $2',
 'allpagesfrom'   => 'страни́цѧ видѣ́ти хощѫ́ съ начѧ́льнами боу́къвами :',
@@ -367,6 +373,7 @@
 # Watchlist
 'watchlist'     => 'моꙗ́ блюдє́ниꙗ',
 'mywatchlist'   => 'Моꙗ́ блюдє́ниꙗ',
+'watchlistfor'  => "(по́льꙃєватєлꙗ и́мѧ '''$1''' ѥ́стъ)",
 'watch'         => 'блюдє́ниѥ',
 'watchthispage' => 'си страни́цѧ блюдє́ниѥ',
 'unwatch'       => 'оста́ви блюдє́ниѥ',
@@ -397,7 +404,8 @@
 'mycontris'     => 'моꙗ́ добродѣꙗ́ниꙗ',
 'uctop'         => '(послѣ́дьнꙗ мѣ́на)',
 
-'sp-contributions-submit' => 'ищи́',
+'sp-contributions-blocklog' => 'ꙁаграждє́ниꙗ їсторі́ꙗ',
+'sp-contributions-submit'   => 'ищи́',
 
 # What links here
 'whatlinkshere'           => 'дос̑ьдє́щьнѩ съвѧ́ꙁи',
@@ -411,6 +419,7 @@
 'ipblocklist-submit' => 'иска́ниѥ',
 'blocklink'          => 'ꙁагради́',
 'contribslink'       => 'добродѣꙗ́ниꙗ',
+'blocklogpage'       => 'ꙁаграждє́ниꙗ їсторі́ꙗ',
 
 # Move page
 'move-page'        => 'прѣимєнова́ниѥ ⁖ $1 ⁖',
@@ -435,7 +444,7 @@
 # Media information
 'file-info-size' => '($1 × $2 п҃ѯ · дѣ́ла мѣ́ра : $3 · MIME тѵ́пъ : $4)',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ищи́',
 
 # EXIF tags
@@ -465,7 +474,7 @@
 'version-license'          => 'прощє́ниѥ',
 'version-software-version' => 'о́браꙁъ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'дѣ́ло :',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesKo.php
===================================================================
--- languages/messages/MessagesKo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,19 +4,16 @@
  * @ingroup Language
  * @file
  *
+ * @author Albamhandae
+ * @author Ficell
+ * @author ITurtle
  * @author Klutzy
+ * @author Kwj2772
+ * @author Pi.C.Noizecehx
+ * @author PuzzletChung
+ * @author TheAlpha for knowledge
  * @author ToePeu
- * @author PuzzletChung
- * @author Siebrand
- * @author ITurtle
- * @author Albamhandae
  * @author לערי ריינהארט
- * @author Kwj2772
- * @author TheAlpha for knowledge
- * @author Ficell
- * @author Pi.C.Noizecehx
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -336,7 +333,7 @@
 'nosuchspecialpage' => '해당하는 특수기능이 없습니다.',
 'nospecialpagetext' => "<big>'''요청한 특수 문서가 존재하지 않습니다.'''</big>
 
-특수 문서의 목록은 [[Special:Specialpages|여기]]에서 볼 수 있습니다.",
+특수 문서의 목록은 [[Special:SpecialPages|여기]]에서 볼 수 있습니다.",
 
 # General errors
 'error'                => '오류',
@@ -391,10 +388,13 @@
 
 # Login and logout pages
 'logouttitle'                => '로그아웃',
-'logouttext'                 => "'''{{SITENAME}}에서 로그아웃했습니다.''' 이대로 이름없이 {{SITENAME}}을(를) 이용하거나, 방금 사용했던 계정이나 다른 계정으로 다시 로그인해서 이용할 수 있습니다. 웹 브라우저의 캐시를 지우지 않으면 몇몇 문서에서 로그인이 되어 있는 것처럼 보일 수 있다는 점을 유의해 주세요.",
+'logouttext'                 => '<strong>{{SITENAME}}에서 로그아웃했습니다.</strong>
+
+이대로 이름 없이 {{SITENAME}}을(를) 이용하거나, 방금 사용했던 계정이나 다른 계정으로 다시 [[Special:UserLogin|로그인]]해서 이용할 수 있습니다.
+웹 브라우저의 캐시를 지우지 않으면 몇몇 문서에서 로그인이 되어 있는 것처럼 보일 수 있다는 점을 유의해 주세요.',
 'welcomecreation'            => '== $1 님, 환영합니다! ==
 계정이 만들어졌습니다.
-사용자 환경 설정에서 당신의 {{SITENAME}} 사용자 환경 설정을 바꿀 수 있습니다.',
+[[Special:Preferences|당신의 {{SITENAME}} 사용자 환경 설정]]을 바꿀 수 있습니다.',
 'loginpagetitle'             => '로그인',
 'yourname'                   => '계정 이름:',
 'yourpassword'               => '비밀번호:',
@@ -465,7 +465,7 @@
 'accountcreated'             => '계정 만들어짐',
 'accountcreatedtext'         => '‘$1’ 사용자 계정이 만들어졌습니다.',
 'createaccount-title'        => '{{SITENAME}} 계정 만들기',
-'createaccount-text'         => '{{SITENAME}}($4)에서 사용자 이름 ‘$2’, 암호 ‘$3’으로 계정을 만들었습니다. 로그인을 한 다음 암호를 바꾸어 주세요.
+'createaccount-text'         => '{{SITENAME}}($4)에서 계정 이름 ‘$2’, 비밀번호 ‘$3’으로 계정을 만들었습니다. 로그인을 한 다음 암호를 바꾸어 주세요.
 
 계정을 잘못 만들었다면 이 메시지는 무시해도 됩니다.',
 'loginlanguagelabel'         => '언어: $1',
@@ -542,9 +542,6 @@
 'blockededitsource'                => "아래에 '''$1'''에서의 '''당신의 편집'''이 나와 있습니다:",
 'whitelistedittitle'               => '편집하려면 로그인 필요',
 'whitelistedittext'                => '문서를 편집하려면 $1해야 합니다.',
-'whitelistreadtitle'               => '문서를 보려면 로그인 필요',
-'whitelistreadtext'                => '문서를 읽기 위해서는 [[Special:Userlogin|로그인]]해야 합니다.',
-'whitelistacctitle'                => '계정을 만들도록 허용되어 있지 않습니다.',
 'confirmedittitle'                 => '편집하려면 이메일 인증 필요',
 'confirmedittext'                  => '문서를 고치려면 이메일 인증 절차가 필요합니다. [[Special:Preferences|사용자 환경 설정]]에서 이메일 주소를 입력하고 이메일 주소 인증을 해 주시기 바랍니다.',
 'nosuchsectiontitle'               => '해당 부분 없음',
@@ -558,9 +555,9 @@
 'newarticletext'                   => "이 문서는 아직 만들어지지 않았습니다. 새 문서를 만들려면 아래의 상자에 문서 내용을 입력하면 됩니다(자세한 내용은 [[{{MediaWiki:Helppage}}|도움말]]을 읽어 주세요).
 만약 잘못 찾아온 문서라면, 웹 브라우저의 '''뒤로''' 버튼을 눌러 주세요.",
 'anontalkpagetext'                 => '----
-여기는 계정에 로그인하지 않은 익명 사용자를 위한 토론 문서입니다. 익명 사용자의 사용자 이름은 IP 주소로 나오기 때문에, 한 IP 주소를 여러 명이 같이 쓰거나 유동 IP를 사용하는 경우 엉뚱한 사람에게 의견이 전달될 수 있습니다. 이러한 문제를 피하려면 [[Special:Userlogin|계정을 만들거나 로그인해 주시기 바랍니다]].',
+여기는 계정에 로그인하지 않은 익명 사용자를 위한 토론 문서입니다. 익명 사용자의 사용자 이름은 IP 주소로 나오기 때문에, 한 IP 주소를 여러 명이 같이 쓰거나 유동 IP를 사용하는 경우 엉뚱한 사람에게 의견이 전달될 수 있습니다. 이러한 문제를 피하려면 [[Special:UserLogin|계정을 만들거나 로그인해 주시기 바랍니다]].',
 'noarticletext'                    => '현재 문서는 비어 있습니다. 이 제목으로 [[Special:Search/{{PAGENAME}}|검색]]하거나 문서를 [{{fullurl:{{FULLPAGENAME}}|action=edit}} 편집]할 수 있습니다.',
-'userpage-userdoesnotexist'        => '‘$1’ 사용자 이름은 등록되어 있지 않습니다. 이 문서를 만들거나 편집하려면 계정을 확인해주세요.',
+'userpage-userdoesnotexist'        => '‘$1’ 계정은 등록되어 있지 않습니다. 이 문서를 만들거나 편집하려면 계정이 존재 하는지 확인해주세요.',
 'clearyourcache'                   => "'''참고''': 설정을 저장한 후에 바뀐 점을 확인하기 위해서는 브라우저의 캐시를 갱신해야 합니다. '''모질라 / 파이어폭스 / 사파리''': ‘시프트’ 키를 누르면서 ‘새로 고침’을 클릭하거나, ''Ctrl-F5''를 입력; '''컨커러''': 단순히 '새로고침'을 클릭하거나 ''F5''를 입력; '''오페라''' 사용자는 ‘도구→설정’에서 캐시를 완전히 비워야 합니다.",
 'usercssjsyoucanpreview'           => "'''안내''': CSS/JS 문서를 저장하기 전에 ‘미리 보기’ 기능을 통해 작동을 확인해주세요.",
 'usercsspreview'                   => "'''이것은 CSS 미리 보기로, 아직 저장하지 않았다는 것을 주의해 주세요!'''",
@@ -612,7 +609,7 @@
 'hiddencategories'                 => '이 문서는 아래의 $1개의 숨겨진 분류에 속해 있습니다.',
 'edittools'                        => '<!-- 이 문서는 편집 창과 파일 올리기 창에 출력됩니다. -->',
 'nocreatetitle'                    => '문서 생성 제한',
-'nocreatetext'                     => '{{SITENAME}}에서 새로운 문서를 생성하는 것은 제한되어 있습니다. 이미 존재하는 다른 문서를 편집하거나, [[Special:Userlogin|로그인하거나 계정을 만들 수 있습니다]].',
+'nocreatetext'                     => '{{SITENAME}}에서 새로운 문서를 생성하는 것은 제한되어 있습니다. 이미 존재하는 다른 문서를 편집하거나, [[Special:UserLogin|로그인하거나 계정을 만들 수 있습니다]].',
 'nocreate-loggedin'                => '{{SITENAME}}에서 새 문서를 만들 권한이 없습니다.',
 'permissionserrors'                => '권한 오류',
 'permissionserrorstext'            => '{{PLURAL:$1|}}해당 명령을 수행할 권한이 없습니다. 다음의 이유를 확인해보세요:',
@@ -673,7 +670,7 @@
 'revdelete-content' => '내용',
 
 # Diffs
-'history-title'           => '‘$1’의 문서 역사',
+'history-title'           => '"$1" 문서의 변경 내력',
 'difference'              => '(버전 사이의 차이)',
 'lineno'                  => '$1번째 줄:',
 'compareselectedversions' => '선택된 버전들을 비교하기',
@@ -686,6 +683,7 @@
 'searchsubtitle'           => "검색 단어 '''[[:$1]]'''",
 'searchsubtitleinvalid'    => "검색 단어 '''$1'''",
 'noexactmatch'             => "'''$1 문서가 없습니다.''' 문서를 [[:$1|만들 수]] 있습니다.",
+'noexactmatch-nocreate'    => "'''\"\$1\" 문서가 존재하지 않습니다.'''",
 'titlematches'             => '문서 제목 일치',
 'notitlematches'           => '해당하는 제목 없음',
 'textmatches'              => '문서 내용 일치',
@@ -701,7 +699,9 @@
 'showingresultsnum'        => "'''$2'''번 부터 '''$3'''개의 결과입니다.",
 'nonefound'                => "'''참고''': 몇개의 이름공간만 기본 검색 범위입니다. 토론이나 틀 등의 모든 자료를 검색하기 위해서는 접두어로 '''all:''' 어떤 이름공간을 위해서는 접두어로 그 이름공간을 쓸 수 있습니다.",
 'powersearch'              => '찾기',
-'powersearch-legend'       => '더 찾아보기',
+'powersearch-legend'       => '고급 검색',
+'powersearch-ns'           => '다음의 이름공간에서 찾기:',
+'powersearch-field'        => '검색',
 'searchdisabled'           => '{{SITENAME}} 검색 기능이 비활성화되어 있습니다. 기능이 작동하지 않는 동안에는 구글(Google)을 이용해 검색할 수 있습니다. 검색 엔진의 내용은 최근 것이 아닐 수 있다는 점을 주의해주세요.',
 
 # Preferences page
@@ -709,7 +709,7 @@
 'mypreferences'            => '사용자 환경 설정',
 'prefs-edits'              => '편집 횟수:',
 'prefsnologin'             => '로그인하지 않음',
-'prefsnologintext'         => '사용자 환경 설정을 바꾸려면 먼저 [[Special:Userlogin|로그인]]해야 합니다.',
+'prefsnologintext'         => '사용자 환경 설정을 바꾸려면 먼저 [[Special:UserLogin|로그인]]해야 합니다.',
 'prefsreset'               => '사용자 환경 설정을 기본값으로 되돌렸습니다.',
 'qbsettings'               => '빨리가기 맞춤',
 'qbsettings-none'          => '없음',
@@ -761,14 +761,14 @@
 'servertime'               => '서버 시각',
 'guesstimezone'            => '웹 브라우저 설정에서 가져오기',
 'allowemail'               => '다른 사용자로부터의 이메일 허용',
-'defaultns'                => '기본으로 다음의 네임스페이스에서 찾기:',
+'defaultns'                => '기본으로 다음의 이름공간에서 찾기:',
 'default'                  => '기본값',
 'files'                    => '파일',
 
 # User rights
 'userrights'                  => '사용자 권한 관리', # Not used as normal message but as header for the special page itself
 'userrights-lookup-user'      => '사용자 권한 관리',
-'userrights-user-editname'    => '사용자 이름:',
+'userrights-user-editname'    => '계정 이름:',
 'editusergroup'               => '사용자 그룹 편집',
 'editinguser'                 => "'''[[User:$1|$1]]'''([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]]) 사용자의 권한 변경",
 'userrights-editusergroup'    => '사용자 그룹 편집',
@@ -780,7 +780,7 @@
 * <nowiki>*</nowiki>표시는 권한을 주거나 거두는 것 중 하나만 할 수 있다는 뜻입니다.',
 'userrights-reason'           => '바꾸는 이유:',
 'userrights-no-interwiki'     => '다른 위키의 사용자 권한을 바꿀 권한이 없습니다.',
-'userrights-nologin'          => '사용자의 권한을 바꾸기 위해서는 반드시 관리자 계정으로 [[Special:Userlogin|로그인]]해야 합니다.',
+'userrights-nologin'          => '사용자의 권한을 바꾸기 위해서는 반드시 관리자 계정으로 [[Special:UserLogin|로그인]]해야 합니다.',
 'userrights-notallowed'       => '다른 사용자의 권한을 조정할 권한이 없습니다.',
 'userrights-changeable-col'   => '바꿀 수 있는 권한',
 'userrights-unchangeable-col' => '바꿀 수 없는 권한',
@@ -867,11 +867,11 @@
 'reupload'                    => '다시 올리기',
 'reuploaddesc'                => '올리기를 취소하고 올리기 양식으로 돌아가기',
 'uploadnologin'               => '로그인하지 않음',
-'uploadnologintext'           => '파일을 올리려면 [[Special:Userlogin|로그인]]해야 합니다.',
+'uploadnologintext'           => '파일을 올리려면 [[Special:UserLogin|로그인]]해야 합니다.',
 'upload_directory_read_only'  => '파일 저장 디렉토리($1)에 쓰기 권한이 없습니다.',
 'uploaderror'                 => '올리기 오류',
 'uploadtext'                  => "파일을 올리기 위해서는 아래의 양식을 채워주세요.
-[[Special:Imagelist|파일 목록]]에서 이전에 올라온 파일을 찾을 수 있습니다.
+[[Special:ImageList|파일 목록]]에서 이전에 올라온 파일을 찾을 수 있습니다.
 [[Special:Log/upload|올리기 기록]]에도 파일이 올라오거나 지워진 기록이 남습니다.
 
 문서에 그림을 넣으려면
@@ -951,7 +951,7 @@
 'nolicense'         => '선택하지 않음',
 'license-nopreview' => '(미리보기 불가능)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => '이 특수문서는 올라온 모든 파일의 목록입니다.
 기본적으로 마지막으로 올라온 파일이 맨 위에 보입니다.
 다르게 정렬하려면 원하는 기준 열의 첫 칸을 누르세요.',
@@ -990,17 +990,17 @@
 # File reversion
 'filerevert'                => '$1 되돌리기',
 'filerevert-legend'         => '파일 되돌리기',
-'filerevert-intro'          => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' 파일을 [$4 $2 $3 버전]으로 되돌립니다.</span>',
+'filerevert-intro'          => "'''[[Media:$1|$1]]''' 파일을 [$4 $2 $3 버전]으로 되돌립니다.",
 'filerevert-comment'        => '내용:',
 'filerevert-defaultcomment' => '$1 $2 버전으로 되돌림',
 'filerevert-submit'         => '되돌리기',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' 파일을 [$4 $2 $3 버전]으로 되돌렸습니다.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' 파일을 [$4 $2 $3 버전]으로 되돌렸습니다.",
 
 # File deletion
 'filedelete'                  => '$1 삭제하기',
 'filedelete-legend'           => '파일 삭제하기',
 'filedelete-intro'            => "'''[[Media:$1|$1]]''' 파일을 삭제합니다.",
-'filedelete-intro-old'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' 파일의 [$4 $2 $3] 버전을 삭제합니다.</span>',
+'filedelete-intro-old'        => "'''[[Media:$1|$1]]''' 파일의 [$4 $2 $3] 버전을 삭제합니다.",
 'filedelete-comment'          => '삭제 이유:',
 'filedelete-submit'           => '삭제',
 'filedelete-success'          => "'''$1''' 파일을 삭제했습니다.",
@@ -1050,7 +1050,7 @@
 위키가 설치된 후 문서는 전체 '''\$3'''번 읽혔고, '''\$4'''번 편집되었습니다. 문서당 평균 편집 횟수는 '''\$5'''번이고, 한번 편집할 때마다 평균 '''\$6'''번 문서를 보았습니다.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]의 길이는 '''\$7'''입니다.",
-'userstatstext'          => "'''$1'''명의 [[Special:Listusers|사용자]]가 등록되어 있고, 이 중 $5 권한을 가진 사용자 수는 '''$2'''명('''$4%''')입니다.",
+'userstatstext'          => "'''$1'''명의 [[Special:ListUsers|사용자]]가 등록되어 있고, 이 중 $5 권한을 가진 사용자 수는 '''$2'''명('''$4%''')입니다.",
 'statistics-mostpopular' => '가장 많이 읽힌 문서',
 
 'disambiguations'      => '동음이의 문서 목록',
@@ -1059,8 +1059,9 @@
 그 링크를 다른 적절한 문서로 연결해 주어야 합니다.<br />
 [[MediaWiki:Disambiguationspage]]에서 링크된 틀을 사용하는 문서를 동음이의 문서로 간주합니다.",
 
-'doubleredirects'     => '이중 넘겨주기 목록',
-'doubleredirectstext' => '각 열의 첫번째 문서는 두번째 문서로, 두번째 문서는 세번째 문서로 연결됩니다. 첫번째 문서를 마지막 문서로 연결해 주어야 합니다.',
+'doubleredirects'            => '이중 넘겨주기 목록',
+'doubleredirectstext'        => '각 열의 첫번째 문서는 두번째 문서로, 두번째 문서는 세번째 문서로 연결됩니다. 첫번째 문서를 마지막 문서로 연결해 주어야 합니다.',
+'double-redirect-fixed-move' => '넘겨주기 수정: [[$1]] 문서가 [[$2]]로 이동되었습니다.',
 
 'brokenredirects'        => '끊긴 넘겨주기 목록',
 'brokenredirectstext'    => '존재하지 않는 문서로 넘겨주기가 되어 있는 문서의 목록입니다:',
@@ -1136,10 +1137,10 @@
 'all-logs-page'        => '모든 기록',
 'log-search-legend'    => '로그 검색',
 'log-search-submit'    => '찾기',
-'alllogstext'          => '{{SITENAME}}에서의 기록이 모두 나와 있습니다. 로그 종류, 사용자 이름, 문서 이름을 선택해서 볼 수 있습니다.',
+'alllogstext'          => '{{SITENAME}}에서의 기록이 모두 나와 있습니다. 로그 종류, 계정 이름, 문서 이름을 선택해서 볼 수 있습니다.',
 'logempty'             => '일치하는 항목이 없습니다.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '모든 문서 목록',
 'alphaindexline'    => '$1에서 $2까지',
 'nextpage'          => '다음 문서 ($1)',
@@ -1159,17 +1160,17 @@
 'categories'         => '분류',
 'categoriespagetext' => '문서나 자료를 담고 있는 분류 목록입니다.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '다음으로 시작하는 사용자 보이기:',
 'listusers-submit'   => '보이기',
 'listusers-noresult' => '해당 사용자가 없습니다.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights' => '사용자 권한 목록',
 
 # E-mail user
 'mailnologin'     => '보낼 이메일 주소가 없음',
-'mailnologintext' => '다른 사용자에게 이메일을 보내려면, [[Special:Userlogin|로그인]]한 다음 [[Special:Preferences|사용자 환경 설정]]에서 자신의 이메일 주소를 저장해야 합니다.',
+'mailnologintext' => '다른 사용자에게 이메일을 보내려면, [[Special:UserLogin|로그인]]한 다음 [[Special:Preferences|사용자 환경 설정]]에서 자신의 이메일 주소를 저장해야 합니다.',
 'emailuser'       => '이메일 보내기',
 'emailpage'       => '사용자에게 이메일 보내기',
 'emailpagetext'   => '이 사용자가 환경 설정에 올바른 이메일 주소를 적었다면, 아래 양식을 통해 이메일을 보낼 수 있습니다. 이메일을 받은 사용자가 바로 답장할 수 있도록 하기 위해, 당신의 이메일 주소가 ‘발신자’ 정보에 들어갑니다.',
@@ -1194,9 +1195,9 @@
 'nowatchlist'          => '주시하는 문서가 아직 없습니다.',
 'watchlistanontext'    => '주시문서 목록의 항목들을 보거나 편집하려면 $1을(를) 보세요.',
 'watchnologin'         => '로그인하지 않음',
-'watchnologintext'     => '[[Special:Userlogin|로그인]]을 해야만 주시문서 목록을 볼 수 있습니다.',
+'watchnologintext'     => '[[Special:UserLogin|로그인]]을 해야만 주시문서 목록을 볼 수 있습니다.',
 'addedwatch'           => '주시문서 목록에 추가',
-'addedwatchtext'       => "‘[[:$1]]’ 문서가 주시문서 목록에 추가되었습니다. 앞으로 이 문서나 토론 문서가 변경되면 [[Special:Recentchanges|최근 바뀜]]에서 변경점들이 '''굵은 글씨'''로 나타날 것입니다. 더 이상 주시하지 않으려면 ‘주시 해제’를 누르면 됩니다.",
+'addedwatchtext'       => "‘[[:$1]]’ 문서가 주시문서 목록에 추가되었습니다. 앞으로 이 문서나 토론 문서가 변경되면 [[Special:RecentChanges|최근 바뀜]]에서 변경점들이 '''굵은 글씨'''로 나타날 것입니다. 더 이상 주시하지 않으려면 ‘주시 해제’를 누르면 됩니다.",
 'removedwatch'         => '주시문서 목록에서 제거',
 'removedwatchtext'     => '‘[[:$1]]’ 문서를 주시문서 목록에서 제거했습니다.',
 'watch'                => '주시',
@@ -1368,7 +1369,7 @@
 $1',
 
 # Namespace form on various pages
-'namespace'      => '이름 공간:',
+'namespace'      => '이름공간:',
 'invert'         => '선택 반전',
 'blanknamespace' => '(일반)',
 
@@ -1385,7 +1386,7 @@
 'sp-contributions-newbies-sub' => '새 사용자들의 기여',
 'sp-contributions-blocklog'    => '차단 기록',
 'sp-contributions-search'      => '기여 검색',
-'sp-contributions-username'    => 'IP 주소 혹은 사용자 이름:',
+'sp-contributions-username'    => 'IP 주소 혹은 계정 이름:',
 'sp-contributions-submit'      => '찾기',
 
 # What links here
@@ -1408,7 +1409,7 @@
 차단은 문서 훼손을 막기 위해, [[{{MediaWiki:Policy-url}}|정책]]에 의해서만 이루어져야 합니다.
 차단 이유를 같이 적어주세요(예: 특정 문서 훼손).',
 'ipaddress'                   => 'IP 주소:',
-'ipadressorusername'          => 'IP 주소 또는 사용자 이름',
+'ipadressorusername'          => 'IP 주소 또는 계정 이름:',
 'ipbexpiry'                   => '기간:',
 'ipbreason'                   => '이유:',
 'ipbreasonotherlist'          => '다른 이유',
@@ -1419,7 +1420,7 @@
 ** 장난 편집
 ** 협박성 행동
 ** 다중 계정 악용
-** 잘못된 사용자 이름',
+** 잘못된 계정 이름',
 'ipbanononly'                 => '익명 사용자만 차단하기',
 'ipbcreateaccount'            => '계정 생성을 막기',
 'ipbemailban'                 => '이메일을 보내지 못하도록 막기',
@@ -1431,7 +1432,7 @@
 'ipbotherreason'              => '다른 이유/추가적인 이유:',
 'badipaddress'                => '잘못된 IP 주소',
 'blockipsuccesssub'           => '차단 완료',
-'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] 사용자가 차단되었습니다. 차단된 사용자 목록은 [[Special:Ipblocklist|여기]]에서 볼 수 있습니다.',
+'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] 사용자가 차단되었습니다. 차단된 사용자 목록은 [[Special:IPBlockList|여기]]에서 볼 수 있습니다.',
 'ipb-edit-dropdown'           => '차단 사유 고치기',
 'ipb-unblock-addr'            => '$1 차단 해제하기',
 'ipb-unblock'                 => '사용자/IP 주소 차단 해제하기',
@@ -1442,7 +1443,7 @@
 'ipusubmit'                   => '차단 해제',
 'unblocked'                   => '[[User:$1|$1]] 사용자 차단 해제됨',
 'unblocked-id'                => '차단 $1 해제됨',
-'ipblocklist'                 => '현재 차단 중인 IP 주소와 사용자 이름 목록',
+'ipblocklist'                 => '현재 차단 중인 IP 주소와 계정 이름 목록',
 'ipblocklist-submit'          => '찾기',
 'blocklistline'               => '$1, $2 사용자는 $3을 차단함 ($4)',
 'infiniteblock'               => '무기한',
@@ -1457,7 +1458,7 @@
 'autoblocker'                 => "당신의 IP 주소는 최근 ‘[[User:$1|$1]]’이(가) 사용하였기 때문에 자동으로 차단되었습니다. $1의 차단 이유는 다음과 같습니다: '''$2'''",
 'blocklogpage'                => '차단 기록',
 'blocklogentry'               => '[[$1]] 사용자를 $2 $3 차단함',
-'blocklogtext'                => '이 목록은 사용자 차단/차단 해제 기록입니다. 자동으로 차단된 IP 주소는 여기에 나오지 않습니다. [[Special:Ipblocklist|여기]]에서 현재 차단된 사용자 목록을 볼 수 있습니다.',
+'blocklogtext'                => '이 목록은 사용자 차단/차단 해제 기록입니다. 자동으로 차단된 IP 주소는 여기에 나오지 않습니다. [[Special:IPBlockList|여기]]에서 현재 차단된 사용자 목록을 볼 수 있습니다.',
 'unblocklogentry'             => '$1을 차단 해제했습니다.',
 'block-log-flags-anononly'    => 'IP만 막음',
 'block-log-flags-nocreate'    => '계정 생성 막음',
@@ -1488,7 +1489,7 @@
 'lockdbsuccesssub'    => '데이터베이스 잠김',
 'unlockdbsuccesssub'  => '데이터베이스 잠금 해제됨',
 'lockdbsuccesstext'   => '데이터베이스가 잠겼습니다.<br />
-관리가 끝나면 잊지 말고 [[Special:Unlockdb|잠금을 풀어]] 주세요.',
+관리가 끝나면 잊지 말고 [[Special:UnlockDB|잠금을 풀어]] 주세요.',
 'unlockdbsuccesstext' => '데이터베이스 잠금 상태가 해제되었습니다.',
 'lockfilenotwritable' => '데이터베이스 잠금 파일에 쓰기 권한이 없습니다. 데이터베이스를 잠그거나 잠금 해제하려면, 웹 서버에서 이 파일의 쓰기 권한을 설정해야 합니다.',
 'databasenotlocked'   => '데이터베이스가 잠겨 있지 않습니다.',
@@ -1514,8 +1515,6 @@
 * 아래의 선택을 해제하는 경우
 이 경우에는 문서를 직접 이동하거나 두 문서를 합쳐야 합니다.",
 'movearticle'             => '문서 이동하기',
-'movenologin'             => '로그인하지 않음',
-'movenologintext'         => '[[Special:Userlogin|로그인]]해야만 문서를 이동할 수 있습니다.',
 'movenotallowed'          => '{{SITENAME}}에서 문서를 이동할 권한이 없습니다.',
 'newtitle'                => '새 문서 이름',
 'move-watch'              => '이 문서 주시하기',
@@ -1527,6 +1526,8 @@
 'talkexists'              => "'''문서는 이동되었습니다. 하지만 딸린 토론 문서의 새 이름으로 된 문서가 이미 존재해서, 토론 문서는 이동하지 않았습니다. 직접 문서를 합쳐 주세요.'''",
 'movedto'                 => '새 이름',
 'movetalk'                => '딸린 토론도 함께 이동합니다.',
+'move-subpages'           => '하위 문서도 함께 이동합니다.',
+'move-talk-subpages'      => '토론 문서에 딸린 문서도 함께 이동합니다.',
 'movepage-page-exists'    => '이동할 수 없습니다. ‘$1’ 문서가 이미 존재합니다.',
 '1movedto2'               => '[[$1]]을(를) [[$2]](으)로 옮김',
 '1movedto2_redir'         => '[[$1]]을(를) [[$2]](으)로 옮기면서 넘겨주기를 덮어 씀',
@@ -1537,11 +1538,12 @@
 'delete_and_move'         => '삭제하고 이동',
 'delete_and_move_text'    => '== 삭제 필요 ==
 
-이동하려는 제목으로 된 문서 [[$1]]이(가) 이미 존재합니다. 삭제하고 이동할까요?',
+이동하려는 제목으로 된 문서 [[:$1]]이(가) 이미 존재합니다. 삭제하고 이동할까요?',
 'delete_and_move_confirm' => '네. 문서를 삭제합니다',
 'delete_and_move_reason'  => '문서를 이동하기 위해 삭제함',
 'selfmove'                => '이동하려는 제목이 원래 제목과 같습니다. 이동할 수 없습니다.',
 'immobile_namespace'      => '특수한 네임스페이스로는 이동할 수 없습니다.',
+'fix-double-redirects'    => '기존 이름을 가리키는 넘겨주기를 갱신',
 
 # Export
 'export'          => '문서 내보내기',
@@ -1723,7 +1725,7 @@
 'show-big-image'       => '최대 해상도',
 'show-big-image-thumb' => '<small>미리보기 크기: $1 × $2 픽셀</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '새 그림 파일 목록',
 'imagelisttext'         => '$1개의 파일이 $2 순으로 정렬되어 있습니다.',
 'showhidebots'          => '(봇을 $1)',
@@ -1762,7 +1764,7 @@
 
 # External editor support
 'edit-externally'      => '이 파일을 외부 프로그램을 사용해서 편집하기',
-'edit-externally-help' => '[http://meta.wikimedia.org/wiki/Help:External_editors 여기]에서 외부 편집기에 대한 정보를 얻을 수 있습니다.',
+'edit-externally-help' => '[http://www.mediawiki.org/wiki/Manual:External_editors 여기]에서 외부 편집기에 대한 정보를 얻을 수 있습니다.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '모두',
@@ -1820,7 +1822,7 @@
 'recreate'            => '새로 만들기',
 
 # HTML dump
-'redirectingto' => '[[$1]]로 넘어가는 중...',
+'redirectingto' => '[[:$1]]로 넘어가는 중...',
 
 # action=purge
 'confirm_purge'        => '문서의 캐시를 지울까요?
@@ -1895,7 +1897,7 @@
 'version-software-product'     => '제품',
 'version-software-version'     => '버전',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => '파일 주소',
 'filepath-page'    => '파일:',
 'filepath-submit'  => '주소',
Index: languages/messages/MessagesSi.php
===================================================================
--- languages/messages/MessagesSi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,14 +1,11 @@
 <?php
-/** Sinhalese (සිංහල)
+/** Sinhala (සිංහල)
  *
  * @ingroup Language
  * @file
  *
  * @author Asiri wiki
  * @author Chandana
- * @author Siebrand
- * @author Jon Harald Søby
- * @author Nike
  */
 
 $namespaceNames = array(
@@ -331,12 +328,12 @@
 'log'               => 'ලඝු',
 'log-search-submit' => 'යන්න',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'සියලු පිටු',
 'alphaindexline' => '$1 සි‍ට $2',
 'allpagessubmit' => 'යන්න',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'පෙන්වන්න',
 
 # Watchlist
@@ -372,7 +369,7 @@
 'tooltip-t-specialpages' => 'සියලු විශේෂ පිටු ලැයිස්තුව',
 'tooltip-save'           => 'ඔබගේ වෙනස් කිරීම් සුරකින්න',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'සොයන්න',
 
 # Metadata
Index: languages/messages/MessagesCy.php
===================================================================
--- languages/messages/MessagesCy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,7 +6,6 @@
  *
  * @author Lloffiwr
  * @author Thaf
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -393,7 +392,7 @@
 'nosuchspecialpage' => 'Y dudalen arbennig ddim yn bod',
 'nospecialpagetext' => "<big>'''Dyw'r wici ddim yn adnabod y dudalen arbennig y gofynnwyd amdani.'''</big>
 
-Mae rhestr o'r tudalennau arbennig dilys i'w gael [[Special:Specialpages|yma]].",
+Mae rhestr o'r tudalennau arbennig dilys i'w gael [[Special:SpecialPages|yma]].",
 
 # General errors
 'error'                => 'Gwall',
@@ -419,6 +418,7 @@
 'readonlytext'         => "Mae databas Wicipedia ar glo; nid yw'n bosib cadw erthyglau newydd na gwneud unrhyw newid arall. Mae'n debygol fod hyn er mwyn cynnal a chadw'r databas -- fe fydd ar gael eto cyn bo hir.
 
 Rhoddwyd y rheswm canlynol gan y gweinyddwr a'i glodd: $1",
+'missingarticle-diff'  => '(Gwahaniaeth: $1, $2)',
 'readonly_lag'         => "Mae'r databas wedi'i gloi'n awtomatig tra bod y gwas-weinyddion yn asio gyda'r prif weinydd",
 'internalerror'        => 'Gwall mewnol',
 'internalerror_info'   => 'Gwall mewnol: $1',
@@ -444,6 +444,8 @@
 'viewsource'           => 'Dangos côd y dudalen',
 'viewsourcefor'        => 'ar gyfer $1',
 'actionthrottled'      => 'Tagwyd y weithred',
+'actionthrottledtext'  => "Mae camau gwrth-sbam y wici yn cyfyngu ar ba mor aml y gall defnyddwyr ailwneud y weithred hon mewn byr amser, ac rydych chi wedi croesi'r terfyn.
+Ceisiwch eto ymhen rhai munudau.",
 'protectedpagetext'    => "Mae'r dudalen hon wedi'i diogelu rhag cael ei golygu.",
 'viewsourcetext'       => 'Cewch weld a chopïo côd y dudalen:',
 'protectedinterface'   => 'Testun ar gyfer rhyngwyneb y wici yw cynnwys y dudalen hon. Clowyd y dudalen er mwyn ei diogeli.',
@@ -459,11 +461,13 @@
 
 # Login and logout pages
 'logouttitle'                => "Allgofnodi'r defnyddiwr",
-'logouttext'                 => '<strong>Rydych wedi allgofnodi.</strong><br />
-Gallwch ddefnyddio {{SITENAME}} yn anhysbys, neu fe allwch fewngofnodi eto wrth yr un un enw neu wrth enw arall. Sylwer y bydd rhai tudalennau yn parhau i ymddangos fel ag yr oeddent pan oeddech wedi mewngofnodi hyd nes i chi glirio celc eich porwr.',
+'logouttext'                 => '<strong>Rydych wedi allgofnodi.</strong>
+
+Gallwch ddefnyddio {{SITENAME}} yn anhysbys, neu fe allwch [[Special:UserLogin|fewngofnodi eto]] wrth yr un un enw neu wrth enw arall. 
+Sylwer y bydd rhai tudalennau yn parhau i ymddangos fel ag yr oeddent pan oeddech wedi mewngofnodi hyd nes i chi glirio celc eich porwr.',
 'welcomecreation'            => "==Croeso, $1!==
 Mae eich cyfrif wedi'i greu. 
-Cofiwch osod eich dewisiadau er mwyn gwneud {{SITENAME}} yn fwy personol i chi.",
+Cofiwch osod y [[Special:Preferences|dewisiadau]] sydd fwyaf hwylus i chi ar {{SITENAME}}.",
 'loginpagetitle'             => 'Mewngofnodi',
 'yourname'                   => 'Eich enw defnyddiwr:',
 'yourpassword'               => 'Eich cyfrinair:',
@@ -474,7 +478,7 @@
 'loginproblem'               => '<b>Ni lwyddodd y mewngofnodi.</b><br />Ceisiwch eto!',
 'login'                      => 'Mewngofnodi',
 'nav-login-createaccount'    => 'Mewngofnodi',
-'loginprompt'                => "Mae'n rhaid galluogi cwcis er mwyn mewngofnodi i {{SITENAME}}.",
+'loginprompt'                => "Mae'n rhaid galluogi cwcis er mwyn [[Special:UserLogin|mewngofnodi i {{SITENAME}}]].",
 'userlogin'                  => 'Mewngofnodi',
 'logout'                     => 'Allgofnodi',
 'userlogout'                 => 'Allgofnodi',
@@ -619,13 +623,9 @@
 
 Cyfeirnod y bloc yw $5. Nodwch hwn wrth drafod y bloc.",
 'blockednoreason'                  => 'dim rheswm wedi ei roi',
-'blockedoriginalsource'            => "Dengosir tarddiad '''$1''' isod:",
+'blockedoriginalsource'            => "Dangosir côd '''$1''' isod:",
 'whitelistedittitle'               => 'Rhaid mewngofnodi i golygu',
 'whitelistedittext'                => 'Rhaid $1 i olygu tudalennau.',
-'whitelistreadtitle'               => 'Rhaid mewngofnodi cyn darllen',
-'whitelistreadtext'                => "Mae'n rhaid i chi [[Special:Userlogin|fewngofnodi]] er mwyn darllen tudalennau.",
-'whitelistacctitle'                => 'Ni chaniateir i chi greu cyfrif',
-'whitelistacctext'                 => "Er mwyn creu cyfrif ar {{SITENAME}}, mae'n rhaid i chi [[Special:Userlogin|fewngofnodi]] a meddu ar y galluoedd priodol.",
 'confirmedittitle'                 => 'Cadarnhad trwy e-bost cyn dechrau golygu.',
 'confirmedittext'                  => "Mae'n rhaid i chi gadarnhau eich cyfeiriad e-bost cyn y gallwch ddechrau golygu tudalennau.
 Gosodwch eich cyfeiriad e-bost drwy eich [[Special:Preferences|dewisiadau defnyddiwr]] ac yna'i gadarnhau, os gwelwch yn dda.",
@@ -640,7 +640,7 @@
 'newarticletext'                   => "Rydych chi wedi dilyn cysylltiad i dudalen sydd heb gael ei chreu eto.
 I greu'r dudalen, dechreuwch deipio yn y blwch isod (gweler y [[{{MediaWiki:Helppage}}|dudalen gymorth]] am fwy o wybodaeth).
 Os daethoch yma ar ddamwain, cliciwch botwm '''n&ocirc;l''' y porwr.",
-'anontalkpagetext'                 => "---- ''Dyma dudalen sgwrs defnyddiwr sydd heb greu cyfrif, neu nad yw'n defnyddio'i gyfrif. Mae'n rhaid i ni ddefnyddio'r cyfeiriad IP i'w (h)adnabod. Mae'n bosib fod sawl defnyddiwr yn rhannu'r un cyfeiriad IP. Os ydych chi'n ddefnyddiwr anhysbys ac yn teimlo'ch bod wedi derbyn sylwadau amherthnasol, [[Special:Userlogin|crëwch gyfrif neu mewngofnodwch]] i osgoi dryswch gyda defnyddwyr anhysbys yn y dyfodol.''",
+'anontalkpagetext'                 => "---- ''Dyma dudalen sgwrs defnyddiwr sydd heb greu cyfrif, neu nad yw'n defnyddio'i gyfrif. Mae'n rhaid i ni ddefnyddio'r cyfeiriad IP i'w (h)adnabod. Mae'n bosib fod sawl defnyddiwr yn rhannu'r un cyfeiriad IP. Os ydych chi'n ddefnyddiwr anhysbys ac yn teimlo'ch bod wedi derbyn sylwadau amherthnasol, [[Special:UserLogin/signup|crëwch gyfrif]] neu [[Special:UserLogin|mewngofnodwch]] i osgoi dryswch gyda defnyddwyr anhysbys o hyn ymlaen.''",
 'noarticletext'                    => "Mae'r dudalen hon yn wag. Gallwch [[Special:Search/{{PAGENAME}}|chwilio am y teitl hwn]] ar dudalennau eraill neu [{{fullurl:{{FULLPAGENAME}}|action=edit}} golygu'r dudalen].",
 'userpage-userdoesnotexist'        => 'Nid oes defnyddiwr a\'r enw "$1" yn bod. Gwnewch yn siwr eich bod am greu/golygu\'r dudalen hon.',
 'clearyourcache'                   => "'''Sylwer - Wedi i chi roi'r dudalen ar gadw, efallai y bydd angen mynd heibio celc eich porwr er mwyn gweld y newidiadau.''' 
@@ -652,12 +652,14 @@
 'note'                             => '<strong>Dalier sylw:</strong>',
 'previewnote'                      => "<strong>Cofiwch taw rhagolwg yw hwn; nid yw'r dudalen wedi ei chadw eto.</strong>",
 'previewconflict'                  => "Mae'r rhagolwg hwn yn dangos y testun yn yr ardal golygu uchaf, fel ag y byddai'n ymddangos petaech yn rhoi'r dudalen ar gadw.",
-'session_fail_preview'             => "<strong>Ymddiheurwn! Methwyd prosesu eich golygiad gan fod rhan o ddata'r sesiwn wedi'i golli. Ceisiwch eto. Os digwydd yr un peth eto, ceisiwch allgofnodi ac yna mewngofnodi eto.</strong>",
+'session_fail_preview'             => "<strong>Ymddiheurwn! Methwyd prosesu eich golygiad gan fod rhan o ddata'r sesiwn wedi'i golli. Ceisiwch eto. 
+Os digwydd yr un peth eto, ceisiwch [[Special:UserLogout|allgofnodi]] ac yna mewngofnodi eto.</strong>",
 'session_fail_preview_html'        => "<strong>Ymddiheurwn! Methwyd prosesu eich golygiad gan fod rhan o ddata'r sesiwn wedi'i golli.</strong>
 
 ''Oherwydd bod HTML amrwd ar waith ar {{SITENAME}}, cuddir y rhagolwg er mwyn gochel rhag ymosodiad JavaScript.''
 
-<strong>Os ydych am wneud golygiad dilys, ceisiwch eto. Os methwch unwaith eto, ceisiwch allgofnodi ac yna mewngofnodi unwaith eto.</strong>",
+<strong>Os ydych am wneud golygiad dilys, ceisiwch eto. 
+Os methwch unwaith eto, ceisiwch [[Special:UserLogout|allgofnodi]] ac yna mewngofnodi unwaith eto.</strong>",
 'token_suffix_mismatch'            => "<strong>Gwrthodwyd eich golygiad oherwydd bod eich gweinydd cleient wedi gwneud cawl o'r atalnodau yn y tocyn golygu.
 Gwrthodwyd y golygiad rhag i destun y dudalen gael ei lygru. 
 Weithiau fe ddigwydd hyn wrth ddefnyddio dirprwy-wasanaeth anhysbys gwallus yn seiliedig ar y we.</strong>",
@@ -699,7 +701,7 @@
 'template-semiprotected'           => '(lled-diogelwyd)',
 'hiddencategories'                 => "Mae'r dudalen hon yn aelod o $1 {{PLURAL:$1|categori|categori|gategori|chategori|chategori|categori}} cuddiedig:",
 'nocreatetitle'                    => 'Cyfyngwyd ar greu tudalennau',
-'nocreatetext'                     => "Mae'r safle hwn wedi cyfyngu'r gallu i greu tudalennau newydd. Gallwch olygu tudalen sydd eisoes yn bodoli, neu [[Special:Userlogin|fewngofnodi, neu greu cyfrif]].",
+'nocreatetext'                     => "Mae'r safle hwn wedi cyfyngu'r gallu i greu tudalennau newydd. Gallwch olygu tudalen sydd eisoes yn bodoli, neu [[Special:UserLogin|fewngofnodi, neu greu cyfrif]].",
 'nocreate-loggedin'                => "Nid yw'r gallu gennych i greu tudalennau ar {{SITENAME}}.",
 'permissionserrors'                => 'Gwallau Caniatâd',
 'permissionserrorstext'            => "Nid yw'r gallu ganddoch i weithredu yn yr achos yma, am y {{PLURAL:$1|rheswm|rheswm|rhesymau|rhesymau|rhesymau|rhesymau}} canlynol:",
@@ -710,13 +712,13 @@
 Dyma lòg dileu'r dudalen, er gwybodaeth:",
 
 # Parser/template warnings
-'post-expand-template-inclusion-category' => 'Tudalennau lle mae maint cynnwys templed wedi ei ragori',
+'post-expand-template-inclusion-category' => "Tudalennau a phatrymlun ynddynt sy'n fwy na chyfyngiad y meddalwedd",
 
 # "Undo" feature
 'undo-success' => "Gellir dadwneud y golygiad. Byddwch gystal â gwirio'r gymhariaeth isod i sicrhau mai dyma sydd arnoch eisiau gwneud, ac yna rhowch y newidiadau ar gadw i gwblhau'r gwaith o ddadwneud y golygiad.",
 'undo-failure' => 'Methwyd a dadwneud y golygiad oherwydd gwrthdaro â golygiadau cyfamserol.',
 'undo-norev'   => "Ni ellid dadwneud y golygiad oherwydd nad yw'n bod neu iddo gael ei ddileu.",
-'undo-summary' => 'Dadwneud y golygiad $1 gan [[Special:Contributions/$2|$2]] ([[User talk:$2|Sgwrs]])',
+'undo-summary' => 'Dadwneud y golygiad $1 gan [[Special:Contributions/$2|$2]] ([[User talk:$2|Sgwrs]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Yn methu creu cyfrif',
@@ -762,9 +764,9 @@
 Tynnwyd y dudalen hon o\'r archif cyhoeddus.
 Hwyrach bod manylion pellach ar y [{{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}} lòg dileu].</div>',
 'rev-deleted-text-view'       => "<div class=\"mw-warning plainlinks\">
-Mae'r diwygiad hon o'r dudalen wedi cael ei ddiddymu o'r archifau cyhoeddus.
+Mae'r diwygiad hwn o'r dudalen wedi cael ei ddiddymu o'r archifau cyhoeddus.
 Fel gweinyddwr ar {{SITENAME}} gallwch ei weld;
-gall fod manylion yn y [lòg dileu {{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}}].</div>",
+gall fod manylion yn y [{{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}} lòg dileu].</div>",
 'rev-delundel'                => 'dangos/cuddio',
 'revisiondelete'              => 'Dileu/dad-ddileu diwygiadau',
 'revdelete-selected'          => 'Y {{PLURAL:$2|golygiad|golygiad|golygiadau|golygiadau|golygiadau|golygiadau}} dewisedig o [[:$1]]:',
@@ -783,6 +785,7 @@
 'logdelete-success'           => "'''Llwyddwyd i guddio'r digwyddiad.'''",
 'revdel-restore'              => 'Newid gwelededd',
 'pagehist'                    => 'Hanes y dudalen',
+'deletedhist'                 => 'Hanes dilëedig',
 'revdelete-content'           => 'cynnwys',
 'revdelete-summary'           => 'crynodeb golygu',
 'revdelete-uname'             => 'yr enw defnyddiwr ar gyfer',
@@ -795,7 +798,7 @@
 # Suppression log
 'suppressionlog'     => 'Lòg cuddio',
 'suppressionlogtext' => "Dyma restr y dileuon a'r blociau lle y cuddiwyd cynnwys rhag y gweinyddwyr.
-Gallwch weld rhestr y gwaharddiadau a'r blociau gweithredol ar y [[Special:Ipblocklist|rhestr blociau IP]].",
+Gallwch weld rhestr y gwaharddiadau a'r blociau gweithredol ar y [[Special:IPBlockList|rhestr blociau IP]].",
 
 # History merging
 'mergehistory'                     => 'Cyfuno hanesion y tudalennau',
@@ -832,7 +835,7 @@
 # Search results
 'searchresults'             => "Canlyniadau'r chwiliad",
 'searchresulttext'          => 'Am fwy o wybodaeth am chwilio {{SITENAME}}, gwelwch [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "Chwiliwyd am '''[[:$1]]'''",
+'searchsubtitle'            => 'Chwiliwyd am \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|pob tudalen yn dechrau gyda "$1"]] | [[Special:WhatLinksHere/$1|pob tudalen sy\'n cysylltu â "$1"]])',
 'searchsubtitleinvalid'     => "Chwiliwyd am '''$1'''",
 'noexactmatch'              => "'''Nid oes tudalen a'r enw '$1' yn bod.''' Gallwch [[:$1|greu'r dudalen]].",
 'noexactmatch-nocreate'     => "'''Does dim tudalen a'r enw '$1' yn bod.'''",
@@ -875,7 +878,7 @@
 'mypreferences'            => 'fy newisiadau',
 'prefs-edits'              => 'Nifer y golygiadau:',
 'prefsnologin'             => 'Nid ydych wedi mewngofnodi',
-'prefsnologintext'         => 'Rhaid i chi [[Special:Userlogin|fewngofnodi]] er mwyn gosod eich dewisiadau defnyddiwr.',
+'prefsnologintext'         => 'Rhaid i chi [[Special:UserLogin|fewngofnodi]] er mwyn gosod eich dewisiadau defnyddiwr.',
 'prefsreset'               => "Mae'r dewisiadau wedi cael eu hail-osod o'r storfa.",
 'qbsettings'               => 'Panel llywio',
 'qbsettings-none'          => 'Dim',
@@ -927,6 +930,8 @@
 'servertime'               => 'Amser y gweinydd yw',
 'guesstimezone'            => 'Llenwi oddi wrth y porwr',
 'allowemail'               => 'Galluogi e-bost oddi wrth ddefnyddwyr eraill',
+'prefs-searchoptions'      => 'Dewisiadau chwilio',
+'prefs-namespaces'         => 'Parthau',
 'defaultns'                => 'Chwiliwch y parthau rhagosodedig isod:',
 'default'                  => 'rhagosodyn',
 'files'                    => 'Ffeiliau',
@@ -947,7 +952,7 @@
 'userrights-reason'           => 'Y rheswm dros y newid:',
 'userrights-no-interwiki'     => "Nid yw'r gallu ganddoch i newid galluoedd defnyddwyr ar wicïau eraill.",
 'userrights-nodatabase'       => "Nid yw'r bas data $1 yn bod neu nid yw'n un lleol.",
-'userrights-nologin'          => 'Rhaid i chi [[Special:Userlogin|fewngofnodi]] ar gyfrif gweinyddwr er mwyn pennu galluoedd defnyddwyr.',
+'userrights-nologin'          => 'Rhaid i chi [[Special:UserLogin|fewngofnodi]] ar gyfrif gweinyddwr er mwyn pennu galluoedd defnyddwyr.',
 'userrights-notallowed'       => "Nid yw'r gallu i bennu galluoedd defnyddwyr ynghlwm wrth eich cyfrif defnyddiwr.",
 'userrights-changeable-col'   => 'Grwpiau y gallwch eu newid',
 'userrights-unchangeable-col' => 'Grwpiau na allwch eu newid',
@@ -1006,7 +1011,7 @@
 'recentchanges'                     => 'Newidiadau diweddar',
 'recentchangestext'                 => "Dilynwch y newidiadau diweddaraf i'r wici ar y dudalen hon.",
 'recentchanges-feed-description'    => "Dilynwch y newidiadau diweddaraf i'r wici gyda'r porthiant hwn.",
-'rcnote'                            => "Isod mae'r '''$1''' newid diweddaraf yn ystod y '''$2''' {{PLURAL:$2|diwrnod|diwrnod|ddiwrnod|diwrnod|diwrnod|diwrnod}} diwethaf, hyd at $3.",
+'rcnote'                            => "Isod mae'r '''$1''' newid diweddaraf yn ystod y '''$2''' {{PLURAL:$2|diwrnod|diwrnod|ddiwrnod|diwrnod|diwrnod|diwrnod}} diwethaf, hyd at $5, $4.",
 'rcnotefrom'                        => "Isod mae pob newidiad ers '''$2''' (hyd at '''$1''' ohonynt).",
 'rclistfrom'                        => 'Dangos newidiadau newydd gan ddechrau o $1',
 'rcshowhideminor'                   => '$1 golygiadau bychain',
@@ -1042,22 +1047,23 @@
 'reupload'                    => 'Ail-uwchlwytho',
 'reuploaddesc'                => "Dileu'r uwchlwytho a dychwelyd i'r ffurflen uwchlwytho",
 'uploadnologin'               => 'Nid ydych wedi mewngofnodi',
-'uploadnologintext'           => "Mae'n rhaid i chi [[Special:Userlogin|fewngofnodi]] er mwyn uwchlwytho ffeiliau.",
+'uploadnologintext'           => "Mae'n rhaid i chi [[Special:UserLogin|fewngofnodi]] er mwyn uwchlwytho ffeiliau.",
 'upload_directory_read_only'  => "Ni all y gweinydd ysgrifennu i'r cyfeiriadur uwchlwytho ($1).",
 'uploaderror'                 => "Gwall tra'n uwchlwytho ffeil",
 'uploadtext'                  => "Defnyddiwch y ffurflen isod i uwchlwytho ffeiliau.
-I weld a chwilio am ffeiliau sydd eisoes wedi eu huwchlwytho ewch at y [[Special:Imagelist|rhestr o'r ffeiliau sydd wedi eu huwchlwytho]]. I weld cofnodion uwchlwytho a dileu ffeiliau ewch at y [[Special:Log/upload|lòg uwchlwytho]].
+I weld a chwilio am ffeiliau sydd eisoes wedi eu huwchlwytho ewch at y [[Special:ImageList|rhestr o'r ffeiliau sydd wedi eu huwchlwytho]]. I weld cofnodion uwchlwytho a dileu ffeiliau ewch at y [[Special:Log/upload|lòg uwchlwytho]].
 
-I osod ffeil mewn tudalen defnyddiwch gyswllt wici a fydd yn arwain yn syth at y ffeil, fel a ganlyn:
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Ffeil.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Ffeil.png|testun amgen]]</nowiki>''' neu
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Ffeil.ogg]]</nowiki>'''.",
+I osod ffeil mewn tudalen defnyddiwch gyswllt wici, ar un o'r ffurfiau canlynol:
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Ffeil.jpg]]</nowiki><tt>''', er mwyn defnyddio fersiwn llawn y ffeil
+*'''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Ffeil.png|200px|bawd|chwith|testun amgen]]</nowiki><tt>''' a wnaiff dangos llun 200 picsel o led mewn bocs ar yr ochr chwith a'r testun 'testun amgen' wrth ei odre
+*'''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Ffeil.ogg]]</nowiki><tt>''' a fydd yn arwain yn syth at y ffeil heb arddangos y ffeil.",
 'upload-permitted'            => 'Mathau o ffeiliau a ganiateir: $1',
 'upload-preferred'            => 'Mathau ffeil dewisol: $1.',
 'upload-prohibited'           => 'Mathau o ffeiliau a waherddir: $1.',
 'uploadlog'                   => 'lòg uwchlwytho',
 'uploadlogpage'               => 'Lòg uwchlwytho',
-'uploadlogpagetext'           => "Isod mae rhestr o'r uwchlwythiadau ffeiliau <nowiki>diweddaraf</nowiki>.",
+'uploadlogpagetext'           => "Isod mae rhestr o'r uwchlwythiadau ffeiliau <nowiki>diweddaraf</nowiki>.
+Gweler y [[Special:NewImages|galeri o ffeiliau newydd]] i fwrw golwg drostynt.",
 'filename'                    => "Enw'r ffeil",
 'filedesc'                    => 'Crynodeb',
 'fileuploadsummary'           => 'Crynodeb:',
@@ -1070,8 +1076,8 @@
 'illegalfilename'             => 'Mae\'r enw ffeil "$1" yn cynnwys nodau sydd wedi\'u gwahardd mewn teitlau tudalennau. Ail-enwch y ffeil ac uwchlwythwch hi eto os gwelwch yn dda.',
 'badfilename'                 => 'Mae enw\'r ffeil wedi\'i newid i "$1".',
 'filetype-badmime'            => "Ni chaniateir uwchlwytho ffeiliau o'r math MIME '$1'.",
-'filetype-unwanted-type'      => "Mae'r math '''\".\$1\"''' o ffeil yn anghymeradwy.  Mae'n well defnyddio ffeil o'r math \$2.",
-'filetype-banned-type'        => "Ni chaniateir ffeiliau o'r math '''\".\$1\"'''.  \$2 yw'r mathau o ffeiliau a ganiateir.",
+'filetype-unwanted-type'      => "Mae'r math '''\".\$1\"''' o ffeil yn anghymeradwy.  Mae'n well defnyddio ffeil {{PLURAL:\$3|o'r math|o'r math|o'r mathau|o'r mathau|o'r mathau|o'r mathau}} \$2.",
+'filetype-banned-type'        => "Ni chaniateir ffeiliau o'r math '''\".\$1\"'''.  \$2 yw'r {{PLURAL:\$3|math|math|mathau|mathau|mathau|mathau}} o ffeil a ganiateir.",
 'filetype-missing'            => "Nid oes gan y ffeil hon estyniad (megis '.jpg').",
 'large-file'                  => "Argymhellir na ddylai ffeil fod yn fwy na $1. Mae'r ffeil hwn yn $2 o faint.",
 'largefileserver'             => "Mae'r ffeil yn fwy na'r hyn mae'r gweinydd yn ei ganiatau.",
@@ -1113,11 +1119,11 @@
 'upload-proto-error-text' => "Rhaid cael URLs yn dechrau gyda <code>http://</code> neu <code>ftp://</code> wrth uwchlwytho'n bell.",
 'upload-file-error'       => 'Gwall mewnol',
 'upload-file-error-text'  => 'Cafwyd gwall mewnol wrth geisio creu ffeil dros dro ar y gweinydd.
-Byddwch gystal â chysylltu â gweinyddwr y system.',
+Byddwch gystal â chysylltu â [[Special:ListUsers/sysop|gweinyddwr]].',
 'upload-misc-error'       => 'Gwall uwchlwytho anhysbys',
 'upload-misc-error-text'  => "Cafwyd gwall anghyfarwydd yn ystod yr uwchlwytho.
 Sicrhewch bod yr URL yn ddilys ac yn hygyrch a cheisiwch eto.
-Os yw'r broblem yn parhau, cysylltwch â gweinyddwr y system.",
+Os yw'r broblem yn parhau, cysylltwch â [[Special:ListUsers/sysop|gweinyddwr]].",
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Wedi methu cyrraedd yr URL',
@@ -1133,7 +1139,7 @@
 'upload_source_url'  => " (URL dilys, ar gael i'r cyhoedd)",
 'upload_source_file' => ' (ffeil ar eich cyfrifiadur)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => "Chwilio am enw'r ddelwedd:",
 'imgfile'               => 'ffeil',
 'imagelist'             => "Rhestr o'r holl ffeiliau",
@@ -1172,11 +1178,11 @@
 # File reversion
 'filerevert'                => 'Gwrthdroi $1',
 'filerevert-legend'         => "Gwrthdroi'r ffeil",
-'filerevert-intro'          => '<span class="plainlinks">Rydych yn gwrthdroi \'\'\'[[Media:$1|$1]]\'\'\' i\'r [fersiwn $4 fel ag yr oedd ar $3, $2].</span>',
+'filerevert-intro'          => "Rydych yn gwrthdroi '''[[Media:$1|$1]]''' i'r [fersiwn $4 fel ag yr oedd ar $3, $2].",
 'filerevert-comment'        => 'Sylw:',
 'filerevert-defaultcomment' => 'Wedi adfer fersiwn $2, $1',
 'filerevert-submit'         => 'Gwrthdroi',
-'filerevert-success'        => '<span class="plainlinks">Mae \'\'\'[[Media:$1|$1]]\'\'\' wedi cael ei wrthdroi i\'r [fersiwn $4 fel ag yr oedd ar $3, $2].</span>',
+'filerevert-success'        => "Mae '''[[Media:$1|$1]]''' wedi cael ei wrthdroi i'r [fersiwn $4 fel ag yr oedd ar $3, $2].",
 'filerevert-badversion'     => "Nid oes fersiwn lleol cynt o'r ffeil hwn gyda'r amsernod a nodwyd.",
 
 # File deletion
@@ -1232,7 +1238,7 @@
 Ar gyfartaledd felly, bu '''\$5''' golygiad i bob tudalen, a '''\$6''' ymweliad â thudalen ar gyfer pob golygiad.
 
 Hyd y [http://www.mediawiki.org/wiki/Manual:Job_queue rhes dasgau] yw '''\$7'''.",
-'userstatstext'          => "Mae '''$1''' {{PLURAL:$1|[[Special:Listusers|defnyddiwr]]|[[Special:Listusers|defnyddiwr]]|[[Special:Listusers|ddefnyddiwr]]|[[Special:Listusers|defnyddiwr]]|[[Special:Listusers|defnyddiwr]]|[[Special:Listusers|defnyddiwr]]}} ar y cofrestr defnyddwyr.
+'userstatstext'          => "Mae '''$1''' {{PLURAL:$1|[[Special:ListUsers|defnyddiwr]]|[[Special:ListUsers|defnyddiwr]]|[[Special:ListUsers|ddefnyddiwr]]|[[Special:ListUsers|defnyddiwr]]|[[Special:ListUsers|defnyddiwr]]|[[Special:ListUsers|defnyddiwr]]}} ar y cofrestr defnyddwyr.
 Mae gan '''$2''' (neu '''$4%''') ohonynt alluoedd $5.",
 'statistics-mostpopular' => "Tudalennau sy'n derbyn ymweliad amlaf",
 
@@ -1324,7 +1330,7 @@
 'logempty'             => 'Does dim eitemau yn cyfateb yn y lòg.',
 'log-title-wildcard'   => "Chwilio am deitlau'n dechrau gyda'r geiriau hyn",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Pob tudalen',
 'alphaindexline'    => '$1 i $2',
 'nextpage'          => 'Y bloc nesaf gan ddechrau gyda ($1)',
@@ -1347,26 +1353,26 @@
 'special-categories-sort-count' => 'trefnu yn ôl nifer',
 'special-categories-sort-abc'   => 'trefnu yn ôl yr wyddor',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Dangos y defnyddwyr gan ddechrau â:',
 'listusers-submit'   => 'Dangos',
 'listusers-noresult' => "Dim defnyddiwr i'w gael.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'         => 'Galluoedd grwpiau defnyddwyr',
-'listgrouprights-summary' => "Dyma restr o'r grwpiau defnyddwyr sydd i'w cael ar y wici hon, ynghyd â galluoedd aelodau'r gwahanol grwpiau. Cewch wybodaeth pellach am y wahanol galluoedd ar [[{{MediaWiki:Listgrouprights-helppage}}]].",
+'listgrouprights-summary' => "Dyma restr o'r grwpiau defnyddwyr sydd i'w cael ar y wici hon, ynghyd â galluoedd aelodau'r gwahanol grwpiau. Cewch wybodaeth pellach am y gwahanol alluoedd ar y [[{{MediaWiki:Listgrouprights-helppage}}|dudalen gymorth]].",
 'listgrouprights-group'   => 'Grŵp',
 'listgrouprights-rights'  => 'Galluoedd',
 'listgrouprights-members' => '(rhestr aelodau)',
 
 # E-mail user
 'mailnologin'     => "Does dim cyfeiriad i'w anfon iddo",
-'mailnologintext' => 'Rhaid eich bod wedi [[Special:Userlogin|mewngofnodi]]
+'mailnologintext' => 'Rhaid eich bod wedi [[Special:UserLogin|mewngofnodi]]
 a bod cyfeiriad e-bost dilys yn eich [[Special:Preferences|dewisiadau]]
 er mwyn medru anfon e-bost at ddefnyddwyr eraill.',
 'emailuser'       => 'Anfon e-bost at y defnyddiwr hwn',
 'emailpage'       => 'Anfon e-bost at ddefnyddiwr',
-'emailpagetext'   => 'Os yw\'r defnyddiwr hwn wedi gosod cyfeiriad e-bost yn ei ddewisiadau, gellir anfon un neges ato ar y ffurflen isod. Bydd y cyfeiriad e-bost a osodoch yn eich dewisiadau chithau yn ymddangos ym maes "Oddi wrth" yr e-bost, fel bod y defnyddiwr arall yn gallu ei ateb.',
+'emailpagetext'   => 'Os yw\'r defnyddiwr hwn wedi gosod cyfeiriad e-bost dilys yn ei ddewisiadau, gellir anfon un neges ato ar y ffurflen isod. Bydd y cyfeiriad e-bost a osodoch yn eich [[Special:Preferences|dewisiadau chithau]] yn ymddangos ym maes "Oddi wrth" yr e-bost, fel bod y defnyddiwr arall yn gallu ei ateb.',
 'usermailererror' => 'Dychwelwyd gwall gan y rhaglen e-bost:',
 'defemailsubject' => 'E-bost {{SITENAME}}',
 'noemailtitle'    => 'Dim cyfeiriad e-bost',
@@ -1388,14 +1394,14 @@
 'nowatchlist'          => "Mae eich rhestr gwylio'n wag.",
 'watchlistanontext'    => "Rhaid $1 er mwyn gweld neu ddiwygio'ch rhestr gwylio.",
 'watchnologin'         => 'Nid ydych wedi mewngofnodi',
-'watchnologintext'     => "Mae'n rhaid i chi [[Special:Userlogin|fewngofnodi]] er mwyn newid eich rhestr gwylio.",
+'watchnologintext'     => "Mae'n rhaid i chi [[Special:UserLogin|fewngofnodi]] er mwyn newid eich rhestr gwylio.",
 'addedwatch'           => 'Rhoddwyd ar eich rhestr gwylio',
 'addedwatchtext'       => "Mae'r dudalen \"[[:\$1|\$1]]\" wedi cael ei hychwanegu at eich [[Special:Watchlist|rhestr gwylio]].
-Pan fydd y dudalen hon, neu ei thudalen sgwrs, yn newid, fe fyddant yn ymddangos ar eich rhestr gwylio ac hefyd '''yn gryf''' ar restr y [[Special:Recentchanges|newidiadau diweddar]], fel ei bod yn haws eu gweld.
+Pan fydd y dudalen hon, neu ei thudalen sgwrs, yn newid, fe fyddant yn ymddangos ar eich rhestr gwylio ac hefyd '''yn gryf''' ar restr y [[Special:RecentChanges|newidiadau diweddar]], fel ei bod yn haws eu gweld.
 
 Os ydych am ddiddymu'r dudalen o'r rhestr gwylio, cliciwch ar \"Stopio gwylio\" yn y bar ar frig y dudalen.",
 'removedwatch'         => 'Tynnwyd oddi ar eich rhestr gwylio',
-'removedwatchtext'     => 'Mae\'r dudalen "[[:$1]]" wedi\'i thynnu oddi ar eich rhestr gwylio.',
+'removedwatchtext'     => 'Mae\'r dudalen "[[:$1]]" wedi\'i thynnu oddi ar [[Special:Watchlist|eich rhestr gwylio]].',
 'watch'                => 'Gwylio',
 'watchthispage'        => 'Gwylier y dudalen hon',
 'unwatch'              => 'Stopio gwylio',
@@ -1490,10 +1496,10 @@
 'rollbacklink'                => 'gwrthdroi',
 'rollbackfailed'              => 'Methodd y gwrthdroi',
 'cantrollback'                => "Wedi methu gwrthdroi'r golygiad; y cyfrannwr diwethaf oedd unig awdur y dudalen hon.",
-'alreadyrolled'               => "Nid yw'n bosib dadwneud y golygiad diwethaf i'r dudalen [[:$1|$1]] gan [[User:$2|$2]] ([[User talk:$2|Sgwrs]]);
+'alreadyrolled'               => "Nid yw'n bosib dadwneud y golygiad diwethaf i'r dudalen [[:$1|$1]] gan [[User:$2|$2]] ([[User talk:$2|Sgwrs]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
 mae rhywun arall eisoes wedi dadwneud y golygiad neu wedi golygu'r dudalen.
 
-[[User:$3|$3]] ([[User talk:$3|Sgwrs]]) a wnaeth y golygiad diwethaf.",
+[[User:$3|$3]] ([[User talk:$3|Sgwrs]] | [[Special:Contributions/$3|{{int:contribslink}}]]) a wnaeth y golygiad diwethaf.",
 'editcomment'                 => 'Crynodeb y golygiad oedd: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Wedi gwrthdroi golygiadau gan [[Special:Contributions/$2|$2]] ([[User talk:$2|Sgwrs]]); wedi adfer y golygiad diweddaraf gan [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => "Gwrthdrowyd y golygiadau gan $1; 
@@ -1550,6 +1556,7 @@
 'viewdeletedpage'              => "Gweld tudalennau sydd wedi'u dileu",
 'undeletepagetext'             => "Mae'r tudalennau isod wedi cael eu dileu ond mae cofnod ohonynt o hyd yn yr archif, felly mae'n bosibl eu hadfer. 
 Gall yr archif gael ei glanhau o dro i dro.",
+'undelete-fieldset-title'      => 'Dewis ac adfer diwygiadau',
 'undeleteextrahelp'            => "I adfer y dudalen gyfan, gadewch pob blwch ticio'n wag a phwyswch y botwm '''''Adfer'''''. I adfer rhai diwygiadau'n unig, ticiwch y blychau ar gyfer y diwygiadau dewisedig, a phwyswch ar '''''Adfer'''''. Os y pwyswch ar '''''Ailosod''''' bydd y blwch sylwadau a phob blwch ticio yn gwacáu.",
 'undeleterevisions'            => 'Gosodwyd $1 {{PLURAL:$1|fersiwn|fersiwn|fersiwn|fersiwn|fersiwn|fersiwn}} yn yr archif',
 'undeletehistory'              => "Os adferwch y dudalen, fe fydd yr hanes gyfan yn cael ei atgyfodi hefyd. 
@@ -1658,7 +1665,7 @@
 'badipaddress'                => 'Cyfeiriad IP annilys.',
 'blockipsuccesssub'           => 'Y blocio wedi llwyddo',
 'blockipsuccesstext'          => 'Mae cyfeiriad IP [[Special:Contributions/$1|$1]] wedi cael ei flocio.
-<br />Gwelwch [[Special:Ipblocklist|restr y blociau IP]] er mwyn arolygu blociau.',
+<br />Gwelwch [[Special:IPBlockList|restr y blociau IP]] er mwyn arolygu blociau.',
 'ipb-edit-dropdown'           => "Golygu'r rhesymau dros flocio",
 'ipb-unblock-addr'            => 'Datflocio $1',
 'ipb-unblock'                 => 'Datflocio enw defnyddiwr neu cyfeiriad IP',
@@ -1687,7 +1694,7 @@
 'autoblocker'                 => 'Rydych chi wedi cael eich blocio yn awtomatig gan eich bod chi\'n rhannu cyfeiriad IP gyda "[[User:$1|$1]]". Dyma\'r rheswm a roddwyd dros flocio $1: "$2".',
 'blocklogpage'                => 'Lòg blociau',
 'blocklogentry'               => 'wedi blocio "[[$1]]" am gyfnod o $2 $3',
-'blocklogtext'                => "Dyma lòg o'r holl weithredoedd blocio a datflocio. Nid yw'r cyfeiriadau IP sydd wedi cael eu blocio'n awtomatig ar y rhestr. Gweler [[Special:Ipblocklist|rhestr y blociau IP]] am restr y blociau a'r gwaharddiadau sydd yn weithredol ar hyn o bryd.",
+'blocklogtext'                => "Dyma lòg o'r holl weithredoedd blocio a datflocio. Nid yw'r cyfeiriadau IP sydd wedi cael eu blocio'n awtomatig ar y rhestr. Gweler [[Special:IPBlockList|rhestr y blociau IP]] am restr y blociau a'r gwaharddiadau sydd yn weithredol ar hyn o bryd.",
 'unblocklogentry'             => 'wedi dadflocio $1',
 'block-log-flags-anononly'    => 'defnyddwyr anhysbys yn unig',
 'block-log-flags-nocreate'    => 'analluogwyd creu cyfrif',
@@ -1719,7 +1726,7 @@
 'lockdbsuccesssub'    => "Wedi llwyddo cloi'r databas",
 'unlockdbsuccesssub'  => "Databas wedi'i ddatgloi",
 'lockdbsuccesstext'   => "Mae'r databas wedi'i gloi.<br />
-Cofiwch [[Special:Unlockdb|ddatgloi'r]] databas pan fydd y gwaith cynnal ar ben.",
+Cofiwch [[Special:UnlockDB|ddatgloi'r]] databas pan fydd y gwaith cynnal ar ben.",
 'unlockdbsuccesstext' => "Mae'r databas wedi'i ddatgloi.",
 
 # Move page
@@ -1727,7 +1734,7 @@
 'move-page-legend'        => 'Symud tudalen',
 'movepagetext'            => "Wrth ddefnyddio'r ffurflen isod byddwch yn ail-enwi tudalen, gan symud ei hanes gyfan i'r enw newydd.
 Bydd yr hen deitl yn troi'n dudalen ail-gyfeirio i'r teitl newydd.
-Ni fydd cysylltiadau i'r hen deitl yn newid; rhaid cywiro ail-gyfeiriadau dwbl ac ail-gyfeiriadau tor eich hunan.
+Ni fydd cysylltiadau i'r hen deitl yn newid; rhaid cywiro [[Special:DoubleRedirects|ail-gyfeiriadau dwbl]] ac [[Special:BrokenRedirects|ail-gyfeiriadau tor]] eich hunan.
 Eich cyfrifoldeb chi yw sicrhau bod cysylltiadau wici'n dal i arwain at y man iawn!
 
 Sylwch '''na fydd''' y dudalen yn symud os oes yna dudalen o'r enw newydd yn bodoli'n barod ar y databas (heblaw ei bod hi'n wag neu'n ail-gyfeiriad heb unrhyw hanes golygu).
@@ -1743,8 +1750,6 @@
 
 Os felly, gallwch symud y dudalen sgwrs neu ei gyfuno ar ôl symud y dudalen ei hun.",
 'movearticle'             => 'Symud y dudalen:',
-'movenologin'             => 'Nid ydych wedi mewngofnodi',
-'movenologintext'         => "Mae'n rhaid bod yn ddefnyddiwr cofrestredig a'ch bod wedi [[Special:Userlogin|mewngofnodi]] cyn medru symud tudalen.",
 'movenotallowed'          => 'Nid oes caniatâd gennych i symud tudalennau ar {{SITENAME}}.',
 'newtitle'                => "I'r teitl newydd:",
 'move-watch'              => 'Gwylier y dudalen hon',
@@ -1768,7 +1773,7 @@
 'delete_and_move'         => 'Dileu a symud',
 'delete_and_move_text'    => "==Angen dileu==
 
-Mae'r erthygl \"[[\$1]]\" yn bodoli'n barod. Ydych chi am ddileu'r erthygl er mwyn cwblhau'r symudiad?",
+Mae'r erthygl \"[[:\$1]]\" yn bodoli'n barod. Ydych chi am ddileu'r erthygl er mwyn cwblhau'r symudiad?",
 'delete_and_move_confirm' => "Ie, dileu'r dudalen",
 'delete_and_move_reason'  => "Wedi'i dileu er mwyn symud tudalen arall yn ei lle.",
 'selfmove'                => "Mae'r teitlau hen a newydd yn union yr un peth;
@@ -1967,7 +1972,7 @@
 'show-big-image'       => 'Maint llawn',
 'show-big-image-thumb' => '<small>Maint y rhagolwg: $1 × $2 picsel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Oriel y ffeiliau newydd',
 'imagelisttext'         => "Isod mae rhestr {{PLURAL:$1|gwag o ffeiliau|o '''$1''' ffeil|o '''$1''' ffeil wedi'u trefnu $2|o '''$1''' ffeil wedi'u trefnu $2|o '''$1''' o ffeiliau wedi'u trefnu $2|o '''$1''' o ffeiliau wedi'u trefnu $2|}}.",
 'showhidebots'          => '($1 botiau)',
@@ -2047,11 +2052,11 @@
 'exif-shutterspeedvalue'           => 'Cyflymder y caead',
 'exif-aperturevalue'               => 'Agorfa',
 'exif-brightnessvalue'             => 'Disgleirdeb',
-'exif-exposurebiasvalue'           => 'Bias dinoethiad',
+'exif-exposurebiasvalue'           => 'Bias dinoethi',
 'exif-maxaperturevalue'            => "Maint mwyaf agorfa'r glan",
 'exif-subjectdistance'             => 'Pellter y goddrych',
 'exif-meteringmode'                => 'Modd mesur goleuni',
-'exif-lightsource'                 => 'Tarddiad golau',
+'exif-lightsource'                 => 'Ffynhonell goleuni',
 'exif-flash'                       => 'Fflach',
 'exif-focallength'                 => 'Hyd ffocal y lens',
 'exif-subjectarea'                 => 'Maint a lleoliad y goddrych',
@@ -2062,14 +2067,14 @@
 'exif-filesource'                  => 'Ffynhonnell y ffeil',
 'exif-scenetype'                   => 'Math o olygfa',
 'exif-cfapattern'                  => 'Patrwm CFA',
-'exif-exposuremode'                => 'Dull dinoethiad',
+'exif-exposuremode'                => 'Modd dinoethi',
 'exif-whitebalance'                => 'Cydbwysedd Gwyn',
 'exif-contrast'                    => 'Cyferbyniad',
 'exif-saturation'                  => 'Dirlawnder',
 'exif-sharpness'                   => 'Eglurder',
-'exif-gpslatituderef'              => 'Lledred Gogledd neu De',
+'exif-gpslatituderef'              => "Lledred i'r Gogledd neu i'r De",
 'exif-gpslatitude'                 => 'Lledred',
-'exif-gpslongituderef'             => 'Hydred Dwyrain neu Gorllewin',
+'exif-gpslongituderef'             => "Hydred i'r Dwyrain neu i'r Gorllewin",
 'exif-gpslongitude'                => 'Hydred',
 'exif-gpsaltituderef'              => 'Cyfeirnod uchder',
 'exif-gpsaltitude'                 => 'Uchder',
@@ -2080,22 +2085,25 @@
 
 'exif-orientation-3' => 'Wedi ei droi 180°', # 0th row: bottom; 0th column: right
 
-'exif-componentsconfiguration-0' => "nid yw'n bodoli",
+'exif-componentsconfiguration-0' => "ddim i'w gael",
 
-'exif-exposureprogram-0' => 'Heb ei ddiffinio',
+'exif-exposureprogram-0' => 'Heb ei gosod',
 
 'exif-subjectdistance-value' => '$1 medr',
 
 'exif-meteringmode-0'   => 'Anhysbys',
-'exif-meteringmode-1'   => 'Cyfartaledd',
-'exif-meteringmode-5'   => 'Patrwm',
+'exif-meteringmode-1'   => 'Cyfartaleddu',
+'exif-meteringmode-2'   => 'Cyfartaleddu canol-bwysedig',
+'exif-meteringmode-3'   => 'Smotyn',
+'exif-meteringmode-4'   => 'Smotiau',
+'exif-meteringmode-5'   => 'Patrymu',
 'exif-meteringmode-6'   => 'Rhannol',
 'exif-meteringmode-255' => 'Arall',
 
 'exif-lightsource-0'  => 'Anhysbys',
 'exif-lightsource-1'  => 'Golau dydd',
-'exif-lightsource-2'  => 'Fflwroleuol',
-'exif-lightsource-4'  => 'Flach',
+'exif-lightsource-2'  => 'Fflworoleuol',
+'exif-lightsource-4'  => 'Fflach',
 'exif-lightsource-9'  => 'Tywydd braf',
 'exif-lightsource-10' => 'Tywydd cymylog',
 'exif-lightsource-11' => 'Cysgod',
@@ -2106,7 +2114,7 @@
 
 'exif-scenecapturetype-1' => 'Tirlun',
 'exif-scenecapturetype-2' => 'Portread',
-'exif-scenecapturetype-3' => 'Golygfa nôs',
+'exif-scenecapturetype-3' => 'Golygfa nos',
 
 'exif-gaincontrol-0' => 'Dim',
 
@@ -2119,11 +2127,11 @@
 'exif-subjectdistancerange-0' => 'Anhysbys',
 
 # Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
-'exif-gpslatitude-n' => 'Lledred gogledd',
-'exif-gpslatitude-s' => 'Lledred de',
+'exif-gpslatitude-n' => "Lledred i'r Gogledd",
+'exif-gpslatitude-s' => "Lledred i'r De",
 
 # Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
-'exif-gpslongitude-e' => 'Hydred dwyrain',
+'exif-gpslongitude-e' => "Hydred i'r Dwyrain",
 'exif-gpslongitude-w' => "Hydred i'r Gorllewin",
 
 # Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
@@ -2135,7 +2143,7 @@
 
 # External editor support
 'edit-externally'      => 'Golygwch y ffeil gyda rhaglen allanol',
-'edit-externally-help' => 'Gwelwch y [http://meta.wikimedia.org/wiki/Help:External_editors cyfarwyddiadau gosod] am fwy o wybodaeth.',
+'edit-externally-help' => 'Gwelwch y [http://www.mediawiki.org/wiki/Manual:External_editors cyfarwyddiadau gosod] am fwy o wybodaeth.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'holl',
@@ -2198,7 +2206,7 @@
 'recreate'            => 'Ail-greu',
 
 # HTML dump
-'redirectingto' => "Wrthi'n ailgyfeirio i [[$1]]...",
+'redirectingto' => "Wrthi'n ailgyfeirio i [[:$1]]...",
 
 # action=purge
 'confirm_purge'        => "Clirio'r dudalen o'r storfa?
@@ -2207,9 +2215,11 @@
 'confirm_purge_button' => 'Iawn',
 
 # AJAX search
-'articletitles' => "Erthyglau'n dechrau gyda: ''$1''",
-'hideresults'   => "Cuddio'r canlyniadau",
-'useajaxsearch' => 'Chwilio gyda AJAX',
+'searchcontaining' => "Chwilio am dudalennau yn cynnwys ''$1''.",
+'searchnamed'      => "Chwilio am dudalennau a'r enw ''$1''.",
+'articletitles'    => "Erthyglau'n dechrau gyda: ''$1''",
+'hideresults'      => "Cuddio'r canlyniadau",
+'useajaxsearch'    => 'Chwilio gyda AJAX',
 
 # Multipage image navigation
 'imgmultipageprev' => "← i'r dudalen gynt",
@@ -2240,8 +2250,8 @@
 'livepreview-error'   => 'Wedi methu cysylltu: $1 "$2". Rhowch gynnig ar y rhagolwg arferol.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Hwyrach na ddangosir isod y newidiadau a ddigwyddodd o fewn y $1 eiliad ddiwethaf.',
-'lag-warn-high'   => 'Mae gweinydd y data-bas ar ei hôl hi: efallai nad ymddengys newidiadau o fewn y $1 eiliad ddiwethaf ar y rhestr.',
+'lag-warn-normal' => 'Hwyrach na ddangosir isod y newidiadau a ddigwyddodd o fewn y $1 {{PLURAL:$1|eiliad|eiliad|eiliad|eiliad|eiliad|eiliad}} ddiwethaf.',
+'lag-warn-high'   => 'Mae gweinydd y data-bas ar ei hôl hi: efallai nad ymddengys newidiadau o fewn y $1 {{PLURAL:$1|eiliad|eiliad|eiliad|eiliad|eiliad|eiliad}} ddiwethaf ar y rhestr.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Mae {{PLURAL:$1|$1 tudalen|$1 dudalen|$1 dudalen|$1 tudalen|$1 thudalen|$1 o dudalennau}} ar eich rhestr gwylio, heb gynnwys tudalennau sgwrs.',
@@ -2289,7 +2299,7 @@
 'version-software-product'      => 'Cynnyrch',
 'version-software-version'      => 'Fersiwn',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Llwybr y ffeil',
 'filepath-page'    => 'Ffeil:',
 'filepath-submit'  => 'Llwybr',
@@ -2328,7 +2338,7 @@
 'specialpages-group-redirects'   => 'Tudalennau arbennig ailgyfeirio',
 'specialpages-group-spam'        => 'Offer sbam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Tudalen wag',
 'intentionallyblankpage' => 'Gadawyd y dudalen hon yn wag o fwriad',
 
Index: languages/messages/MessagesSm.php
===================================================================
--- languages/messages/MessagesSm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -119,14 +119,13 @@
 'email'             => "'Imeli",
 
 # Edit pages
-'summary'          => "'Oto'otoga",
-'minoredit'        => "'O se teuteuga la'itiiti lenei",
-'watchthis'        => 'Matau lenei itulau',
-'savearticle'      => 'Sefe le itulau',
-'showpreview'      => "Fa'aali teuteuga",
-'showdiff'         => "Fa'aali suiga",
-'whitelistacctext' => 'To be allowed to create accounts in {{SITENAME}} you have to [[Special:Userlogin|log]] in and have the appropriate permissions.',
-'loginreqlink'     => "Fa'aola",
+'summary'      => "'Oto'otoga",
+'minoredit'    => "'O se teuteuga la'itiiti lenei",
+'watchthis'    => 'Matau lenei itulau',
+'savearticle'  => 'Sefe le itulau',
+'showpreview'  => "Fa'aali teuteuga",
+'showdiff'     => "Fa'aali suiga",
+'loginreqlink' => "Fa'aola",
 
 # Search results
 'powersearch' => "Su'e",
@@ -163,7 +162,7 @@
 # Book sources
 'booksources-go' => 'Alu',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Alu',
 
 # E-mail user
@@ -195,7 +194,6 @@
 # Move page
 'move-page-legend' => "Si'i le itulau",
 'movearticle'      => "Si'i le itulau",
-'movenologin'      => "Le'i fa'aolaina",
 'newtitle'         => "'I le ulutala fou",
 'move-watch'       => 'Matau lenei itulau',
 'movepagebtn'      => "Si'i le itulau",
@@ -205,7 +203,7 @@
 # Namespace 8 related
 'allmessagesname' => 'Igoa',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => "Su'e",
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesArn.php
===================================================================
--- languages/messages/MessagesArn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesArn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,6 +4,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Clerc
  * @author Lin linao
  * @author Poquil
  */
@@ -11,6 +12,9 @@
 $fallback = 'es';
 
 $messages = array(
+# User preference toggles
+'tog-editondblclick' => 'Wirin pakina epu klik mew (JavaScript)',
+
 'underline-always' => 'Rumel',
 'underline-never'  => 'Turpu',
 
@@ -69,14 +73,15 @@
 # Categories related messages
 'listingcontinuesabbrev' => 'ramt.',
 
-'qbfind'      => 'Kintun',
-'qbedit'      => 'Wirin',
-'qbmyoptions' => 'tañi nütramkawe',
-'mypage'      => 'tañi nütramkawe',
-'mytalk'      => 'Tañi nütramkawe',
-'and'         => 'ka',
+'qbfind'        => 'Kintun',
+'qbedit'        => 'Wirin',
+'qbmyoptions'   => 'tañi nütramkawe',
+'moredotdotdot' => 'Doy...',
+'mypage'        => 'tañi nütramkawe',
+'mytalk'        => 'Tañi nütramkawe',
+'and'           => 'ka',
 
-'returnto'         => 'Wüñonge $1 püle.',
+'returnto'         => 'Amutun $1 püle.',
 'tagline'          => '{{SITENAME}} mew',
 'help'             => 'Kellu',
 'search'           => 'Kintun',
@@ -86,9 +91,12 @@
 'history'          => 'Pünon',
 'history_short'    => 'Pünon',
 'edit'             => 'Wirin',
+'create'           => 'Llitun',
+'editthispage'     => 'Wirin tüfachi página',
 'delete'           => 'Ñamümün',
 'protect'          => 'Elulan ñi wiriael',
 'unprotect'        => 'Elun ñi wiriael',
+'talkpage'         => 'Nütramkafinge tüfachi pakina',
 'talkpagelinktext' => 'Nütramkawe',
 'articlepage'      => 'adkintun artículo',
 'talk'             => 'Nütramkawe',
@@ -106,7 +114,8 @@
 'jumptosearch'     => 'kintu',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'helppage' => 'Help:Kellu',
+'edithelppage' => 'Help:Chum wiringekey pakina',
+'helppage'     => 'Help:Kellu',
 
 'ok'                      => 'Feley may',
 'youhavenewmessages'      => 'Elungeymi $1 ($2).',
@@ -130,22 +139,27 @@
 'badtitle'        => 'Nornongey ta üy',
 
 # Login and logout pages
-'yourname'           => 'Tami lludüchi üy',
-'yourpassword'       => 'Tami kondungu',
-'login'              => 'Konün',
-'logout'             => 'Tripan',
-'userlogout'         => 'Tripan',
-'notloggedin'        => 'Petu konlaymi.',
-'nologin'            => 'Nielaymi kiñe lludüwe? $1.',
-'nologinlink'        => 'Dewmafinge',
-'gotaccountlink'     => 'Konün',
-'yourrealname'       => 'Tami mupiñ üy *',
-'yourlanguage'       => 'Dungun:',
-'loginlanguagelabel' => 'Dungun: $1',
+'loginpagetitle'          => 'Konün',
+'yourname'                => 'Tami lludüchi üy',
+'yourpassword'            => 'Tami kondungu',
+'login'                   => 'Konün',
+'nav-login-createaccount' => 'Registrarse/Konün',
+'userlogin'               => 'Konün',
+'logout'                  => 'Tripan',
+'userlogout'              => 'Tripan',
+'notloggedin'             => 'Petu konlaymi.',
+'nologin'                 => 'Nielaymi kiñe lludüwe? $1.',
+'nologinlink'             => 'Dewmafinge',
+'gotaccountlink'          => 'Konün',
+'yourrealname'            => 'Tami mupiñ üy *',
+'yourlanguage'            => 'Dungun:',
+'loginlanguagelabel'      => 'Dungun: $1',
 
 # Edit pages
 'subject'    => 'Dungu/üy',
 'newarticle' => '(We)',
+'editing'    => 'Wirimekey $1',
+'yourtext'   => 'Tami wirin',
 
 # History pages
 'page_first'   => 'wünen',
@@ -162,8 +176,9 @@
 'editundo' => 'wüñoeltun',
 
 # Search results
-'viewprevnext' => 'Pen ($1) ($2) ($3).',
-'powersearch'  => 'Kintu',
+'viewprevnext'          => 'Pen ($1) ($2) ($3).',
+'search-interwiki-more' => '(Doy)',
+'powersearch'           => 'Kintu',
 
 # Groups
 'group'       => 'Kisuwen:',
@@ -180,7 +195,7 @@
 
 'nolicense' => 'Chemnorume dullinnongey',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Üy',
 
 # Image description page
@@ -208,11 +223,11 @@
 'speciallogtitlelabel' => 'Üy:',
 'log-search-submit'    => 'Amun',
 
-# Special:Allpages
+# Special:AllPages
 'allpagesnext'   => 'Inan',
 'allpagessubmit' => 'Pengelün',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Pengelün',
 
 # E-mail user
@@ -260,7 +275,7 @@
 # Patrol log
 'patrol-log-diff' => 'ng$1',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Kintu',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
@@ -298,4 +313,7 @@
 'size-megabytes' => '$1 Mb',
 'size-gigabytes' => '$1 Gb',
 
+# Special:SpecialPages
+'specialpages-group-login' => 'Konün',
+
 );
Index: languages/messages/MessagesWuu.php
===================================================================
--- languages/messages/MessagesWuu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesWuu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -33,6 +33,7 @@
 'tog-watchlisthideown'        => '勒拉监控列表里向囥脱我个编辑',
 'tog-watchlisthidebots'       => '勒拉监控列表里向囥脱机器人个编辑',
 'tog-watchlisthideminor'      => '在监控列表中隐藏微小更改',
+'tog-showhiddencats'          => '显示囥脱分类',
 
 'underline-always'  => '总归',
 'underline-never'   => '从来弗',
@@ -206,7 +207,7 @@
 'editsectionhint'         => '编辑段落: $1',
 'toc'                     => '目录',
 'showtoc'                 => '显示',
-'hidetoc'                 => '隐藏',
+'hidetoc'                 => '囥脱',
 'thisisdeleted'           => '查看或者恢复$1？',
 'viewdeleted'             => '望望$1看？',
 'restorelink'             => '个被删除个版本',
@@ -440,9 +441,9 @@
 'uploadbtn'         => '上载文件',
 'reupload'          => '重新上载',
 'uploadnologin'     => '朆登录',
-'uploadnologintext' => '倷板定要[[Special:Userlogin|登录]]仔再好上载文件。',
+'uploadnologintext' => '倷板定要[[Special:UserLogin|登录]]仔再好上载文件。',
 'uploaderror'       => '上载出错',
-'uploadtext'        => "拿下头只表格来上载文件。要查看或者搜寻之前上载个图片个说法，请到[[Special:Imagelist|已上载文件列表]]，上载搭仔删脱也记录勒拉[[Special:Log/upload|上载日志]]里向。
+'uploadtext'        => "拿下头只表格来上载文件。要查看或者搜寻之前上载个图片个说法，请到[[Special:ImageList|已上载文件列表]]，上载搭仔删脱也记录勒拉[[Special:Log/upload|上载日志]]里向。
 
 要勒拉页面里向摆进图片个说法，用下头该种形式个链接
 '''<nowiki>[[{{ns:image}}:文件.jpg]]</nowiki>'''，
@@ -466,7 +467,7 @@
 'destfilename'      => '目标文件名:',
 'watchthisupload'   => '监控该只页面',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => '寻图片名字:',
 'imgfile'               => '源文件',
 'imagelist'             => '文件列表',
@@ -547,7 +548,7 @@
 'speciallogtitlelabel' => '标题:',
 'log'                  => '记录',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '全部页面',
 'alphaindexline'    => '$1到$2',
 'nextpage'          => '下页 ($1)',
@@ -564,7 +565,7 @@
 # Special:Categories
 'categories' => '页面分类',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => '显示',
 
 # E-mail user
@@ -585,7 +586,7 @@
 'watchnologin'         => '朆登录',
 'addedwatch'           => '加到监控列表哉',
 'addedwatchtext'       => "该个页面 \"[[:\$1]]\" 已经加到侬个[[Special:Watchlist|监控列表]]哉。
-将来对该页面个改动搭仔搭界个讲张页个改动会列表垃该面，并且页面会垃拉[[Special:Recentchanges|近段辰光个改变列表]]里向显示成功'''黑体'''，实梗好外加便当拿渠拣出来。假使侬歇仔两日又想拿箇个页面登侬个监控列表里向拿脱个说法，垃侧条里向点击“弗要监控。",
+将来对该页面个改动搭仔搭界个讲张页个改动会列表垃该面，并且页面会垃拉[[Special:RecentChanges|近段辰光个改变列表]]里向显示成功'''黑体'''，实梗好外加便当拿渠拣出来。假使侬歇仔两日又想拿箇个页面登侬个监控列表里向拿脱个说法，垃侧条里向点击“弗要监控。",
 'removedwatch'         => '登监控列表里向拿脱哉',
 'removedwatchtext'     => '"[[:$1]]"已经从侬个监控列表移除。',
 'watch'                => '监控',
@@ -667,7 +668,7 @@
 'blocklink'          => '封禁',
 'contribslink'       => '贡献',
 'blocklogpage'       => '封禁日志',
-'blocklogtext'       => '该个是用户封禁搭仔解禁操作个记录。自动封禁个IP地址弗会列勒该答。到[[Special:Ipblocklist|IP 封禁列表]]去看当前生效个封禁列表。',
+'blocklogtext'       => '该个是用户封禁搭仔解禁操作个记录。自动封禁个IP地址弗会列勒该答。到[[Special:IPBlockList|IP 封禁列表]]去看当前生效个封禁列表。',
 'proxyblocksuccess'  => '好哉。',
 
 # Move page
@@ -683,8 +684,6 @@
 个作兴会引起对一只热门页面剧烈个、想弗着个改变。
 来操作前头请倷确定倷已经充分了解个能做法个后果。",
 'movearticle'             => '页面捅荡:',
-'movenologin'             => '朆登录',
-'movenologintext'         => '倷板定要是已登记用户且勒拉[[Special:Userlogin|登录]]状态下头再好拿页面捅荡。',
 'newtitle'                => '新个题目:',
 'movepagebtn'             => '页面捅荡',
 'pagemovedsub'            => '捅荡成功哉',
@@ -765,7 +764,7 @@
 # Image deletion
 'deletedrevision' => '拨删脱个旧修订 $1',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'    => '新文件陈列室',
 'showhidebots' => '（$1机器人）',
 'ilsubmit'     => '搜寻',
@@ -847,7 +846,7 @@
 # Special:Version
 'version' => '版本', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => '文件路径',
 'filepath-page'   => '文件：',
 'filepath-submit' => '路径',
Index: languages/messages/MessagesKw.php
===================================================================
--- languages/messages/MessagesKw.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKw.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -115,7 +115,7 @@
 # Tooltip help for the actions
 'tooltip-pt-preferences' => 'Teythi ow akont',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Hwilas',
 
 # Special:SpecialPages
Index: languages/messages/MessagesSq.php
===================================================================
--- languages/messages/MessagesSq.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSq.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Dori
  * @author Cradel
+ * @author Dori
  * @author Ergon
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -571,10 +568,6 @@
 'blockededitsource'                => "Më poshtë tregohet teksti i '''redaktimeve tuaja''' të '''$1''':",
 'whitelistedittitle'               => 'Duhet të hyni brënda për të redaktuar',
 'whitelistedittext'                => 'Duhet të $1 për të redaktuar artikuj.',
-'whitelistreadtitle'               => 'Duhet të hyni brënda për të lexuar',
-'whitelistreadtext'                => 'Duhet të [[Special:Userlogin|hyni brënda]] për të lexuar artikuj.',
-'whitelistacctitle'                => 'Nuk ju lejohet të hapni një llogari',
-'whitelistacctext'                 => 'Për të hapur llogari tek {{SITENAME}} duhet të [[Special:Userlogin|hyni brënda]] dhe të keni të drejta të posaçme.',
 'confirmedittitle'                 => 'Nevojitet adresë email-i e vërtetuar për të redaktuar',
 'confirmedittext'                  => 'Ju duhet së pari ta vërtetoni e-mail adresen para se të redaktoni. Ju lutem plotësoni dhe vërtetoni e-mailin tuaj  te [[Special:Preferences|parapëlqimet]] e juaja.',
 'nosuchsectiontitle'               => 'Asnjë seksion i tillë nuk ekziston',
@@ -589,7 +582,7 @@
 'newarticletext'                   => "{{SITENAME}} nuk ka akoma një ''{{NAMESPACE}} faqe'' të quajtur '''{{PAGENAME}}'''. Shtypni '''redaktoni''' më sipër ose [[Special:Search/{{PAGENAME}}|bëni një kërkim për {{PAGENAME}}]]",
 'anontalkpagetext'                 => "---- ''Kjo është një faqe diskutimi për një përdorues anonim i cili nuk ka hapur akoma një llogari ose nuk e përdor atë.
 Prandaj, më duhet të përdor numrin e adresës IP për ta identifikuar.
-Kjo adresë mund të përdoret nga disa njerëz. Në qoftë se jeni një përdorues anonim dhe mendoni se komente kot janë drejtuar ndaj jush, ju lutem [[Special:Userlogin|krijoni një llogari ose hyni brënda]] për të mos u ngatarruar me përdorues të tjerë anonim.''",
+Kjo adresë mund të përdoret nga disa njerëz. Në qoftë se jeni një përdorues anonim dhe mendoni se komente kot janë drejtuar ndaj jush, ju lutem [[Special:UserLogin|krijoni një llogari ose hyni brënda]] për të mos u ngatarruar me përdorues të tjerë anonim.''",
 'noarticletext'                    => 'Tani për tani nuk ka tekst në këtë faqe, mund ta [[Special:Search/{{PAGENAME}}|kërkoni]] këtë titull në faqe të tjera ose mund ta [{{fullurl:{{FULLPAGENAME}}|action=edit}} filloni] atë.',
 'userpage-userdoesnotexist'        => 'Llogaria e përdoruesit "$1" nuk është hapur. Ju lutem mendohuni mirë nëse dëshironi të krijoni/redaktoni këtë faqe.',
 'clearyourcache'                   => "'''Shënim:''' Pasi të ruani parapëlqimet ose pasi të kryeni ndryshimet, duhet të pastroni ''cache''-në e shfletuesit tuaj për të parë ndryshimet: për '''Mozilla/Safari/Konqueror''' shtypni ''Ctrl+Shift+Reload'' (ose ''ctrl+shift+r''), për '''IE''' ''Ctrl+f5'', '''Opera''': ''F5''.",
@@ -646,7 +639,7 @@
 'hiddencategories'                 => 'Kjo faqe është nën {{PLURAL:$1|një kategori të fshehur|$1 kategori të fshehura}}:',
 'edittools'                        => '<!-- Teksti këtu do të tregohet poshtë kutive të redaktimit dhe ngarkimit të skedave. -->',
 'nocreatetitle'                    => 'Krijimi i faqeve të reja është i kufizuar.',
-'nocreatetext'                     => 'Mundësia për të krijuar faqe të reja është kufizuar. Duhet të [[Special:Userlogin|hyni ose të hapni një llogari]] për të krijuar faqe të reja, ose mund të ktheheni mbrapsh dhe të redaktoni një faqe ekzistuese.',
+'nocreatetext'                     => 'Mundësia për të krijuar faqe të reja është kufizuar. Duhet të [[Special:UserLogin|hyni ose të hapni një llogari]] për të krijuar faqe të reja, ose mund të ktheheni mbrapsh dhe të redaktoni një faqe ekzistuese.',
 'nocreate-loggedin'                => 'Nuk ju lejohet të krijoni faqe të reja tek {{SITENAME}}.',
 'permissionserrors'                => 'Gabime privilegjesh',
 'permissionserrorstext'            => 'Nuk keni leje për të bërë këtë veprim për {{PLURAL:$1|këtë arsye|këto arsye}}:',
@@ -759,7 +752,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Regjistri i ndalimeve',
-'suppressionlogtext' => 'Më poshtë jepet një listë grisjesh dhe bllokimesh që kanë të bëjnë me përmbatje të fshehur nga administruesit. Shikoni [[Special:Ipblocklist|listën e IP bllokimeve]] për një listë të bllokimeve dhe përzënieve në fuqi.',
+'suppressionlogtext' => 'Më poshtë jepet një listë grisjesh dhe bllokimesh që kanë të bëjnë me përmbatje të fshehur nga administruesit. Shikoni [[Special:IPBlockList|listën e IP bllokimeve]] për një listë të bllokimeve dhe përzënieve në fuqi.',
 
 # History merging
 'mergehistory'                     => 'Bashko historikët e faqeve',
@@ -850,7 +843,7 @@
 'mypreferences'            => 'Parapëlqimet',
 'prefs-edits'              => 'Numri i redaktimeve:',
 'prefsnologin'             => 'Nuk keni hyrë brenda',
-'prefsnologintext'         => 'Duhet të keni [[Special:Userlogin|hyrë brenda]] për të ndryshuar parapëlqimet e përdoruesit.',
+'prefsnologintext'         => 'Duhet të keni [[Special:UserLogin|hyrë brenda]] për të ndryshuar parapëlqimet e përdoruesit.',
 'prefsreset'               => 'Parapëlqimet janë rikthyer siç ishin.',
 'qbsettings'               => 'Vendime të shpejta',
 'qbsettings-none'          => 'Asnjë',
@@ -924,7 +917,7 @@
 'userrights-reason'           => 'Arsyeja për ndryshimin:',
 'userrights-no-interwiki'     => 'Nuk keni leje për të ndryshuar privilegjet e përdoruesve në wiki të tjera.',
 'userrights-nodatabase'       => 'Regjistri $1 nuk ekziston ose nuk është vendor.',
-'userrights-nologin'          => 'Duhet të [[Special:Userlogin|hyni brenda]] me një llogari administrative për të ndryshuar privilegjet e përdoruesve.',
+'userrights-nologin'          => 'Duhet të [[Special:UserLogin|hyni brenda]] me një llogari administrative për të ndryshuar privilegjet e përdoruesve.',
 'userrights-notallowed'       => 'Llogaria juaj nuk ju lejon të ndryshoni privilegjet e përdoruesve.',
 'userrights-changeable-col'   => 'Grupe që mund të ndryshoni',
 'userrights-unchangeable-col' => "Grupe që s'mund të ndryshoni",
@@ -1001,11 +994,11 @@
 'reupload'                    => 'Ngarkojeni përsëri',
 'reuploaddesc'                => 'Kthehu tek formulari i dhënies.',
 'uploadnologin'               => 'Nuk keni hyrë brënda',
-'uploadnologintext'           => 'Duhet të keni [[Special:Userlogin|hyrë brenda]] për të dhënë skeda.',
+'uploadnologintext'           => 'Duhet të keni [[Special:UserLogin|hyrë brenda]] për të dhënë skeda.',
 'upload_directory_read_only'  => 'Skedari i ngarkimit ($1) nuk mund të shkruhet nga shërbyesi.',
 'uploaderror'                 => 'Gabim dhënie',
 'uploadtext'                  => "Përdorni formularin e mëposhtëm për të ngarkuar skeda.
-Për të parë ose për të kërkuar skedat e ngarkuara më parë shikoni [[Special:Imagelist|listën e skedave të ngarkuara]]. Ngarkime dhe grisje shënohen edhe tek [[Special:Log/upload|regjistri i ngarkimeve]].
+Për të parë ose për të kërkuar skedat e ngarkuara më parë shikoni [[Special:ImageList|listën e skedave të ngarkuara]]. Ngarkime dhe grisje shënohen edhe tek [[Special:Log/upload|regjistri i ngarkimeve]].
 
 Për të përdorur një skedë në një faqe përdorni lidhje të llojit:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Skedë.jpg]]</nowiki>''',
@@ -1101,7 +1094,7 @@
 'upload_source_url'  => ' (URL e vlefshme, publikisht e përdorshme)',
 'upload_source_file' => ' (skeda në kompjuterin tuaj)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Kjo faqe speciale tregon tërë skedat e ngarkuara.
 Fillimisht skedat e ngarkuara së fundmi jepen më sipër.
 Shtypni kolonat e tjera për të ndryshuar radhitjen.',
@@ -1129,7 +1122,7 @@
 'imagelinks'                     => 'Lidhje skedash',
 'linkstoimage'                   => 'Këto faqe lidhen tek kjo skedë:',
 'nolinkstoimage'                 => 'Asnjë faqe nuk lidhet tek kjo skedë.',
-'morelinkstoimage'               => 'Shikoni [[Special:Whatlinkshere/$1|më shumë lidhje]] tek kjo skedë.',
+'morelinkstoimage'               => 'Shikoni [[Special:WhatLinksHere/$1|më shumë lidhje]] tek kjo skedë.',
 'redirectstofile'                => 'Skedat e mëposhtme përcillen tek kjo skedë:',
 'duplicatesoffile'               => 'Skedat e më poshtme janë kopje të kësaj skede:',
 'sharedupload'                   => 'Kjo skedë është një ngarkim i përbashkët dhe mund të përdoret nga projekte të tjera.',
@@ -1148,18 +1141,18 @@
 # File reversion
 'filerevert'                => 'Rikthe $1',
 'filerevert-legend'         => 'Rikthe skedën',
-'filerevert-intro'          => '<span class="plainlinks">Po ktheni \'\'\'[[Media:$1|$1]]\'\'\' tek [versioni $4 i $3, $2].</span>',
+'filerevert-intro'          => "Po ktheni '''[[Media:$1|$1]]''' tek [versioni $4 i $3, $2].",
 'filerevert-comment'        => 'Arsyeja:',
 'filerevert-defaultcomment' => 'U rikthye tek versioni i $2, $1',
 'filerevert-submit'         => 'Riktheje',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' është kthyer tek [versioni $4 i $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' është kthyer tek [versioni $4 i $3, $2].",
 'filerevert-badversion'     => 'Nuk ka version vendor tjetër të kësaj skede në kohën e dhënë.',
 
 # File deletion
 'filedelete'                  => 'Grise $1',
 'filedelete-legend'           => 'Grise skedën',
 'filedelete-intro'            => "Jeni duke grisur '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Po grisni versionin e \'\'\'[[Media:$1|$1]]\'\'\' të [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Po grisni versionin e '''[[Media:$1|$1]]''' të [$4 $3, $2].",
 'filedelete-comment'          => 'Arsyeja:',
 'filedelete-submit'           => 'Grise',
 'filedelete-success'          => "'''$1''' është grisur.",
@@ -1210,7 +1203,7 @@
 '''\$3''' {{PLURAL:\$3|Është bërë '''\$3''' shikim faqeje|Janë bërë '''\$3''' shikime faqesh}} dhe '''\$4''' {{PLURAL:\$4|redaktim faqeje|redaktime faqesh}} që nga dita kur {{SITENAME}} u hap. Kjo do të thotë se janë bërë afërsisht '''\$5''' redaktime për faqe, dhe '''\$6''' shikime për çdo redaktim.
 
 Gjatësia e [http://www.mediawiki.org/wiki/Manual:Job_queue radhës së punëve] është '''\$7'''.",
-'userstatstext'          => "{{PLURAL:$1|Gjëndet|Gjënden}} '''$1''' [[Special:Listusers|përdorues]] {{PLURAL:$1|i|të}} regjistruar. '''$2''' prej tyre (ose '''$4'''%) {{PLURAL:$2|ka|kanë}} privilegjin $5.",
+'userstatstext'          => "{{PLURAL:$1|Gjëndet|Gjënden}} '''$1''' [[Special:ListUsers|përdorues]] {{PLURAL:$1|i|të}} regjistruar. '''$2''' prej tyre (ose '''$4'''%) {{PLURAL:$2|ka|kanë}} privilegjin $5.",
 'statistics-mostpopular' => 'Faqet më të shikuara',
 
 'disambiguations'      => 'Faqe kthjelluese',
@@ -1303,7 +1296,7 @@
 'alllogstext'          => 'Kjo faqe tregon një pamje të përmbledhur të regjistrave të ngarkimeve, grisjeve, mbrojtjeve, bllokimeve, dhe të veprimeve administrative. Mundeni të kufizoni informactionin sipas tipit të regjistrit, emrit të përdoruesit, si dhe faqes në çështje.',
 'logempty'             => 'Nuk ka asnjë përputhje në regjistër.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Të gjitha faqet',
 'alphaindexline'    => '$1 deri në $2',
 'nextpage'          => 'Faqja më pas ($1)',
@@ -1321,12 +1314,12 @@
 'categories'         => 'Kategori',
 'categoriespagetext' => 'Ndodhen këto kategori:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Trego përdoruesit duke filluar prej te:',
 'listusers-submit'   => 'Trego',
 'listusers-noresult' => "Asnjë përdorues s'u gjet.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Grupime përdoruesish me privilegje',
 'listgrouprights-summary'  => 'Më poshtë jepet grupimi i përdoruesve sipas privilegjeve që ju janë dhënë në këtë wiki. Më shumë informacion rreth privilegjeve në veçanti mund të gjendet tek [[{{MediaWiki:Listgrouprights-helppage}}]].',
 'listgrouprights-group'    => 'Grupi',
@@ -1336,7 +1329,7 @@
 
 # E-mail user
 'mailnologin'     => "S'ka adresë dërgimi",
-'mailnologintext' => 'Duhet të keni [[Special:Userlogin|hyrë brenda]] dhe të keni një adresë të saktë në [[Special:Preferences|parapëlqimet]] tuaja për tu dërguar email përdoruesve të tjerë.',
+'mailnologintext' => 'Duhet të keni [[Special:UserLogin|hyrë brenda]] dhe të keni një adresë të saktë në [[Special:Preferences|parapëlqimet]] tuaja për tu dërguar email përdoruesve të tjerë.',
 'emailuser'       => 'Email përdoruesit',
 'emailpage'       => 'Dërgo email përdoruesve',
 'emailpagetext'   => 'Në qoftë se ky përdorues ka dhënë një adresë të saktë në parapëlqimet, formulari më poshtë do t\'i dërgojë një mesazh. 
@@ -1363,9 +1356,9 @@
 'watchlistfor'         => "(për '''$1''')",
 'nowatchlist'          => 'Nuk keni asnjë faqe në listën mbikqyrëse.',
 'watchnologin'         => 'Nuk keni hyrë brënda',
-'watchnologintext'     => 'Duhet të keni [[Special:Userlogin|hyrë brenda]] për të ndryshuar listën mbikqyrëse.',
+'watchnologintext'     => 'Duhet të keni [[Special:UserLogin|hyrë brenda]] për të ndryshuar listën mbikqyrëse.',
 'addedwatch'           => 'U shtua tek lista mbikqyrëse',
-'addedwatchtext'       => "Faqja \"<nowiki>\$1</nowiki>\" është shtuar [[Special:Watchlist|listës mbikqyrëse]] tuaj. Ndryshimet e ardhshme të kësaj faqeje dhe faqes së diskutimit të saj do të jepen më poshtë, dhe emri i faqes do të duket i '''trashë''' në [[Special:Recentchanges|listën e ndryshimeve së fundmi]] për t'i dalluar më kollaj.
+'addedwatchtext'       => "Faqja \"<nowiki>\$1</nowiki>\" është shtuar [[Special:Watchlist|listës mbikqyrëse]] tuaj. Ndryshimet e ardhshme të kësaj faqeje dhe faqes së diskutimit të saj do të jepen më poshtë, dhe emri i faqes do të duket i '''trashë''' në [[Special:RecentChanges|listën e ndryshimeve së fundmi]] për t'i dalluar më kollaj.
 
 Në qoftë se dëshironi të hiqni një faqe nga lista mbikqyrëse më vonë, shtypni \"çmbikqyre\" në tabelën e sipërme.",
 'removedwatch'         => 'U hoq nga lista mibkqyrëse',
@@ -1607,7 +1600,7 @@
 'badipaddress'                => 'Nuk ka asnjë përdorues me atë emër',
 'blockipsuccesssub'           => 'Bllokimi u bë me sukses',
 'blockipsuccesstext'          => 'Përdoruesi/IP-Adresa [[Special:Contributions/$1|$1]] u bllokua.<br />
-Shiko te [[Special:Ipblocklist|Lista e përdoruesve dhe e IP adresave të bllokuara]] për të çbllokuar Përdorues/IP.',
+Shiko te [[Special:IPBlockList|Lista e përdoruesve dhe e IP adresave të bllokuara]] për të çbllokuar Përdorues/IP.',
 'ipb-edit-dropdown'           => 'Redakto arsyet e bllokimit',
 'ipb-unblock-addr'            => 'Çblloko $1',
 'ipb-unblock'                 => 'Çblloko përdorues dhe IP të bllokuara',
@@ -1637,7 +1630,7 @@
 'autoblocker'                 => 'I bllokuar automatikisht sepse përdor të njëjtën IP adresë si "$1". Arsye "$2".',
 'blocklogpage'                => 'Regjistri i bllokimeve',
 'blocklogentry'               => 'bllokoi [[$1]] për një kohë prej: $2 $3',
-'blocklogtext'                => 'Ky është një regjistër bllokimesh dhe çbllokimesh të përdoruesve. IP-të e bllokuara automatikisht nuk janë të dhëna. Shikoni dhe [[Special:Ipblocklist|listën e IP-ve të bllokuara]] për një listë të bllokimeve të tanishme.',
+'blocklogtext'                => 'Ky është një regjistër bllokimesh dhe çbllokimesh të përdoruesve. IP-të e bllokuara automatikisht nuk janë të dhëna. Shikoni dhe [[Special:IPBlockList|listën e IP-ve të bllokuara]] për një listë të bllokimeve të tanishme.',
 'unblocklogentry'             => 'çbllokoi "$1"',
 'range_block_disabled'        => 'Mundësia e administruesve për të bllokuar me shtrirje është çaktivizuar.',
 'ipb_expiry_invalid'          => 'Afati i kohës është gabim.',
@@ -1664,7 +1657,7 @@
 'lockdbsuccesssub'    => 'Regjistri u bllokua me sukses',
 'unlockdbsuccesssub'  => 'Regjistri u çbllokua me sukses',
 'lockdbsuccesstext'   => 'Regjistri është bllokuar.<br />
-Kujtohuni ta [[Special:Unlockdb|çbllokoni]] pasi të keni mbaruar mirëmbajtjen.',
+Kujtohuni ta [[Special:UnlockDB|çbllokoni]] pasi të keni mbaruar mirëmbajtjen.',
 'unlockdbsuccesstext' => 'Regjistri i {{SITENAME}} është çbllokuar.',
 'lockfilenotwritable' => "Skeda për bllokimin e regjistrit s'mund të shkruhet.
 Shërbyesi i rrjetit duhet të jetë në gjendje të shkruaj këtë skedë për të bllokuar ose çbllokuar regjistrin.",
@@ -1691,8 +1684,6 @@
 
 Në ato raste, duhet ta zhvendosni ose përpuqni faqen vetë n.q.s. dëshironi.",
 'movearticle'             => 'Zhvendose faqen',
-'movenologin'             => 'Nuk keni hyrë brenda',
-'movenologintext'         => 'Duhet të keni hapur një llogari dhe të keni [[Special:Userlogin|hyrë brenda]] për të zhvendosur një faqe.',
 'movenotallowed'          => 'Nuk ju lejohet të zhvendosni faqe në {{SITENAME}}.',
 'newtitle'                => 'Tek titulli i ri',
 'move-watch'              => 'Mbikqyre këtë faqe',
@@ -1719,7 +1710,7 @@
 'delete_and_move'         => 'Grise dhe zhvendose',
 'delete_and_move_text'    => '==Nevojitet grisje==
 
-Faqja "[[$1]]" ekziston, dëshironi ta grisni për të mundësuar zhvendosjen?',
+Faqja "[[:$1]]" ekziston, dëshironi ta grisni për të mundësuar zhvendosjen?',
 'delete_and_move_confirm' => 'Po, grise faqen',
 'delete_and_move_reason'  => 'U gris për të liruar vendin për përcjellim',
 'selfmove'                => 'Nuk munda ta zhvendos faqen sepse titulli i ri është i njëjtë me të vjetrin.',
@@ -1903,10 +1894,10 @@
 'show-big-image'       => 'Rezolucion i plotë',
 'show-big-image-thumb' => '<small>Madhësia e këtij shikimi: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria e figurave të reja',
 'imagelisttext'         => 'Më poshtë është një listë e $1 {{PLURAL:$1|skedës të renditur|skedave të renditura}} sipas $2.',
-'newimages-summary'     => 'Kjo faqe speciale tregon skedat e ngarkuara së fundmi',
+'newimages-summary'     => 'Kjo faqe speciale tregon skedat e ngarkuara së fundmi.',
 'showhidebots'          => '($1 robotët)',
 'noimages'              => "S'ka gjë për të parë.",
 'ilsubmit'              => 'Kërko',
@@ -2071,7 +2062,7 @@
 
 # External editor support
 'edit-externally'      => 'Ndryshoni këtë skedë me një mjet të jashtëm',
-'edit-externally-help' => 'Shikoni [http://meta.wikimedia.org/wiki/Help:External_editors udhëzimet e instalimit] për më shumë informacion.',
+'edit-externally-help' => 'Shikoni [http://www.mediawiki.org/wiki/Manual:External_editors udhëzimet e instalimit] për më shumë informacion.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'të gjitha',
@@ -2134,7 +2125,7 @@
 'recreate'            => 'Rikrijo',
 
 # HTML dump
-'redirectingto' => 'Përcjellin tek [[$1]]...',
+'redirectingto' => 'Përcjellin tek [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Pastro cache për këtë faqe?
@@ -2218,7 +2209,7 @@
 'version-software-product' => 'Produkti',
 'version-software-version' => 'Versioni',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Vendndodhja e skedave',
 'filepath-page'    => 'Skeda:',
 'filepath-submit'  => 'Shko',
Index: languages/messages/MessagesRuq_latn.php
===================================================================
--- languages/messages/MessagesRuq_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRuq_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Макѕе
  * @author Кумулај Маркус
+ * @author Макѕе
  * @author Приетен тев
- * @author Siebrand
  */
 
 $fallback = 'ro';
@@ -242,7 +241,7 @@
 # Book sources
 'booksources' => 'Surse de cărţi',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Toats paži',
 'alphaindexline' => '$1 vo $2',
 'allarticles'    => 'Toats paži',
Index: languages/messages/MessagesSu.php
===================================================================
--- languages/messages/MessagesSu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
- * @author Kandar
  * @author Irwangatot
- * @author Siebrand
+ * @author Kandar
+ * @author Meursault2004
  * @author Mssetiadi
  * @author לערי ריינהארט
- * @author Meursault2004
- * @author SPQRobin
  */
 
 $fallback = 'id';
@@ -529,10 +527,6 @@
 'blockededitsource'                => "Tulisan '''éditan anjeun''' dina '''$1''' dipidangkeun di handap ieu:",
 'whitelistedittitle'               => 'Perlu asup log sangkan bisa ngédit',
 'whitelistedittext'                => 'Anjeun kudu asup $1 sangkan bisa ngédit.',
-'whitelistreadtitle'               => 'Perlu asup log pikeun maca',
-'whitelistreadtext'                => 'Anjeun kudu asup [[Special:Userlogin|log]] sangkan bisa maca.',
-'whitelistacctitle'                => 'Anjeun teu diwenangkeun nyieun rekening',
-'whitelistacctext'                 => 'Sangkan diwenangkeun nyieun rekening na wiki ieu, anjeun kudu asup [[Special:Userlogin|log]] sarta boga kawenangan nu cukup.',
 'confirmedittitle'                 => 'Konfirmasi surélék diperlukeun pikeun ngédit.',
 'confirmedittext'                  => 'Saméméh ngédit, kompirmasikeun heula alamat surélék anjeun.
 Mangga setél, lajeng sahkeun alamat surélék anjeun dina [[Special:Preferences|préferénsi pamaké]].',
@@ -548,7 +542,7 @@
 Pikeun nyieun kaca, mimitian ku ngetik jeroeun kotak di handap
 (tempo [[{{MediaWiki:Helppage}}|kaca pitulung]] pikeun leuwih écés).
 Mun anjeun ka dieu teu ngahaja, klik baé tombol '''back''' na panyungsi anjeun.",
-'anontalkpagetext'                 => "----''Ieu mangrupa kaca sawala pikeun pamaké anonim nu can (henteu) nyieun rekening, kusabab kitu alamat IP dipaké dina hal ieu pikeun nyirikeun anjeunna. Alamat IP ieu bisa dipaké ku sababaraha urang. Mun anjeun salasahiji pamaké anonim sarta ngarasa aya koméntar nu teu pakait geus ditujukeun ka anjeun, leuwih hadé [[Special:Userlogin|nyieun rekening atawa asup log]] sangkan teu pahili jeung pamaké anonim séjén.''",
+'anontalkpagetext'                 => "----''Ieu mangrupa kaca sawala pikeun pamaké anonim nu can (henteu) nyieun rekening, kusabab kitu alamat IP dipaké dina hal ieu pikeun nyirikeun anjeunna. Alamat IP ieu bisa dipaké ku sababaraha urang. Mun anjeun salasahiji pamaké anonim sarta ngarasa aya koméntar nu teu pakait geus ditujukeun ka anjeun, leuwih hadé [[Special:UserLogin|nyieun rekening atawa asup log]] sangkan teu pahili jeung pamaké anonim séjén.''",
 'noarticletext'                    => 'Kiwari can aya téks na kaca ieu. Mun anjeun geus kungsi nyieun kaca ieu, coba fungsi [[Special:Search/{{PAGENAME}}|sungsi keur judul]] di kaca sejen atawa [{{fullurl:{{FULLPAGENAME}}|action=edit}} édit kaca ieu].',
 'userpage-userdoesnotexist'        => 'Rekening pamaké "$1" tacan kadaptar. Mangga tilikan lamun anjeun hoyong ngadamel/ngédit kaca ieu.',
 'clearyourcache'                   => "'''Catetan:''' Sanggeus nyimpen, anjeun perlu ngosongkeun sindangan panyungsi anjeun pikeun nempo parobahanana:
@@ -602,7 +596,7 @@
 'edittools'                        => '<!-- Téks di dieu bakal némbongan di handapeun formulir édit jeung muat.-->',
 'nocreatetitle'                    => 'Nyieun kaca kakara diwatesan',
 'nocreatetext'                     => '{{SITENAME}} nutup kabisa nyieun kaca anyar.
-Mangga édit artikel nu geus aya, atawa [[Special:Userlogin|asup log/daptar heula]].',
+Mangga édit artikel nu geus aya, atawa [[Special:UserLogin|asup log/daptar heula]].',
 'nocreate-loggedin'                => 'Anjeun teu ngabogaan hak aksés pikeun nyieun kaca anyar di {{SITENAME}}.',
 'permissionserrors'                => 'Kasalahan Hak Aksés',
 'permissionserrorstext'            => 'Anjeung teu boga kawenangan pikeun peta kitu, kalawan {{PLURAL:$1|alesan|alesan}} di handap ieu:',
@@ -717,7 +711,7 @@
 # Suppression log
 'suppressionlog'     => 'Log nyumputken',
 'suppressionlogtext' => 'Katut, nyaéta daptar hapusan sarta dipeungpeuk kaasup eusi anu disumputkeun ti para kuncén.
-Tempo [[Special:Ipblocklist|daptar IP anu dipeungpeuk]] pikeun daptar larangan sarta dipeungpeuk ayeuna.',
+Tempo [[Special:IPBlockList|daptar IP anu dipeungpeuk]] pikeun daptar larangan sarta dipeungpeuk ayeuna.',
 
 # History merging
 'mergehistory'                     => 'Gabungkeun jujutan kaca',
@@ -798,7 +792,7 @@
 'mypreferences'            => 'Préferénsi kuring',
 'prefs-edits'              => 'Jumlah éditan:',
 'prefsnologin'             => 'Can asup log',
-'prefsnologintext'         => 'Anjeun kudu [[Special:Userlogin|asup log]] pikeun ngatur préferénsi pamaké.',
+'prefsnologintext'         => 'Anjeun kudu [[Special:UserLogin|asup log]] pikeun ngatur préferénsi pamaké.',
 'prefsreset'               => 'Préferénsi geus disét ulang tina arsip.',
 'qbsettings'               => 'Bar gancang',
 'qbsettings-none'          => 'Henteu aya',
@@ -871,7 +865,7 @@
 'userrights-reason'           => 'Alesan ngarobah :',
 'userrights-no-interwiki'     => 'Anjeung teu diwenangkeun ngarobah hak pamaké dina wiki séjén.',
 'userrights-nodatabase'       => 'Pangkalan data $1 euweuh atawa henteu lokal.',
-'userrights-nologin'          => 'Pikeun ngatur hak pamaké, anjeun kudu [[Special:Userlogin|asup log]] migunakeun rekening kuncén.',
+'userrights-nologin'          => 'Pikeun ngatur hak pamaké, anjeun kudu [[Special:UserLogin|asup log]] migunakeun rekening kuncén.',
 'userrights-notallowed'       => 'Rekening anjeun teu diwenangkeun ngatur hak pamaké.',
 'userrights-changeable-col'   => 'Jumplukan anu bisa Anjeun robah',
 'userrights-unchangeable-col' => 'Jumplukan anu teu bisa Anjeun robah',
@@ -978,14 +972,14 @@
 'reupload'                    => 'Muat ulang',
 'reuploaddesc'                => 'Balik ka formulir muatan.',
 'uploadnologin'               => 'Can asup log',
-'uploadnologintext'           => 'Anjeun kudu [[Special:Userlogin|asup log]] pikeun ngamuat koropak.',
+'uploadnologintext'           => 'Anjeun kudu [[Special:UserLogin|asup log]] pikeun ngamuat koropak.',
 'upload_directory_read_only'  => 'Diréktori muatan ($1) teu bisa ditulis ku server ramat.',
 'uploaderror'                 => 'Kasalahan muat',
 'uploadtext'                  => "<strong>HEUP!</strong> Méméh anjeun ngamuat di dieu, pastikeun yén anjeun geus maca sarta tumut ka kawijakan maké gambar.
 
 Mun geus aya koropak na wiki nu ngaranna sarua jeung nu disebutkeun ku anjeun, koropak nu geus lila bakal diganti otomatis. Mangka, iwal ti pikeun ngaropéa hiji koropak, tangtu leuwih hadé mun anjeun mariksa heula bisi koropak nu sarupa geus aya.
 
-Pikeun némbongkeun atawa néang gambar-gambar nu pernah dimuat saméméhna, mangga lebet ka [[Special:Imagelist|daptar gambar nu dimuat]]. Muatan sarta hapusan kadaptar dina log [[Special:Log/upload|log muatan]].
+Pikeun némbongkeun atawa néang gambar-gambar nu pernah dimuat saméméhna, mangga lebet ka [[Special:ImageList|daptar gambar nu dimuat]]. Muatan sarta hapusan kadaptar dina log [[Special:Log/upload|log muatan]].
 
 Paké formulir di handap pikeun ngamuat koropak gambar anyar pikeun ilustrasi kaca anjeun. Na kalolobaan panyungsi, anjeun bakal manggihan tombol \"Sungsi/''Browse''...\", nu bakal nganteur ka dialog muka-koropak nu baku na sistim operasi anjeun. Milih hiji koropak bakal ngeusian ngaran koropakna kana rohangan téks gigireun tombol nu tadi. Anjeun ogé kudu nyontréng kotak nu nandakeun yén anjeun teu ngarumpak hak cipta batur ku dimuatna ieu koropak. Pencét tombol \"Muatkeun/''Upload''\" pikeun ngeréngsékeun muatan. Prosés ieu bisa lila mun anjeun migunakeun sambungan internét nu lambat.
 
@@ -1053,7 +1047,7 @@
 'upload_source_url'  => '(URL nu sohéh sarta bisa dibuka ku umum)',
 'upload_source_file' => ' (koropak dina komputer salira)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Sungsi ngaran média:',
 'imgfile'               => 'koropak',
 'imagelist'             => 'Daptar gambar',
@@ -1092,18 +1086,18 @@
 # File reversion
 'filerevert'                => 'balikkeun $1',
 'filerevert-legend'         => 'Balikkeun gambar',
-'filerevert-intro'          => '<span class="plainlinks">Anjeun keur mulangkeun \'\'\'[[Media:$1|$1]]\'\'\' ka [vérsi $4, $3, $2].</span>',
+'filerevert-intro'          => "Anjeun keur mulangkeun '''[[Media:$1|$1]]''' ka [vérsi $4, $3, $2].",
 'filerevert-comment'        => 'Ringkesan:',
 'filerevert-defaultcomment' => 'Dipulangkeun ka vérsi $2, $1',
 'filerevert-submit'         => 'Balikkeun',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' geus dipulangkeun ka [vérsi $4, $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' geus dipulangkeun ka [vérsi $4, $3, $2].",
 'filerevert-badversion'     => 'Euweuh vérsi lokal tiheula ti koropak ieu kalawan cap waktu anu dimaksud.',
 
 # File deletion
 'filedelete'                  => 'Ngahapus $1',
 'filedelete-legend'           => 'Ngahapus gambar',
 'filedelete-intro'            => "Anjeun ngahapus '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Anjeun keur ngahapus vérsi \'\'\'[[Media:$1|$1]]\'\'\', [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Anjeun keur ngahapus vérsi '''[[Media:$1|$1]]''', [$4 $3, $2].",
 'filedelete-comment'          => 'koméntar:',
 'filedelete-submit'           => 'Hapus',
 'filedelete-success'          => "'''$1''' geus dihapus.",
@@ -1154,7 +1148,7 @@
 Jumlah-jamléh geus aya '''\$3''' {{PLURAL:\$3|kaca}} ulasan sarta '''\$4''' {{PLURAL:\$4|éditan}} ti saprak {{SITENAME}} ieu ngadeg. Jadi hartina aya rata-rata '''\$5''' éditan per kaca sarta '''\$6''' ulasan per édit.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Antrian gawé] lobana '''\$7'''.",
-'userstatstext'          => "Aya '''$1''' [[Special:Listusers|{{PLURAL:$1|pamaké|pamaké}}]] nu kadaptar.
+'userstatstext'          => "Aya '''$1''' [[Special:ListUsers|{{PLURAL:$1|pamaké|pamaké}}]] nu kadaptar.
 '''$2''' ($4) di antarana boga hak $5.",
 'statistics-mostpopular' => 'Kaca nu pangmindengna dibuka',
 
@@ -1249,7 +1243,7 @@
 'logempty'             => 'Taya item nu cocog dina log.',
 'log-title-wildcard'   => 'Téangan judul nu dimimitian ku tulisan ieu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Sadaya kaca',
 'alphaindexline'    => '$1 ka $2',
 'nextpage'          => 'Kaca salajengna ($1)',
@@ -1271,12 +1265,12 @@
 'categoriesfrom'                => 'Tembongkeun kategori-kategori dimimitian ku:',
 'special-categories-sort-count' => 'ngurut numutkeun jumlah',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Témbongkeun pamaké nu dimimitian ku',
 'listusers-submit'   => 'Témbongkeun',
 'listusers-noresult' => 'Teu kapendak.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Hak-hak grup pamaké',
 'listgrouprights-summary'  => 'Ieu mangrupa daptar jumplukan pamaké anu aya di wiki ieu, kalawan daptar hak aksés maranéhanana.
 Informasi leuwih luyu ngeunaan hak pamaké bisa ditingali di [[{{MediaWiki:Listgrouprights-helppage}}]].',
@@ -1287,7 +1281,7 @@
 
 # E-mail user
 'mailnologin'     => 'Euweuh alamat ngirim',
-'mailnologintext' => "Anjeun kudu '''[[Special:Userlogin|asup log]]''' sarta boga alamat surélék nu sah na [[Special:Preferences|préferénsi]] anjeun sangkan bisa nyurélékan pamaké séjén.",
+'mailnologintext' => "Anjeun kudu '''[[Special:UserLogin|asup log]]''' sarta boga alamat surélék nu sah na [[Special:Preferences|préferénsi]] anjeun sangkan bisa nyurélékan pamaké séjén.",
 'emailuser'       => 'Surélékan pamaké ieu',
 'emailpage'       => 'Surélékan pamaké',
 'emailpagetext'   => 'Mun pamaké ieu ngasupkeun alamat surélék nu sah na préferénsi pamakéna, formulir di handap bakal ngirimkeun hiji surat. Alamat surélék nu ku anjeun diasupkeun kana préferénsi pamaké anjeun bakal katémbong salaku alamat "Ti" surélékna, sahingga nu dituju bisa males.',
@@ -1311,10 +1305,10 @@
 'nowatchlist'          => 'Anjeun teu boga awaskeuneun.',
 'watchlistanontext'    => 'Mangga $1 pikeun némbongkeun atawa ngarobah béréndélan awaskeuneun anjeun.',
 'watchnologin'         => 'Can asup log',
-'watchnologintext'     => 'Anjeun kudu [[Special:Userlogin|asup log]] pikeun ngarobah awaskeuneun.',
+'watchnologintext'     => 'Anjeun kudu [[Special:UserLogin|asup log]] pikeun ngarobah awaskeuneun.',
 'addedwatch'           => 'Geus ditambahkeun ka awaskeuneun',
 'addedwatchtext'       => "Kaca \"[[:\$1]]\" geus ditambahkeun ka [[Special:Watchlist|awaskeuneun]] anjeun.
-Jaga, parobahan na kaca ieu katut kaca obrolanana bakal dibéréndélkeun di dinya, sarta kacana bakal katémbong '''dikandelan''' dina kaca [[Special:Recentchanges|Nu anyar robah]] sangkan leuwih gampang ngawaskeunana.
+Jaga, parobahan na kaca ieu katut kaca obrolanana bakal dibéréndélkeun di dinya, sarta kacana bakal katémbong '''dikandelan''' dina kaca [[Special:RecentChanges|Nu anyar robah]] sangkan leuwih gampang ngawaskeunana.
 
 <p>Mun jaga anjeun moal deui ngawaskeun parobahan na kaca éta, klik tumbu \"Eureun ngawaskeun\" na lajursisi.",
 'removedwatch'         => 'Dikaluarkeun ti awaskeuneun',
@@ -1420,7 +1414,7 @@
 'rollback-success'            => 'Mulangkeun éditan $1; balik deui ka vérsi panungtung ku $2.',
 'sessionfailure'              => 'Sigana aya masalah jeung termin log anjeun; peta ieu geus dibolaykeun salaku pépéling pikeun ngalawan ayana pangbajak. Mangga pencét "back" jeung muat ulang ti kaca asal anjeun, lajeng cobaan deui.',
 'protectlogpage'              => 'Log_koncian',
-'protectlogtext'              => 'Di handap ieu mangrupa daptar koncian kaca. Tempo [[Special:Protectedpages|kaca nu dikonci]] pikeun iber leuwih lengkep.',
+'protectlogtext'              => 'Di handap ieu mangrupa daptar koncian kaca. Tempo [[Special:ProtectedPages|kaca nu dikonci]] pikeun iber leuwih lengkep.',
 'protectedarticle'            => 'ngonci $1',
 'modifiedarticleprotection'   => 'hambalan koncian "[[$1]]" geus dirobah',
 'unprotectedarticle'          => 'muka konci $1',
@@ -1561,7 +1555,7 @@
 'badipaddress'                => 'Alamat IP teu sah',
 'blockipsuccesssub'           => 'Meungpeuk geus hasil',
 'blockipsuccesstext'          => '"$1" dipeungpeuk.
-<br />Tempo [[Special:Ipblocklist|daptar peungpeuk IP]] pikeun nempoan deui peungpeuk.',
+<br />Tempo [[Special:IPBlockList|daptar peungpeuk IP]] pikeun nempoan deui peungpeuk.',
 'ipb-edit-dropdown'           => 'Édit alesan meungpeuk',
 'ipb-unblock-addr'            => 'Buka peungpeuk $1',
 'ipb-unblock'                 => 'Nyabut peungpeuk pamaké atawa alamat IP',
@@ -1591,7 +1585,7 @@
 'autoblocker'                 => 'Otomatis dipeungpeuk sabab alamat IP anjeun sarua jeung "$1". Alesan "$2".',
 'blocklogpage'                => 'Log_peungpeuk',
 'blocklogentry'               => 'meungpeuk "$1" nepi ka $2 $3',
-'blocklogtext'                => 'Ieu mangrupa log peta meungpeuk jeung muka peungpeuk pamaké, teu kaasup alamat IP nu dipeungpeukna otomatis. Tempo [[Special:Ipblocklist|daptar peungpeuk IP]] pikeun daptar cegahan jeung peungpeuk.',
+'blocklogtext'                => 'Ieu mangrupa log peta meungpeuk jeung muka peungpeuk pamaké, teu kaasup alamat IP nu dipeungpeukna otomatis. Tempo [[Special:IPBlockList|daptar peungpeuk IP]] pikeun daptar cegahan jeung peungpeuk.',
 'unblocklogentry'             => 'peungpeuk dibuka "$1"',
 'block-log-flags-anononly'    => 'pamaké anonim wungkul',
 'block-log-flags-nocreate'    => 'Nyieun rekening ditumpurkeun',
@@ -1647,8 +1641,6 @@
 
 Dina kajadian kitu, mun hayang (jeung perlu) anjeun kudu mindahkeun atawa ngagabungkeun kacana sacara manual.",
 'movearticle'             => 'Pindahkeun kaca',
-'movenologin'             => 'Can asup log',
-'movenologintext'         => 'Anjeun kudu jadi pamaké nu kadaptar tur [[Special:Userlogin|asup log]] pikeun mindahkeun kaca.',
 'movenotallowed'          => 'Anjeung teu boga kawenangan mindahkeun kaca di {{SITENAME}}.',
 'newtitle'                => 'Ka judul anyar',
 'move-watch'              => 'Awaskeuneun kaca ieu',
@@ -1673,7 +1665,7 @@
 'delete_and_move'         => 'Hapus jeung pindahkeun',
 'delete_and_move_text'    => '==Merlukeun hapusan==
 
-Artikel nu dituju "[[$1]]" geus aya. Badé dihapus baé sangkan bisa mindahkeun?',
+Artikel nu dituju "[[:$1]]" geus aya. Badé dihapus baé sangkan bisa mindahkeun?',
 'delete_and_move_confirm' => 'Enya, hapus kaca éta',
 'delete_and_move_reason'  => 'Hapus sangkan bisa mindahkeun',
 'selfmove'                => 'Judul sumber jeung tujuanana sarua, lain gé mindahkeun atuh!',
@@ -1879,10 +1871,10 @@
 'show-big-image'       => 'Résolusi pinuh',
 'show-big-image-thumb' => '<small>Ukuran ieu pidangan: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeri gambar anyar',
 'imagelisttext'         => "Di handap ieu daptar '''$1''' {{PLURAL:$1|gambar|gambar}} nu disusun $2.",
-'newimages-summary'     => 'Ieu kaca husus ngabéréndélkeun koropak nu alanyar dimuat',
+'newimages-summary'     => 'Ieu kaca husus ngabéréndélkeun koropak nu alanyar dimuat.',
 'showhidebots'          => '($1 bot)',
 'noimages'              => 'Taya nanaon.',
 'ilsubmit'              => 'Sungsi',
@@ -2073,7 +2065,7 @@
 
 # External editor support
 'edit-externally'      => 'Édit koropak ieu migunakeun aplikasi éksternal',
-'edit-externally-help' => 'Tempo [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] pikeun émbaran leuwih jéntré.',
+'edit-externally-help' => 'Tempo [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] pikeun émbaran leuwih jéntré.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'sadaya',
@@ -2133,7 +2125,7 @@
 'recreate'            => 'Jieun deui',
 
 # HTML dump
-'redirectingto' => 'Mindahkeun ka [[$1]]...',
+'redirectingto' => 'Mindahkeun ka [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Hapus sindangan kaca ieu?
@@ -2225,7 +2217,7 @@
 'version-software-product'         => 'Produk',
 'version-software-version'         => 'Vérsi',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Jalur koropak',
 'filepath-page'   => 'Koropak:',
 'filepath-submit' => 'Jalur',
Index: languages/messages/MessagesArz.php
===================================================================
--- languages/messages/MessagesArz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesArz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Alnokta
  * @author Ghaly
+ * @author Meno25
+ * @author Ramsis II
  * @author Ramsis1978
- * @author Alnokta
- * @author Meno25
- * @author Siebrand
  */
 
 $fallback = 'ar';
@@ -162,6 +162,7 @@
 	'hiddencat'           => array( '1', '__تصنيف_مخفي__', '__HIDDENCAT__' ),
 	'pagesincategory'     => array( '1', 'صفحات_في_التصنيف', 'PAGESINCATEGORY', 'PAGESINCAT' ),
 	'pagesize'            => array( '1', 'حجم_الصفحة', 'حجم_صفحة', 'PAGESIZE' ),
+	'staticredirect'      => array( '1', '__تحويلة_إستاتيكية__', '__تحويلة_ساكنة__', '__STATICREDIRECT__' ),
 );
 
 $skinNames = array(
@@ -258,6 +259,7 @@
 	'MergeHistory'              => array( 'دمج_التاريخ' ),
 	'Filepath'                  => array( 'مسار_ملف' ),
 	'Invalidateemail'           => array( 'تعطيل_البريد_الإلكترونى' ),
+	'Blankpage'                 => array( 'صفحة_فارغة' ),
 );
 
 $messages = array(
@@ -538,7 +540,7 @@
 'nosuchspecialpage' => 'مافيش صفحة خاصة بالاسم ده',
 'nospecialpagetext' => "<big>'''انت طلبت صفحة مخصوصة مش صحيحة.'''</big>
 
-لستة الصفحات المخصوصة الصحيحة ممكن تلاقيها في [[Special:Specialpages]].",
+لستة الصفحات المخصوصة الصحيحة ممكن تلاقيها في [[Special:SpecialPages]].",
 
 # General errors
 'error'                => 'غلطة',
@@ -612,6 +614,7 @@
 'titleprotected'       => "العنوان دا محمي من الإنشاء بـ[[User:$1|$1]]. السبب هو ''$2''.",
 
 # Virus scanner
+'virus-badscanner'     => 'غلطه : ماسح فيروسات مش معروف: <i>$1</i>',
 'virus-scanfailed'     => 'المسح فشل(كود $1)',
 'virus-unknownscanner' => 'انتي فيروس مش معروف:',
 
@@ -734,26 +737,24 @@
 'hr_tip'          => 'خط افقى (ما تستعملهموش كتير)',
 
 # Edit pages
-'summary'                   => 'ملخص',
-'subject'                   => ' راس الموضوع/موضوع',
-'minoredit'                 => ' التعديل ده تعديل صغير',
-'watchthis'                 => 'راقب الصفحه دى',
-'savearticle'               => 'سييف الصفحه',
-'preview'                   => 'بروفه',
-'showpreview'               => 'عرض البروفه',
-'showlivepreview'           => 'بروفه حيه',
-'showdiff'                  => 'بيين التعديلات',
-'anoneditwarning'           => "'''تحذير:''' انت ما عملتش لوجين؛ عنوان الااى  بى  بتاعك هايتسجل فى تاريخ الصفحه .",
-'missingsummary'            => "'''خد بالك:''' انت ما كتبتش ملخص للتعديل. لو دوست على حفظ الصفحة مرة تانية التعديل بتاعك ح يتحفظ من غير ملخص.",
-'missingcommenttext'        => 'لو سمحت اكتب تعليق تحت.',
-'missingcommentheader'      => "'''خد بالك:''' انت ما كتبتش عنوان\\موضوع للتعليق دا، لو دوست على حفظ الصفحة مرة تانية، تعليقك ح يتحفظ من غير عنوان.",
-'summary-preview'           => 'بروفه للملخص',
-'subject-preview'           => 'بروفة للعنوان\\الموضوع',
-'blockedtitle'              => 'اليوزر ممنوع',
-'blockedtext'               => "
+'summary'                          => 'ملخص',
+'subject'                          => ' راس الموضوع/موضوع',
+'minoredit'                        => ' التعديل ده تعديل صغير',
+'watchthis'                        => 'راقب الصفحه دى',
+'savearticle'                      => 'سييف الصفحه',
+'preview'                          => 'بروفه',
+'showpreview'                      => 'عرض البروفه',
+'showlivepreview'                  => 'بروفه حيه',
+'showdiff'                         => 'بيين التعديلات',
+'anoneditwarning'                  => "'''تحذير:''' انت ما عملتش لوجين؛ عنوان الااى  بى  بتاعك هايتسجل فى تاريخ الصفحه .",
+'missingsummary'                   => "'''خد بالك:''' انت ما كتبتش ملخص للتعديل. لو دوست على حفظ الصفحة مرة تانية التعديل بتاعك ح يتحفظ من غير ملخص.",
+'missingcommenttext'               => 'لو سمحت اكتب تعليق تحت.',
+'missingcommentheader'             => "'''خد بالك:''' انت ما كتبتش عنوان\\موضوع للتعليق دا، لو دوست على حفظ الصفحة مرة تانية، تعليقك ح يتحفظ من غير عنوان.",
+'summary-preview'                  => 'بروفه للملخص',
+'subject-preview'                  => 'بروفة للعنوان\\الموضوع',
+'blockedtitle'                     => 'اليوزر ممنوع',
+'blockedtext'                      => "<big>'''تم منع اسم اليوزر أو عنوان الااى بى بتاعك .'''</big>
 
-<big>'''تم منع اسم اليوزر أو عنوان الااى بى بتاعك .'''</big>
-
 سبب المنع هو: ''$2''. وقام بالمنع $1.
 
 * بداية المنع: $8
@@ -763,7 +764,7 @@
 ممكن التواصل مع $1 لمناقشة المنع، أو مع واحد من [[{{MediaWiki:Grouppage-sysop}}|الاداريين]] عن المنع>
 افتكر انه مش ممكن تبعت ايميل  لليوزرز الا اذا كنت سجلت عنوان ايميل صحيح فى صفحة [[Special:Preferences|التفضيلات]] بتاعتك.
 عنوان الااى بى بتاعك حاليا هو $3 وكود المنع هو #$5.من فضلك ضيف اى واحد منهم أو كلاهما في اى رسالة للتساؤل عن المنع.",
-'autoblockedtext'           => 'عنوان الأيبي بتاعك اتمنع اتوماتيكي  علشان في يوزر تاني استخدمه واللي هو كمان ممنوع بــ $1.
+'autoblockedtext'                  => 'عنوان الأيبي بتاعك اتمنع اتوماتيكي  علشان في يوزر تاني استخدمه واللي هو كمان ممنوع بــ $1.
 السبب هو:
 
 :\'\'$2\'\'
@@ -777,74 +778,109 @@
 لاحظ أنه مش ممكن استخدام خاصية "ابعت رسالة لليوزر دا" إلا اذا كان عندك ايميل صحيح متسجل في [[Special:Preferences|تفضيلاتك]].
 
 رقم المنع هو $5. لو سمحت تذكر الرقم دا في اي استفسار.',
-'blockednoreason'           => 'ما فيش سبب',
-'blockedoriginalsource'     => "المصدر بتاع '''$1''' معروض تحت:",
-'blockededitsource'         => "نص '''تعديلاتك''' في '''$1''' معروض هنا:",
-'whitelistedittitle'        => 'لازم تسجل دخولك علشان تقدر تعدل',
-'whitelistedittext'         => 'لازم $1 علشان تقدر تعدل الصفحات.',
-'whitelistreadtitle'        => 'تسجيل الدخول لازم  علشان تقرا',
-'whitelistreadtext'         => 'لازم [[Special:Userlogin|تسجيل الدخول]] علشان تقرا الصفحات.',
-'whitelistacctitle'         => 'انت مش مسموح لك تفتح حساب',
-'whitelistacctext'          => 'علشان نسمح لك تفتح حسابات في {{SITENAME}} لازم [[Special:Userlogin|تسجيل الدخول]] وأن يكون عندك الصلاحية المناسبة.',
-'confirmedittitle'          => 'علشان تبتدي تعدل، لازم نتاكد من الايميل بتاعك',
-'confirmedittext'           => 'قبل ما تبتدي تعدل لازم نتأكد من الايميل بتاعك. لو سمحت تكتب وتأكد الايميل بتاعك  في[[Special:Preferences|تفضيلاتك]]',
-'nosuchsectiontitle'        => 'مافيش قسم بالاسم ده',
-'nosuchsectiontext'         => 'انت حاولت تعمل تعديل على قسم مش موجود. و علشان القسم $1 مش موجود اصلاً، فمش ممكن نحفظ التعديلات بتاعتك.',
-'loginreqtitle'             => 'لازم تسجل دخولك',
-'loginreqlink'              => 'ادخل',
-'loginreqpagetext'          => 'لازم تكون $1 علشان تشوف صفحات تانية.',
-'accmailtitle'              => ' كلمة السر اتبعتت .',
-'accmailtext'               => "الباسورد بتاعة '$1' اتبعتت لـ $2.",
-'newarticle'                => '(جديد)',
-'newarticletext'            => "انت وصلت لصفحه مابتدتش لسه.
+'blockednoreason'                  => 'ما فيش سبب',
+'blockedoriginalsource'            => "المصدر بتاع '''$1''' معروض تحت:",
+'blockededitsource'                => "نص '''تعديلاتك''' في '''$1''' معروض هنا:",
+'whitelistedittitle'               => 'لازم تسجل دخولك علشان تقدر تعدل',
+'whitelistedittext'                => 'لازم $1 علشان تقدر تعدل الصفحات.',
+'confirmedittitle'                 => 'علشان تبتدي تعدل، لازم نتاكد من الايميل بتاعك',
+'confirmedittext'                  => 'قبل ما تبتدي تعدل لازم نتأكد من الايميل بتاعك. لو سمحت تكتب وتأكد الايميل بتاعك  في[[Special:Preferences|تفضيلاتك]]',
+'nosuchsectiontitle'               => 'مافيش قسم بالاسم ده',
+'nosuchsectiontext'                => 'انت حاولت تعمل تعديل على قسم مش موجود. و علشان القسم $1 مش موجود اصلاً، فمش ممكن نحفظ التعديلات بتاعتك.',
+'loginreqtitle'                    => 'لازم تسجل دخولك',
+'loginreqlink'                     => 'ادخل',
+'loginreqpagetext'                 => 'لازم تكون $1 علشان تشوف صفحات تانية.',
+'accmailtitle'                     => ' كلمة السر اتبعتت .',
+'accmailtext'                      => "الباسورد بتاعة '$1' اتبعتت لـ $2.",
+'newarticle'                       => '(جديد)',
+'newarticletext'                   => "انت وصلت لصفحه مابتدتش لسه.
 علشان  تبتدى الصفحة ابتدى الكتابه في الصندوق اللى تحت.
 (بص على [[{{MediaWiki:Helppage}}|صفحة المساعده]] علشان معلومات اكتر)
 لو كانت زيارتك للصفحه دى بالخطأ، اضغط على زر ''رجوع'' في متصفح الإنترنت عندك.",
-'anontalkpagetext'          => "----'' صفحة النقاش دي بتاعة يوزر مجهول لسة ما فتحش لنفسه حساب أو عنده واحد بس ما بيستعملوش. علشان كدا لازم تستعمل رقم الأيبي علشان تتعرف عليه/عليها. العنوان دا ممكن اكتر من واحد يكونو بيستعملوه. لو انت يوزر مجهول و حاسس  ان في تعليقات بتتوجهلك مع انك مالكش دعوة بيها ،من فضلك [[Special:Userlogin|افتحلك حساب أو سجل الدخول]] علشان تتجنب اللخبطة اللي ممكن تحصل في المستقبل مع يوزرز مجهولين تانيين.''",
-'noarticletext'             => 'مافيش  دلوقتى اى نص فى  الصفحه دى ، ممكن [[Special:Search/{{PAGENAME}}|تدور على عنوان الصفحه]] في الصفحات التانيه او [{{fullurl:{{FULLPAGENAME}}|action=edit}} تعدل الصفحه دى].',
-'userpage-userdoesnotexist' => 'حساب اليوزر "$1" مش متسجل. لو سمحت تشوف لو عايز تبتدي/تعدل الصفحة دي.',
-'usercssjsyoucanpreview'    => "<strong>ملاحظة:</strong> استعمل زرار ' عرض بروفة' علشان تجرب النمط (CSS) أو الجافا سكريبت الجديد قبل حفظ الصفحة.",
-'usercsspreview'            => "'''افتكرأنك  بتعرض  (CSS) بتاع اليوزر بس وانها لسة ماتحفظتش!'''",
-'userjspreview'             => "'''أفتكر أنك بس بتجرب/بتعرض الجافا سكريبت بتاع اليوزر بتاعك، و انها لسة ماتحفظتش!'''",
-'userinvalidcssjstitle'     => "'''تحذير:'''مافيش واجهة  \"\$1\". افتكر أن ملفات ال.css و ال.js بتستخدم حروف صغيرة في العنوان ، مثلا {{ns:user}}:Foo/monobook.css و مش {{ns:user}}:Foo/Monobook.css.",
-'updated'                   => '(متحدثة)',
-'note'                      => '<strong>ملحوظه:</strong>',
-'previewnote'               => '<strong> دى بروفه للصفحه بس، ولسه ما تسييفتش!</strong>',
-'previewconflict'           => 'البروفة دي بتبينلك فوق إزاي ح يكون شكل النص لو انت دوست على حفظ',
-'editing'                   => 'تعديل $1',
-'editingsection'            => 'تعديل $1 (جزء)',
-'editingcomment'            => 'تعديل $1 (تعليق)',
-'editconflict'              => 'تضارب فى التحرير: $1',
-'yourtext'                  => 'النص بتاعك',
-'storedversion'             => 'النسخة المخزنة',
-'yourdiff'                  => 'الفروق',
-'copyrightwarning'          => 'من فضلك لاحظ ان كل المساهمات فى {{SITENAME}} بتتنشر حسب شروط ترخيص $2 (بص على $1 علشان تعرف  تفاصيل اكتر)
+'anontalkpagetext'                 => "----'' صفحة النقاش دي بتاعة يوزر مجهول لسة ما فتحش لنفسه حساب أو عنده واحد بس ما بيستعملوش. علشان كدا لازم تستعمل رقم الأيبي علشان تتعرف عليه/عليها. العنوان دا ممكن اكتر من واحد يكونو بيستعملوه. لو انت يوزر مجهول و حاسس  ان في تعليقات بتتوجهلك مع انك مالكش دعوة بيها ،من فضلك [[Special:UserLogin|افتحلك حساب أو سجل الدخول]] علشان تتجنب اللخبطة اللي ممكن تحصل في المستقبل مع يوزرز مجهولين تانيين.''",
+'noarticletext'                    => 'مافيش  دلوقتى اى نص فى  الصفحه دى ، ممكن [[Special:Search/{{PAGENAME}}|تدور على عنوان الصفحه]] في الصفحات التانيه او [{{fullurl:{{FULLPAGENAME}}|action=edit}} تعدل الصفحه دى].',
+'userpage-userdoesnotexist'        => 'حساب اليوزر "$1" مش متسجل. لو سمحت تشوف لو عايز تبتدي/تعدل الصفحة دي.',
+'clearyourcache'                   => "'''ملاحظة - بعد التسييف,  يمكن لازم تفرغ كاش متصفحك لرؤية التغييرات.''' '''موزيللا / فايرفوكس / سافارى:''' دوس على ''Shift'' أثناء ضغط ''Reload,'' أو دوس على أيا من ''Ctrl-F5'' أو ''Ctrl-R'' (''Command-R'' على ماكنتوش); '''كونكرر: '''دوس على ''Reload'' أو دوس على ''F5;'' '''أوبرا:''' فرغ الكاش فى ''Tools → Preferences;'' '''إنترنت إكسبلورر:''' دوس على ''Ctrl'' أثناء ضغط ''Refresh,'' أو دوس على ''Ctrl-F5.''",
+'usercssjsyoucanpreview'           => "<strong>ملاحظة:</strong> استعمل زرار ' عرض بروفة' علشان تجرب النمط (CSS) أو الجافا سكريبت الجديد قبل حفظ الصفحة.",
+'usercsspreview'                   => "'''افتكرأنك  بتعرض  (CSS) بتاع اليوزر بس وانها لسة ماتحفظتش!'''",
+'userjspreview'                    => "'''أفتكر أنك بس بتجرب/بتعرض الجافا سكريبت بتاع اليوزر بتاعك، و انها لسة ماتحفظتش!'''",
+'userinvalidcssjstitle'            => "'''تحذير:'''مافيش واجهة  \"\$1\". افتكر أن ملفات ال.css و ال.js بتستخدم حروف صغيرة في العنوان ، مثلا {{ns:user}}:Foo/monobook.css و مش {{ns:user}}:Foo/Monobook.css.",
+'updated'                          => '(متحدثة)',
+'note'                             => '<strong>ملحوظه:</strong>',
+'previewnote'                      => '<strong> دى بروفه للصفحه بس، ولسه ما تسييفتش!</strong>',
+'previewconflict'                  => 'البروفة دي بتبينلك فوق إزاي ح يكون شكل النص لو انت دوست على حفظ',
+'session_fail_preview'             => '<strong>اسف! ما قدرناش  نحفظ التعديلات اللى قمت بيها نتيجة لضياع بيانات  الجلسه.
+الرجاء المحاولة مرة تانيه.
+في حال استمرار المشكلة حاول  تخرج وتدخل مرة تانيه .</strong>',
+'session_fail_preview_html'        => "<strong>اسف ! ماقدرناش نعالج تعديلك بسبب ضياع بيانات الجلسة.</strong>
+
+''لأن {{SITENAME}} بها HTML هل الخام شغاله، البروفه مخفيه كاحتياط ضد هجمات الجافا سكريبت.''
+
+<strong>إذا كانت دى محاولة تعديل صادقه، من فضلك حاول مرة تانيه. إذا كانت لسه مش شغاله، حاول تسجيل الخروج و تسجيل الدخول من جديد.</strong>",
+'token_suffix_mismatch'            => '<strong>تعديلك اترفض لأن عميلك غلط في علامات الترقيم 
+في نص التعديل. التعديل اترفض علشان ما يبوظش نص المقالة.
+دا ساعات بيحصل لما تستعمل خدمة بروكسي مجهولة بايظة أساسها الويب.</strong>',
+'editing'                          => 'تعديل $1',
+'editingsection'                   => 'تعديل $1 (جزء)',
+'editingcomment'                   => 'تعديل $1 (تعليق)',
+'editconflict'                     => 'تضارب فى التحرير: $1',
+'explainconflict'                  => "في واحد تاني عدل الصفحة دي  بعد ما انت ابتديت بتحريرها.
+صندوق النصوص الفوقاني فيه النص الموجود دلوقتي في الصفحة.
+والتغييرات انت عملتها موجودة في الصندوق التحتاني في الصفحة.
+لازم تدمج تغييراتك في النص الموجود دلوقتي.
+'''بس''' اللي موجود في الصندوق الفوقاني هو اللي ح يتحفظ لما تدوس على زرار \"حفظ الصفحة\".",
+'yourtext'                         => 'النص بتاعك',
+'storedversion'                    => 'النسخة المخزنة',
+'nonunicodebrowser'                => '<strong>تحذير: البراوزر بتاعك مش متوافق مع اليونيكود.
+اتعالج الموضوع دا علشان تقدر تعدل الصفحة بامان: الحروف اللي مش ASCII ح تظهر في صندوق التحرير كأكواد سداسية عشرية.</strong>',
+'editingold'                       => '<strong>   تحذير: أنت تقدلوقتي بتحرر نسخة قديمة من  الصفحة دي.
+ ولو حفظتها، ح تضيع كل التغييرات اللي حصلت بعد  النسخة دي. </strong>',
+'yourdiff'                         => 'الفروق',
+'copyrightwarning'                 => 'من فضلك لاحظ ان كل المساهمات فى {{SITENAME}} بتتنشر حسب شروط ترخيص $2 (بص على $1 علشان تعرف  تفاصيل اكتر)
 لو مش عايز كتابتك تتعدل او تتوزع من غير مقابل و بدون اذنك ، ما تحطهاش هنا<br />. كمان انت  بتتعهد بانك كتبت كلام تعديلك بنفسك، او نسخته من مصدر يعتبر ضمن الملكيه العامه، أو مصدر حر تان.
 
 <strong>ما تحطش اى عمل له حقوق محفوظه بدون اذن صاحب الحق</strong>.',
-'copyrightwarning2'         => 'لو سمحت تعمل حسابك ان كل مشاركاتك في {{SITENAME}} ممكن المشاركين التانيين يعدلوها،يغيروها، او يمسحوها خالص. لو مانتش حابب ان كتاباتك تتعدل و تتغير بالشكل دا، فياريت ما تنشرهاش هنا.<br />.
+'copyrightwarning2'                => 'لو سمحت تعمل حسابك ان كل مشاركاتك في {{SITENAME}} ممكن المشاركين التانيين يعدلوها،يغيروها، او يمسحوها خالص. لو مانتش حابب ان كتاباتك تتعدل و تتغير بالشكل دا، فياريت ما تنشرهاش هنا.<br />.
 و كمان انت بتدينا كلمة شرف  انك صاحب الكتابات دي، او انك نقلتها من مكان مش خاضع لحقوق النشر .(شوف التفاصيل في $1 ).
 <strong>لو سمحت ما تحطش هنا اي نص خاضع لحقوق النشر من غير تصريح!</strong>.',
-'longpagewarning'           => '
+'longpagewarning'                  => '
 <strong>تحذير: الصفحه دى حجمها $1 كيلوبايت، بعض المتصفحات (براوزرز) ممكن تواجه مشاكل لما تحاول تعديل صفحات يزيد حجمها عن 32 كيلوبايت. من فضلك ,لو امكن قسم الصفحة لصفحات اصغر فى الحجم.</strong>',
-'templatesused'             => 'القوالب المستعمله في الصفحه دى:',
-'templatesusedpreview'      => 'القوالب المستعمله فى البروفه دى:',
-'templatesusedsection'      => 'القوالب اللي بتستخدم في القسم دا:',
-'template-protected'        => '(حمايه كامله)',
-'template-semiprotected'    => '(حمايه جزئيه )',
-'nocreatetitle'             => 'إنشاء الصفحات اتحدد',
-'nocreatetext'              => '{{SITENAME}} حدد القدره على انشاء صفحات جديده.
-ممكن ترجع وتحرر صفحه موجوده بالفعل، او [[Special:Userlogin|الدخول / فتح حساب]].',
-'nocreate-loggedin'         => 'انت ما عندك ش صلاحية تعمل صفحات جديدة في {{SITENAME}}.',
-'permissionserrors'         => 'غلطات فى السماح',
-'permissionserrorstext'     => 'ما عندك ش صلاحية تعمل كدا،{{PLURAL:$1|علشان|علشان}}:',
-'recreate-deleted-warn'     => "'''تحذير: انت بتعيد انشاء صفحه اتمسحت قبل كده.'''
+'longpageerror'                    => '<strong>غلط: النص اللي دخلته حجمه $1 كيلوبايت، ودا أكبر من الحد الأقصى و اللي هو $2 كيلوبايت.
+مش ممكن يتحفظ.</strong>',
+'readonlywarning'                  => '<strong>تحذير: قاعدة البيانات اتقفلت للصيانة، و علشان كدا انت مش ح تقدر تحفظ التعديلات اللي عملتها دلوقاي.
+لو حبيت ممكن  تنسخ النص وتحفظه في ملف نصي علشان تستعمله بعدين.</strong>',
+'protectedpagewarning'             => '<strong>تحذير:الصفحة دا اتقفلت بطريقة تخلى اليوزرز السيسوبات هم بس اللي يقدرو يعدلوها.</strong>',
+'semiprotectedpagewarning'         => "'''ملاحظة:''' الصفحة  دي اتقفلت بطريقة تخلي اليوزرز المتسجلين بس هم اللي قدرو يعدلوها.",
+'titleprotectedwarning'            => '<strong>تحذير: الصفحة اتقفلت علشان مش كل اليوزرز يقدرو ينشأوها .</strong>',
+'templatesused'                    => 'القوالب المستعمله في الصفحه دى:',
+'templatesusedpreview'             => 'القوالب المستعمله فى البروفه دى:',
+'templatesusedsection'             => 'القوالب اللي بتستخدم في القسم دا:',
+'template-protected'               => '(حمايه كامله)',
+'template-semiprotected'           => '(حمايه جزئيه )',
+'hiddencategories'                 => ' الصفحه دى موجوده فى {{PLURAL:$1|تصنيف مخفى واحد|$1 تصنيف مخفى}}:',
+'nocreatetitle'                    => 'إنشاء الصفحات اتحدد',
+'nocreatetext'                     => '{{SITENAME}} حدد القدره على انشاء صفحات جديده.
+ممكن ترجع وتحرر صفحه موجوده بالفعل، او [[Special:UserLogin|الدخول / فتح حساب]].',
+'nocreate-loggedin'                => 'انت ما عندك ش صلاحية تعمل صفحات جديدة في {{SITENAME}}.',
+'permissionserrors'                => 'غلطات فى السماح',
+'permissionserrorstext'            => 'ما عندك ش صلاحية تعمل كدا،{{PLURAL:$1|علشان|علشان}}:',
+'permissionserrorstext-withaction' => 'أنت ما عندكش الصلاحيات ل$2، لل{{PLURAL:$1|سبب|أسباب}} دي:',
+'recreate-deleted-warn'            => "'''تحذير: انت بتعيد انشاء صفحه اتمسحت قبل كده.'''
 لازم تتأكد من ان الاستمرار فى تحرير الصفحه دى ملائم.
 سجل الحذف للصفحه دى معروض هنا:",
 
 # Parser/template warnings
-'post-expand-template-argument-category' => 'صفحات فيها مناقشات القالب المحذوفة',
+'expensive-parserfunction-warning'        => 'تحذير: الصفحه دى فيهااستدعاءات دالة محلل كثيرة مكلفة.
 
+لازم تكون أقل من $2، فيها دلوقتى $1.',
+'expensive-parserfunction-category'       => 'صفحات فيها استدعاءات دوال محلل كثيرة ومكلفة',
+'post-expand-template-inclusion-warning'  => 'تحذير: حجم تضمين القالب كبير قوي.
+بعض القوالب مش ح تتضمن.',
+'post-expand-template-inclusion-category' => 'الصفحات اللى تم تجاوز حجم تضمين القالب فيها',
+'post-expand-template-argument-warning'   => 'تحذير: الصفحة  دي فيها عامل قالب واحد على الأقل ليه حجم تمدد كبير قوي.
+العوامل دي اتمسحت.',
+'post-expand-template-argument-category'  => 'صفحات فيها مناقشات القالب المحذوفة',
+
 # "Undo" feature
 'undo-success' => 'ممكن ترجع في التعديل. لو سمحت تشوف المقارنة اللي تحت علشان تتأكد من إن هو دا اللي إنت عايز تعمله ،وبعدين احفظ التغييرات اللي تحت علشان ترجع في التعديل.',
 'undo-failure' => 'الرجوع في التعديل ما نفعش علشان في تعديلات متعاكسة حصلت في الصفحة.',
@@ -905,20 +941,35 @@
 'rev-delundel'                => 'عرض/إخفاء',
 'revisiondelete'              => 'امسح/الغي المسح بتاع المراجعات',
 'revdelete-nooldid-title'     => 'مراجعة هدف مش صح',
+'revdelete-nooldid-text'      => 'أنت ياإما ما حددتش مراجعة (مراجعات) معينة كهدف للفعل دا، المراجعة المحددة مش موجودة، أو أنك بتحاول تخبي المراجعة الحالية.',
+'revdelete-selected'          => '{{PLURAL:$2|المراجعة المختارة|المراجعات المختارة}} ل[[:$1]]:',
+'logdelete-selected'          => '{{PLURAL:$1|حدث السجل المختار|أحداث السجل المختارة}}:',
+'revdelete-text'              => 'المراجعات والأحداث الممسوحة هاتفضل تظهر فى تاريخ الصفحة والسجلات،
+لكن أجزاء من محتواهم مش هايكون مسموح للعامة يشوفوها.
+
+الإداريون التانين في {{SITENAME}}هايفضل بإمكانهم رؤية المحتوى المخفى وممكن يسترجعوه من جديد من خلال الواجهة نفسها، الا اذا تم وضع قيود إضافية.',
 'revdelete-legend'            => 'وضع حدود رؤية',
 'revdelete-hide-text'         => 'إخفاء نص النسخة',
 'revdelete-hide-name'         => 'تخبية الإجراء والهدف منه',
-'revdelete-hide-comment'      => 'إخفاء تعليق التعديل',
+'revdelete-hide-comment'      => 'خبي تعليق التعديل',
 'revdelete-hide-user'         => 'خبي اسم/عنوان الاي بي بتاع اليوزر',
+'revdelete-hide-restricted'   => 'طبق الضوابط  دي على السيسوبات واقفل الواجهة دي',
+'revdelete-suppress'          => 'تخبية البيانات عن السيسوبات و اليوزرز التانيين',
 'revdelete-hide-image'        => 'خبي المحتويات بتاعة الملف',
+'revdelete-unsuppress'        => 'إزالة الضوابط من المراجعات المسترجعة',
 'revdelete-log'               => 'تعليق  على السجل:',
 'revdelete-submit'            => 'طبق على النسخه المختاره',
+'revdelete-logentry'          => 'غير رؤية المراجعة ل[[$1]]',
+'logdelete-logentry'          => 'غير رؤية الحدث ل[[$1]]',
+'revdelete-success'           => "''' رؤية المراجعات اتظبطت بنجاح.'''",
+'logdelete-success'           => "'''رؤية السجلات اتظبطت بنجاح.'''",
 'revdel-restore'              => 'تغيير الرؤية',
 'pagehist'                    => 'تاريخ الصفحة',
 'deletedhist'                 => 'التاريخ الممسوح',
 'revdelete-content'           => 'محتويات',
 'revdelete-summary'           => 'ملخص التعديل',
 'revdelete-uname'             => 'اسم اليوزر',
+'revdelete-restricted'        => 'طبق التعليمات على السيسوبات',
 'revdelete-unrestricted'      => 'شيل الضوابط من على السيسوبات',
 'revdelete-hid'               => 'أخفى $1',
 'revdelete-unhid'             => 'أظهر $1',
@@ -928,22 +979,36 @@
 # Suppression log
 'suppressionlog'     => 'سجل الإخفاء',
 'suppressionlogtext' => 'تحت في لستة بعمليات المسح والمنع اللي فيها محتوى مستخبي على الإداريين.
-شوف [[Special:Ipblocklist|للستة المنع]] علشان تشوف عمليات المنع الشغالة دلوقتي .',
+شوف [[Special:IPBlockList|للستة المنع]] علشان تشوف عمليات المنع الشغالة دلوقتي .',
 
 # History merging
-'mergehistory'             => 'دمج تواريخ الصفحة',
-'mergehistory-from'        => 'الصفحه المصدر:',
-'mergehistory-into'        => 'الصفحه الهدف:',
-'mergehistory-list'        => 'تاريخ التعديل اللي ممكن يتدمج',
-'mergehistory-go'          => 'عرض التعديلات اللي ممكن تتدمج',
-'mergehistory-submit'      => 'دمج النسخ',
-'mergehistory-autocomment' => 'دمج [[:$1]] في [[:$2]]',
-'mergehistory-comment'     => 'دمج [[:$1]] في [[:$2]]: $3',
+'mergehistory'                     => 'دمج تواريخ الصفحة',
+'mergehistory-header'              => ' الصفحةدي  بتسمح لك بدمج نسخ تاريخ صفحة  في صفحة تانية.
+اتأكد من أن التغيير دا ح يحافظ على استمرارية تاريخ الصفحة.',
+'mergehistory-box'                 => 'دمج تعديلات صفحتين:',
+'mergehistory-from'                => 'الصفحه المصدر:',
+'mergehistory-into'                => 'الصفحه الهدف:',
+'mergehistory-list'                => 'تاريخ التعديل اللي ممكن يتدمج',
+'mergehistory-merge'               => 'المراجعات دي من [[:$1|$1]] ممكن دمجها مع[[:$2|$2]].
+استخدم عامود الصناديق لدمج المراجعات التي اتنشأت في وقبل الوقت المحدد.
+خد بالك من إن استخدام وصلات التصفح ح يعيد ضبط  العامود دا.',
+'mergehistory-go'                  => 'عرض التعديلات اللي ممكن تتدمج',
+'mergehistory-submit'              => 'دمج النسخ',
+'mergehistory-empty'               => 'مافيش مراجعات ممكن دمجها.',
+'mergehistory-success'             => '$3 {{PLURAL:$3|مراجعة|مراجعة}} من [[:$1]] تم دمجها بنجاح في [[:$2]].',
+'mergehistory-fail'                => 'مش قادر يعمل دمج للتاريخ، لو سمحت تتأكد تاني من محددات الصفحة والزمن.',
+'mergehistory-no-source'           => 'الصفحة المصدر $1  مش موجودة.',
+'mergehistory-no-destination'      => 'الصفحه الهدف $1 مش موجوده.',
+'mergehistory-invalid-source'      => 'الصفحه المصدر لازم تكون عنوان صحيح.',
+'mergehistory-invalid-destination' => 'الصفحة الهدف لازم تكون عنوانها صحيح.',
+'mergehistory-autocomment'         => 'دمج [[:$1]] في [[:$2]]',
+'mergehistory-comment'             => 'دمج [[:$1]] في [[:$2]]: $3',
 
 # Merge log
 'mergelog'           => 'سجل الدمج',
 'pagemerge-logentry' => 'دمج [[$1]] لـ [[$2]] (النسخ حتى $3)',
 'revertmerge'        => 'استرجاع الدمج',
+'mergelogpagetext'   => 'في تحت لستة بأحدث عمليات الدمج لتاريخ صفحة في التانية.',
 
 # Diffs
 'history-title'           => 'تاريخ تعديل "$1"',
@@ -960,6 +1025,7 @@
 'searchsubtitleinvalid'     => "انت دورت على '''$1'''",
 'noexactmatch'              => "'''مافيش  صفحه بالاسم \"\$1\"'''. ممكن [[:\$1| تبتدى الصفحه دى]].",
 'noexactmatch-nocreate'     => "'''مافيش صفحة بالاسم \"\$1\".'''",
+'toomanymatches'            => 'لقينا حاجات كتيرة متطابقة، لو سمحت تجرب استعلام مختلف',
 'titlematches'              => 'عنوان الصفحة زى',
 'notitlematches'            => 'مالقيناش ولا عنوان صفحة مطابق:',
 'textmatches'               => 'نص الصفحة بيطابق',
@@ -998,7 +1064,7 @@
 'mypreferences'            => 'تفضيلاتى',
 'prefs-edits'              => 'عدد التعديلات:',
 'prefsnologin'             => 'مش متسجل',
-'prefsnologintext'         => 'لازم تكون [[Special:Userlogin|متسجل]] علشان تقدر تعدل تفضيلاتك .',
+'prefsnologintext'         => 'لازم تكون [[Special:UserLogin|متسجل]] علشان تقدر تعدل تفضيلاتك .',
 'prefsreset'               => 'التفضيلات اترجعت تاني زي الأول',
 'qbsettings'               => 'البار السريع',
 'qbsettings-none'          => 'ما في ش',
@@ -1017,7 +1083,10 @@
 'math_unknown_function'    => 'وظيفة مش معروفة',
 'math_lexing_error'        => 'غلط في الكلمة',
 'math_syntax_error'        => 'غلط في تركيب الجملة',
+'math_image_error'         => 'فشل التحويل لـ PNG ؛ 
+اتاكد من التثبيت المضبوط لـ :Latex و dvips و gs و convert.',
 'math_bad_tmpdir'          => 'مش ممكن الكتابة أو انشاء مجلد الرياضة الموؤقت',
+'math_bad_output'          => 'مش ممكن الكتابة لـ أو إنشاء مجلد الخرج للرياضيات',
 'math_notexvc'             => 'ضايعtexvc executable؛ لو سمحت شوف math/README to configure.',
 'prefs-personal'           => 'البروفيل بتاع اليوزر',
 'prefs-rc'                 => 'اخر التغييرات',
@@ -1063,10 +1132,14 @@
 'userrights-editusergroup'    => 'تعديل مجموعات اليوزر',
 'saveusergroups'              => 'حفظ مجموعات اليوزر',
 'userrights-groupsmember'     => 'عضو في:',
+'userrights-groups-help'      => 'إنت ممكن تغير المجموعات اللي اليوزر دا عضو فيها .
+* صندوق متعلم يعني اليوزر دا عضو في المجموعة دي.
+* صندوق مش متعلم يعني  اليوزر دا مش عضو في المجموعة دي.
+* علامة * يعنى انك مش ممكن تشيل المجموعات بعد ما تضيفها و العكس بالعكس.',
 'userrights-reason'           => 'سبب التغيير:',
 'userrights-no-interwiki'     => 'أنت  مش من حقك تعدل صلاحيات اليوزرز على الويكيات التانية.',
 'userrights-nodatabase'       => 'قاعدة البيانات $1  مش موجودة أو مش محلية.',
-'userrights-nologin'          => 'انت لازم [[Special:Userlogin|تسجيل الدخول]] بحساب  مدير لتعديل حقوق اليوزر.',
+'userrights-nologin'          => 'انت لازم [[Special:UserLogin|تسجيل الدخول]] بحساب  مدير لتعديل حقوق اليوزر.',
 'userrights-notallowed'       => 'حسابك  ماعندوش  إذن لتعديل حقوق اليوزر.',
 'userrights-changeable-col'   => 'المجموعات اللي تقدر تغييرها',
 'userrights-unchangeable-col' => 'المجموعات اللى مش ممكن انك تغيرها',
@@ -1096,67 +1169,91 @@
 'grouppage-suppress'      => '{{ns:project}}:أوفرسايت',
 
 # Rights
-'right-read'             => 'قراية الصفحات',
-'right-edit'             => 'تعديل الصفحات',
-'right-createpage'       => 'إبتدي الصفحات (اللي مالهاش صفحات نقاش)',
-'right-createtalk'       => 'إبتدى صفحات النقاش',
-'right-createaccount'    => 'افتح حسابات يوزر جديده',
-'right-minoredit'        => 'التعليم على التعديلات كطفيفة',
-'right-move'             => 'انقل الصفحات',
-'right-move-subpages'    => 'انقل الصفحات مع صفحاتها الفرعيه',
-'right-upload'           => 'حمل الملفات',
-'right-reupload'         => 'الكتابة على ملف موجود',
-'right-reupload-own'     => 'الكتابة على ملف موجود اتحمل ب اليوزر نفسه',
-'right-autoconfirmed'    => 'تعديل الصفحات  النص محميه',
-'right-bot'              => 'بتتعامل كأنها عملية أوتوماتيكية',
-'right-writeapi'         => 'استخدام API الكتابة',
-'right-delete'           => 'مسح الصفحات',
-'right-bigdelete'        => 'مسح الصفحات اللي ليها تواريخ كبيرة',
-'right-deleterevision'   => 'مسح وترجيع مراجعات معينة من الصفحات',
-'right-deletedhistory'   => 'شوف مدخلات التاريخ الممسوحة، من غير النصوص اللي معاها',
-'right-browsearchive'    => 'التدوير في الصفحات الممسوحة',
-'right-undelete'         => 'استرجاع صفحة',
-'right-suppressrevision' => 'مراجعة واسترجاع المراجعات المستخبية عن الإداريين',
-'right-suppressionlog'   => 'شوف السجلات الخاصة',
-'right-block'            => 'امنع اليوزرز التانيين من التعديل',
-'right-ipblock-exempt'   => 'إتفادى عمليات منع الأيبي، المنع الأوتوماتيكي ومنع النطاق.',
-'right-proxyunbannable'  => 'إتفادى عمليات المنع الأوتوماتيكية للبروكسيهات',
-'right-protect'          => 'تغيير مستويات الحماية وتعديل الصفحات المحمية',
-'right-editprotected'    => 'تعديل الصفحات المحمية (من غير الحماية المتضمنة)',
-'right-editinterface'    => 'تعديل الواجهة بتاعة اليوزر',
-'right-import'           => 'استيراد الصفحات من ويكيات تانيه',
-'right-importupload'     => 'استيراد الصفحات من فايل متحمل',
-'right-unwatchedpages'   => 'بين لستة الصفحات اللي مش متراقبة',
-'right-userrights'       => 'تعديل كل الحقوق بتاعة اليوزر',
-'right-siteadmin'        => 'قفل وفتح قاعدة البيانات',
+'right-read'                 => 'قراية الصفحات',
+'right-edit'                 => 'تعديل الصفحات',
+'right-createpage'           => 'إبتدي الصفحات (اللي مالهاش صفحات نقاش)',
+'right-createtalk'           => 'إبتدى صفحات النقاش',
+'right-createaccount'        => 'افتح حسابات يوزر جديده',
+'right-minoredit'            => 'التعليم على التعديلات كطفيفة',
+'right-move'                 => 'انقل الصفحات',
+'right-move-subpages'        => 'انقل الصفحات مع صفحاتها الفرعيه',
+'right-suppressredirect'     => 'ما تعملش تحويلة من الاسم القديم عند نقل صفحة',
+'right-upload'               => 'حمل الملفات',
+'right-reupload'             => 'الكتابة على ملف موجود',
+'right-reupload-own'         => 'الكتابة على ملف موجود اتحمل ب اليوزر نفسه',
+'right-reupload-shared'      => 'التحميل على الملفات في مخزن الملفات المشترك  في المكان دا بس',
+'right-upload_by_url'        => 'تحميل ملف من عنوان مسار',
+'right-purge'                => 'تحديث كاش الموقع لصفحة من غير تأكيد',
+'right-autoconfirmed'        => 'تعديل الصفحات  النص محميه',
+'right-bot'                  => 'بتتعامل كأنها عملية أوتوماتيكية',
+'right-nominornewtalk'       => 'ماتخليش التعديلات الطفيفة لصفحات النقاش تتطلع برواز الرسايل الجديدة',
+'right-apihighlimits'        => 'استخدام حدود أعلى فى استعلامات API',
+'right-writeapi'             => 'استخدام API الكتابة',
+'right-delete'               => 'مسح الصفحات',
+'right-bigdelete'            => 'مسح الصفحات اللي ليها تواريخ كبيرة',
+'right-deleterevision'       => 'مسح وترجيع مراجعات معينة من الصفحات',
+'right-deletedhistory'       => 'شوف مدخلات التاريخ الممسوحة، من غير النصوص اللي معاها',
+'right-browsearchive'        => 'التدوير في الصفحات الممسوحة',
+'right-undelete'             => 'استرجاع صفحة',
+'right-suppressrevision'     => 'مراجعة واسترجاع المراجعات المستخبية عن الإداريين',
+'right-suppressionlog'       => 'شوف السجلات الخاصة',
+'right-block'                => 'امنع اليوزرز التانيين من التعديل',
+'right-blockemail'           => 'منع يوزر من إنه يبعت إيميل',
+'right-hideuser'             => 'منع اسم يوزر، و خبيه عن الناس',
+'right-ipblock-exempt'       => 'إتفادى عمليات منع الأيبي، المنع الأوتوماتيكي ومنع النطاق.',
+'right-proxyunbannable'      => 'إتفادى عمليات المنع الأوتوماتيكية للبروكسيهات',
+'right-protect'              => 'تغيير مستويات الحماية وتعديل الصفحات المحمية',
+'right-editprotected'        => 'تعديل الصفحات المحمية (من غير الحماية المتضمنة)',
+'right-editinterface'        => 'تعديل الواجهة بتاعة اليوزر',
+'right-editusercssjs'        => 'تعديل ملفات CSS و JS لليوزرز التانيين',
+'right-rollback'             => 'رجع بسرعه التعديلات بتاعة آخر يوزر عدل صفحة معينة',
+'right-markbotedits'         => 'التعليم على التعديلات المترجعة كتعديلات بوت',
+'right-noratelimit'          => 'مش متأثر بحدود المعدل',
+'right-import'               => 'استيراد الصفحات من ويكيات تانيه',
+'right-importupload'         => 'استيراد الصفحات من فايل متحمل',
+'right-patrol'               => 'علم على تعديلات اليوزرز التانيين على انها متراجعة.',
+'right-autopatrol'           => 'خلى التعديلات  بتاعتي متعلم عليها كأنها متراجعة أوتوماتيكي',
+'right-patrolmarks'          => 'عرض علامات المراجعة في أحدث التغييرات',
+'right-unwatchedpages'       => 'بين لستة الصفحات اللي مش متراقبة',
+'right-trackback'            => 'تنفيذ تراكباك',
+'right-mergehistory'         => 'ادمج تاريخ الصفحات',
+'right-userrights'           => 'تعديل كل الحقوق بتاعة اليوزر',
+'right-userrights-interwiki' => 'تعديل صلاحيات اليوزر لليوزرز فى مواقع الويكى التانيه',
+'right-siteadmin'            => 'قفل وفتح قاعدة البيانات',
 
 # User rights log
-'rightslog'  => 'سجل صلاحيات اليوزرز',
-'rightsnone' => '(فاضى)',
+'rightslog'      => 'سجل صلاحيات اليوزرز',
+'rightslogtext'  => 'ده سجل بالتغييرات ف صلاحيات اليوزرز .',
+'rightslogentry' => 'غير صلاحيات $1 من $2 ل $3',
+'rightsnone'     => '(فاضى)',
 
 # Recent changes
-'nchanges'                       => '{{PLURAL:$1|تعديل|تعديلين|$1 تعديلات|$1 تعديل|$1 تعديل}}',
-'recentchanges'                  => 'احدث التعديلات',
-'recentchanges-feed-description' => 'تابع احدث التعديلات للويكى ده عن طريق الفييد ده .',
-'rcnote'                         => "فيه تحت {{PLURAL:$1|'''1''' تعديل|آخر '''$1''' تعديل}} في اخر {{PLURAL:$2|يوم|'''$2''' يوم}}، بدايه من $3.",
-'rcnotefrom'                     => "دى التعديلات من '''$2''' (ل '''$1''' معروضه).",
-'rclistfrom'                     => 'اظهر التعديلات بدايه من $1',
-'rcshowhideminor'                => '$1 تعديلات صغيره',
-'rcshowhidebots'                 => '$1 البوتات',
-'rcshowhideliu'                  => '$1 اليوزرز المتسجلين',
-'rcshowhideanons'                => '$1 اليوزرز المجهولين',
-'rcshowhidepatr'                 => '$1 التعديلات المتراجعه',
-'rcshowhidemine'                 => '$1 تعديلاتى',
-'rclinks'                        => 'بيين اخر $1 تعديل في اخر $2 يوم، $3',
-'diff'                           => 'التغيير',
-'hist'                           => 'تاريخ',
-'hide'                           => 'تخبيه',
-'show'                           => 'عرض',
-'minoreditletter'                => 'ص',
-'newpageletter'                  => 'ج',
-'boteditletter'                  => 'ب',
-'rc_categories_any'              => 'أى',
-'newsectionsummary'              => '/* $1 */ قسم جديد',
+'nchanges'                          => '{{PLURAL:$1|تعديل|تعديلين|$1 تعديلات|$1 تعديل|$1 تعديل}}',
+'recentchanges'                     => 'احدث التعديلات',
+'recentchangestext'                 => 'تابع آخر التغييرات في الويكي على الصفحة دي.',
+'recentchanges-feed-description'    => 'تابع احدث التعديلات للويكى ده عن طريق الفييد ده .',
+'rcnote'                            => "فيه تحت {{PLURAL:$1|'''1''' تعديل|آخر '''$1''' تعديل}} في اخر {{PLURAL:$2|يوم|'''$2''' يوم}}، بدايه من $3.",
+'rcnotefrom'                        => "دى التعديلات من '''$2''' (ل '''$1''' معروضه).",
+'rclistfrom'                        => 'اظهر التعديلات بدايه من $1',
+'rcshowhideminor'                   => '$1 تعديلات صغيره',
+'rcshowhidebots'                    => '$1 البوتات',
+'rcshowhideliu'                     => '$1 اليوزرز المتسجلين',
+'rcshowhideanons'                   => '$1 اليوزرز المجهولين',
+'rcshowhidepatr'                    => '$1 التعديلات المتراجعه',
+'rcshowhidemine'                    => '$1 تعديلاتى',
+'rclinks'                           => 'بيين اخر $1 تعديل في اخر $2 يوم، $3',
+'diff'                              => 'التغيير',
+'hist'                              => 'تاريخ',
+'hide'                              => 'تخبيه',
+'show'                              => 'عرض',
+'minoreditletter'                   => 'ص',
+'newpageletter'                     => 'ج',
+'boteditletter'                     => 'ب',
+'sectionlink'                       => '←',
+'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1| يوزر مراقب|يوزر مراقب}}]',
+'rc_categories'                     => 'حصر لتصنيفات (مفصولة برمز "|")',
+'rc_categories_any'                 => 'أى',
+'newsectionsummary'                 => '/* $1 */ قسم جديد',
 
 # Recent changes linked
 'recentchangeslinked'          => 'تعديلات  ليها علاقه',
@@ -1164,54 +1261,151 @@
 'recentchangeslinked-noresult' => 'مافيش تعديلات حصلت فى الصفحات اللى ليها وصلات هنا خلال الفترة المحدده.',
 'recentchangeslinked-summary'  => "دى صفحة مخصوصه بتعرض اخر التغييرات في الصفحات الموصوله. الصفحات اللى   فى  لسته بالصفحات اللى انت بتراقب التعديلات فيها معروضه''' بحروف عريضه'''",
 'recentchangeslinked-page'     => 'اسم الصفحه :',
+'recentchangeslinked-to'       => 'إظهارالتغييرات للصفحات الموصولة للصفحة اللي انت اديتها',
 
 # Upload
-'upload'             => 'حمل',
-'uploadbtn'          => 'حمل الملف',
-'reupload'           => 'حمل مره تانيه',
-'uploaderror'        => 'غلطه فى التحميل',
-'upload-prohibited'  => 'أنواع الملفات الممنوعة: $1.',
-'uploadlog'          => 'سجل التحميل',
-'uploadlogpage'      => 'سجل التحميل',
-'uploadlogpagetext'  => 'تحت في لستة بأحدث عمليات تحميل الملفات.',
-'filename'           => 'اسم الملف',
-'filedesc'           => 'الخلاصة',
-'fileuploadsummary'  => 'الخلاصة:',
-'filestatus'         => 'حالة حقوق النسخ:',
-'filesource'         => 'مصدر:',
-'uploadedfiles'      => 'الملفات المتحملة',
-'ignorewarning'      => 'إتجاهل التحذير و احفظ الملف وخلاص',
-'ignorewarnings'     => 'اتجاهل اى تحذير',
-'minlength1'         => 'أسامي الملفات لازم تكون متكونة من حرف واحد على الأقل.',
-'successfulupload'   => 'التحميل ناجح',
-'uploadwarning'      => 'تحذير التحميل',
-'savefile'           => 'حفظ الملف',
-'uploadedimage'      => 'اتحمل "[[$1]]"',
-'overwroteimage'     => 'اتحملت  نسخة جديدة من "[[$1]]"',
-'uploaddisabled'     => 'التحميل متعطل',
-'uploaddisabledtext' => 'تحميل الملفات متعطل في {{SITENAME}}.',
-'uploadscripted'     => 'الملف دا  فيه كود HTML أو كود تاني يمكن البراوزر يفهمه غلط.',
-'uploadcorrupt'      => 'الملف دا  بايظ أو ليه امتداد غلط. لو سمحت ا تأكد من الملف و حمله مرة تانية.',
-'uploadvirus'        => 'الملف فيه فيروس! التفاصيل: $1',
-'sourcefilename'     => 'اسم الملف  بتاع المصدر:',
-'watchthisupload'    => 'حط الصفحة دي تحت المراقبة',
+'upload'                      => 'حمل',
+'uploadbtn'                   => 'حمل الملف',
+'reupload'                    => 'حمل مره تانيه',
+'reuploaddesc'                => 'إلغى التحميل وارجع لاستمارة التحميل',
+'uploadnologin'               => 'ما سجلتش الدخول',
+'uploadnologintext'           => 'لازم تكون [[Special:UserLogin|مسجل الدخول]] علشان تقدر تحمل الملفات.',
+'upload_directory_missing'    => 'مجلد التحميل($1) ضايع السيرفير وماقدرش يعمل واحد تاني.',
+'upload_directory_read_only'  => 'مجلد التحميل ($1) مش ممكن الكتابة عليه بواسطة سيرڨر الويب.',
+'uploaderror'                 => 'غلطه فى التحميل',
+'uploadtext'                  => "استخدم الاستمارة لتحميل الملفات.
+لعرض أو البحث ف الملفات المتحملة سابقا، راجع [[Special:ImageList|قايمة الملفات المتحملة]]، عمليات التحميل والحذف موجودة في [[Special:Log/upload|سجل التحميل]].
 
-'upload-proto-error' => 'بروتوكول مش صحيح',
+علشان تحط صورة في صفحة، استخدم الوصلات في الصيغ التالية:
+'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>'''،
+'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|نص بديل]]</nowiki>''' أو
+'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' للوصل للملف مباشرة.",
+'upload-permitted'            => 'أنواع الملفات المسموحة: $1.',
+'upload-preferred'            => 'أنواع الملفات المفضلة: $1.',
+'upload-prohibited'           => 'أنواع الملفات الممنوعة: $1.',
+'uploadlog'                   => 'سجل التحميل',
+'uploadlogpage'               => 'سجل التحميل',
+'uploadlogpagetext'           => 'تحت فية لستة بأحدث عمليات تحميل الملفات.',
+'filename'                    => 'اسم الملف',
+'filedesc'                    => 'الخلاصة',
+'fileuploadsummary'           => 'الخلاصة:',
+'filestatus'                  => 'حالة حقوق النسخ:',
+'filesource'                  => 'مصدر:',
+'uploadedfiles'               => 'الملفات المتحملة',
+'ignorewarning'               => 'إتجاهل التحذير و احفظ الملف وخلاص',
+'ignorewarnings'              => 'اتجاهل اى تحذير',
+'minlength1'                  => 'أسامي الملفات لازم تكون متكونة من حرف واحد على الأقل.',
+'illegalfilename'             => 'اسم الملف "$1" فيه علامات  مش مسموح بيها في عناوين الصفحات.
+لو سمحت تختار اسم تاني للمف و بعدين تحمله من اول و جديد.',
+'badfilename'                 => ' اسم الملف إتغيير ل "$1".',
+'filetype-badmime'            => 'مش مسموح تحميل ملفات من نوع "$1".',
+'filetype-unwanted-type'      => "'''\".\$1\"''' هو مش نوع ملف مرغوب فيه.
+{{PLURAL:\$3|نوع الملف المفضل هو|أنواع الملفات المفضلة هي}} \$2.",
+'filetype-banned-type'        => "'''\".\$1\"''' مش نوع ملف مسموح بيه.
+{{PLURAL:\$3|نوع الملف المسموح بيه هو|أنواع الملفات المسموح بيها هي}} \$2.",
+'filetype-missing'            => 'الملف مالوش امتدا(مثلا ".jpg").',
+'large-file'                  => 'ينصح ان الملفات ماتكونش أكبر من $1؛ الملف ده حجمه $2.',
+'largefileserver'             => 'حجم الملف ده أكبر من المسموح بيه على السيرڨر ده .',
+'emptyfile'                   => 'الظاهر ان الملف اللي انت حملته طلع فاضي.
+يمكن يكون السبب هوه كتابة الاسم غلط.
+لو سمحت تتاكد من إنك فعلا عايز تحمل الملف دا..',
+'fileexists'                  => 'فيه  ملف موجود بالاسم ده  الرجاء التأكد من الملف ده باتباع الوصلة التالية <strong><tt>$1</tt></strong> قبل ما تغيره.',
+'filepageexists'              => 'صفحة الوصف بتاعة المف دا خلاص اتعملها انشاء في <strong><tt>$1</tt></strong>، بس مافيش ملف بالاسم دا دلوقتى.
+الملخص اللي ح تكتبه  مش ح يظهر على صفحة الوصف.
+علشان تخلى الملف يظهر هناك، ح تحتاج تعدله يدوي.',
+'fileexists-extension'        => 'في ملف موجود باسم قريب:<br />
+اسم الملف اللي انت عايز تحمله: <strong><tt>$1</tt></strong><br />
+اسم الملف الموجود: <strong><tt>$2</tt></strong><br />
+لو سمحت تختار اسم تاني.',
+'fileexists-thumb'            => "<center>'''الملف الموجود'''</center>",
+'fileexists-thumbnail-yes'    => 'الظاهر ان الملف دا عبارة عن صورة متصغرة <i>(تصغير)</i>. 
+لو سمحت تشيك على الملف <strong><tt>$1</tt></strong>.<br />
+لو كان الملف هو نفس الصورة بالحجم الاصلي، ف مافيش داعى تحمله مرة تانية',
+'file-thumbnail-no'           => 'يبدأ الملف ب <strong><tt>$1</tt></strong>. 
+يبدو أن الملف مصتغر لحجم أعلى <i>(تصغير)</i>.
+إذا كان عندك الصورة في درجة دقة كامله حملها، أو غير اسم الملف من فضلك.',
+'fileexists-forbidden'        => 'في ملف تاني بنفس الاسم موجود
+لو سمحت ترجع تاني و تحمل الملف باسم جديد. [[Image:$1|thumb|center|$1]]',
+'fileexists-shared-forbidden' => 'في ملف بنفس الاسم دا في مخزن الملفات المشترك؛
+لو سمحت ارجع وحمل الملف دا باسم جديد. [[Image:$1|thumb|center|$1]]',
+'file-exists-duplicate'       => ' الملف دا تكرار  {{PLURAL:$1|للملف|للملفات}} دي:',
+'successfulupload'            => 'التحميل ناجح',
+'uploadwarning'               => 'تحذير التحميل',
+'savefile'                    => 'حفظ الملف',
+'uploadedimage'               => 'اتحمل "[[$1]]"',
+'overwroteimage'              => 'اتحملت  نسخة جديدة من "[[$1]]"',
+'uploaddisabled'              => 'التحميل متعطل',
+'uploaddisabledtext'          => 'تحميل الملفات متعطل في {{SITENAME}}.',
+'uploadscripted'              => 'الملف دا  فيه كود HTML أو كود تاني يمكن البراوزر يفهمه غلط.',
+'uploadcorrupt'               => 'الملف دا  بايظ أو ليه امتداد غلط. لو سمحت ا تأكد من الملف و حمله مرة تانية.',
+'uploadvirus'                 => 'الملف فيه فيروس! التفاصيل: $1',
+'sourcefilename'              => 'اسم الملف  بتاع المصدر:',
+'destfilename'                => 'اسم الملف المستهدف:',
+'upload-maxfilesize'          => 'حجم الملف الأقصى: $1',
+'watchthisupload'             => 'حط الصفحة دي تحت المراقبة',
+'filewasdeleted'              => 'في ملف بنفس الاسم دا تحمل قبل كدا و بعدين اتمسح.
+لو سمحت تراجع $1 قبل ما تحمله كمان مرة.',
+'upload-wasdeleted'           => "'''تحذير: انت بتحمل ملف اتمسح قبل كدا.'''
 
-'license'   => 'ترخيص:',
-'nolicense' => 'مش متحدد',
+لازم تتاكد من انك عايز تستمر في تحميل الملف دا.
+سجل المسح بتاع الملف دا معروض هنا علشان تبص عليه:",
+'filename-bad-prefix'         => 'اسم الملف اللي بتحمله بيبتدي بـ<strong>"$1"</strong>، واللي هو اسم مش وصفي بيتحط غالبا من الكاميرات الديجيتال اوتوماتيكي.
+لو سمحت تختار اسم يكون بيوصف الملف بتاعك احسن من كدا.',
+'filename-prefix-blacklist'   => ' #<!-- leave this line exactly as it is --> <pre>
+# الصيغة كدا: 
+#   * كل حاجة من أول علامة "#" لحد أخر السطر هي تعليق
+#   * كل سطر مش فاضي هو بريفيكس لأسماء الملفات النمطية اللي بتحطها اوتوماتيكي  الكاميرات الديجيتال
+CIMG # Casio
+DSC_ # Nikon
+DSCF # Fuji
+DSCN # Nikon
+DUW # some mobil phones
+IMG # generic
+JD # Jenoptik
+MGP # Pentax
+PICT # misc.
+ #</pre> <!-- leave this line exactly as it is -->',
 
-# Special:Imagelist
-'imgfile'        => 'ملف',
-'imagelist'      => 'لستة الملفات',
-'imagelist_date' => 'تاريخ',
-'imagelist_name' => 'اسم',
-'imagelist_user' => 'يوزر',
+'upload-proto-error'      => 'بروتوكول مش صحيح',
+'upload-proto-error-text' => 'االتحميل عن بعد لازمله يوأرإل بيبتدي بـ <code>http://</code> أو <code>ftp://</code>.',
+'upload-file-error'       => 'غلط داخلي',
+'upload-file-error-text'  => 'حصل غلط داخلي واحنا بنحاول نعمل ملف مؤقت على السيرفر. لو سمحت اتصل بإداري نظام.',
+'upload-misc-error'       => 'غلط مش معروف في التحميل',
+'upload-misc-error-text'  => 'حصل غلط مش معروف وإنت بتحمل. لو سمحت تتاكد أن اليوأرإل صح و ممكن تدخل عليه و بعدين حاول تاني. إذا المشكلة تنتها موجودة،اتصل بإداري نظام.',
 
+# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
+'upload-curl-error6'       => 'ما قدرناش نوصل لليو أر إل',
+'upload-curl-error6-text'  => 'ما قدرناش نوصل لليوأرإل إللي انت عاوزه. لو سمحت تشيك تاني إن اليوأرإل صح و إن السايت شغال.',
+'upload-curl-error28'      => 'انتهاء مهلة التحميل',
+'upload-curl-error28-text' => 'السايت خد وقت كبير علشان يستجيب.
+لو سمحت اتأكد أن السايت شغال، واستنا شوية و بعدين حاول تاني.
+يمكن تجرب تاني في وقت مايكونش فيه زحمة.',
+
+'license'            => 'ترخيص:',
+'nolicense'          => 'مش متحدد',
+'license-nopreview'  => '(البروفه مش متوفره)',
+'upload_source_url'  => '  (اليوأرإل صحيح وممكن توصل ليه)',
+'upload_source_file' => ' (ملف على الكمبيوتر بتاعك)',
+
+# Special:ImageList
+'imagelist-summary'     => 'الصفحة المخصوصة دي بتعرض كل الملفات المتحملة.
+اوتوماتيكي اخر الملفات اللي اتحملت ح تظهر في اللستة من فوق.
+لو دوست على راس العمود الترتيب ح يتغير.',
+'imagelist_search_for'  => 'دور على اسم الميديا:',
+'imgfile'               => 'ملف',
+'imagelist'             => 'لستة الملفات',
+'imagelist_date'        => 'تاريخ',
+'imagelist_name'        => 'اسم',
+'imagelist_user'        => 'يوزر',
+'imagelist_size'        => 'حجم',
+'imagelist_description' => 'وصف',
+
 # Image description page
 'filehist'                       => 'تاريخ الملف',
 'filehist-help'                  => 'اضغط على الساعه/التاريخ علشان تشوف الفايل زى ما كان فى  الوقت ده.',
+'filehist-deleteall'             => 'امسح كله',
 'filehist-deleteone'             => 'مسح',
+'filehist-revert'                => 'استرجع',
 'filehist-current'               => 'دلوقتي',
 'filehist-datetime'              => 'الساعه / التاريخ',
 'filehist-user'                  => 'يوزر',
@@ -1221,46 +1415,108 @@
 'imagelinks'                     => 'وصلات',
 'linkstoimage'                   => '{{PLURAL:$1|الصفحة|ال$1 صفحة}} دى فيها وصله للفايل ده:',
 'nolinkstoimage'                 => 'مافيش صفحات بتوصل للفايل ده.',
+'morelinkstoimage'               => 'عرض [[Special:WhatLinksHere/$1|لينكات اكتر]] للملف دا.',
+'redirectstofile'                => '{{PLURAL:$1| الملف|ال$1 ملف}} اللي جاي  بيحول للملف دا:',
+'duplicatesoffile'               => '{{PLURAL:$1| الملف|ال$1 ملف اللي بعده}} مكررات للملف دا:',
 'sharedupload'                   => 'الملف ده اتحمل علشان التشارك بين المشاريع وممكن استخدامه في المشاريع التانيه.',
+'shareduploadwiki'               => 'لو سمحت تشوف $1 اللي فيه معلوات زيادة.',
+'shareduploadwiki-desc'          => 'الوصف على $1 في المخزن المشترك معروض تحت.',
+'shareduploadwiki-linktext'      => 'صفحة وصف الملف',
+'shareduploadduplicate'          => 'الملف دا تكرار ل$1 من المخزن المشترك.',
 'shareduploadduplicate-linktext' => 'ملف تاني',
-'noimage'                        => ' مافيش  ملف بالاسم ده ،ممكن انك تقوم بـ$1.',
+'shareduploadconflict'           => 'الملف دا ليه نفس الاسم زي $1 من المخزن المشترك.',
+'shareduploadconflict-linktext'  => 'ملف تانى',
+'noimage'                        => 'مافيش  ملف بالاسم ده ،ممكن انك  تـ$1.',
 'noimage-linktext'               => 'تحميله',
 'uploadnewversion-linktext'      => 'حمل نسخه جديده من الملف ده',
+'imagepage-searchdupe'           => 'دور على ملفات متكررة',
 
+# File reversion
+'filerevert'                => 'استرجع $1',
+'filerevert-legend'         => 'استرجع الملف',
+'filerevert-intro'          => "أنت بترجع '''[[Media:$1|$1]]''' [$4 للنسخةاللي بتاريخ $2، $3].",
+'filerevert-comment'        => 'تعليق:',
+'filerevert-defaultcomment' => 'رجع النسخة اللي بتاريخ $1، $2',
+'filerevert-submit'         => 'استرجع',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' اترجعت [$4 للنسخةاللي بتاريخ $2، $3].",
+'filerevert-badversion'     => 'مافيش نسخة محلية قديمة  للملف دا بالتاريخ المتقدم',
+
 # File deletion
-'filedelete'         => 'امسح $1',
-'filedelete-legend'  => 'امسح الملف',
-'filedelete-comment' => 'سبب المسح:',
-'filedelete-submit'  => 'مسح',
+'filedelete'                  => 'امسح $1',
+'filedelete-legend'           => 'امسح الملف',
+'filedelete-intro'            => "أنت بتمسح '''[[Media:$1|$1]]'''.",
+'filedelete-intro-old'        => '<span class="plainlinks">أنت بتمسح نسخة \'\'\'[[Media:$1|$1]]\'\'\'اللي  بتاريخ [$4 $3، $2].</span>',
+'filedelete-comment'          => 'سبب المسح:',
+'filedelete-submit'           => 'مسح',
+'filedelete-success'          => "'''$1''' خلاص اتمسح.",
+'filedelete-success-old'      => '<span class="plainlinks">نسخة \'\'\'[[Media:$1|$1]]\'\'\' اللي بتاريخ $3، $2 اتمسحت.</span>',
+'filedelete-nofile'           => "'''$1''' مش موجود في {{SITENAME}}.",
+'filedelete-nofile-old'       => "مافيش نسخة في الارشيف من '''$1''' بالعناصر المتحددة.",
+'filedelete-iscurrent'        => 'أنت بتحاول تمسح أجدد نسخة من الملف دا.
+لو سمحت ترجع النسخة القديمة الاول.',
+'filedelete-otherreason'      => 'سبب زيادة/تاني:',
+'filedelete-reason-otherlist' => 'سبب تانى',
+'filedelete-reason-dropdown'  => '*أسباب المسح الشايعة
+** الاعتداء على حقوق النشر
+** ملف متكرر',
+'filedelete-edit-reasonlist'  => 'عدل أسباب المسح',
 
 # MIME search
-'mimesearch' => 'تدوير MIME',
-'download'   => 'تنزيل',
+'mimesearch'         => 'تدوير MIME',
+'mimesearch-summary' => 'الصفحة دي مهمتها فلترة الملفات على حسب نوعها.
+المدخل: نوع المحتوى/النوع الفرعي، يعني مثلا
+<tt>image/jpeg</tt>.',
+'mimetype'           => 'نوع الملف:',
+'download'           => 'تنزيل',
 
+# Unwatched pages
+'unwatchedpages' => 'صفحات مش متراقبة',
+
 # List redirects
 'listredirects' => 'عرض التحويلات',
 
 # Unused templates
-'unusedtemplates'    => 'قوالب مش مستعمله',
-'unusedtemplateswlh' => 'وصلات  تانيه',
+'unusedtemplates'     => 'قوالب مش مستعمله',
+'unusedtemplatestext' => 'الصفحة دي فيها لستة بالصفحات من نطاق قالب و اللي مش مستعملة في صفحات تانية
+افتكر قبل ما تمسحها تشوف لو في وصلات تانية للقوالب دي',
+'unusedtemplateswlh'  => 'وصلات  تانيه',
 
 # Random page
-'randompage' => 'صفحة عشوائيه',
+'randompage'         => 'صفحة عشوائيه',
+'randompage-nopages' => 'مافيش صفحات في النطاق دا.',
 
 # Random redirect
-'randomredirect' => 'تحويله عشوائيه',
+'randomredirect'         => 'تحويله عشوائيه',
+'randomredirect-nopages' => 'مافيش تحويلات فى النطاق ده.',
 
 # Statistics
 'statistics'             => 'احصائيات',
+'sitestats'              => 'إحصائيات {{SITENAME}}',
 'userstats'              => 'الاحصاءات بتاعة اليوزر',
+'sitestatstext'          => "فيه{{PLURAL:\$1|'''1''' صفحه|'''\$1''' صفحه كليه}} في قاعدة البيانات.
+ده يشمل  صفحات \"المناقشه\"، الصفحات حول {{SITENAME}}، الصغرى \"البذور\"
+صفحات، التحويلات، و غيرها اللى غالبا ما تتأهلش كصفحات محتوى.
+باستثناء اللى، فيه {{PLURAL:\$2|'''1''' صفحة| '''\$2''' صفحة}} تعتبر على الأرجح
+{{PLURAL:\$2|صفحة|صفحة}} محتوى معتبرة.
+
+'''\$8''' {{PLURAL:\$8|ملف|ملف}} تم تحميله.
+
+فيه كإجمالي '''\$3''' {{PLURAL:\$3|عرض صفحة|عرض صفحة}}، و '''\$4''' {{PLURAL:\$4|تعديل صفحة|تعديل صفحة}}
+من تنصيب {{SITENAME}}.
+ده يعني '''\$5''' تعديل متوسط لكل صفحة، و '''\$6''' عرض لكل تعديل.
+
+طول [http://www.mediawiki.org/wiki/Manual:Job_queue طابور الشغل] هو '''\$7'''.",
+'userstatstext'          => "في {{PLURAL:$1|[[Special:ListUsers|يوزر]] متسجل '''واحد'''|'''$1''' [[Special:ListUsers|يوزر]] متسجل}}، منهم '''$2''' (أو '''$4%''') {{PLURAL:$2|عنده|عندهم}} صلاحيات $5.",
 'statistics-mostpopular' => 'اكتر صفحات اتشافت',
 
 'disambiguations'      => 'صفحات التوضيح',
 'disambiguationspage'  => 'Template:توضيح',
 'disambiguations-text' => "الصفحات دي بتوصل لـ '''صفحة توضيح'''. المفروض على العكس انهم يوصلو ل للصفحات المناسبة. <br />أي صفحة بتتعامل على انها صفحة توضيح إذا كانت بتستعمل قالب موجود في [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'تحويلات مزدوجه',
-'doubleredirectstext' => 'الصفحة دي فيها لستة الصفحات اللي فيها تحويلة لصفحة تانية فيها تحويلة. كل سطر في اللستة دي  فيه لينك للتحويلة الأولانية والتانية و كمان للصفحة بتاعة التحويلة التانية و اللي غالبا هي الصفحة الاصلية اللي المفروض التحويلة الاولانية توصل ليها.',
+'doubleredirects'            => 'تحويلات مزدوجه',
+'doubleredirectstext'        => 'الصفحة دي فيها لستة الصفحات اللي فيها تحويلة لصفحة تانية فيها تحويلة. كل سطر في اللستة دي  فيه لينك للتحويلة الأولانية والتانية و كمان للصفحة بتاعة التحويلة التانية و اللي غالبا هي الصفحة الاصلية اللي المفروض التحويلة الاولانية توصل ليها.',
+'double-redirect-fixed-move' => '[[$1]] اتنقلت، هى دلوقتى تحويله ل [[$2]]',
+'double-redirect-fixer'      => 'مصلح التحويل',
 
 'brokenredirects'        => 'تحويلات مكسوره',
 'brokenredirectstext'    => 'التحويلات دي بتوصل لصفحات مش موجودة:',
@@ -1310,19 +1566,30 @@
 'protectedpagestext'      => 'الصفحات دي محمية من النقل أو التعديل',
 'protectedpagesempty'     => 'مافيش  صفحات محمية دلوقتي  على حسب المحددات دي.',
 'protectedtitles'         => 'عناوين محمية',
+'protectedtitlestext'     => 'العناوين دى محمية ضد الإنشاء',
+'protectedtitlesempty'    => 'مافيش عناوين محمية دلوقتي على حسب المحددات دي.',
 'listusers'               => 'لستة الأعضاء',
 'newpages'                => 'صفحات جديده',
 'newpages-username'       => 'اسم اليوزر:',
 'ancientpages'            => 'اقدم الصفحات',
 'move'                    => 'انقل',
 'movethispage'            => 'انقل الصفحه دى',
+'unusedimagestext'        => 'لو سمحت تاخد بالك إن المواقع التانية ممكن تكون بتوصل لملف عن طريق يوأرإل مباشر، و علشان كدا ممكن يكون لسة معروض هنا مع إنه.
+بيستعمل.',
+'unusedcategoriestext'    => 'التصنيفات دي موجودة مع إنها ما فيهاش اي صفحات او تصنيفات تانية.',
 'notargettitle'           => 'مافيش هدف',
+'notargettext'            => 'انت ما حددتش الصفحة أو اليوزر المستهدف لعمل العملية دي.',
 'nopagetitle'             => 'مافيش صفحة هدف بالاسم ده',
+'nopagetext'              => 'صفحة الهدف اللي انت طالبها مش موجودة.',
+'pager-newer-n'           => '{{PLURAL:$1|أجدد 1|أجدد $1}}',
+'pager-older-n'           => '{{PLURAL:$1|أقدم 1|أقدم $1}}',
 'suppress'                => 'أوفرسايت',
 
 # Book sources
-'booksources'    => 'مصادر من كتب',
-'booksources-go' => 'روح',
+'booksources'               => 'مصادر من كتب',
+'booksources-search-legend' => 'التدوير على مصادر الكتب',
+'booksources-go'            => 'روح',
+'booksources-text'          => 'في تحت لستة بوصلات لمواقع تانية بتبيع الكتب الجديدة والمستعملة، كمان ممكن تلاقي معلومات إضافية عن الكتب اللي يتدور عليها :',
 
 # Special:Log
 'specialloguserlabel'  => 'اليوزر:',
@@ -1331,10 +1598,12 @@
 'all-logs-page'        => 'كل السجلات',
 'log-search-legend'    => 'دور على سجلات',
 'log-search-submit'    => 'روح',
+'alllogstext'          => 'عرض شامل لكل السجلات الموجودة في {{SITENAME}}. 
+ممكن تخلي اللستة متحددة اكتر لو تختار نوع العملية، أو اسم اليوزر، أو الصفحات المتأثرة.',
 'logempty'             => 'مافيش  سجلات مطابقة في السجل.',
 'log-title-wildcard'   => 'التدوير على عناوين تبتدي بالنص دا',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'كل الصفحات',
 'alphaindexline'    => '$1 ل $2',
 'nextpage'          => 'الصفحه اللى بعد كده ($1)',
@@ -1357,12 +1626,12 @@
 'special-categories-sort-count' => 'رتب بالعدد',
 'special-categories-sort-abc'   => 'ترتيب ابجدي',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'عرض اليوزرز من أول:',
 'listusers-submit'   => 'عرض',
 'listusers-noresult' => 'ما في ش يوزر',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'حقوق مجموعات اليوزرز',
 'listgrouprights-summary'  => 'دي لستة بمجموعات اليوزرز المتعرفة في الويكي دا، بالحقوق اللي معاهم.
 ممكن تلاقي معلومات زيادة عن الحقوق بتاعة كل واحد  [[{{MediaWiki:Listgrouprights-helppage}}|هنا]].',
@@ -1373,46 +1642,71 @@
 
 # E-mail user
 'mailnologin'     => 'مافيش عنوان نبعت عليه',
-'mailnologintext' => 'لازم تعمل [[Special:Userlogin|تسجيل الدخول]] و تدخل ايميل صحيح في صفحة [[Special:Preferences|التفضيلات]] علشان تقدر تبعت ايميلات لليوزرز التانيين.',
+'mailnologintext' => 'لازم تعمل [[Special:UserLogin|تسجيل الدخول]] و تدخل ايميل صحيح في صفحة [[Special:Preferences|التفضيلات]] علشان تقدر تبعت ايميلات لليوزرز التانيين.',
 'emailuser'       => 'ابعت ايميل لليوزر دا',
 'emailpage'       => 'ابعت ايميل لليوزر ده',
 'emailpagetext'   => 'لو اليوزر دا دخل ايميل صحيح في التفضيلات بتاعته،
 ف حيتبعت له رسالة واحدة بس حسب الاستمارة اللي تحت دي.
 عنوان الايميل اللي دخلته في التفضيلات بتاعتك
 ح يظهر في  على انه عنوان الاستمارة و بكدة اللي حيستقبله ح يقدر يرد على الايميل.',
+'usermailererror' => 'البريد رجع غلط:',
+'defemailsubject' => 'إيميل من {{SITENAME}}',
 'noemailtitle'    => 'مافيش  عنوان ايميل',
+'noemailtext'     => 'يا إما اليوزر دا ما كتبش االايميل بتاعه صح ، أو  انه طلب ما يستلمش ايميلات من اليوزرز التانيين.',
 'emailfrom'       => 'من',
 'emailto'         => 'لـ',
 'emailsubject'    => 'الموضوع',
+'emailmessage'    => 'الرساله',
 'emailsend'       => 'إبعت',
 'emailccme'       => 'ابعتلي نسخة من الايميل اللي بعته.',
+'emailccsubject'  => 'نسخة من رسالتك ل $1: $2',
 'emailsent'       => 'الإيميل اتبعت',
+'emailsenttext'   => 'الايميل بتاعك اتبعت خلاص.',
+'emailuserfooter' => 'الايميل دا بعته $1 لـ $2 عن طريق خاصية "مراسلة اليوزر" في {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'لستة الصفحات اللى باراقبها',
 'mywatchlist'          => 'لستة  الصفحات اللى باراقبها',
 'watchlistfor'         => "(ل '''$1''')",
+'nowatchlist'          => 'مافيش حاجة في لستة مراقبتك.',
+'watchlistanontext'    => 'لو سمحت $1 لعرض أو تعديل الصفحات في لستة مراقبتك.',
+'watchnologin'         => 'مش متسجل',
+'watchnologintext'     => 'لازم تكون [[Special:UserLogin|مسجل الدخول]] علشان تعدل لستة المراقبة بتاعتك.',
 'addedwatch'           => 'تمت الاضافه للستة الصفحات اللى بتراقبها',
 'addedwatchtext'       => '
-تمت إضافة الصفحه  "$1"  [[Special:Watchlist|للستة الصفحات اللى بتراقبها]] . التعديلات اللى بعد كده ها تتحط على الصفحه دى، وصفحة المناقش الخاصه بها ها تتحط هناك. واسم الصفحة هايظهر  بخط <b>عريض</b> في صفحة [[Special:Recentchanges|أحدث التعديلات]] لتسهيل تحديدها واكتشافها.
+تمت إضافة الصفحه  "$1"  [[Special:Watchlist|للستة الصفحات اللى بتراقبها]] . التعديلات اللى بعد كده ها تتحط على الصفحه دى، وصفحة المناقش الخاصه بها ها تتحط هناك. واسم الصفحة هايظهر  بخط <b>عريض</b> في صفحة [[Special:RecentChanges|أحدث التعديلات]] لتسهيل تحديدها واكتشافها.
 
 علشان تشيل الصفحة من لستة الصفحات اللى بتراقبها، اضغط على "توقف عن المراقبة" فوق.',
 'removedwatch'         => 'اتشالت  من لستة الصفحات اللى بتراقبها',
-'removedwatchtext'     => ' الصفحه دى اتشالت "[[:$1]]" من لستة الصفحات اللى بتراقبها.',
+'removedwatchtext'     => 'الصفحه دى اتشالت "[[:$1]]" من لستة الصفحات اللى بتراقبها.',
 'watch'                => 'راقب',
 'watchthispage'        => 'راقب الصفحه دى',
 'unwatch'              => 'بطل مراقبه',
 'unwatchthispage'      => 'اتوقف عن المراقبة',
+'notanarticle'         => 'دي مش صفحة بتاعة محتوى',
+'notvisiblerev'        => 'النسحة اتمسحت',
+'watchnochange'        => 'مافيش ولا صفحة اتعدلت في لستة مراقبتك في الفترة الزمنية اللي حددتها.',
 'watchlist-details'    => '{{PLURAL:$1|$1 صفحه|$1 صفحه}} متراقبه بدون عد صفحات المناقشه.',
+'wlheader-enotif'      => '*خاصية الاعلام بالايميل متفعلة',
+'wlheader-showupdated' => "* الصفحات اللي اتغيرت  بعد زيارتك ليها اخر مرة معروضة بالخط '''العريض'''",
+'watchmethod-recent'   => 'التشييك على التعديلات الاخيرة للصفحات المتراقبة',
+'watchmethod-list'     => 'التشييك في الصفحات المتراقبة على التعديلات الاخيرة',
+'watchlistcontains'    => 'لستة المراقبة بتاعتك فيها $1 {{PLURAL:$1|صفحة|صفحات}}.',
+'iteminvalidname'      => "مشكلة في '$1'، اسم مش صحيح...",
+'wlnote'               => "تحت في {{PLURAL:$1|آخر تغيير|آخر '''$1''' تغيير}} في آخر {{PLURAL:$2|ساعة|'''$2''' ساعة}}.",
 'wlshowlast'           => 'عرض اخر $1 ساعات $2 ايام $3',
+'watchlist-show-bots'  => 'عرض تعديلات البوتات',
 'watchlist-hide-bots'  => 'تخبية تعديلات البوت',
+'watchlist-show-own'   => 'عرض تعديلاتى',
 'watchlist-hide-own'   => 'اخفاء تعديلاتى',
+'watchlist-show-minor' => 'عرض التعديلات الطفيفة',
 'watchlist-hide-minor' => 'خبى التعديلات الصغيره',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'راقب...',
 'unwatching' => 'بطل مراقبه...',
 
+'enotif_mailer'                => 'نظام {{SITENAME}} البريدي للإخطارات',
 'enotif_reset'                 => 'علم على كل الصفحات كأنك خلاص زرتها',
 'enotif_newpagetext'           => 'دى صفحه جديده.',
 'enotif_impersonal_salutation' => 'يوزر {{SITENAME}}',
@@ -1422,10 +1716,35 @@
 'enotif_lastvisited'           => 'شوف $1 لمراجعة كل التغييرات اللي حصلت من أخر زيارة ليك.',
 'enotif_lastdiff'              => 'شوف $1 علشان تبص على التغيير دا.',
 'enotif_anon_editor'           => 'يوزر مش معروف $1',
+'enotif_body'                  => 'عزيزى $WATCHINGUSERNAME،
 
+صفحة $PAGETITLE فى {{SITENAME}} إتغيرت ل $CHANGEDORCREATED قبل كدا $PAGEEDITOR،  علشان تشوف النسخة الحالية من الصفحة بص: $PAGETITLE_URL.
+
+$NEWPAGE
+
+ملخص تعديل المحرر: $PAGESUMMARY $PAGEMINOREDIT
+
+اتصل بالمحرر:
+إيميل: $PAGEEDITOR_EMAIL
+صفحة اليوزر: $PAGEEDITOR_WIKI
+
+مش ح يكون في اي إخطارات تانية عن أي تغييرات ح تحصل في المستقبل إلا إذا زرت  الصفحه دى. ممكن أنك تعيد تصفير عداد الإخطارات لكل الصفحات اللى بتراقبها فى لستة مراقبتك.
+
+نظام إخطار {{SITENAME}}
+
+--
+لتغيير إعدادات قايمة مراقبتك، روح على:
+{{fullurl:{{ns:special}}:Watchlist/edit}}
+
+للاقتراحات والحصول على مساعدة إضافية:
+{{fullurl:{{MediaWiki:Helppage}}}}',
+
 # Delete/protect/revert
 'deletepage'                  => 'امسح الصفحه',
 'confirm'                     => 'أكد',
+'excontent'                   => "المحتوى كان: '$1'",
+'excontentauthor'             => "المحتوى كان: '$1' (والمساهم الوحيد كان '[[Special:Contributions/$2|$2]]')",
+'exbeforeblank'               => "المحتوى قبل التفضيه كان: '$1'",
 'exblank'                     => 'الصفحه كانت فاضيه',
 'delete-confirm'              => 'مسح"$1"',
 'delete-legend'               => 'مسح',
@@ -1435,8 +1754,11 @@
 'deletedtext'                 => '"<nowiki>$1</nowiki>" اتمسحت.
 بص على $2 لسجل آخر عمليات المسح.',
 'deletedarticle'              => 'اتمسحت "[[$1]]"',
+'suppressedarticle'           => 'خببى "[[$1]]"',
 'dellogpage'                  => 'سجل المسح',
+'dellogpagetext'              => 'لسته بأحدث عمليات المسح.',
 'deletionlog'                 => 'سجل المسح',
+'reverted'                    => 'استرجع لنسخة أقدم',
 'deletecomment'               => 'سبب المسح:',
 'deleteotherreason'           => 'سبب تانى/اضافي:',
 'deletereasonotherlist'       => 'سبب تانى',
@@ -1445,16 +1767,44 @@
 ** التعدي على حقوق النشر
 ** التخريب',
 'delete-edit-reasonlist'      => 'عدل اسباب المسح',
+'delete-toobig'               => 'الصفحه دى  ليها تاريخ تعديل كبير، أكتر من $1 {{PLURAL:$1|مراجعة|مراجعة}}.
+مسح الصفحات اللى زى دى تم تحديده لمنع الاضطراب العرضى فى {{SITENAME}}.',
+'delete-warning-toobig'       => ' الصفحة دي ليها تاريخ تعديل كبير، أكتر من $1 {{PLURAL:$1|مراجعة|مراجعة}}.
+ممكن مسحها يعمل اضطراب  في عمليات قاعدة البيانات في {{SITENAME}}؛
+استمر بس خد بالك.',
+'rollback'                    => 'إرجع في التعديلات',
+'rollback_short'              => 'إرجع لـ ورا',
 'rollbacklink'                => 'استعاده',
+'rollbackfailed'              => 'الترجيع ما نفعش',
+'cantrollback'                => 'ماقدرناش نرجع في التعديل؛ آخر مساهم هوه الوحيد اللي ساهم في الصفحة دي.',
+'alreadyrolled'               => 'ماقدرناش نرجع آخر تعديل للصفحة [[$1]] [[User:$2|$2]] ([[User talk:$2|نقاش]]) لأن في واحد عمل تعديل او ترجيع للصفحة دي قبل كده.
+
+آخر واحد  عدل الصفحة دي هوه [[User:$3|$3]] ([[User talk:$3|نقاش]]).',
 'editcomment'                 => 'تعليق التعديل كان: "<i>$1</i>".', # only shown if there is an edit comment
+'revertpage'                  => 'استرجع التعديلات بواسطة [[Special:Contributions/$2|$2]] ([[User talk:$2|مناقشة]]) لآخر نسخة بواسطة [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'rollback-success'            => 'استرجع تعديلات $1؛
+استرجع لآخر نسخة بواسطة $2.',
+'sessionfailure'              => 'الظاهر انه في مشكلة في جلسة دخولك دي ؛
+وعلشان كدا العملية دي اتلغت كإجراء احترازي ضد الاختراق.
+لو سمحت دوس على زرار"رجوع" علشان تحمل الصفحة اللي جيت منها مرة تانية، و بعدين حاول تاني.',
 'protectlogpage'              => 'سجل الحمايه',
+'protectlogtext'              => 'تحت في لستة بالصفحات اللي اعملها حماية او اتشالت منها الحماية.
+شوف [[Special:ProtectedPages|لستة الصفحات المحمية]] لستة بعمليات حماية الصفحات الشغالة دلوقتي.',
 'protectedarticle'            => 'حمى "[[$1]]"',
+'modifiedarticleprotection'   => 'غير مستوى الحماية ل"[[$1]]"',
+'unprotectedarticle'          => 'شال حماية [[$1]]',
+'protect-title'               => 'غير مستوى الحماية ل"$1"',
+'protect-legend'              => 'تأكيد الحماية',
 'protectcomment'              => 'تعليق:',
 'protectexpiry'               => 'تنتهى فى:',
 'protect_expiry_invalid'      => 'وقت الانتهاء مش صحيح.',
 'protect_expiry_old'          => 'وقت انتهاء المنع قديم.',
 'protect-unchain'             => 'استعادة سماح النقل',
 'protect-text'                => 'ممكن هنا تعرض و تغير مستوى الحمايه للصفحه <strong><nowiki>$1</nowiki></strong>.',
+'protect-locked-blocked'      => 'انت مش ممكن تغير مستويات الحماية وأنت ممنوع.
+الإعدادات بتاعة الصفحة <strong>$1</strong> دلوقتي هي:',
+'protect-locked-dblock'       => 'ما ينفعش تغير مستويات الحماية بسبب قفل قاعدة البيانات دلوقتي.
+الإعدادات بتاعة الصفحة <strong>$1</strong> دلوقتي هي:',
 'protect-locked-access'       => 'حسابك ما لوش  صلاحية تغيير مستوى حماية الصفحه.
 الاعدادات الحالية للصفحه <strong>$1</strong> هى:',
 'protect-cascadeon'           => 'الصفحه دى محميه لكونها متضمنه فى {{PLURAL:$1|الصفحه|الصفحات}} دى، واللى  فيها اختيار حماية الصفحات المتضمنه شغال. ممكن تغير مستوى حماية الصفحه دى بدون التأثير على حماية الصفحات المتضمنه التانيه.',
@@ -1484,34 +1834,54 @@
 'restriction-level-all'           => 'أي مستوى',
 
 # Undelete
-'undelete'                 => 'عرض الصفحات الممسوحة',
-'undeletepage'             => 'عرض واسترجاع الصفحات المسوحة',
-'undeletepagetitle'        => "'''دا بيتكون من النسخ الممسوحة لـ[[:$1]]'''.",
-'viewdeletedpage'          => 'عرض الصفحات الممسوحة',
-'undeletepagetext'         => ' الصفحات دي إتمسحت بس لسة موجودة في الأرشيف و ممكن تترجع. الأرشيف ممكن يتنضف كل شوية..',
-'undelete-fieldset-title'  => 'رجع النسخ',
-'undeleteextrahelp'        => " علشان ترجع الصفحة كلها، سيب كل الصناديق فاضية و دوس
+'undelete'                     => 'عرض الصفحات الممسوحة',
+'undeletepage'                 => 'عرض واسترجاع الصفحات المسوحة',
+'undeletepagetitle'            => "'''دا بيتكون من النسخ الممسوحة لـ[[:$1]]'''.",
+'viewdeletedpage'              => 'عرض الصفحات الممسوحة',
+'undeletepagetext'             => ' الصفحات دي إتمسحت بس لسة موجودة في الأرشيف و ممكن تترجع. الأرشيف ممكن يتنضف كل شوية..',
+'undelete-fieldset-title'      => 'رجع النسخ',
+'undeleteextrahelp'            => " علشان ترجع الصفحة كلها، سيب كل الصناديق فاضية و دوس
  '''''ترجيع'''''. علشان ترجع جزء من الصفحة، حط علامة في الصناديق أدام التعديلات اللي عايز  ترجعهاو دوس '''''ترجيع'''''. لو دوست على  '''''إبتدي تاني'''''  التعليق ح يتمسح و كل العلامات  اللي في الصناديق ح تتحذف.",
-'undeleterevisions'        => '$1 {{PLURAL:$1|نسخة|نسخة}} اتحطت في  الارشيف',
-'undelete-nodiff'          => 'ما لقيناش نسخة قديمة.',
-'undeletebtn'              => 'استعاده',
-'undeletelink'             => 'استرجاع',
-'undeletereset'            => 'ابتدي من الأول',
-'undeletecomment'          => 'تعليق:',
-'undeletedarticle'         => 'رجع  "[[$1]]" تاني',
-'undeletedrevisions'       => 'رجعنا تاني {{PLURAL:$1|تعديل واحد|تعديلين|$1 تعديلات|$1 تعديل|$1 تعديل}}',
-'undeletedrevisions-files' => '{{PLURAL:$1|1 نسخة|$1 نسخة}} و {{PLURAL:$2|1 ملف|$2 ملف}} رجعو تاني',
-'undeletedfiles'           => '{{PLURAL:$1|ملف|ملفات}} $1 رجعو تاني',
-'cannotundelete'           => 'الترجيع ما نفعش :ممكن يكون في حد تاني رجع الصفحة قبل كدا.',
-'undeletedpage'            => "<big>'''اترجع $1'''</big>
+'undeleterevisions'            => '$1 {{PLURAL:$1|نسخة|نسخة}} اتحطت في  الارشيف',
+'undeletehistory'              => 'لو رجعت الصفحة، كل المراجعات ح تترجع للتاريخ دا
+لو في صفحة جديدة اتعملت بنفس الاسم بعد المسح، المراجعات المترجعة ح تبان في التاريخ اللي فات.
+كمان اعمل حسابك ان الضوابط على مراجعات الملف ح تضيع مع الترجيع',
+'undeleterevdel'               => 'الترجيع مش ح يحصل لو كان ح يسبب ان المراجعة تيجي في راس الصفحة أو ان الملف يتمسح حتة منه .
+في الحالات اللي زي كدا، لازم تبين أخر المراجعات الممسوحة.',
+'undeletehistorynoadmin'       => 'الصفحة دي اتمسحت.
+سبب المسح موجود في الملخص اللي تحت، كمان في تفاصيل اليوزرز اللي عملو تعديل على الصفحة دي قبل ما تتمسح.
+نص المراجعات الممسوحة دي متوفرة بس للاداريين.',
+'undelete-revision'            => 'المراجعة الممسوحة ل$1 (بتاريخ $2) عن طريق $3:',
+'undeleterevision-missing'     => 'مراجعة مش صحيحةأو ضايعة.
+يمكن اللينك بتاعتك بايظة،أو يمكن المراجعة اترجعت او اتشالت من الارشيف.',
+'undelete-nodiff'              => 'ما لقيناش نسخة قديمة.',
+'undeletebtn'                  => 'استعاده',
+'undeletelink'                 => 'استرجاع',
+'undeletereset'                => 'ابتدي من الأول',
+'undeletecomment'              => 'تعليق:',
+'undeletedarticle'             => 'رجع  "[[$1]]" تاني',
+'undeletedrevisions'           => 'رجعنا تاني {{PLURAL:$1|تعديل واحد|تعديلين|$1 تعديلات|$1 تعديل|$1 تعديل}}',
+'undeletedrevisions-files'     => '{{PLURAL:$1|1 نسخة|$1 نسخة}} و {{PLURAL:$2|1 ملف|$2 ملف}} رجعو تاني',
+'undeletedfiles'               => '{{PLURAL:$1|ملف|ملفات}} $1 رجعو تاني',
+'cannotundelete'               => 'الترجيع ما نفعش :ممكن يكون في حد تاني رجع الصفحة قبل كدا.',
+'undeletedpage'                => "<big>'''اترجع $1'''</big>
 
 بص على [[Special:Log/delete|سجل المسح]] علشان تشوف عمليات المسح و الترجيع الاخيرة.",
-'undelete-header'          => 'شوف الصفحات الممسوحة قريب في [[Special:Log/delete|سجل المسح]].',
-'undelete-search-box'      => 'دور في الصفحات الممسوحة',
-'undelete-search-prefix'   => 'عرض الصفحات اللي بتبتدي بـ:',
-'undelete-search-submit'   => 'دور',
-'undelete-no-results'      => 'مالقيناش صفحات مطابقة في أرشيف المسح.',
+'undelete-header'              => 'شوف الصفحات الممسوحة قريب في [[Special:Log/delete|سجل المسح]].',
+'undelete-search-box'          => 'دور في الصفحات الممسوحة',
+'undelete-search-prefix'       => 'عرض الصفحات اللي بتبتدي بـ:',
+'undelete-search-submit'       => 'دور',
+'undelete-no-results'          => 'مالقيناش صفحات مطابقة في أرشيف المسح.',
+'undelete-filename-mismatch'   => 'ماقدرناش نرجع المراجعة بتاعة الملف بتاريخ $1: اسم الملف مش مطابق',
+'undelete-bad-store-key'       => 'ما قدرناش نرجع المراجعة بتاعة الملف بتاريخ $1: الملف كان ضايع قبل المسح',
+'undelete-cleanup-error'       => 'خطأ مسح ملف أرشيف مش بيستعمل"$1".',
+'undelete-missing-filearchive' => 'مش قادرين نرجع ملف الأرشيف رقم $1 لأنه مش موجود في قاعدة البيانات.
+يمكن يكون اترجع قبل كدا.',
+'undelete-error-short'         => 'غلطة ترجيع ملف: $1',
+'undelete-error-long'          => 'حصلت غلطات و الملف بيترجع:
 
+$1',
+
 # Namespace form on various pages
 'namespace'      => 'النيمسبيس:',
 'invert'         => 'عكس الاختيار',
@@ -1521,60 +1891,164 @@
 'contributions' => 'مساهمات اليوزر',
 'mycontris'     => 'تعديلاتى',
 'contribsub2'   => 'لليوزر $1 ($2)',
+'nocontribs'    => 'مالقيناش   تغييرات تطابق المحددات دي.',
 'uctop'         => '(فوق)',
 'month'         => 'من شهر (واللى قبل كده):',
 'year'          => 'من سنة (واللى قبل كده):',
 
+'sp-contributions-newbies'     => 'عرض مساهمات الحسابات الجديدة بس',
 'sp-contributions-newbies-sub' => 'للحسابات الجديده',
 'sp-contributions-blocklog'    => 'سجل المنع',
+'sp-contributions-search'      => 'دور على مساهمات',
+'sp-contributions-username'    => 'عنوان أيبي أو اسم يوزر:',
+'sp-contributions-submit'      => 'تدوير',
 
 # What links here
-'whatlinkshere'           => 'ايه بيوصل هنا',
-'whatlinkshere-title'     => 'الصفحات اللي بتودي ل $1',
-'whatlinkshere-page'      => 'الصفحة:',
-'linklistsub'             => '(لسته بالوصلات)',
-'linkshere'               => "الصفحات دى فيها وصله ل '''[[:$1]]''':",
-'nolinkshere'             => "مافيش صفحات بتوصل ل '''[[:$1]]'''.",
-'isredirect'              => 'صفحة تحويل',
-'istemplate'              => 'متضمن',
-'isimage'                 => 'لينك صورة',
-'whatlinkshere-prev'      => '{{PLURAL:$1|اللى قبل كده|الـ $1 اللى قبل كده}}',
-'whatlinkshere-next'      => '{{PLURAL:$1|اللى بعد كده|الـ $1 اللى بعد كده}}',
-'whatlinkshere-links'     => '← وصلات',
-'whatlinkshere-hidelinks' => '$1 لينكات',
+'whatlinkshere'            => 'ايه بيوصل هنا',
+'whatlinkshere-title'      => 'الصفحات اللي بتودي لـ "$1"',
+'whatlinkshere-page'       => 'الصفحة:',
+'linklistsub'              => '(لسته بالوصلات)',
+'linkshere'                => "الصفحات دى فيها وصله ل '''[[:$1]]''':",
+'nolinkshere'              => "مافيش صفحات بتوصل ل '''[[:$1]]'''.",
+'nolinkshere-ns'           => "مافيش صفحات بتوصل لـ '''[[:$1]]''' في النطاق اللي انت اختارته.",
+'isredirect'               => 'صفحة تحويل',
+'istemplate'               => 'متضمن',
+'isimage'                  => 'لينك صورة',
+'whatlinkshere-prev'       => '{{PLURAL:$1|اللى قبل كده|الـ $1 اللى قبل كده}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|اللى بعد كده|الـ $1 اللى بعد كده}}',
+'whatlinkshere-links'      => '← وصلات',
+'whatlinkshere-hideredirs' => '$1 التحويلات',
+'whatlinkshere-hidetrans'  => '$1 التضمينات',
+'whatlinkshere-hidelinks'  => '$1 لينكات',
+'whatlinkshere-hideimages' => '$1 وصلة صورة',
+'whatlinkshere-filters'    => 'فلاتر',
 
 # Block/unblock
-'blockip'                 => 'منع يوزر',
-'ipbexpiry'               => 'مدة المنع:',
-'ipbreason'               => 'السبب:',
-'ipbemailban'             => 'منع اليوزر ده من بعتان إيميل',
-'ipbother'                => 'وقت تاني:',
-'ipboptions'              => 'ربع ساعة:15 minutes,ساعة واحدة:1 hour,ساعتين:2 hours,يوم:1 day,ثلاثة أيام:3 days,أسبوع:1 week,أسبوعان:2 weeks,شهر:1 month,ثلاثة شهور:3 months,ستة شهور:6 months,عام واحد:1 year,دائم:infinite', # display1:time1,display2:time2,...
-'ipblocklist'             => 'لستة عناوين الااى بى واسامى اليوزر الممنوعه',
-'ipblocklist-submit'      => 'تدوير',
-'blocklink'               => 'منع',
-'unblocklink'             => 'رفع المنع',
-'contribslink'            => 'تعديلات',
-'blocklogpage'            => 'سجل المنع',
-'blocklogentry'           => 'منع "[[$1]]" لفترةه زمنيه مدتها $2 $3',
-'block-log-flags-noemail' => 'الإيميل ممنوع',
-'ipb_cant_unblock'        => 'غلطه: عنوان الااى بى الممنوع  مش موجود  $1. يمكن اترفع منعه فعلا.',
-'blockme'                 => 'امنعنى',
-'proxyblocksuccess'       => 'خلاص.',
+'blockip'                         => 'منع يوزر',
+'blockip-legend'                  => 'منع اليوزر',
+'blockiptext'                     => 'استخدم الاستمارة اللي تحت لمنع عنوان أيبي أو يوزر معين من الكتابة.
+دا لازم يحصل بس علشان تمنع التخريب ،و على حسب 
+[[{{MediaWiki:Policy-url}}|السياسة]].
+اكتب سبب محدد تحت (يعنى مثلا، اكتب الصفحات المعينة اللي اتخربت بسببه)).',
+'ipaddress'                       => 'عنوان الأيبي:',
+'ipadressorusername'              => 'عنوان الأيبي أو اسم اليوزر:',
+'ipbexpiry'                       => 'مدة المنع:',
+'ipbreason'                       => 'السبب:',
+'ipbreasonotherlist'              => 'سبب تاني',
+'ipbreason-dropdown'              => '*أسباب المنع المشهورة
+** تدخيل معلومات غلط
+** مسح المحتوى من الصفحات
+** سبام لينك لمواقع خارجية
+** كتابة كلام مالوش معنى في الصفحات
+** سلوك عدواني/تحرش
+** إساءة استخدام اكتر من حسابات 
+** اسم يوزر مش مقبول',
+'ipbanononly'                     => 'امنع اليوزرز المجهولين بس',
+'ipbcreateaccount'                => 'امنع فتح الحسابات',
+'ipbemailban'                     => 'منع اليوزر ده من بعتان إيميل',
+'ipbenableautoblock'              => ' امنع آخر عنوان أيبي استخدمه اليوزر دا اوتوماتيكي، وأي عناوين أيبي تانية يحاول التحرير منها',
+'ipbsubmit'                       => 'منع اليوزر دا',
+'ipbother'                        => 'وقت تاني:',
+'ipboptions'                      => 'ربع ساعة:15 minutes,ساعة واحدة:1 hour,ساعتين:2 hours,يوم:1 day,تلات-ت-أيام:3 days,أسبوع:1 week,أسبوعين:2 weeks,شهر:1 month,تلات شهور:3 months,ست-ت- شهور:6 months,سنة واحدة:1 year,على طول:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'كمان',
+'ipbotherreason'                  => 'سبب تاني:',
+'ipbhidename'                     => 'خبي اسم اليوزر من سجل المنع، لستة المنع النشطة ولستة اليوزرز',
+'ipbwatchuser'                    => 'راقب صفحات اليوزر و النقاش بتوع اليوزر دا',
+'badipaddress'                    => 'عنوان أيبي مش صحيح',
+'blockipsuccesssub'               => 'المنع حصل بنجاح',
+'blockipsuccesstext'              => 'اتمنع [[Special:Contributions/$1|$1]].<br />
+شوف [[Special:IPBlockList|لستة منع الأيبي]] علشان تراجع حالات المنع.',
+'ipb-edit-dropdown'               => 'عدل أسباب المنع',
+'ipb-unblock-addr'                => 'رفع منع $1',
+'ipb-unblock'                     => 'رفع المنع عن يوزر أو عنوان أيبي',
+'ipb-blocklist-addr'              => 'عرض المنع الموجود ل$1',
+'ipb-blocklist'                   => 'عرض حالات المنع الموجودة دلوقتي',
+'unblockip'                       => 'رفع منع يوزر',
+'unblockiptext'                   => 'استخدم الاستمارة اللي تحت علشان ترجع حق الكتابة بتاعة عنوان أيبي أو يوزر اتسحب منه الحق دا قبل كدا.',
+'ipusubmit'                       => 'رفع منع  العنوان ده',
+'unblocked'                       => 'المنع اترفع عن [[User:$1|$1]]',
+'unblocked-id'                    => 'منع $1 اترفع',
+'ipblocklist'                     => 'لستة عناوين الااى بى واسامى اليوزر الممنوعه',
+'ipblocklist-legend'              => 'دور على مستخدم ممنوع',
+'ipblocklist-username'            => 'اسم اليوزر او عنوان ال اي بي.',
+'ipblocklist-submit'              => 'تدوير',
+'blocklistline'                   => '$1, $2 منع $3 ($4)',
+'infiniteblock'                   => 'دايم',
+'expiringblock'                   => 'ينتهى فى $1',
+'anononlyblock'                   => 'مجهول بس',
+'noautoblockblock'                => 'المنع التلقائى متعطل',
+'createaccountblock'              => ' فتح الحسابات ممنوع',
+'emailblock'                      => 'الإيميل ممنوع',
+'ipblocklist-empty'               => 'لستة المنع فاضية.',
+'ipblocklist-no-results'          => 'عنوان الأيبي أو اسم اليوزر المطلوب مش ممنوع.',
+'blocklink'                       => 'منع',
+'unblocklink'                     => 'رفع المنع',
+'contribslink'                    => 'تعديلات',
+'autoblocker'                     => 'انت اتمنعت اوتوماتيكي لأن الأيبي بتاعك استعمله"[[User:$1|$1]]" في الفترة الاخيرة. 
+السبب   اللي خلا $1 يتمنع هو: "$2"',
+'blocklogpage'                    => 'سجل المنع',
+'blocklogentry'                   => 'منع "[[$1]]" لفترةه زمنيه مدتها $2 $3',
+'blocklogtext'                    => 'دا سجل بعمليات المنع ورفع المنع.
+عناوين الأيبي اللي اتمنعت اوتوماتيكي مش معروضة.
+شوف [[Special:IPBlockList|عناوين الأيبي الممنوعة]] علشان تشوف عمليات المنع الشغالة دلوقتي.',
+'unblocklogentry'                 => 'رفع منع $1',
+'block-log-flags-anononly'        => 'اليوزرز المجهولين  بس',
+'block-log-flags-nocreate'        => ' فتح الحسابات ممنوع',
+'block-log-flags-noautoblock'     => 'المنع التلقائى متعطل',
+'block-log-flags-noemail'         => 'الإيميل ممنوع',
+'block-log-flags-angry-autoblock' => 'المنع الاوتوماتيكي المتقدم متفعل',
+'range_block_disabled'            => 'إمكانيةالسيسوب لمنع نطاق متعطلة.',
+'ipb_expiry_invalid'              => 'تاريخ الانتهاء مش صحيح.',
+'ipb_expiry_temp'                 => 'عمليات منع أسماء اليوزرز المستخبية لازم تكون على طول.',
+'ipb_already_blocked'             => '"$1" ممنوع فعلا',
+'ipb_cant_unblock'                => 'غلطه: عنوان الااى بى الممنوع  مش موجود  $1. يمكن اترفع منعه فعلا.',
+'ipb_blocked_as_range'            => 'غلط: الأيبي $1 مش ممنوع مباشرةو مش ممكن رفع المنع عنه.
+بس هو، على الرغم من كدا،ممنوع لانه جزء من النطاق $2، و اللي ممكن رفع المنع عنه.',
+'ip_range_invalid'                => 'نطاق عناوين الأيبي مش صحيح.',
+'blockme'                         => 'امنعنى',
+'proxyblocker'                    => 'مانع البروكسي',
+'proxyblocker-disabled'           => 'الخاصية دي متعطلة.',
+'proxyblockreason'                => 'عنوان الأيبي بتاعك اتمنع لانه بروكسي مفتوح.
+لو سمحت تتصل بمزود خدمة الإنترنت بتاعك أو الدعم الفني و قولهم على المشكلة الامنية الخطيرة دي.',
+'proxyblocksuccess'               => 'خلاص.',
+'sorbs'                           => 'دي إن إس بي إل',
+'sorbsreason'                     => 'عنوان الأيبي بتاعك موجود كبروكسي مفتوح في DNSBL اللي بيستعمله{{SITENAME}}.',
+'sorbs_create_account_reason'     => 'عنوان الأيبي بتاعك موجود كبروكسي مفتوح في ال DNSBL اللي بيستعمله{{SITENAME}}. 
+ما ينفعش تفتح حساب.',
 
+# Developer tools
+'lockdb'              => 'اقفل قاعدة البيانات',
+'unlockdb'            => 'افتح قاعدة البيانات',
+'lockdbtext'          => 'قفل قاعدة البيانات ح يمنع كل اليوزرز من تحرير الصفحات وتغيير التفضيلات بتاعتهم وتعديل لستة المراقبة حاجات تانية بتحتاج تغيير قاعدة البيانات.
+لو سمحت تتأكد من  ان هو دا اللي انت عايز تعمله فعلا، ومن إنك ح تشيل القفل بعد ما تخلص الصيانة.',
+'unlockdbtext'        => 'فتح قاعدة البيانات ح يخلى كل اليوزرز يقدرو يحررو الصفحات، يغيرو  تفضيلاتهم،يعدلو لستة المراقبة  بتاعتهم، و حاجات تانية محتاجين يغيروها في قاعدة البانات.
+. لو سمحت تتاكد ان هو دا اللي انت عايز تعمله',
+'lockconfirm'         => 'أيوه، أنا فعلا عايز اقفل قاعدة البيانات.',
+'unlockconfirm'       => 'أيوه، أنا فعلا عايز افتح قاعدة البيانات.',
+'lockbtn'             => 'قفل قاعدة البيانات',
+'unlockbtn'           => 'افتح قاعدة البيانات',
+'locknoconfirm'       => 'انت ما علمتش على صندوق التأكيد.',
+'lockdbsuccesssub'    => 'نجح قفل قاعدة البيانات',
+'unlockdbsuccesssub'  => 'قفل قاعدة البيانات إتشال.',
+'lockdbsuccesstext'   => 'قاعدة البانات اتقفلت خلاص.<br />
+ماتنساش [[Special:UnlockDB|تشيل القفل]] بعد أعمال الصيانة ما تخلص .',
+'unlockdbsuccesstext' => 'قاعدة البيانات إتفتحت تانى',
+'lockfilenotwritable' => 'ملف قفل قاعدة البيانات مش ممكن يتكتب عليه.
+علشان تقفل قاعدة البيانات أو تشيل القفل لازم سيرفر الويب يسمح بالكتابة على الملف دا .',
+'databasenotlocked'   => 'قاعدة البيانات بتاعتك مش  مقفولة.',
+
 # Move page
-'move-page'        => 'انقل $1',
-'move-page-legend' => 'انقل الصفحة',
-'movepagetext'     => "
-لو استعملت النموذج ده ممكن تغير اسم الصفحه، و تنقل تاريخها للاسم الجديد.
+'move-page'               => 'انقل $1',
+'move-page-legend'        => 'انقل الصفحة',
+'movepagetext'            => "لو استعملت النموذج ده ممكن تغير اسم الصفحه، و تنقل تاريخها للاسم الجديد.
 هاتبتدى تحويله من العنوان القديم للصفحه بالعنوان الجديد.
-لكن،  الوصلات في الصفحات اللى تتصل بالصفحه دى مش ها تتغير؛ اتأكد من ان مافيش وصلات مقطوعه، أو وصلات متتاليه، للتأكد من أن المقالات تتصل مع بعضها بشكل مناسب.
+لكن،  الوصلات في الصفحات اللى بتتوصل بالصفحه دى مش ها تتغير؛ اتأكد من ان مافيش  [[Special:BrokenRedirects|وصلات مقطوعه]] ، أو [[Special:DoubleRedirects|وصلات متتاليه]] ، للتأكد من أن المقالات تتصل مع بعضها بشكل مناسب.
 
 لاحظ ان الصفحه مش هاتتنقل لو كان فيه صفحه بالاسم الجديد، إلا إذا كانت صفحة فاضيه، أو صفحة تحويل، ومالهاش تاريخ. و ده معناه أنك مش ها تقدر تحط صفحه مكان صفحه، كمان ممكن ارجاع الصفحه لمكانها في حال تم النقل بشكل غلط.
 
 '''تحذير!'''
 نقل الصفحه ممكن يكون له اثار كبيرة، وتغييرات مش متوقعه بالنسبة للصفحات المشهوره. من فضلك  اتأكد من فهم عواقب نقل الصفحات قبل ما تقوم بنقل الصفحه.",
-'movepagetalktext' => '
+'movepagetalktext'        => '
 
 صفحة المناقشه بتاعة المقاله هاتتنقل برضه، لو كانت موجوده. لكن صفحة المناقشه مش هاتتنقل فى الحالات  دى:
 * نقل الصفحة عبر نطاقات  مختلفه.
@@ -1582,56 +2056,130 @@
 * لو انت شلت اختيار نقل صفحة المناقشه .
 
 وفي الحالات  دى، لو عايز  تنقل صفحة المناقشه  لازم تنقل أو تدمج محتوياتها  يدويا.',
-'movearticle'      => 'انقل الصفحه:',
-'movenologin'      => 'مش متسجل',
-'movenologintext'  => 'لازم تكون يوزر متسجل و تعمل [[Special:Userlogin|دخول]] علشان تنقل الصفحة.',
-'movenotallowed'   => 'ماعندكش الصلاحية لنقل الصفحات في {{SITENAME}}.',
-'newtitle'         => 'للعنوان الجديد:',
-'move-watch'       => 'راقب الصفحه دى',
-'movepagebtn'      => 'نقل الصفحه',
-'pagemovedsub'     => 'تم  النقل بنجاح',
-'movepage-moved'   => '<big>\'\'\'"$1" اتنقلت ل"$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'articleexists'    => '
+'movearticle'             => 'انقل الصفحه:',
+'movenotallowed'          => 'ماعندكش الصلاحية لنقل الصفحات في {{SITENAME}}.',
+'newtitle'                => 'للعنوان الجديد:',
+'move-watch'              => 'راقب الصفحه دى',
+'movepagebtn'             => 'نقل الصفحه',
+'pagemovedsub'            => 'تم  النقل بنجاح',
+'movepage-moved'          => '<big>\'\'\'"$1" اتنقلت ل"$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'articleexists'           => '
 
 يا اما فيه صفحه  بالاسم ده ،او ان الاسم اللى  تم اختياره مش صالح. لو سمحت اختار اسم تانى .',
-'talkexists'       => "'''الصفحه دى اتنقلت لصفحة بنجاح، ولكن صفحة المناقشه بتاعتها ما اتنقلتش  علشان فيه صفحة مناقشه تحت العنوان الجديد. من فضلك انقل محتويات صفحة المناقشه يدويا، وادمجها مع المحتويات اللى قبل كده.'''",
-'movedto'          => 'اتنقلت ل',
-'movetalk'         => 'انقل صفحة المناقشه.',
-'1movedto2'        => '[[$1]] اتنقلت ل [[$2]]',
-'movelogpage'      => 'سجل النقل',
-'movereason'       => 'السبب:',
-'revertmove'       => 'استعاده',
+'cantmove-titleprotected' => 'ما ينفعش تنقل صفحة للمكان دا،لأن العنوان الجديد محمي ضد الانشاء',
+'talkexists'              => "'''الصفحه دى اتنقلت لصفحة بنجاح، ولكن صفحة المناقشه بتاعتها ما اتنقلتش  علشان فيه صفحة مناقشه تحت العنوان الجديد. من فضلك انقل محتويات صفحة المناقشه يدويا، وادمجها مع المحتويات اللى قبل كده.'''",
+'movedto'                 => 'اتنقلت ل',
+'movetalk'                => 'انقل صفحة المناقشه.',
+'move-subpages'           => 'انقل كل الصفحات الفرعية، إن امكن',
+'move-talk-subpages'      => 'انقل كل الصفحات الفرعية لصفحة النقاش، لو ممكن',
+'movepage-page-exists'    => 'الصفحة $1 موجودة فعلا ومش ممكن الكتابة عليها اوتوماتيكي..',
+'movepage-page-moved'     => 'الصفحة $1 اتنقلت لـ $2.',
+'movepage-page-unmoved'   => 'ماقدرناش ننقل الصفحة $1 لـ $2.',
+'movepage-max-pages'      => 'الحد الأقصى $1 {{PLURAL:$1|صفحة|صفحة}} اتنقل. و مافيش حاجة تاني ح تتنقل اوتوماتيكي.',
+'1movedto2'               => '[[$1]] اتنقلت ل [[$2]]',
+'1movedto2_redir'         => '[[$1]] انقلت لـ[[$2]] فوق التحويلة',
+'movelogpage'             => 'سجل النقل',
+'movelogpagetext'         => 'تحت في لستة الصفحات اللي اتنقلت.',
+'movereason'              => 'السبب:',
+'revertmove'              => 'استعاده',
+'delete_and_move'         => 'مسح ونقل',
+'delete_and_move_text'    => '==المسح مطلوب==
+الصفحة الهدف "[[:$1]]" موجودة فعلا.
+انت عايز تمسحها علشان تقدر تنقلها؟',
+'delete_and_move_confirm' => 'ايوة، امسح الصفحة',
+'delete_and_move_reason'  => 'اتمسحت علشان تسمح للنقل',
+'selfmove'                => 'عنوان المصدر والهدف هو نفسه؛
+مش ممكن نقل الصفحة على نفسها.',
+'immobile_namespace'      => 'عنوان المصدر أو الهدف ليه طبيعة خاصة؛
+مش ممكن تنقل الصفحات من و للنطاق دا.',
+'imagenocrossnamespace'   => 'مش ممكن تنقل الملف لنطاق غير نطاق الملفات',
+'imagetypemismatch'       => 'امتداد الملف الجديد مش ماشي مع نوعه',
+'imageinvalidfilename'    => 'اسم الملف الهدف مش صحيح',
+'fix-double-redirects'    => 'اعمل تحديث لاي تحويلات بتشاور على العنوان الاصلي',
 
 # Export
-'export'        => 'تصدير صفحات',
-'export-addcat' => 'زيادة',
+'export'            => 'تصدير صفحات',
+'exporttext'        => 'انت ممكن تصدر النص وتاريخ تعديلات صفحة معينة أو مجموعة صفحات في صيغة إكس إم إل. لو قصدكو بكدا ممكن استيرادها في ويكي تاني بيستعمل ميدياويكي عن طريق الصفحة [[Special:Import|صفحة الاستيراد]].
 
+علشان تصدر الصفحات، اكتب العناوين في الصندوق اللي تحت، عنوان واحد في كل السطر، و اختار اذا كنت عايز  النسخة الحالية بالإضافة  للنسخ القديمة كاملة أو مع معلومات تاريخ الصفحة عنها ولا بس النسخة الحالية مع معلومات عن التعديل الأخير.
+
+في الحالة التانية ممكن تستخدم لينك مباشرة، مثلا [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] للصفحة [[{{MediaWiki:Mainpage}}]].',
+'exportcuronly'     => 'ضمن المراجعة دي بس، ومش التاريخ الكامل',
+'exportnohistory'   => "----
+ملاحظة:''' التصدير الكامل لتاريخ الصفحة  بالطريقة دي مش شغال بسبب الاداء'''",
+'export-submit'     => 'تصدير',
+'export-addcattext' => 'ضيف صفحات من تصنيف:',
+'export-addcat'     => 'زيادة',
+'export-download'   => 'احفظ كملف',
+'export-templates'  => 'دخل القوالب',
+
 # Namespace 8 related
-'allmessages'        => 'رسايل النظام',
-'allmessagesname'    => 'اسم',
-'allmessagescurrent' => 'النص دلوقتى',
+'allmessages'               => 'رسايل النظام',
+'allmessagesname'           => 'اسم',
+'allmessagesdefault'        => 'النص الاوتوماتيكي',
+'allmessagescurrent'        => 'النص دلوقتى',
+'allmessagestext'           => 'دي لستة برسايل النظام المتوفرة في نطاق ميدياويكي.
+لو سمحت تزور[http://www.mediawiki.org/wiki/Localisation ترجمة ميدياويكي] و [http://translatewiki.net بيتاويكي] لو كنت عايز تساهم في ترجمة ميدياويكي الاصلية.',
+'allmessagesnotsupportedDB' => "الصفحة دي مش يمكن حد يستعملها علشان'''\$wgUseDatabaseMessages''' متعطل.",
+'allmessagesfilter'         => 'فلتر اسم الرسالة:',
+'allmessagesmodified'       => 'اعرض اللي اتعدل بس',
 
 # Thumbnails
-'thumbnail-more'  => 'كبر',
-'filemissing'     => 'الملف ضايع',
-'thumbnail_error' => 'غلطه فى انشاء صوره مصغره: $1',
+'thumbnail-more'           => 'كبر',
+'filemissing'              => 'الملف ضايع',
+'thumbnail_error'          => 'غلطه فى انشاء صوره مصغره: $1',
+'djvu_page_error'          => 'صفحة DjVu بره النطاق',
+'djvu_no_xml'              => 'مش ممكن تجيب XML لملف DjVu',
+'thumbnail_invalid_params' => 'محددات التصغير مش صحيحة',
+'thumbnail_dest_directory' => 'مش قادر ينشئ المجلد الهدف',
 
 # Special:Import
-'import'                  => 'استيراد صفحات',
-'import-interwiki-submit' => 'استيراد',
-'importbadinterwiki'      => 'اللينك بتاعة الانترويكي دي غلط',
-'importnotext'            => 'فاضي او مافيش نص',
+'import'                     => 'استيراد صفحات',
+'importinterwiki'            => 'استيراد ترانسويكي',
+'import-interwiki-text'      => 'اختار الويكي و عنوان الصفحة اللي عاوز تستوردها.
+تواريخ التعديلات و اسامي المحررين  ح يتحافظ عليها.
+كل عمليات الاستيراد للترانسويكي بتتسجل في [[Special:Log/import|سجل الاستيراد]].',
+'import-interwiki-history'   => 'انسخ كل نسخ التاريخ للصفحة دي',
+'import-interwiki-submit'    => 'استيراد',
+'import-interwiki-namespace' => 'انقل الصفحات للنطاق:',
+'importtext'                 => 'لو سمحت تصدّر الملف من الويكي المصدر عن طريق [[Special:Export|خاصية التصدير]]،احفظه على جهازك و بعدين حمله هنا.',
+'importstart'                => 'استيراد صفحات...',
+'import-revision-count'      => '{{PLURAL:$1|نسخة واحدة|نسخة}} $1',
+'importnopages'              => 'مافيش صفحات للاستيراد',
+'importfailed'               => 'فشل استيراد: $1',
+'importunknownsource'        => 'نوع مصدر الاستيراد مش معروف',
+'importcantopen'             => 'ماقدرناش نفتح ملف الاستيراد',
+'importbadinterwiki'         => 'اللينك بتاعة الانترويكي دي غلط',
+'importnotext'               => 'فاضي او مافيش نص',
+'importsuccess'              => 'الاستيراد خلص!',
+'importhistoryconflict'      => 'في تاريخ تعديلات متعارض مع بعضه(يمكن الصفحة دي تكون استوردت قبل كدا)',
+'importnosources'            => ' مصادر استيراد الترانسويكي ما تحددتش  و الاستيراد المباشر عن طريق التحميل مش شغال.',
+'importnofile'               => 'ملف الاستيراد ما تحملش.',
+'importuploaderrorsize'      => 'تحميل ملف الاستيراد فشل. الملف أكبر من حجم التحميل المسموح.',
+'importuploaderrorpartial'   => 'تحميل ملف الاستيراد فشل.  جزء من الملف بس اتحمل',
+'importuploaderrortemp'      => 'تحميل ملف الاستيراد فشل. في مجلد مؤقت ضايع.',
+'import-parse-failure'       => 'فشل بارس استيراد XML',
+'import-noarticle'           => 'مافيش صفحة للاستيراد!',
+'import-nonewrevisions'      => 'كل النسخ استوردت قبل كدا.',
+'xml-error-string'           => '$1 عند السطر $2، العمود $3 (بايت $4): $5',
+'import-upload'              => 'حمل بيانات إكس‌إم‌إل',
 
 # Import log
-'importlogpage'             => 'سجل الاستيراد',
-'import-logentry-interwiki' => 'استيراد ويكى $1',
+'importlogpage'                    => 'سجل الاستيراد',
+'importlogpagetext'                => 'استيرادات إدارية لصفحات ليها تاريخ تعديل من مواقع ويكي تانية.',
+'import-logentry-upload'           => 'استورد [[$1]] بواسطة تحميل ملف',
+'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|تعديل واحد|تعديل}}',
+'import-logentry-interwiki'        => 'استيراد ويكى $1',
+'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|تعديل واحد|تعديل}} من $2',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'صفحتى الخاصه',
+'tooltip-pt-anonuserpage'         => 'صفحة اليوزر للأيبي اللي انت بتعمل منه تحرير',
 'tooltip-pt-mytalk'               => 'صفحة مناقشاتى',
+'tooltip-pt-anontalk'             => 'نقاش حوالين التعديلات من عنوان الأيبي دا',
 'tooltip-pt-preferences'          => 'تفضيلاتى',
 'tooltip-pt-watchlist'            => 'لسته بالصفحات اللى انت بتراقب التعديلات فيها',
-'tooltip-pt-mycontris'            => ' لسته بتعديلاتى',
+'tooltip-pt-mycontris'            => 'لسته بتعديلاتى',
 'tooltip-pt-login'                => 'من الافضل انك تسجل دخولك، لكن ده مش شرط',
 'tooltip-pt-anonlogin'            => 'من الأفضل انك تسجل دخولك، لكن ده مش إجبارى.',
 'tooltip-pt-logout'               => 'خروج',
@@ -1639,12 +2187,16 @@
 'tooltip-ca-edit'                 => 'ممكن تعدل  الصفحه دى، بس لو سمحت استعمل زرار البروفه قبل ما تسييفها',
 'tooltip-ca-addsection'           => 'ضيف تعليق للمناقشه دى.',
 'tooltip-ca-viewsource'           => 'الصفحه دى محميه. ممكن تشوف مصدرها.',
+'tooltip-ca-history'              => 'النسخ القديمة من الصفحة دي',
 'tooltip-ca-protect'              => 'احمى الصفحه دى',
 'tooltip-ca-delete'               => 'امسح الصفحه دى',
+'tooltip-ca-undelete'             => 'رجع التعديلات اللي حصلت على الصفحة دي قبل ما تتمسح',
 'tooltip-ca-move'                 => 'انقل الصفحه دى',
 'tooltip-ca-watch'                => 'حط الصفحة دى فى لسته الصفحات اللى باراقب التعديلات فيها',
 'tooltip-ca-unwatch'              => 'شيل الصفحه دى من لستة الصفحات اللى بتراقبها',
 'tooltip-search'                  => 'دور فى {{SITENAME}}',
+'tooltip-search-go'               => 'روح  لصفحة بنفس الاسم دا لو موجودة',
+'tooltip-search-fulltext'         => 'دور في الصفحات  على النص دا',
 'tooltip-p-logo'                  => 'الصفحه الرئيسيه',
 'tooltip-n-mainpage'              => 'زور الصفحه الرئيسيه',
 'tooltip-n-portal'                => 'عن المشروع، ممكن تعمل ايه، و فين تلاقى اللى بتدور عليه',
@@ -1653,11 +2205,18 @@
 'tooltip-n-randompage'            => 'حمل صفحة عشوائيه',
 'tooltip-n-help'                  => 'لو محتاج مساعده بص هنا',
 'tooltip-t-whatlinkshere'         => 'صفحات الويكى اللى بتوصل هنا',
+'tooltip-t-recentchangeslinked'   => 'اخر التغييرات في الصفحات الموصولة من الصفحة دي',
+'tooltip-feed-rss'                => 'تلقيم أر إس إس للصفحة دي',
+'tooltip-feed-atom'               => 'تلقيم أتوم للصفحة دي',
 'tooltip-t-contributions'         => 'عرض مساهمات اليوزر ده',
 'tooltip-t-emailuser'             => 'ابعت ايميل لليوزر ده',
 'tooltip-t-upload'                => 'حمل ملفات',
 'tooltip-t-specialpages'          => 'لسته بكل الصفحات المخصوصه',
+'tooltip-t-print'                 => 'نسخة للطباعة لصفحة دي',
+'tooltip-t-permalink'             => 'لينك دايمة للنسخة دي من الصفحة',
+'tooltip-ca-nstab-main'           => 'اعرض صفحة المحتوى',
 'tooltip-ca-nstab-user'           => 'اعرض صفحة اليوزر',
+'tooltip-ca-nstab-media'          => 'اعرض صفحة الميديا',
 'tooltip-ca-nstab-special'        => 'الصفحة دي صفحة مخصوصة ، مش ممكن تعدل الصفحة نفسها',
 'tooltip-ca-nstab-project'        => 'اعرض صفحة المشروع',
 'tooltip-ca-nstab-image'          => 'اعرض صفحة الفايل',
@@ -1671,40 +2230,120 @@
 'tooltip-diff'                    => 'اعرض التعديلات اللى انت عملتها على النص.',
 'tooltip-compareselectedversions' => 'شوف الفروق بين النسختين المختارتين للصفحه دى.',
 'tooltip-watch'                   => 'ضم الصفحه دى للستة الصفحات اللى بتراقبها',
+'tooltip-recreate'                => 'إنشيء الصفحة تاني مع انها اتمسحت قبل كدا',
 'tooltip-upload'                  => 'ابتدي التحميل',
 
+# Scripts
+'common.js'      => '/*  أي جافاسكريبت  هناح يتحمل لكل اليوزرز مع كل تحميل للصفحة. */',
+'standard.js'    => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة ستاندرد */',
+'nostalgia.js'   => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة نوستالجيا */',
+'cologneblue.js' => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة كولون بلو */',
+'monobook.js'    => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة مونوبوك */',
+'myskin.js'      => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة ماي سكين */',
+'chick.js'       => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة تشيك */',
+'simple.js'      => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة سيمبل */',
+'modern.js'      => '/* أي جافاسكريبت هنا ح تتحمل لليوزرز اللي بيستعملو واجهة مودرن */',
+
+# Metadata
+'nodublincore'      => 'Dublin Core RDF metadata متعطلة للسيرفر دا.',
+'nocreativecommons' => 'Creative Commons RDF metadata متعطلة  للسيرفر دا.',
+'notacceptable'     => 'السيرفر بتاع الويكي مش ممكن يديلك بيانات بصيغة ممكن عميلك يقراها.',
+
 # Attribution
-'others'      => 'تانيين',
-'creditspage' => 'حقوق الصفحة',
+'anonymous'        => 'يوزر مجهول ل {{SITENAME}}',
+'siteuser'         => 'يوزر {{SITENAME}} $1',
+'lastmodifiedatby' => 'آخر تعديل  للصفحة دي كان في $2، $1 عن طريق $3.', # $1 date, $2 time, $3 user
+'othercontribs'    => 'بناء على عمل $1.',
+'others'           => 'تانيين',
+'siteusers'        => '{{SITENAME}} يوزر(و) $1',
+'creditspage'      => 'حقوق الصفحة',
+'nocredits'        => 'مافيش معلومات حقوق متوفرة للصفحة دي.',
 
 # Spam protection
 'spamprotectiontitle' => 'فلتر الحمايه من السبام',
+'spamprotectiontext'  => 'السبام فيلتر منعك من إنك تحفظ الصفحة دي. السبب يمكن  علشان في لينك لسايت خارجي.',
+'spamprotectionmatch' => 'النص دا هو اللي نشط السبام فيلتر بتاعنا: $1',
 'spambot_username'    => 'تنظيف سبام ميدياويكى',
+'spam_reverting'      => 'ترجيع آخر نسخة مافيهاش لينكات لـ $1',
+'spam_blanking'       => 'كل النسخ فيها لينكات ل $1، فضيها',
 
 # Info page
-'infosubtitle' => 'معلومات للصفحه',
+'infosubtitle'   => 'معلومات للصفحه',
+'numedits'       => 'عدد التعديلات (صفحة): $1',
+'numtalkedits'   => 'عدد التعديلات (صفحة نقاش): $1',
+'numwatchers'    => 'عدد المراقبين: $1',
+'numauthors'     => 'عدد المؤلفين المميزين (صفحة): $1',
+'numtalkauthors' => 'عدد المؤلفين المميزين (صحفة نقاش): $1',
 
+# Math options
+'mw_math_png'    => 'دايما اعرض PNG',
+'mw_math_simple' => 'يا إما HTML لو بسيطة قوي أو PNG',
+'mw_math_html'   => 'ياإما HTML لو ممكن أو PNG',
+'mw_math_source' => 'اعرض على هيئة TeX (للبراوزرات النصية)',
+'mw_math_modern' => 'أحسن للبراوزرات الحديثة',
+'mw_math_mathml' => 'اعرض بصيغة MathML لو ممكن (تحت التجريب)',
+
+# Patrolling
+'markaspatrolleddiff'                 => 'علم عليها انها متراجعة',
+'markaspatrolledtext'                 => 'علم على المقاله دي إنها متراجعة',
+'markedaspatrolled'                   => 'اتعلم عليها متراجعة',
+'markedaspatrolledtext'               => 'النسخة المختارة اتعلم عيها انها متراجعة',
+'rcpatroldisabled'                    => 'مراجعة أخر التغييرات متعطلة',
+'rcpatroldisabledtext'                => 'خاصية مراجعة أحدث التغييرات متعطلة  دلوقتي',
+'markedaspatrollederror'              => 'مش ممكن تعلم علها إنها متراجعة',
+'markedaspatrollederrortext'          => 'لازم تختار النسخة اللي عاوز تعلم عليها إنها متراجعة',
+'markedaspatrollederror-noautopatrol' => 'مش مسموح ليك تعلم على تغييراتك الشخصية كأنها متراجعة.',
+
 # Patrol log
-'patrol-log-auto' => '(اوتوماتيكي)',
+'patrol-log-page'   => 'سجل المراجعة',
+'patrol-log-header' => 'دا سجل بالنسخ المتراجعة',
+'patrol-log-line'   => 'علم على $1 من $2 كأنها متراجعة $3',
+'patrol-log-auto'   => '(اوتوماتيكي)',
+'patrol-log-diff'   => 'ن$1',
 
+# Image deletion
+'deletedrevision'                 => 'مسح النسخة القديمة $1',
+'filedeleteerror-short'           => 'غلط مسح الملف: $1',
+'filedeleteerror-long'            => 'حصلت غلطات و الملف دا بيتمسح :
+
+$1',
+'filedelete-missing'              => 'الملف "$1" ما ينفعش يتمسح لأنه مش موجود.',
+'filedelete-old-unregistered'     => 'نسخة الملف المحددة "$1" مش في قاعدة البيانات.',
+'filedelete-current-unregistered' => 'الملف المحدد "$1" مش في قاعدة البيانات.',
+'filedelete-archive-read-only'    => 'مش ممكن تكتب على مجلد الأرشيف "$1" بالويب سيرفر',
+
 # Browsing diffs
 'previousdiff' => '→ الفرق اللى قبل كده',
 'nextdiff'     => 'الفرق اللى بعد كده ←',
 
 # Media information
-'thumbsize'            => 'حجم العرض المصغر:',
+'mediawarning'         => "'''تحذير''': الملف دا فيه كود خبيث، يمكن عند تشغيله يبوظ الكمبيوتر بتاعك.<hr />",
+'imagemaxsize'         => 'حدد الصور في صفحات وصف الملفات لـ:',
+'thumbsize'            => 'حجم العرض المتصغر:',
+'widthheightpage'      => '$1×$2، $3 {{PLURAL:$3|صفحة|صفحة}}',
+'file-info'            => '(حجم الملف: $1، نوع MIME: $2)',
 'file-info-size'       => '($1 × $2 بكسل حجم الفايل: $3، نوع MIME: $4)',
 'file-nohires'         => '<small>مافيش  ريزوليوشن اعلى متوفر.</small>',
 'svg-long-desc'        => '(ملف SVG، اساسا $1 × $2 بكسل، حجم الملف: $3)',
 'show-big-image'       => 'الصورة بدقه كامله',
 'show-big-image-thumb' => '<small>حجم البروفه دى: $1 × $2 بكسل</small>',
 
-# Special:Newimages
-'newimages'    => 'جاليرى الصور الجديده',
-'showhidebots' => '($1 بوتات)',
-'ilsubmit'     => 'تدوير',
-'bydate'       => 'على حسب التاريخ',
+# Special:NewImages
+'newimages'             => 'جاليرى الصور الجديده',
+'imagelisttext'         => 'دي لستة بـ$1 {{PLURAL:$1|ملف|ملفات}} مترتبة $2.',
+'newimages-summary'     => 'الصفحةالمخصوصة دي بتعرض آخر الملفات المتحملة',
+'showhidebots'          => '($1 بوتات)',
+'noimages'              => 'مافيش حاجة للعرض.',
+'ilsubmit'              => 'تدوير',
+'bydate'                => 'على حسب التاريخ',
+'sp-newimages-showfrom' => 'بين الملفات الجديدة  من أول $2، $1',
 
+# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
+'video-dims'     => '$1، $2×$3',
+'seconds-abbrev' => 'ث',
+'minutes-abbrev' => 'ق',
+'hours-abbrev'   => 'س',
+
 # Bad image list
 'bad_image_list' => 'الصيغه بالشكل ده:
 
@@ -1733,17 +2372,31 @@
 'exif-photometricinterpretation'   => 'تركيب البكسل',
 'exif-orientation'                 => 'التوجيه',
 'exif-samplesperpixel'             => 'عدد المكونات',
+'exif-planarconfiguration'         => 'ترتيب البيانات',
+'exif-ycbcrsubsampling'            => 'نسبة العينة الفرعية بتاعة Y لـ C',
 'exif-ycbcrpositioning'            => 'وضع Y و C',
+'exif-xresolution'                 => 'الدقة الأفقية',
+'exif-yresolution'                 => 'الدقة الرأسية',
+'exif-resolutionunit'              => 'وحدة تحليل X و Y',
+'exif-stripoffsets'                => 'موقع بيانات الصورة',
+'exif-rowsperstrip'                => 'عدد الصفوف لكل ستريب',
+'exif-stripbytecounts'             => 'بايت لكل ستريب مضغوط',
+'exif-jpeginterchangeformat'       => 'الحد ل JPEG SOI',
 'exif-jpeginterchangeformatlength' => 'بايت من بيانات JPEG',
 'exif-transferfunction'            => 'وظيفة النقل',
+'exif-whitepoint'                  => 'ألوان النقطة البيضا',
+'exif-primarychromaticities'       => 'ألوان الأساسيات',
+'exif-ycbcrcoefficients'           => 'معاملات مصفوفة تحويل فراغ اللون',
+'exif-referenceblackwhite'         => 'جوز من قيم المرجع السودا والبيضا',
 'exif-datetime'                    => 'تاريخ و وقت تغيير الملف',
 'exif-imagedescription'            => 'عنوان الصورة',
-'exif-make'                        => 'منتج آلة التصوير',
+'exif-make'                        => 'منتج الكاميرا',
 'exif-model'                       => 'موديل الكاميرا',
 'exif-software'                    => 'البرمجيات المستخدمة',
 'exif-artist'                      => 'المؤلف',
 'exif-copyright'                   => 'صاحب الحقوق الممحفوظة',
 'exif-exifversion'                 => 'نسخة Exif',
+'exif-flashpixversion'             => 'نسخة فلاش بكس المدعومة',
 'exif-colorspace'                  => 'فرق اللون',
 'exif-componentsconfiguration'     => 'معنى كل مكون',
 'exif-compressedbitsperpixel'      => 'طور ضغط الصورة',
@@ -1755,13 +2408,16 @@
 'exif-datetimeoriginal'            => 'تاريخ و وقت الإنتاج',
 'exif-datetimedigitized'           => 'تاريخ و وقت التحويل الرقمى',
 'exif-subsectime'                  => 'وقت تاريخ ثوانى فرعية',
+'exif-subsectimeoriginal'          => 'وقت تاريخ أصلي ثواني فرعية',
 'exif-subsectimedigitized'         => 'وقت تاريخ رقمى ثوانى فرعية',
 'exif-exposuretime'                => 'مدة التعرض',
 'exif-exposuretime-format'         => '$1 ثانية ($2)',
 'exif-fnumber'                     => 'العدد البؤرى',
+'exif-fnumber-format'              => 'البعد البؤري/$1',
 'exif-exposureprogram'             => 'برنامج التعرض',
 'exif-spectralsensitivity'         => 'الحساسية الطيفية',
 'exif-isospeedratings'             => 'تقييم سرعة أيزو',
+'exif-oecf'                        => 'عامل التحويل الكهروضوئى',
 'exif-shutterspeedvalue'           => 'سرعة القافل',
 'exif-aperturevalue'               => 'فتحة القافل',
 'exif-brightnessvalue'             => 'الضي',
@@ -1769,14 +2425,17 @@
 'exif-maxaperturevalue'            => 'أقصى قافل أرضى',
 'exif-subjectdistance'             => 'مسافة من الجسم',
 'exif-meteringmode'                => 'طور القياس بالمتر',
-'exif-lightsource'                 => 'مصدر الضوء',
+'exif-lightsource'                 => 'مصدر النور',
 'exif-flash'                       => 'فلاش',
 'exif-focallength'                 => 'البعد البؤرى  للعدسة',
-'exif-subjectarea'                 => ' منطقة الجسم',
+'exif-focallength-format'          => '$1 ملم',
+'exif-subjectarea'                 => 'منطقة الجسم',
 'exif-flashenergy'                 => 'طاقة الفلاش',
+'exif-spatialfrequencyresponse'    => 'استجابة التردد الفراغي',
 'exif-focalplanexresolution'       => 'تحليل المستوى البؤرى X',
+'exif-focalplaneyresolution'       => 'تحليل المستوى البؤرى Y',
 'exif-focalplaneresolutionunit'    => 'وحدة تحليل المستوى البؤرى',
-'exif-subjectlocation'             => 'موضع الجسم',
+'exif-subjectlocation'             => 'مكان الجسم',
 'exif-exposureindex'               => 'فهرس التعرض',
 'exif-sensingmethod'               => 'وسيلة الاستشعار',
 'exif-filesource'                  => 'مصدر الملف',
@@ -1970,7 +2629,7 @@
 
 # External editor support
 'edit-externally'      => 'استعمل تطبيق من بره علشان تعدل الملف دا',
-'edit-externally-help' => 'بص على [http://meta.wikimedia.org/wiki/Help:External_editors  تعليمات الاعداد] علشان معلومات اكتر.',
+'edit-externally-help' => 'بص على [http://www.mediawiki.org/wiki/Manual:External_editors  تعليمات الاعداد] علشان معلومات اكتر.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'الكل',
@@ -2040,7 +2699,7 @@
 'unit-pixel' => 'بيكس',
 
 # HTML dump
-'redirectingto' => 'بتتحول لـ [[$1]]...',
+'redirectingto' => 'بتتحول لـ [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'امسح الكاش بتاع الصفحة دي؟
@@ -2057,7 +2716,7 @@
 
 # Separators for various lists, etc.
 'semicolon-separator' => '؛',
-'comma-separator'     => '،',
+'comma-separator'     => '،&#32;',
 'autocomment-prefix'  => '-',
 
 # Multipage image navigation
@@ -2098,8 +2757,8 @@
 جرب البروفة العادية.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'التغييرات الأحدث من $1 ثانية ممكن ما تظهرش في اللستة دي.',
-'lag-warn-high'   => 'علشان في تأخير كبير في تحديث قاعدة البيانات بتاعة السيرفر، التغييرات أحدث من $1 ثانية
+'lag-warn-normal' => 'التغييرات الأحدث من $1 {{PLURAL:$1|ثانية|ثانية}} ثانية ممكن ما تظهرش في اللستة دي.',
+'lag-warn-high'   => 'علشان في تأخير كبير في تحديث قاعدة البيانات بتاعة السيرفر، التغييرات أحدث من $1 {{PLURAL:$1|ثانية|ثانية}}
 ممكن ما تظهرش في اللستة دي.',
 
 # Watchlist editor
@@ -2157,7 +2816,7 @@
 'version-software-product'         => 'المنتج',
 'version-software-version'         => 'النسخه',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'مسار ملف',
 'filepath-page'    => 'الملف:',
 'filepath-submit'  => 'المسار',
@@ -2193,7 +2852,7 @@
 'specialpages-group-redirects'   => 'صفحات  التحويل الخاصه',
 'specialpages-group-spam'        => 'أدوات السبام',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'صفحة فاضية',
 'intentionallyblankpage' => 'الصفحة دي متسابة فاضية بالقصد',
 
Index: languages/messages/MessagesLb.php
===================================================================
--- languages/messages/MessagesLb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Kaffi
  * @author Robby
- * @author Kaffi
- * @author Siebrand
- * @author SPQRobin
  * @author לערי ריינהארט
- * @author Jon Harald Søby
  */
 
 $fallback = 'de';
@@ -167,7 +164,7 @@
 'tog-uselivepreview'          => 'Live-Preview notzen (JavaScript) (experimentell)',
 'tog-forceeditsummary'        => 'Warnen, wa beim Späicheren de Resumé feelt',
 'tog-watchlisthideown'        => 'Meng Ännerungen op menger Iwwerwaachungslëscht verstoppen',
-'tog-watchlisthidebots'       => 'Ännerungen vu Botten op menger Iwwerwaachungslëscht verstoppen',
+'tog-watchlisthidebots'       => 'Ännerunge vu Botten op menger Iwwerwaachungslëscht verstoppen',
 'tog-watchlisthideminor'      => 'Kleng Ännerungen op menger Iwwerwaachungslëscht verstoppen',
 'tog-nolangconversion'        => 'Ëmwandlung vu Sproochvarianten ausschalten',
 'tog-ccmeonemails'            => 'Schéck mir eng Kopie vun de Mailen, déi ech anere Benotzer schécken.',
@@ -408,7 +405,7 @@
 'nosuchspecialpage' => 'Spezialsäit gëtt et net',
 'nospecialpagetext' => "<big>'''Dir hutt eng Spezialsäit ofgefrot déi et net gëtt.'''</big>
 
-All Spezialsäiten déi et gëtt sinn op der [[Special:Specialpages|Lescht vun de Spezialsäiten]] ze fannen.",
+All Spezialsäiten déi et gëtt sinn op der [[Special:SpecialPages|Lescht vun de Spezialsäiten]] ze fannen.",
 
 # General errors
 'error'                => 'Feeler',
@@ -421,9 +418,9 @@
 'laggedslavemode'      => 'Opgepasst: Dës Säit ass net onbedingt um neiste Stand.',
 'readonly'             => "D'Datebank ass gespaart",
 'enterlockreason'      => "Gitt w.e.g. e Grond u firwat d'Datebak gespaart ass, a wéi laang dës Spär ongeféier bestoe soll.",
-'readonlytext'         => 'Datebank ass am Moment fir all Ännerunge gespaart, wahrscheinlech wéinst Maintenance vun der Datebank, duerno ass erëm alles beim alen.
+'readonlytext'         => 'Datebank ass elo fir all Ännerunge gespaart, wahrscheinlech wéinst Maintenance vun der Datebank, duerno ass erëm alles beim alen.
 
-Den Administrateur huet folgend Erklärung uginn: $1',
+Den Administrateur huet dës Erklärung uginn: $1',
 'missingarticle-rev'   => '(Versiounsnummer: $1)',
 'missingarticle-diff'  => '(Ënnerscheed tësche Versiounen: $1, $2)',
 'readonly_lag'         => "D'Datebank gouf automatesch gespaart fir datt d'Zweetserveren (slaves) nees mat dem Haaptserver (master) synchron geschalt kënne ginn.",
@@ -473,11 +470,11 @@
 'logouttitle'                => 'Benotzer-Ofmeldung',
 'logouttext'                 => '<strong>Dir sidd elo ofgemeld.</strong>
 
-Dir kënnt {{SITENAME}} elo anonym benotzen, oder Iech nacheemol als deeselwechten oder en anere Benotzer umelden.
+Dir kënnt {{SITENAME}} elo anonym benotzen, oder Iech [[Special:UserLogin|nacheemol umellen]] als deeselwechten oder en anere Benotzer.
 Opgepasst: Op verschiddene Säite gesäit et nach esou aus, wéi wann Dir nach ugemeld wiert, bis Dir ärem Browser seng Cache eidelmaacht.',
 'welcomecreation'            => '== Wëllkomm, $1! ==
-
-Äre Kont gouf kreéiert. Denkt drun, Är {{SITENAME}}-Astellungen unzepassen.',
+Äre Kont gouf kreéiert. 
+Denkt drun, Är [[Special:Preferences|{{SITENAME}}-Astellungen]] unzepassen.',
 'loginpagetitle'             => 'Benotzer-Umeldung',
 'yourname'                   => 'Benotzernumm:',
 'yourpassword'               => 'Passwuert:',
@@ -490,7 +487,7 @@
 Probéiert et w.e.g. nach eng Kéier!",
 'login'                      => 'Umellen',
 'nav-login-createaccount'    => 'Aloggen',
-'loginprompt'                => "Fir sech op {{SITENAME}} umellen ze kënnen, mussen d'Cookien aktivéiert sinn.",
+'loginprompt'                => "Fir sech op [[Special:UserLogin|{{SITENAME}} umellen]] ze kënnen, mussen d'Cookien aktivéiert sinn.",
 'userlogin'                  => 'Aloggen',
 'logout'                     => 'Ofmellen',
 'userlogout'                 => 'Ausloggen',
@@ -633,29 +630,28 @@
 Aus deem Grond ass et recommandéiert, sech e Benotzernumm zouzeleeën, fir all Mëssverständnes z'évitéieren. 
 
 Dir kënnt d'Funktioun \"Dësem Benotzer eng E-Mail schécken\" nëmme benotzen, wann Dir eng gülteg E-Mail Adress bei äre [[Special:Preferences|Astellungen]] aginn hutt.
-Är aktuell-IP Adress ass \$3 an d'Nummer vun der Spär ass #\$5. Schreift dës w.e.g. bei all Fro dobäi.",
+Är aktuell-IP Adress ass \$3 an d'Nummer vun der Spär ass #\$5. 
+Schreift all dës Informatioune w.e.g. bei all Ufro derbäi.",
 'autoblockedtext'                  => 'Är IP-Adress gouf automatesch gespaart, well se vun engem anere Benotzer gebraucht gouf, an dëse vum $1 gespaart ginn ass.
 De Grond dofir war:
 
 :\'\'$2\'\'
 
 * Ufank vun der Spär: $8
+* Dauer vun der Spär: $6
 * D\'Spär leeft of: $6
 
 Dir kënnt de(n) $1 oder soss een [[{{MediaWiki:Grouppage-sysop}}|Administrateur]] kontaktéieren, fir iwwer dës Spär ze diskutéieren.
 
 Bedenkt datt Dir d\'Fonctioun "Dësem Benotzer eng E-Mail schécken" benotze kënnt wann Dir eng gülteg E-Mailadress an ären [[Special:Preferences|Astellungen]] uginn hutt a wann dat net fir iech gespaart gouf.
 
-D\'Nummer vun ärer Spär ass $5. Gitt dës Nummer w.e.g bei allen Ufroen zu dëser Spär un.',
+Är aktuell IP-Adress ass $3 an d\'Nummer vun ärer Spär ass $5. 
+Gitt dës Donnéeë w.e.g bei allen Ufroen zu dëser Spär un.',
 'blockednoreason'                  => 'Kee Grond uginn',
 'blockedoriginalsource'            => "De Quelltext vun '''$1''' steet hei ënnendrënner:",
 'blockededitsource'                => "Den Text vun '''ären Ännerungen''' op '''$1''' steet hei ënnendrënner:",
-'whitelistedittitle'               => 'Login noutwännesch fir ze änneren',
+'whitelistedittitle'               => "[[Special:UserLogin|Login noutwännesch]] fir z'änneren",
 'whitelistedittext'                => 'Dir musst iech $1, fir Säiten änneren ze kënnen.',
-'whitelistreadtitle'               => 'Fir ze liesen muss Dir ugemeld sinn',
-'whitelistreadtext'                => 'Dir musst [[Special:Userlogin|ageloggt]] sinn, fir Säiten ze liesen.',
-'whitelistacctitle'                => 'Dir däerft kee Benotzerkont uleeën.',
-'whitelistacctext'                 => 'Fir Konten op {{SITENAME}} kënnen opzemaachen musst Dir [[Special:Userlogin|ageloggt]] sinn an déi noutwänneg Rechter hunn.',
 'confirmedittitle'                 => "Konfirmatioun vun ärer E-Mailadress ass erfuederlech fir z'änneren.",
 'confirmedittext'                  => 'Dir musst är E-Mail-Adress conirméieren, ier Dir ännerunge maache kënnt.
 Gitt w.e.g. Eng E-Mailadrss a validéiert se op äre [[Special:Preferences|Benotzerastellungen]].',
@@ -668,7 +664,10 @@
 'accmailtext'                      => "D'Passwuert fir „$1“ gouf op $2 geschéckt.",
 'newarticle'                       => '(Nei)',
 'newarticletext'                   => "Dir hutt op e Link vun enger Säit geklickt, déi et nach net gëtt. Fir dës Säit unzeleeën, gitt w.e.g. ären Text an déi Këscht hei ënnendrënner an (kuckt d'[[{{MediaWiki:Helppage}}|Hëllef Säit]] fir méi Informatiounen). Wann Dir duerch een Iertum heihi komm sidd, da klickt einfach op de Knäppchen '''Zréck''' vun ärem Browser.",
-'anontalkpagetext'                 => "---- ''Dëst ass d'Diskussiounssäit fir en anonyme Benotzer deen nach kee Kont opgemaach huet oder en net benotzt. Dowéinster musse mir d'IP Adress benotzen fir hien/hatt z'identifizéieren. Sou eng IP Adress ka vun e puer Benotzer gedeelt ginn. Wann Dir en anonyme Benotzer sidd an dir irrelevant Kommentäre krut, [[Special:Userlogin|maacht e Kont op oder loggt Iech an]] fir weider Verwiesselungen mat anonyme Benotzer ze verhënneren.''",
+'anontalkpagetext'                 => "---- ''Dëst ass d'Diskussiounssäit fir en anonyme Benotzer deen nach kee Kont opgemaach huet oder en net benotzt.
+Dowéinster musse mir d'IP Adress benotzen fir hien/hatt z'identifizéieren. 
+Sou eng IP Adress ka vun e puer Benotzer gedeelt ginn. 
+Wann Dir en anonyme Benotzer sidd an dir irrelevant Kommentäre krut,  [[Special:UserLogin|maacht w.e.g. e Kont op]] oder [[Special:UserLogin|loggt Iech an]] fir weider Verwiesselungen mat anonyme Benotzer ze verhënneren.''",
 'noarticletext'                    => 'Dës Säit huet momentan nach keen Text, Dir kënnt op anere Säiten no [[Special:Search/{{PAGENAME}}|dësem Säitentitel sichen]] oder [{{fullurl:{{FULLPAGENAME}}|action=edit}} esou eng Säit uleeën].',
 'userpage-userdoesnotexist'        => 'De Benotzerkont "$1" gëtt et net. Iwwerpréift w.e.g. op Dir dës Säit erschafe/ännere wëllt.',
 'clearyourcache'                   => "'''Opgepasst - Nom Späichere muss der Ärem Browser seng Cache eidel maachen, fir d'Ännerungen ze gesinn.''' '''Mozilla / Firefox / Safari: ''' dréckt op ''Shift'' während Dir ''reload'' klickt oder dréckt ''Ctrl-F5'' oder ''Ctrl-R''(''Command-R'' op engem Macintosh);'''Konqueror: ''' klickt  ''Reload'' oder dréckt ''F5'' '''Opera:''' maacht de Cache eidel an ''Tools → Preferences;'' '''Internet Explorer:''' dréckt ''Ctrl'' während Dir op ''Refresh'' klickt oder dréckt ''Ctrl-F5.''",
@@ -679,12 +678,15 @@
 'note'                             => '<strong>Notiz:</strong>',
 'previewnote'                      => "<strong>Dëst ass nëmmen e Preview; D'Ännerunge sinn nach net gespäichert!</strong>",
 'previewconflict'                  => 'Dir gesitt an dem ieweschten Textfeld wéi den Text ausgesi wäert, wann Dir späichert.',
-'session_fail_preview'             => "<strong>Et deet eis leed, mee är Ännerung konnt net gespäichert gi well d'Date vun ärer Sessioun verluergaange sinn. Versicht et w.e.g. nach eng Kéier. Wann de Problem dann ëmmer nach bestoe sollt, da versicht iech kuerz aus- an dann erëm anzeloggen.</strong>",
-'session_fail_preview_html'        => "<strong>Et deet eis leed, mee är Ännerung konnt net gespäichert gi well d'Date vun ärer Sessioun verluergaange sinn.</strong>
+'session_fail_preview'             => "<strong>Et deet eis leed, mee är Ännerung konnt net gespäichert gi well d'Date vun ärer Sessioun verluergaange sinn.
+Versicht et w.e.g. nach eng Kéier.
+Wann de Problem dann ëmmer nach bestoe sollt, da versicht iech [[Special:UserLogout|auszeloggen]] an dann erëm anzeloggen.</strong>",
+'session_fail_preview_html'        => "<strong>Et deet eis leed! Är Ännerung konnt net gespäichert gi well d'Date vun ärer Sessioun verluergaange sinn.</strong>
 
-''Well op {{SITENAME}} d'Späichere vu ''raw HTML'' aktivéiert ass, gouf de Preview ausgeblendt, fir JavaScript-Attacken ze vermeiden.''
+''Well op {{SITENAME}} ''raw HTML'' aktivéiert ass, gouf de Preview ausgeblendt fir JavaScript-Attacken ze vermeiden.''
 
-<strong>Versicht et w.e.g. nach eng Kéier. Wann de Problem dann ëmmer nach bestoe sollt, da versicht iech kuerz aus- an dann erëm anzeloggen.</strong>",
+<strong>Wann dir eng berechtigt Ännerung maache wëllt, da versicht et w.e.g. nach eng Kéier. 
+Wann de Problem dann ëmmer nach bestoe sollt, versicht iech [[Special:UserLogout|auszeloggen]] an dann erëm anzeloggen.</strong>",
 'editing'                          => 'Ännere vun $1',
 'editingsection'                   => 'Ännere vun $1 (Abschnitt)',
 'editingcomment'                   => 'Ännere vun $1 (Bemierkung)',
@@ -722,7 +724,7 @@
 'hiddencategories'                 => 'Dës Säit gehéiert zu {{PLURAL:$1|1 verstoppter Kategorie|$1 verstoppte Kategorien}}:',
 'edittools'                        => '<!-- Dësen Text gëtt ënnert dem "Ännere"-Formulair esouwéi dem "Eropluede"-Formulair ugewisen. -->',
 'nocreatetitle'                    => "D'Uleeë vun neie Säiten ass limitéiert.",
-'nocreatetext'                     => "Op {{SITENAME}} gouf d'Schafe vun neie Säite limitéiert. Dir kënnt Säiten déi scho bestinn änneren oder Iech [[Special:Userlogin|umellen]].",
+'nocreatetext'                     => "Op {{SITENAME}} gouf d'Schafe vun neie Säite limitéiert. Dir kënnt Säiten déi scho bestinn änneren oder Iech [[Special:UserLogin|umellen]].",
 'nocreate-loggedin'                => 'Dir hutt keng Berechtigung fir nei Säiten op {{SITENAME}} unzeleeën.',
 'permissionserrors'                => 'Berechtigungs-Feeler',
 'permissionserrorstext'            => 'Dir hutt net genuch Rechter fir déi Aktioun auszeféieren. {{PLURAL:$1|Grond|Grënn}}:',
@@ -745,7 +747,7 @@
 'undo-success' => "D'Ännerung gëtt réckgängeg gemaach. Iwwerpréift w.e.g. de Verglach ënnedrënner fir nozekuckeen ob et esou richteg ass, duerno späichert w.e.g d'Ännerungen of fir dës Aktioun ofzeschléissen.",
 'undo-failure' => '<span class="error">D\'Ännerung konnt net réckgängeg gemaach ginn, wëll de betraffenen Abschnitt an der Tëschenzäit geännert gouf.</span>',
 'undo-norev'   => "D'Ännerung kann net zréckgesat ginn, well et se net gëtt oder well se scho geläscht ass.",
-'undo-summary' => 'Ännerung $1 vu(n) [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussioun]]) gouf annulléiert.',
+'undo-summary' => 'Ännerung $1 vu(n) [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussioun]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])) annulléieren.',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Benotzerkont konnt net opgemaach ginn',
@@ -831,7 +833,7 @@
 # Suppression log
 'suppressionlog'     => 'Lëscht vun de verstoppten a geläschte Säiten',
 'suppressionlogtext' => "Ënnendrënner ass eng Lëscht vun de geläschte Säiten a Spären déi fir d'Administrateuren net sichtbar sinn.
-Kuckt [[Special:Ipblocklist|Lëscht vun de gespaarten IPen]] fir déi aktuell Spären.",
+Kuckt [[Special:IPBlockList|Lëscht vun de gespaarten IPen]] fir déi aktuell Spären.",
 
 # History merging
 'mergehistory'                     => 'Historiquë fusionéieren',
@@ -871,7 +873,7 @@
 # Search results
 'searchresults'             => 'Resultat vun der Sich',
 'searchresulttext'          => "Fir méi Informatiounen iwwert d'Sichfunktiounen op {{SITENAME}}, kuckt w.e.g op [[{{MediaWiki:Helppage}}|{{int:help}}]].",
-'searchsubtitle'            => 'Dir hutt no "[[:$1|$1]]" gesicht.',
+'searchsubtitle'            => 'Dir hutt no "[[:$1]]" gesicht ([[Special:Prefixindex/$1|all Säiten déi mat "$1" ufänken]] | [[Special:WhatLinksHere/$1|all Sàiten déi op "$1" linken]])',
 'searchsubtitleinvalid'     => 'Dir hutt no "$1" gesicht.',
 'noexactmatch'              => "'''Et gëtt keng Säite mam Titel \"\$1\".'''
 
@@ -916,7 +918,7 @@
 'mypreferences'            => 'Meng Astellungen',
 'prefs-edits'              => 'Zuel vun den Ännerungen:',
 'prefsnologin'             => 'Net ageloggt',
-'prefsnologintext'         => 'Dir musst [[Special:Userlogin|agelogged]] sinn, fir är Astellungen änneren ze kënnen.',
+'prefsnologintext'         => 'Dir musst [[Special:UserLogin|agelogged]] sinn, fir är Astellungen änneren ze kënnen.',
 'prefsreset'               => "D'Astellungen goufen zréckgesat esou wéi se ofgespäichert waren.",
 'qbsettings'               => 'Geschirläischt',
 'qbsettings-none'          => 'Keen',
@@ -987,7 +989,7 @@
 'userrights-reason'           => 'Grond:',
 'userrights-no-interwiki'     => "Dir hutt net déi néideg Rechter, fir d'Rechter vu Benoutzer op anere Wikien z'änneren.",
 'userrights-nodatabase'       => "D'Datebank $1 gëtt et net oder se ass net lokal.",
-'userrights-nologin'          => 'Dir musst mat engem Administrateurs-Benutzerkont [[Special:Userlogin|agelogged sinn]], fir Benotzerrechter änneren ze kënnen.',
+'userrights-nologin'          => 'Dir musst mat engem Administrateurs-Benutzerkont [[Special:UserLogin|agelogged sinn]], fir Benotzerrechter änneren ze kënnen.',
 'userrights-notallowed'       => "Dir hutt net déi néideg Rechter fir d'Rechter vun anere Benotzer z'änneren.",
 'userrights-changeable-col'   => 'Gruppen déi Dir ännere kënnt',
 'userrights-unchangeable-col' => 'Gruppen déi Dir net ännere kënnt',
@@ -1034,7 +1036,7 @@
 'right-autoconfirmed'        => 'Hallef-protegéiert Säiten änneren',
 'right-bot'                  => 'Als automatesche Prozess behandelen (Bot)',
 'right-nominornewtalk'       => 'Kleng Ännerungen op Diskussiounssäite léisen de Banner vun de neie Messagen net aus',
-'right-apihighlimits'        => 'Benotzt déi héich Limite an den API Ufroen',
+'right-apihighlimits'        => 'Benotzt méi héich Limite bei den API Ufroen',
 'right-writeapi'             => "API benotzen fir d'Wiki z'änneren",
 'right-delete'               => 'Säite läschen',
 'right-bigdelete'            => 'Säite mat engem groussen Historique läschen',
@@ -1077,7 +1079,7 @@
 'recentchanges-feed-description'    => 'Verfollegt mat dësem Feed déi rezent Ännerungen op {{SITENAME}}.',
 'rcnote'                            => "Hei {{PLURAL:$1|ass déi lescht Ännerung|sinn déi lescht '''$1''' Ännerungen}} {{PLURAL:$2|vum leschten Dag|vun de leschten '''$2''' Deeg}}, Stand: $4 ëm $5 Auer.",
 'rcnotefrom'                        => "Ugewise ginn d'Ännerunge vum '''$2''' un (maximal '''$1''' Ännerunge gi gewisen).",
-'rclistfrom'                        => 'Nëmmen Ännerungen zënter $1 weisen.',
+'rclistfrom'                        => 'Weis Ännerunge vun $1 un',
 'rcshowhideminor'                   => 'Kleng Ännerunge $1',
 'rcshowhidebots'                    => 'Botte $1',
 'rcshowhideliu'                     => 'Ugemellte Benotzer $1',
@@ -1102,8 +1104,8 @@
 'recentchangeslinked'          => 'Ännerungen op verlinkte Säiten',
 'recentchangeslinked-title'    => 'Ännerungen a Verbindung matt "$1"',
 'recentchangeslinked-noresult' => 'Am ausgewielten Zäitraum goufen op de verlinkte Säite keng Ännerunge gemaach.',
-'recentchangeslinked-summary'  => "Dëst ass eng Lëscht matt Ännerungen vu verlinkte Säiten op eng Bestëmmte Säit (oder vu Membersäite vun der spetifiéierter Kategorie).
-Säiten  vun [[Special:Watchlist|ärer Iwwerwaachungslëscht]] si '''fett''' geschriwwen.",
+'recentchangeslinked-summary'  => "Dëst ass eng Lëscht matt Ännerunge vu verlinkte Säiten op eng bestëmmte Säit (oder vu Membersäite vun der spetifizéierter Kategorie).
+Säite vun [[Special:Watchlist|ärer Iwwerwaachungslëscht]] si '''fett''' geschriwwen.",
 'recentchangeslinked-page'     => 'Säitennumm:',
 'recentchangeslinked-to'       => 'Weis Ännerungen zu de verlinkte Säiten aplaz vun der gefroter Säit',
 
@@ -1113,33 +1115,24 @@
 'reupload'                    => 'Nacheemol eroplueden',
 'reuploaddesc'                => 'Eroplueden ofbriechen an zréck op de Formulaire fir Eropzelueden',
 'uploadnologin'               => 'Net ageloggt',
-'uploadnologintext'           => 'Dir musst [[Special:Userlogin|agelogged sinn]], fir Fichieren eroplueden zu kënnen.',
+'uploadnologintext'           => 'Dir musst [[Special:UserLogin|agelogged sinn]], fir Fichieren eroplueden zu kënnen.',
 'upload_directory_missing'    => 'De Repertoire an deen Dir eropluede wollt ($1) feelt a konnt net vum Webserver ugeluecht ginn.',
 'upload_directory_read_only'  => 'De Webserver kann net an den Upload-Repertoire ($1) schreiwen.',
 'uploaderror'                 => 'Feeler bäim Eroplueden',
-'uploadtext'                  => "Gitt op d'[[Special:Imagelist|Lëscht vun den eropgeluedene Fichieren]], fir no Fichieren ze sichen.
+'uploadtext'                  => "Benotzt dëse Formulair, fir nei Fichieren eropzelueden.
+Gitt op d'[[Special:ImageList|Lëscht vun den eropgeluedene Fichieren]], fir no Fichieren ze sichen déi virdrun eropgeluede goufen, Eropgeluedungen fannt dir an der [[Special:Log/upload|Lëscht vun den eropgeluedene Fichieren]], geläschte Fichieren am [[Special:Log/delete|Läschlog]].
 
-Benotzt dëse Formulair, fir nei Fichieren eropzelueden. Klickt op '''Duerchsichen ...''', fir eng Fënster opzemaachen wou Dir de Ficher eraussiche kënnt.
-
-Nodeem Dir e Fichier erausgesicht hutt gëtt de Numm vun dësem am Textfeld '''Quell-Fichier''' ugewisen.
-Confirméiert dann d'Lizenz a klickt duerno op '''Fichier eroplueden'''.
-Dat kann eng Zäit daueren, besonnesch bäi enger lueser Internet-Verbindung.
-
-Fir e '''Bild''' op enger Säit zu benotzen, schreiwt aplaz vum Bild zum Beispiel:
-* '''<tt><nowiki>[[</nowiki>{{ns:image}}:Fichier.jpg<nowiki>]]</nowiki></tt>'''
-* '''<tt><nowiki>[[</nowiki>{{ns:image}}:Fichier.jpg|Link-Text<nowiki>]]</nowiki></tt>'''
-
-Fir '''Fichieren mat anere Medien ''' anzebannen, benotzt zum Beispiel:
-* '''<tt><nowiki>[[</nowiki>{{ns:media}}:Fichier.ogg<nowiki>]]</nowiki></tt>'''
-* '''<tt><nowiki>[[</nowiki>{{ns:media}}:Fichier.ogg|Link-Text<nowiki>]]</nowiki></tt>'''
-
-Dir sollt onbedingt bedenken, datt, genee wéi bäi normale Säiten, aner Benotzer är Fichiere läschen oder verännere kënnen.",
+Fir e '''Bild''' op enger Säit zu benotzen, schreiwt aplaz vum Bild eng vun dëse Formelen:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fichier.jpg]]</nowiki></tt>''' fir déi ganz Versioun vum Fichier ze benotzen
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fichier.png|200px|thumb|left|alt text]]</nowiki></tt>''' fir eng 200 Pixel breed Versioun an enger Këscht am lenke Rand mat 'alt text' als Beschreiwung
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Fichier.ogg]]</nowiki></tt>''' fir e Fichier direk ze verlinken ouni de Fichier ze weisen",
 'upload-permitted'            => 'Erlaabte Formater vun de Fichieren: $1.',
 'upload-preferred'            => 'Fichierszorten déi am beschte funktionéieren: $1.',
 'upload-prohibited'           => 'Verbuede Fichiers Formater: $1.',
 'uploadlog'                   => 'Lëscht vun den eropgeluedene Fichieren',
 'uploadlogpage'               => 'Logbuch vum Eroplueden',
-'uploadlogpagetext'           => 'Dëst ass dLëscht vun de Fichieren déi eropgeluede goufen.',
+'uploadlogpagetext'           => "Dëst ass d'Lëscht vun de rezente Fichieren déi eropgeluede goufen.
+Kuckt [[Special:NewImages|d'Gallerie vun de neie Fichieren]] wann Dir méi e visuellen Iwwerbléck wëllt",
 'filename'                    => 'Numm vum Fichier',
 'filedesc'                    => 'Resumé',
 'fileuploadsummary'           => 'Resumé/Quell:',
@@ -1165,6 +1158,9 @@
 
 Dir kënnt also äre Fichier eroplueden, mee déi Beschreiwung déi dir aginn hutt gëtt net op d'Beschreiwungssäit iwwerholl. D'Beschreiwungssäit musst der nom Eropluede vum Fichier nach manuell änneren.",
 'fileexists-thumb'            => "<center>'''Dëse Fichier gëtt et'''</center>",
+'file-thumbnail-no'           => 'Den Numm vum Fichier fänkt mat <strong><tt>$1</tt></strong> unn.
+Da däit drop hin dat et e Bild vu reduzéierter Gréisst <i>(thumbnail)</i> ass.
+Kuckt w.e.g. no ob Dir dat Bild net a méi enger grousser Opléisung hutt a lued dëst dann ënnert sengem Orginialnumm erop.',
 'fileexists-forbidden'        => "Et gëtt schonn e Fichier mat ësem Nummm. Gitt w.e.g. z'réck a lued dëse Fichier ënntert engem aner Numm erop. [[Image:$1|thumb|center|$1]]",
 'fileexists-shared-forbidden' => 'E Fichier mat dësem Numm gëtt et schonn;
 gitt w.e.g. zréck a lued dëse Fichier ënner engem anere Numm erop. [[Image:$1|thumb|center|$1]]',
@@ -1193,9 +1189,12 @@
 'upload-proto-error'      => 'Falsche Protokoll',
 'upload-proto-error-text' => "D'URL muss matt <code>http://</code> oder <code>ftp://</code> ufänken.",
 'upload-file-error'       => 'Interne Feeler',
-'upload-file-error-text'  => 'Beim Erstelle vun engem temporäre Fichier um Server ass een interne Feeler geschitt. Informéiert w.e.g. e vun de System-Administrateuren.',
+'upload-file-error-text'  => 'Beim Erstelle vun engem temporäre Fichier um Server ass een interne Feeler geschitt.
+Informéiert w.e.g. e vun den [[Special:ListUsers/sysop|Administrateuren]].',
 'upload-misc-error'       => 'Onbekannte Feeler beim Eroplueden',
-'upload-misc-error-text'  => "Beim Eroplueden ass en onbekannte Feeler geschitt. Kuckt d'URL w.e.g. no, a vergewëssert iech datt d'Säit online ass a probéiert et dann nach eng Kéier. Wann de Problem weider besteet, dann un de System-Administrateuren.",
+'upload-misc-error-text'  => "Beim Eroplueden ass en onbekannte Feeler geschitt.
+Kuckt d'URL w.e.g. no, a vergewëssert iech datt d'Säit online ass a probéiert et dann nach eng Kéier.
+Wann de Problem weider besteet, dann un de [[Special:ListUsers/sysop|Administrateuren]].",
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => "URL ass net z'erreechen",
@@ -1210,7 +1209,7 @@
 'upload_source_url'  => ' (gülteg, ëffentlech zougänglech URL)',
 'upload_source_file' => ' (e Fichier op Ärem Computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Op dëser Spezialsäit stinn all déi eropgeluede Fichieren. Déi als läscht eropgeluede Fichieren ginn als éischt ugewisen. Duerch e Klick op d'Iwwerschrëfte vun de Kolonnen kënnt Dir d'Sortéierung ëmdréinen an Dir kënnt esou och no enger anerer Kolonn sortéieren.",
 'imagelist_search_for'  => 'Sicht nom Fichier:',
 'imgfile'               => 'Fichier',
@@ -1230,13 +1229,13 @@
 'filehist-current'               => 'aktuell',
 'filehist-datetime'              => 'Versioun vum',
 'filehist-user'                  => 'Benotzer',
-'filehist-dimensions'            => 'Dimesiounen',
+'filehist-dimensions'            => 'Dimensiounen',
 'filehist-filesize'              => 'Gréisst vum Fichier',
 'filehist-comment'               => 'Bemierkung',
 'imagelinks'                     => 'Biller Linken',
 'linkstoimage'                   => 'Dës {{PLURAL:$1|Säit benotzt|Säite benotzen}} dëse Fichier:',
 'nolinkstoimage'                 => 'Keng Säit benotzt dëse Fichier.',
-'morelinkstoimage'               => 'Weis [[Special:Whatlinkshere/$1|méi Linken]] op dëse Fichier.',
+'morelinkstoimage'               => 'Weis [[Special:WhatLinksHere/$1|méi Linken]] op dëse Fichier.',
 'redirectstofile'                => '{{PLURAL:$1|De Fichier leed|Dës Fichiere leede}} virun op de Fichier:',
 'duplicatesoffile'               => '{{PLURAL:$1|De Fichier ass een Doublon|Dës Fichiere sinn Doublonen}} vum Fichier:',
 'sharedupload'                   => 'Dës Fichier ass ee gemeinsam genotzten Upload a ka vun anere Projeten benotzt ginn.',
@@ -1255,18 +1254,18 @@
 # File reversion
 'filerevert'                => '"$1" zrécksetzen',
 'filerevert-legend'         => 'De Fichier zrécksetzen.',
-'filerevert-intro'          => '<span class="plainlinks">Du setz de Fichier \'\'\'[[Media:$1|$1]]\'\'\' op d\'[$4 Versioun vum $2, $3 Auer] zréck.</span>',
+'filerevert-intro'          => "Du setz de Fichier '''[[Media:$1|$1]]''' op d'[$4 Versioun vum $2, $3 Auer] zréck.",
 'filerevert-comment'        => 'Grond:',
 'filerevert-defaultcomment' => "zréckgesat op d'Versioun vum $1, $2 Auer",
 'filerevert-submit'         => 'Zrécksetzen',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' gouf op d\'[$4 Versioun vum $2, $3 Auer] zréckgesat.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' gouf op d'[$4 Versioun vum $2, $3 Auer] zréckgesat.",
 'filerevert-badversion'     => 'Et gët keng Versioun vun deem Fichier mat der Zäitinformatoun déi Dir uginn hutt.',
 
 # File deletion
 'filedelete'                  => 'Läsch "$1"',
 'filedelete-legend'           => 'Fichier läschen',
 'filedelete-intro'            => "Dir läscht de Fichier '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Dir läscht  d\'Versioun $4  vum $2, $3 Auer vum Fichier \'\'\'„[[Media:$1|$1]]“\'\'\'.</span>',
+'filedelete-intro-old'        => "Dir läscht  d'Versioun $4  vum $2, $3 Auer vum Fichier '''„[[Media:$1|$1]]“'''.",
 'filedelete-comment'          => 'Grond:',
 'filedelete-submit'           => 'Läschen',
 'filedelete-success'          => "'''$1''' gouf geläscht.",
@@ -1322,7 +1321,7 @@
 Doraus ergi sech '''\$5''' Ännerunge pro Säit an '''\$6''' Säitenoffroen pro Ännerung.
 
 Längt vun der [http://www.mediawiki.org/wiki/Manual:Job_queue „Job queue“]: '''\$7'''",
-'userstatstext'          => "'''$1''' [[Special:Listusers|Benotzer]] {{PLURAL:$1|ass|sinn}} ageschriwwen.  '''$2''' (oder '''$4%''') vun dëse {{PLURAL:$2|ass|sinn}} $5.",
+'userstatstext'          => "'''$1''' [[Special:ListUsers|Benotzer]] {{PLURAL:$1|ass|sinn}} ageschriwwen.  '''$2''' (oder '''$4%''') vun dëse {{PLURAL:$2|ass|sinn}} $5.",
 'statistics-mostpopular' => 'Am meeschte gekuckte Säiten',
 
 'disambiguations'      => 'Homonymie Säiten',
@@ -1331,12 +1330,14 @@
 Sie sollten am beschten op déi eigentlech gemengte Säit verlinkt sinn.<br />
 Eng Säite gëtt als Homonymiesäit behandelt, wa si eng Schabloun benotzt déi vu [[MediaWiki:Disambiguationspage]] verlinkt ass.',
 
-'doubleredirects'     => 'Duebel Viruleedungen',
-'doubleredirectstext' => '<b>Opgepasst:</b> An dëser Lëscht kënne falsch Positiver stoen. Dat heescht meeschtens datt et nach Text zu de Linke vun der éischter Viruleedung gëtt.<br /> 
+'doubleredirects'            => 'Duebel Viruleedungen',
+'doubleredirectstext'        => '<b>Opgepasst:</b> An dëser Lëscht kënne falsch Positiver stoen. Dat heescht meeschtens datt et nach Text zu de Linke vun der éischter Viruleedung gëtt.<br /> 
 An all Rei sti Linken zur éischter an zweeter Viruleedung, souwéi déi éischt Zeil vum Text vun der zweeter Viruleedung, wou normalerweis déi "richteg" Zilsäit drasteet, op déi déi éischt Viruleedung hilinke soll.',
+'double-redirect-fixed-move' => '[[$1]] gouf geréckelt, et ass elo en Viruleedung op [[$2]]',
+'double-redirect-fixer'      => 'Verbesserung vu Viruleedungen',
 
 'brokenredirects'        => 'Futtis Viruleedungen',
-'brokenredirectstext'    => 'Viruleedungen op Säiten déi et net gëtt',
+'brokenredirectstext'    => 'Viruleedungen op Säiten déi et net gëtt.',
 'brokenredirects-edit'   => '(änneren)',
 'brokenredirects-delete' => '(läschen)',
 
@@ -1414,12 +1415,12 @@
 'all-logs-page'        => "All d'Logbicher",
 'log-search-legend'    => 'Logbicher duerchsichen',
 'log-search-submit'    => 'Sichen',
-'alllogstext'          => "Dëst ass eng kombinéiert Lëscht vu Logbicher vu(n) {{SITENAME}}.
+'alllogstext'          => "Dëst ass eng kombinéiert Lëscht vu Logbicher op {{SITENAME}}.
 Dir kënnt d'Sich limitéieren wann dir e Log-Typ, e Benotzernumm oder déi gefrote Säit agitt.",
 'logempty'             => 'Näischt fonnt.',
 'log-title-wildcard'   => 'Titel fänkt u matt …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'All Säiten',
 'alphaindexline'    => '$1 bis $2',
 'nextpage'          => 'Nächst Säit ($1)',
@@ -1442,15 +1443,15 @@
 'special-categories-sort-count' => 'No der Zuel sortéieren',
 'special-categories-sort-abc'   => 'alphabetesch sortéieren',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "D'Benotzer uweisen, ugefaange bei:",
 'listusers-submit'   => 'Weis',
 'listusers-noresult' => 'Kee Benotzer fonnt.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rechter vun de Benotzergruppen',
 'listgrouprights-summary'  => 'Dëst ass eng Lëscht vun den op dëser Wiki definéierte Benotzergruppen an den domatt verbonnene Rechter.
-Zousätzlech Informatiounen iwwer individuell Benotzerrechter fannt Dir [[{{MediaWiki:Listgrouprights-helppage}}|hei]].',
+Et ginn [[{{MediaWiki:Listgrouprights-helppage}}|zousätzlech Informatiounen]] iwwer individuell Benotzerrechter.',
 'listgrouprights-group'    => 'Grupp',
 'listgrouprights-rights'   => 'Rechter',
 'listgrouprights-helppage' => 'Help:Grupperechter',
@@ -1458,10 +1459,10 @@
 
 # E-mail user
 'mailnologin'     => 'Keng E-Mailadress',
-'mailnologintext' => 'Dir musst [[Special:Userlogin|ugemellt]] sinn an eng gülteg E-Mail Adress an äre [[Special:Preferences|Asteelunge]] aginn hunn, fir engem anere Benotzer eng E-Mail ze schécken.',
+'mailnologintext' => 'Dir musst [[Special:UserLogin|ugemellt]] sinn an eng gülteg E-Mail Adress an äre [[Special:Preferences|Asteelunge]] aginn hunn, fir engem anere Benotzer eng E-Mail ze schécken.',
 'emailuser'       => 'Dësem Benotzer eng E-Mail schécken',
 'emailpage'       => 'Dem Benotzer eng E-Mail schécken',
-'emailpagetext'   => 'Wann dëse Benotzer eng valid E-Mail Adress a sengen Astellungen uginn huet, kënnt Dir mat dësem Formulaire e Message schécken. Déi E-Mailadress, déi dir an Ären Astellungen aginn hutt, steet an der "From" Adress vun der Mail, sou datt den Destinataire Iech och äntwerte kann.',
+'emailpagetext'   => 'Wann dëse Benotzer eng valid E-Mail Adress a sengen Astellungen uginn huet, kënnt Dir mat dësem Formulaire e Message schécken. Déi E-Mailadress, déi dir an [[Special:Preferences|Ären Astellungen]] aginn hutt, steet an der "From" Adress vun der Mail, sou datt den Destinataire Iech och äntwerte kann.',
 'usermailererror' => 'E-Mail-Objet mellt deen heite Feeler:',
 'defemailsubject' => 'E-Mail vu(n) {{SITENAME}}',
 'noemailtitle'    => 'Keng E-Mailadress',
@@ -1484,9 +1485,9 @@
 'nowatchlist'          => 'Är Iwwerwaachungslëscht ass eidel.',
 'watchlistanontext'    => "Dir musst $1 fir Säiten op ärer Iwwerwaachungslëscht ze gesinn oder z'änneren.",
 'watchnologin'         => 'Net ageloggt',
-'watchnologintext'     => "Dir musst [[Special:Userlogin|ugemellt]] sinn, fir Är Iwwerwaachungslëscht z'änneren.",
+'watchnologintext'     => "Dir musst [[Special:UserLogin|ugemellt]] sinn, fir Är Iwwerwaachungslëscht z'änneren.",
 'addedwatch'           => "Op d'Iwwerwaachungslëscht gesat",
-'addedwatchtext'       => "D'Säit \"<nowiki>\$1</nowiki>\" gouf bei an är [[Special:Watchlist|Iwwerwaachtungslëscht]] gesat. All weider Ännerungen op dëser Säit an/oder der Diskussiounssäit ginn hei opgelëscht, an d'Säit gesäit '''fettgedréckt''' bei de [[Special:Recentchanges|rezenten Ännerungen]] aus fir, se méi séier erëmzefannen.
+'addedwatchtext'       => "D'Säit \"<nowiki>\$1</nowiki>\" gouf bei an är [[Special:Watchlist|Iwwerwaachtungslëscht]] gesat. All weider Ännerungen op dëser Säit an/oder der Diskussiounssäit ginn hei opgelëscht, an d'Säit gesäit '''fettgedréckt''' bei de [[Special:RecentChanges|rezenten Ännerungen]] aus fir, se méi séier erëmzefannen.
 
 Wann dir dës Säit net iwwerwaache wëllt, klickt op \"Net méi iwwerwaachen\" uewen op der Säit.",
 'removedwatch'         => 'Vun der Iwwerwaachungslëscht erofgeholl',
@@ -1501,7 +1502,7 @@
 'watchlist-details'    => "Dir iwwerwaacht {{PLURAL:$1|1 Säit|$1 Säiten}} (d'Diskussiounssäite net matgezielt).",
 'wlheader-enotif'      => '* E-Mail-Bescheed ass aktivéiert.',
 'wlheader-showupdated' => "* Säiten déi zënter ärer leschter Visite geännert goufen, si '''fett''' geschriwwen",
-'watchmethod-recent'   => 'Rezent Ännerungen gin op iwwerwaacht Säiten iwwerpréift',
+'watchmethod-recent'   => 'Rezent Ännerunge ginn op iwwerwaacht Säiten iwwerpréift',
 'watchmethod-list'     => 'Verfollegt Säite ginn op rezent Ännerungen iwwerpréift',
 'watchlistcontains'    => 'Op ärer Iwwerwaachungslëscht $1 {{PLURAL:$1|steet $1 Säit|stinn $1 Säiten}}.',
 'iteminvalidname'      => "Problem mat dem Objet '$1', ongültege Numm ...",
@@ -1588,7 +1589,10 @@
 'rollbacklink'                => 'Zrécksetzen',
 'rollbackfailed'              => 'Zrécksetzen huet net geklappt',
 'cantrollback'                => 'Lescht Ännerung kann net zréckgesat ginn. De leschten Auteur ass deen eenzegen Auteur vun dëser Säit.',
-'alreadyrolled'               => 'Déi lescht Ännerung vun der Säit [[$1]] vum [[User:$2|$2]] ([[User talk:$2|Diskussioun]]) kann net zréckgesat ginn; een Aneren huet dëst entweder scho gemaach oder nei Ännerungen agedroen. Lescht Ännerung vum [[User:$3|$3]] ([[User talk:$3|Diskussioun]]).',
+'alreadyrolled'               => 'Déi lescht Ännerung vun der Säit [[$1]] vum [[User:$2|$2]] ([[User talk:$2|Diskussioun]] | [[Special:Contributions/$2|{{int:contribslink}}]]);) kann net zréckgesat ginn; 
+een Aneren huet dëst entweder scho gemaach oder nei Ännerungen agedroen.
+
+Déi lescht Ännerung vun der Säit ass vum [[User:$3|$3]] ([[User talk:$3|Diskussioun]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Ännerungskommentar: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Ännerunge vum [[Special:Contributions/$2|Kontributioune]] ([[User talk:$2|Diskussioun]]) zréckgesat op déi lescht Versioun vum [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => "D'Ännerunge vum $1 goufen zréckgesat op déi lescht Versioun vum $2.",
@@ -1597,7 +1601,7 @@
 KLickt w.e.g. op "Zréck" a lued déi Sàit vun däer Dir komm sidd nei, a versicht et dann nach eng Kéier.',
 'protectlogpage'              => 'Protectiouns-Logbuch',
 'protectlogtext'              => "Dëst ass d'Lëscht vun de Säitespären.
-Kuckt d'[[Special:Protectedpages|Lëscht vun de protegéierte Säite]] fir eng L!escht vun den aktuelle Säite-Protectiounen.",
+Kuckt d'[[Special:ProtectedPages|Lëscht vun de protegéierte Säite]] fir eng L!escht vun den aktuelle Säite-Protectiounen.",
 'protectedarticle'            => 'huet [[$1]] protegéiert',
 'modifiedarticleprotection'   => 'huet d\'Protectioun vun "[[$1]]" geännert',
 'unprotectedarticle'          => "huet d'Spär vu(n) [[$1]] opgehuewen",
@@ -1644,7 +1648,12 @@
 'viewdeletedpage'              => 'Geläschte Säite weisen',
 'undeletepagetext'             => "Dës Säite goufe geläscht mee sinn nach ëmmer am Archiv a kënne vun Administrateure restauréiert ginn. D'Archiv gëtt periodesch eidel gemaach.",
 'undelete-fieldset-title'      => 'Versioune restauréieren',
+'undeleteextrahelp'            => "* Fir d'Säit komplett mat alle Versiounen ze retabléieren, markéiert keng vun den eenzelne Casë mat engem Krop, klickt op '''''Restauréieren'''''. 
+* Fir nëmmen eng bestëmmte Versioun vun der Säit ze retabléieren, markéiert d'Case vun der gewënschter Versioun mat engem Krop, a klickt duerno op '''''Restauréiere'''''. 
+* '''''Reset''''' mécht d'Kommentarfeld eidel an hëlt d'Kreep vun all de Casen ewech.",
 'undeleterevisions'            => '{{PLURAL:$1|1 Versioun|$1 Versiounen}} archivéiert',
+'undeletehistory'              => "Wann Dir dës Säit restauréiert, ginn och all déi al Versioune restauréiert. Wann zënter dem Läschen eng nei Säit mat dem selweschte Numm ugeluecht gouf, ginn déi restauréiert Versioune chronologesch an den Historique agedro.
+D'Astellunge - wien eng Versioun ka gesinn - gi beim Restauréiere verluer.",
 'undeletehistorynoadmin'       => "Dës Säit gouf geläscht. De Grond fir d'Läsche gesitt der ënnen, zesumme mat der Iwwersiicht vun den eenzele Versioune vun der Säit an hiren Auteuren. Déi verschidden Textversioune kënnen awer just vun Administrateure gekuckt a restauréiert ginn.",
 'undelete-revision'            => 'Geläschte Versioun vun $1 (Versioun  vum $2) vum $3:',
 'undeleterevision-missing'     => "Ongëlteg oder Versioun déi feelt. Entweder ass de Link falsch oder d'Versioun gouf aus dem Archiv restauréiert oder geläscht.",
@@ -1698,7 +1707,7 @@
 
 # What links here
 'whatlinkshere'            => 'Linken op dës Säit',
-'whatlinkshere-title'      => 'Säiten, déi mat „$1“ verlinkt sinn',
+'whatlinkshere-title'      => 'Säiten, déi mat "$1" verlinkt sinn',
 'whatlinkshere-page'       => 'Säit:',
 'linklistsub'              => '(Lëscht vun de Linken)',
 'linkshere'                => "Déi folgend Säite linken op '''[[:$1]]''':",
@@ -1748,7 +1757,7 @@
 'blockipsuccesssub'           => 'Gouf gespaart',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] gouf gespaart. <br />
 
-Kuckt d'[[Special:Ipblocklist|IP Spär-Lëscht]] fir all Spären ze gesin.",
+Kuckt d'[[Special:IPBlockList|IP Spär-Lëscht]] fir all Spären ze gesin.",
 'ipb-edit-dropdown'           => 'Spärgrënn änneren',
 'ipb-unblock-addr'            => 'Spär vum $1 annuléieren',
 'ipb-unblock'                 => 'Spär vun enger IP-Adress oder engem Benotzer annuléieren',
@@ -1759,7 +1768,7 @@
 'ipusubmit'                   => "D'Spär vun dëser Adress ophiewen",
 'unblocked'                   => "D'Spär fir de(n) [[User:$1|$1]] gouf annulléiert",
 'unblocked-id'                => "D'Spär $1 gouf annulléiert",
-'ipblocklist'                 => 'Lëscht vu gespaarte Benotzer an IP-Adressen',
+'ipblocklist'                 => 'Lëscht vu gespaarten IP-Adressen a Benotzernimm',
 'ipblocklist-legend'          => 'No engem gespaarte Benotzer sichen',
 'ipblocklist-username'        => 'Benotzernumm oder IP-Adress:',
 'ipblocklist-submit'          => 'Sichen',
@@ -1778,7 +1787,7 @@
 'autoblocker'                 => 'Dir sidd automatesch gespaart well dir eng IP Adress mam "$1" deelt. Grond "$2".',
 'blocklogpage'                => 'Spärlëscht',
 'blocklogentry'               => '"[[$1]]" gespaart, gülteg bis $2 $3',
-'blocklogtext'                => "Dëst ass eng Lëscht vu Spären an den Annulatioune vun de Spären. Automatesch gespaarten IP Adresse sinn hei net opgelëscht. Kuckt d'[[Special:Ipblocklist|IP Spärlëschtt]] fir déi aktuell Spären.",
+'blocklogtext'                => "Dëst ass eng Lëscht vu Spären an den Annulatioune vun de Spären. Automatesch gespaarten IP Adresse sinn hei net opgelëscht. Kuckt d'[[Special:IPBlockList|IP Spärlëschtt]] fir déi aktuell Spären.",
 'unblocklogentry'             => "huet d'Spär vum [[$1]] annulléiert",
 'block-log-flags-anononly'    => 'Nëmmen anonym Benotzer',
 'block-log-flags-nocreate'    => 'Schafe vu Benotzerkonte gespaart',
@@ -1816,18 +1825,18 @@
 'lockdbsuccesssub'    => "D'Datebank ass elo gespaart",
 'unlockdbsuccesssub'  => "D'Spär vun der Datebank gouf opgehuewen",
 'lockdbsuccesstext'   => "D'{{SITENAME}}-Datebank gouf gespaart. <br />
-Denkt drun [[Special:Unlockdb|d'Spär erëm ewechzehuele]] soubaal d'Maintenance-Aarbechte fäerdeg sinn.",
+Denkt drun [[Special:UnlockDB|d'Spär erëm ewechzehuele]] soubaal d'Maintenance-Aarbechte fäerdeg sinn.",
 'unlockdbsuccesstext' => "D'Spär vun der Datebank ass opgehuewen.",
 'databasenotlocked'   => "D'Datebank ass net gespaart.",
 
 # Move page
 'move-page'               => 'Réckel $1',
 'move-page-legend'        => 'Säit réckelen',
-'movepagetext'            => "Wann der dëse Formulaire benotzt, réckelt dir eng komplett Säit mat hirem Historique op en neien Numm.
+'movepagetext'            => "Wann dir dëse Formulaire benotzt, réckelt dir eng komplett Säit mat hirem Historique op en neien Numm.
 Den alen Titel déngt als Viruleedung op déi nei Säit.
-Linken op déi al Säit ginn net ëmgeännert;
-Passt op datt keng duebel oder feelerhaft Viruleedungen am Spill sinn.
-Dir sidd responsabel datt d'Linke weiderhinn dohinner pointéieren, wou se hisollen.
+Dir kënnt Viruleedungen op déi al Säit ginn automatesch aktualiséieren.
+Wann Dir dat net maacht, da vergewëssert iech datt keng [[Special:DoubleRedirects|duebel]] oder [[Special:BrokenRedirects|futtis Viruleedungen]] am Spill sinn.
+Dir sidd responsabel datt d'Linke weiderhinn dohinner pointéieren, wou se hi sollen.
 
 Beuecht w.e.g. datt d'Säit '''net''' geréckelt gëtt, wann ët schonns eng Säit mat deem Titel gëtt, ausser dës ass eidel, ass eng Viruleedung oder huet keen Historique.
 Dëst bedeit datt dir eng Säit ëmbenenne kënnt an datt dir keng Säit iwwerschreiwe kënnt, déi et schonns gëtt.
@@ -1842,8 +1851,6 @@
 
 An deene Fäll musst Dir d'Diskussiounssäit manuell réckelen oder fusionéieren.",
 'movearticle'             => 'Säit réckelen:',
-'movenologin'             => 'Net ageloggt',
-'movenologintext'         => 'Dir musst e registréierte Benotzer an [[Special:Userlogin|ageloggt]] sinn, fir eng Säit ze réckelen.',
 'movenotallowed'          => 'Dir hutt net déi néideg Rechter fir Säiten op {{SITENAME}} ze réckelen.',
 'newtitle'                => 'Op den neien Titel:',
 'move-watch'              => 'Dës Säit iwwerwaachen',
@@ -1862,19 +1869,20 @@
 'movepage-page-unmoved'   => "D'Säit $1 konnt nett op $2 geréckelt ginn.",
 'movepage-max-pages'      => 'Déi Maximalzuel vun $1 {{PLURAL:$1|Säit gouf|Säite goufe}} gouf geréckelt. All déi aner Säite kënnen net automatesch geréckelt ginn.',
 '1movedto2'               => '[[$1]] gouf op [[$2]] geréckelt',
-'1movedto2_redir'         => '[[$1]] gouf op [[$2]] geréckelt, dobäi gouf eng Weiderleedung iwwerschriwwen.',
+'1movedto2_redir'         => '[[$1]] gouf op [[$2]] geréckelt, dobäi gouf eng Viruleedung iwwerschriwwen.',
 'movelogpage'             => 'Réckellëscht',
 'movelogpagetext'         => 'Dëst ass eng Lëscht vun alle geréckelte Säiten.',
 'movereason'              => 'Grond:',
 'revertmove'              => 'zréck réckelen',
 'delete_and_move'         => 'Läschen a réckelen',
-'delete_and_move_text'    => '== Läsche vun der Destinatiounssäit néideg == D\'Säit "[[$1]]" existéiert schonn. Wëll der se läsche fir d\'Réckelen ze erméiglechen?',
+'delete_and_move_text'    => '== Läsche vun der Destinatiounssäit néideg == D\'Säit "[[:$1]]" existéiert schonn. Wëll der se läsche fir d\'Réckelen ze erméiglechen?',
 'delete_and_move_confirm' => "Jo, läsch d'Destinatiounssäit",
 'delete_and_move_reason'  => 'Geläscht fir Plaz ze maache fir eng Säit heihin ze réckelen',
 'selfmove'                => 'Source- an Destinatiounsnumm sinn dselwecht; eng Säit kann net op sech selwer geréckelt ginn.',
 'imagenocrossnamespace'   => 'Fichiere kënnen net an aner Nummraim geréckelt ginn',
 'imagetypemismatch'       => 'Déi nei Dateierweiderung ass net mat dem Fichier kompatibel',
 'imageinvalidfilename'    => 'Den Numm vum Zil-Fichier ass ongëlteg',
+'fix-double-redirects'    => 'All Viruleedungen déi op den Originaltitel weisen aktualiséieren',
 
 # Export
 'export'            => 'Säiten exportéieren',
@@ -1917,7 +1925,8 @@
 'import-interwiki-history'   => "Importéier all d'Versioune vun dëser Säit",
 'import-interwiki-submit'    => 'Import',
 'import-interwiki-namespace' => 'Kopéier Säiten an den Nummraum:',
-'importtext'                 => 'Exportéiert de Fichier w.e.g vun der Source-Wiki mat der Funktioun Spezial:Export, späichert en op ärem Disk of a lued en hei nees erop.',
+'importtext'                 => 'Exportéiert de Fichier w.e.g vun der Source-Wiki mat der [[Special:Export|Funktioun Export]].
+Späichert en op ärem Computer of a lued en hei nees erop.',
 'importstart'                => 'Importéier Säiten …',
 'import-revision-count'      => '$1 {{PLURAL:$1|Versioun|Versiounen}}',
 'importnopages'              => "Et gëtt keng Säiten fir z'importéieren.",
@@ -1931,6 +1940,8 @@
 'importnosources'            => 'Fir den Transwiki-Import si keng Quellen definéiert an et ass net méiglech fir Säite mat alle Versiounen aus dem Transwiki-Tëschespäicher eropzelueden.',
 'importnofile'               => 'Et gouf keen importéierte Fichier eropgelueden',
 'importuploaderrorsize'      => 'DEropluede vum importéierte Fichier huet net fonctionnéiert. De Fichier ass méi grouss wéi maximal erlaabt.',
+'importuploaderrorpartial'   => "D'Eropluede vum Fichier huet net geklappt. De Fichier gouf nëmmen deelweis eropgelueden.",
+'importuploaderrortemp'      => "D'Eropluede vum Fichier huet net fonctionnéiert. En temporäre Repertoire feelt.",
 'import-parse-failure'       => 'Feeler bei engem XML-Import',
 'import-noarticle'           => "Keng Säit fir z'importéieren!",
 'import-nonewrevisions'      => "All d'Versioune goufe scho virdrunn importéiert.",
@@ -1947,7 +1958,7 @@
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Meng Benotzersäit',
-'tooltip-pt-anonuserpage'         => 'Benotzersäit vun der IP-Adress vun däer aus Dir den Ament Ännerungen maachtt',
+'tooltip-pt-anonuserpage'         => 'Benotzersäit vun der IP-Adress vun där aus Dir den Ament Ännerunge maachtt',
 'tooltip-pt-mytalk'               => 'Meng Diskussioun',
 'tooltip-pt-anontalk'             => "Diskussioun iwwer d'Ännerungen déi vun dëser IP-Adress aus gemaach gi sinn",
 'tooltip-pt-preferences'          => 'Meng Astellungen',
@@ -2081,7 +2092,7 @@
 'show-big-image'       => 'Versioun an enger méi héijer Opléisung',
 'show-big-image-thumb' => '<small>Gréisst vun dem Thumbnail: $1 × $2 Pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Gallerie vun de neie Biller',
 'imagelisttext'         => "Hei ass eng Lëscht vun '''$1''' {{PLURAL:$1|Fichier|Fichieren}}, zortéiert $2.",
 'newimages-summary'     => 'Dës Spezialsäit weist eng Lëscht mat de Biller a Fichieren déi als läscht eropgeluede goufen.',
@@ -2278,6 +2289,8 @@
 'exif-whitebalance-1' => 'Manuelle Wäissofgläich',
 
 'exif-scenecapturetype-0' => 'Standard',
+'exif-scenecapturetype-1' => 'Landschaft',
+'exif-scenecapturetype-2' => 'Portrait',
 'exif-scenecapturetype-3' => 'Nuetszeen',
 
 'exif-gaincontrol-0' => 'Keng',
@@ -2322,7 +2335,7 @@
 
 # External editor support
 'edit-externally'      => 'Dëse Fichier mat engem externe Programm veränneren',
-'edit-externally-help' => "<small>Fir gewuer ze gi wéi dat genee geet liest d'[http://meta.wikimedia.org/wiki/Help:External_editors Installatiounsinstruktiounen].</small>",
+'edit-externally-help' => "<small>Fir gewuer ze gi wéi dat genee geet liest d'[http://www.mediawiki.org/wiki/Manual:External_editors Installatiounsinstruktiounen].</small>",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'all',
@@ -2377,7 +2390,7 @@
 'recreate'            => 'Erëm uleeën',
 
 # HTML dump
-'redirectingto' => 'Virugeleed op [[$1]]',
+'redirectingto' => 'Virugeleed op [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Dës Säit aus dem Server-Cache läschen?
@@ -2423,8 +2436,8 @@
 Benotzt w.e.g. de normale Preview (Kucken ouni ofzespäicheren).',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Ännerunge vun de leschte(n) $1 Sekonnen kënne an dëser Lëscht net gewise ginn.',
-'lag-warn-high'   => 'Duerch eng héich Serverbelaaschtung kënne Verännerungen déi viru manner wéi $1 Sekonne gemaach goufen, net an dëser Lëscht ugewise ginn.',
+'lag-warn-normal' => 'Ännerunge vun {{PLURAL:$1|der leschter Sekonn|de leschte(n) $1 Sekonnen}} kënne an dëser Lëscht net gewise ginn.',
+'lag-warn-high'   => 'Duerch eng héich Serverbelaaschtung kënne Verännerungen déi viru manner wéi $1 {{PLURAL:$1|Sekonn|Sekonne}} gemaach goufen, net an dëser Lëscht ugewise ginn.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => "Op Ärer Iwwerwaachungslëscht {{PLURAL:$1|steet 1 Säit|stinn $1 Säiten}}, ouni d'Diskussiounssäiten.",
@@ -2474,7 +2487,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Versioun',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Pad bäi de Fichier',
 'filepath-page'    => 'Fichier:',
 'filepath-submit'  => 'Pad',
@@ -2512,7 +2525,7 @@
 'specialpages-group-redirects'   => 'Spezialsäiten déi viruleeden',
 'specialpages-group-spam'        => 'Handwierksgeschir géint de Spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Eidel Säit',
 'intentionallyblankpage' => 'Dës Säit ass absichtlech eidel. Si gëtt fir Benchmarking an Ähnleches benotzt.',
 
Index: languages/messages/MessagesPa.php
===================================================================
--- languages/messages/MessagesPa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author AS Alam
+ * @author Gman124
  * @author Sukh
  * @author Ævar Arnfjörð Bjarmason
- * @author AS Alam
+ * @author לערי ריינהארט
  *
  * @license http://www.gnu.org/copyleft/fdl.html GNU Free Documentation License
  * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
@@ -59,14 +61,15 @@
 
 $messages = array(
 # User preference toggles
-'tog-underline'        => 'ਅੰਡਰ-ਲਾਈਨ ਲਿੰਕ:',
-'tog-numberheadings'   => 'ਆਟੋ-ਨੰਬਰ ਹੈਡਿੰਗ',
-'tog-showtoolbar'      => 'ਐਡਿਟ ਟੂਲਬਾਰ ਵੇਖੋ (JavaScript)',
-'tog-showtoc'          => 'ਟੇਬਲ ਆਫ਼ ਕੰਨਟੈੱਟ ਵੇਖਾਓ (for pages with more than 3 headings)',
-'tog-rememberpassword' => 'ਇਹ ਕੰਪਿਊਟਰ ਲਈ ਮੇਰਾ ਲਾਗਇਨ ਯਾਦ ਰੱਖੋ',
-'tog-editwidth'        => 'ਐਡਿਟ ਬਾਕਸ ਦੀ ਪੂਰੀ ਚੌੜਾਈ',
-'tog-previewontop'     => 'ਐਡਿਟ ਬਕਸੇ ਤੋਂ ਪਹਿਲਾਂ ਝਲਕ ਵੇਖਾਓ',
-'tog-previewonfirst'   => 'ਪਹਿਲੇ ਐਡਿਟ ਉੱਤੇ ਝਲਕ ਵੇਖਾਓ',
+'tog-underline'          => 'ਅੰਡਰ-ਲਾਈਨ ਲਿੰਕ:',
+'tog-numberheadings'     => 'ਆਟੋ-ਨੰਬਰ ਹੈਡਿੰਗ',
+'tog-showtoolbar'        => 'ਐਡਿਟ ਟੂਲਬਾਰ ਵੇਖੋ (JavaScript)',
+'tog-showtoc'            => 'ਟੇਬਲ ਆਫ਼ ਕੰਨਟੈੱਟ ਵੇਖਾਓ (for pages with more than 3 headings)',
+'tog-rememberpassword'   => 'ਇਹ ਕੰਪਿਊਟਰ ਲਈ ਮੇਰਾ ਲਾਗਇਨ ਯਾਦ ਰੱਖੋ',
+'tog-editwidth'          => 'ਐਡਿਟ ਬਾਕਸ ਪੇਜ ਦੀ ਪੂਰੀ ਚੌੜਾਈ ਵਿੱਚ ਕਰੋ',
+'tog-previewontop'       => 'ਐਡਿਟ ਬਕਸੇ ਤੋਂ ਪਹਿਲਾਂ ਝਲਕ ਵੇਖਾਓ',
+'tog-previewonfirst'     => 'ਪਹਿਲੇ ਐਡਿਟ ਉੱਤੇ ਝਲਕ ਵੇਖਾਓ',
+'tog-watchlisthideminor' => 'ਛੋਟੇ ਸੋਧ ਵਾਚ-ਲਿਸਟ ਤੋਂ ਓਹਲੇ ਰੱਖੋ',
 
 'underline-always'  => 'ਹਮੇਸ਼ਾਂ',
 'underline-never'   => 'ਕਦੇ ਨਹੀਂ',
@@ -90,9 +93,9 @@
 'fri'           => 'ਸ਼ੁੱਕਰ',
 'sat'           => 'ਸ਼ਨਿੱਚਰ',
 'january'       => 'ਜਨਵਰੀ',
-'february'      => 'ਫਰਵਰੀ',
+'february'      => 'ਫ਼ਰਵਰੀ',
 'march'         => 'ਮਾਰਚ',
-'april'         => 'ਅਪਰੈਲ',
+'april'         => 'ਅਪ੍ਰੈਲ',
 'may_long'      => 'ਮਈ',
 'june'          => 'ਜੂਨ',
 'july'          => 'ਜੁਲਾਈ',
@@ -100,11 +103,11 @@
 'september'     => 'ਸਤੰਬਰ',
 'october'       => 'ਅਕਤੂਬਰ',
 'november'      => 'ਨਵੰਬਰ',
-'december'      => 'ਦਸੰਬਰ',
+'december'      => 'ਦਿਸੰਬਰ',
 'january-gen'   => 'ਜਨਵਰੀ',
-'february-gen'  => 'ਫਰਵਰੀ',
+'february-gen'  => 'ਫ਼ਰਵਰੀ',
 'march-gen'     => 'ਮਾਰਚ',
-'april-gen'     => 'ਅਪਰੈਲ',
+'april-gen'     => 'ਅਪ੍ਰੈਲ',
 'may-gen'       => 'ਮਈ',
 'june-gen'      => 'ਜੂਨ',
 'july-gen'      => 'ਜੁਲਾਈ',
@@ -112,11 +115,11 @@
 'september-gen' => 'ਸਤੰਬਰ',
 'october-gen'   => 'ਅਕਤੂਬਰ',
 'november-gen'  => 'ਨਵੰਬਰ',
-'december-gen'  => 'ਦਸੰਬਰ',
+'december-gen'  => 'ਦਿਸੰਬਰ',
 'jan'           => 'ਜਨਵਰੀ',
-'feb'           => 'ਫਰਵਰੀ',
+'feb'           => 'ਫ਼ਰਵਰੀ',
 'mar'           => 'ਮਾਰਚ',
-'apr'           => 'ਅਪਰੈਲ',
+'apr'           => 'ਅਪ੍ਰੈਲ',
 'may'           => 'ਮਈ',
 'jun'           => 'ਜੂਨ',
 'jul'           => 'ਜੁਲਾਈ',
@@ -124,7 +127,7 @@
 'sep'           => 'ਸਤੰਬਰ',
 'oct'           => 'ਅਕਤੂਬਰ',
 'nov'           => 'ਨਵੰਬਰ',
-'dec'           => 'ਦਸੰਬਰ',
+'dec'           => 'ਦਿਸੰਬਰ',
 
 # Categories related messages
 'pagecategories'        => '{{PLURAL:$1|ਕੈਟਾਗਰੀ|ਕੈਟਾਗਰੀਆਂ}}',
@@ -136,18 +139,18 @@
 'mainpagetext' => "<big>'''ਮੀਡਿਆਵਿਕਿ ਠੀਕ ਤਰ੍ਹਾਂ ਇੰਸਟਾਲ ਹੋ ਗਿਆ ਹੈ।'''</big>",
 
 'about'          => 'ਇਸ ਬਾਰੇ',
-'article'        => 'ਸਮੱਗਰੀ ਪੇਜ਼',
+'article'        => 'ਸਮੱਗਰੀ ਪੇਜ',
 'newwindow'      => '(ਨਵੀਂ ਵਿੰਡੋ ਵਿੱਚ ਖੋਲ੍ਹੋ)',
 'cancel'         => 'ਰੱਦ ਕਰੋ',
 'qbfind'         => 'ਖੋਜ',
 'qbbrowse'       => 'ਬਰਾਊਜ਼',
 'qbedit'         => 'ਸੋਧ',
-'qbpageoptions'  => 'ਇਹ ਪੇਜ਼',
+'qbpageoptions'  => 'ਇਹ ਪੇਜ',
 'qbpageinfo'     => 'ਭਾਗ',
-'qbmyoptions'    => 'ਮੇਰੇ ਪੇਜ਼',
-'qbspecialpages' => 'ਖਾਸ ਪੇਜ਼',
+'qbmyoptions'    => 'ਮੇਰੇ ਪੇਜ',
+'qbspecialpages' => 'ਖਾਸ ਪੇਜ',
 'moredotdotdot'  => 'ਹੋਰ...',
-'mypage'         => 'ਮੇਰਾ ਪੇਜ਼',
+'mypage'         => 'ਮੇਰਾ ਪੇਜ',
 'mytalk'         => 'ਮੇਰੀ ਗੱਲਬਾਤ',
 'anontalk'       => 'ਇਹ IP ਲਈ ਗੱਲਬਾਤ',
 'navigation'     => 'ਨੇਵੀਗੇਸ਼ਨ',
@@ -161,7 +164,7 @@
 'searchbutton'      => 'ਖੋਜ',
 'go'                => 'ਜਾਓ',
 'searcharticle'     => 'ਜਾਓ',
-'history'           => 'ਪੇਜ਼ ਅਤੀਤ',
+'history'           => 'ਪੇਜ ਅਤੀਤ',
 'history_short'     => 'ਅਤੀਤ',
 'updatedmarker'     => 'ਮੇਰੇ ਆਖਰੀ ਖੋਲ੍ਹਣ ਬਾਦ ਅੱਪਡੇਟ',
 'info_short'        => 'ਜਾਣਕਾਰੀ',
@@ -169,39 +172,39 @@
 'permalink'         => 'ਪੱਕਾ ਲਿੰਕ',
 'print'             => 'ਪਰਿੰਟ ਕਰੋ',
 'edit'              => 'ਬਦਲੋ',
-'editthispage'      => 'ਇਹ ਪੇਜ਼ ਸੋਧੋ',
+'editthispage'      => 'ਇਹ ਪੇਜ ਸੋਧੋ',
 'delete'            => 'ਹਟਾਓ',
-'deletethispage'    => 'ਇਹ ਪੇਜ਼ ਹਟਾਓ',
+'deletethispage'    => 'ਇਹ ਪੇਜ ਹਟਾਓ',
 'undelete_short'    => 'ਅਣ-ਹਟਾਓ {{PLURAL:$1|one edit|$1 edits}}',
 'protect'           => 'ਸੁਰੱਖਿਆ',
 'protect_change'    => 'ਸੁਰੱਖਿਆ ਬਦਲੋ',
-'protectthispage'   => 'ਇਹ ਪੇਜ਼ ਸੁਰੱਖਿਅਤ',
+'protectthispage'   => 'ਇਹ ਪੇਜ ਸੁਰੱਖਿਅਤ ਕਰੋ',
 'unprotect'         => 'ਅਣ-ਸੁਰੱਖਿਅਤ',
-'unprotectthispage' => 'ਇਹ ਪੇਜ਼ ਅਣ-ਸੁਰੱਖਿਅਤ ਬਣਾਓ',
-'newpage'           => 'ਨਵਾਂ ਪੇਜ਼',
-'talkpage'          => 'ਇਹ ਪੇਜ਼ ਬਾਰੇ ਚਰਚਾ',
+'unprotectthispage' => 'ਇਹ ਪੇਜ ਅਣ-ਸੁਰੱਖਿਅਤ ਬਣਾਓ',
+'newpage'           => 'ਨਵਾਂ ਪੇਜ',
+'talkpage'          => 'ਇਸ ਪੇਜ ਬਾਰੇ ਚਰਚਾ',
 'talkpagelinktext'  => 'ਗੱਲਬਾਤ',
-'specialpage'       => 'ਖਾਸ ਪੇਜ਼',
+'specialpage'       => 'ਖਾਸ ਪੇਜ',
 'personaltools'     => 'ਨਿੱਜੀ ਟੂਲ',
 'postcomment'       => 'ਇੱਕ ਟਿੱਪਣੀ ਦਿਓ',
-'articlepage'       => 'ਸਮੱਗਰੀ ਪੇਜ਼ ਵੇਖੋ',
+'articlepage'       => 'ਸਮੱਗਰੀ ਪੇਜ ਵੇਖੋ',
 'talk'              => 'ਚਰਚਾ',
 'views'             => 'ਵੇਖੋ',
 'toolbox'           => 'ਟੂਲਬਾਕਸ',
-'userpage'          => 'ਯੂਜ਼ਰ ਪੇਜ਼ ਵੇਖੋ',
-'projectpage'       => 'ਪਰੋਜੈਕਟ ਪੇਜ਼ ਵੇਖੋ',
-'imagepage'         => 'ਚਿੱਤਰ ਪੇਜ਼ ਵੇਖੋ',
-'mediawikipage'     => 'ਸੁਨੇਹਾ ਪੇਜ਼ ਵੇਖੋ',
-'templatepage'      => 'ਟੈਪਲੇਟ ਪੇਜ਼ ਵੇਖੋ',
-'viewhelppage'      => 'ਮੱਦਦ ਪੇਜ਼ ਵੇਖੋ',
-'categorypage'      => 'ਕੈਟਾਗਰੀ ਪੇਜ਼ ਵੇਖੋ',
+'userpage'          => 'ਯੂਜ਼ਰ ਪੇਜ ਵੇਖੋ',
+'projectpage'       => 'ਪਰੋਜੈਕਟ ਪੇਜ ਵੇਖੋ',
+'imagepage'         => 'ਚਿੱਤਰ ਪੇਜ ਵੇਖੋ',
+'mediawikipage'     => 'ਸੁਨੇਹਾ ਪੇਜ ਵੇਖੋ',
+'templatepage'      => 'ਟੈਪਲੇਟ ਪੇਜ ਵੇਖੋ',
+'viewhelppage'      => 'ਮੱਦਦ ਪੇਜ ਵੇਖੋ',
+'categorypage'      => 'ਕੈਟਾਗਰੀ ਪੇਜ ਵੇਖੋ',
 'viewtalkpage'      => 'ਚਰਚਾ ਵੇਖੋ',
 'otherlanguages'    => 'ਹੋਰ ਭਾਸ਼ਾਵਾਂ ਵਿੱਚ',
 'redirectedfrom'    => '($1 ਤੋਂ ਰੀ-ਡਿਰੈਕਟ)',
-'redirectpagesub'   => 'ਰੀ-ਡਿਰੈਕਟ ਪੇਜ਼',
-'lastmodifiedat'    => 'ਇਹ ਪੇਜ਼ ਆਖਰੀ ਵਾਰ $2, $1 ਨੂੰ ਸੋਧਿਆ ਗਿਆ ਸੀ।', # $1 date, $2 time
-'viewcount'         => 'ਇਹ ਪੇਜ਼ ਅਸੈੱਸ ਕੀਤਾ ਗਿਆ {{PLURAL:$1|ਇੱਕਵਾਰ|$1 ਵਾਰ}}.',
-'protectedpage'     => 'ਸੁਰੱਖਿਅਤ ਪੇਜ਼',
+'redirectpagesub'   => 'ਰੀ-ਡਿਰੈਕਟ ਪੇਜ',
+'lastmodifiedat'    => 'ਇਹ ਪੇਜ ਆਖਰੀ ਵਾਰ $2, $1 ਨੂੰ ਸੋਧਿਆ ਗਿਆ ਸੀ।', # $1 date, $2 time
+'viewcount'         => 'ਇਹ ਪੇਜ ਅਸੈੱਸ ਕੀਤਾ ਗਿਆ {{PLURAL:$1|ਇੱਕਵਾਰ|$1 ਵਾਰ}}.',
+'protectedpage'     => 'ਸੁਰੱਖਿਅਤ ਪੇਜ',
 'jumpto'            => 'ਜੰਪ ਕਰੋ:',
 'jumptonavigation'  => 'ਨੇਵੀਗੇਸ਼ਨ',
 'jumptosearch'      => 'ਖੋਜ',
@@ -223,13 +226,13 @@
 'faq'                  => 'ਸਵਾਲ-ਜਵਾਬ',
 'faqpage'              => 'Project:ਸਵਾਲ-ਜਵਾਬ',
 'helppage'             => 'Help:ਸਮੱਗਰੀ',
-'mainpage'             => 'ਮੁੱਖ ਪੇਜ਼',
-'mainpage-description' => 'ਮੁੱਖ ਪੇਜ਼',
+'mainpage'             => 'ਮੁੱਖ ਪੇਜ',
+'mainpage-description' => 'ਮੁੱਖ ਪੇਜ',
 'policy-url'           => 'Project:ਪਾਲਸੀ',
 'portal'               => 'ਕਮਿਊਨਟੀ ਪੋਰਟਲ',
 'portal-url'           => 'Project:ਕਮਿਊਨਟੀ ਪੋਰਟਲ',
 'privacy'              => 'ਪਰਾਈਵੇਸੀ ਪਾਲਸੀ',
-'privacypage'          => 'Project:ਪਰਾਈਵੇਸ ਪੇਜ਼',
+'privacypage'          => 'Project:ਪਰਾਈਵੇਸ ਪੇਜ',
 
 'badaccess'        => 'ਅਧਿਕਾਰ ਗਲਤੀ',
 'badaccess-group0' => 'ਤੁਹਾਨੂੰ ਉਹ ਐਕਸ਼ਨ ਕਰਨ ਦੀ ਮਨਜ਼ੂਰੀ ਨਹੀਂ, ਜਿਸ ਦੀ ਤੁਸੀਂ ਮੰਗ ਕੀਤੀ ਹੈ।',
@@ -252,22 +255,22 @@
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'ਲੇਖ',
-'nstab-user'      => 'ਯੂਜ਼ਰ ਪੇਜ਼',
-'nstab-media'     => 'ਮੀਡਿਆ ਪੇਜ਼',
+'nstab-user'      => 'ਯੂਜ਼ਰ ਪੇਜ',
+'nstab-media'     => 'ਮੀਡਿਆ ਪੇਜ',
 'nstab-special'   => 'ਖਾਸ',
-'nstab-project'   => 'ਪਰੋਜੈਕਟ ਪੇਜ਼',
+'nstab-project'   => 'ਪਰੋਜੈਕਟ ਪੇਜ',
 'nstab-image'     => 'ਫਾਇਲ',
 'nstab-mediawiki' => 'ਸੁਨੇਹਾ',
 'nstab-template'  => 'ਟੈਪਲੇਟ',
-'nstab-help'      => 'ਮੱਦਦ ਪੇਜ਼',
+'nstab-help'      => 'ਮੱਦਦ ਪੇਜ',
 'nstab-category'  => 'ਕੈਟਾਗਰੀ',
 
 # Main script and global functions
 'nosuchaction'      => 'ਕੋਈ ਇੰਝ ਦਾ ਐਕਸ਼ਨ ਨਹੀਂ',
-'nosuchspecialpage' => 'ਕੋਈ ਇੰਝ ਦਾ ਖਾਸ ਪੇਜ਼ ਨਹੀਂ',
-'nospecialpagetext' => "<big>'''ਤੁਸੀਂ ਇੱਕ ਅਵੈਧ ਖਾਸ ਪੇਜ਼ ਦੀ ਮੰਗ ਕੀਤੀ ਹੈ।'''</big>
+'nosuchspecialpage' => 'ਕੋਈ ਇੰਝ ਦਾ ਖਾਸ ਪੇਜ ਨਹੀਂ',
+'nospecialpagetext' => "<big>'''ਤੁਸੀਂ ਇੱਕ ਅਵੈਧ ਖਾਸ ਪੇਜ ਦੀ ਮੰਗ ਕੀਤੀ ਹੈ।'''</big>
 
-A list of valid special pages can be found at [[Special:Specialpages]].",
+A list of valid special pages can be found at [[Special:SpecialPages]].",
 
 # General errors
 'error'              => 'ਗਲਤੀ',
@@ -353,7 +356,7 @@
 'acct_creation_throttle_hit' => 'ਅਫਸੋਸ ਹੈ, ਪਰ ਤੁਸੀਂ ਪਹਿਲਾਂ ਹੀ $1 ਅਕਾਊਂਟ ਬਣਾ ਚੁੱਕੇ ਹੋ। ਤੁਸੀਂ ਹੋਰ ਨਹੀਂ ਬਣਾ ਸਕਦੇ।',
 'emailauthenticated'         => 'ਤੁਹਾਡਾ ਈਮੇਲ ਐਡਰੈੱਸ $1 ਉੱਤੇ ਪਰਮਾਣਿਤ ਕੀਤਾ ਗਿਆ ਹੈ।',
 'emailnotauthenticated'      => 'ਤੁਹਾਡਾ ਈਮੇਲ ਐਡਰੈੱਸ ਹਾਲੇ ਪਰਮਾਣਿਤ ਨਹੀਂ ਹੈ। ਹੇਠ ਦਿੱਤੇ ਫੀਚਰਾਂ ਲਈ ਕੋਈ ਵੀ ਈਮੇਲ ਨਹੀਂ ਭੇਜੀ ਜਾਵੇਗੀ।',
-'noemailprefs'               => 'ਇਹ ਫੀਚਰ ਵਰਤਣ ਲ ਈ ਇੱਕ ਈਮੇਲ ਐਡਰੈੱਸ ਦਿਓ।।',
+'noemailprefs'               => 'ਇਹ ਫੀਚਰ ਵਰਤਣ ਲਈ ਇੱਕ ਈਮੇਲ ਐਡਰੈੱਸ ਦਿਓ।।',
 'emailconfirmlink'           => 'ਆਪਣਾ ਈ-ਮੇਲ ਐਡਰੈੱਸ ਕਨਫਰਮ ਕਰੋ।',
 'invalidemailaddress'        => 'ਈਮੇਲ ਐਡਰੈੱਸ ਮਨਜ਼ੂਰ ਨਹੀਂ ਕੀਤਾ ਜਾ ਸਕਦਾ ਹੈ ਕਿਉਂਕਿ ਇਹ ਠੀਕ ਫਾਰਮੈਟ ਨਹੀਂ ਜਾਪਦਾ ਹੈ। ਇੱਕ ਠੀਕ ਫਾਰਮੈਟ ਵਿੱਚ ਦਿਓ ਜਾਂ ਇਹ ਖੇਤਰ ਖਾਲੀ ਛੱਡ ਦਿਓ।',
 'accountcreated'             => 'ਅਕਾਊਂਟ ਬਣਾਇਆ',
@@ -388,26 +391,24 @@
 'summary'                => 'ਸੰਖੇਪ',
 'subject'                => 'ਵਿਸ਼ਾ/ਹੈੱਡਲਾਈਨ',
 'minoredit'              => 'ਇਹ ਛੋਟੀ ਸੋਧ ਹੈ',
-'watchthis'              => 'ਇਹ ਪੇਜ਼ ਵਾਚ ਕਰੋ',
-'savearticle'            => 'ਪੇਜ਼ ਸੰਭਾਲੋ',
+'watchthis'              => 'ਇਹ ਪੇਜ ਵਾਚ ਕਰੋ',
+'savearticle'            => 'ਪੇਜ ਸੰਭਾਲੋ',
 'preview'                => 'ਝਲਕ',
 'showpreview'            => 'ਝਲਕ ਵੇਖੋ',
 'showlivepreview'        => 'ਲਾਈਵ ਝਲਕ',
 'showdiff'               => 'ਬਦਲਾਅ ਵੇਖਾਓ',
-'anoneditwarning'        => "'''ਚੇਤਾਵਨੀ:''' ਤੁਸੀਂ ਲਾਗਇਨ ਨਹੀਂ ਕੀਤਾ ਹੈ। ਤੁਹਾਡਾ IP ਐਡਰੈੱਸ ਇਹ ਪੇਜ਼ ਦੇ ਐਡਿਟ ਅਤੀਤ ਵਿੱਚ ਰਿਕਾਰਡ ਕੀਤਾ ਜਾਵੇਗਾ।",
+'anoneditwarning'        => "'''ਚੇਤਾਵਨੀ:''' ਤੁਸੀਂ ਲਾਗਇਨ ਨਹੀਂ ਕੀਤਾ ਹੈ। ਤੁਹਾਡਾ IP ਐਡਰੈੱਸ ਇਸ ਪੇਜ ਦੇ ਐਡਿਟ ਅਤੀਤ ਵਿੱਚ ਰਿਕਾਰਡ ਕੀਤਾ ਜਾਵੇਗਾ।",
 'missingcommenttext'     => 'ਹੇਠਾਂ ਇੱਕ ਟਿੱਪਣੀ ਦਿਓ।',
 'summary-preview'        => 'ਸੰਖੇਪ ਝਲਕ',
 'subject-preview'        => 'ਵਿਸ਼ਾ/ਹੈੱਡਲਾਈਨ ਝਲਕ',
 'blockedtitle'           => 'ਯੂਜ਼ਰ ਬਲਾਕ ਕੀਤਾ ਗਿਆ',
 'whitelistedittitle'     => 'ਸੋਧਣ ਲਈ ਲਾਗਇਨ ਕਰਨਾ ਪਵੇਗਾ',
-'whitelistedittext'      => 'ਪੇਜ਼ ਸੋਧਣ ਲਈ ਤੁਹਾਨੂੰ $1 ਕਰਨਾ ਪਵੇਗਾ।',
-'whitelistreadtitle'     => 'ਪੜ੍ਹਨ ਲਈ ਲਾਗਇਨ ਕਰਨਾ ਪਵੇਗਾ',
-'whitelistacctitle'      => 'ਤੁਹਾਨੂੰ ਇੱਕ ਅਕਾਊਂਟ ਬਣਾਉਣ ਦੀ ਮਨਜ਼ੂਰੀ ਨਹੀਂ ਹੈ।',
+'whitelistedittext'      => 'ਪੇਜ ਸੋਧਣ ਲਈ ਤੁਹਾਨੂੰ $1 ਕਰਨਾ ਪਵੇਗਾ।',
 'confirmedittitle'       => 'ਐਡੀਟ ਕਰਨ ਲਈ ਈਮੇਲ ਕਨਫਰਮੇਸ਼ਨ ਦੀ ਲੋੜ ਹੈ',
 'nosuchsectiontitle'     => 'ਇੰਝ ਦਾ ਕੋਈ ਸ਼ੈਕਸ਼ਨ ਨਹੀਂ ਹੈ।',
 'loginreqtitle'          => 'ਲਾਗਇਨ ਚਾਹੀਦਾ ਹੈ',
 'loginreqlink'           => 'ਲਾਗਇਨ',
-'loginreqpagetext'       => 'ਹੋਰ ਪੇਜ਼ ਵੇਖਣ ਲਈ ਤੁਹਾਨੂੰ $1 ਕਰਨਾ ਪਵੇਗਾ।',
+'loginreqpagetext'       => 'ਹੋਰ ਪੇਜ ਵੇਖਣ ਲਈ ਤੁਹਾਨੂੰ $1 ਕਰਨਾ ਪਵੇਗਾ।',
 'accmailtitle'           => 'ਪਾਸਵਰਡ ਭੇਜਿਆ।',
 'accmailtext'            => '"$1" ਲਈ ਪਾਸਵਰਡ $2 ਨੂੰ ਭੇਜਿਆ ਗਿਆ।',
 'newarticle'             => '(ਨਵਾਂ)',
@@ -421,7 +422,7 @@
 'yourtext'               => 'ਤੁਹਾਡਾ ਟੈਕਸਟ',
 'storedversion'          => 'ਸੰਭਾਲਿਆ ਵਰਜਨ',
 'yourdiff'               => 'ਅੰਤਰ',
-'templatesused'          => 'ਇਹ ਪੇਜ਼ ਉੱਤੇ ਟੈਪਲੇਟ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ:',
+'templatesused'          => 'ਇਸ ਪੇਜ ਉੱਤੇ ਟੈਪਲੇਟ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ:',
 'templatesusedpreview'   => 'ਇਹ ਝਲਕ ਵਿੱਚ ਟੈਪਲੇਟ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ:',
 'templatesusedsection'   => 'ਇਹ ਸ਼ੈਕਸ਼ਨ ਵਿੱਚ ਟੈਪਲੇਟ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ:',
 'template-protected'     => '(ਸੁਰੱਖਿਅਤ)',
@@ -433,7 +434,7 @@
 'cantcreateaccounttitle' => 'ਅਕਾਊਂਟ ਬਣਾਇਆ ਨਹੀਂ ਜਾ ਸਕਦਾ',
 
 # History pages
-'viewpagelogs'        => 'ਇਹ ਪੇਜ਼ ਲਈ ਲਾਗ ਵੇਖੋ',
+'viewpagelogs'        => 'ਇਸ ਪੇਜ ਦੇ ਲਈ ਲਾਗ ਵੇਖੋ',
 'revnotfound'         => 'ਰੀਵਿਜ਼ਨ ਨਹੀਂ ਲੱਭਿਆ',
 'currentrev'          => 'ਮੌਜੂਦਾ ਰੀਵਿਜ਼ਨ',
 'revisionasof'        => '$1 ਦੇ ਰੀਵਿਜ਼ਨ ਵਾਂਗ',
@@ -466,6 +467,8 @@
 'revdelete-hide-image'    => 'ਫਾਇਲ ਸਮੱਗਰੀ ਓਹਲੇ',
 'revdelete-log'           => 'ਲਾਗ ਟਿੱਪਣੀ:',
 'revdelete-submit'        => 'ਚੁਣੇ ਰੀਵਿਜ਼ਨ ਉੱਤੇ ਲਾਗੂ ਕਰੋ',
+'pagehist'                => 'ਪੇਜ ਦਾ ਅਤੀਤ',
+'deletedhist'             => 'ਹਟਾਇਆ ਗਿਆ ਅਤੀਤ',
 
 # Diffs
 'difference'              => '(ਰੀਵਿਜ਼ਨ ਵਿੱਚ ਅੰਤਰ)',
@@ -478,14 +481,15 @@
 'searchresulttext'      => '{{SITENAME}} ਖੋਜ ਬਾਰੇ ਹੋਰ ਜਾਣਕਾਰੀ ਲਵੋ, ਵੇਖੋ [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle'        => "ਤੁਸੀਂ '''[[:$1]]''' ਲਈ ਖੋਜ ਕੀਤੀ।",
 'searchsubtitleinvalid' => "ਤੁਸੀਂ'''$1''' ਲਈ ਖੋਜ ਕੀਤੀ।",
-'noexactmatch'          => "'''\"\$1\"''' ਟਾਇਟਲ ਨਾਲ ਕੋਈ ਪੇਜ਼ ਨਹੀਂ ਹੈ। ਤੁਸੀਂ [[:\$1|ਇਹ ਪੇਜ਼]] ਬਣਾ ਸਕਦੇ ਹੋ।",
+'noexactmatch'          => "'''\"\$1\"''' ਟਾਇਟਲ ਨਾਲ ਦਾ ਕੋਈ ਪੇਜ ਨਹੀਂ ਹੈ। ਤੁਸੀਂ [[:\$1|ਇਹ ਪੇਜ]] ਬਣਾ ਸਕਦੇ ਹੋ।",
 'titlematches'          => 'ਆਰਟੀਕਲ ਟੈਕਸਟ ਮਿਲਦਾ',
-'notitlematches'        => 'ਕੋਈ ਪੇਜ਼ ਟਾਇਟਲ ਨਹੀਂ ਮਿਲਦਾ',
-'textmatches'           => 'ਪੇਜ਼ ਟੈਕਸਟ ਮਿਲਦਾ',
-'notextmatches'         => 'ਕੋਈ ਪੇਜ਼ ਟੈਕਸਟ ਨਹੀਂ ਮਿਲਦਾ',
+'notitlematches'        => 'ਕੋਈ ਪੇਜ ਟਾਇਟਲ ਨਹੀਂ ਮਿਲਦਾ',
+'textmatches'           => 'ਪੇਜ ਟੈਕਸਟ ਮਿਲਦਾ',
+'notextmatches'         => 'ਕੋਈ ਪੇਜ ਟੈਕਸਟ ਨਹੀਂ ਮਿਲਦਾ',
 'prevn'                 => 'ਪਿੱਛੇ $1',
 'nextn'                 => 'ਅੱਗੇ $1',
 'viewprevnext'          => 'ਵੇਖੋ ($1) ($2) ($3)',
+'searchall'             => 'ਸਭ',
 'powersearch'           => 'ਖੋਜ',
 
 # Preferences page
@@ -493,7 +497,7 @@
 'mypreferences'         => 'ਮੇਰੀ ਪਸੰਦ',
 'prefs-edits'           => 'ਸੋਧਾਂ ਦੀ ਗਿਣਤੀ:',
 'prefsnologin'          => 'ਲਾਗਇਨ ਨਹੀਂ',
-'prefsnologintext'      => 'ਯੂਜ਼ਰ ਪਸੰਦ ਸੈੱਟ ਕਰਨ ਲਈ ਤੁਹਾਨੂੰ [[Special:Userlogin|logged in]] ਕਰਨਾ ਪਵੇਗਾ।',
+'prefsnologintext'      => 'ਯੂਜ਼ਰ ਪਸੰਦ ਸੈੱਟ ਕਰਨ ਲਈ ਤੁਹਾਨੂੰ [[Special:UserLogin|logged in]] ਕਰਨਾ ਪਵੇਗਾ।',
 'prefsreset'            => 'ਪਸੰਦੀ ਸਟੋਰੇਜ਼ ਤੋਂ ਮੁੜ-ਸੈੱਟ ਕੀਤੀ ਗਈ ਹੈ।',
 'qbsettings'            => 'ਤੁਰੰਤ ਬਾਰ',
 'qbsettings-none'       => 'ਕੋਈ ਨਹੀਂ',
@@ -521,7 +525,7 @@
 'rows'                  => 'ਕਤਾਰਾਂ:',
 'columns'               => 'ਕਾਲਮ:',
 'searchresultshead'     => 'ਖੋਜ',
-'resultsperpage'        => 'ਪ੍ਰਤੀ ਪੇਜ਼ ਹਿੱਟ:',
+'resultsperpage'        => 'ਪ੍ਰਤੀ ਪੇਜ ਹਿੱਟ:',
 'savedprefs'            => 'ਤੁਹਾਡੀ ਪਸੰਦ ਸੰਭਾਲੀ ਗਈ ਹੈ।',
 'timezonelegend'        => 'ਟਾਈਮ ਜ਼ੋਨ',
 'localtime'             => 'ਲੋਕਲ ਟਾਈਮ',
@@ -542,8 +546,12 @@
 'userrights-reason'        => 'ਬਦਲਣ ਦੇ ਕਾਰਨ:',
 
 # Groups
-'group' => 'ਗਰੁੱਪ:',
+'group'      => 'ਗਰੁੱਪ:',
+'group-user' => 'ਮੈਂਬਰ',
+'group-all'  => '(ਸਭ)',
 
+'group-user-member' => 'ਮੈਂਬਰ',
+
 # User rights log
 'rightsnone' => '(ਕੋਈ ਨਹੀਂ)',
 
@@ -552,6 +560,9 @@
 'rcshowhidemine'    => '$1 ਮੇਰਾ ਐਡਿਟ',
 'hide'              => 'ਓਹਲੇ',
 'show'              => 'ਵੇਖਾਓ',
+'minoreditletter'   => 'ਛ',
+'newpageletter'     => 'ਨ',
+'boteditletter'     => 'ਬ',
 'rc_categories_any' => 'ਕੋਈ ਵੀ',
 
 # Recent changes linked
@@ -563,7 +574,7 @@
 'reupload'             => 'ਰੀ-ਅੱਪਲੋਡ',
 'reuploaddesc'         => 'ਅੱਪਲੋਡ ਫਾਰਮ ਉੱਤੇ ਜਾਓ।',
 'uploadnologin'        => 'ਲਾਗਇਨ ਨਹੀਂ ਹੋ',
-'uploadnologintext'    => 'ਤੁਹਾਨੂੰ[[Special:Userlogin|logged in] ਕਰਨਾ ਪਵੇਗਾ]
+'uploadnologintext'    => 'ਤੁਹਾਨੂੰ[[Special:UserLogin|logged in] ਕਰਨਾ ਪਵੇਗਾ]
 to upload files.',
 'uploaderror'          => 'ਅੱਪਲੋਡ ਗਲਤੀ',
 'uploadlog'            => 'ਅੱਪਲੋਡ ਲਾਗ',
@@ -591,7 +602,7 @@
 'uploaddisabled'       => 'ਅੱਪਲੋਡ ਆਯੋਗ ਹੈ',
 'uploadvirus'          => 'ਇਹ ਫਾਇਲ ਵਿੱਚ ਵਾਇਰਸ ਹੈ! ਵੇਰਵੇ ਲਈ ਵੇਖੋ: $1',
 'sourcefilename'       => 'ਸੋਰਸ ਫਾਇਲ ਨਾਂ:',
-'watchthisupload'      => 'ਇਹ ਪੇਜ਼ ਵਾਚ ਕਰੋ',
+'watchthisupload'      => 'ਇਹ ਪੇਜ ਵਾਚ ਕਰੋ',
 
 'upload-file-error' => 'ਅੰਦਰੂਨੀ ਗਲਤੀ',
 'upload-misc-error' => 'ਅਣਜਾਣ ਅੱਪਲੋਡ ਗਲਤੀ',
@@ -604,7 +615,7 @@
 'license-nopreview'  => '(ਝਲਕ ਉਪਲੱਬਧ ਨਹੀਂ)',
 'upload_source_file' => ' (ਤੁਹਾਡੇ ਕੰਪਿਊਟਰ ਉੱਤੇ ਇੱਕ ਫਾਇਲ)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'               => 'ਫਾਇਲ',
 'imagelist'             => 'ਫਾਇਲ ਲਿਸਟ',
 'imagelist_date'        => 'ਮਿਤੀ',
@@ -650,7 +661,7 @@
 'statistics'             => 'ਅੰਕੜੇ',
 'sitestats'              => '{{SITENAME}} ਅੰਕੜੇ',
 'userstats'              => 'ਯੂਜ਼ਰ ਅੰਕੜੇ',
-'statistics-mostpopular' => 'ਸਭ ਤੋਂ ਵੱਧ ਵੇਖੇ ਪੇਜ਼',
+'statistics-mostpopular' => 'ਸਭ ਤੋਂ ਵੱਧ ਵੇਖੇ ਪੇਜ',
 
 'brokenredirects-edit'   => '(ਸੋਧ)',
 'brokenredirects-delete' => '(ਹਟਾਓ)',
@@ -658,13 +669,14 @@
 # Miscellaneous special pages
 'unusedcategories'  => 'ਅਣਵਰਤੀਆਂ ਕੈਟਾਗਰੀਆਂ',
 'unusedimages'      => 'ਅਣਵਰਤੀਆਂ ਫਾਇਲਾਂ',
-'popularpages'      => 'ਪਾਪੂਲਰ ਪੇਜ਼',
+'popularpages'      => 'ਪਾਪੂਲਰ ਪੇਜ',
+'shortpages'        => 'ਛੋਟੇ ਪੇਜ',
 'listusers'         => 'ਯੂਜ਼ਰ ਲਿਸਟ',
-'newpages'          => 'ਨਵੇਂ ਪੇਜ਼',
+'newpages'          => 'ਨਵੇਂ ਪੇਜ',
 'newpages-username' => 'ਯੂਜ਼ਰ ਨਾਂ:',
-'ancientpages'      => 'ਸਭ ਤੋਂ ਪੁਰਾਣੇ ਪੇਜ਼',
+'ancientpages'      => 'ਸਭ ਤੋਂ ਪੁਰਾਣੇ ਪੇਜ',
 'move'              => 'ਭੇਜੋ',
-'movethispage'      => 'ਇਹ ਪੇਜ਼ ਭੇਜੋ',
+'movethispage'      => 'ਇਹ ਪੇਜ ਭੇਜੋ',
 'notargettitle'     => 'ਟਾਰਗੇਟ ਨਹੀਂ',
 
 # Book sources
@@ -678,13 +690,14 @@
 'all-logs-page'        => 'ਸਭ ਲਾਗ',
 'log-search-submit'    => 'ਜਾਓ',
 
-# Special:Allpages
-'allpages'          => 'ਸਭ ਪੇਜ਼',
-'nextpage'          => 'ਅੱਗੇ ਪੇਜ਼ ($1)',
-'prevpage'          => 'ਪਿੱਛੇ ਪੇਜ਼ ($1)',
+# Special:AllPages
+'allpages'          => 'ਸਭ ਪੇਜ',
+'alphaindexline'    => '$1 ਤੋਂ $2',
+'nextpage'          => 'ਅੱਗੇ ਪੇਜ ($1)',
+'prevpage'          => 'ਪਿੱਛੇ ਪੇਜ ($1)',
 'allarticles'       => 'ਸਭ ਲੇਖ',
-'allinnamespace'    => 'ਸਭ ਪੇਜ਼ ($1 ਨੇਮਸਪੇਸ)',
-'allnotinnamespace' => 'ਸਭ ਪੇਜ਼ ($1 ਨੇਮਸਪੇਸ ਵਿੱਚ ਨਹੀਂ)',
+'allinnamespace'    => 'ਸਭ ਪੇਜ ($1 ਨੇਮਸਪੇਸ)',
+'allnotinnamespace' => 'ਸਭ ਪੇਜ ($1 ਨੇਮਸਪੇਸ ਵਿੱਚ ਨਹੀਂ)',
 'allpagesprev'      => 'ਪਿੱਛੇ',
 'allpagesnext'      => 'ਅੱਗੇ',
 'allpagessubmit'    => 'ਜਾਓ',
@@ -692,7 +705,7 @@
 # Special:Categories
 'categories' => 'ਕੈਟਾਗਰੀਆਂ',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'ਵੇਖੋ',
 'listusers-noresult' => 'ਕੋਈ ਯੂਜ਼ਰ ਨਹੀਂ ਲੱਭਿਆ।',
 
@@ -718,23 +731,23 @@
 'watchnologin'       => 'ਲਾਗਇਨ ਨਹੀਂ',
 'addedwatch'         => 'ਵਾਚ-ਲਿਸਟ ਵਿੱਚ ਸ਼ਾਮਲ',
 'watch'              => 'ਵਾਚ',
-'watchthispage'      => 'ਇਹ ਪੇਜ਼ ਵਾਚ ਕਰੋ',
+'watchthispage'      => 'ਇਹ ਪੇਜ ਵਾਚ ਕਰੋ',
 'unwatch'            => 'ਅਣ-ਵਾਚ',
 'wlshowlast'         => 'ਆਖਰੀ $1 ਦਿਨ $2 ਘੰਟੇ $3 ਵੇਖੋ',
 'watchlist-show-own' => 'ਮੇਰੀ ਸੋਧ ਵੇਖਾਓ',
 'watchlist-hide-own' => 'ਮੇਰੀ ਸੋਧ ਓਹਲੇ',
 
-'enotif_newpagetext'           => 'ਇਹ ਨਵਾਂ ਪੇਜ਼ ਹੈ।',
+'enotif_newpagetext'           => 'ਇਹ ਨਵਾਂ ਪੇਜ ਹੈ।',
 'enotif_impersonal_salutation' => '{{SITENAME}} ਯੂਜ਼ਰ',
 'changed'                      => 'ਬਦਲਿਆ',
 'created'                      => 'ਬਣਾਇਆ',
 'enotif_anon_editor'           => 'ਅਗਿਆਤ ਯੂਜ਼ਰ $1',
 
 # Delete/protect/revert
-'deletepage'       => 'ਪੇਜ਼ ਹਟਾਓ',
+'deletepage'       => 'ਪੇਜ ਹਟਾਓ',
 'confirm'          => 'ਪੁਸ਼ਟੀ',
 'excontent'        => "ਸਮੱਗਰੀ ਸੀ: '$1'",
-'exblank'          => 'ਪੇਜ਼ ਖਾਲੀ ਹੈ',
+'exblank'          => 'ਪੇਜ ਖਾਲੀ ਹੈ',
 'actioncomplete'   => 'ਐਕਸ਼ਨ ਪੂਰਾ ਹੋਇਆ',
 'deletedarticle'   => '"[[$1]]" ਹਟਾਇਆ',
 'rollback_short'   => 'ਰੋਲਬੈਕ',
@@ -751,8 +764,9 @@
 'pagesize'         => '(ਬਾਈਟ)',
 
 # Restrictions (nouns)
-'restriction-edit' => 'ਸੋਧ',
-'restriction-move' => 'ਭੇਜੋ',
+'restriction-edit'   => 'ਸੋਧ',
+'restriction-move'   => 'ਭੇਜੋ',
+'restriction-upload' => 'ਅੱਪਲੋਡ',
 
 # Restriction levels
 'restriction-level-sysop'         => 'ਪੂਰਾ ਸੁਰੱਖਿਅਤ',
@@ -812,13 +826,11 @@
 'lockdb' => 'ਡਾਟਾਬੇਸ ਲਾਕ',
 
 # Move page
-'move-page-legend' => 'ਪੇਜ਼ ਮੂਵ ਕਰੋ',
-'movearticle'      => 'ਪੇਜ਼ ਮੂਵ ਕਰੋ:',
-'movenologin'      => 'ਲਾਗਇਨ ਨਹੀਂ ਹੋ',
-'movenologintext'  => 'ਇੱਕ ਪੇਜ਼ ਮੂਵ ਕਰਨ ਲਈ ਤੁਸੀਂ ਰਜਿਸਟਰਡ ਯੂਜ਼ਰ ਹੋਣੇ ਚਾਹੀਦੇ ਹੋ ਅਤੇ [[Special:Userlogin|logged in]] ਕੀਤਾ ਹੋਣਾ ਚਾਹੀਦਾ ਹੈ।',
+'move-page-legend' => 'ਪੇਜ ਮੂਵ ਕਰੋ',
+'movearticle'      => 'ਪੇਜ ਮੂਵ ਕਰੋ:',
 'newtitle'         => 'ਨਵੇਂ ਟਾਇਟਲ ਲਈ:',
-'move-watch'       => 'ਇਹ ਪੇਜ਼ ਵਾਚ ਕਰੋ',
-'movepagebtn'      => 'ਪੇਜ਼ ਮੂਵ ਕਰੋ',
+'move-watch'       => 'ਇਹ ਪੇਜ ਵਾਚ ਕਰੋ',
+'movepagebtn'      => 'ਪੇਜ ਮੂਵ ਕਰੋ',
 'pagemovedsub'     => 'ਮੂਵ ਸਫ਼ਲ ਰਿਹਾ',
 'movedto'          => 'ਮੂਵ ਕੀਤਾ',
 'movelogpage'      => 'ਮੂਵ ਲਾਗ',
@@ -841,9 +853,9 @@
 'filemissing' => 'ਫਾਇਲ ਗੁੰਮ ਹੈ',
 
 # Special:Import
-'import'                  => 'ਪੇਜ਼ ਇੰਪੋਰਟ ਕਰੋ',
+'import'                  => 'ਪੇਜ ਇੰਪੋਰਟ ਕਰੋ',
 'import-interwiki-submit' => 'ਇੰਪੋਰਟ',
-'importstart'             => 'ਪੇਜ਼ ਇੰਪੋਰਟ ਕੀਤੇ ਜਾ ਰਹੇ ਹਨ...',
+'importstart'             => 'ਪੇਜ ਇੰਪੋਰਟ ਕੀਤੇ ਜਾ ਰਹੇ ਹਨ...',
 'importfailed'            => 'ਇੰਪੋਰਟ ਫੇਲ੍ਹ: $1',
 'importnotext'            => 'ਖਾਲੀ ਜਾਂ ਕੋਈ ਟੈਕਸਟ ਨਹੀਂ',
 'importsuccess'           => 'ਇੰਪੋਰਟ ਸਫ਼ਲ!',
@@ -854,37 +866,37 @@
 'import-logentry-upload-detail' => '$1 ਰੀਵਿਜ਼ਨ',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'        => 'ਮੇਰਾ ਯੂਜ਼ਰ ਪੇਜ਼',
-'tooltip-pt-mytalk'          => 'ਮੇਰਾ ਗੱਲਬਾਤ ਪੇਜ਼',
+'tooltip-pt-userpage'        => 'ਮੇਰਾ ਯੂਜ਼ਰ ਪੇਜ',
+'tooltip-pt-mytalk'          => 'ਮੇਰਾ ਗੱਲਬਾਤ ਪੇਜ',
 'tooltip-pt-preferences'     => 'ਮੇਰੀ ਪਸੰਧ',
 'tooltip-pt-mycontris'       => 'ਮੇਰੇ ਯੋਗਦਾਨ ਦੀ ਲਿਸਟ',
 'tooltip-pt-logout'          => 'ਲਾਗ ਆਉਟ',
-'tooltip-ca-protect'         => 'ਇਹ ਪੇਜ਼ ਸੁਰੱਖਿਅਤ ਬਣਾਓ',
-'tooltip-ca-delete'          => 'ਇਹ ਪੇਜ਼ ਹਟਾਓ',
-'tooltip-ca-move'            => 'ਇਹ ਪੇਜ਼ ਹਿਲਾਓ',
+'tooltip-ca-protect'         => 'ਇਹ ਪੇਜ ਸੁਰੱਖਿਅਤ ਬਣਾਓ',
+'tooltip-ca-delete'          => 'ਇਹ ਪੇਜ ਹਟਾਓ',
+'tooltip-ca-move'            => 'ਇਹ ਪੇਜ ਭੇਜੋ',
 'tooltip-search'             => 'ਖੋਜ {{SITENAME}}',
-'tooltip-p-logo'             => 'ਮੇਨੂ ਪੇਜ਼',
-'tooltip-n-mainpage'         => 'ਮੁੱਖ ਪੇਜ਼ ਖੋਲ੍ਹੋ',
-'tooltip-n-randompage'       => 'ਇੱਕ ਰਲਵਾਂ ਪੇਜ਼ ਲੋਡ ਕਰੋ',
+'tooltip-p-logo'             => 'ਮੁੱਖ ਪੇਜ',
+'tooltip-n-mainpage'         => 'ਮੁੱਖ ਪੇਜ ਖੋਲ੍ਹੋ',
+'tooltip-n-randompage'       => 'ਇੱਕ ਰਲਵਾਂ ਪੇਜ ਲੋਡ ਕਰੋ',
 'tooltip-n-help'             => 'ਖੋਜਣ ਲਈ ਥਾਂ',
 'tooltip-t-emailuser'        => 'ਇਹ ਯੂਜ਼ਰ ਨੂੰ ਮੇਲ ਭੇਜੋ',
 'tooltip-t-upload'           => 'ਚਿੱਤਰ ਜਾਂ ਮੀਡਿਆ ਫਾਇਲਾਂ ਅੱਪਲੋਡ ਕਰੋ',
-'tooltip-ca-nstab-main'      => 'ਸਮਗੱਰੀ ਪੇਜ਼ ਵੇਖੋ',
-'tooltip-ca-nstab-user'      => 'ਯੂਜ਼ਰ ਪੇਜ਼ ਵੇਖੋ',
-'tooltip-ca-nstab-media'     => 'ਮੀਡਿਆ ਪੇਜ਼ ਵੇਖੋ',
-'tooltip-ca-nstab-project'   => 'ਪਰੋਜੈਕਟ ਪੇਜ਼ ਵੇਖੋ',
-'tooltip-ca-nstab-image'     => 'ਚਿੱਤਰ ਪੇਜ਼ ਵੇਖੋ',
+'tooltip-ca-nstab-main'      => 'ਸਮਗੱਰੀ ਪੇਜ ਵੇਖੋ',
+'tooltip-ca-nstab-user'      => 'ਯੂਜ਼ਰ ਪੇਜ ਵੇਖੋ',
+'tooltip-ca-nstab-media'     => 'ਮੀਡਿਆ ਪੇਜ ਵੇਖੋ',
+'tooltip-ca-nstab-project'   => 'ਪਰੋਜੈਕਟ ਪੇਜ ਵੇਖੋ',
+'tooltip-ca-nstab-image'     => 'ਚਿੱਤਰ ਪੇਜ ਵੇਖੋ',
 'tooltip-ca-nstab-mediawiki' => 'ਸਿਸਟਮ ਸੁਨੇਹੇ ਵੇਖੋ',
 'tooltip-ca-nstab-template'  => 'ਟੈਪਲੇਟ ਵੇਖੋ',
-'tooltip-ca-nstab-help'      => 'ਮੱਦਦ ਪੇਜ਼ ਵੇਖੋ',
-'tooltip-ca-nstab-category'  => 'ਕੈਟਾਗਰੀ ਪੇਜ਼ ਵੇਖੋ',
+'tooltip-ca-nstab-help'      => 'ਮੱਦਦ ਪੇਜ ਵੇਖੋ',
+'tooltip-ca-nstab-category'  => 'ਕੈਟਾਗਰੀ ਪੇਜ ਵੇਖੋ',
 'tooltip-save'               => 'ਆਪਣੇ ਬਦਲਾਅ ਸੰਭਾਲੋ',
 'tooltip-upload'             => 'ਅੱਪਲੋਡ ਸਟਾਰਟ ਕਰੋ',
 
 # Attribution
 'others'      => 'ਹੋਰ',
 'siteusers'   => '{{SITENAME}} ਯੂਜ਼ਰ $1',
-'creditspage' => 'ਪੇਜ਼ ਮਾਣ',
+'creditspage' => 'ਪੇਜ ਮਾਣ',
 
 # Spam protection
 'spamprotectiontitle' => 'Spam ਸੁਰੱਖਿਆ ਫਿਲਟਰ',
@@ -908,7 +920,7 @@
 'show-big-image'       => 'ਪੂਰਾ ਰੈਜ਼ੋਲੇਸ਼ਨ',
 'show-big-image-thumb' => '<small>ਇਹ ਝਲਕ ਦਾ ਆਕਾਰ: $1 × $2 ਪਿਕਸਲ</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'ਨਵੀਆਂ ਫਾਇਲਾਂ ਦੀ ਗੈਲਰੀ',
 'noimages'  => 'ਵੇਖਣ ਲਈ ਕੁਝ ਨਹੀਂ',
 'ilsubmit'  => 'ਖੋਜ',
@@ -955,12 +967,19 @@
 'exif-gpsspeed-k' => 'ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ',
 'exif-gpsspeed-m' => 'ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ',
 
+# 'all' in various places, this might be different for inflected languages
+'recentchangesall' => 'ਸਭ',
+'imagelistall'     => 'ਸਭ',
+'watchlistall2'    => 'ਸਭ',
+'namespacesall'    => 'ਸਭ',
+'monthsall'        => 'ਸਭ',
+
 # E-mail address confirmation
 'confirmemail'          => 'ਈਮੇਲ ਐਡਰੈੱਸ ਪੁਸ਼ਟੀ',
 'confirmemail_send'     => 'ਇੱਕ ਪੁਸ਼ਟੀ ਕੋਡ ਭੇਜੋ',
 'confirmemail_sent'     => 'ਪੁਸ਼ਟੀ ਈਮੇਲ ਭੇਜੀ ਗਈ।',
 'confirmemail_invalid'  => 'ਗਲਤ ਪੁਸ਼ਟੀ ਕੋਡ ਹੈ। ਕੋਡ ਦੀ ਮਿਆਦ ਪੁੱਗੀ ਹੋ ਸਕਦੀ ਹੈ।',
-'confirmemail_loggedin' => 'ਹੁਣ ਤੁਹਾਡਾ ਈਮੇਮਲ ਐਡਰੈੱਸ ਚੈੱਕ (confirmed) ਹੋ ਗਿਆ ਹੈ।',
+'confirmemail_loggedin' => 'ਹੁਣ ਤੁਹਾਡਾ ਈਮੇਲ ਐਡਰੈੱਸ ਚੈੱਕ (confirmed) ਹੋ ਗਿਆ ਹੈ।',
 'confirmemail_subject'  => '{{SITENAME}} ਈਮੇਲ ਐਡਰੈੱਸ ਪੁਸ਼ਟੀ',
 
 # Scary transclusion
@@ -974,7 +993,7 @@
 'recreate' => 'ਮੁੜ-ਬਣਾਓ',
 
 # HTML dump
-'redirectingto' => '[[$1]] ਲਈ ਰੀ-ਡਿਰੈਕਟ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ...',
+'redirectingto' => '[[:$1]] ਲਈ ਰੀ-ਡਿਰੈਕਟ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ...',
 
 # action=purge
 'confirm_purge_button' => 'ਠੀਕ ਹੈ',
@@ -983,22 +1002,22 @@
 'hideresults' => 'ਨਤੀਜੇ ਓਹਲੇ',
 
 # Multipage image navigation
-'imgmultipageprev' => '← ਪੇਜ਼ ਪਿੱਛੇ',
-'imgmultipagenext' => 'ਪੇਜ਼ ਅੱਗੇ →',
+'imgmultipageprev' => '← ਪਿਛਲਾ ਪੇਜ',
+'imgmultipagenext' => 'ਅਗਲਾ ਪੇਜ →',
 'imgmultigo'       => 'ਜਾਓ!',
 
 # Table pager
-'table_pager_next'         => 'ਪੇਜ਼ ਅੱਗੇ',
-'table_pager_prev'         => 'ਪੇਜ਼ ਪਿੱਛੇ',
-'table_pager_first'        => 'ਪਹਿਲਾਂ ਪੇਜ਼',
-'table_pager_last'         => 'ਆਖਰੀ ਪੇਜ਼',
-'table_pager_limit'        => 'ਹਰੇਕ ਪੇਜ਼ ਲਈ $1 ਆਈਟਮਾਂ',
+'table_pager_next'         => 'ਅਗਲਾ ਪੇਜ',
+'table_pager_prev'         => 'ਪਿਛਲਾ ਪੇਜ',
+'table_pager_first'        => 'ਪਹਿਲਾ ਪੇਜ',
+'table_pager_last'         => 'ਆਖਰੀ ਪੇਜ',
+'table_pager_limit'        => 'ਹਰੇਕ ਪੇਜ ਲਈ $1 ਆਈਟਮਾਂ',
 'table_pager_limit_submit' => 'ਜਾਓ',
 'table_pager_empty'        => 'ਕੋਈ ਨਤੀਜਾ ਨਹੀਂ',
 
 # Auto-summaries
-'autosumm-blank' => 'ਪੇਜ਼ ਤੋਂ ਸਭ ਸਮੱਗਰੀ ਹਟਾਓ',
-'autosumm-new'   => 'ਨਵਾਂ ਪੇਜ਼: $1',
+'autosumm-blank' => 'ਪੇਜ ਤੋਂ ਸਭ ਸਮੱਗਰੀ ਹਟਾਓ',
+'autosumm-new'   => 'ਨਵਾਂ ਪੇਜ: $1',
 
 # Live preview
 'livepreview-loading' => 'ਲੋਡ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ…',
@@ -1013,6 +1032,7 @@
 'version' => 'ਵਰਜਨ', # Not used as normal message but as header for the special page itself
 
 # Special:SpecialPages
-'specialpages' => 'ਖਾਸ ਪੇਜ਼',
+'specialpages'             => 'ਖਾਸ ਪੇਜ',
+'specialpages-group-login' => 'ਲਾਗ ਇਨ / ਅਕਾਊਂਟ ਬਣਾਓ',
 
 );
Index: languages/messages/MessagesBar.php
===================================================================
--- languages/messages/MessagesBar.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBar.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
  * @author Malafaya
  */
 
@@ -50,9 +48,6 @@
 'watchthis'          => 'De Seitn beobachtn',
 'whitelistedittitle' => 'Zum Bearbatn miaßn Sie si oomeidn',
 'whitelistedittext'  => 'Sie miaßn si $1, um Seiten bearbatn zum kinna.',
-'whitelistreadtitle' => 'Zum Lesn is erforderlich, ogmeldt zum sei',
-'whitelistreadtext'  => 'Sie miaßn si [[Special:Userlogin|da oomeidn]], um de Seitn lesen zum kinna.',
-'whitelistacctitle'  => 'Sie san net berechtigt, a Benutzerkonto ozumlegn.',
 'accmailtitle'       => 'Passwort is vaschickt worn',
 'newarticle'         => '(Nei)',
 'yourtext'           => 'Eana Text',
@@ -74,7 +69,7 @@
 # Special:Log
 'all-logs-page' => 'Alle Logbiacha',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle Seitn',
 'allarticles'       => 'Alle Seitn',
 'allinnamespace'    => 'Alle Seitn (Namensraum: $1)',
@@ -110,7 +105,7 @@
 Please visit [http://www.mediawiki.org/wiki/Localisation MediaWiki Localisation] and [http://translatewiki.net Betawiki] if you wish to contribute to the generic MediaWiki localisation.',
 'allmessagesmodified' => 'Nur geänderte zoagn',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Neie Dateien',
 
 );
Index: languages/messages/MessagesNah.php
===================================================================
--- languages/messages/MessagesNah.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNah.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,5 +1,5 @@
 <?php
-/** Nahuatl (Nahuatl)
+/** Nahuatl (Nāhuatl)
  *
  * @ingroup Language
  * @file
@@ -7,9 +7,6 @@
  * @author Fluence
  * @author Ricardo gs
  * @author Rob Church <robchur@gmail.com>
- *
- * @copyright Copyright © 2006-2007, Rob Church, Fluence
- * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License 2.0 or later
  */
 
 # Per conversation with a user in IRC, we inherit from Spanish and work from there
@@ -17,30 +14,49 @@
 # understand Spanish if a Nah translation is not available
 $fallback = 'es';
 
+$specialPageAliases = array(
+	'Userlogin'               => array( 'Tlacalaquiliztli', 'Registrarse' ),
+	'Upload'                  => array( 'Quetza', 'Subir' ),
+	'Shortpages'              => array( 'Zāzaniltōn', 'PáginasCortas' ),
+	'Longpages'               => array( 'HuēiyacZāzaniltin', 'PáginasLargas' ),
+	'Newpages'                => array( 'YancuīcZāzaniltin', 'PáginasNuevas' ),
+	'Ancientpages'            => array( 'HuēhuehZāzaniltin', 'PáginasViejas' ),
+	'Allpages'                => array( 'MochīntīnZāzaniltin', 'TodasPáginas' ),
+	'Specialpages'            => array( 'NōncuahquīzquiĀmatl', 'PáginasEspeciales' ),
+	'Emailuser'               => array( 'EmailTlācatl', 'CorreoUsuario' ),
+	'Categories'              => array( 'Neneuhcāyōtl', 'Categorías' ),
+	'Mypage'                  => array( 'Nozāzanil', 'MiPágina' ),
+	'Mytalk'                  => array( 'Notēixnāmiquiliz', 'MiDiscusión' ),
+	'Mycontributions'         => array( 'Notlahcuilōl', 'MisContribuciones' ),
+	'Search'                  => array( 'Tlatēmōz', 'Buscar' ),
+);
+
 $messages = array(
 # User preference toggles
-'tog-hideminor'            => 'Xiquintlātīz tlapatlatzintli yancuīc tlapatlalizpan',
-'tog-watchcreations'       => 'Xiquinchiyāz zāzaniltin tiquinchīhua',
-'tog-watchdefault'         => 'Xiquinchiyāz zāzaniltin tiquimpatla',
-'tog-watchmoves'           => 'Xiquinchiyāz zāzaniltin tiquinzaca',
-'tog-watchdeletion'        => 'Xiquinchiyāz zāzaniltin tiquimpoloa',
+'tog-hideminor'            => 'Tiquintlātīz tlapatlatzintli yancuīc tlapatlalizpan',
+'tog-editondblclick'       => 'Tiquimpatlāz zāzaniltin ōme clicca (JavaScript)',
+'tog-showtoc'              => 'Tiquittāz in tlein cah zāzotlahcuilōlco',
+'tog-watchcreations'       => 'Tiquintlachiyāz zāzaniltin tiquinchīhua',
+'tog-watchdefault'         => 'Tiquintlachiyāz zāzaniltin tiquimpatla',
+'tog-watchmoves'           => 'Tiquintlachiyāz zāzaniltin tiquinzaca',
+'tog-watchdeletion'        => 'Tiquintlachiyāz zāzaniltin tiquimpoloa',
 'tog-minordefault'         => 'Ticmachiyōtīz mochīntīn tlapatlalitzintli ic default',
 'tog-previewontop'         => 'Tiquittāz achtochīhualiztli achtopa tlapatlaliztli caxitl',
-'tog-previewonfirst'       => 'Xiquittāz achtochīhualiztli inic cē tlapatlalizpan',
+'tog-previewonfirst'       => 'Xiquitta achtochīhualiztli inic cē tlapatlalizpan',
 'tog-enotifwatchlistpages' => 'Timitz-e-mailīzqueh ihcuāc mopatla cē zāzanilli tictlachiya.',
 'tog-enotifusertalkpages'  => 'Nēchihtoa ihcuāc tlecpatla motēixnāmiquiliz',
 'tog-enotifminoredits'     => 'Timitz-e-mailīzqueh nō zāzanilpatlatzintli ītechcopa',
 'tog-enotifrevealaddr'     => 'Ticnēxtīz mo e-mailcān āxcāncayōtechcopa āmatlacuilizpan',
-'tog-watchlisthideown'     => 'Xiquintlātīz mopatlaliz motlachiyalizpan',
-'tog-watchlisthidebots'    => 'Xiquintlātīz tepozpatlaliztli motlachiyalizpan',
-'tog-watchlisthideminor'   => 'Xiquintlātīz tlapatlalitzintli motlachiyalizpan',
+'tog-watchlisthideown'     => 'Tiquintlātīz mopatlaliz motlachiyalizpan',
+'tog-watchlisthidebots'    => 'Tiquintlātīz tepozpatlaliztli motlachiyalizpan',
+'tog-watchlisthideminor'   => 'Tiquintlātīz tlapatlalitzintli motlachiyalizpan',
 'tog-nolangconversion'     => 'Ahmo tictēquitiltia tlahtōlcuepaliztli',
-'tog-showhiddencats'       => 'Xiquittāz motlātiani neneuhcāyōtl',
+'tog-showhiddencats'       => 'Xiquitta motlātiani neneuhcāyōtl',
 
 'underline-always' => 'Mochipa',
 'underline-never'  => 'Aīcmah',
 
-'skinpreview' => '(Xiquittāz quemeh yez)',
+'skinpreview' => '(Xiquitta quemeh yez)',
 
 # Dates
 'sunday'        => 'Tōnatiuhtōnal',
@@ -77,7 +93,7 @@
 'june-gen'      => 'Tlachicuazti',
 'july-gen'      => 'Tlachicōnti',
 'august-gen'    => 'Tlachicuēiti',
-'september-gen' => 'Tlachīucnāuhti',
+'september-gen' => 'Tlachiucnāuhti',
 'october-gen'   => 'Tlamahtlācti',
 'november-gen'  => 'Tlamahtlāccēti',
 'december-gen'  => 'Tlamahtlācōnti',
@@ -100,8 +116,8 @@
 'subcategories'                  => 'Neneuhcāyōtzintli',
 'category-media-header'          => 'Media "$1" neneuhcāyōc',
 'category-empty'                 => "''Cah ahtlein inīn neneuhcāyōc.''",
-'hidden-categories'              => '{{PLURAL:$1|Motlātiani neneuhcāyōtl|Motlātiani neneuhcāyōtl}}',
-'hidden-category-category'       => 'Motlātiani neneuhcāyōtl', # Name of the category where hidden categories will be listed
+'hidden-categories'              => 'Neneuhcāyōtl {{PLURAL:$1|ōmotlāti|ōmotlātih}}',
+'hidden-category-category'       => 'Neneuhcāyōtl ōmotlāti', # Name of the category where hidden categories will be listed
 'category-subcat-count'          => '{{PLURAL:$2|Inīn neneuhcāyōtl zan quipiya|Inīn neneuhcāyōtl quimpiya {{PLURAL:$1|inīn neneuhcāyōtzintli|inīn $1 neneuhcāyōtzintli}}, īhuīcpa $2.}}',
 'category-subcat-count-limited'  => 'Inīn {{PLURAL:$1|neneuhcāyōtzintli cah|$1 neneuhcāyōtzintli cateh}} inīn neneuhcāyōc.',
 'category-article-count'         => '{{PLURAL:$2|Inīn neneuhcāyōtl zan quipiya|Inīn neneuhcāyōtl quimpiya {{PLURAL:$1|inīn zāzanilli|inīn $1 zāzanilli}}, īhuīcpa $2.}}',
@@ -114,36 +130,39 @@
 'article'        => 'tlahcuilōlli',
 'newwindow'      => '(Motlapoāz cē yancuīc tlanexillōtl)',
 'cancel'         => 'Ticcuepāz',
-'qbfind'         => 'Tlatēmoāz',
+'qbfind'         => 'Tlatēmōz',
 'qbedit'         => 'Ticpatlāz',
 'qbpageoptions'  => 'Inīn zāzanilli',
 'qbmyoptions'    => 'Nozāzanil',
 'qbspecialpages' => 'Nōncuahquīzqui āmatl',
 'moredotdotdot'  => 'Huehca ōmpa...',
-'mypage'         => 'Nozāzanilli',
+'mypage'         => 'Nozāzanil',
 'mytalk'         => 'Notēixnāmiquiliz',
 'anontalk'       => 'Inīn IP ītēixnāmiquiliz',
-'navigation'     => 'ācalpapanōliztli',
+'navigation'     => 'Ācalpapanōliztli',
 'and'            => 'īhuān',
 
 'errorpagetitle'    => 'Ahcuallōtl',
+'returnto'          => 'Timocuepāz īhuīc $1.',
 'tagline'           => 'Īhuīcpa {{SITENAME}}',
 'help'              => 'Tēpalēhuiliztli',
-'search'            => 'Tlatēmoāz',
-'searchbutton'      => 'Tlatēmoāz',
+'search'            => 'Tlatēmōz',
+'searchbutton'      => 'Tlatēmōz',
 'go'                => 'Yāuh',
 'searcharticle'     => 'Yāuh',
 'history'           => 'tlahcuilōlloh',
 'history_short'     => 'Tlahcuilōlloh',
 'info_short'        => 'Tlanōnōtzaliztli',
-'print'             => 'Tictepoztlahcuiloāz',
+'printableversion'  => 'Tepoztlahcuilōlli',
+'permalink'         => 'Mochipa tzonhuiliztli',
+'print'             => 'Tictepoztlahcuilōz',
 'edit'              => 'Ticpatlāz',
 'create'            => 'Ticchīhuāz',
 'editthispage'      => 'Ticpatlāz inīn zāzanilli',
 'create-this-page'  => 'Ticchīhuāz inīn zāzanilli',
 'delete'            => 'Ticpolōz',
 'deletethispage'    => 'Ticpolōz inīn zāzanilli',
-'undelete_short'    => 'Ahticpolōz $1 tlapatlaliztli',
+'undelete_short'    => 'Ahticpolōz {{PLURAL:$1|cē tlapatlaliztli|$1 tlapatlaliztli}}',
 'protect'           => 'Ticquīxtīz',
 'protect_change'    => 'ticpatlāz tlaquīxtiliztli',
 'protectthispage'   => 'Ticquīxtiāz inīn zāzanilli',
@@ -154,28 +173,32 @@
 'talkpagelinktext'  => 'Tēixnāmiquiliztli',
 'specialpage'       => 'Nōncuahquīzqui āmatl',
 'personaltools'     => 'In tlein nitēquitiltilia',
+'postcomment'       => 'Xiquihcuiloa cē tlanehnemiliztli',
 'articlepage'       => 'Xiquittaz in tlahcuilōlli',
 'talk'              => 'tēixnāmiquiliztli',
-'userpage'          => 'Xiquittāz tlatēquitiltilīlli zāzanilli',
-'projectpage'       => 'Xiquittāz tlachīhualiztli zāzanilli',
-'mediawikipage'     => 'Xiquittāz tlahcuilōltzin zāzanilli',
-'templatepage'      => 'Xiquittāz nemachiyōtīlli zāzanilli',
-'viewhelppage'      => 'Xiquittāz tēpalehuiliztli zāzanilli',
-'categorypage'      => 'Xiquittāz neneuhcāyōtl zāzanilli',
-'viewtalkpage'      => 'Xiquittāz tēixnāmiquiliztli zāzanilli',
+'toolbox'           => 'In tlein motequitiltia',
+'userpage'          => 'Xiquitta tlatequitiltilīlli zāzanilli',
+'projectpage'       => 'Xiquitta tlachīhualiztli zāzanilli',
+'imagepage'         => 'Xiquitta īxiptli zāzanilli',
+'mediawikipage'     => 'Xiquitta tlahcuilōltzin zāzanilli',
+'templatepage'      => 'Tiquittāz nemachiyōtīlli zāzanilli',
+'viewhelppage'      => 'Xiquitta tēpalēhuiliztli zāzanilli',
+'categorypage'      => 'Xiquitta neneuhcāyōtl zāzanilli',
+'viewtalkpage'      => 'Xiquitta tēixnāmiquiliztli zāzanilli',
 'otherlanguages'    => 'Occequīntīn tlahtōlcopa',
 'redirectedfrom'    => '(Ōmotlacuep īhuīcpa $1)',
 'redirectpagesub'   => 'Ōmotlacuep zāzanilli',
 'lastmodifiedat'    => 'Inīn zāzanilli ōtlapatlac catca īpan $2, $1.', # $1 date, $2 time
-'viewcount'         => 'Inīn zāzanilli quintlahpōhua $1 tlahpololiztli.',
+'viewcount'         => 'Inīn zāzanilli quintlapōhua {{PLURAL:$1|cē tlahpololiztli|$1 tlahpololiztli}}.',
 'protectedpage'     => 'Ōmoquīxtix zāzanilli',
 'jumptonavigation'  => 'ācalpapanōliztli',
-'jumptosearch'      => 'tlatēmoāz',
+'jumptosearch'      => 'tlatēmoliztli',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Ītechcopa {{SITENAME}}',
 'aboutpage'            => 'Project:Ītechcopa',
 'copyright'            => 'Tlahcuilōltzin cah yōllōxoxouhqui īpan $1',
+'copyrightpagename'    => '{{SITENAME}} copyright',
 'currentevents'        => 'Āxcāncāyōtl',
 'currentevents-url'    => 'Project:Āxcāncāyōtl',
 'disclaimers'          => 'Nahuatīllahtōl',
@@ -183,6 +206,7 @@
 'edithelppage'         => 'Help:¿Quēn motlahcuiloa cē zāzanilli?',
 'faq'                  => 'FAQ',
 'faqpage'              => 'Project:FAQ',
+'helppage'             => 'Help:Tlapiyaliztli',
 'mainpage'             => 'Calīxatl',
 'mainpage-description' => 'Calīxatl',
 'portal'               => 'Calīxcuātl tocalpōl',
@@ -190,9 +214,9 @@
 'privacy'              => 'Tlahcuilōlli piyaliznahuatīlli',
 
 'badaccess-group0' => 'Tehhuātl ahmo tiquichīhua inōn tiquiēlēhuia.',
-'badaccess-group1' => 'Inōn tiquiēlēhuia zan quichīhuah tlatēquitiltilīlli oncān: $1.',
-'badaccess-group2' => 'Inōn tiquiēlēhuia zan quichīhuah tlatēquitiltilīlli oncān: $1.',
-'badaccess-groups' => 'Inōn tiquiēlēhuia zan quichīhuah tlatēquitiltilīlli oncān: $1.',
+'badaccess-group1' => 'Inōn tiquiēlēhuia zan quichīhuah tlatequitiltilīlli oncān: $1.',
+'badaccess-group2' => 'Inōn tiquiēlēhuia zan quichīhuah tlatequitiltilīlli oncān: $1.',
+'badaccess-groups' => 'Inōn tiquiēlēhuia zan quichīhuah tlatequitiltilīlli oncān: $1.',
 
 'ok'                      => 'Cualli',
 'youhavenewmessages'      => 'Tiquimpiya $1 ($2).',
@@ -201,11 +225,14 @@
 'youhavenewmessagesmulti' => 'Tiquimpiya yancuīc tlahcuilōlli īpan $1',
 'editsection'             => 'ticpatlāz',
 'editold'                 => 'ticpatlāz',
-'viewsourceold'           => 'xiquittāz tlahtōlcaquiliztilōni',
+'viewsourceold'           => 'xiquitta tlahtōlcaquiliztilōni',
+'editsectionhint'         => 'Ticpatlahua: $1',
 'toc'                     => 'Inīn tlahcuilōlco',
-'showtoc'                 => 'xiquittāz',
-'hidetoc'                 => 'xictlātīz',
+'showtoc'                 => 'xiquitta',
+'hidetoc'                 => 'tictlātīz',
+'thisisdeleted'           => '¿Tiquittāz nozo ahticpolōz $1?',
 'viewdeleted'             => '¿Tiquiēlēhuia tiquitta $1?',
+'restorelink'             => '{{PLURAL:$1|cē tlapatlaliztli polotic|$1 tlapatlaliztli polotic}}',
 'site-rss-feed'           => '$1 RSS huelītiliztli',
 'site-atom-feed'          => '$1 Atom huelītiliztli',
 'page-rss-feed'           => '"$1" RSS huelītiliztli',
@@ -214,166 +241,354 @@
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Tlahcuilōlli',
-'nstab-user'      => 'Tlatēquitiltilīlli',
+'nstab-user'      => 'Tlatequitiltilīlli',
+'nstab-media'     => 'Mēdiatl',
 'nstab-special'   => 'Nōncuahquīzqui',
+'nstab-project'   => 'Tlachīhualiztli zāzanilli',
 'nstab-image'     => 'Īxiptli',
 'nstab-mediawiki' => 'Tlahcuilōltzintli',
 'nstab-template'  => 'Nemachiyōtīlli',
 'nstab-help'      => 'Tēpalēhuiliztli',
 'nstab-category'  => 'Neneuhcāyōtl',
 
+# Main script and global functions
+'nosuchaction'      => 'Ahmo ia tlachīhualiztli',
+'nosuchspecialpage' => 'Ahmelāhuac nōncuahquīzqui zāzanilli',
+
 # General errors
 'error'               => 'Ahcuallōtl',
+'missingarticle-diff' => '(Ahneneuh.: $1, $2)',
 'filecopyerror'       => 'Ahmo ōmohuelītic tlacopīna "$1" īhuīc "$2".',
 'filerenameerror'     => 'Ahmo ōmohuelītic tlazaca "$1" īhuīc "$2".',
 'filedeleteerror'     => 'Ahmo ōmohuelītic tlapoloa "$1".',
 'filenotfound'        => 'Ahmo ōmohuelītic tlanāmiqui "$1".',
+'fileexistserror'     => 'Ahmo ōmohuelītih tlahcuiloa "$1" tlahcuilōlhuīc: tlahcuilōlli ia',
 'badtitle'            => 'Ahcualli tōcāitl',
-'viewsource'          => 'Xiquittāz tlahtōlcaquiliztilōni',
+'viewsource'          => 'Tiquittāz tlahtōlcaquiliztilōni',
+'viewsourcefor'       => '$1 ītechcopa',
+'actionthrottled'     => 'Tlachīhualiztli ōmotzacuili',
+'viewsourcetext'      => 'Tihuelīti tiquitta auh ticcopīna inīn zāzanilli ītlahtōlcaquiliztilōni:',
+'sqlhidden'           => '(Tlatēmoliztli SQL omotlāti)',
 'namespaceprotected'  => "Ahmo tiquihuelīti tiquimpatla zāzaniltin īpan '''$1'''.",
 'ns-specialprotected' => 'Ahmohuelīti quimpatla nōncuahquīzqui zāzaniltin.',
 
 # Login and logout pages
-'logouttitle'             => 'Tiquīzāz',
-'loginpagetitle'          => 'Ximomachiyōmaca/Ximocalaqui',
-'yourname'                => 'Motlatēquitiltilīltōcā:',
-'yourpassword'            => 'Tlahtolichtacayo',
-'yourpasswordagain'       => 'Tlahtolichtacayo zapa',
-'yourdomainname'          => 'Moāxcāyō',
-'login'                   => 'Ximomachiyōmaca/Ximocalaqui',
-'nav-login-createaccount' => 'Ximocalaqui / ximomachiyōmaca',
-'userlogin'               => 'Ximomachiyōmaca/Ximocalaqui',
-'logout'                  => 'Tiquīzāz',
-'userlogout'              => 'Tiquīzāz',
-'nologin'                 => '¿Ahmo tiquipiya calaquiliztli? $1.',
-'gotaccountlink'          => 'Ximocalaqui',
-'createaccountmail'       => 'e-mailcopa',
-'youremail'               => 'E-mail:',
-'username'                => 'Tlatēquitiltilīltōcāitl:',
-'uid'                     => 'Tlatēquitiltilīlli ID:',
-'yourrealname'            => 'Melāhuac motōcā:',
-'yourlanguage'            => 'Motlahtōl:',
-'yournick'                => 'Motōcātlaliz:',
-'badsiglength'            => 'Motōcātlaliz cah achi huēiyac.
-Ahmo huīquilia quimpiya achi $1 tlahtōl.',
-'email'                   => 'E-mail',
-'loginerror'              => 'Ahcuallōtl tlacalaquiliztechcopa',
-'loginsuccesstitle'       => 'Cualli ōticalac',
-'loginsuccess'            => "'''Ōticalac {{SITENAME}} quemeh \"\$1\".'''",
-'emailconfirmlink'        => 'Ticchicāhua mo e-mail',
-'loginlanguagelabel'      => 'Tlahtōlli: $1',
+'logouttitle'               => 'Ōtiquīz',
+'loginpagetitle'            => 'Ximomachiyōmaca/Ximocalaqui',
+'yourname'                  => 'Motlatequitiltilīltōcā:',
+'yourpassword'              => 'Tlahtolichtacayo',
+'yourpasswordagain'         => 'Tlahtolichtacayo zapa',
+'yourdomainname'            => 'Moāxcāyō',
+'login'                     => 'Ximomachiyōmaca/Ximocalaqui',
+'nav-login-createaccount'   => 'Ximocalaqui / ximomachiyōmaca',
+'userlogin'                 => 'Ximomachiyōmaca/Ximocalaqui',
+'logout'                    => 'Tiquīzāz',
+'userlogout'                => 'Tiquīzāz',
+'notloggedin'               => 'Ahmo ōtimocalac',
+'nologin'                   => '¿Ahmo tiquipiya calaquiliztli? $1.',
+'gotaccountlink'            => 'Ximocalaqui',
+'createaccountmail'         => 'e-mailcopa',
+'youremail'                 => 'E-mail:',
+'username'                  => 'Tlatequitiltilīltōcāitl:',
+'uid'                       => 'Tlatequitiltilīlli ID:',
+'prefs-memberingroups'      => 'Tlācatl {{PLURAL:$1|olōlco|olōlco}}:',
+'yourrealname'              => 'Melāhuac motōcā:',
+'yourlanguage'              => 'Motlahtōl:',
+'yournick'                  => 'Motōcātlaliz:',
+'badsiglength'              => 'Motōcātlaliz cah achi huēiyac.
+Ahmo huīquilia quimpiya achi $1 {{PLURAL:$1|tlahtōl|tlahtōltin}}.',
+'email'                     => 'E-mail',
+'loginerror'                => 'Ahcuallōtl tlacalaquiliztechcopa',
+'prefs-help-email-required' => 'Tihuīquilia quihcuiloa mo e-mailcān.',
+'noname'                    => 'Ahmo ōtiquihto cualli tlatequitiltilīlli tōcāitl.',
+'loginsuccesstitle'         => 'Cualli calaquiliztli',
+'loginsuccess'              => "'''Ōticalac {{SITENAME}} quemeh \"\$1\".'''",
+'nosuchusershort'           => 'Ahmo cah tlatequitiltilīlli ītōcā "<nowiki>$1</nowiki>". 
+Xiquimpiya motlahtōl.',
+'emailconfirmlink'          => 'Ticchicāhua mo e-mail',
+'loginlanguagelabel'        => 'Tlahtōlli: $1',
 
 # Edit page toolbar
 'bold_sample'    => 'Tlīltic tlahcuilōlli',
 'bold_tip'       => 'Tlīltic tlahcuilōlli',
 'italic_sample'  => 'Italic tlahcuilōlli',
 'italic_tip'     => 'Italic tlahcuilōlli',
+'link_sample'    => 'Tzonhuiliztli ītōcā',
+'link_tip'       => 'Tzonhuiliztli tlahtic',
 'extlink_sample' => 'http://www.tlamantli.com Tōcāitl',
+'extlink_tip'    => 'Tzonhuilizcallān (xitequitiltia http://)',
+'headline_tip'   => 'Iuhcāyōtl 2 tōcāyōtl',
+'math_sample'    => 'Xihcuiloa nicān',
 'math_tip'       => 'Tlapōhualmatiliztlahtōl (LaTeX)',
+'media_tip'      => 'Mēdiahuīc tzonhuiliztli',
+'sig_tip'        => 'Motōcā īca cāhuitl',
 
 # Edit pages
-'summary'            => 'Mopatlaliz',
-'minoredit'          => 'Inīn cah tlapatlalitzintli',
-'watchthis'          => 'Titlachiyāz inīn zāzanilli',
-'savearticle'        => 'Ticpiyāz',
-'preview'            => 'Xiquittāz achtochīhualiztli',
-'showpreview'        => 'Xiquittāz achtochīhualiztli',
-'showlivepreview'    => 'Niman achtochīhualiztli',
-'showdiff'           => 'Xiquittāz tlapatlaliztli',
-'blockedtitle'       => 'Ōmotzacuili tlatēquitiltilīlli',
-'blockednoreason'    => 'ahmo cah īxtlamatiliztli',
-'whitelistedittitle' => 'Tihuīquilia timocalaqui ic patla',
-'whitelistedittext'  => 'Tihuīquilia $1 ic ticpatla zāzaniltin.',
-'whitelistreadtitle' => 'Tihuīquilia timocalaqui ic āmaxpōhua',
-'loginreqtitle'      => 'Ximocalaqui',
-'loginreqlink'       => 'ximocalaqui',
-'newarticle'         => '(Yancuīc)',
-'newarticletext'     => 'Ōtictocac cētiliztli cē zāzanilhuīc oc ahmo ia. Intlā quiēlēhuia quichīhua, xitlahcuiloa niman (nō xiquitta [[{{MediaWiki:Helppage}}|tēpalēhuiliztli zāzanilli]] huehca ōmpa tlapatlaliztli). Intlā ahmo, yāuh achtopa zāzanilli.',
-'noarticletext'      => 'Āxcān, in ahmō cateh tlahtōl inīn zāzanilpan. Tihuelīti tictēmoa [[Special:Search/{{PAGENAME}}|inīn zāzaniltōcācopa]] occequīntīn zāzanilpan nozo [{{fullurl:{{FULLPAGENAME}}|action=edit}} quipatla inīn zāzanilli].',
-'previewnote'        => '<strong>¡Ca inīn moachtochīhualiz, auh mopatlaliz ahmō cateh ōmochīhuah nozan!</strong>',
-'editing'            => 'Ticpatlahua $1',
-'editingsection'     => 'Ticpatlahua $1 (tlahtōltzintli)',
-'yourtext'           => 'Motlahcuilōl',
-'copyrightwarning'   => '<small>Timitztlātlauhtiah xiquitta mochi mopatlaliz cana {{SITENAME}} tlatzayāna īpan $2 (huēhca ōmpa xiquitta $1). Āqueh tlācah quipatlazqueh in motlahcuilōl auh tlatzayāna occeppa; intlā ahmō ticnequi, zātēpan ahmō titlahcuilōz nicān. Nō mitzihtoah in ōtitlahcuiloh ahmō quipiya in copyright nozo in yōllōxoxouhqui tlahcuilōlli. <strong>¡AHMŌ XITĒQUITILTIA AHYŌLLŌXOXOUHQUI TLAHCUILŌLLI!</strong></small>',
-'templatesused'      => 'Nemachiyōtīlli inīn zāzanilpan:',
+'summary'                          => 'Mopatlaliz',
+'minoredit'                        => 'Inīn cah tlapatlalitzintli',
+'watchthis'                        => 'Tictlachiyāz inīn zāzanilli',
+'savearticle'                      => 'Ticpiyāz',
+'preview'                          => 'Xiquitta achtochīhualiztli',
+'showpreview'                      => 'Xiquitta achtochīhualiztli',
+'showlivepreview'                  => 'Niman achtochīhualiztli',
+'showdiff'                         => 'Tiquinttāz tlapatlaliztli',
+'summary-preview'                  => 'Tlahcuilōltōn achtochīhualiztli',
+'blockedtitle'                     => 'Ōmotzacuili tlatequitiltilīlli',
+'blockednoreason'                  => 'ahmo cah īxtlamatiliztli',
+'blockedoriginalsource'            => "Nicān motta '''$1''' ītlahtōlcaquiliztilōni:",
+'blockededitsource'                => "'''Mopatlaliz''' ītlahtōl īpan '''$1''' motta nicān:",
+'whitelistedittitle'               => 'Tihuīquilia timocalaqui ic patla',
+'whitelistedittext'                => 'Tihuīquilia $1 ic ticpatla zāzaniltin.',
+'confirmedittitle'                 => 'E-mail chicāhualiztli moēlēhuia ic ticpatla',
+'loginreqtitle'                    => 'Ximocalaqui',
+'loginreqlink'                     => 'ximocalaqui',
+'loginreqpagetext'                 => 'Tihuīquilia $1 ic tiquintta occequīntīn zāzaniltin.',
+'newarticle'                       => '(Yancuīc)',
+'newarticletext'                   => 'Ōtictocac cētiliztli cē zāzanilhuīc oc ahmo ia. Intlā quiēlēhuia quichīhua, xitlahcuiloa niman (nō xiquitta [[{{MediaWiki:Helppage}}|tēpalēhuiliztli zāzanilli]] huehca ōmpa tlapatlaliztli). Intlā ahmo, yāuh achtopa zāzanilli.',
+'noarticletext'                    => 'Āxcān, in ahmō cateh tlahtōl inīn zāzanilpan. Tihuelīti tictēmoa [[Special:Search/{{PAGENAME}}|inīn zāzaniltōcācopa]] occequīntīn zāzanilpan nozo [{{fullurl:{{FULLPAGENAME}}|action=edit}} quipatla inīn zāzanilli].',
+'updated'                          => '(Ōmoyancuīli)',
+'previewnote'                      => '<strong>¡Ca inīn moachtochīhualiz, auh mopatlaliz ahmō cateh ōmochīhuah nozan!</strong>',
+'editing'                          => 'Ticpatlahua $1',
+'editingsection'                   => 'Ticpatlahua $1 (tlahtōltzintli)',
+'yourtext'                         => 'Motlahcuilōl',
+'yourdiff'                         => 'Ahneneuhquiliztli',
+'copyrightwarning'                 => '<small>Timitztlātlauhtiah xiquitta mochi mopatlaliz cana {{SITENAME}} tlatzayāna īpan $2 (huēhca ōmpa xiquitta $1). Āqueh tlācah quipatlazqueh in motlahcuilōl auh tlatzayāna occeppa; intlā ahmō ticnequi, zātēpan ahmō titlahcuilōz nicān. Nō mitzihtoah in ōtitlahcuiloh ahmō quipiya in copyright nozo in yōllōxoxouhqui tlahcuilōlli. <strong>¡AHMŌ XITĒQUITILTIA AHYŌLLŌXOXOUHQUI TLAHCUILŌLLI!</strong></small>',
+'copyrightwarning2'                => '<small>Āqueh tlācah quipatlazqueh in motlahcuilōl auh tlatzayāna occeppa; intlā ahmō ticnequi, zātēpan ahmō titlahcuilōz nicān {{SITENAME}}. Nō mitzihtoah in ōtitlahcuiloh ahmō quipiya in copyright nozo in yōllōxoxouhqui tlahcuilōlli (huēhca ōmpa xiquitta $1). <strong>¡AHMŌ TIQUINTEQUITILTIA AHYŌLLŌXOXOUHQUI TLAHCUILŌLLI!</strong></small>',
+'longpageerror'                    => '<strong>AHCUALLŌTL: Motlahcuilōl cah huēiyac $1 KB, huehca ōmpa $2 KB. Ahmo mopiyāz.</strong>',
+'templatesused'                    => 'Nemachiyōtīlli inīn zāzanilpan:',
+'templatesusedpreview'             => 'Nemachiyōtīlli motequitiltia inīn achtochīhualizpan:',
+'templatesusedsection'             => 'Nemachiyōtīlli motequitiltia nicān:',
+'template-protected'               => '(ōmoquīxti)',
+'hiddencategories'                 => 'Inīn zāzanilli mopiya {{PLURAL:$1|1 neneuhcāyōc ōmotlāti|$1 neneuhcāyōc ōmotlāti}}:',
+'nocreate-loggedin'                => 'Ahmo tihuelīti tiquinchīhua yancuīc zāzaniltin īpan {{SITENAME}}.',
+'permissionserrors'                => 'Huelītiliztechcopa ahcuallōtl',
+'permissionserrorstext'            => 'Ahmo tihuelīti quichīhua inōn, inīn {{PLURAL:$1|īxtlamatilizpampa|īxtlamatilizpampa}}:',
+'permissionserrorstext-withaction' => 'Ahmo tiquihuelīti $2 inīn {{PLURAL:$1|īxtlamatilizpampa|īxtlamatilizpampa}}:',
 
 # History pages
+'viewpagelogs'        => 'Tiquinttāz tlahcuilōlloh inīn zāzaniltechcopa',
+'nohistory'           => 'Ahmo cah tlapatlaliztechcopa tlahcuilōlloh inīn zāzaniltechcopa.',
+'revnotfound'         => 'Ahmo ōmonēxti tlachiyaliztli',
 'currentrev'          => 'Āxcān tlapatlaliztli',
+'revisionasof'        => 'Tlachiyaliztli īpan $1',
+'revision-info'       => 'Tlachiyaliztli īpan $1; $2',
 'previousrevision'    => '← Huēhueh tlapatlaliztli',
 'nextrevision'        => 'Yancuīc tlapatlaliztli →',
 'currentrevisionlink' => 'Āxcān tlapatlaliztli',
+'cur'                 => 'āxcān',
 'next'                => 'niman',
 'last'                => 'xōcoyōc',
 'page_first'          => 'achto',
 'page_last'           => 'xōcoyōc',
+'deletedrev'          => '[ōmopolo]',
+'histfirst'           => 'Achto',
+'histlast'            => 'Yancuīc',
+'historysize'         => '({{PLURAL:$1|1 byte|$1 bytes}})',
+'historyempty'        => '(iztāc)',
 
 # Revision feed
-'history-feed-empty' => 'In zāzanilli tiquiēlēhuia ahmo ia.
+'history-feed-title'          => 'Tlachiyaliztli tlahcuilōlloh',
+'history-feed-description'    => 'Tlachiyaliztli tlahcuilōlloh inīn zāzaniltechcopa huiquipan',
+'history-feed-item-nocomment' => '$1 īpan $2', # user at time
+'history-feed-empty'          => 'In zāzanilli tiquiēlēhuia ahmo ia.
 Hueliz ōmopolo huiqui nozo ōmozacac.
 [[Special:Search|Xitēmoa huiquipan]] yancuīc huēyi zāzaniltin.',
 
 # Revision deletion
-'rev-delundel'    => 'xiquittāz/xictlātīz',
-'pagehist'        => 'Zāzanilli tlahcuilōlloh',
-'deletedhist'     => 'Ōtlapolo tlahcuilōlloh',
-'revdelete-uname' => 'tlatēquitiltilīltōcāitl',
-'revdelete-hid'   => 'xictlātīz $1',
+'rev-delundel'         => 'tiquittāz/tictlātīz',
+'revdelete-selected'   => '{{PLURAL:$2|Tlachiyaliztli ōmoēlēhui|Tlachiyaliztli ōmoēlēhuih}} [[:$1]] ītechcopa:',
+'revdelete-hide-text'  => 'Tictlātīz tlachiyaliztli ītlahcuilōl',
+'revdelete-hide-image' => 'Tictlātīz tlahcuilōlli ītlapiyaliz',
+'pagehist'             => 'Zāzanilli tlahcuilōlloh',
+'deletedhist'          => 'Ōtlapolo tlahcuilōlloh',
+'revdelete-content'    => 'tlapiyaliztli',
+'revdelete-summary'    => 'ticpatlāz tlahcuilōltōn',
+'revdelete-uname'      => 'tlatēquitiltilīltōcāitl',
+'revdelete-hid'        => 'xictlātia $1',
+'revdelete-unhid'      => 'tiquittāz $1',
 
+# History merging
+'mergehistory-from'           => 'Zāzanilhuīcpa:',
+'mergehistory-into'           => 'Zāzanilhuīc:',
+'mergehistory-no-source'      => 'Zāzanilhuīcpa $1 ahmo ia.',
+'mergehistory-no-destination' => 'Zāzanilhuīc $1 ahmo ia.',
+'mergehistory-autocomment'    => 'Ōmocēntili [[:$1]] īpan [[:$2]]',
+'mergehistory-comment'        => 'Ōmocēntili [[:$1]] īpan [[:$2]]: $3',
+
+# Diffs
+'difference' => '(Ahneneuhquiliztli tlapatlaliznepantlah)',
+'editundo'   => 'ahticchīhuāz',
+
 # Search results
-'searchsubtitle'        => "Ōtictēmōz '''[[:$1]]'''",
-'searchsubtitleinvalid' => "Ōtictēmōz '''$1'''",
-'noexactmatch-nocreate' => "'''Ahmo ia \"\$1\" zāzanilli.'''",
-'prevn'                 => '$1 achtopa',
-'searchall'             => 'mochīntīn',
+'searchresults'            => 'Tlatēmoliztli',
+'searchsubtitle'           => 'Ōtictēmōz \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|mochīntīn zāzaniltin mopēhua īca "$1"]] | [[Special:WhatLinksHere/$1|mochīntīn zāzaniltin tzonhuilia "$1" īhuīc]])',
+'searchsubtitleinvalid'    => "Ōtictēmōz '''$1'''",
+'noexactmatch'             => "'''Ahmo ia zāzanilli ītōcā \"\$1\".''' Tihuelīti [[:\$1|ticchīhua]].",
+'noexactmatch-nocreate'    => "'''Ahmo ia \"\$1\" zāzanilli.'''",
+'prevn'                    => '$1 achtopa',
+'nextn'                    => 'niman $1',
+'viewprevnext'             => 'Xiquintta ($1) ($2) ($3).',
+'search-redirect'          => '(tlacuepaliztli $1)',
+'search-suggest'           => 'Mohtoa ahnozo: $1',
+'search-interwiki-caption' => 'Tlachīhualiztli īcnīhuān',
+'search-interwiki-more'    => '(huehca ōmpa)',
+'search-relatedarticle'    => 'Ītechcopa',
+'searchrelated'            => 'ītechcopa',
+'searchall'                => 'mochīntīn',
+'powersearch'              => 'Chicāhuac tlatēmoliztli',
+'powersearch-legend'       => 'Chicāhuac tlatēmoliztli',
+'powersearch-ns'           => 'Tlatēmōz tōcātzimpan:',
+'powersearch-redir'        => 'Quimpiya tlacuepaliztli',
+'powersearch-field'        => 'Tlatēmōz',
+'search-external'          => 'Tlatēmotiliztli calāmpa',
 
 # Preferences page
-'saveprefs'         => 'Ticpiyāz',
-'textboxsize'       => 'Tlapatlaliztli',
-'searchresultshead' => 'Tlatēmoliztli',
+'preferences'           => 'Tlaēlēhuiliztli',
+'mypreferences'         => 'Notlaēlēhuiliz',
+'prefs-edits'           => 'Tlapatlaliztli tlapōhualli:',
+'prefsnologin'          => 'Ahmo ōtimocalac',
+'qbsettings-none'       => 'Ahtlein',
+'math'                  => 'Tlapōhualmatiliztli',
+'dateformat'            => 'Cāuhtiliztli iuhcāyōtl',
+'datetime'              => 'Cāuhtiliztli īhuān cāhuitl',
+'prefs-watchlist'       => 'Tlachiyaliztli',
+'prefs-watchlist-days'  => 'Tōnaltin tiquinttāz tlachiyalizpan:',
+'prefs-watchlist-edits' => 'Tlapatlaliztli tiquintta tlachiyalizpan:',
+'prefs-misc'            => 'Zāzo',
+'saveprefs'             => 'Ticpiyāz',
+'textboxsize'           => 'Tlapatlaliztli',
+'rows'                  => 'Pāntli:',
+'searchresultshead'     => 'Tlatēmoliztli',
+'localtime'             => 'Cāhuitl nicān',
+'prefs-searchoptions'   => 'Tlatēmoliztli tlaēlēhuiliztli',
+'prefs-namespaces'      => 'Tōcātzin',
+'defaultns'             => 'Tlatēmōz inīn tōcātzimpan ic default:',
+'default'               => 'ic default',
+'files'                 => 'Tlahcuilōlli',
 
+# User rights
+'userrights-user-editname' => 'Xihcuiloa cē tlatequitiltilīltōcāitl:',
+'editusergroup'            => 'Tiquimpatlāz tlatequitiltilīlli olōlli',
+'userrights-editusergroup' => 'Tiquimpatlāz tlatequitiltilīlli olōlli',
+'saveusergroups'           => 'Tiquimpiyāz tlatequitiltilīlli olōlli',
+'userrights-groupsmember'  => 'Olōlco:',
+'userrights-reason'        => 'Tlapatlaliztli īxtlamatiliztli:',
+'userrights-no-interwiki'  => 'Ahmo tihuelīti ticpatla tlatequitiltilīlli huelītiliztli occequīntīn huiquipan.',
+
 # Groups
-'group'     => 'Olōlli:',
-'group-all' => '(mochīntīn)',
+'group'       => 'Olōlli:',
+'group-user'  => 'Tlatequitiltilīlli',
+'group-bot'   => 'Tepoztlācah',
+'group-sysop' => 'Tlahcuilōlpixqueh',
+'group-all'   => '(mochīntīn)',
 
+'group-user-member'  => 'Tlatequitiltilīlli',
+'group-bot-member'   => 'Tepoztlācatl',
+'group-sysop-member' => 'Tlahcuilōlpixqui',
+
+'grouppage-user'  => '{{ns:project}}:Tlatequitiltilīlli',
+'grouppage-bot'   => '{{ns:project}}:Tepoztlācah',
+'grouppage-sysop' => '{{ns:project}}:Tlahcuilōlpixqueh',
+
+# Rights
+'right-read'                 => 'Tiquimpōhuāz zāzaniltin',
+'right-edit'                 => 'Tiquimpatlāz zāzaniltin',
+'right-createpage'           => 'Ticchīhuāz zāzaniltin (ahmo tēixnāmiquiliztli zāzaniltin)',
+'right-createtalk'           => 'Ticchīhuāz tēixnāmiquiliztli zāzaniltin',
+'right-minoredit'            => 'Ticpatlāz quemeh tlapatlalitzintli',
+'right-move'                 => 'Tiquinzacāz zāzaniltin',
+'right-move-subpages'        => 'Tiquinzacāz zāzaniltin auh īzāzaniltōn',
+'right-suppressredirect'     => 'Ahmo ticchīhuāz tlacuepaliztli huēhueh tōcāhuīc ihcuāc ticzacāz cē zāzanilli',
+'right-upload'               => 'Tiquinquetzāz tlahcuilōlli',
+'right-delete'               => 'Tiquimpolōz zāzaniltin',
+'right-bigdelete'            => 'Tiquimpolōz zāzaniltin īca huēiyac tlahcuilōlloh',
+'right-browsearchive'        => 'Tlatēmōz zāzaniltin ōmopoloh',
+'right-undelete'             => 'Ahticpolōz cē zāzanilli',
+'right-block'                => 'Tiquintzacuilīz occequīntīn tlatequitiltilīlli',
+'right-import'               => 'Ticcōhuāz zāzaniltin occequīntīn huiquihuīcpa',
+'right-importupload'         => 'Tiquincōhuāz zāzaniltin tlahcuilōlquetzalizhuīcpa',
+'right-userrights'           => 'Tiquimpatlāz mochīntīn tlatequitiltilīlli huelītiliztli',
+'right-userrights-interwiki' => 'Tiquimpatlāz tlatequitiltilīlli huelītiliztli occequīntīn huiquipan',
+
+# User rights log
+'rightslog'  => 'Tlatequitiltilīlli huelītiliztli tlahcuilōlloh',
+'rightsnone' => 'ahtlein',
+
 # Recent changes
+'nchanges'          => '$1 {{PLURAL:$1|tlapatlaliztli|tlapatlaliztli}}',
 'recentchanges'     => 'Yancuīc patlaliztli',
 'recentchangestext' => 'Xiquitta in achi yancuīc patlaliztli huiquipan inīn zāzanilpan.',
 'rcnote'            => "Nicān {{PLURAL:$1|cah '''1''' tlapatlaliaztli|cateh in xōcoyōc '''$1''' tlapatlaliztli}} īpan xōcoyōc {{PLURAL:$2|tōnalli|'''$2''' tōnaltin}} īhuīcpa $5, $4.",
 'rclistfrom'        => 'Xiquittaz yancuīc patlaliztli īhuīcpa $1',
-'rcshowhidebots'    => '$1 tepoztlatēquitiltilīlli',
-'rclinks'           => 'Xiquittaz xōcoyōc $1 patlaliztli xōcoyōc $2 tōnalpan.<br />$3',
-'hide'              => 'Xictlātīz',
-'show'              => 'Xiquittāz',
+'rcshowhideminor'   => '$1 tlapatlalitzintli',
+'rcshowhidebots'    => '$1 tepoztlācah',
+'rcshowhideliu'     => '$1 tlatequitiltilīlli ōmocalacqueh',
+'rcshowhideanons'   => '$1 ahtōcā tlatequitiltilīlli',
+'rcshowhidemine'    => '$1 notlahcuilōl',
+'rclinks'           => 'Xiquintta xōcoyōc $1 tlapatlaliztli xōcoyōc $2 tōnalpan.<br />$3',
+'diff'              => 'ahneneuh',
+'hist'              => 'tlahcuil',
+'hide'              => 'Tiquintlātīz',
+'show'              => 'Tiquinttāz',
+'minoreditletter'   => 'p',
 'newpageletter'     => 'Y',
+'boteditletter'     => 'T',
+'rc_categories_any' => 'Zāzo',
+'newsectionsummary' => 'Yancuīc tlahtōltzintli: /* $1 */',
 
 # Recent changes linked
+'recentchangeslinked'       => 'Tlapatlaliztli tzonhuilizpan',
 'recentchangeslinked-title' => 'Tlapatlaliztli "$1" ītechcopa',
 'recentchangeslinked-page'  => 'Zāzanilli ītōcā:',
 
 # Upload
-'upload'           => 'Tlahcuilōlquetza',
-'uploadbtn'        => 'Tlahcuilōlquetza',
-'reupload'         => 'Tiquiquetzāz occeppa',
-'minlength1'       => 'Tlahcuilōltōcāitl quihuīlquilia huehca ōmpa cē tlahtōl.',
-'successfulupload' => 'Cualli quetzaliztli',
-'savefile'         => 'Quipiyāz tlahcuilōlli',
-'sourcefilename'   => 'Tōcāhuīcpa:',
-'destfilename'     => 'Tōcāhuīc:',
-'watchthisupload'  => 'Titlachiyāz inīn zāzanilli',
+'upload'                 => 'Tlahcuilōlquetza',
+'uploadbtn'              => 'Tlahcuilōlquetza',
+'reupload'               => 'Tiquiquetzāz occeppa',
+'uploadnologin'          => 'Ahmo ōtimocalac',
+'uploaderror'            => 'Tlaquetzaliztli ahcuallōtl',
+'uploadlog'              => 'tlaquetzaliztli tlahcuilōlloh',
+'uploadlogpage'          => 'Tlaquetzaliztli tlahcuilōlloh',
+'filename'               => 'Tlahcuilōlli ītōcā',
+'filedesc'               => 'Tlahcuilōltōn',
+'fileuploadsummary'      => 'Tlahcuilōltōn:',
+'filestatus'             => 'Copyright:',
+'filesource'             => 'Īhuīcpa:',
+'uploadedfiles'          => 'Tlahcuilōlli ōmoquetz',
+'minlength1'             => 'Tlahcuilōltōcāitl quihuīlquilia huehca ōmpa cē tlahtōl.',
+'badfilename'            => 'Īxiptli ītōcā ōmopatlac īhuīc "$1".',
+'filetype-unwanted-type' => "'''\".\$1\"''' ahmo moēlēhuia quemeh tlahcuilōlli iuhcāyōtl.
+Tlahcuilōlli iuhcāyōtl {{PLURAL:\$3|moēlēhuia cah|moēlēhuiah cateh}} \$2.",
+'filetype-missing'       => 'Tlahcuilōlli ahmo quipiya huēiyaquiliztli (quemeh ".jpg").',
+'successfulupload'       => 'Cualli quetzaliztli',
+'savefile'               => 'Quipiyāz tlahcuilōlli',
+'uploadedimage'          => 'ōmoquetz "[[$1]]"',
+'overwroteimage'         => 'ōmoquetz yancuīc "[[$1]]" iuhcāyōtl',
+'uploaddisabled'         => 'Ahmo mohuelīti tlahcuilōlquetzā',
+'sourcefilename'         => 'Tōcāhuīcpa:',
+'destfilename'           => 'Tōcāhuīc:',
+'watchthisupload'        => 'Tictlachiyāz inīn zāzanilli',
 
 'upload_source_file' => ' (cē tlahcuilōlli mochīuhpōhualhuazco)',
 
-# Special:Imagelist
-'imgfile'        => 'īxiptli',
-'imagelist_name' => 'Tōcāitl',
-'imagelist_user' => 'Tlatēquitiltilīlli',
+# Special:ImageList
+'imagelist_search_for' => 'Tlatēmōz mēdiatl tōcācopa:',
+'imgfile'              => 'īxiptli',
+'imagelist'            => 'Mochīntīn īxiptli',
+'imagelist_name'       => 'Tōcāitl',
+'imagelist_user'       => 'Tlatequitiltilīlli',
 
 # Image description page
-'filehist-deleteall'             => 'tiquimpoloāz mochīntīn',
+'filehist'                       => 'Tlahcuilōlli tlahcuilōlloh',
+'filehist-deleteall'             => 'tiquimpolōz mochīntīn',
 'filehist-deleteone'             => 'ticpolōz',
 'filehist-revert'                => 'tlacuepāz',
 'filehist-current'               => 'āxcān',
-'filehist-user'                  => 'Tlatēquitiltilīlli',
+'filehist-user'                  => 'Tlatequitiltilīlli',
+'imagelinks'                     => 'Īxiphuīc tzonhuiliztli',
+'linkstoimage'                   => 'Inīn {{PLURAL:$1|zāzanilli tzonhuilia|$1 zāzaniltin tzonhuiliah}} inīn tlahcuilōlhuīc:',
+'nolinkstoimage'                 => 'Ahmo cateh zāzaniltin tlein tzonhuiliah inīn tlahcuilōlhuīc.',
+'sharedupload'                   => 'Inīn īxiptli huelīti motequitiltia zāzocāmpa',
 'shareduploadduplicate-linktext' => 'occē tlahcuilōlli',
 'shareduploadconflict-linktext'  => 'occē tlahcuilōlli',
 'noimage-linktext'               => 'ticquetzāz',
@@ -382,14 +597,42 @@
 'filerevert-submit' => 'Tlacuepāz',
 
 # File deletion
-'filedelete'        => 'Ticpolōz $1',
-'filedelete-legend' => 'Ticpolōz tlahcuilōlli',
-'filedelete-submit' => 'Ticpolōz',
+'filedelete'                  => 'Ticpolōz $1',
+'filedelete-legend'           => 'Ticpolōz tlahcuilōlli',
+'filedelete-comment'          => 'Tlapololiztli īxtlamatiliztli:',
+'filedelete-submit'           => 'Ticpolōz',
+'filedelete-success'          => "Ōmopolo '''$1'''.",
+'filedelete-nofile'           => "'''$1''' ahmo ia īpan {{SITENAME}}.",
+'filedelete-otherreason'      => 'Occē īxtlamatiliztli:',
+'filedelete-reason-otherlist' => 'Occē īxtlamatiliztli',
+'filedelete-edit-reasonlist'  => 'Tiquimpatlāz īxtlamatiliztli tlapoloaliztechcopa',
 
+# MIME search
+'mimesearch' => 'MIME tlatēmoliztli',
+'mimetype'   => 'MIME iuhcāyōtl:',
+'download'   => 'tictemōz',
+
+# Unwatched pages
+'unwatchedpages' => 'Zāzaniltin ahmo motlachiya',
+
+# List redirects
+'listredirects' => 'Tlacuepaliztli',
+
+# Unused templates
+'unusedtemplates'    => 'Nemachiyōtīlli ahmotequitiltiah',
+'unusedtemplateswlh' => 'occequīntīn tzonhuiliztli',
+
 # Random page
-'randompage' => 'Zāzotlein zāzanilli',
+'randompage'         => 'Zāzozāzanilli',
+'randompage-nopages' => 'Ahmo cateh zāzaniltin īpan inīn tōcātzin.',
 
+# Random redirect
+'randomredirect' => 'Zāzotlacuepaliztli',
+
 # Statistics
+'statistics'    => 'Tlapōhualiztli',
+'sitestats'     => '{{SITENAME}} ītlapōhualiz',
+'userstats'     => 'Tlatequitiltilīlli ītlapōhualiz',
 'sitestatstext' => "{{PLURAL:$1|Cah '''1''' zāzanilli|Cateh '''$1''' zāzaniltin}} nicān.
 Inīn quimpiya tēixnāmiquiliztli zāzanilli, {{SITENAME}} ītechcopa zāzanilli, machiyōtōn, tlacuepaliztli auh occequīntīn hueliz ahmo cualli.
 Ahtle, in {{PLURAL:$2|cah '''1''' cualli zāzanilli|cateh '''$2''' cualli zāzaniltin}}.
@@ -401,29 +644,60 @@
 
 Huēiyacaliztli [http://www.mediawiki.org/wiki/Manual:Job_queue tequilcān] cah '''$7'''.",
 
+'disambiguations' => 'Ōmetōcāitl zāzaniltin',
+
+'doubleredirects' => 'Ōntetl tlacuepaliztli',
+
+'brokenredirects'        => 'Tzomoc tlacuepaliztli',
 'brokenredirects-edit'   => '(ticpatlāz)',
 'brokenredirects-delete' => '(ticpolōz)',
 
-'withoutinterwiki-submit' => 'Xiquittāz',
+'withoutinterwiki'        => 'Zāzaniltin ahtle tzonhuiliztli',
+'withoutinterwiki-submit' => 'Tiquittāz',
 
 # Miscellaneous special pages
-'nbytes'            => '$1 byte',
-'longpages'         => 'Huēiyac zāzaniltin',
-'newpages'          => 'Yancuīc zāzaniltin',
-'newpages-username' => 'Tlatēquitiltilīltōcāitl:',
-'ancientpages'      => 'Huēhuehzāzanilli',
-'move'              => 'Ticzacāz',
-'movethispage'      => 'Ticzacāz inīn zāzanilli',
+'nbytes'                  => '$1 {{PLURAL:$1|byte|bytes}}',
+'ncategories'             => '$1 {{PLURAL:$1|neneuhcāyōtl|neneuhcāyōtl}}',
+'nlinks'                  => '$1 {{PLURAL:$1|tzonhuiliztli|tzonhuiliztli}}',
+'nmembers'                => '$1 {{PLURAL:$1|tlahcuilōlli|tlahcuilōlli}}',
+'nrevisions'              => '$1 {{PLURAL:$1|tlapiyaliztli|tlapiyaliztli}}',
+'uncategorizedpages'      => 'Zāzaniltin ahmoneneuhcāyōtiah',
+'uncategorizedcategories' => 'Neneuhcāyōtl ahmoneneuhcāyōtiah',
+'uncategorizedimages'     => 'Īxiptli ahmoneneuhcāyōtiah',
+'uncategorizedtemplates'  => 'Nemachiyōtīlli ahmoneneuhcāyōtiah',
+'unusedcategories'        => 'Neneuhcāyōtl ahmotequitiltiah',
+'unusedimages'            => 'Īxiptli ahmotequitiltiah',
+'wantedcategories'        => 'Neneuhcāyōtl moēlēhuiah',
+'wantedpages'             => 'Zāzaniltin moēlēhuiah',
+'mostlinked'              => 'Tlahcuilōlli achi motzonhuilia',
+'mostlinkedcategories'    => 'Neneuhcāyōtl achi motzonhuilia',
+'mostlinkedtemplates'     => 'Nemachiyōtīlli achi motzonhuilia',
+'shortpages'              => 'Ahhuēiyac zāzaniltin',
+'longpages'               => 'Huēiyac zāzaniltin',
+'deadendpages'            => 'Ahtlaquīzaliztli zāzaniltin',
+'protectedpages'          => 'Zāzaniltin ōmoquīxti',
+'protectedpages-indef'    => 'Zan ahcāhuitl tlaquīxtiliztli',
+'protectedpagestext'      => 'Inīn zāzaniltin ōmoquīxtih, auh ahmo mohuelītih mozacah nozo mopatlah',
+'protectedtitles'         => 'Tōcāitl ōmoquīxtih',
+'protectedtitlestext'     => 'Inīn tōcāitl ōmoquīxtih, auh ahmo mohuelītih mochīhuah',
+'newpages'                => 'Yancuīc zāzaniltin',
+'newpages-username'       => 'Tlatequitiltilīltōcāitl:',
+'ancientpages'            => 'Huēhuehzāzanilli',
+'move'                    => 'Ticzacāz',
+'movethispage'            => 'Ticzacāz inīn zāzanilli',
 
 # Book sources
 'booksources-go' => 'Yāuh',
 
 # Special:Log
-'specialloguserlabel'  => 'Tlatēquitiltilīlli:',
+'specialloguserlabel'  => 'Tlatequitiltilīlli:',
 'speciallogtitlelabel' => 'Tōcāitl:',
+'log'                  => 'Tlahcuilōlloh',
+'all-logs-page'        => 'Mochīntīn tlahcuilōlloh',
+'log-search-legend'    => 'Tiquintēmōz tlahcuilōlloh',
 'log-search-submit'    => 'Yāuh',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Mochīntīn zāzanilli',
 'alphaindexline'    => '$1 oc $2',
 'nextpage'          => 'Niman zāzanilli ($1)',
@@ -433,44 +707,73 @@
 'allnotinnamespace' => 'Mochīntīn zāzanilli (quihcuāc $1)',
 'allpagesprev'      => 'Achtopa',
 'allpagesnext'      => 'Niman',
-'allpagessubmit'    => 'Xiquittāz',
+'allpagessubmit'    => 'Tiquittāz',
 
 # Special:Categories
-'categories'         => 'Neneuhcāyōtl',
-'categoriespagetext' => 'Inīn neneuhcāyōtl īpan inīn huiqui cateh.',
-'categoriesfrom'     => 'Xiquittaz neneuhcāyōtl mopēhuah īca:',
+'categories'                    => 'Neneuhcāyōtl',
+'categoriespagetext'            => 'Inīn neneuhcāyōtl īpan inīn huiqui cateh.',
+'categoriesfrom'                => 'Xiquittaz neneuhcāyōtl mopēhuah īca:',
+'special-categories-sort-count' => 'tlapōhualcopa',
+'special-categories-sort-abc'   => 'tlahtōlcopa',
 
-# Special:Listusers
-'listusers-submit' => 'Xiquittāz',
+# Special:ListUsers
+'listusers-submit' => 'Tiquittāz',
 
-# Special:Listgrouprights
-'listgrouprights-group' => 'Olōlli',
+# Special:ListGroupRights
+'listgrouprights-group'  => 'Olōlli',
+'listgrouprights-rights' => 'Huelītiliztli',
 
 # E-mail user
-'emailfrom'    => 'Īhuīcpa',
-'emailto'      => 'Īhuīc',
-'emailmessage' => 'Tlahcuilōltzintli',
+'emailuser'       => 'Tique-mailīz inīn tlatequitiltilīlli',
+'defemailsubject' => '{{SITENAME}} e-mail',
+'emailfrom'       => 'Īhuīcpa',
+'emailto'         => 'Īhuīc',
+'emailmessage'    => 'Tlahcuilōltzintli',
 
 # Watchlist
-'watchlist'     => 'Notlachiyaliz',
-'mywatchlist'   => 'Notlachiyaliz',
-'watchlistfor'  => "(ic '''$1''')",
-'addedwatch'    => 'Ōmocētili tlachiyalizpan',
-'watch'         => 'Tictlachiyāz',
-'watchthispage' => 'Titlachiyāz inīn zāzanilli',
+'watchlist'            => 'Notlachiyaliz',
+'mywatchlist'          => 'Notlachiyaliz',
+'watchlistfor'         => "('''$1''' ītechcopa)",
+'watchnologin'         => 'Ahmo ōtimocalac',
+'addedwatch'           => 'Ōmocētili tlachiyalizpan',
+'watch'                => 'Tictlachiyāz',
+'watchthispage'        => 'Tictlachiyāz inīn zāzanilli',
+'unwatch'              => 'Ahtictlachiyāz',
+'watchlist-hide-bots'  => 'Tiquintlātīz tepoztlācah īntlapatlaliz',
+'watchlist-hide-own'   => 'Tiquintlātīz notlahcuilōl',
+'watchlist-hide-minor' => 'Tiquintlātīz tlapatlalitzintli',
 
-'changed' => 'ōmotlacuep',
-'created' => 'ōmochīuh',
+'enotif_newpagetext'           => 'Inīn cah yancuīc zāzanilli.',
+'enotif_impersonal_salutation' => 'tlatequitiltilīlli īpan {{SITENAME}}',
+'changed'                      => 'ōmotlacuep',
+'created'                      => 'ōmochīuh',
 
 # Delete/protect/revert
-'deletepage'       => 'Ticpolōz inīn zāzanilli',
-'exblank'          => 'zāzanilli ōcatca iztāc',
-'delete-confirm'   => 'Ticpolōz "$1"',
-'delete-legend'    => 'Ticpolōz',
-'actioncomplete'   => 'Cēntetl',
-'rollback_short'   => 'Tlacuepāz',
-'rollbacklink'     => 'tlacuepāz',
-'rollback-success' => 'Ōmotlacuep $1 īpatlaliz; āxcān achto $2 īpatlaliz.',
+'deletepage'             => 'Ticpolōz inīn zāzanilli',
+'excontent'              => "Tlapiyaliztli ōcatca: '$1'",
+'excontentauthor'        => "Tlapiyaliztli ōcatca: '$1' (auh zancē ōquipatlac ōcatca '[[Special:Contributions/$2|$2]]')",
+'exblank'                => 'zāzanilli ōcatca iztāc',
+'delete-confirm'         => 'Ticpolōz "$1"',
+'delete-legend'          => 'Ticpolōz',
+'actioncomplete'         => 'Cēntetl',
+'deletedtext'            => '"<nowiki>$1</nowiki>" ōmopolo.
+Xiquitta $2 ic yancuīc tlapololiztli.',
+'deletedarticle'         => 'ōmopolo "$1"',
+'dellogpage'             => 'Tlapololiztli tlahcuilōlloh',
+'deletionlog'            => 'tlapololiztli tlahcuilōlloh',
+'deletecomment'          => 'Tlapololiztli īxtlamatiliztli:',
+'deleteotherreason'      => 'Occē īxtlamatiliztli:',
+'deletereasonotherlist'  => 'Occē īxtlamatiliztli',
+'delete-edit-reasonlist' => 'Tiquimpatlāz īxtlamatiliztli tlapoloaliztechcopa',
+'rollback_short'         => 'Tlacuepāz',
+'rollbacklink'           => 'tlacuepāz',
+'rollback-success'       => 'Ōmotlacuep $1 ītlahcuilōl; āxcān achto $2 ītlahcuilōl.',
+'protectedarticle'       => 'ōmoquīxti "[[$1]]"',
+'unprotectedarticle'     => 'ōahmoquīxti "[[$1]]"',
+'protectexpiry'          => 'Tlamiliztli:',
+'protect_expiry_invalid' => 'Ahcualli tlamiliztli cāhuitl.',
+'protect-default'        => '(ic default)',
+'protect-expiring'       => 'motlamīz $1 (UTC)',
 
 # Restrictions (nouns)
 'restriction-edit'   => 'Ticpatlāz',
@@ -479,79 +782,166 @@
 'restriction-upload' => 'Tlahcuilōlquetza',
 
 # Undelete
+'undelete'               => 'Tiquinttāz zāzaniltin ōmopolōzqueh',
+'viewdeletedpage'        => 'Tiquinttāz zāzaniltin ōmopolōzqueh',
 'undeletebtn'            => 'Ahticpolōz',
 'undeletelink'           => 'ahticpolōz',
-'undelete-search-submit' => 'Tlatēmoāz',
+'undelete-search-box'    => 'Tiquintlatēmōz zāzaniltin ōmopolōz',
+'undelete-search-prefix' => 'Tiquittāz zāzaniltin mopēhua īca:',
+'undelete-search-submit' => 'Tlatēmōz',
 
 # Namespace form on various pages
+'namespace'      => 'Tōcātzin:',
 'invert'         => 'Tlacuepāz motlahtōl',
 'blanknamespace' => '(Huēyi)',
 
 # Contributions
-'contributions' => 'Īpatlaliz',
-'mycontris'     => 'Nopatlaliz',
+'contributions' => 'Ītlahcuilōl',
+'mycontris'     => 'Notlahcuilōl',
+'contribsub2'   => '$1 ($2)',
 'uctop'         => ' (ahco)',
 'month'         => 'Īhuīcpa mētztli (auh achtopa):',
 'year'          => 'Xiuhhuīcpa (auh achtopa):',
 
-'sp-contributions-submit' => 'Tlatēmoāz',
+'sp-contributions-newbies'     => 'Tiquinttāz zan yancuīc tlatequitiltilīlli īntlapatlaliz',
+'sp-contributions-newbies-sub' => 'Ic yancuīc',
+'sp-contributions-blocklog'    => 'Tlatzacuiliztli tlahcuilōlloh',
+'sp-contributions-search'      => 'Tiquintlatēmōz tlapatlaliztli',
+'sp-contributions-username'    => 'IP nozo tlatequitiltilīlli ītōcā:',
+'sp-contributions-submit'      => 'Tlatēmōz',
 
 # What links here
-'whatlinkshere'       => 'In tlein quitzonhuilia nicān',
-'whatlinkshere-title' => 'Zāzanilli quitzonhuilia $1',
-'whatlinkshere-page'  => 'Zāzanilli:',
-'isredirect'          => 'ōmotlacuep zāzanilli',
-'whatlinkshere-prev'  => '$1 achtopa',
-'whatlinkshere-next'  => '$1 niman',
+'whatlinkshere'            => 'In tlein quitzonhuilia nicān',
+'whatlinkshere-title'      => 'Zāzanilli quitzonhuilia $1',
+'whatlinkshere-page'       => 'Zāzanilli:',
+'linklistsub'              => '(Tzonhuiliztli)',
+'linkshere'                => "Inīn zāzaniltin quitzonhuiliah '''[[:$1]]''' īhuīc:",
+'nolinkshere'              => "Ahtle quitzonhuilia '''[[:$1]]''' īhuīc.",
+'isredirect'               => 'ōmotlacuep zāzanilli',
+'isimage'                  => 'īxiptli tzonhuiliztli',
+'whatlinkshere-prev'       => '{{PLURAL:$1|achtopa|$1 achtopa}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|niman|$1 niman}}',
+'whatlinkshere-links'      => '← tzonhuiliztli',
+'whatlinkshere-hideredirs' => '$1 tlacuepaliztli',
+'whatlinkshere-hidelinks'  => '$1 tzonhuiliztli',
+'whatlinkshere-hideimages' => '$1 īxiptzonhuiliztli',
 
 # Block/unblock
-'blockip'            => 'Tiquitzacuilīz tlatēquitiltilīlli',
-'blockip-legend'     => 'Tiquitzacuilīz tlatēquitiltilīlli',
-'ipbsubmit'          => 'Tiquitzacuilīz inīn tlatēquitiltilīlli',
+'blockip'            => 'Tiquitzacuilīz tlatequitiltilīlli',
+'blockip-legend'     => 'Tiquitzacuilīz tlatequitiltilīlli',
+'ipaddress'          => 'IP:',
+'ipadressorusername' => 'IP nozo tlatequitiltilīlli ītōcā:',
+'ipbreason'          => 'Īīxtlamatiliztli:',
+'ipbreasonotherlist' => 'Occē īxtlamatiliztli',
+'ipbsubmit'          => 'Tiquitzacuilīz inīn tlatequitiltilīlli',
+'ipboptions'         => '2 yēmpōhualminutl:2 hours,1 tōnalli:1 day,3 tōnaltin:3 days,7 tōnaltin:1 week,14 tōnaltin:2 weeks,1 mētztli:1 month,3 mētztli:3 months,6 mētztli:6 months,1 xihuitl:1 year,Mochipa:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'     => 'occē',
+'ipbotherreason'     => 'Occē īxtlamatiliztli:',
 'blockipsuccesssub'  => 'Cualli tlatzacuiliztli',
-'ipblocklist-submit' => 'Tlatēmoāz',
+'ipb-unblock-addr'   => 'Ahtiquitzacuilīz $1',
+'ipb-unblock'        => 'Ahtiquitzacuilīz IP nozo tlatequitiltilīlli',
+'unblockip'          => 'Ahtiquitzacuilīz tlatequitiltilīlli',
+'ipblocklist-submit' => 'Tlatēmōz',
 'blocklistline'      => '$1, $2 ōquitzacuili $3 ($4)',
 'infiniteblock'      => 'ahtlamic',
 'anononlyblock'      => 'zan ahtōcā',
 'blocklink'          => 'tiquitzacuilīz',
 'unblocklink'        => 'ahtiquitzacuilīz',
+'contribslink'       => 'tlapatlaliztli',
+'blockme'            => 'Timitzcuilīz',
+'proxyblocksuccess'  => 'Ōmochīuh.',
 
 # Move page
-'move-page'        => 'Ticzacāz $1',
-'move-page-legend' => 'Ticzacāz zāzanilli',
-'movearticle'      => 'Ticzacāz zāzanilli:',
-'move-watch'       => 'Titlachiyāz inīn zāzanilli',
-'movepagebtn'      => 'Ticzacāz zāzanilli',
-'movepage-moved'   => '<big>\'\'\'"$1" ōmotlacuep īhuīc "$2".\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'revertmove'       => 'tlacuepāz',
+'move-page'               => 'Ticzacāz $1',
+'move-page-legend'        => 'Ticzacāz zāzanilli',
+'movearticle'             => 'Ticzacāz tlahcuilōlli',
+'movenotallowed'          => 'Ahmo tihuelīti tiquinzaca zāzaniltin īpan {{SITENAME}}.',
+'newtitle'                => 'Yancuīc tōcāhuīc',
+'move-watch'              => 'Tictlachiyāz inīn zāzanilli',
+'movepagebtn'             => 'Ticzacāz zāzanilli',
+'pagemovedsub'            => 'Cualli ōmozacac',
+'movepage-moved'          => '<big>\'\'\'"$1" ōmotlacuep īhuīc "$2".\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movedto'                 => 'ōmozacac īhuīc',
+'movetalk'                => 'Ticzacāz nō tēixnāmiquiliztli tlahcuilōltechcopa.',
+'1movedto2'               => '[[$1]] ōmozacac īhuīc [[$2]]',
+'1movedto2_redir'         => '[[$1]] ōmozacac īhuīc [[$2]] tlacuepalpampa',
+'movelogpage'             => 'Tlazacaliztli tlahcuilōlloh',
+'movereason'              => 'Īxtlamatiliztli:',
+'revertmove'              => 'tlacuepāz',
+'delete_and_move'         => 'Ticpolōz auh ticzacāz',
+'delete_and_move_confirm' => 'Quēmah, ticpolōz in zāzanilli',
 
+# Export
+'export'          => 'Tiquinnamacāz zāzaniltin',
+'export-submit'   => 'Ticnamacāz',
+'export-addcat'   => 'Ticcētilīz',
+'export-download' => 'Ticpiyāz quemeh tlahcuilōlli',
+
 # Namespace 8 related
 'allmessages'        => 'Mochīntīn Huiquimedia tlahcuilōltzintli',
 'allmessagesname'    => 'Tōcāitl',
 'allmessagescurrent' => 'Āxcān tlahcuilōlli',
 
+# Special:Import
+'import'                  => 'Tiquincōhuāz zāzaniltin',
+'import-interwiki-submit' => 'Tiquicōhuāz',
+'importstart'             => 'Motlacōhua zāzaniltin...',
+
 # Tooltip help for the actions
-'tooltip-pt-userpage'       => 'Notlatēquitiltilīlzāzanil',
-'tooltip-pt-mytalk'         => 'Notēixnāmiquiliz',
-'tooltip-pt-logout'         => 'Tiquīzāz',
-'tooltip-ca-protect'        => 'Ticquīxtiāz inīn zāzanilli',
-'tooltip-ca-delete'         => 'Ticpolōz inīn zāzanilli',
-'tooltip-ca-move'           => 'Ticzacāz inīn zāzanilli',
-'tooltip-p-logo'            => 'Calīxatl',
-'tooltip-n-mainpage'        => 'Tictlahpolōz in Calīxatl',
-'tooltip-ca-nstab-main'     => 'Xiquittāz in tlahcuilōlli',
-'tooltip-ca-nstab-user'     => 'Xiquittāz tlatēquitiltilīlli īzāzanil',
-'tooltip-ca-nstab-template' => 'Xiquittāz in nemachiyōtīlli',
-'tooltip-ca-nstab-help'     => 'Xiquittāz in tēpalēhuiliztli zāzanilli',
-'tooltip-ca-nstab-category' => 'Xiquittāz in neneuhcāyōtl zāzanilli',
-'tooltip-save'              => 'Ticpiyāz mopatlaliz',
-'tooltip-preview'           => 'Xiquitta achtopa mopatlaliz, ¡timitztlātlauhtiah quitēquitiltilia achto ticpiya!',
-'tooltip-upload'            => 'Ticpēhua quetzaliztli',
+'tooltip-pt-userpage'             => 'Notlatequitiltilīlzāzanil',
+'tooltip-pt-mytalk'               => 'Notēixnāmiquiliz',
+'tooltip-pt-preferences'          => 'Notlaēlēhuiliz',
+'tooltip-pt-watchlist'            => 'Zāzaniltin tiquintlachiya ic tlapatlaliztli',
+'tooltip-pt-mycontris'            => 'Notlahcuilōl',
+'tooltip-pt-login'                => 'Tihuelīti timocalaqui, tēl ahmo tihuīquilia.',
+'tooltip-pt-anonlogin'            => 'Tihuelīti timocalaqui, tēl ahmo tihuīquilia.',
+'tooltip-pt-logout'               => 'Tiquīzāz',
+'tooltip-ca-talk'                 => 'Inīn tlahcuilōlli ītēixnāmiquiliz',
+'tooltip-ca-edit'                 => 'Tihuelīti ticpatla inīn zāzanilli. Timitztlātlauhtiah, tiquiclica achtochīhualizpan achtopa ticpiya.',
+'tooltip-ca-addsection'           => 'Tiquihcuilōz itlah inīn tēixnāmiquilizhuīc.',
+'tooltip-ca-viewsource'           => 'Inīn zāzanilli ōmoquīxti. Tihuelīti tiquitta ītlahtōlcaquiliztilōni.',
+'tooltip-ca-history'              => 'Achtopa āxcān zāzanilli īhuān in tlatequitiltilīlli ōquinchīuhqueh',
+'tooltip-ca-protect'              => 'Ticquīxtiāz inīn zāzanilli',
+'tooltip-ca-delete'               => 'Ticpolōz inīn zāzanilli',
+'tooltip-ca-undelete'             => 'Ahticpolōz inīn zāzanilli',
+'tooltip-ca-move'                 => 'Ticzacāz inīn zāzanilli',
+'tooltip-ca-watch'                => 'Ticcēntilīz inīn zāzanilli motlachiyalizhuīc',
+'tooltip-ca-unwatch'              => 'Ahtictlachiyāz inīn zāzanilli',
+'tooltip-search'                  => 'Tlatēmōz īpan {{SITENAME}}',
+'tooltip-p-logo'                  => 'Calīxatl',
+'tooltip-n-mainpage'              => 'Tictlahpolōz in Calīxatl',
+'tooltip-n-recentchanges'         => 'Yancuīc tlapatlaliztli huiquipan',
+'tooltip-n-randompage'            => 'Tiquittāz cē zāzotlein zāzanilli',
+'tooltip-t-whatlinkshere'         => 'Mochīntīn zāzaniltin huiquipan quitzonhuiliah nicān',
+'tooltip-t-recentchangeslinked'   => 'Yancuīc tlapatlaliztli inīn zāzanilhuīcpa moquintzonhuilia',
+'tooltip-feed-rss'                => 'RSS tlachicāhualiztli inīn zāzaniltechcopa',
+'tooltip-feed-atom'               => 'Atom tlachicāhualiztli inīn zāzaniltechcopa',
+'tooltip-t-contributions'         => 'Xiquitta inīn tlatequitiltilīlli ītlahcuilōl',
+'tooltip-t-emailuser'             => 'Tiquihcuilōz inīn tlatequitiltililhuīc',
+'tooltip-t-upload'                => 'Tiquinquetzāz tlahcuilōlli',
+'tooltip-t-specialpages'          => 'Mochīntīn nōncuahquīzqui zāzaniltin',
+'tooltip-ca-nstab-main'           => 'Xiquitta in tlahcuilōlli',
+'tooltip-ca-nstab-user'           => 'Xiquitta tlatequitiltilīlli īzāzanil',
+'tooltip-ca-nstab-special'        => 'Cah inīn cē nōncuahquīzqui zāzanilli; ahmo tihuelīti ticpatla.',
+'tooltip-ca-nstab-project'        => 'Xiquitta tlachīhualiztli īzāzanil',
+'tooltip-ca-nstab-mediawiki'      => 'Xiquitta in tlahcuilōltzin',
+'tooltip-ca-nstab-template'       => 'Xiquitta in nemachiyōtīlli',
+'tooltip-ca-nstab-help'           => 'Xiquitta in tēpalēhuiliztli zāzanilli',
+'tooltip-ca-nstab-category'       => 'Xiquitta in neneuhcāyōtl zāzanilli',
+'tooltip-minoredit'               => 'Ticmachiyōz quemeh tlapatlalitzintli',
+'tooltip-save'                    => 'Ticpiyāz mopatlaliz',
+'tooltip-preview'                 => 'Xiquitta achtopa mopatlaliz, ¡timitztlātlauhtiah quitēquitiltilia achto ticpiya!',
+'tooltip-diff'                    => 'Xiquitta in tlein ōticpatlāz tlahcuilōlco.',
+'tooltip-compareselectedversions' => 'Tiquinttāz ahneneuhquiliztli ōme zāzanilli tlapatlaliznepantlah.',
+'tooltip-watch'                   => 'Ticcēntilīz inīn zāzanilli motlachiyalizhuīc',
+'tooltip-upload'                  => 'Ticpēhua quetzaliztli',
 
 # Attribution
+'anonymous'        => 'Ahtōcāitl tlatequitiltilīlli īpan {{SITENAME}}',
+'siteuser'         => '$1 tlatequitiltilīlli īpan {{SITENAME}}',
 'lastmodifiedatby' => 'Inīn zāzanilli ōtlapatlac catca īpan $2, $1 īpal $3.', # $1 date, $2 time, $3 user
 'others'           => 'occequīntīn',
+'siteusers'        => '$1 tlatequitiltilīlli īpan {{SITENAME}}',
 
 # Browsing diffs
 'previousdiff' => '← Achtopa',
@@ -559,20 +949,38 @@
 
 # Media information
 'widthheightpage' => '$1×$2, $3 {{PLURAL:|zāzanilli|zāzanilli}}',
+'show-big-image'  => 'Mochi cuallōtl',
 
-# Special:Newimages
-'ilsubmit' => 'Tlatēmoāz',
-'bydate'   => 'tōnalcopa',
+# Special:NewImages
+'newimages'     => 'Yancuīc īxipcān',
+'imagelisttext' => "Nicān {{PLURAL:$1|mopiya|mopiyah}} '''$1''' īxiptli $2 iuhcopa.",
+'showhidebots'  => '($1 tepoztlācah)',
+'ilsubmit'      => 'Tlatēmōz',
+'bydate'        => 'tōnalcopa',
 
 # EXIF tags
-'exif-imagedescription' => 'Īxiptli ītōcā',
+'exif-photometricinterpretation' => 'Pixelli chīhualiztli',
+'exif-imagedescription'          => 'Īxiptli ītōcā',
+'exif-software'                  => 'Software ōmotēquitilti',
+'exif-artist'                    => 'Chīhualōni',
+'exif-usercomment'               => 'Quihtoa tlatequitiltilīlli',
+'exif-exposuretime'              => 'Cāuhcāyōtl',
+'exif-isospeedratings'           => 'ISO iciuhquiliztli tlapōhualcāyōtl',
+'exif-flash'                     => 'Flax',
+'exif-flashenergy'               => 'Flax chicāhualiztli',
 
 'exif-meteringmode-255' => 'Occē',
 
 'exif-lightsource-1'   => 'Tōnameyyōtl',
+'exif-lightsource-4'   => 'Flax',
 'exif-lightsource-10'  => 'Mixxoh',
+'exif-lightsource-11'  => 'Ecahuīlli',
 'exif-lightsource-255' => 'Occequīntīn tlāhuīlli',
 
+'exif-scenecapturetype-3' => 'Yohualcopa',
+
+'exif-gaincontrol-0' => 'Ahtlein',
+
 # Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
 'exif-gpslatitude-n' => 'Ayamictlān',
 'exif-gpslatitude-s' => 'Huiztlān',
@@ -586,7 +994,7 @@
 
 # E-mail address confirmation
 'confirmemail'           => 'Ticchicāhuāz e-mail',
-'confirmemail_needlogin' => 'Tihuīquilia ticchicāhua mo e-mail.',
+'confirmemail_needlogin' => 'Tihuīquilia $1 ic ticchicāhua mo e-mail.',
 'confirmemail_success'   => 'Mo e-mailcān ōmochicāuh. 
 Niman tihuelīti timocalaqui auh quiyōlēhua huiqui.',
 'confirmemail_loggedin'  => 'Mo e-mailcān ōmochicāuh.',
@@ -606,7 +1014,9 @@
 'confirm_purge_button' => 'Cualli',
 
 # AJAX search
-'articletitles' => "Tlahcuilōlli mopēhuah īca ''$1''",
+'searchcontaining' => "Tiquintēmōz zāzaniltin quipiyah ''$1''.",
+'searchnamed'      => "Tiquintēmōz zāzaniltin īntōcā ''$1''.",
+'articletitles'    => "Tlahcuilōlli mopēhuah īca ''$1''",
 
 # Multipage image navigation
 'imgmultipageprev' => '← achto zāzanilli',
@@ -626,6 +1036,12 @@
 'autoredircomment' => 'Mocuepahua īhuīc [[$1]]',
 'autosumm-new'     => 'Yancuīc zāzanilli: $1',
 
+# Size units
+'size-bytes'     => '$1 B',
+'size-kilobytes' => '$1 KB',
+'size-megabytes' => '$1 MB',
+'size-gigabytes' => '$1 GB',
+
 # Live preview
 'livepreview-loading' => 'Tēmohua...',
 
@@ -635,7 +1051,8 @@
 'watchlistedit-raw-added'    => '{{PLURAL:$1|Ōmocentili cē zāzanilli|Ōmocentilih $1 zāzaniltin}}:',
 
 # Watchlist editing tools
-'watchlisttools-view' => 'Xiquittāz huēyi tlapatlaliztli',
+'watchlisttools-view' => 'Tiquinttāz huēyi tlapatlaliztli',
+'watchlisttools-edit' => 'Tiquittāz auh ticpatlāz motlachiyaliz',
 
 # Special:Version
 'version'                  => 'Machiyōtzin', # Not used as normal message but as header for the special page itself
@@ -644,20 +1061,28 @@
 'version-version'          => 'Machiyōtzin',
 'version-software-version' => 'Machiyōtzin',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Tlahcuilōlli:',
 
 # Special:FileDuplicateSearch
-'fileduplicatesearch-submit' => 'Tlatēmoāz',
-'fileduplicatesearch-info'   => '$1 × $2 pixelli<br />Tlahcuilōlli īxquichiliz: $3<br />MIME iuhcāyōtl: $4',
+'fileduplicatesearch-filename' => 'Tlahcuilōlli ītōcā:',
+'fileduplicatesearch-submit'   => 'Tlatēmōz',
+'fileduplicatesearch-info'     => '$1 × $2 pixelli<br />Tlahcuilōlli īxquichiliz: $3<br />MIME iuhcāyōtl: $4',
 
 # Special:SpecialPages
-'specialpages'             => 'Nōncuahquīzqui āmatl',
-'specialpages-group-other' => 'Occequīntīn nōncuahquīzqui zāzaniltin',
-'specialpages-group-login' => 'Ximocalaqui / ximomachiyōmaca',
-'specialpages-group-pages' => 'Mochīntīn zāzaniltin',
+'specialpages'                 => 'Nōncuahquīzqui āmatl',
+'specialpages-note'            => '----
+* Nōncuahquīzqui.
+* <span class="mw-specialpagerestricted">Tzacuilic.</span>',
+'specialpages-group-other'     => 'Occequīntīn nōncuahquīzqui zāzaniltin',
+'specialpages-group-login'     => 'Ximocalaqui / ximomachiyōmaca',
+'specialpages-group-changes'   => 'Yancuīc tlapatlaliztli īhuān tlahcuilōlloh',
+'specialpages-group-users'     => 'Tlatequitiltilīlli īhuān huelītiliztli',
+'specialpages-group-highuse'   => 'Zāzaniltin tlatequitiliztechcopa',
+'specialpages-group-pages'     => 'Mochīntīn zāzaniltin',
+'specialpages-group-redirects' => 'Tlatēmoliztli īhuān  tlacuepaliztli',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage' => 'Iztāc zāzanilli',
 
 );
Index: languages/messages/MessagesCsb.php
===================================================================
--- languages/messages/MessagesCsb.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCsb.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,7 @@
  * @file
  *
  * @author Warszk
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Jon Harald Søby
- * @author SPQRobin
  */
 
 $namespaceNames = array(
@@ -331,7 +328,6 @@
 'blockedoriginalsource' => "Zdrój '''$1''' je niżi:",
 'blockededitsource'     => "Tekst '''Twòjëch edicëji''' do '''$1''' je niżi:",
 'whitelistedittitle'    => 'Bë editowac je nót sã wlogòwac',
-'whitelistreadtitle'    => 'Bë czëtac je nót sã wlogòwac',
 'accmailtitle'          => 'Parola wësłónô.',
 'accmailtext'           => 'Parola dlô "$1" je wësłónô do $2.',
 'newarticletext'        => "Môsz przëszłi z lënkù do starnë jaka jesz nie òbstoji.
@@ -340,7 +336,7 @@
 Jeżlë jes të tuwò bez zmiłkã, le klëkni w swòjim przezérnikù knąpã '''nazôd'''.",
 'anontalkpagetext'      => "----''To je starna dyskùsëji anonimòwiégò brëkòwnika, chtëren nie zrobił jesz kònta dlô se, abò gò nie brëkùje.
 Takô adresa IP, mòże bëc brëkòwónô òb wiele lëdzy.
-Eżlë klëczi na ti starnie nie są sczérowóne do ce, tedë [[Special:Userlogin|zrobi sobie nowé kònto]] abò zalogùje sã, bë niechac zmiłczi z jinëma anonimòwima brëkòwnikama.''",
+Eżlë klëczi na ti starnie nie są sczérowóne do ce, tedë [[Special:UserLogin|zrobi sobie nowé kònto]] abò zalogùje sã, bë niechac zmiłczi z jinëma anonimòwima brëkòwnikama.''",
 'clearyourcache'        => "'''Bôczë:''' Pò zapisanim, mòże bãdzesz mùszôł òminąc pamiãc przezérnika bë òbaczëc zmianë. '''Mozilla / Firefox / Safari:''' przëtrzëmôj ''Shift'' òbczas klëkaniô na ''Reload'', abò wcësni ''Ctrl-Shift-R'' (''Cmd-Shift-R'' na kòmpùtrach Mac); '''IE:''' przëtrzëmôj ''Ctrl'' òbczas klëkaniô na ''Refresh'', abò wcësni ''Ctrl-F5''; '''Konqueror''': prosto klëkni na knąpã ''Reload'', abò wcësni ''F5''; brëkòwnicë '''Operë''' bãdą mést mùszële wëczëszczëc pamiãc w ''Tools→Preferences''.",
 'previewnote'           => '<strong>To je blós pòdzérk - artikel jesz nie je zapisóny!</strong>',
 'editing'               => 'Edicëjô $1',
@@ -443,7 +439,7 @@
 'upload'            => 'Wladënk lopka',
 'reupload'          => 'Wëslë jesz rôz',
 'uploadnologin'     => 'Felënk logòwaniô',
-'uploadtext'        => '<strong>STOP!</strong> Nigle wladëjesz jaczi lopk,\\nprzeczëtôj regle wladowaniô lopków ë ùgwësnij sã, że wladëwającë gò òstóniesz z\\nnima w zgòdze.\\n<p>Jeżle chcesz przezdrzec abò przeszëkac do terô wladowóné lopczi,\\nprzeńdzë do [[Special:Imagelist|lëstë wladowónëch lopków]].\\nWszëtczé wladënczi ë rëmania są òdnotérowóné w\\nspecjalnëch zestôwkach: [[Special:Log/upload|wladënczi]] ë [[Special:Log/delete|rëmóné]].\\n<p>Bë wëslac nowi lopk do zòbrazowaniô Twòjégò artikla wëzwëskùj \\nhewòtny fòrmùlar.\\nW wikszoscë przezérników ùzdrzesz knąpã <i>Browse...</i>\\nabò <i>Przezérôj...</i>, chtëren ùmożlëwi Cë òtemkniãcé sztandardowégò\\nòkna wëbiérkù lopka. Wëbranié lopka sprawi wstôwienié jegò miona\\nw tekstowim pòlu kòl knąpë.\\nZaznaczającë pasowné pòle, mùszisz téż pòcwierdzëc, ëż sélającë\\nlopk nie gwôłcësz nikògò autorsczich praw.\\nWladënk zacznie sã pò wcësniãcym <i>Wladëjë lopk</i>.\\nTo mòże sztërk zdérowac, òsoblëwò jeżle ni môsz chùtczégò dopùscënkù do internetu.\\n<p>Preferowónyma fòrmatama są: JPEG dlô òdjimków, PNG dlô céchùnków\\në òbrôzków ze znankama ikònów, ôs OGG dlô zwãków. Bë nie dac przińc do lëchòrozmieniów nadôwôj lopkom miona sparłãczóné z jich zamkłoscą.\\nBë wstôwic òbrôzk do artikla, wpiszë lënk:\\n<b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:miono.jpg]]</nowiki></b> abò <b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:miono.png|òpcjonalny tekst]]</nowiki></b>.\\nDlô zwãkòwëch lopków lënk mdze wëzdrzôł tak: <b><nowiki>[[</nowiki>{{ns:media}}<nowiki>:file.ogg]]</nowiki></b>.\\n<p>Prosymë wdarzëc, ëż tak samò jak w przëtrôfkù zwëczajnëch starnów {{SITENAME}},\\njińszi brëkòwnicë mògą editowac abò rëmac wladowóné przez Ce lopczi,\\njeżle mdą dbë, że to mdze lepi służëc całi ùdbie {{SITENAME}}.\\nTwòje prawò do sélaniégò lopków mòże bëc Cë òdebróné, eżle nadùżëjesz systemë.',
+'uploadtext'        => '<strong>STOP!</strong> Nigle wladëjesz jaczi lopk,\\nprzeczëtôj regle wladowaniô lopków ë ùgwësnij sã, że wladëwającë gò òstóniesz z\\nnima w zgòdze.\\n<p>Jeżle chcesz przezdrzec abò przeszëkac do terô wladowóné lopczi,\\nprzeńdzë do [[Special:ImageList|lëstë wladowónëch lopków]].\\nWszëtczé wladënczi ë rëmania są òdnotérowóné w\\nspecjalnëch zestôwkach: [[Special:Log/upload|wladënczi]] ë [[Special:Log/delete|rëmóné]].\\n<p>Bë wëslac nowi lopk do zòbrazowaniô Twòjégò artikla wëzwëskùj \\nhewòtny fòrmùlar.\\nW wikszoscë przezérników ùzdrzesz knąpã <i>Browse...</i>\\nabò <i>Przezérôj...</i>, chtëren ùmożlëwi Cë òtemkniãcé sztandardowégò\\nòkna wëbiérkù lopka. Wëbranié lopka sprawi wstôwienié jegò miona\\nw tekstowim pòlu kòl knąpë.\\nZaznaczającë pasowné pòle, mùszisz téż pòcwierdzëc, ëż sélającë\\nlopk nie gwôłcësz nikògò autorsczich praw.\\nWladënk zacznie sã pò wcësniãcym <i>Wladëjë lopk</i>.\\nTo mòże sztërk zdérowac, òsoblëwò jeżle ni môsz chùtczégò dopùscënkù do internetu.\\n<p>Preferowónyma fòrmatama są: JPEG dlô òdjimków, PNG dlô céchùnków\\në òbrôzków ze znankama ikònów, ôs OGG dlô zwãków. Bë nie dac przińc do lëchòrozmieniów nadôwôj lopkom miona sparłãczóné z jich zamkłoscą.\\nBë wstôwic òbrôzk do artikla, wpiszë lënk:\\n<b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:miono.jpg]]</nowiki></b> abò <b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:miono.png|òpcjonalny tekst]]</nowiki></b>.\\nDlô zwãkòwëch lopków lënk mdze wëzdrzôł tak: <b><nowiki>[[</nowiki>{{ns:media}}<nowiki>:file.ogg]]</nowiki></b>.\\n<p>Prosymë wdarzëc, ëż tak samò jak w przëtrôfkù zwëczajnëch starnów {{SITENAME}},\\njińszi brëkòwnicë mògą editowac abò rëmac wladowóné przez Ce lopczi,\\njeżle mdą dbë, że to mdze lepi służëc całi ùdbie {{SITENAME}}.\\nTwòje prawò do sélaniégò lopków mòże bëc Cë òdebróné, eżle nadùżëjesz systemë.',
 'uploadlog'         => 'Lësta wladënków',
 'uploadlogpage'     => 'Dołączoné',
 'uploadlogpagetext' => 'Hewò je lësta slédno wladowónëch lopków.\\nWszëtczé gòdzënë tikają conë ùniwersalnégò czasë (UTC).',
@@ -459,7 +455,7 @@
 'uploadedimage'     => 'wladënk: "$1"',
 'uploaddisabled'    => 'Przeprôszómë! Mòżlëwòta wladënkù lopków na nen serwer òsta wëłączonô.',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => 'Lësta òbrôzków',
 'imagelist_user' => 'Brëkòwnik',
 
@@ -515,7 +511,7 @@
 'log'                 => 'Lodżi',
 'alllogstext'         => 'Sparłãczone registrë wësłónëch lopków, rëmónëch starn, zazychrowaniô, blokòwaniô ë nadôwaniô ùdowierzeniów. Mòżesz zawãżëc wëszłosc òb wëbranié ôrtu registru, miona brëkòwnika abò miona zajimnej dlô ce starnë.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Wszëtczé starnë',
 'alphaindexline'    => '$1 --> $2',
 'allpagesfrom'      => 'Starnë naczënające sã na:',
@@ -548,7 +544,7 @@
 'watchnologin'         => 'Felënk logòwóniô',
 'addedwatch'           => 'Dodónô do lëstë ùzérónëch',
 'addedwatchtext'       => "Starna \"[[:\$1]]\" òsta dodónô do twòji [[Special:Watchlist|lëstë ùzérónëch artiklów]].
-Na ti lësce są registre przińdnëch zjinak ti starne ë na ji starnie dyskùsëji, a samò miono starnë mdze '''wëtłëszczone''' na [[Special:Recentchanges|lësce slédnich edicëji]], bë të mògł to òbaczëc. 
+Na ti lësce są registre przińdnëch zjinak ti starne ë na ji starnie dyskùsëji, a samò miono starnë mdze '''wëtłëszczone''' na [[Special:RecentChanges|lësce slédnich edicëji]], bë të mògł to òbaczëc. 
 
 Czej chcesz remôc starnã z lëste ùzéronëch artiklów, klikni ''Òprzestôj ùzérac''.",
 'removedwatch'         => 'Rëmóné z lëstë ùzérónëch',
@@ -627,7 +623,7 @@
 'badipaddress'       => 'IP-adresa nie je richtich pòdónô.',
 'blockipsuccesssub'  => 'Zascëgónié dało sã',
 'blockipsuccesstext' => 'Brëkòwnik [[Special:Contributions/$1|$1]] òstał zascëgóny.<br />
-Biéj do [[Special:Ipblocklist|lëstë zascëgónëch adresów IP]] abë òbaczëc zascëdżi.',
+Biéj do [[Special:IPBlockList|lëstë zascëgónëch adresów IP]] abë òbaczëc zascëdżi.',
 'blocklistline'      => '$1, $2 zascëgôł $3 ($4)',
 'blocklink'          => 'zascëgôj',
 'contribslink'       => 'wkłôd',
@@ -640,7 +636,6 @@
 # Move page
 'move-page-legend'        => 'Przeniesë starnã',
 'movearticle'             => 'Przeniesë artikel',
-'movenologin'             => 'Felënk logòwaniô',
 'movepagebtn'             => 'Przeniesë starnã',
 'pagemovedsub'            => 'Przeniesenié darzëło sã',
 'articleexists'           => 'Starna ò taczim mionie ju je abò nie je òno bezzmiłkòwé. Wëbierzë nowé miono.',
@@ -703,7 +698,7 @@
 'imagemaxsize' => 'Limitëjë òbrôzczi na starnie òpisënkù òbrôzków do:',
 'thumbsize'    => 'Miara miniaturków:',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Szëkôj',
 'bydate'   => 'wedle datumù',
 
Index: languages/messages/MessagesLn.php
===================================================================
--- languages/messages/MessagesLn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,7 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
  * @author Eruedin
- * @author Siebrand
  */
 
 $fallback = 'fr';
@@ -213,7 +211,7 @@
 'uploadbtn' => 'kokumbisa',
 'savefile'  => 'kobómbisa kásá-kásá',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_date' => 'Mokɔlɔ',
 
 # File deletion
@@ -241,7 +239,7 @@
 # Book sources
 'booksources-go' => 'Kɛndɛ́',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Nkásá ínsɔ',
 'alphaindexline' => '$1 kina $2',
 'nextpage'       => 'Lokásá ya nsima ($1)',
@@ -333,7 +331,7 @@
 # Browsing diffs
 'previousdiff' => '← diff ya libosó',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Boluki',
 
 # EXIF tags
@@ -345,7 +343,7 @@
 'watchlistall2' => 'nyɔ́nsɔ',
 
 # HTML dump
-'redirectingto' => 'Eyendísí na [[$1]]...',
+'redirectingto' => 'Eyendísí na [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Nandimi',
Index: languages/messages/MessagesTh.php
===================================================================
--- languages/messages/MessagesTh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,16 +4,14 @@
  * @ingroup Language
  * @file
  *
- * @author Passawuth
  * @author Ans
- * @author Octahedron80
+ * @author LMNOP at Thai Wikipedia (manop@itshee.com) since July 2007
  * @author Manop
- * @author Siebrand
+ * @author Octahedron80
+ * @author Passawuth
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author วรากร อึ้งวิเชียร (Varakorn Ungvichian)
  * @author จักรกฤช วงศ์สระหลวง (Jakkrit Vongsraluang) / PaePae
- * @author LMNOP at Thai Wikipedia (manop@itshee.com) since July 2007
+ * @author วรากร อึ้งวิเชียร (Varakorn Ungvichian)
  */
 
 $skinNames = array(
@@ -357,7 +355,7 @@
 'nosuchaction'      => 'ไม่มีการกระทำดังกล่าว',
 'nosuchactiontext'  => 'การกระทำที่กำหนดผ่านยูอาร์แอลไม่เป็นที่ยอมรับของวิกิ',
 'nosuchspecialpage' => 'ไม่มีหน้าพิเศษดังกล่าว',
-'nospecialpagetext' => 'หน้าพิเศษตามคำขอไม่ถูกต้อง รายชื่อของหน้าพิเศษดูได้ที่ [[Special:Specialpages|รายชื่อหน้าพิเศษ]]',
+'nospecialpagetext' => 'หน้าพิเศษตามคำขอไม่ถูกต้อง รายชื่อของหน้าพิเศษดูได้ที่ [[Special:SpecialPages|รายชื่อหน้าพิเศษ]]',
 
 # General errors
 'error'                => 'ผิดพลาด',
@@ -560,17 +558,17 @@
 'summary-preview'                  => 'ตัวอย่างคำอธิบายการแก้ไข',
 'subject-preview'                  => 'ตัวอย่างหัวข้อ',
 'blockedtitle'                     => 'ผู้ใช้ถูกห้ามใช้งาน',
-'blockedtext'                      => "<big>'''ชื่อผู้ใช้หรือหมายเลขไอพีถูกของคุณถูกระงับการใช้งาน'''</big>
+'blockedtext'                      => "<big>'''ชื่อผู้ใช้หรือหมายเลขไอพีถูกของคุณถูกบล็อกการใช้งาน'''</big>
 
-$1 เป็นผู้ดำเนินการระงับการใช้งานนี้ โดยให้เหตุผลไว้ว่า ''$2''
+$1 เป็นผู้ดำเนินการบล็อกในครั้งนี้ โดยให้เหตุผลไว้ว่า ''$2''
 
-* เริ่มการระงับ: $8
-* สิ้นสุดการระงับ: $6
-* ผู้ถูกระงับ: $7
+* เริ่มการบล็อก: $8
+* สิ้นสุดการบล็อก: $6
+* ผู้ถูกบล็อก: $7
 
-สามารถติดต่อ $1 หรือ [[{{MediaWiki:Grouppage-sysop}}|ผู้ดูแลระบบ]]คนอื่นเพื่อหารือเกี่ยวกับการระงับนี้ หรือสามารถที่จะอีเมลผ่านระบบวิกิด้วยคำสั่ง 'อีเมลหาผู้ใช้นี้'
-(ถ้าคุณได้ตั้งค่ารองรับการใช้คำสั่งพิเศษผ่านทางอีเมลในส่วน [[Special:Preferences|การตั้งค่าผู้ใช้]])
-หมายเลขไอพีปัจจุบันของคุณคือ $3 และรหัสการระงับคือ #$5 กรุณาระบุหมายเลขเหล่านี้ในการติดต่อผู้ดูแล",
+คุณสามารถติดต่อ $1 หรือ [[{{MediaWiki:Grouppage-sysop}}|ผู้ดูแลระบบ]]คนอื่นเพื่อหารือเกี่ยวกับการบล็อกนี้ หรือสามารถที่จะอีเมลผ่านระบบวิกิด้วยคำสั่ง 'อีเมลหาผู้ใช้นี้'
+(ถ้าคุณได้ตั้งค่ารองรับการใช้คำสั่งพิเศษผ่านทางอีเมลในส่วน [[Special:Preferences|การตั้งค่าผู้ใช้]] และคุณไม่ถูกบล็อกจากการใช้คำสั่งนี้)
+หมายเลขไอพีปัจจุบันของคุณคือ $3 และหมายเลขการบล็อกคือ #$5 กรุณาระบุหมายเลขเหล่านี้ในการติดต่อผู้ดูแล",
 'autoblockedtext'                  => 'หมายเลขไอพีของคุณถูกบล็อกโดยอัตโนมัติ เนื่องจากมีผู้ใช้อื่นใช้งานผ่านหมายเลขไอพีนี้มาก่อนและได้ถูกบล็อกการใช้งานโดย $1. เหตุผลที่ให้ไว้ในการบล็อกคือ:
 
 :\'\'$2\'\'
@@ -588,10 +586,6 @@
 'blockededitsource'                => "'''ข้อความที่คุณได้แก้ไข''' ใน '''$1''' แสดงผลด้านล่าง:",
 'whitelistedittitle'               => 'ไม่อนุญาตให้แก้ไขถ้าไม่ล็อกอิน',
 'whitelistedittext'                => 'คุณต้อง $1 เพื่อทำการแก้ไข',
-'whitelistreadtitle'               => 'ไม่อนุญาตให้อ่านถ้าไม่ล็อกอิน',
-'whitelistreadtext'                => 'คุณต้อง[[Special:Userlogin|ล็อกอิน]] ก่อนถึงจะอ่านได้',
-'whitelistacctitle'                => 'คุณไม่ได้รับอนุญาตให้สร้างบัญชีผู้ใช้',
-'whitelistacctext'                 => 'เพื่อที่จะสร้างบัญชีผู้ใช้ในวิกินี้ คุณต้อง[[Special:Userlogin|ล็อกอิน]] และได้รับอนุญาตตามแต่เหมาะสม',
 'confirmedittitle'                 => 'ไม่อนุญาตให้แก้ไขถ้าไม่ได้ทำการยืนยันอีเมล',
 'confirmedittext'                  => 'ไม่อนุญาตให้แก้ไขถ้าไม่ได้ทำการยืนยันอีเมล กรุณายืนยันอีเมลผ่านทาง [[Special:Preferences|การตั้งค่าผู้ใช้]]',
 'nosuchsectiontitle'               => 'ไม่มีหัวข้อย่อย',
@@ -605,7 +599,7 @@
 'newarticletext'                   => 'หน้านี้ยังไม่มีข้อความใด สามารถเริ่มสร้างหน้านี้โดยการพิมพ์ข้อความลงในกล่องด้านล่าง
 (ดูเพิ่มเติมที่ [[{{MediaWiki:Helppage}}|หน้าคำอธิบาย]])
 ถ้าไม่ต้องการสร้างให้กดปุ่ม ถอยหลัง (back) ที่เว็บเบราว์เซอร์',
-'anontalkpagetext'                 => '----หน้านี้เป็นหน้าพูดคุยสำหรับผู้ใช้ที่ไม่ประสงค์ออกนามผู้ซึ่งยังไม่ได้สร้างบัญชีผู้ใช้ โดยทางเราจำเป็นต้องระบุผ่านทางหมายเลขไอพี อย่างไรก็ตามหมายเลขไอพีนี้ อาจจะเกิดจากจากผู้ใช้หลายคนก็ตาม ถ้าคุณเป็นผู้ไม่ประสงค์ออกนามและรู้สึกว่าข้อความความเห็นที่คุณได้รับไม่เกี่ยวข้องกับคุณแต่อย่างใด กรุณา[[Special:Userlogin|สร้างบัญชีผู้ใช้หรือทำการล็อกอิน]] เพื่อป้องกันการสับสนกับผู้ใช้ที่ไม่ล็อกอินรายอื่น',
+'anontalkpagetext'                 => '----หน้านี้เป็นหน้าพูดคุยสำหรับผู้ใช้ที่ไม่ประสงค์ออกนามผู้ซึ่งยังไม่ได้สร้างบัญชีผู้ใช้ โดยทางเราจำเป็นต้องระบุผ่านทางหมายเลขไอพี อย่างไรก็ตามหมายเลขไอพีนี้ อาจจะเกิดจากจากผู้ใช้หลายคนก็ตาม ถ้าคุณเป็นผู้ไม่ประสงค์ออกนามและรู้สึกว่าข้อความความเห็นที่คุณได้รับไม่เกี่ยวข้องกับคุณแต่อย่างใด กรุณา[[Special:UserLogin|สร้างบัญชีผู้ใช้หรือทำการล็อกอิน]] เพื่อป้องกันการสับสนกับผู้ใช้ที่ไม่ล็อกอินรายอื่น',
 'noarticletext'                    => 'ไม่มีข้อความในหน้านี้ ลอง[[Special:Search/{{PAGENAME}}|ค้นหา]]ในหน้าอื่นที่เกี่ยวข้อง หรืออาจจะ [{{fullurl:{{FULLPAGENAME}}|action=edit}} เริ่มสร้างหน้านี้]',
 'userpage-userdoesnotexist'        => 'ไม่มีบัญชีผู้ใช้ "$1" อยู่ในสารบบ  กรุณาตรวจสอบให้แน่ใจว่าคุณต้องการสร้างหรือแก้ไขหน้านี้จริงๆ',
 'clearyourcache'                   => "'''คำแนะนำ:''' หลังจากบันทึกผลแล้ว คุณอาจจะต้องล้างแคชเว็บเบราว์เซอร์ของคุณเพื่อดูผลการเปลี่ยนแปลง <br />
@@ -669,7 +663,7 @@
 'edittools'                        => '<!-- ข้อความนี้จะแสดงผลด้านใต้การแก้ไขและฟอร์มสำหรับอัปโหลด -->',
 'nocreatetitle'                    => 'จำกัดการสร้างหน้าใหม่',
 'nocreatetext'                     => 'เว็บไซต์นี้จำกัดการสร้างหน้าเว็บเพจใหม่
-คุณสามารถทำการแก้ไขหน้าที่สร้างไว้แล้ว หรือ [[Special:Userlogin|ล็อกอินหรือสร้างบัญชีผู้ใช้]]',
+คุณสามารถทำการแก้ไขหน้าที่สร้างไว้แล้ว หรือ [[Special:UserLogin|ล็อกอินหรือสร้างบัญชีผู้ใช้]]',
 'nocreate-loggedin'                => 'คุณไม่ได้รับสิทธิในการสร้างหน้าใหม่บน {{SITENAME}}.',
 'permissionserrors'                => 'ข้อผิดพลาดในการใช้สิทธิ',
 'permissionserrorstext'            => 'คุณไม่ได้รับสิทธิในการทำสิ่งนี้ตาม{{PLURAL:$1|เหตุผล|เหตุผล}}ต่อไปนี้ :',
@@ -856,7 +850,7 @@
 'mypreferences'            => 'ตั้งค่าส่วนตัว',
 'prefs-edits'              => 'จำนวนการแก้ไข:',
 'prefsnologin'             => 'ไม่ได้ล็อกอิน',
-'prefsnologintext'         => 'ต้อง[[Special:Userlogin|ล็อกอิน]]ก่อนเพื่อจะตั้งค่าส่วนตัว',
+'prefsnologintext'         => 'ต้อง[[Special:UserLogin|ล็อกอิน]]ก่อนเพื่อจะตั้งค่าส่วนตัว',
 'prefsreset'               => 'การตั้งค่าถูกตั้งเป็นค่าเริ่มต้น',
 'qbsettings'               => 'แถบพิเศษ',
 'qbsettings-none'          => 'ไม่มี',
@@ -930,7 +924,7 @@
 'userrights-reason'           => 'สาเหตุการเปลี่ยน:',
 'userrights-no-interwiki'     => 'คุณไม่ได้รับสิทธิในการแก้ไขสิทธิของผู้ใช้บนวิกิอื่นๆ',
 'userrights-nodatabase'       => 'ไม่มีฐานข้อมูล $1 อยู่ หรือ ฐานข้อมูลอยู่บนเครื่องอื่น',
-'userrights-nologin'          => 'คุณต้อง[[Special:Userlogin|ล็อกอิน]]ด้วยบัญชีผู้ใช้ที่เป็นผู้ดูแลสิทธิแต่งตั้ง จึงจะสามารถกำหนดสิทธิต่างๆ ของผู้ใช้ได้',
+'userrights-nologin'          => 'คุณต้อง[[Special:UserLogin|ล็อกอิน]]ด้วยบัญชีผู้ใช้ที่เป็นผู้ดูแลสิทธิแต่งตั้ง จึงจะสามารถกำหนดสิทธิต่างๆ ของผู้ใช้ได้',
 'userrights-notallowed'       => 'บัญชีผู้ใช้ของคุณไม่ได้รับสิทธิในการแก้ไขสิทธิของผู้ใช้',
 'userrights-changeable-col'   => 'กลุ่มที่คุณสามารถเปลี่ยนได้',
 'userrights-unchangeable-col' => 'กลุ่มที่คุณไม่สามารถเปลี่ยนได้',
@@ -1038,10 +1032,10 @@
 'reupload'                    => 'อัปโหลดใหม่',
 'reuploaddesc'                => 'กลับไปสู่หน้าอัปโหลด',
 'uploadnologin'               => 'ไม่ได้ล็อกอิน',
-'uploadnologintext'           => 'ต้องทำการ[[Special:Userlogin|ล็อกอิน]]ก่อนถึงจะอัปโหลดไฟล์ได้',
+'uploadnologintext'           => 'ต้องทำการ[[Special:UserLogin|ล็อกอิน]]ก่อนถึงจะอัปโหลดไฟล์ได้',
 'upload_directory_read_only'  => 'ไม่สามารถเก็บข้อมูลในไดเรกทอรี ($1) ปัญหาเกิดที่เว็บเซิร์ฟเวอร์',
 'uploaderror'                 => 'เกิดความขัดข้องในการอัปโหลด',
-'uploadtext'                  => "ใช้แบบฟอร์มด้านล่างในการอัปโหลด หรือดู[[Special:Imagelist|รายการไฟล์ที่ถูกอัปโหลดแล้ว]] การอัปโหลดที่ผ่านมาดูได้ [[Special:Log/upload|บันทึกการอัปโหลด]]
+'uploadtext'                  => "ใช้แบบฟอร์มด้านล่างในการอัปโหลด หรือดู[[Special:ImageList|รายการไฟล์ที่ถูกอัปโหลดแล้ว]] การอัปโหลดที่ผ่านมาดูได้ [[Special:Log/upload|บันทึกการอัปโหลด]]
 
 ถ้าต้องการใช้งานไฟล์ที่อัปโหลดให้ใช้คำสั่งดังตัวอย่างต่อไปนี้
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1124,7 +1118,7 @@
 'upload_source_url'  => ' (ค่าถูกต้อง ยูอาร์แอลที่ใช้งานได้)',
 'upload_source_file' => ' (ไฟล์จากคอมพิวเตอร์คุณ)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'หน้าพิเศษนี้แสดงไฟล์ทั้งหมดที่ถูกอัปโหลด
 โดยปริยาย ไฟล์ที่ถูกอัปโหลดล่าสุด จะแสดงอยู่บนสุดของรายการไฟล์
 คลิกที่คอมลัมน์บนสุดจะเปลี่ยนการจัดแยกประเภท',
@@ -1152,7 +1146,7 @@
 'imagelinks'                     => 'หน้าที่ใช้ภาพนี้',
 'linkstoimage'                   => '{{PLURAL:$1|หน้า|หน้า}}ที่ลิงก์มายังไฟล์นี้:',
 'nolinkstoimage'                 => 'ไม่มีหน้าที่ใช้ภาพนี้',
-'morelinkstoimage'               => 'ดู[[Special:Whatlinkshere/$1|หน้าที่ลิงก์]]มายังไฟล์นี้เพิ่มเติม',
+'morelinkstoimage'               => 'ดู[[Special:WhatLinksHere/$1|หน้าที่ลิงก์]]มายังไฟล์นี้เพิ่มเติม',
 'redirectstofile'                => '{{PLURAL:$1|ไฟล์|$1 ไฟล์}}ดังต่อไปนี้เปลี่ยนทางมาที่ไฟล์นี้:',
 'duplicatesoffile'               => '{{PLURAL:$1|ไฟล์|ไฟล์}}นี้ซ้ำกับไฟล์ดังต่อไปนี้:',
 'sharedupload'                   => 'ไฟล์นี้เป็นไฟล์ที่ใช้ร่วมหลายโครงการ และอาจถูกใช้งานในโครงการอื่น',
@@ -1180,7 +1174,7 @@
 'filedelete'                  => 'ลบ $1',
 'filedelete-legend'           => 'ลบไฟล์',
 'filedelete-intro'            => "คุณกำลังลบ '''[[Media:$1|$1]]'''",
-'filedelete-intro-old'        => '<span class="plainlinks">คุณกำลังลบ \'\'\'[[Media:$1|$1]]\'\'\' รุ่น [$4 $3, $2]</span>',
+'filedelete-intro-old'        => "คุณกำลังลบ '''[[Media:$1|$1]]''' รุ่น [$4 $3, $2]",
 'filedelete-comment'          => 'เหตุผลในการลบ:',
 'filedelete-submit'           => 'ลบ',
 'filedelete-success'          => "ลบไฟล์ '''$1''' เรียบร้อยแล้ว",
@@ -1324,7 +1318,7 @@
 'logempty'             => 'ไม่มีในบันทึกก่อนหน้า',
 'log-title-wildcard'   => 'ค้นหาคำหลากหลาย',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'หน้าทุกหน้า',
 'alphaindexline'    => '$1 ไป $2',
 'nextpage'          => 'ถัดไป ($1)',
@@ -1347,12 +1341,12 @@
 'special-categories-sort-count' => 'เรียงตามจำนวน',
 'special-categories-sort-abc'   => 'เรียงลำดับตามตัวอักษร',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'แสดงชื่อผู้ใช้เริ่มต้นจาก:',
 'listusers-submit'   => 'แสดง',
 'listusers-noresult' => 'ไม่พบผู้ใช้ที่ต้องการ',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'สิทธิกลุ่มผู้ใช้งาน',
 'listgrouprights-group'    => 'กลุ่ม',
 'listgrouprights-rights'   => 'สิทธิ',
@@ -1361,7 +1355,7 @@
 
 # E-mail user
 'mailnologin'     => 'ไม่มีการส่งอีเมล',
-'mailnologintext' => 'ต้องการทำ[[Special:Userlogin|ล็อกอิน]]และตั้งค่าอีเมลในส่วน[[Special:Preferences|การตั้งค่า]] เพื่อจะส่งอีเมลหาผู้ใช้คนอื่น',
+'mailnologintext' => 'ต้องการทำ[[Special:UserLogin|ล็อกอิน]]และตั้งค่าอีเมลในส่วน[[Special:Preferences|การตั้งค่า]] เพื่อจะส่งอีเมลหาผู้ใช้คนอื่น',
 'emailuser'       => 'ส่งอีเมลหาผู้ใช้นี้',
 'emailpage'       => 'อีเมลผู้ใช้',
 'emailpagetext'   => 'ถ้าผู้ใช้คนนี้ได้ตั้งค่าอีเมลในส่วนการตั้งค่าส่วนตัว ข้อความด้านล่างจะถูกส่งผ่านไปที่อีเมลผู้รับ โดยอีเมลของคุณจะแสดงผลในส่วน "อีเมลจาก" ซึ่งสามารถให้ผู้รับตอบกลับได้',
@@ -1387,10 +1381,10 @@
 'nowatchlist'          => 'ไม่ได้ใส่หน้าไหนเข้ารายการเฝ้าดู',
 'watchlistanontext'    => 'กรุณา $1 เพื่อที่จะดูหรือแก้ไขหน้าในรายการเฝ้าดู',
 'watchnologin'         => 'ไม่ได้ล็อกอิน',
-'watchnologintext'     => 'ต้อง[[Special:Userlogin|ล็อกอิน]]เพื่อที่จะแก้ไขรายการเฝ้าดู',
+'watchnologintext'     => 'ต้อง[[Special:UserLogin|ล็อกอิน]]เพื่อที่จะแก้ไขรายการเฝ้าดู',
 'addedwatch'           => 'ถูกใส่เข้ารายการเฝ้าดู',
 'addedwatchtext'       => 'หน้า "[[:$1]]" ถูกใส่เข้าไปใน[[Special:Watchlist|รายการเฝ้าดู]]ของคุณ ถ้ามีการเปลี่ยนแปลงเกิดขึ้นในหน้าเหล่านี้ รวมถึงหน้าพูดคุยของหน้านี้
-รายชื่อหน้าจะแสดงเป็นตัวหนาในส่วนของ[[Special:Recentchanges|หน้าการเปลี่ยนแปลงล่าสุด]]เพื่อให้โดดเด่นเป็นที่สังเกต
+รายชื่อหน้าจะแสดงเป็นตัวหนาในส่วนของ[[Special:RecentChanges|หน้าการเปลี่ยนแปลงล่าสุด]]เพื่อให้โดดเด่นเป็นที่สังเกต
 ถ้าไม่ต้องการเฝ้าดูให้กดที่  "เลิกเฝ้าดู" ในส่วนของเมนู',
 'removedwatch'         => 'ถูกนำออกจากรายการเฝ้าดู',
 'removedwatchtext'     => 'หน้า "[[:$1]]"ถูกนำออกจากรายการเฝ้าดู',
@@ -1500,7 +1494,7 @@
 'rollback-success'            => 'ย้อนการแก้ไขของ $1 ไปยังรุ่นของ $2',
 'sessionfailure'              => 'ท่าทางจะมีปัญหาเกี่ยวการล็อกอินในช่วงเวลานี้ เกิดจากทางระบบป้องกันการลักลอบการขโมยล็อกอิน กรุณาย้อนกลับไปหน้าก่อนหน้า และลองโหลดใหม่อีกครั้ง',
 'protectlogpage'              => 'บันทึกการล็อก',
-'protectlogtext'              => 'รายการด้านล่างแสดงการล็อกหน้าและการปลดล็อก สำหรับหน้าที่โดนล็อกในปัจจุบันดูที่ [[Special:Protectedpages|รายการหน้าที่ถูกล็อก]]',
+'protectlogtext'              => 'รายการด้านล่างแสดงการล็อกหน้าและการปลดล็อก สำหรับหน้าที่โดนล็อกในปัจจุบันดูที่ [[Special:ProtectedPages|รายการหน้าที่ถูกล็อก]]',
 'protectedarticle'            => '"[[$1]]" ถูกล็อก',
 'modifiedarticleprotection'   => 'เปลี่ยนระดับการล็อกสำหรับ "[[$1]]"',
 'unprotectedarticle'          => '"[[$1]]" ถูกปลดล็อก',
@@ -1656,7 +1650,7 @@
 'badipaddress'                => 'หมายเลขไอพีไม่ถูกต้อง',
 'blockipsuccesssub'           => 'บล็อกเรียบร้อย',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] ถูกบล็อก
-<br />ดู  [[Special:Ipblocklist|รายการไอพีที่ถูกบล็อก]] เพื่อตรวจสอบการบล็อก',
+<br />ดู  [[Special:IPBlockList|รายการไอพีที่ถูกบล็อก]] เพื่อตรวจสอบการบล็อก',
 'ipb-edit-dropdown'           => 'แก้ไขสาเหตุการบล็อก',
 'ipb-unblock-addr'            => 'เลิกบล็อก $1',
 'ipb-unblock'                 => 'เลิกบล็อกผู้ใช้หรือหมายเลขไอพี',
@@ -1686,7 +1680,7 @@
 'autoblocker'                 => 'ถูกบล็อกอัตโนมัติเนื่องจากหมายเลขไอพีของคุณตรงกับ "[[User:$1|$1]]" ถูกบล็อกกล่อนหน้านี้เนื่องจากสาเหตุ: "$2"',
 'blocklogpage'                => 'บันทึกการบล็อก',
 'blocklogentry'               => 'บล็อก "[[$1]]" หมดอายุ $2 $3',
-'blocklogtext'                => 'ด้านล่างเป็นบันทึกการบล็อกและการเลิกบล็อก  ส่วนการบล็อกอัตโนมัติจะไม่ถูกรวมอยู่ในรายการนี้ ดู [[Special:Ipblocklist|รายการบล็อกไอพี]] สำหรับการบล็อกทั้งหมด',
+'blocklogtext'                => 'ด้านล่างเป็นบันทึกการบล็อกและการเลิกบล็อก  ส่วนการบล็อกอัตโนมัติจะไม่ถูกรวมอยู่ในรายการนี้ ดู [[Special:IPBlockList|รายการบล็อกไอพี]] สำหรับการบล็อกทั้งหมด',
 'unblocklogentry'             => 'เลิกบล็อก $1',
 'block-log-flags-anononly'    => 'ผู้ใช้ไม่ล็อกอินเท่านั้น',
 'block-log-flags-nocreate'    => 'ห้ามสร้างบัญชีผู้ใช้',
@@ -1719,7 +1713,7 @@
 'lockdbsuccesssub'    => 'ล็อกฐานข้อมูลเรียบร้อย',
 'unlockdbsuccesssub'  => 'ปลดล็อกฐานข้อมูลเรียบร้อย',
 'lockdbsuccesstext'   => 'ล็อกฐานข้อมูลเรียบร้อย
-<br />อย่าลืมที่จะ [[Special:Unlockdb|ปลดล็อก]] เพื่อให้ใช้งานได้ตามปกติ',
+<br />อย่าลืมที่จะ [[Special:UnlockDB|ปลดล็อก]] เพื่อให้ใช้งานได้ตามปกติ',
 'unlockdbsuccesstext' => 'ปลดล็อกฐานข้อมูลเรียบร้อย',
 'lockfilenotwritable' => 'ไม่สามารถล็อกฐานข้อมูลได้ เนื่องจากการเขียนลงฐานข้อมูล การล็อกและการปลดล็อกจำเป็นต้องทำที่เว็บเซิร์ฟเวอร์',
 'databasenotlocked'   => 'ฐานข้อมูลไม่ได้ล็อก',
@@ -1741,8 +1735,6 @@
 
 ในกรณีนั้นให้เปลี่ยนชื่อหน้าเอง",
 'movearticle'             => 'เปลี่ยนชื่อ',
-'movenologin'             => 'ไม่ได้ล็อกอิน',
-'movenologintext'         => 'ถ้าต้องการเปลี่ยนชื่อหน้านี้ ต้องลงทะเบียนและให้ทำการ[[Special:Userlogin|ล็อกอิน]]',
 'movenotallowed'          => 'คุณไม่ได้รับสิทธิในการย้ายหน้าบน {{SITENAME}}',
 'newtitle'                => 'ชื่อใหม่',
 'move-watch'              => 'เฝ้าดูหน้านี้',
@@ -1769,7 +1761,7 @@
 'delete_and_move'         => 'ลบและย้าย',
 'delete_and_move_text'    => '== จำเป็นต้องลบ ==
 
-ชื่อหัวข้อที่ต้องการ "[[$1]]" มีอยู่แล้ว แน่ใจหรือไม่ว่าต้องการลบเพื่อที่จะให้การเปลี่ยนชื่อสำเร็จ',
+ชื่อหัวข้อที่ต้องการ "[[:$1]]" มีอยู่แล้ว แน่ใจหรือไม่ว่าต้องการลบเพื่อที่จะให้การเปลี่ยนชื่อสำเร็จ',
 'delete_and_move_confirm' => 'ยืนยัน ต้องการลบ',
 'delete_and_move_reason'  => 'ถูกลบสำหรับการเปลี่ยนชื่อ',
 'selfmove'                => 'ชื่อหน้าเดิมและหน้าใหม่เป็นชื่อเดียวกัน ไม่สามารถเปลี่ยนชื่อได้',
@@ -2001,7 +1993,7 @@
 'show-big-image'       => 'ความละเอียดสูงสุด',
 'show-big-image-thumb' => '<small>ขนาดของภาพแสดงผล: $1 × $2 พิกเซล</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'แกลลอรีภาพใหม่',
 'imagelisttext'         => "รายชื่อไฟล์ '''$1''' รายการ เรียงตาม$2",
 'newimages-summary'     => 'หน้าพิเศษนี้แสดงไฟล์ที่ถูกอัปโหลดล่าสุด',
@@ -2282,7 +2274,7 @@
 
 # External editor support
 'edit-externally'      => 'แก้ไขไฟล์นี้โดยใช้ซอฟต์แวร์ตัวอื่น',
-'edit-externally-help' => 'ดูเพิ่มที่ [http://meta.wikimedia.org/wiki/Help:External_editors วิธีการตั้งค่า]',
+'edit-externally-help' => 'ดูเพิ่มที่ [http://www.mediawiki.org/wiki/Manual:External_editors วิธีการตั้งค่า]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ทั้งหมด',
@@ -2346,7 +2338,7 @@
 'recreate'            => 'สร้างใหม่',
 
 # HTML dump
-'redirectingto' => 'กำลังเปลี่ยนทางไปที่ [[$1]]...',
+'redirectingto' => 'กำลังเปลี่ยนทางไปที่ [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'ล้างแคชสำหรับหน้านี้หรือไม่
@@ -2446,7 +2438,7 @@
 'version-software-product'         => 'ชื่อ',
 'version-software-version'         => 'รุ่น',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'ตำแหน่งไฟล์',
 'filepath-page'   => 'ไฟล์ :',
 'filepath-submit' => 'ตำแหน่งไฟล์',
@@ -2478,7 +2470,7 @@
 'specialpages-group-redirects'   => 'เปลี่ยนทางหน้าพิเศษ',
 'specialpages-group-spam'        => 'เครื่องมือเกี่ยวกับสแปม',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'หน้าว่างเปล่า',
 'intentionallyblankpage' => 'หน้านี้ถูกทิ้งว่างโดยเจตนา',
 
Index: languages/messages/MessagesPam.php
===================================================================
--- languages/messages/MessagesPam.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPam.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Katimawan2005
  * @author Val2397
- * @author Siebrand
- * @author SPQRobin
  */
 
 $messages = array(
@@ -285,7 +283,7 @@
 'nosuchspecialpage' => 'Alang bulung a makabukud/espesial a anti kanian',
 'nospecialpagetext' => "<big>'''E ustu ing aduan mung bulung a makabukud.'''</big>
 
-Ating tala da reng bulung a makabukud king [[Special:Specialpages|{{int:specialpages}}]].",
+Ating tala da reng bulung a makabukud king [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Mali',
@@ -536,10 +534,6 @@
 'blockededitsource'         => "Atyu king lalam ing makasulat ketang '''ding kekang in-edit''' king '''$1''' ('''your edits''' to '''$1'''):",
 'whitelistedittitle'        => 'Kailangang mag-login bang makapag-edit',
 'whitelistedittext'         => 'Kailangan mung $1 bayu ka makapag-edit bulung.',
-'whitelistreadtitle'        => 'Kailangang mag-login bang makapamasa',
-'whitelistreadtext'         => 'Kailangan mung [[Special:Userlogin|mag-login]] ba kang makapamasang bulung.',
-'whitelistacctitle'         => 'Ala kang paintulut maglalang account',
-'whitelistacctext'          => 'Kailangan mung [[Special:Userlogin|mag-login]] at mirinan karetang makayagpang a paintulut ba kang makapaglalang account king {{SITENAME}}.',
 'confirmedittitle'          => 'Kaylangan yang patutwan ing kekang e-mail ba kang makapag-edit o makapanalili.',
 'confirmedittext'           => "Kailangan meng kumpirman ing kekang e-mail address bayo mo a-edit deting bulung.
 Pakisulat me at patutuan ing kekang e-mail address kapamilata'ning [[Special:Preferences|pinili ning talagamit]] (user preferences).",
@@ -555,7 +549,7 @@
 'newarticletext'            => "Dela na ka ning suglung king bulung a e pa melalang.
 Ba meng lalangan ing bulung a iti, sumulat ka king kahun king lalam (lon me ing  [[{{MediaWiki:Helppage}}|help page]] para king karagdagang impormasiun).
 Nung migkamali kang minta keni, i-click me mu ing '''back''' (mibalik) button ning kekang browser.",
-'anontalkpagetext'          => "----''Ini ing bulung ning pamitalamitam (discussion page) para kareng gagamit a e pepakilala, e pa miglalang account, o e gagamit kaniti. Uli na nita, kaylangan ming gumamit IP address a nomiru ba yang makilala. Mapalyaring e ya mu metung ing gagamit kaniti. Nung metung kang gagamit a e pepakilala at king palage mu, mituran ka o meyatu king e dapat, pakisabi ming [[Special:Userlogin|maglalang kang account o mag-log in]] ba ra kang e pagkamalyan kareng aliwang gagamit.''",
+'anontalkpagetext'          => "----''Ini ing bulung ning pamitalamitam (discussion page) para kareng gagamit a e pepakilala, e pa miglalang account, o e gagamit kaniti. Uli na nita, kaylangan ming gumamit IP address a nomiru ba yang makilala. Mapalyaring e ya mu metung ing gagamit kaniti. Nung metung kang gagamit a e pepakilala at king palage mu, mituran ka o meyatu king e dapat, pakisabi ming [[Special:UserLogin|maglalang kang account o mag-log in]] ba ra kang e pagkamalyan kareng aliwang gagamit.''",
 'noarticletext'             => 'King salukuyan, alang sulat king bulung a ini; malyari meng [[Special:Search/{{PAGENAME}}|paintunan ing pamagat ning bulung a ini]] kareng aliwang bulung o [{{fullurl:{{FULLPAGENAME}}|action=edit}} i-edit ining bulung].',
 'userpage-userdoesnotexist' => 'E makarehistru ing account ning talagamit (user account) a "$1". Pakilawe mu nung buri meng lalangan o i-edit ing bulung a ini.',
 'clearyourcache'            => "'''Kapabaluan:''' Kaibat mung mig-save, maliari meng lakton ing simpan (cache) ning kekang browser ba mong akit deng miyalilan. '''Mozilla / Firefox / Safari:''' timid me ing ''Shift'' kabang ki-click me ing ''Reload'', o timid me ing ''Ctrl-Shift-R'' (''Cmd-Shift-R'' king Apple Mac); '''IE:''' timid me ing ''Ctrl'' kabang ki-click me ing ''Refresh'', o timid me ing ''Ctrl-F5''; '''Konqueror:''': i-click me mu ing ''Reload'' button, o timid me ing ''F5''; deng talagamit ning '''Opera''', mapaliaring kailangan deng laganas a linisan (i-clear) ing karelang simpan (cache) king ''Tools→Preferences''.",
@@ -623,7 +617,7 @@
 'hiddencategories'          => 'Kayabe ya ing bulung a ini king/karing {{PLURAL:$1|1 makasalikut a kategoriya|$1 makasalikut a kategoriya}}:',
 'nocreatetitle'             => 'Maki angganan (limitadu) ing pamangawang bulung',
 'nocreatetext'              => 'Lilimitan ning {{SITENAME}} ing pamangawa kareng bayung bulung.
-Malyari kang magbalik at mag-edit king bulung a atyu na, o makapag[[Special:Userlogin|log in ka at maglalang account]].',
+Malyari kang magbalik at mag-edit king bulung a atyu na, o makapag[[Special:UserLogin|log in ka at maglalang account]].',
 'nocreate-loggedin'         => 'Ala kang paintulut a maglalang bayung bulung king {{SITENAME}}.',
 'permissionserrors'         => 'Pamagkamali king Pamaniad Paintulut',
 'permissionserrorstext'     => 'Ala kang paintulut bang gawan ita, uling kareng makatuking {{PLURAL:$1|sangkan|sangkan}}:',
@@ -733,7 +727,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Tala da reng mibawal (suppression log)',
-'suppressionlogtext' => 'Oini ing tala da reng mebura ampong mesabat a maki kaugnayan kareng kasulatang makasalikut kareng sysop. Lon ya ing [[Special:Ipblocklist|IP block list]] para king tala da reng kasalungsungan a mimiral a pamagbawal ampong pamaniabat.',
+'suppressionlogtext' => 'Oini ing tala da reng mebura ampong mesabat a maki kaugnayan kareng kasulatang makasalikut kareng sysop. Lon ya ing [[Special:IPBlockList|IP block list]] para king tala da reng kasalungsungan a mimiral a pamagbawal ampong pamaniabat.',
 
 # History merging
 'mergehistory'                     => 'Piyabe/pisanib la reng amlat ding bulung',
@@ -820,7 +814,7 @@
 'mypreferences'            => 'Deng pinili ku',
 'prefs-edits'              => 'Bilang da reng edit:',
 'prefsnologin'             => 'ekamaka log',
-'prefsnologintext'         => 'Kailangan kang [[Special:Userlogin|maka-login]] ba mong apagana deng pinili ning talagamit (user preferences).',
+'prefsnologintext'         => 'Kailangan kang [[Special:UserLogin|maka-login]] ba mong apagana deng pinili ning talagamit (user preferences).',
 'prefsreset'               => 'Misubli king sadia manibat ketang makasimpan (storage) deng pinili/preferences.',
 'qbsettings-none'          => 'Ala',
 'qbsettings-fixedleft'     => 'Makapirmi ya ing kaili',
@@ -891,7 +885,7 @@
 'userrights-reason'           => 'Sangkan king pamanalili:',
 'userrights-no-interwiki'     => 'Ala kang paintulut a i-edit la reng katuliran da reng talagamit (user rights) kareng aliwang wiki.',
 'userrights-nodatabase'       => 'Alang database a $1 o e ya lokal iti.',
-'userrights-nologin'          => 'Kailangan mung [[Special:Userlogin|mag-login]] king metung a administrator account ba kang makapamieng katulirang talagamit (user rights).',
+'userrights-nologin'          => 'Kailangan mung [[Special:UserLogin|mag-login]] king metung a administrator account ba kang makapamieng katulirang talagamit (user rights).',
 'userrights-notallowed'       => 'Ala yang paintulut mamieng katulirang talagamit (user rights) ing kekang account.',
 'userrights-changeable-col'   => 'Deng grupung maliari mung alilan',
 'userrights-unchangeable-col' => 'Deng grupung e mu maliaring alilan',
@@ -1019,11 +1013,11 @@
 'reupload'                    => 'Ilulan yang pasibayu',
 'reuploaddesc'                => 'Iurung ya ing pamaglulan at isubli ya king upload form',
 'uploadnologin'               => 'E maka-login',
-'uploadnologintext'           => 'Kailangan kang [[Special:Userlogin|maka-login]] ba kang makapaglulan simpan (upload files).',
+'uploadnologintext'           => 'Kailangan kang [[Special:UserLogin|maka-login]] ba kang makapaglulan simpan (upload files).',
 'upload_directory_read_only'  => 'E ne maliaring sulatanan ning webserver ing piyakitan pamaglulan o upload directory ($1).',
 'uploaderror'                 => 'Migkamaling maglulan',
 'uploadtext'                  => "Gamitan me ing ayus (form) king lalam bang maglulan simpan (upload files).
-Ba mong lon o paintunan deng simpan a sadia nang milulan, munta ka king [[Special:Imagelist|tala da reng simpan a milulan]]; maka-login la murin deng milulan ampong mebura king [[Special:Log/upload|tala da reng milulan (upload log)]].
+Ba mong lon o paintunan deng simpan a sadia nang milulan, munta ka king [[Special:ImageList|tala da reng simpan a milulan]]; maka-login la murin deng milulan ampong mebura king [[Special:Log/upload|tala da reng milulan (upload log)]].
 
 Ba yang iyabe ing simpan king metung a bulung gamitan me ing suglung (link) king ayus (form) a
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1122,7 +1116,7 @@
 'upload_source_url'  => ' (metung a URL a matatanggap at aluban ding malda)',
 'upload_source_file' => ' (metung a simpan king kekang computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Papakit no ngan niting bulung a makabukud/espesial deng simpan a milulan (uploaded files).
 Karaniwan, keta lang babo ning tala deng simpan a tauling milulan.
 Miyalilan ing pamanayus nung i-click ya ing pamagat ning kolum (column header).',
@@ -1166,18 +1160,18 @@
 # File reversion
 'filerevert'                => 'Isubli ya ing $1',
 'filerevert-legend'         => 'Isubli (revert) ya ing simpan',
-'filerevert-intro'          => '<span class="plainlinks">Susubli me ing \'\'\'[[Media:$1|$1]]\'\'\' king [$4 bersion aniang $3, $2].</span>',
+'filerevert-intro'          => "Susubli me ing '''[[Media:$1|$1]]''' king [$4 bersion aniang $3, $2].",
 'filerevert-comment'        => 'Komentu:',
 'filerevert-defaultcomment' => 'Misubli ya king bersion aniang $2, $1',
 'filerevert-submit'         => 'Isubli',
-'filerevert-success'        => '<span class="plainlinks">Ing \'\'\'[[Media:$1|$1]]\'\'\' misubli ya king [$4 bersion aniang $3, $2].</span>',
+'filerevert-success'        => "Ing '''[[Media:$1|$1]]''' misubli ya king [$4 bersion aniang $3, $2].",
 'filerevert-badversion'     => 'Alang sadiang/minunang lokal a bersion na niting simpan a tambing maki timestamp.',
 
 # File deletion
 'filedelete'                  => 'Buran ya ing $1',
 'filedelete-legend'           => 'Buran ya ing simpan (file)',
 'filedelete-intro'            => "Buburan me ing '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Buburan me ing bersion ning \'\'\'[[Media:$1|$1]]\'\'\' aniang [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Buburan me ing bersion ning '''[[Media:$1|$1]]''' aniang [$4 $3, $2].",
 'filedelete-comment'          => 'Sangkan king pamamura:',
 'filedelete-submit'           => 'Buran',
 'filedelete-success'          => "Mebura ne ing '''$1'''.",
@@ -1231,7 +1225,7 @@
 King kabilugan, miras ya iti king average a '''\$5''' a pamagbayu o edit balang bulung, at '''\$6''' a pamaglawe balang edit.  
 
 Ing kaba ning [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]  '''\$7''' ya.",
-'userstatstext'          => "Ating {{PLURAL:$1|'''1''' a makarehistrung [[Special:Listusers|talagamit]]|'''$1''' makarehistrung [[Special:Listusers|talagamit]]}}, at kareti '''$2''' (o '''$4%''') {{PLURAL:$2|ing|ing}} maki katuliran (rights) a $5.",
+'userstatstext'          => "Ating {{PLURAL:$1|'''1''' a makarehistrung [[Special:ListUsers|talagamit]]|'''$1''' makarehistrung [[Special:ListUsers|talagamit]]}}, at kareti '''$2''' (o '''$4%''') {{PLURAL:$2|ing|ing}} maki katuliran (rights) a $5.",
 'statistics-mostpopular' => 'Bulung a pekamaralas dang linawe',
 
 'disambiguations'      => 'Bulung a pamipalino',
@@ -1325,7 +1319,7 @@
 'logempty'             => 'Ala yang kapareu (matching items) king tala (log).',
 'log-title-wildcard'   => 'Maintun bansag (title) magumpisa king sulat a ini',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Deng eganaganang bulung',
 'alphaindexline'    => '$1 papuntang $2',
 'nextpage'          => 'Tutuking bulung ($1)',
@@ -1347,12 +1341,12 @@
 'special-categories-sort-count' => 'surian tukituki agpang keng bilang',
 'special-categories-sort-abc'   => 'surian lang tukituki agpang keng kulitan',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Ipakit la reng talagamit magumpisa king:',
 'listusers-submit'   => 'Pakit',
 'listusers-noresult' => 'Alang meyakit a talagamit.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Katuliran da reng grupung talagamit (user group rights)',
 'listgrouprights-summary'  => 'Ing makatuki tala (list) de reng grupung talagamit a mituldu kening wiki, ampo reng karelang katuliran king pamaglub (access rights). Ating karagdagang impormasiun tungkul king katuliran ning balang metung [[{{MediaWiki:Listgrouprights-helppage}}|keni]].',
 'listgrouprights-group'    => 'Grupu',
@@ -1362,7 +1356,7 @@
 
 # E-mail user
 'mailnologin'     => 'Alang piparalan (no send address)',
-'mailnologintext' => 'Kailangan [[Special:Userlogin|maka-login]] ka at maki gaganang e-mail address kareng kekang  [[Special:Preferences|pinili]] ba kang makaparalang e-mail kareng aliwang talagamit.',
+'mailnologintext' => 'Kailangan [[Special:UserLogin|maka-login]] ka at maki gaganang e-mail address kareng kekang  [[Special:Preferences|pinili]] ba kang makaparalang e-mail kareng aliwang talagamit.',
 'emailuser'       => 'E-mail me ing talagamit a ini',
 'emailpage'       => 'E-mail talagamit',
 'emailpagetext'   => 'Nung atin yang gaganang e-mail address ketang kayang pinili ning talagamit (user preferences) ing talagamit a ini, magparla yang metung a mensahi ing form king lalam. Lunto ya ing e-mail address a sinulat mu ketang kekang pinili ning talagamit ketang  "From" address ("ibat kang") ning sulat, ba yang makapakibat itang miparalan.',
@@ -1387,11 +1381,11 @@
 'nowatchlist'          => 'Ala yang laman ing kekang tala ring babanten (watchlist).',
 'watchlistanontext'    => 'Paki $1 ba mong akit o a-edit deng laman ning kekang tala ring babanten (watchlist).',
 'watchnologin'         => 'E maka-login',
-'watchnologintext'     => 'Kailangan kang [[Special:Userlogin|maka-login]] ba meng abayu ing kekang tala ding babanten (watchlist).',
+'watchnologintext'     => 'Kailangan kang [[Special:UserLogin|maka-login]] ba meng abayu ing kekang tala ding babanten (watchlist).',
 'addedwatch'           => 'Midagdag king babanten a tala.',
 'addedwatchtext'       => "Miragdag ya ing bulung a \"[[:\$1]]\" king kekang [[Special:Watchlist|watchlist]].
 Mitala la karin deng miyalilan king bulung a iti ampo ing kayang Talk page. Lunto ya
-muring '''pepakapal''' ing bulung ketang [[Special:Recentchanges|tala da reng bayung miyalilan]] ba kang e magkasakit maintun kaniti.
+muring '''pepakapal''' ing bulung ketang [[Special:RecentChanges|tala da reng bayung miyalilan]] ba kang e magkasakit maintun kaniti.
 
 Nung buri meng idayu potang kayi itang bulung ketang tala da reng babanten mu, paki
 click me ing \"Tuknangan ing pamagbante\" (Unwatch) king gilid na ning bulung.",
@@ -1511,7 +1505,7 @@
 Pakitimid me ing "mibalik" ("back") at luban meng pasibayu ing bulung a penibatan mu, potang kai subukan mung pasibayu.',
 'protectlogpage'              => 'Tala da reng babanten',
 'protectlogtext'              => 'Maki tala da reng pamaniara ampong pamamusning bulung (page locks and unlocks) king lalam.
-Lon me ing [[Special:Protectedpages|tala ring bulung a protektadu/makakambil]] para king tala ring proteksiung bulung a gagana king salukuyan.',
+Lon me ing [[Special:ProtectedPages|tala ring bulung a protektadu/makakambil]] para king tala ring proteksiung bulung a gagana king salukuyan.',
 'protectedarticle'            => 'protektadu/makakambil "[[$1]]"',
 'modifiedarticleprotection'   => 'miyalilan ing sikan ning proteksiun/pamangambil para king "[[$1]]"',
 'unprotectedarticle'          => 'e protektadu "[[$1]]"',
@@ -1676,7 +1670,7 @@
 'badipaddress'                => 'E matatanggap ing IP address',
 'blockipsuccesssub'           => 'Ing sabat migtagumpe ya',
 'blockipsuccesstext'          => 'Mesabat ya ing [[Special:Contributions/$1|$1]]
-<br />Lon me ing [[Special:Ipblocklist|IP block list]] ba mong akit detang mesabat.',
+<br />Lon me ing [[Special:IPBlockList|IP block list]] ba mong akit detang mesabat.',
 'ipb-edit-dropdown'           => 'Sangkan ning pamaniabat king pamag-edit',
 'ipb-unblock-addr'            => 'Ilako ya pangasabat ing $1',
 'ipb-unblock'                 => 'Ilako ya pangasabat ing lagyungtalagamit (username) o IP address',
@@ -1708,7 +1702,7 @@
 'blocklogentry'               => 'Mesabat ya ing "[[$1]]" a mapupus kilub ning $2 $3',
 'blocklogtext'                => 'Ini tala (log) de reng pamaniabat ampong pamaglako pangasabat kareng talagamit.
 E la makabili deng IP address a tambing nang makasabat.
-Lon me ing [[Special:Ipblocklist|IP block list]] para king tala da reng kasalungsungan a makabawal o makasabat.',
+Lon me ing [[Special:IPBlockList|IP block list]] para king tala da reng kasalungsungan a makabawal o makasabat.',
 'unblocklogentry'             => 'milako pangasabat $1',
 'block-log-flags-anononly'    => 'den mung gagamit a e pepakilala',
 'block-log-flags-nocreate'    => 'pamilalang account e malyari',
@@ -1746,7 +1740,7 @@
 'lockdbsuccesssub'    => 'Melaus ing pamaniara ning database',
 'unlockdbsuccesssub'  => 'Milako ing pangasara ning database',
 'lockdbsuccesstext'   => 'Makasara ya ing database.<br />
-Tandanan meng [[Special:Unlockdb|ibusni]] kayari ning kekang pamanayus (maintenance).',
+Tandanan meng [[Special:UnlockDB|ibusni]] kayari ning kekang pamanayus (maintenance).',
 'unlockdbsuccesstext' => 'Mibusni ne ing database.',
 'lockfilenotwritable' => 'E maliaring sulatanan ing database lock file (simpan pamaniara ning database).
 Kailangan, maliari neng sulatanan ning web server iti ba yang isara o ibusni ing database.',
@@ -1772,8 +1766,6 @@
 
 Nung makanyan pin ing milyari, kailangan meng iyalis o isanib (merge) ing bulung a saparadu nung ita ing buri mung gawan.",
 'movearticle'             => 'Ialis ya ing bulung',
-'movenologin'             => 'E maka-login',
-'movenologintext'         => 'Kailangan, metung kang talagamit a makarehistru at [[Special:Userlogin|maka-login]] ka ba kang makapanalis bulung.',
 'movenotallowed'          => 'Ala kang paintulut a manalis bulung king {{SITENAME}}.',
 'newtitle'                => 'King bayung bansag:',
 'move-watch'              => 'Banten ya ing bulung a ini',
@@ -1796,7 +1788,7 @@
 'revertmove'              => 'isubli',
 'delete_and_move'         => 'Buran at ialis',
 'delete_and_move_text'    => '==Kailangan ing pamamura==
-Atiu ne ing "[[$1]]" a bulung a puntalan.
+Atiu ne ing "[[:$1]]" a bulung a puntalan.
 Buri meng buran bang malaus ing pamanales?',
 'delete_and_move_confirm' => 'Wa, buran ya ing bulung',
 'delete_and_move_reason'  => 'Mebura ya bang malaus ing pamanalis',
@@ -2031,10 +2023,10 @@
 'show-big-image'       => 'Pekamalino',
 'show-big-image-thumb' => '<small>Dagul na niting preview: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Pirinan kareng bayung simpan (new files)',
 'imagelisttext'         => "Ing makatuki tala yang '''$1''' {{PLURAL:$1|simpan|simpan}} a misamasan $2.",
-'newimages-summary'     => 'Ining bulung a makabukud papakit no reng simpan (file) a tauling milulan',
+'newimages-summary'     => 'Ining bulung a makabukud papakit no reng simpan (file) a tauling milulan.',
 'showhidebots'          => '($1 bot)',
 'noimages'              => 'Ala kang akit.',
 'ilsubmit'              => 'Manintun',
@@ -2252,7 +2244,7 @@
 
 # External editor support
 'edit-externally'      => 'I-edit me ing simpan a ini kapamilatan ning aplikasiun o program a ibat king kilual.',
-'edit-externally-help' => 'Lon me ing [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] para king karagdagang impormasiun.',
+'edit-externally-help' => 'Lon me ing [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] para king karagdagang impormasiun.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'eganagana',
@@ -2314,7 +2306,7 @@
 'recreate'            => 'Lalangan yang pasibayu',
 
 # HTML dump
-'redirectingto' => 'Iyalis ya direksion king [[$1]]...',
+'redirectingto' => 'Iyalis ya direksion king [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Ilako ya king simpanan (cache) ing bulung a ine?
@@ -2380,7 +2372,7 @@
 'version-software-product' => 'Produktu',
 'version-software-version' => 'Bersion',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Dalan ning simpan (file path)',
 'filepath-page'   => 'Simpan (file):',
 'filepath-submit' => 'Dalan',
Index: languages/messages/MessagesDiq.php
===================================================================
--- languages/messages/MessagesDiq.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDiq.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Mirzali
  * @author Belekvor
- * @author Siebrand
- * @author SPQRobin
+ * @author Mirzali
  */
 
 $messages = array(
@@ -255,7 +253,7 @@
 'nosuchspecialpage' => 'Pela xasa henêne/otir çina',
 'nospecialpagetext' => "<big>'''To yew pela xasa nêvêrdiye waşte.'''</big>
 
-Seba /qandê lista pelanê xasanê vêrdeyan kerem ke: [[Special:Specialpages|{{int:specialpages}}]].",
+Seba /qandê lista pelanê xasanê vêrdeyan kerem ke: [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'               => 'Ğelet',
@@ -347,7 +345,7 @@
 'filesource' => 'Çımey:',
 'savefile'   => 'Dosya qeyd ke',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'dosya',
 'imagelist'      => 'Lista Dosya',
 'imagelist_date' => 'Tarix',
@@ -391,13 +389,13 @@
 'specialloguserlabel' => 'Karber:',
 'log-search-submit'   => 'Şo',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Şo',
 
 # Special:Categories
 'categories' => 'Kategoriy',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Bımocne',
 
 # Watchlist
@@ -425,7 +423,7 @@
 # Attribution
 'lastmodifiedatby' => 'Ena pele tewr peyên roca $2, $1 by $3. de biya rocaniye', # $1 date, $2 time, $3 user
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Cıgeyre',
 
 'exif-gaincontrol-0' => 'çino',
@@ -433,7 +431,7 @@
 # AJAX search
 'articletitles' => "Perri be ''$1'' dest cı kenê",
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Dosya:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesVec.php
===================================================================
--- languages/messages/MessagesVec.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesVec.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author BrokenArrow
  * @author Candalua
  * @author Nick1915
- * @author BrokenArrow
- * @author Siebrand
+ * @author Omnipaedista
  * @author לערי ריינהארט
- * @author Omnipaedista
- * @author Jon Harald Søby
  */
 
 $fallback = 'it';
@@ -315,7 +313,7 @@
 'nosuchspecialpage' => 'No xè disponibiłe nissuna pàxena speciałe co sto nome',
 'nospecialpagetext' => "<big>'''Te ghè richiesto na pagina speciale mìa esistente.'''</big>
 
-Te podi catar na lista de le pagine speciali esistenti in [[Special:Specialpages|{{int:specialpages}}]].",
+Te podi catar na lista de le pagine speciali esistenti in [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erór',
@@ -341,10 +339,10 @@
 L'aministrador de sistema che gà messo el bloco el gà lassà sta spiegassion: $1",
 'missing-article'      => 'El database no\'l gà mìa catà el testo de na pagina che la gavarìa dovùo èssarghe soto el nome de "$1" $2.
 
-De solito questo el se verifica quando vien riciamà, a partir da la cronologia o dal confronto tra revision, un colegamento a na pagina scancelà, a un confronto tra revision inesistenti o a un confronto tra revision ripulìe da la cronologia.
+De solito questo el se verifica quando vien riciamà un confronto tra revision vece de la pagina o un colegamento a na version vecia de na pagina che xe stà scancelà.
 
 In caso contrario, se gà probabilmente catà un eror del software MediaWiki.
-Se prega de segnalar l\'acaduto a un aministrador specificando la URL in question.',
+Se prega de segnalar l\'acaduto a un [[Special:ListUsers/sysop|aministrador]] specificando la URL in question.',
 'missingarticle-rev'   => '(revision n°: $1)',
 'missingarticle-diff'  => '(Dif.: $1, $2)',
 'readonly_lag'         => 'El database el xe stà blocà automaticamente par consentirghe ai server coi database slave de sincronizarse col master',
@@ -397,11 +395,10 @@
 'logouttitle'                => 'Logout utente',
 'logouttext'                 => '<strong>Logout efetuà.</strong>
 
-Ora te podi continuar a doparar {{SITENAME}} come utente anonimo (ma el to indirizo IP el restarà riconossìbile), opure te podi far de novo el login col nome utente de prima, opure con uno difarente. Nota che çerte pagine le podarìa èssar visualizà come se te fussi ancora loggà, fin che no te neti la cache del to browser.',
-'welcomecreation'            => "== Benvegnù, $1==
-El to account l'è stà creà con sucesso.<br />
-Grasie par aver scelto de far cresere {{SITENAME}} co'l to aiuto.<br />
-Par rendere {{SITENAME}} più tua, e par usarla più scorrevolmente, no sta desmentegarte de personalixare le to preferense.",
+Ora te podi continuar a doparar {{SITENAME}} come utente anonimo, opure te podi far [[Special:UserLogin|de novo el login]] col nome utente de prima, opure con uno difarente. Nota che çerte pagine le podarìa èssar visualizà come se te fussi ancora loggà, fin che no te neti la cache del to browser.',
+'welcomecreation'            => "== Benvegnù, $1! ==
+El to account l'è stà creà con sucesso.
+No sta desmentegarte de personalixare le to [[Special:Preferences|preferense de {{SITENAME}}]].",
 'loginpagetitle'             => 'Login',
 'yourname'                   => 'Nome utente:',
 'yourpassword'               => 'Scegli na password',
@@ -412,7 +409,7 @@
 'loginproblem'               => '<b>Si gà verificà un erore durante el to tentativo de login.</b><br />Ripróa da novo!',
 'login'                      => 'Entra',
 'nav-login-createaccount'    => 'Entra o crea un novo acesso',
-'loginprompt'                => 'Par acedere a {{SITENAME}} xè necessario abiłitare i cookie.',
+'loginprompt'                => 'Par acédere a {{SITENAME}} ti gà da abiłitare i cookie.',
 'userlogin'                  => 'Entra o crea un novo acesso',
 'logout'                     => 'Và fora',
 'userlogout'                 => 'và fora',
@@ -518,7 +515,7 @@
 'subject'                          => 'Argomento (intestazion)',
 'minoredit'                        => "Sta quà l'è na modifica minore",
 'watchthis'                        => "Tegni d'ocio sta voçe",
-'savearticle'                      => 'Salva la pagina',
+'savearticle'                      => 'Salva la pàxena',
 'preview'                          => 'Anteprima',
 'showpreview'                      => 'Mostra anteprima',
 'showlivepreview'                  => "Funzion ''Live preview''",
@@ -530,17 +527,18 @@
 'summary-preview'                  => 'Anteprima ogeto',
 'subject-preview'                  => 'Anteprima ogeto/intestazion',
 'blockedtitle'                     => 'Utente blocà',
-'blockedtext'                      => "<big>'''Sto nome utente o indirizo IP i xe stà blocà.'''</big>
+'blockedtext'                      => "<big>'''Sto nome utente o indirizo IP el xe stà blocà.'''</big>
 
-El bloco el xe stà messo da $1. La motivazion del bloco la xe sta qua: ''$2''
+El bloco el xe stà messo da $1.
+La motivazion del bloco la xe sta qua: ''$2''.
 
 * Inizio del bloco: $8
-* Scadenza del bloco: $6
-* Intervalo di bloco: $7
+* Scadensa del bloco: $6
+* Intervalo del bloco: $7
 
 Se te vol, te pol contatar $1 o n'altro [[{{MediaWiki:Grouppage-sysop}}|aministrador]] par discùtar del bloco.
 
-Nota che la funzion 'Scrivi a l'utente' no la xe mìa ativa se no xe stà registrà un indirizo e-mail valido ne le proprie [[Special:Preferences|preferenze]].
+Nota che la funzion 'Scrivi a l'utente' no la xe mìa ativa se no te ghè registrà un indirizo e-mail valido ne le to [[Special:Preferences|preferenze]] e se sto indirizo no'l xe stà blocà.
 
 Se prega de specificare l'indirizo IP atuale ($3) o el nùmaro del bloco (ID #$5) in qualsiasi richiesta de ciarimenti.",
 'autoblockedtext'                  => "Sto indirizo IP el xe stà blocà automaticamente parché condiviso con n'altro utente, a so volta blocà da $1.
@@ -550,21 +548,18 @@
 
 * Inizio del bloco: $8
 * Scadenza del bloco: $6
+* Intervalo del bloco: $7
 
 Se pol contatar $1 o n'altro [[{{MediaWiki:Grouppage-sysop}}|aministrador]] par discùtar del bloco.
 
-Nota che la funzion 'Scrivi a l'utente' no la xe ativa se no xe stà registrà un indirizo e-mail valido ne le proprie [[Special:Preferences|preferenze]].
+Nota che la funzion 'Scrivi a l'utente' no la xe ativa a meno che no te gavi registrà un indirizo e-mail valido ne le to [[Special:Preferences|preferenze]] e che l'indirizo no'l sia stà blocà.
 
-Se prega de specificar el nùmaro del bloco (ID #$5) in qualsiasi richiesta de ciarimenti.",
+Se prega de specificar el to indirizo IP atuale ($3) e el nùmaro del bloco (ID #$5) in qualsiasi richiesta de ciarimenti.",
 'blockednoreason'                  => 'nissuna motivazion indicà',
 'blockedoriginalsource'            => "El còdese sorgente de '''$1''' el vien mostrà de seguito:",
 'blockededitsource'                => "El testo de le '''to modifiche''' a '''$1''' el xe mostrà qua soto:",
-'whitelistedittitle'               => 'Bisogna èssar registrà par poder modificar la pàxena.',
+'whitelistedittitle'               => 'Bisogna èssar registrà par poder modificar le pàxene',
 'whitelistedittext'                => 'Par modificar łe pàxene ghe xè bisogno de $1.',
-'whitelistreadtitle'               => 'Bisogna èssar registrà par lèxar ła pàxena',
-'whitelistreadtext'                => 'Xe necessario effettuar el [[Special:Userlogin|login]] par lexere i articoli.',
-'whitelistacctitle'                => 'No te ghè el permesso de creare un account',
-'whitelistacctext'                 => 'To be allowed to create accounts in this Wiki you have to [[Special:Userlogin|log]] in and have the appropriate permissions.',
 'confirmedittitle'                 => 'Ghe vole ła conferma e-mail par scrivare',
 'confirmedittext'                  => "Te ghè da confermar l'indirizo e-mail prima de editar le pàxene. Par piaxer inposta e conferma el to indirizo e--mail tramite le to [[Special:Preferences|preferenze]].",
 'nosuchsectiontitle'               => 'Sta sezion no la esiste',
@@ -582,7 +577,7 @@
 'anontalkpagetext'                 => "----''Sta quà l'è la pàxena de discussion de un utente anonimo che no'l se gà gnancora registrà o che no l'efetua el login.
 De conseguenza xè necessario identificarlo tramite l'indirizo IP numerico.
 Sto indirizo el pode èssar condivixo da diversi utenti.
-Se te sì un utente anonimo e te pensi che ghe sia stà comenti irilevanti, te podi [[Special:Userlogin|registrarte o efetuar el login]] par evitar confuxion con altri utenti in futuro.''",
+Se te sì un utente anonimo e te ghè riçevù dei messagi che te secondo ti i xera direti a qualchedun altro, te podi [[Special:UserLogin/signup|registrarte]] o [[Special:UserLogin|efetuar el login]] par evitar confuxion con altri utenti anonimi in futuro.''",
 'noarticletext'                    => 'In sto momento ła pàxena richiesta la xè voda. Se pol [[Special:Search/{{PAGENAME}}|çercar sto titoło]] ne łe altre pàxene del sito opure [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificar ła pàxena desso].',
 'userpage-userdoesnotexist'        => 'L\'account "$1" no\'l corisponde mìa a un utente registrà. Verifica se te voli dal bon crear o modificar sta pagina.',
 'clearyourcache'                   => "'''Ocio: dopo aver salvà, te ghè da netar la cache del to browser par védar i canbiamenti.''' Par '''Mozilla / Firefox / Safari:''' tien macà el boton de le majuscole e schiza \"Ricarica\", o senò maca ''Ctrl-F5'' o ''Ctrl-R'' (''Command-R'' se te ghè el Macintosh); par '''Konqueror:''' schiza \"Ricarica\" o maca ''F5;'' par '''Opera:''' néta la cache in ''Strumenti → Preferenze;'' par '''Internet Explorer:''' tien macà ''Ctrl'' fin che te schizi ''Ricarica'', o maca ''Ctrl-F5.''",
@@ -594,13 +589,14 @@
 'note'                             => '<strong>Nota:</strong>',
 'previewnote'                      => "<strong>Tegni presente che sta qua xè solo n'anteprima, e che la to version NO la xè stà gnancora salvà!</strong>",
 'previewconflict'                  => 'Sta anteprima la corisponde al testo ne la casèla de edizion de sora, e la fa védar come vegnarà fora la pagina se te machi "Salva la pagina" in sto momento.',
-'session_fail_preview'             => '<strong>Purtropo no xè stà possibiłe salvar le to modifiche parché i dati de la sezion i xè andai persi. Par piaser, riproa da novo.<br />
-Se te rizevi sto messajo de erór pì olte, proa a scołegarte (struca su "và fora" in alto a destra) e a cołegarte novamente.</strong>',
-'session_fail_preview_html'        => "<strong>Semo spiacenti, ma no xe mìa stà possibile elaborar la modifica parché xe 'ndà persi i dati relativi a la session.</strong>
+'session_fail_preview'             => '<strong>Ne dispiase, ma purtropo no xè stà possibiłe salvar le to modifiche parché i dati de la session i xè andai persi. Par piaser, riproa da novo.
+Se no funsiona gnancora, proa a [[Special:UserLogout|scołegarte]] e a cołegarte de novo.</strong>',
+'session_fail_preview_html'        => "!<strong>Semo spiacenti, ma no xe mìa stà possibile elaborar la modifica parché xe 'ndà persi i dati relativi a la session.</strong>
 
-''Dato che in sto sito xe abilità l'uso de HTML senza limitazion, l'anteprima no la vien visualizà; se tratta de na misura de sicureza contro i atachi JavaScript.''
+''Dato che su {{SITENAME}} xe abilità l'uso de HTML senza limitazion, l'anteprima no la vien visualizà; se tratta de na misura de sicureza contro i atachi JavaScript.''
 
-<strong>Se el problema el persiste, te pol proár a scolegarte e efetuar da novo l'acesso.</strong>",
+<strong>Se te stè fasendo na modifica legìtima, par piaser próa de novo.
+Se no funsiona gnancora, te pol proár a [[Special:UserLogout|scolegarte]] e efetuar da novo l'acesso.</strong>",
 'token_suffix_mismatch'            => "<strong>La modifica no la xe mìa stà salvà parché el client el gà mostrà de gestir in maniera sbaglià i caràteri de puntegiatura nel token associà a la stessa. Par evitar na possibile coruzion del testo de la pagina, xe stà rifiutà l'intera modifica. Sta situazion la pode verificarse, a olte, quando vien doparà çerti servizi de proxy anonimi via web che presenta dei bug.</strong>",
 'editing'                          => 'Modifica de $1',
 'editingsection'                   => 'Modifica $1 (sezion)',
@@ -638,7 +634,7 @@
 'template-semiprotected'           => '(semiproteto)',
 'hiddencategories'                 => 'Sta pagina la fa parte de {{PLURAL:$1|una categoria sconta|$1 categorie sconte}}:',
 'nocreatetitle'                    => 'Creazion de le pagine limitada',
-'nocreatetext'                     => 'La possibilità de crear pagine nóve su {{SITENAME}} la xe stà limità ai soli utenti registrà. Se pol tornar indrìo e modificar na pagina esistente, opure [[Special:Userlogin|entrar o crear un nóvo acesso]].',
+'nocreatetext'                     => 'La possibilità de crear pagine nóve su {{SITENAME}} la xe stà limità ai soli utenti registrà. Se pol tornar indrìo e modificar na pagina esistente, opure [[Special:UserLogin|entrar o crear un nóvo acesso]].',
 'nocreate-loggedin'                => 'No te ghè i permessi necessari a crear nove pagine su {{SITENAME}}.',
 'permissionserrors'                => 'Eror nei permessi',
 'permissionserrorstext'            => "No te ghè i permessi necessari ad eseguir l'azion richiesta, par {{PLURAL:$1|el seguente motivo|i seguenti motivi}}:",
@@ -664,7 +660,7 @@
 'undo-success' => 'Sta modifica la pode èssar anulà. Verifica el confronto presentà de seguito par èssar sicuro che el contenuto el sia come te lo voli e quindi salva le modifiche par conpletar la procedura de anulamento.',
 'undo-failure' => 'No se pol mìa anular la modifica, par via de un conflito con modifiche intermedie.',
 'undo-norev'   => 'La modifica no la pode vegner anulà parché no la esiste o la xe stà scancelà.',
-'undo-summary' => 'Anulà la modifica $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]])',
+'undo-summary' => 'Anulà la modifica $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => "Inpossibile registrar l'utente",
@@ -755,7 +751,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Registro dei ocultamenti',
-'suppressionlogtext' => "Qua soto se cata na lista de le pi reçenti scancelazioni e blochi che riguarda contenuti sconti dai aministradori. Varda la [[Special:Ipblocklist|lista dei IP blocà]] par védar l'elenco dei blochi atualmente ativi.",
+'suppressionlogtext' => "Qua soto se cata na lista de le pi reçenti scancelazioni e blochi che riguarda contenuti sconti dai aministradori. Varda la [[Special:IPBlockList|lista dei IP blocà]] par védar l'elenco dei blochi atualmente ativi.",
 
 # History merging
 'mergehistory'                     => 'Union cronologie',
@@ -795,7 +791,7 @@
 # Search results
 'searchresults'             => 'Risultato de la riçerca',
 'searchresulttext'          => 'Par verghe piassè informassion su la riçerca interna de {{SITENAME}}, varda [[{{MediaWiki:Helppage}}|Riçerca in {{SITENAME}}]].',
-'searchsubtitle'            => "Te ghè çercà '''[[:$1]]'''",
+'searchsubtitle'            => 'Te ghè çercà \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|tute le pàxene che taca con "$1"]] | [[Special:WhatLinksHere/$1|tute le pàxene che punta a "$1"]])',
 'searchsubtitleinvalid'     => "Te ghè çercà '''$1'''",
 'noexactmatch'              => "'''La pàxena \"\$1\" no ła esiste.''' Te pol [[:\$1|crearla desso]].",
 'noexactmatch-nocreate'     => "'''No ghe xe nissuna pagina con titolo \"\$1\".'''",
@@ -838,7 +834,7 @@
 'mypreferences'            => 'le me preferenze',
 'prefs-edits'              => 'Nùmaro de modifiche:',
 'prefsnologin'             => 'No te ghè eseguìo el login',
-'prefsnologintext'         => 'Te ghè da aver eseguìo el [[Special:Userlogin|login]]
+'prefsnologintext'         => 'Te ghè da aver eseguìo el [[Special:UserLogin|login]]
 par poder personalixare le to preferense.',
 'prefsreset'               => 'Le to Preferense le xè stà ripescae da la memoria de sistema del server de {{SITENAME}}.',
 'qbsettings'               => 'Settaggio barra menu',
@@ -913,7 +909,7 @@
 'userrights-reason'           => 'Motivo de la modifica:',
 'userrights-no-interwiki'     => 'No te ghè i parmessi necessari par modificar i diriti dei utenti su altri siti.',
 'userrights-nodatabase'       => "El database $1 no l'esiste mìa o no l'è un database local.",
-'userrights-nologin'          => "Par assegnarghe diriti ai utenti te ghè da [[Special:Userlogin|efetuar l'acesso]] come aministrador.",
+'userrights-nologin'          => "Par assegnarghe diriti ai utenti te ghè da [[Special:UserLogin|efetuar l'acesso]] come aministrador.",
 'userrights-notallowed'       => 'No te ghè i parmessi necessari par assegnarghe diriti ai utenti.',
 'userrights-changeable-col'   => 'Grupi che te pol canbiar',
 'userrights-unchangeable-col' => 'Grupi che no te pol canbiar',
@@ -1003,7 +999,7 @@
 
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|modifica|modifiche}}',
-'recentchanges'                     => 'Ultime modifeghe',
+'recentchanges'                     => 'Ùltimi canbiamenti',
 'recentchangestext'                 => 'Sta pàxena la presenta łe ultime modifeghe aportàe ai contenuti de el sito.',
 'recentchanges-feed-description'    => 'Sto feed qua el riporta le modifiche piassè recenti ai contenuti del sito.',
 'rcnote'                            => "Qua soto ghe xe {{PLURAL:$1|l'ultimo cambiamento|i ultimi '''$1''' canbiamenti}} ne {{PLURAL:$2|l'ultimo giòrno|i ultimi '''$2''' giòrni}}; i dati i xe agiornà a le ore $5 del $4.",
@@ -1029,7 +1025,7 @@
 'newsectionsummary'                 => '/* $1 */ sezion nova',
 
 # Recent changes linked
-'recentchangeslinked'          => 'Modifeghe ligà a sta pagina',
+'recentchangeslinked'          => 'Modifeghe ligà a sta pàxena',
 'recentchangeslinked-title'    => 'Modifiche ligà a "$1"',
 'recentchangeslinked-noresult' => 'Nel periodo specificà no ghe xe stà nissuna modifica a le pagine colegà.',
 'recentchangeslinked-summary'  => "Sta pagina speciale la fa védar le modifiche piassè recenti a le pagine ligà a quela specificà (o a le pagine contegnù ne la categoria specificà).
@@ -1043,24 +1039,25 @@
 'reupload'                    => 'Carga da novo',
 'reuploaddesc'                => 'Lassa pèrdar el caricamento e torna al modulo de caricamento',
 'uploadnologin'               => 'Te devi far el login par exeguire sta operassion.',
-'uploadnologintext'           => 'Te ghè da far [[Special:Userlogin|el login]]
+'uploadnologintext'           => 'Te ghè da far [[Special:UserLogin|el login]]
 par poder cargar dei file.',
 'upload_directory_missing'    => 'La cartèla de caricamento ($1) no la esiste mìa e no la pode vegner creàda dal browser web.',
 'upload_directory_read_only'  => "El server web no l'è bon de scrìvar ne la directory de caricamento ($1).",
 'uploaderror'                 => 'Eror nel caricamento',
 'uploadtext'                  => "Par cargar novi file, dopara el modulo qua soto. 
-Par védar o çercar i file zà caricà, consulta la [[Special:Imagelist|lista dei file caricà]]. I caricamenti e le scancelazion de file te pol védarle nel [[Special:Log/upload|registro dei caricamenti]].
+Par védar o çercar i file zà caricà, consulta la [[Special:ImageList|lista dei file caricà]]. I caricamenti de file te pol védarli nel [[Special:Log/upload|registro dei caricamenti]], le scancelasion nel [[Special:Log/delete|registro de le scancelasion]].
 
-Par métar na imagine drento na pagina, te ghè da far un colegamento de sto tipo:
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|testo alternativo]]</nowiki>''' opure
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' par crear un colegamento direto al file.",
+Par métar un file drento de na pagina, te ghè da inserir un colegamento fato come uno de sti qua:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' par doparar la version conpleta de sto file
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|testo alternativo]]</nowiki></tt>'''par inserir sto file co na larghessa de 200 pixel in te un riquadro a sinistra con 'testo alternativo' come descrission
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' par inserir diretamente un colegamento al file sensa che el se véda in te la pagina",
 'upload-permitted'            => 'Tipi de file consentìi: $1.',
 'upload-preferred'            => 'Tipi de file consiglià: $1.',
 'upload-prohibited'           => 'Tipi de file mìa consentìi: $1.',
 'uploadlog'                   => 'File caricai',
 'uploadlogpage'               => 'Registro dei file caricai',
-'uploadlogpagetext'           => 'Qua se cata la lista dei ultimi files caricà sul server de {{SITENAME}}.',
+'uploadlogpagetext'           => 'Qua se cata la lista dei ultimi files caricà.
+Varda la [[Special:NewImages|galerìa dei file nóvi]] par na vision de insieme.',
 'filename'                    => 'Nome del file',
 'filedesc'                    => 'Somario',
 'fileuploadsummary'           => 'Somario:',
@@ -1117,9 +1114,12 @@
 'upload-proto-error'      => 'Protocòl mìa giusto',
 'upload-proto-error-text' => 'Par el caricamento remoto bisogna specificar URL che scuminsia con <code>http://</code> opure <code>ftp://</code>.',
 'upload-file-error'       => 'Eror interno',
-'upload-file-error-text'  => 'Se gà verificà un eror interno durante la creazion de un file tenporaneo sul server. Contata un aministrador de sistema.',
+'upload-file-error-text'  => 'Se gà verificà un eror interno durante la creazion de un file tenporaneo sul server.
+Par piaser, contatar un [[Special:ListUsers/sysop|aministrador]].',
 'upload-misc-error'       => 'Eror non identificà par el caricamento',
-'upload-misc-error-text'  => 'Se gà verificà un eror mìa identificà durante el caricamento del file. Verifica che la URL la sia giusta e acessibile e próa da novo. Se el problema el persiste, contata un aministrador de sistema.',
+'upload-misc-error-text'  => '!Se gà verificà un eror mìa identificà durante el caricamento del file.
+Par piaser, verifica che la URL la sia giusta e acessibile e próa da novo.
+Se el problema el persiste, contatar un [[Special:ListUsers/sysop|aministrador]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL mìa ragiungibile',
@@ -1133,7 +1133,7 @@
 'upload_source_url'  => ' (na URL coreta e acessibile)',
 'upload_source_file' => ' (un file sul to computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Sta pagina speciale la fa védar tuti i file caricài.
 I file caricài piessè de reçente i vien mostrà a l'inizio de la lista.
 Par modificar l'ordinamento, struca su l'intestazion de la colona presièlta.",
@@ -1161,7 +1161,7 @@
 'imagelinks'                     => "Colegamenti a l'imagine",
 'linkstoimage'                   => '{{PLURAL:$1|La pagina seguente la|Le $1 pàxene seguenti le}} riciama sto file:',
 'nolinkstoimage'                 => 'Nissuna pàxena la punta a sta imagine.',
-'morelinkstoimage'               => 'Varda i [[Special:Whatlinkshere/$1|altri colegamenti]] verso sto file.',
+'morelinkstoimage'               => 'Varda i [[Special:WhatLinksHere/$1|altri colegamenti]] verso sto file.',
 'redirectstofile'                => '{{PLURAL:$1|El file seguente el|I $1 file seguenti i}} redirige verso sto file:',
 'duplicatesoffile'               => '{{PLURAL:$1|El file seguente el|I $1 file seguenti i}} xe dei dopioni de sto file:',
 'sharedupload'                   => 'Sto file qua el xe un caricamento condiviso; quindi el pol èssar doparà da più progeti wiki.',
@@ -1180,18 +1180,18 @@
 # File reversion
 'filerevert'                => 'Ripristina $1',
 'filerevert-legend'         => 'Ripristina file',
-'filerevert-intro'          => '<span class="plainlinks">Te stè par ripristinar el file \'\'\'[[Media:$1|$1]]\'\'\' a la [versione $4 del $2, $3].</span>',
+'filerevert-intro'          => "Te stè par ripristinar el file '''[[Media:$1|$1]]''' a la [versione $4 del $2, $3].",
 'filerevert-comment'        => 'Comento:',
 'filerevert-defaultcomment' => 'Xe stà ripristinà la version del $1, $2',
 'filerevert-submit'         => 'Ripristina',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'El file [[Media:$1|$1]]\'\'\' el xe stà ripristinà a la [$4 version del $2, $3].</span>',
+'filerevert-success'        => "'''El file [[Media:$1|$1]]''' el xe stà ripristinà a la [$4 version del $2, $3].",
 'filerevert-badversion'     => 'No esiste mìa version locali precedenti del file col timestamp richiesto.',
 
 # File deletion
 'filedelete'                  => 'Scancela $1',
 'filedelete-legend'           => 'Scancela el file',
 'filedelete-intro'            => "Te stè par scancelar '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Te sì drio scancelar la version de \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Te sì drio scancelar la version de '''[[Media:$1|$1]]''' del [$4 $3, $2].",
 'filedelete-comment'          => 'Motivo:',
 'filedelete-submit'           => 'Scancela',
 'filedelete-success'          => "El file '''$1''' el xe stà scancelà.",
@@ -1244,7 +1244,7 @@
 Da l'instalazion del sito fin a sto momento, xe stà visità '''\$3''' pagine ed eseguìe '''\$4''' modifeghe, pari a na media de '''\$5''' modifeghe par pàxena e '''\$6''' richieste de letura par ciascuna modifega.
 
 La [http://www.mediawiki.org/wiki/Manual:Job_queue coa] la contien '''\$7''' proçessi.",
-'userstatstext'          => "Ghe xe {{PLURAL:$1|'''1''' [[Special:Listusers|utente]]|'''$1''' [[Special:Listusers|utenti]]}} registrà, de cui '''$2''' (pari al '''$4%''') {{PLURAL:$2|el|i}} gà i diriti de $5.",
+'userstatstext'          => "Ghe xe {{PLURAL:$1|'''1''' [[Special:ListUsers|utente]]|'''$1''' [[Special:ListUsers|utenti]]}} registrà, de cui '''$2''' (pari al '''$4%''') {{PLURAL:$2|el|i}} gà i diriti de $5.",
 'statistics-mostpopular' => 'Pagine piassè visità',
 
 'disambiguations'      => 'Pàxene de disanbiguazion',
@@ -1252,8 +1252,10 @@
 'disambiguations-text' => "Le pagine ne la lista che segue le contien dei colegamenti a '''pagine de disanbiguazion''' e no a l'argomento a cui le dovarìà far riferimento.<br />
 Vien considerà pagine de disanbiguazion tute quele che contien i template elencà in [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redirect dopi',
-'doubleredirectstext' => '<b>Ocio:</b> Stà lista la pode talvolta contegnere dei risultati mìa giusti. Podaria magari sucédar parché ghe fusse del testo agiuntivo o dei colegamenti dopo el tag #REDIRECT.<br /> Ogni riga la contegne i colegamenti al primo ed al secondo redirect, oltre a la prima riga de testo del secondo redirect che de solito contegne el "reale" articolo de destinassion, quelo al quale anca el primo redirect dovaria puntar.',
+'doubleredirects'            => 'Redirect dopi',
+'doubleredirectstext'        => '<b>Ocio:</b> Stà lista la pode talvolta contegnere dei risultati mìa giusti. Podaria magari sucédar parché ghe fusse del testo agiuntivo o dei colegamenti dopo el tag #REDIRECT.<br /> Ogni riga la contegne i colegamenti al primo ed al secondo redirect, oltre a la prima riga de testo del secondo redirect che de solito contegne el "reale" articolo de destinassion, quelo al quale anca el primo redirect dovaria puntar.',
+'double-redirect-fixed-move' => '[[$1]] xe stà spostà, desso el xe solo un rimando a [[$2]]',
+'double-redirect-fixer'      => 'Coretòr de redirect',
 
 'brokenredirects'        => 'Redirect mìa giusti',
 'brokenredirectstext'    => 'I seguenti redirect i punta a articoli gnancora creai.',
@@ -1338,7 +1340,7 @@
 'logempty'             => "El registro no'l contien mìa elementi corispondenti a la riçerca.",
 'log-title-wildcard'   => 'Riçerca dei titoli che scuminsia con',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tute łe pàxene',
 'alphaindexline'    => 'da $1 a $2',
 'nextpage'          => 'Pàxena dopo ($1)',
@@ -1361,15 +1363,15 @@
 'special-categories-sort-count' => 'ordina par nùmaro',
 'special-categories-sort-abc'   => 'ordina alfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostra i utenti tacando da:',
 'listusers-submit'   => 'Mostra',
 'listusers-noresult' => 'Nissun utente el risponde ai criteri inpostà.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Diriti dei grupi utenti',
 'listgrouprights-summary'  => 'Sta qua la xe na lista dei grupi de utenti definìi su sta wiki, coi diriti asocià a ognuno.
-Altre informassion sui diriti individuali se pol catarle [[{{MediaWiki:Listgrouprights-helppage}}|qua]].',
+Se pol consultar anca dele altre [[{{MediaWiki:Listgrouprights-helppage}}|informassion in pi]] sui diriti individuali.',
 'listgrouprights-group'    => 'Grupo',
 'listgrouprights-rights'   => 'Diriti',
 'listgrouprights-helppage' => 'Help:Diriti dei grupi',
@@ -1377,10 +1379,11 @@
 
 # E-mail user
 'mailnologin'     => 'Nissun indirizo a cui mandarghe el messagio',
-'mailnologintext' => 'Par inviare messagi e-mail ad altri utenti xè neçessario [[Special:Userlogin|açedere al sito]] e aver registrà un indirisso vałido ne łe proprie [[Special:Preferences|preferense]].',
+'mailnologintext' => 'Par inviare messagi e-mail ad altri utenti xè neçessario [[Special:UserLogin|açedere al sito]] e aver registrà un indirisso vałido ne łe proprie [[Special:Preferences|preferense]].',
 'emailuser'       => "Scrivi a l'utente",
 'emailpage'       => "Scrivi na e-mail a l'utente",
-'emailpagetext'   => 'Se sto Utente el gà registrà na casela e-mail valida, el modulo qua soto el te consentirà de scriverghe un solo messagio. La e-mail che te ghè indicà ne le to preferense la vegnarà fora nel canpo "Da" de la mail, così che el destinatario el possa, solo se el lo desidera però, rispóndarte.',
+'emailpagetext'   => 'Se sto Utente el gà registrà na casela e-mail valida, el modulo qua soto el te consentirà de scriverghe un singolo messagio.
+La e-mail che te ghè indicà ne le [[Special:Preferences|to preferense]] la vegnarà fora nel canpo "Da" de la mail, così che el destinatario el possa rispóndarte.',
 'usermailererror' => "L'ogeto mail el gà restituìo l'eror:",
 'defemailsubject' => 'Messagio da {{SITENAME}}',
 'noemailtitle'    => 'Nissun indirisso e-mail',
@@ -1403,14 +1406,14 @@
 'nowatchlist'          => "No te ghè indicà pagine da tegner d'ocio.",
 'watchlistanontext'    => "Per vardar e modifegar l'ełenco de i osservati speciałi bisogna $1.",
 'watchnologin'         => 'Acesso non efetuà',
-'watchnologintext'     => 'Te ghè prima da far el [[Special:Userlogin|login]] par modificar la to lista de osservati speciali.',
+'watchnologintext'     => 'Te ghè prima da far el [[Special:UserLogin|login]] par modificar la to lista de osservati speciali.',
 'addedwatch'           => 'Xontà ai tòi Osservati Speciali',
 'addedwatchtext'       => "La pàxena  \"<nowiki>\$1</nowiki>\" l'è stà xontà a la to [[Special:Watchlist|lista de osservati speciali]].
-Le future modifiche a sta pagina e a la relativa pagina de discussion le sarà elencae qui, e la paxena la vegnarà fora in '''grasseto''' ne la pàxena de le [[Special:Recentchanges|ultime modifiche]] par èssar pì façile da tegner d'ocio.
+Le future modifiche a sta pagina e a la relativa pagina de discussion le sarà elencae qui, e la paxena la vegnarà fora in '''grasseto''' ne la pàxena de le [[Special:RecentChanges|ultime modifiche]] par èssar pì façile da tegner d'ocio.
 
 Se pì avanti te vorè cavar sta articolo da la to lista de Osservati Speciali, maca \"No sta tegner d'ocio\" ne la barra dei menu.",
 'removedwatch'         => 'Cavà da la lista dei Osservati Speciali',
-'removedwatchtext'     => 'La pàxena  "<nowiki>$1</nowiki>" la xè stà cavà da ła łista de i toi Osservati Speciałi.',
+'removedwatchtext'     => 'La pàxena "[[:$1]]" la xè stà cavà da ła to łista de le [[Special:Watchlist|pàxene tegnùe de ocio]].',
 'watch'                => "Tien d'ocio",
 'watchthispage'        => "Tien d'ocio sta voçe",
 'unwatch'              => "No sta tegner d'ocio",
@@ -1507,7 +1510,9 @@
 'rollbacklink'                => 'tira indrìo',
 'rollbackfailed'              => 'Ripristino mìa riussìo',
 'cantrollback'                => "No xè mia possibiłe tornar a na versión precedente: l'ultima modifica la xè stà aportà da l'unico utente che gà laorà a sto articoło.",
-'alreadyrolled'               => "No xè mia possibile efetuar el ripristino de [[$1]] da [[User:$2|$2]] ([[User talk:$2|discussion]]); qualcun altro gà xà modificà o efetuà el ripristino de sta voçe. L'ultima modefega l'è stà fata da [[User:$3|$3]] ([[User talk:$3|discussion]]).",
+'alreadyrolled'               => "No xè mia possibile efetuar el ripristino de [[:$1]] da [[User:$2|$2]] ([[User talk:$2|discussion]] | [[Special:Contributions/$2|{{int:contribslink}}]]); qualcun altro gà xà modificà o efetuà el ripristino de sta voçe.
+
+L'ultima modefega l'è stà fata da [[User:$3|$3]] ([[User talk:$3|discussion]] | [[Special:Contributions/$3|{{int:contribslink}}]]).",
 'editcomment'                 => 'El comento a la modifica el xera: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Anułàe łe modifeghe de [[Special:Contributions/$2|$2]] ([[User talk:$2|discussion]]), riportà a ła version preçedente de [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Anulà le modifiche de $1; riportà a la version precedente de $2.',
@@ -1620,7 +1625,7 @@
 
 # What links here
 'whatlinkshere'            => 'Pàxene che le punta qua',
-'whatlinkshere-title'      => 'Pagine che punta a $1',
+'whatlinkshere-title'      => 'Pagine che punta a "$1"',
 'whatlinkshere-page'       => 'Pagina:',
 'linklistsub'              => '(Lista dei colegamenti)',
 'linkshere'                => "Ste pagine qua le contien dei colegamenti a '''[[:$1]]''':",
@@ -1669,7 +1674,7 @@
 'badipaddress'                    => "L'indirisso IP indicà no'l xè mìa coreto.",
 'blockipsuccesssub'               => 'Bloco eseguìo',
 'blockipsuccesstext'              => 'L\'indirizzo IP "$1" l\'è sta bloccà.
-<br />Varda [[Special:Ipblocklist|lista IP bloccati]].',
+<br />Varda [[Special:IPBlockList|lista IP bloccati]].',
 'ipb-edit-dropdown'               => 'Motivi par el bloco',
 'ipb-unblock-addr'                => 'Sbloca $1',
 'ipb-unblock'                     => 'Sbloca un utente o un indirizo IP',
@@ -1680,7 +1685,7 @@
 'ipusubmit'                       => 'Sbloca sto indirisso IP',
 'unblocked'                       => "L'utente [[User:$1|$1]] el xe stà sblocà",
 'unblocked-id'                    => 'El bloco $1 el xe stà cavà',
-'ipblocklist'                     => 'Indirizi IP bloccai',
+'ipblocklist'                     => 'Nomi utenti e indirizi IP blocài',
 'ipblocklist-legend'              => 'Cata fora un utente blocà',
 'ipblocklist-username'            => 'Nome utente o indirizo IP:',
 'ipblocklist-submit'              => 'Çerca',
@@ -1699,7 +1704,7 @@
 'autoblocker'                     => 'Bloccà automaticamente parché el to indirisso IP el xè stà doparà de recente da "[[User:$1|$1]]". La motivassion del bloco de $1 la xe: "$2"',
 'blocklogpage'                    => 'Registro dei blochi',
 'blocklogentry'                   => 'gà blocà [[$1]] par un periodo de $2 $3',
-'blocklogtext'                    => "Sto qua xè un elenco de azioni de bloco e sbloco dei indirizi IP. I indirizi blocai in automatico no i xè mìa elencai. Varda l'[[Special:Ipblocklist|elenco dei IP blocà]] par la lista dei indirizi el cui bloco el xè operativo.",
+'blocklogtext'                    => "Sto qua xè un elenco de azioni de bloco e sbloco dei indirizi IP. I indirizi blocai in automatico no i xè mìa elencai. Varda l'[[Special:IPBlockList|elenco dei IP blocà]] par la lista dei indirizi el cui bloco el xè operativo.",
 'unblocklogentry'                 => 'gà sblocà $1',
 'block-log-flags-anononly'        => 'solo utenti anonimi',
 'block-log-flags-nocreate'        => 'creazion account blocà',
@@ -1736,7 +1741,7 @@
 'lockdbsuccesssub'    => 'Blocco de el database eseguio',
 'unlockdbsuccesssub'  => 'Sbloco del database eseguìo',
 'lockdbsuccesstext'   => 'El database el xe stà blocà.<br />
-Tiente in mente de [[Special:Unlockdb|sblocarlo]] co te ghè finìo de far manutenzion.',
+Tiente in mente de [[Special:UnlockDB|sblocarlo]] co te ghè finìo de far manutenzion.',
 'unlockdbsuccesstext' => 'El database de {{SITENAME}} el xe stà sblocà.',
 'lockfilenotwritable' => "Inpossibile scrìvar sul file de ''lock'' del database. Ghe vole acesso in scritura a sto file da parte del server web, par blocar e sblocar el database.",
 'databasenotlocked'   => "El database no l'è mìa blocà.",
@@ -1744,10 +1749,10 @@
 # Move page
 'move-page'               => 'Spostamento de $1',
 'move-page-legend'        => 'Spostamento de pàxena',
-'movepagetext'            => "Col modulo qua soto te podi rinominar na pàxena, spostando anca tuta la so cronołogia al novo nome.
+'movepagetext'            => "Col modulo qua soto te podi rinominar na pàxena, spostando anca tuta la so cronołogia al nome novo.
 El vecio titoło el deventarà automaticamente un rimando (redirect) che punta al novo titoło.
-I colegamenti a la vecia pàxena no i sarà mìa agiornài (e i puntarà quindi al rimando);
-tiente in mente de controłar con cura che no se crea dopi redirect o redirect interoti.
+Te podi agiornar automaticamente i rimandi che punta al vecio titolo.
+Se te siegli de no farlo, tiente in mente de controłar con cura che no se crea [[Special:DoubleRedirects|dopi redirect]] o [[Special:BrokenRedirects|redirect interoti]].
 Resta ne la to responsabilità de controlar che i colegamenti i continua a puntar verso dove i deve dirìgiarse.
 
 Nota ben: la pàxena '''no''' la sarà spostà se ghe fusse xà na voçe col nome novo, a meno che no la sia na pàxena voda o un rimando, e senpre che no la gabia cronologia.
@@ -1761,8 +1766,6 @@
 * In corispondenza del novo titoło ghe xe xà na pàxena de discussion (mìa voda)
 * La caseła chi soto la xè stà desełezionà.",
 'movearticle'             => 'Rinomina voçe',
-'movenologin'             => 'No te ghè efetuà el login',
-'movenologintext'         => 'Te ghè da èssar un utente registrà ed aver efetuà el [[Special:Userlogin|login]] par poder spostar na pàxena.',
 'movenotallowed'          => 'No te ghè i parmessi necessari al spostamento de le pagine su {{SITENAME}}.',
 'newtitle'                => 'Al novo titoło de:',
 'move-watch'              => "Tien d'ocio",
@@ -1789,7 +1792,7 @@
 'delete_and_move'         => 'Scanceła e sposta',
 'delete_and_move_text'    => '==Scancełassion richiesta==
 
-La voçe specificà come destinassion "[[$1]]" l\'esiste xà. Vóto scancełarla par proseguir con ło spostamento?',
+La voçe specificà come destinassion "[[:$1]]" l\'esiste xà. Vóto scancełarla par proseguir con ło spostamento?',
 'delete_and_move_confirm' => 'Si! Scancèła ła pàxena',
 'delete_and_move_reason'  => 'Scancełà par rendere possibile lo spostamento',
 'selfmove'                => 'El novo titoło el xè conpagno del vecio; no se pol spostar ła pàxena su de ela.',
@@ -1797,6 +1800,7 @@
 'imagenocrossnamespace'   => 'No se pol spostar na imagine verso un namespace diverso da quelo de le imagini',
 'imagetypemismatch'       => "L'estension nova del file no la corisponde mìa al tipo de file",
 'imageinvalidfilename'    => "El nome file de destinassion no'l xe mia valido",
+'fix-double-redirects'    => 'Agiorna tuti quanti i redirect che ponta al titolo originàl',
 
 # Export
 'export'            => 'Esporta pàxene',
@@ -1839,7 +1843,8 @@
 'import-interwiki-history'   => "Copia l'intiera cronołogia de sta pàxena",
 'import-interwiki-submit'    => 'Inporta',
 'import-interwiki-namespace' => 'Trasferissi le pagine nel namespace:',
-'importtext'                 => 'Par piaser, esporta el file da la wiki de origine doparando la funsion Special:Export, salvalo sul to disco e càrghelo qua.',
+'importtext'                 => 'Par piaser, esporta el file da la wiki de origine doparando la [[Special:Export|funsion de esportassion]].
+Salvalo sul to computer e càrghelo qua.',
 'importstart'                => 'Inportazion de łe pàxene in corso...',
 'import-revision-count'      => '{{PLURAL:$1|una revixion importà|$1 revixion importae}}',
 'importnopages'              => 'Nissuna pàxena da inportar.',
@@ -1981,9 +1986,10 @@
 'markedaspatrollederror-noautopatrol' => 'No te ghè i parmessi necessari par segnar le to stesse modifiche come verificàe.',
 
 # Patrol log
-'patrol-log-page' => 'Modifiche verificàe',
-'patrol-log-line' => 'gà segnà la $1 a la pagina $2 come verificà $3',
-'patrol-log-auto' => '(verifica automatica)',
+'patrol-log-page'   => 'Modifiche verificàe',
+'patrol-log-header' => 'Qua de sèvito xe elencàe le verifiche de le modifiche.',
+'patrol-log-line'   => 'gà segnà la $1 a la pagina $2 come verificà $3',
+'patrol-log-auto'   => '(verifica automatica)',
 
 # Image deletion
 'deletedrevision'                 => 'Vecia version scancełà $1',
@@ -2012,10 +2018,10 @@
 'show-big-image'       => 'Version ad alta risoluzion',
 'show-big-image-thumb' => '<small>Dimension de sta anteprima: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Imagini nove',
 'imagelisttext'         => "Qua ghe xe na lista de '''$1''' {{PLURAL:$1|file|files}} ordinà par $2.",
-'newimages-summary'     => 'Sta pagina speciale la mostra i file cargà piassè reçentemente',
+'newimages-summary'     => 'Sta pagina speciale la mostra i file cargà piassè reçentemente.',
 'showhidebots'          => '($1 i bot)',
 'noimages'              => 'No ghè gnente da vardare.',
 'ilsubmit'              => 'Serca',
@@ -2302,7 +2308,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifica sto file doparando un programa esterno',
-'edit-externally-help' => 'Par magiori informazion varda le [http://meta.wikimedia.org/wiki/Help:External_editors istruzion] (in inglese)',
+'edit-externally-help' => 'Par magiori informazion varda le [http://www.mediawiki.org/wiki/Manual:External_editors istruzion] (in inglese)',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tute',
@@ -2373,7 +2379,7 @@
 'recreate'            => 'Ricrea',
 
 # HTML dump
-'redirectingto' => 'Reindirizzamento a [[$1]]...',
+'redirectingto' => 'Reindirizzamento a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Vóto scancełar ła cache in sta pàxena?
@@ -2409,7 +2415,7 @@
 'autosumm-blank'   => 'Pagina svodà conpletamente',
 'autosumm-replace' => "Pagina sostituìa con '$1'",
 'autoredircomment' => 'Rimando a ła pàxena [[$1]]',
-'autosumm-new'     => 'Nova pagina: $1',
+'autosumm-new'     => 'Pàxena nova: $1',
 
 # Live preview
 'livepreview-loading' => 'Caricamento in corso…',
@@ -2420,8 +2426,8 @@
 Doparar l\'anteprima standard.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Le modifiche fate nei ultimi $1 secondi no podarìa no èssarghe gnancora su sta lista.',
-'lag-warn-high'   => "Par via de un ecessivo ritardo ne l'agiornamento del server de database, le modifiche fate nei ultimi $1 secondi la podarìa no èssarghe mìa su sta lista.",
+'lag-warn-normal' => "Le modifiche fate {{PLURAL:$1|ne l'ultimo secondo|nei ultimi $1 secondi}} no podarìa no èssarghe gnancora su sta lista.",
+'lag-warn-high'   => "Par via de un ecessivo ritardo ne l'agiornamento del server de database, le modifiche fate {{PLURAL:$1|ne l'ultimo secondo|nei ultimi $1 secondi}} le podarìa no èssarghe mìa su sta lista.",
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'La lista dei osservati speciali la contien {{PLURAL:$1|una pagina (e la rispetiva pagina de discussion)|$1 pagine (e le rispetive pagine de discussion)}}.',
@@ -2469,7 +2475,7 @@
 'version-software-product'         => 'Prodoto',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Percorso de un file',
 'filepath-page'    => 'Nome del file:',
 'filepath-submit'  => 'Percorso',
@@ -2501,13 +2507,13 @@
 'specialpages-group-media'       => 'Resoconti e caricamenti dei file multimediài',
 'specialpages-group-users'       => 'Utenti e diriti',
 'specialpages-group-highuse'     => 'Pagine doparà assè',
-'specialpages-group-pages'       => 'Liste de pagine',
-'specialpages-group-pagetools'   => 'Strumenti de pagina',
+'specialpages-group-pages'       => 'Liste de pàxene',
+'specialpages-group-pagetools'   => 'Strumenti de pàxena',
 'specialpages-group-wiki'        => 'Dati e strumenti wiki',
 'specialpages-group-redirects'   => 'Reindirizamenti',
 'specialpages-group-spam'        => 'Strumenti anti spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pàxena voda',
 'intentionallyblankpage' => 'Sta pagina la xe stà lassà voda aposta',
 
Index: languages/messages/MessagesNap.php
===================================================================
--- languages/messages/MessagesNap.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNap.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
- * @author SabineCretella
+ * @author Carmine Colacino
  * @author Cryptex
  * @author E. abu Filumena
- * @author SPQRobin
- * @author Siebrand
+ * @author SabineCretella
  * @author לערי ריינהארט
- * @author Carmine Colacino
  */
 
 $fallback = 'it';
@@ -257,7 +255,7 @@
 'fileexists-thumb' => "<center>'''Immagine esistente'''</center>",
 'uploadedimage'    => 'ha carecato "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'Nomme',
 
 # Image description page
@@ -285,7 +283,7 @@
 'move'         => 'Spusta',
 'movethispage' => 'Spusta chesta paggena',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => "Tutte 'e ppaggene",
 'allarticles'    => "Tutt' 'e vvoce",
 'allinnamespace' => "Tutt' 'e ppaggene d&#39;&#39;o namespace $1",
@@ -341,7 +339,7 @@
 'blocklink'          => 'ferma',
 'blocklogpage'       => 'Blocche',
 'blocklogentry'      => 'ha fermato "[[$1]]" pe\' nu mumento \'e $2 $3',
-'blocklogtext'       => "Chesta è 'a lista d&#39;&#39;e azzione 'e blocco e sblocco utente.  'E nnerizze IP bloccate automaticamente nun nce so'. Addumannà 'a [[Special:Ipblocklist|lista IP bloccate]] pp' 'a lista d&#39;&#39;e nnerizze e nomme utente 'o ca blocco nce sta.",
+'blocklogtext'       => "Chesta è 'a lista d&#39;&#39;e azzione 'e blocco e sblocco utente.  'E nnerizze IP bloccate automaticamente nun nce so'. Addumannà 'a [[Special:IPBlockList|lista IP bloccate]] pp' 'a lista d&#39;&#39;e nnerizze e nomme utente 'o ca blocco nce sta.",
 
 # Move page
 'movearticle'             => "Spusta 'a paggena",
@@ -385,7 +383,7 @@
 'numedits'    => "Nummero 'e cagnamiente (articulo): $1",
 'numwatchers' => "Nummero 'e asservature: $1",
 
-# Special:Newimages
+# Special:NewImages
 'noimages' => "Nun nc'è nind' 'a veré.",
 'ilsubmit' => 'Truova',
 
@@ -403,7 +401,7 @@
 'exif-subjectdistancerange-0' => 'Scanusciuta',
 
 # External editor support
-'edit-externally-help' => "Pe piglià cchiù nfromma veré 'e [http://meta.wikimedia.org/wiki/Help:External_editors struzione] ('n ngrese)",
+'edit-externally-help' => "Pe piglià cchiù nfromma veré 'e [http://www.mediawiki.org/wiki/Manual:External_editors struzione] ('n ngrese)",
 
 # 'all' in various places, this might be different for inflected languages
 'namespacesall' => 'Tutte',
Index: languages/messages/MessagesTl.php
===================================================================
--- languages/messages/MessagesTl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Felipe Aira
  * @author Sky Harbor
  * @author לערי ריינהארט
- * @author Felipe Aira
- * @author Siebrand
  */
 
 $messages = array(
@@ -264,7 +263,7 @@
 'nosuchspecialpage' => 'Walang ganoong natatanging pahina',
 'nospecialpagetext' => "<big>'''Humiling ka ng isang natatanging pahina na walang saysay.'''</big>
 
-Isang tala ng mga natatanging pahina na may saysay ay matatagpuan sa [[Special:Specialpages|{{int:specialpages}}]].",
+Isang tala ng mga natatanging pahina na may saysay ay matatagpuan sa [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Kamalian',
@@ -393,7 +392,7 @@
 'reupload'          => 'Magkarga muli',
 'reuploaddesc'      => 'Bumalik sa pormularyo ng pagkarga',
 'uploadnologin'     => 'Hindi nakalagda',
-'uploadnologintext' => 'Dapat ikaw ay [[Special:Userlogin|nakalagda]]
+'uploadnologintext' => 'Dapat ikaw ay [[Special:UserLogin|nakalagda]]
 upang makapagkarga ng talaksan.',
 'uploaderror'       => 'Kamalian sa pagkarga',
 'watchthisupload'   => 'Bantayan itong pahina',
@@ -440,7 +439,7 @@
 'move'              => 'Ilipat',
 'movethispage'      => 'Ilipat itong pahina',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'        => 'Lahat ng pahina',
 'allpages-bad-ns' => 'Wala sa {{SITENAME}} ang ngalan-espasyong "$1".',
 
@@ -530,8 +529,6 @@
 'unlockdb' => 'Buksan ang kalipunan ng datos',
 
 # Move page
-'movenologin'             => 'Hindi nakalagda',
-'movenologintext'         => 'Kailangang ikaw ay isang naka-rehistrong manggagamit at ay [[Special:Userlogin|nakalagda]] upang makapaglipat ng pahina.',
 'movenotallowed'          => 'Wala kang permisong maglipat ng pahina sa {{SITENAME}}.',
 'newtitle'                => 'Sa bagong pamagat:',
 'move-watch'              => 'Bantayan itong pahina',
@@ -600,7 +597,7 @@
 'show-big-image'       => 'Buong resolusyon',
 'show-big-image-thumb' => '<small>Laki ng itong pribyu: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Galeriya ng mga bagong talaksan',
 
 # External editor support
@@ -611,7 +608,7 @@
 'recreate'            => 'Likhain muli',
 
 # HTML dump
-'redirectingto' => 'Nagkakarga sa [[$1]]...',
+'redirectingto' => 'Nagkakarga sa [[:$1]]...',
 
 # action=purge
 'confirm_purge' => 'Linisin ang baunan ng pahinang ito?
@@ -644,7 +641,7 @@
 'version-software-product'  => 'Produkto',
 'version-software-version'  => 'Bersyon',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Talaksan:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesZea.php
===================================================================
--- languages/messages/MessagesZea.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZea.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,11 @@
  * @ingroup Language
  * @file
  *
+ * @author Adnergje
  * @author NJ
- * @author SPQRobin
- * @author Siebrand
- * @author Jon Harald Søby
  * @author Rob Church <robchur@gmail.com>
  * @author Steinbach
  * @author Troefkaart
- * @author Adnergje
  */
 
 $fallback = 'nl';
@@ -319,7 +316,7 @@
 'nosuchspecialpage' => 'Deêze speciaole pagina besti nie',
 'nospecialpagetext' => "<big>'''Je ei een onbestaende speciaole pagina opevrogen.'''</big>
 
-Een lieste mie speciaole pagina’s sti op [[Special:Specialpages|speciaole pagina’s]].",
+Een lieste mie speciaole pagina’s sti op [[Special:SpecialPages|speciaole pagina’s]].",
 
 # General errors
 'error'                => 'Fout',
@@ -551,10 +548,6 @@
 'blockededitsource'         => "D'n tekst van '''joen biedragen''' an '''$1''' staet ieronder:",
 'whitelistedittitle'        => 'Voe bewerken is anmelden verplicht',
 'whitelistedittext'         => "Je mò $1 om pagina's te bewerken.",
-'whitelistreadtitle'        => 'Voe leestoehang is anmelden verplicht',
-'whitelistreadtext'         => "[[Special:Userlogin|Mel jen eihen an]] voe leestoehang toet pagina's.",
-'whitelistacctitle'         => "'t Anmaeken van nieuwe gebrukers is nie toehestaen",
-'whitelistacctext'          => 'Je dien [[Special:Userlogin|anemeld]] te zien en de juuste rechen te ène om gebrukers an te maeken in {{SITENAME}}.',
 'confirmedittitle'          => 'E-mailbevestigieng is verplicht voeda je kan bewerken',
 'confirmedittext'           => "Je mò jen e-mailadres bevestihen voe da je kan bewerken.
 Voer jen e-mailadres in en bevestig 't via [[Special:Preferences|je vòkeuren]].",
@@ -570,7 +563,7 @@
 Gebruuk de knoppe '''vorige''' in je browser as je ier per ongeluk terecht bin ekomm'n.",
 'anontalkpagetext'          => "----''Dit is de overlegbladzie vò 'n anonieme gebruker die-a gin inlognaem eit of 'm nie gebruukt.
 Zien/eur IP-adres kan deu meêr as eên gebruker gebruukt ore.
-A je 'n bericht gekrege è dat-a dudelik nie an joe gericht is, ka je 't beste [[Special:Userlogin|jen eige anmelde]] om zukke verwarrienge in 't vervolg te vòkommen.''",
+A je 'n bericht gekrege è dat-a dudelik nie an joe gericht is, ka je 't beste [[Special:UserLogin|jen eige anmelde]] om zukke verwarrienge in 't vervolg te vòkommen.''",
 'noarticletext'             => 'Deêze pagina bevat hin tekst.
 Je kan [[Special:Search/{{PAGENAME}}|ni deêze term zoeken]] in aore pagina\'s of <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} deêze pagina bewerken]</span>.',
 'userpage-userdoesnotexist' => 'Je bewerk een gebrukerspagina van een gebruker die a nie besti (gebruker "$1"). Controleer of a je deêze pagina wè wil anmaeken/bewerken.',
@@ -647,7 +640,7 @@
 'hiddencategories'          => 'Deêze pagina val in de volhende verborhen {{PLURAL:$1|categorie|categorieën}}:',
 'nocreatetitle'             => "'t Anmaeken van pagina's is beperkt",
 'nocreatetext'              => "{{SITENAME}} ei de meuhlijkeid om nieuwe pagina's an te maeken beperkt.
-Je kan a bestaende pagina's wiezigen, of je kan [[Special:Userlogin|jen eihen anmelden of een gebruker  anmaeken]].",
+Je kan a bestaende pagina's wiezigen, of je kan [[Special:UserLogin|jen eihen anmelden of een gebruker  anmaeken]].",
 'nocreate-loggedin'         => "Je kan hin nieuwe pagina's anmaeken op {{SITENAME}}.",
 'permissionserrors'         => "Fout'n in rechen",
 'permissionserrorstext'     => "Je ei hin rechen om dit te doene wehens de volhende {{PLURAL:$1|reeën|reden'n}}:",
@@ -755,7 +748,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Verberhiengslogboek',
-'suppressionlogtext' => 'De onderstaende lieste bevat de miste recente verwiederiengen en blokkaodes die an voe opzichters verborhen zien. In de [[Special:Ipblocklist|IP-blokkeerlieste]] zien de udihe blokkaodes te bekieken.',
+'suppressionlogtext' => 'De onderstaende lieste bevat de miste recente verwiederiengen en blokkaodes die an voe opzichters verborhen zien. In de [[Special:IPBlockList|IP-blokkeerlieste]] zien de udihe blokkaodes te bekieken.',
 
 # History merging
 'mergehistory'                     => "Heschiedenisse van pagina's saemenvoehen",
@@ -829,7 +822,7 @@
 'mypreferences'            => 'Mien vòkeuren',
 'prefs-edits'              => 'Antal bewerkiengen:',
 'prefsnologin'             => 'Nie anemeld',
-'prefsnologintext'         => "Je mò [[Special:Userlogin|anemeld]] zien om je vòkeuren te kunn'n instell'n.",
+'prefsnologintext'         => "Je mò [[Special:UserLogin|anemeld]] zien om je vòkeuren te kunn'n instell'n.",
 'prefsreset'               => 'Standardvòkeuren zien hersteld.',
 'qbsettings'               => 'Menubalke',
 'qbsettings-none'          => 'Uuteschaokeld',
@@ -900,7 +893,7 @@
 'userrights-reason'           => "Reeën voe 't verandern:",
 'userrights-no-interwiki'     => "Je ei hin rechen om gebrukersrechen op aore wiki's te wiezigen.",
 'userrights-nodatabase'       => 'Database $1 besti nie of is hin plaetselijke database.',
-'userrights-nologin'          => 'Je mò jen eihen[[Special:Userlogin|anmelden]] mie een gebruker mie de juuste rechen om gebrukersrechen toe te wiezen.',
+'userrights-nologin'          => 'Je mò jen eihen[[Special:UserLogin|anmelden]] mie een gebruker mie de juuste rechen om gebrukersrechen toe te wiezen.',
 'userrights-notallowed'       => 'Je ei hin rechen om gebrukersrechen toe te wiezen.',
 'userrights-changeable-col'   => "Hroep'n die a je kan beheern",
 'userrights-unchangeable-col' => "Hroep'n die a je nie kan beheern",
@@ -972,12 +965,12 @@
 'reupload'                   => "Opnieuw upload'n",
 'reuploaddesc'               => "Upload annuleern en teruggaene ni 't uploadformelier",
 'uploadnologin'              => 'Nie anemeld',
-'uploadnologintext'          => "Je mò [[Special:Userlogin|anemeld]] zien
+'uploadnologintext'          => "Je mò [[Special:UserLogin|anemeld]] zien
 om bestan'n te upload'n.",
 'upload_directory_read_only' => 'De webserver kan nie schrieven in de uploadmap ($1).',
 'uploaderror'                => 'Uploadfout',
 'uploadtext'                 => "Gebruuk 't onderstaende formelier om bestan'n te uploaden.
-Om eêder toehevoegde bestan'n te bekieken of te zoeken kan je ni de [[Special:Imagelist|bestandslieste]] haen.
+Om eêder toehevoegde bestan'n te bekieken of te zoeken kan je ni de [[Special:ImageList|bestandslieste]] haen.
 Uploads en verwiederiengen worn bie'ehouwen in 't [[Special:Log/upload|uploadlogboek]].
 
 Om 't bestand in te voehen in een pagina kan je eên van de volhende codes gebruken, a ni helang 't bestandsformaot dat van toepassieng is:
@@ -1026,7 +1019,7 @@
 'alllogstext'         => "Saemengesteld overzicht van de wis-, bescherm-, blokkeer- en gebrukerslechtenlogboeken.
 Je kan 't overzicht bepaelen deu 'n soôrte logboek, 'n gebrukersnaem of eên bladzie uut te kiezen.",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Aolle bladzies',
 'alphaindexline'    => '$1 toet $2',
 'nextpage'          => 'Volgende bladzie ($1)',
@@ -1053,11 +1046,11 @@
 'mywatchlist'          => 'Mien volglieste',
 'watchlistfor'         => "(vò '''$1''')",
 'watchnologin'         => 'Je bin nie angemolde.',
-'watchnologintext'     => 'Je moe [[Special:Userlogin|angemolde]] weze om je volglieste an te passen.',
+'watchnologintext'     => 'Je moe [[Special:UserLogin|angemolde]] weze om je volglieste an te passen.',
 'addedwatch'           => 'An de volglieste toegevoegd',
 'addedwatchtext'       => "De bladzie \"[[:\$1]]\" is an je [[Special:Watchlist|Volglieste]] toegevoegd.
 Veranderiengen an deêze bladzie en de overlegbladzie die-a d'rbie oort zulle ierop zichtbaer ore
-en de bladzie komt '''vet''' te staen in de [[Special:Recentchanges|lieste van wat-a juust veranderd is]], daermee 't makkeliker te vinden is.
+en de bladzie komt '''vet''' te staen in de [[Special:RecentChanges|lieste van wat-a juust veranderd is]], daermee 't makkeliker te vinden is.
 A je de bladzie laeter weêr van je volglieste afaele wil, klik dan op \"nie meêr volge\" bovenan de bladzie.",
 'watch'                => 'Volg',
 'watchthispage'        => 'Bekiek deêze bladzie',
@@ -1096,7 +1089,7 @@
 'badipaddress'                => 'Ongeldig IP-adres',
 'blockipsuccesssub'           => 'Blokkaode is gelukt.',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] is geblokkeerd.<br />
-Ziet de [[Special:Ipblocklist|IP-blokliest]] vo 'n overzicht van blokkaodes.",
+Ziet de [[Special:IPBlockList|IP-blokliest]] vo 'n overzicht van blokkaodes.",
 'anononlyblock'               => 'alleêne anon.',
 'blocklink'                   => 'blokkeer',
 'contribslink'                => 'biedraegen',
@@ -1105,7 +1098,7 @@
 'blocklogentry'               => 'ei "[[$1]]" geblokkeerd mee \'n afloôptied van $2 $3',
 'blocklogtext'                => "Dit is 'n logboek van gebrukersblokkaodes en -deblokkeriengen.
 Automaotisch geblokte ip-adressen stae d'r nie bie.
-Ziet de [[Special:Ipblocklist|Lieste van ip-blokkeriengen]] vò blokkaodes die op dit moment in werkienge bin.",
+Ziet de [[Special:IPBlockList|Lieste van ip-blokkeriengen]] vò blokkaodes die op dit moment in werkienge bin.",
 'block-log-flags-anononly'    => 'allene anonieme gebrukers',
 'block-log-flags-nocreate'    => 'uutgeslote van anmaeken gebrukersnaemen',
 'block-log-flags-noautoblock' => 'gin autoblokkaode',
Index: languages/messages/MessagesLv.php
===================================================================
--- languages/messages/MessagesLv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,10 @@
  * @ingroup Language
  * @file
  *
+ * @author Knakts
+ * @author Xil
  * @author Yyy
- * @author Knakts
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author M.M.S.
- * @author Jon Harald Søby
- * @author Niklas Laxström
  */
 
 /*
@@ -98,11 +94,11 @@
 'friday'        => 'piektdiena',
 'saturday'      => 'sestdiena',
 'sun'           => 'Sv',
-'mon'           => 'Pi',
+'mon'           => 'Pr',
 'tue'           => 'Ot',
 'wed'           => 'Tr',
 'thu'           => 'Ce',
-'fri'           => 'Pie',
+'fri'           => 'Pk',
 'sat'           => 'Se',
 'january'       => 'janvārī',
 'february'      => 'februārī',
@@ -157,8 +153,14 @@
 'category-file-count-limited'    => 'Šajā kategorijā atrodas {{PLURAL:$1|tikai šis fails|šie $1 faili}}.',
 'listingcontinuesabbrev'         => ' (turpinājums)',
 
-'mainpagetext' => "<big>'''MediaWiki veiksmīgi ieinstalēts'''</big>",
+'mainpagetext'      => "<big>'''MediaWiki veiksmīgi ieinstalēts'''</big>",
+'mainpagedocfooter' => 'Izlasi [http://meta.wikimedia.org/wiki/Help:Contents Lietotāja pamācību], lai iegūtu vairāk informācijas par Wiki programmatūras lietošanu.
 
+== Pirmie soļi ==
+* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Konfigurācijas iespēju saraksts]
+* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki J&A]
+* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce Parakstīties uz paziņojumiem par jaunām MediaWiki versijām]',
+
 'about'          => 'Par',
 'article'        => 'Raksts',
 'newwindow'      => '(atveras jaunā logā)',
@@ -239,6 +241,8 @@
 'currentevents-url'    => 'Project:Aktualitātes',
 'disclaimers'          => 'Saistību atrunas',
 'edithelp'             => 'Palīdzība izmaiņām',
+'edithelppage'         => 'Palīdzība:Rediģēšana',
+'helppage'             => 'Palīdzība:Saturs',
 'mainpage'             => 'Sākumlapa',
 'mainpage-description' => 'Sākumlapa',
 'portal'               => 'Kopienas portāls',
@@ -246,7 +250,8 @@
 'privacy'              => 'Privātuma politika',
 'privacypage'          => 'Project:Privātuma politika',
 
-'badaccess' => 'Atļaujas kļūda',
+'badaccess'        => 'Atļaujas kļūda',
+'badaccess-group0' => 'Tev nav atļauts izpildīt darbību, kuru tu pieprasīji.',
 
 'versionrequired'     => "Nepieciešamā ''MediaWiki'' versija: $1.",
 'versionrequiredtext' => "Lai lietotu šo lapu, nepieciešama ''MediaWiki'' versija $1. Sk. [[Special:Version|versija]].",
@@ -267,12 +272,15 @@
 'viewdeleted'         => 'Skatīt $1?',
 'restorelink'         => '$1 {{PLURAL:$1|dzēsto versiju|dzēstās versijas}}',
 'feedlinks'           => 'Barotne:',
+'page-rss-feed'       => '"$1" RSS barotne',
+'page-atom-feed'      => '"$1" Atom barotne',
 'red-link-title'      => '$1 (vēl nav uzrakstīts)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Raksts',
 'nstab-user'      => 'Lietotāja lapa',
 'nstab-media'     => 'Multivides lapa',
+'nstab-special'   => 'Īpašā lapa',
 'nstab-project'   => 'Projekta lapa',
 'nstab-image'     => 'Attēls',
 'nstab-mediawiki' => 'paziņojums',
@@ -297,6 +305,7 @@
 'readonlytext'         => 'Datubāze šobrīd ir bloķēta pret jauniem ierakstiem un citām izmaiņām. Visdrīzāk iemesls ir parasts datubāzes uzturēšanas pasākums, pēc kura tā tiks atjaunota normālā stāvoklī. Administrators, kurš nobloķēja datubāzi, norādīja šādu iemeslu:
 <p>$1',
 'internalerror'        => 'Iekšēja kļūda',
+'internalerror_info'   => 'Iekšējā kļūda: $1',
 'filecopyerror'        => 'Nav iespējams nokopēt failu "$1" uz "$2"',
 'filerenameerror'      => 'Neizdevās pārdēvēt failu "$1" par "$2".',
 'filedeleteerror'      => 'Nevar izdzēst failu "$1".',
@@ -324,11 +333,11 @@
 'logouttitle'                => 'Lietotāja iziešana',
 'logouttext'                 => "'''Tu esi izgājis no {{grammar:ģenitīvs|{{SITENAME}}}}.'''
 
-Vari turpināt to izmantot anonīmi, vari atgriezties kā cits lietotājs vai varbūt tas pats.
-Ņem vērā, ka arī pēc iziešanas no {{grammar:ģenitīvs|{{SITENAME}}}} dažas lapas var tikt parādītas tā, it kā tu vēl būtu iekšā, līdz tiks iztīrīta pārlūka kešatmiņa.",
-'welcomecreation'            => "== Laipni lūdzam, $1! ==
+Vari turpināt to izmantot anonīmi, vari [[Special:UserLogin|atgriezties]] kā cits lietotājs vai varbūt tas pats.
+Ņem vērā, ka arī pēc iziešanas, dažas lapas var tikt parādītas tā, it kā tu vēl būtu iekšā, līdz tiks iztīrīta pārlūka kešatmiņa.",
+'welcomecreation'            => '== Laipni lūdzam, $1! ==
 
-Tavs lietotāja konts ir izveidots. Neaizmirsti, ka ir iespējams mainīt ''{{grammar:ģenitīvs|{{SITENAME}}}}'' izmantošanas izvēles.",
+Tavs lietotāja konts ir izveidots. Neaizmirsti, ka ir iespējams mainīt [[Special:Preferences|{{grammar:ģenitīvs|{{SITENAME}}}} izmantošanas izvēles]].',
 'loginpagetitle'             => 'Lietotāja ieiešana',
 'yourname'                   => 'Tavs lietotājvārds',
 'yourpassword'               => 'Tava parole',
@@ -339,7 +348,7 @@
 'loginproblem'               => '<b>Radās problēma ar ieiešanu.</b><br />Mēģini vēlreiz!',
 'login'                      => 'Ieiet',
 'nav-login-createaccount'    => 'Izveidot jaunu lietotāju vai doties iekšā',
-'loginprompt'                => 'Lai ieietu {{grammar:lokatīvs|{{SITENAME}}}}, tavam datoram ir jāpieņem sīkdatnes (<i>cookies</i>).',
+'loginprompt'                => 'Lai [[Special:UserLogin|ieietu {{grammar:lokatīvs|{{SITENAME}}}}]], tavam datoram ir jāpieņem sīkdatnes (<i>cookies</i>).',
 'userlogin'                  => 'Izveidot jaunu lietotāju vai doties iekšā',
 'logout'                     => 'Iziet',
 'userlogout'                 => 'Iziet',
@@ -443,7 +452,8 @@
 'blockedtitle'              => 'Lietotājs ir bloķēts.',
 'blockedtext'               => "<big>'''Tavs lietotāja vārds vai IP adrese ir nobloķēta.'''</big>
 
-\$1 ir nobloķējis tavu lietotāja vārdu vai IP adresi. Iemesls tam ir:<br />''\$2''<br />.
+\$1 nobloķēja tavu lietotāja vārdu vai IP adresi.
+Bloķējot norādītais iemesls bija: ''\$2''.
 
 *Bloka sākums: \$8
 *Bloka beigas: \$6
@@ -453,7 +463,7 @@
 
 Pievērs uzmanību, tam, ka ja tu neesi norādījis derīgu e-pasta adresi ''[[Special:Preferences|manās izvēlēs]]'', tev nedarbosies \"sūtīt e-pastu\" iespēja.
 
-Tava IP adrese ir \$3 un bloka identifikators ir \$5. Lūdzu iekļauj vienu no tiem, vai abus, visos turpmākajos pieprasījumos.",
+Tava IP adrese ir \$3 un bloka identifikators ir #\$5. Lūdzu iekļauj vienu no tiem, vai abus, visos turpmākajos pieprasījumos.",
 'autoblockedtext'           => 'Tava IP adrese ir tikusi automātiski nobloķēta, tāpēc, ka to (nupat kā) ir lietojis cits lietotājs, kuru nobloķēja $1.
 Norādītais bloķēšanas iemesls bija:
 
@@ -461,18 +471,16 @@
 
 * Bloka sākums: $8
 * Bloka beigas: $6
+* Bija domāts nobloķēt: $7
 
 Tu vari sazināties ar $1 vai kādu citu [[{{MediaWiki:Grouppage-sysop}}|adminu]] lai apspriestu šo bloku.
 
 Atceries, ka tu nevari lietot "sūtīt e-pastu šim lietotājam" iespēju, ja tu neesi norādījis derīgu e-pasta adresi savās [[Special:Preferences|lietotāja izvelēs]] un bloķējot tev nav aizbloķēta iespēja sūtīt e-pastu.
 
-Tava bloka ID ir $5.
-Lūdzu iekļauj šo ID visos ziņojumos, kurus sūti adminiem, apspriežot šo bloku.',
+Tava pašreizējā IP adrese ir $3 un  bloka ID ir $5.
+Lūdzu iekļauj šos visos ziņojumos, kurus sūti adminiem, apspriežot šo bloku.',
 'whitelistedittitle'        => 'Lai varētu rediģēt, šeit jāielogojas.',
 'whitelistedittext'         => 'Tev $1 lai varētu rediģēt lapas.',
-'whitelistreadtitle'        => 'Jāielogojas, lai varētu lasīt',
-'whitelistreadtext'         => 'Tev [[Special:Userlogin|jāielogojas]] lai varētu lasīt lapas.',
-'whitelistacctitle'         => 'Tev nav atļauts izveidot kontu',
 'loginreqtitle'             => 'Nepieciešama ieiešana',
 'loginreqlink'              => 'login',
 'accmailtitle'              => 'Parole izsūtīta.',
@@ -483,23 +491,26 @@
 Ja tu šeit nonāci kļūdas pēc, vienkārši uzspied '''back''' pogu pārlūkprogrammā.",
 'anontalkpagetext'          => "----''Šī ir diskusiju lapa anonīmam lietotājam, kurš vēl nav kļuvis par reģistrētu lietotāju vai arī neizmanto savu lietotājvārdu. Tādēļ mums ir jāizmanto skaitliskā IP adrese, lai viņu identificētu.
 Šāda IP adrese var būt vairākiem lietotājiem.
-Ja tu esi anonīms lietotājs un uzskati, ka tev ir adresēti neatbilstoši komentāri, lūdzu, [[Special:Userlogin|kļūsti par lietotāju vai arī izmanto jau izveidotu lietotājvārdu]], lai izvairītos no turpmākām neskaidrībām un tu netiktu sajaukts ar citiem anonīmiem lietotājiem.''",
+Ja tu esi anonīms lietotājs un uzskati, ka tev ir adresēti neatbilstoši komentāri, lūdzu, [[Special:UserLogin/signup|kļūsti par lietotāju]] vai arī [[Special:UserLogin|izmanto jau izveidotu lietotājvārdu]], lai izvairītos no turpmākām neskaidrībām un tu netiktu sajaukts ar citiem anonīmiem lietotājiem.''",
 'noarticletext'             => 'Šajā lapā šobrīd nav nekāda teksta, tu vari [[Special:Search/{{PAGENAME}}|meklēt citās lapās pēc šīs lapas nosaukuma]], vai arī [{{fullurl:{{FULLPAGENAME}}|action=edit}} sākt rediģēt šo lapu].',
+'userpage-userdoesnotexist' => 'Lietotājs "$1" nav reģistrēts.
+Lūdzu, pārliecinies vai vēlies izveidot/izmainīt šo lapu.',
 'clearyourcache'            => "'''Piezīme - Pēc saglabāšanas, lai būtu redzamas izmaiņas, var būt nepieciešamas iztīrīt pārlūka kešatmiņu.''' '''Mozilla / Firefox / Safari:''' turi nospiestu ''Shift'' un klikšķini ''Reload,'' vai arī spied ''Ctrl-F5'' vai ''Ctrl-R'' (''Command-R'' uz Macintosh); '''Konqueror: '''klikšķini ''Reload'' vai spied uz ''F5;'' '''Opera:''' kešu var iztīrīt ''Tools → Preferences;'' '''Internet Explorer:''' turi nospiestu ''Ctrl'' un klikšķini ''Refresh,'' vai spied ''Ctrl-F5.''",
 'usercssjsyoucanpreview'    => '<strong>Ieteikums:</strong> Lieto pirmsskata pogu, lai pārbaudītu savu jauno CSS/JS pirms saglabāšanas.',
 'usercsspreview'            => "'''Atceries, ka šis ir tikai tava lietotāja CSS pirmskats, lapa vēl nav saglabāta!'''",
 'userjspreview'             => "'''Atceries, ka šis ir tikai tava lietotāja JavaScript pirmskats/tests, lapa vēl nav saglabāta!'''",
+'updated'                   => '(Atjaunots)',
 'note'                      => '<strong>Piezīme: </strong>',
 'previewnote'               => '<strong>Atceries, ka šis ir tikai pirmskats un vēl nav saglabāts!</strong>',
 'session_fail_preview'      => '<strong>Atvainojiet, neizdevās apstrādāt tavas izmaiņas, jo tika pazaudēti sesijas dati.
 Lūdzu mēģini vēlreiz.
-Ja tas joprojām nedarbojas, mēģini izlogoties ārā un ielogoties no jauna.</strong>',
+Ja tas joprojām nedarbojas, mēģini [[Special:UserLogout|izlogoties ārā]] un ielogoties no jauna.</strong>',
 'session_fail_preview_html' => "<strong>Atvainojiet, neizdevās apstrādāt tavas izmaiņas, jo tika pazaudēti sesijas dati.</strong>
 
 ''Tā, kā {{grammar:ģenitīvs|{{SITENAME}}}} darbojas neapstrādāts HTML, pirmskats ir paslēpts, lai aizsargātos no JavaScripta  uzbrukumiem.''
 
 <strong>Ja šis bija parasts rediģēšanas mēģinājums, mēģini vēlreiz.
-Ja tas joprojām nedarbojas, mēģini izlogoties ārā un ielogoties no jauna.</strong>",
+Ja tas joprojām nedarbojas, mēģini [[Special:UserLogout|izlogoties ārā]] un ielogoties no jauna.</strong>",
 'editing'                   => 'Izmainīt $1',
 'editingsection'            => 'Izmainīt $1 (sadaļa)',
 'editingcomment'            => 'Izmainīt $1 (komentārs)',
@@ -511,6 +522,8 @@
 Kad spiedīsi pogu \"Saglabāt lapu\", tiks saglabāts '''tikai''' teksts, kas ir augšējā teksta logā.",
 'yourtext'                  => 'Tavs teksts',
 'storedversion'             => 'Saglabātā versija',
+'nonunicodebrowser'         => '<strong>Brīdinājums: Tavs pārlūks neatbalsta unikodu.
+Ir pieejams risinājums, kas ļaus tev droši rediģēt lapas: zīmes, kas nav ASCII, parādīsies izmaiņu logā kā heksadecimāli kodi.</strong>',
 'editingold'                => '<strong>BRĪDINĀJUMS: Saglabājot šo lapu, tu izmainīsi šīs lapas novecojušu versiju, un ar to tiks dzēstas visas izmaiņas, kas izdarītas pēc šīs versijas.</strong>',
 'yourdiff'                  => 'Atšķirības',
 'copyrightwarning'          => 'Lūdzu, ņem vērā, ka viss ieguldījums, kas veikts {{grammar:lokatīvs|{{SITENAME}}}}, ir uzskatāms par publiskotu saskaņā ar $2 (vairāk info skat. $1).
@@ -524,16 +537,38 @@
 
 '''BEZ ATĻAUJAS NEPIEVIENO DARBU, KO AIZSARGĀ AUTORTIESĪBAS!'''",
 'longpagewarning'           => '<strong>Šī lapa ir $1 kilobaitus liela. Tas var būt vairāk par lapas optimālo izmēru. Lūdzu apsver iespēju sašķelt to mazākās sekcijās.</strong>',
+'longpageerror'             => '<strong>Kļūda: Teksts, kuru tu mēģināji saglabāt, ir $1 kilobaitus garš, kas ir vairāk nekā pieļaujamie $2 kilobaiti.
+Tas nevar tikt saglabāts.</strong>',
+'readonlywarning'           => '<strong>Brīdinājums: Datubāze ir slēgta apkopei, tāpēc tu tagad nevarēsi saglabāt veiktās izmaiņas.
+Tu varētu nokopēt tekstu un saglabāt kā teksta failu vēlākam laikam.</strong>',
 'protectedpagewarning'      => "'''BRĪDINĀJUMS: Šī lapa ir bloķēta pret izmaiņām, tikai lietotāji ar admina privilēģijām var to izmainīt. To darot, noteikti ievēro [[Project:Norādījumi par aizsargātajām lapām|norādījumus par aizsargātajām lapām]].'''",
 'semiprotectedpagewarning'  => "'''Piezīme:''' Izmaiņu veikšana šajā lapā ir atļauta tikai reģistrētiem lietotājiem.",
+'titleprotectedwarning'     => '<strong>Brīdinājums: Šī lapa ir slēgta un to var izveidot tikai noteikti lietotāji.</strong>',
 'templatesused'             => '<br />Šajā lapā izmantotās veidnes:',
+'templatesusedpreview'      => 'Šajā pirmskatā izmantotās veidnes:',
+'templatesusedsection'      => 'Šajā sadaļā izmantotās veidnes:',
+'template-protected'        => '(aizsargāta)',
+'template-semiprotected'    => '(daļēji aizsargāta)',
+'hiddencategories'          => 'Šī lapa ietilpst {{PLURAL:$1|1 slēptajā kategorijā|$1 slēptajās kategorijās}}:',
 'nocreatetext'              => '{{grammar:lokatīvs|{{SITENAME}}}} ir atslēgta iespēja izveidot jauinas lapas.
-Tu vari atgriezties atpakaļ un izmainīt esošu lapu, vai arī [[Special:Userlogin|ielogoties, vai izveidot kontu]].',
+Tu vari atgriezties atpakaļ un izmainīt esošu lapu, vai arī [[Special:UserLogin|ielogoties, vai izveidot kontu]].',
 'recreate-deleted-warn'     => "'''Brīdinājums: Tu atjauno lapu, kas ir tikusi izdzēsta'''
 
 Tev vajadzētu pārliecināties, vai ir lietderīgi turpināt izmainīt šo lapu.
 Te var apskatīties dzēšanas reģistru, kurā jābūt datiem par to kas, kad un kāpēc šo lapu izdzēsa.",
 
+# "Undo" feature
+'undo-success' => 'Šo izmaiņu var atcellt.
+Lūdzu, pārbaudi zemāk redzamajā salīdzinājumā vai tu to tiešām vēlies darīt un pēc tam saglabā izmaiņas, lai to atceltu.',
+'undo-norev'   => 'Šo izmaiņu nevar atcelt, jo tādas nav vai tā ir izdzēsta.',
+'undo-summary' => 'Atcēlu [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskusija]]) izdarīto izmaiņu $1',
+
+# Account creation failure
+'cantcreateaccounttitle' => 'Nevar izveidot lietotāju',
+'cantcreateaccount-text' => "[[Lietotājs:$3|$3]] ir bloķējis lietotāja izveidošanu no šīs IP adreses ('''$1''').
+
+$3 norādītais iemesls ir ''$2''",
+
 # History pages
 'viewpagelogs'        => 'Apskatīties ar šo lapu saistītos reģistru ierakstus',
 'nohistory'           => 'Šai lapai nav pieejama versiju hronoloģija.',
@@ -559,6 +594,7 @@
 'histfirst'           => 'Senākās',
 'histlast'            => 'Jaunākās',
 'historysize'         => '({{PLURAL:$1|1 baits|$1 baiti}})',
+'historyempty'        => '(tukša)',
 
 # Revision feed
 'history-feed-title'          => 'Versiju hronoloģija',
@@ -581,7 +617,7 @@
 # Search results
 'searchresults'         => 'Meklēšanas rezultāti',
 'searchresulttext'      => 'Lai iegūtu vairāk informācijas par meklēšanu {{grammar:akuzatīvs|{{SITENAME}}}}, skat. [[{{MediaWiki:Helppage}}|{{grammar:ģenitīvs|{{SITENAME}}}} meklēšana]].',
-'searchsubtitle'        => "Pieprasījums: '''[[:$1]]'''",
+'searchsubtitle'        => 'Pieprasījums: \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|visas lapas, kas sākas ar "$1"]] | [[Special:WhatLinksHere/$1|visas lapas, kurās ir saite uz "$1"]])',
 'searchsubtitleinvalid' => 'Pieprasījums: $1',
 'noexactmatch'          => "'''Lapas ar nosaukumu \"\$1\" šeit nav.''' Tu vari to [[:\$1|izveidot]].",
 'noexactmatch-nocreate' => "'''Šeit nav lapas ar nosaukumu \"\$1\".'''",
@@ -607,7 +643,7 @@
 'mypreferences'         => 'manas izvēles',
 'prefs-edits'           => 'Izmaiņu skaits:',
 'prefsnologin'          => 'Neesi iegājis',
-'prefsnologintext'      => 'Tev jābūt [[Special:Userlogin|iegājušam]], lai mainītu lietotāja izvēles.',
+'prefsnologintext'      => 'Tev jābūt [[Special:UserLogin|iegājušam]], lai mainītu lietotāja izvēles.',
 'prefsreset'            => 'Sākotnējās izvēles ir atjaunotas.',
 'qbsettings'            => 'Rīku joslas stāvoklis',
 'changepassword'        => 'Mainīt paroli',
@@ -740,12 +776,12 @@
 'reupload'               => 'Vēlreiz augšuplādēt',
 'reuploaddesc'           => 'Atcelt augšupielādi un atgriezties pie augšupielādes veidnes.',
 'uploadnologin'          => 'Neesi iegājis',
-'uploadnologintext'      => 'Tev jābūt [[Special:Userlogin|iegājušam]], lai augšuplādētu failus.',
+'uploadnologintext'      => 'Tev jābūt [[Special:UserLogin|iegājušam]], lai augšuplādētu failus.',
 'uploaderror'            => 'Augšupielādes kļūda',
 'uploadtext'             => "'''STOP!''' Pirms tu kaut ko augšupielādē, noteikti izlasi un ievēro [[Project:Attēlu izmantošanas noteikumi|attēlu izmantošanas noteikumus]].
 
 Lai aplūkotu vai meklētu agrāk augšuplādētus attēlus,
-dodies uz [[Special:Imagelist|augšupielādēto attēlu sarakstu]].
+dodies uz [[Special:ImageList|augšupielādēto attēlu sarakstu]].
 Augšupielādes un dzēšanas tiek reģistrētas [[Special:Log/upload|augšupielādes reģistrā]].
 
 Izmanto šo veidni, lai augšupielādētu jaunus attēlu failus, ar kuriem ilustrēt tevis izmainītās lapas.
@@ -822,7 +858,7 @@
 
 'license' => 'Licence:',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Šajā lapā ir redzami visi augšuplādētie faili.
 Pēc noklusējuma, pēdējie ielādētie faili atrodas saraksta augšā.
 Uzklikšķinot uz kādas kolonnas virsraksta, var sakārtot pēc kāda cita parametra.',
@@ -859,18 +895,18 @@
 # File reversion
 'filerevert'                => 'Atjaunot $1',
 'filerevert-legend'         => 'Atjaunot failu',
-'filerevert-intro'          => '<span class="plainlinks">Tu atjauno failu \'\'\'[[Media:$1|$1]]\'\'\' uz [$4 versiju kāda bija $3, $2].</span>',
+'filerevert-intro'          => "Tu atjauno failu '''[[Media:$1|$1]]''' uz [$4 versiju kāda bija $3, $2].",
 'filerevert-comment'        => 'Komentārs:',
 'filerevert-defaultcomment' => 'Atjaunots uz $2, $1 versiju',
 'filerevert-submit'         => 'Atjaunot',
-'filerevert-success'        => '<span class="plainlinks">Fails \'\'\'[[Media:$1|$1]]\'\'\' tika atjaunots uz [$4 versiju, kāda tā bija $3, $2].</span>',
+'filerevert-success'        => "Fails '''[[Media:$1|$1]]''' tika atjaunots uz [$4 versiju, kāda tā bija $3, $2].",
 'filerevert-badversion'     => 'Šajam failam nav iepriekšējās versijas, kas atbilstu norādītajam datumam un laikam.',
 
 # File deletion
 'filedelete'                  => 'Dzēst $1',
 'filedelete-legend'           => 'Dzēst failu',
 'filedelete-intro'            => "Tu taisies izdzēst '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Tu tagad taisies izdzēst faila \'\'\'[[Media:$1|$1]]\'\'\' versiju, kas tika augšuplādēta [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Tu tagad taisies izdzēst faila '''[[Media:$1|$1]]''' versiju, kas tika augšuplādēta [$4 $3, $2].",
 'filedelete-comment'          => 'Dzēšanas iemesls:',
 'filedelete-submit'           => 'Izdzēst',
 'filedelete-success'          => "'''$1''' tika veiksmīgi izdzēsts.",
@@ -915,7 +951,7 @@
 Vidēji tas ir '''\$5''' labojumi uz lapu un apskatīšanas/labojumu attiecība ir '''\$6'''.
 
 The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''\$7'''.",
-'userstatstext' => "Reģistrēto [[Special:Listusers|lietotāju]] skaits ir '''$1'''. No tiem '''$2''' (jeb '''$4%''') ir {{PLURAL:$2|administrators|administratori}} (skat. $5).",
+'userstatstext' => "Reģistrēto [[Special:ListUsers|lietotāju]] skaits ir '''$1'''. No tiem '''$2''' (jeb '''$4%''') ir {{PLURAL:$2|administrators|administratori}} (skat. $5).",
 
 'disambiguations'     => 'Nozīmju atdalīšanas lapas',
 'disambiguationspage' => 'Template:Disambig',
@@ -983,7 +1019,7 @@
 Tu vari sašaurināt aplūkojamo reģistru, izvēloties reģistra veidu, lietotāja vārdu vai reģistrēto lapu.',
 'logempty'             => 'Reģistrā nav atbilstošu ierakstu.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Visas lapas',
 'alphaindexline' => 'no $1 līdz $2',
 'nextpage'       => 'Nākamā lapa ($1)',
@@ -998,22 +1034,22 @@
 'categoriespagetext' => 'Wiki ir atrodamas šādas kategorijas.',
 'categoriesfrom'     => 'Parādīt kategorijas sākot ar:',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom' => 'Parādīt lietotājus sākot ar:',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'         => 'Lietotāju grupu tiesības',
-'listgrouprights-summary' => 'Šitas ir šajā wiki definēto lietotāju grupu uskaitījums, kopā ar tām atbilstošajām piekļuves tiesībām.
-Papildu informāciju par katru individuālu piekļuves tiesību veidu var atrast [[{{MediaWiki:Listgrouprights-helppage}}]].',
+'listgrouprights-summary' => 'Šis ir šajā wiki definēto lietotāju grupu uskaitījums, kopā ar tām atbilstošajām piekļuves tiesībām.
+Papildu informāciju par katru individuālu piekļuves tiesību veidu, iespējams, var atrast [[{{MediaWiki:Listgrouprights-helppage}}]].',
 'listgrouprights-group'   => 'Grupa',
 'listgrouprights-rights'  => 'Tiesības',
 
 # E-mail user
 'mailnologin'     => 'Nav adreses, uz kuru sūtīt',
-'mailnologintext' => 'Tev jābūt [[Special:Userlogin|iegājušam]], kā arī tev jābūt [[Special:Preferences|norādītai]] derīgai e-pasta adresei, lai sūtītu e-pastu citiem lietotājiem.',
+'mailnologintext' => 'Tev jābūt [[Special:UserLogin|iegājušam]], kā arī tev jābūt [[Special:Preferences|norādītai]] derīgai e-pasta adresei, lai sūtītu e-pastu citiem lietotājiem.',
 'emailuser'       => 'Sūtīt e-pastu šim lietotājam',
 'emailpage'       => 'Sūtīt e-pastu lietotājam',
-'emailpagetext'   => 'Ja šis lietotājs ir norādījis reālu e-pasta adresi savu izvēļu lapā, tad ar šo veidni ir iespējams tam nosūtīt e-pastu. Tā e-pasta adrese, kuru tu esi norādījis savā izvēļu lapā, parādīsies e-pasta "From" lauciņā, tādēļ saņēmējs varēs tev atbildēt.',
+'emailpagetext'   => 'Ja šis lietotājs ir norādījis reālu e-pasta adresi savu izvēļu lapā, tad ar šo veidni ir iespējams viņam nosūtīt e-pastu. Tā e-pasta adrese, kuru tu esi norādījis [[Special:Preferences|savā izvēļu lapā]], parādīsies e-pasta "From" lauciņā, tādejādi saņēmējs varēs tev atbildēt.',
 'defemailsubject' => 'E-pasts par {{grammar:akuzatīvs|{{SITENAME}}}}',
 'noemailtitle'    => 'Nav e-pasta adreses',
 'noemailtext'     => 'Šis lietotājs nav norādījis derīgu e-pasta adresi vai arī ir izvēlējies nesaņemt e-pastu no citiem lietotājiem.',
@@ -1031,9 +1067,9 @@
 'watchlistfor'         => "(priekš '''$1''')",
 'nowatchlist'          => 'Tavā uzraugāmo rakstu sarakstā nav neviena raksta.',
 'watchnologin'         => 'Neesi iegājis',
-'watchnologintext'     => 'Tev ir [[Special:Userlogin|jāieiet]], lai mainītu uzraugāmo lapu sarakstu.',
+'watchnologintext'     => 'Tev ir [[Special:UserLogin|jāieiet]], lai mainītu uzraugāmo lapu sarakstu.',
 'addedwatch'           => 'Pievienots uzraugāmo sarakstam.',
-'addedwatchtext'       => "Lapa \"<nowiki>\$1</nowiki>\" ir pievienota [[Special:Watchlist|tevis uzraudzītajām lapām]], kur tiks parādītas izmaiņas, kas izdarītas šajā lapā vai šīs lapas diskusiju lapā, kā arī šī lapa tiks iezīmēta '''pustrekna''' [[Special:Recentchanges|pēdējo izmaiņu lapā]], lai to būtu vieglāk pamanīt.
+'addedwatchtext'       => "Lapa \"<nowiki>\$1</nowiki>\" ir pievienota [[Special:Watchlist|tevis uzraudzītajām lapām]], kur tiks parādītas izmaiņas, kas izdarītas šajā lapā vai šīs lapas diskusiju lapā, kā arī šī lapa tiks iezīmēta '''pustrekna''' [[Special:RecentChanges|pēdējo izmaiņu lapā]], lai to būtu vieglāk pamanīt.
 
 Ja vēlāk pārdomāsi un nevēlēsies vairs uzraudzīt šo lapu, klikšķini uz saites '''neuzraudzīt''' rīku joslā.",
 'removedwatch'         => 'Lapa vairs netiek uzraudzīta',
@@ -1092,9 +1128,10 @@
 'rollbacklink'                => 'novērst',
 'rollbackfailed'              => 'Novēršana neizdevās',
 'cantrollback'                => 'Nav iespējams novērst labojumu; iepriekšējais labotājs ir vienīgais lapas autors.',
-'alreadyrolled'               => 'Nav iespējams novērst pēdējās izmaiņas, ko lapā [[$1]] saglabāja [[User:$2|$2]] ([[User talk:$2|Diskusija]]). Kāds cits jau ir rediģējis šo lapu vai novērsis izmaiņas.
+'alreadyrolled'               => 'Nav iespējams novērst pēdējās izmaiņas, ko lapā [[:$1]] saglabāja [[User:$2|$2]] ([[User talk:$2|Diskusija]] | [[Special:Contributions/$2|{{int:contribslink}}]]). Kāds cits jau ir rediģējis šo lapu vai novērsis izmaiņas.
 
-Pēdējās izmaiņas saglabāja [[User:$3|$3]] ([[User talk:$3|diskusija]])',
+Pēdējās izmaiņas saglabāja [[User:$3|$3]] ([[User talk:$3|diskusija]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
+'editcomment'                 => 'Attiecīgās izmaiņas kopsavilkums bija: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Novērsu izmaiņas, ko izdarīja [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskusija]]), atjaunoju versiju, ko saglabāja [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Tika novērstas $1 izdarītās izmaiņas;
 un tika atjaunota iepriekšējā versija, kuru bija izveidojis $2.',
@@ -1185,7 +1222,7 @@
 
 # What links here
 'whatlinkshere'            => 'Norādes uz šo rakstu',
-'whatlinkshere-title'      => 'Lapas, kurās ir saites uz lapu $1',
+'whatlinkshere-title'      => 'Lapas, kurās ir saites uz lapu "$1"',
 'whatlinkshere-page'       => 'Lapa:',
 'linklistsub'              => '(Saišu uzskaitījums)',
 'linkshere'                => "Šajās lapās ir norādes uz lapu '''[[:$1]]''':",
@@ -1227,7 +1264,7 @@
 'badipaddress'         => 'Nederīga IP adrese',
 'blockipsuccesssub'    => 'Nobloķēts veiksmīgi',
 'blockipsuccesstext'   => '[[Special:Contributions/$1|$1]] tika nobloķēts.<br />
-Visus blokus var apskatīties [[Special:Ipblocklist|IP bloku sarakstā]].',
+Visus blokus var apskatīties [[Special:IPBlockList|IP bloku sarakstā]].',
 'ipb-edit-dropdown'    => 'Izmainīt bloķēšanas iemeslus',
 'ipb-unblock-addr'     => 'Atbloķēt $1',
 'ipb-unblock'          => 'Atbloķēt lietotāju vai IP adresi',
@@ -1237,7 +1274,7 @@
 'ipusubmit'            => 'Atbloķēt šo adresi',
 'unblocked'            => '[[Lietotājs:$1|$1]] tika atbloķēts',
 'unblocked-id'         => 'Bloks $1 tika noņemts',
-'ipblocklist'          => 'Bloķēto IP adrešu un lietotājvārdu uzskaitījums',
+'ipblocklist'          => 'Bloķētās IP adreses un lietotājvārdi',
 'ipblocklist-username' => 'Lietotāja vārds vai IP adrese:',
 'blocklistline'        => '$1 $2 bloķēja $3 (termiņš $4)',
 'expiringblock'        => 'beidzas $1',
@@ -1249,7 +1286,7 @@
 'blocklogpage'         => 'Bloķēšanas reģistrs',
 'blocklogentry'        => 'nobloķēja [[$1]] uz $2 $3',
 'blocklogtext'         => 'Šajā lapā ir pēdējo nobloķēto un atbloķēto lietotāju un IP adrešu saraksts. Te neparādās automātiski nobloķētās IP adreses.
-Šobrīd aktīvos blokus var apskatīties [[Special:Ipblocklist|bloķēto lietotāju un IP adrešu sarakstā]].',
+Šobrīd aktīvos blokus var apskatīties [[Special:IPBlockList|bloķēto lietotāju un IP adrešu sarakstā]].',
 'ipb_expiry_invalid'   => 'Nederīgs beigu termiņš',
 'ip_range_invalid'     => 'Nederīgs IP diapazons',
 'proxyblocker'         => 'Starpniekservera bloķētājs',
@@ -1260,7 +1297,8 @@
 'move-page-legend'        => 'Pārvietot lapu',
 'movepagetext'            => "Šajā lapā tu vari pārdēvēt vai pārvietot lapu, kopā tās izmaiņu hronoloģiju pārvietojot to uz citu nosaukumu.
 Iepriekšējā lapa kļūs par lapu, kas pāradresēs uz jauno lapu.
-Saites uz iepriekšējo lapu netiks mainītas, bet noteikti pārbaudi un izlabo, izskaužot dubultu pāradresāciju vai pāradresāciju uz neesošu lapu.
+Šeit var automātiski izmainīt visas pāradresācijas (redirektus) uz šo lapu (2. ķeksis apakšā).
+Saites pārējās lapās uz iepriekšējo lapu netiks mainītas. Ja izvēlies neizmainīt pāradresācijas automātiski, noteikti pārbaudi un izlabo, izskaužot [[Special:DoubleRedirects|dubultu pāradresāciju]] vai [[Special:BrokenRedirects|pāradresāciju uz neesošu lapu]].
 Tev ir jāpārliecinās, vai saites vēl aizvien ved tur, kur tās ir paredzētas.
 
 Ņem vērā, ka lapa '''netiks''' pārvietota, ja jau eksistē kāda cita lapa ar vēlamo nosaukumu (izņemot gadījumus, kad tā ir tukša vai kad tā ir pāradresācijas lapa, kā arī tad, ja tai nav izmaiņu hronoloģijas).
@@ -1276,8 +1314,6 @@
 
 Ja tomēr vēlēsies, tad tev šī diskusiju lapa būs jāpārvieto vai jāapvieno pašam.",
 'movearticle'             => 'Pārvietot lapu',
-'movenologin'             => 'Neesi iegājis kā reģistrēts lietotājs',
-'movenologintext'         => 'Tev ir jābūt reģistrētam lietotājam un jābūt [[Special:Userlogin|iegājušam]] {{grammar:lokatīvs|{{SITENAME}}}}, lai pārvietotu lapu.',
 'movenotallowed'          => 'Tev {{grammar:lokatīvs|{{SITENAME}}}} nav tiesību pārvietot lapas .',
 'newtitle'                => 'Uz šādu lapu',
 'move-watch'              => 'Uzraudzīt šo lapu',
@@ -1302,7 +1338,7 @@
 'revertmove'              => 'atcelt',
 'delete_and_move'         => 'Dzēst un pārvietot',
 'delete_and_move_text'    => '==Nepieciešama dzēšana==
-Mērķa lapa "[[$1]]" jau eksistē.
+Mērķa lapa "[[:$1]]" jau eksistē.
 Vai tu to gribi izdzēst, lai atbrīvotu vietu pārvietošanai?',
 'delete_and_move_confirm' => 'Jā, dzēst lapu',
 'delete_and_move_reason'  => 'Izdzēsts, lai atbrīvotu vietu parvietošanai',
@@ -1310,6 +1346,7 @@
 nevar pārvietot lapu uz sevi.',
 'immobile_namespace'      => "Izejas vai mērķa lapa ir īpašā lapa;
 nevar pārvietot lapas no un lapas uz to ''namespaci''.",
+'fix-double-redirects'    => 'Automātiski izmainīt visas pāradresācijas, kas ved uz sākotnējo nosaukumu',
 
 # Export
 'export'            => 'Eksportēt lapas',
@@ -1448,10 +1485,10 @@
 'show-big-image'       => 'Pilnā izmērā',
 'show-big-image-thumb' => '<small>Šī priekšskata izmērs: $1 × $2 pikseļi</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Jauno attēlu galerija',
 'imagelisttext'         => 'Šobrīd redzams $1 {{PLURAL:$1|attēla|attēlu}} uzskaitījums, kas sakārtots $2.',
-'newimages-summary'     => 'Šeit var apskatīties pēdējos šeit augšuplādētos failus',
+'newimages-summary'     => 'Šeit var apskatīties pēdējos šeit augšuplādētos failus.',
 'showhidebots'          => '($1 botus)',
 'noimages'              => 'Nav nekā ko redzēt.',
 'ilsubmit'              => 'Meklēt',
@@ -1513,7 +1550,7 @@
 
 # External editor support
 'edit-externally'      => 'Izmainīt šo failu ar ārēju programmu',
-'edit-externally-help' => 'Skat. [http://meta.wikimedia.org/wiki/Help:External_editors instrukcijas] Meta-Wiki, lai iegūtu vairāk informācijas.',
+'edit-externally-help' => 'Skat. [http://www.mediawiki.org/wiki/Manual:External_editors instrukcijas] Meta-Wiki, lai iegūtu vairāk informācijas.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'visi',
@@ -1571,7 +1608,7 @@
 'recreate'            => 'Izveidot no jauna',
 
 # HTML dump
-'redirectingto' => 'Pāradresē uz [[$1]]...',
+'redirectingto' => 'Pāradresē uz [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Iztīrīt šīs lapas kešu (''cache'')?
@@ -1611,8 +1648,8 @@
 'livepreview-error'   => 'Neizdevās pievienoties: $1 "$2". Pamēģini parasto pirmskatu.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Izmaiņas, kas ir jaunākas par  $1 sekundēm, var neparādīties šajā sarakstā.',
-'lag-warn-high'   => 'Sakarā ar lielu datubāzes servera lagu, izmaiņas, kas svaigākas par $1 sekundēm šajā sarakstā var neparādīties.',
+'lag-warn-normal' => 'Izmaiņas, kas ir jaunākas par  $1 {{PLURAL:$1|sekundi|sekundēm}}, var neparādīties šajā sarakstā.',
+'lag-warn-high'   => 'Sakarā ar lielu datubāzes servera lagu, izmaiņas, kas svaigākas par $1 {{PLURAL:$1|sekundi|sekundēm}}, šajā sarakstā var neparādīties.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Tavs uzraugāmo lapu saraksts satur {{PLURAL:$1|1 lapu|$1 lapas}}, neieskaitot diskusiju lapas.',
@@ -1646,7 +1683,7 @@
 'version-extensions'   => 'Ieinstalētie paplašinājumi',
 'version-specialpages' => 'Īpašās lapas',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Failu adreses',
 'filepath-page'   => 'Fails:',
 'filepath-submit' => 'Atrast adresi',
Index: languages/messages/MessagesScn.php
===================================================================
--- languages/messages/MessagesScn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesScn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Tonyfroio
  * @author Melos
  * @author Sarvaturi
+ * @author Tonyfroio
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Niklas Laxström
  */
 
 $fallback = 'it';
@@ -400,7 +398,7 @@
 'nosuchspecialpage' => 'Sta pàggina spiciali nun è dispunìbbili',
 'nospecialpagetext' => "<big>'''Hai cercatu na pàggina spiciali nun vàlida.'''</big>
 
-L'alencu dî pàggini spiciali vàlidi s'attrova 'n [[Special:Specialpages|Alencu dî pàggini spiciali]].",
+L'alencu dî pàggini spiciali vàlidi s'attrova 'n [[Special:SpecialPages|Alencu dî pàggini spiciali]].",
 
 # General errors
 'error'                => 'Erruri',
@@ -612,10 +610,6 @@
 'blockededitsource'                => "Di sèquitu vèninu ammustrati li '''canciamenti appurtati''' â pàggina '''$1''':",
 'whitelistedittitle'               => 'Ci voli èssiri riggistrati pi putiri canciari la pàggina.',
 'whitelistedittext'                => "Hai a $1 pi canciari l'artìculi.",
-'whitelistreadtitle'               => 'Ci voli èssiri riggistrati pi putiri lèggiri la pàggina',
-'whitelistreadtext'                => "È nicissariu effittuari lu [[Special:Userlogin|login]] pi lèggiri l'artìculi.",
-'whitelistacctitle'                => 'Nun hai lu pirmissu di criari un account',
-'whitelistacctext'                 => 'Pi putiri criari cunta n sta Wiki hai a fari [[Special:Userlogin|login]] e aviri li nicissari pirmissi.',
 'confirmedittitle'                 => 'Cunferma dâ e-mail nicissaria pi lu canciamentu dî pàggini',
 'confirmedittext'                  => "P'èssiri abbilitati a lu canciamentu dî pàggini è nicissariu cunfirmari lu propiu ndirizzu e-mail. Pi mpustari e cunfirmari lu ndirizzu sirvìrisi dî [[Special:Preferences|prifirenzi]].",
 'nosuchsectiontitle'               => 'Sta sezzioni nun esisti',
@@ -629,7 +623,7 @@
 'newarticletext'                   => "Sta pàggina ancora nun esisti. 
 Pi criari na pàggina cu stu tìtulu, accumenza a scrìviri ccassutta (talìa la [[{{MediaWiki:Helppage}}|pàggina d'aiutu]] pi aviri maiuri nfurmazzioni).
 Si agghicasti ccà pi sbagghiu, clicca lu buttuni ''''n arreri (back)''' dû tò browser.",
-'anontalkpagetext'                 => "----''Chista è la pàggina di discussioni di n’utenti anònimu, ca nun hà ancora criatu n’accessu o comu è gghiè nun l’usa. P’idintificàrilu è quinni nicissariu usari lu nùmmiru di lu sò nnirizzu IP. Li nnirizzi IP ponnu pirò èssiri cunnivisi di cchiù utenti. Siddu sî n’utenti anònimu e riteni ca li cummenti prisenti nta sta pàggina nun si rifirìscinu a tia, [[Special:Userlogin|crea n’accessu novu o trasi]] cu chiddu ca già hai p’evitari d’èssiri cunfusu cu àutri utenti anònimi ‘n futuru''",
+'anontalkpagetext'                 => "----''Chista è la pàggina di discussioni di n’utenti anònimu, ca nun hà ancora criatu n’accessu o comu è gghiè nun l’usa. P’idintificàrilu è quinni nicissariu usari lu nùmmiru di lu sò nnirizzu IP. Li nnirizzi IP ponnu pirò èssiri cunnivisi di cchiù utenti. Siddu sî n’utenti anònimu e riteni ca li cummenti prisenti nta sta pàggina nun si rifirìscinu a tia, [[Special:UserLogin|crea n’accessu novu o trasi]] cu chiddu ca già hai p’evitari d’èssiri cunfusu cu àutri utenti anònimi ‘n futuru''",
 'noarticletext'                    => "Nta stu mumentu la pàggina richiesta è vacanti. È pussìbbili [[Special:Search/{{PAGENAME}}|circari stu tìtulu]] nta l'àutri pàggini dû situ oppuru [{{fullurl:{{FULLPAGENAME}}|action=edit}} canciari la pàggina ora].",
 'userpage-userdoesnotexist'        => 'L\'account "$1" nun currispunni a n\'utenti riggistratu. Virificari si si voli criari o canciari sta pàggina.',
 'clearyourcache'                   => "'''Nota:''' doppu aviri sarvatu è nicissariu puliri la cache dû propiu browser pi vìdiri li canciamenti. Pi '''Mozilla / Firefox / Safari''': fari clic supra ''Ricarica'' tinnennu primutu lu tastu dî maiùsculi, oppuru prèmiri ''Ctrl-Maiusc-R'' (''Cmd-Maiusc-R'' supra Mac); pi '''Internet Explorer:''' mantèniri primutu lu tastu ''Ctrl'' mentri si premi lu pulsanti ''Aggiorna'' o prèmiri ''Ctrl-F5''; pi '''Konqueror''': prèmiri lu pulsanti ''Ricarica'' o lu tastu ''F5''; pi '''Opera''' pò èssiri nicissariu svacantari cumpletamenti la cache dû menu ''Strumenti → Preferenze''.",
@@ -673,7 +667,7 @@
 'hiddencategories'                 => 'Sta pàggina apparteni a {{PLURAL:$1|na catigurìa ammuciata|$1 catigurìi ammuciati}}:',
 'edittools'                        => '<!-- Chistu testu cumpari sutta li moduli di canciu e carricamentu. -->',
 'nocreatetitle'                    => 'Criazzioni dî pàggini limitata',
-'nocreatetext'                     => "La pussibbilitati di criari pàggini novi nta {{SITENAME}} è limitata a l'utenti riggistrati. Poi turnari 'n arreri e canciari na pàggina esistenti, oppuru [[Special:Userlogin|tràsiri o criari nu cuntu novu]].",
+'nocreatetext'                     => "La pussibbilitati di criari pàggini novi nta {{SITENAME}} è limitata a l'utenti riggistrati. Poi turnari 'n arreri e canciari na pàggina esistenti, oppuru [[Special:UserLogin|tràsiri o criari nu cuntu novu]].",
 'nocreate-loggedin'                => 'Nun hai lu pirmissu pi criari pàggini novi nta {{SITENAME}}.',
 'permissionserrors'                => 'Erruri di pirmissu',
 'permissionserrorstext'            => 'Nun hai lu pirmissu pi fari chistu, pi {{PLURAL:$1|chistu motivu|sti mutivi}}:',
@@ -775,7 +769,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Log dê supprissioni',
-'suppressionlogtext' => "Ccà veni prisintatu n'elencu dê cancillazioni e dê blocchi cchiù ricenti supra cuntinuti ammucciati d'amministraturi. Vidi l'[[Special:Ipblocklist|elenco d'IP bloccati]] pi l'elencu dî ban e dî blocchi attivi.",
+'suppressionlogtext' => "Ccà veni prisintatu n'elencu dê cancillazioni e dê blocchi cchiù ricenti supra cuntinuti ammucciati d'amministraturi. Vidi l'[[Special:IPBlockList|elenco d'IP bloccati]] pi l'elencu dî ban e dî blocchi attivi.",
 
 # History merging
 'mergehistory'                     => 'Unioni storie',
@@ -855,7 +849,7 @@
 'mypreferences'            => 'Li mè prifirenzi',
 'prefs-edits'              => 'Nùmmuru di canciamenti:',
 'prefsnologin'             => 'Accessu nun effittuatu',
-'prefsnologintext'         => "Pi putiri pirsunalizzari li prifirenzi è nicissariu effittuari l'[[Special:Userlogin|accessu]].",
+'prefsnologintext'         => "Pi putiri pirsunalizzari li prifirenzi è nicissariu effittuari l'[[Special:UserLogin|accessu]].",
 'prefsreset'               => 'Li prifirenzi hannu statu ripristinati a li valura pridifiniti.',
 'qbsettings'               => 'Pusizzioni QuickBar',
 'qbsettings-none'          => 'Nuddu',
@@ -927,7 +921,7 @@
 'userrights-reason'           => 'Mutivu dû canciu:',
 'userrights-no-interwiki'     => "Nun si disponi di li pirmessi nicissari pi canciari li diritti di l'utenti ni autri siti.",
 'userrights-nodatabase'       => 'Lu database $1 nu esisti o nun è lu database locali.',
-'userrights-nologin'          => "Pi assignari li diritti di l'utenti è nicissariu [[Special:Userlogin|trasiri]] comu amministraturi.",
+'userrights-nologin'          => "Pi assignari li diritti di l'utenti è nicissariu [[Special:UserLogin|trasiri]] comu amministraturi.",
 'userrights-notallowed'       => "L'utenti nun disponi dê pirmessi nicissari pi assignari diritti all'utenti.",
 'userrights-changeable-col'   => 'Gruppi canciabili',
 'userrights-unchangeable-col' => 'Gruppi nun canciabili',
@@ -1023,10 +1017,10 @@
 'reupload'                    => 'Càrrica di novu',
 'reuploaddesc'                => 'Torna a lu mòdulu pi lu carricamentu.',
 'uploadnologin'               => 'Accessu nun effittuatu',
-'uploadnologintext'           => 'Hai a esèquiri [[Special:Userlogin|lu login]] pi carricari mmàggini o àutri files multimidiali.',
+'uploadnologintext'           => 'Hai a esèquiri [[Special:UserLogin|lu login]] pi carricari mmàggini o àutri files multimidiali.',
 'upload_directory_read_only'  => 'Lu server web nun è n gradu di scrìviri ntâ directory di upload ($1).',
 'uploaderror'                 => 'Erruri ntô carricamentu',
-'uploadtext'                  => "Usa lu mòdulu ccà sutta pi carricari file novi. Pi vìdiri o circari li file già carricati, talìa lu [[Special:Imagelist|log dî file carricati]]. Carricamenti e cancillazzioni di file sunnu 
+'uploadtext'                  => "Usa lu mòdulu ccà sutta pi carricari file novi. Pi vìdiri o circari li file già carricati, talìa lu [[Special:ImageList|log dî file carricati]]. Carricamenti e cancillazzioni di file sunnu 
 riggistrati ntô [[Special:Log/upload|log di li upload]].
 
 Pi nziriri nu file nta na pagina, fai nu lijami accussì:
@@ -1119,7 +1113,7 @@
 'upload_source_url'  => '(na URL curretta e accissìbbili)',
 'upload_source_file' => '(un file supra lu propiu computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Ricerca dâ mmàggini di nomu:',
 'imgfile'               => 'file',
 'imagelist'             => 'Alencu dî file',
@@ -1156,18 +1150,18 @@
 # File reversion
 'filerevert'                => 'Riprìstina $1',
 'filerevert-legend'         => 'Riprìstina file',
-'filerevert-intro'          => '<span class="plainlinks">Stai pi ripristinari lu file \'\'\'[[Media:$1|$1]]\'\'\' â [virsioni $4 dô $2, $3].</span>',
+'filerevert-intro'          => "Stai pi ripristinari lu file '''[[Media:$1|$1]]''' â [virsioni $4 dô $2, $3].",
 'filerevert-comment'        => 'Oggettu:',
 'filerevert-defaultcomment' => 'Ripristinata la virsioni dô $1, $2',
 'filerevert-submit'         => 'Riprìstina',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'Lu file [[Media:$1|$1]]\'\'\' hà statu ripristinatu â [$4 virsioni dô $2, $3].</span>',
+'filerevert-success'        => "'''Lu file [[Media:$1|$1]]''' hà statu ripristinatu â [$4 virsioni dô $2, $3].",
 'filerevert-badversion'     => 'Nun esistanu virsiona locali pricidenti dô file cû timestamp richiestu.',
 
 # File deletion
 'filedelete'                  => 'Cancella $1',
 'filedelete-legend'           => 'Cancella lu file',
 'filedelete-intro'            => "Stai pi cancillari '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Stai cancillannu la virsioni di \'\'\'[[Media:$1|$1]]\'\'\' dô [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Stai cancillannu la virsioni di '''[[Media:$1|$1]]''' dô [$4 $3, $2].",
 'filedelete-comment'          => 'Mutivu:',
 'filedelete-submit'           => 'Cancella',
 'filedelete-success'          => "Lu file '''$1''' hà statu cancillatu.",
@@ -1219,7 +1213,7 @@
 Dâ nstallazzioni dô situ nzinu a stu mumentu {{PLURAL:\$3|hà stata visitata '''1''' pàggina|hannu statu visitati '''\$3''' pàggini}} e {{PLURAL:\$4|fattu '''1''' canciamentu|fatti '''\$4''' canciamenti}}, pari a na media di '''\$5''' canciamenti pi pàggina e '''\$6''' richiesti di littura p'ogni canciamentu.
 
 La cuda dî prucessi a esèquiri 'n background cunteni {{PLURAL:\$7|'''1''' elementu|'''\$7''' elementi}}.",
-'userstatstext'          => "C{{PLURAL:$1|'è '''1''' [[Special:Listusers|utilizzaturi]] riggistratu|i sunnu '''$1''' [[Special:Listusers|utilizzatura]] riggistrati}}; di chisti '''$2''' (o lu '''$4%''') {{PLURAL:$2|havi|hannu}} li diritti di lu gruppu $5.",
+'userstatstext'          => "C{{PLURAL:$1|'è '''1''' [[Special:ListUsers|utilizzaturi]] riggistratu|i sunnu '''$1''' [[Special:ListUsers|utilizzatura]] riggistrati}}; di chisti '''$2''' (o lu '''$4%''') {{PLURAL:$2|havi|hannu}} li diritti di lu gruppu $5.",
 'statistics-mostpopular' => 'Pàggini cchiù visitati',
 
 'disambiguations'      => 'Pàggini cu liami ambìgui',
@@ -1304,7 +1298,7 @@
 'logempty'             => 'Lu log nun cunteni elementi currispunnenti â ricerca.',
 'log-title-wildcard'   => 'Attrova tituli chi ncignanu cu',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tutti li paggini',
 'alphaindexline'    => 'di $1 a $2',
 'nextpage'          => 'Pàggina doppu ($1)',
@@ -1326,12 +1320,12 @@
 'special-categories-sort-count' => 'ordina pi nùmmuru',
 'special-categories-sort-abc'   => 'ordina alfabbeticamenti',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "Ammustra l'utenti a pàrtiri di:",
 'listusers-submit'   => 'Ammustra',
 'listusers-noresult' => "Nuddu utenti attruvatu. Virificari l'usu di caràttiri maiùsculi/minùsculi.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Diritti dô gruppu utenti',
 'listgrouprights-summary'  => "Ccà sutta sunnu elincati li gruppi utenti difiniti pi sta wiki, cu li dritti d'accessu assuciati a iddi. Pi sapìrinni chiossai supra li dritti, lèggiti [[{{MediaWiki:Listgrouprights-helppage}}]].",
 'listgrouprights-group'    => 'Gruppu',
@@ -1340,7 +1334,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nuddu ndirizzu cui mannari lu missaggiu',
-'mailnologintext' => 'Hai a fari lu [[Special:Userlogin|login]] e aver riggistratu na casella e-mail vàlida ntê tò [[Special:Preferences|prifirenzi]] pi mannari posta alittrònica a àutri Utenti.',
+'mailnologintext' => 'Hai a fari lu [[Special:UserLogin|login]] e aver riggistratu na casella e-mail vàlida ntê tò [[Special:Preferences|prifirenzi]] pi mannari posta alittrònica a àutri Utenti.',
 'emailuser'       => "Manna n'imail a stu utenti",
 'emailpage'       => "Manna un missaggiu e-mail a l'utenti",
 'emailpagetext'   => "Si st'utenti lassau nu nnirizzu email vàlidu ntê sò prifirenzi, ci putiti mannari nu missaggiu. Lu nnirizzu email chi lassasti ntê tò prifirenzi và a cumpàriri comu mittenti di lu email, di manera chi lu distinatariu ti pò arrispùnniri.",
@@ -1365,9 +1359,9 @@
 'nowatchlist'          => "Nun hai innicatu pàggini a tèniri d'occhiu.",
 'watchlistanontext'    => "Pi visualizzari e canciari l'alencu di l'ossirvati spiciali è nicissariu $1.",
 'watchnologin'         => 'Nun hai effittuatu lu login',
-'watchnologintext'     => 'Hai a fari prima lu [[Special:Userlogin|login]] pi canciari la tò lista di ossirvati spiciali.',
+'watchnologintext'     => 'Hai a fari prima lu [[Special:UserLogin|login]] pi canciari la tò lista di ossirvati spiciali.',
 'addedwatch'           => "Pàggina agghiunciuta â lista di l'ossirvati spiciali",
-'addedwatchtext'       => "La pàggina \"[[:\$1]]\" è stata agghiunciuta â propia [[Special:Watchlist|lista di l'ossirvati spiciali]]. D'ora n poi, li mudìfichi appurtati â pàggina e â sò discussioni vèninu alincati n chidda sedi; lu tìtulu dâ pàggina appari n '''grassettu''' ntâ pàggina di l' [[Special:Recentchanges|ùrtimi canciamenti]] pi rinnìrilu cchiù visìbbili. Siddu n un secunnu tempu s'addisìa eliminari la pàggina dâ lista di l'ossirvati spiciali, fari clic supra \"nun sèquiri\" ntâ barra n àutu.",
+'addedwatchtext'       => "La pàggina \"[[:\$1]]\" è stata agghiunciuta â propia [[Special:Watchlist|lista di l'ossirvati spiciali]]. D'ora n poi, li mudìfichi appurtati â pàggina e â sò discussioni vèninu alincati n chidda sedi; lu tìtulu dâ pàggina appari n '''grassettu''' ntâ pàggina di l' [[Special:RecentChanges|ùrtimi canciamenti]] pi rinnìrilu cchiù visìbbili. Siddu n un secunnu tempu s'addisìa eliminari la pàggina dâ lista di l'ossirvati spiciali, fari clic supra \"nun sèquiri\" ntâ barra n àutu.",
 'removedwatch'         => 'Livata dâ lista dî pàggini di cuntrullari',
 'removedwatchtext'     => 'La pàggina "[[:$1]]" hà statu eliminata dâ lista di l\'ossirvati spiciali.',
 'watch'                => 'talìa',
@@ -1474,7 +1468,7 @@
 lu sistema nun hà esiquitu lu cumannu mpartitu pi pricauzzioni.
 Pi favuri utilizza lu tastu "\'n arreri" dû tò browser, ricàrrica la pàggina e riprova di novu.',
 'protectlogpage'              => 'Pàggini prutetti',
-'protectlogtext'              => 'Lista di prutezzioni/sprutezzioni dî pàggini. Vidi macari la [[Special:Protectedpages|lista dî pàggini prutetti]].',
+'protectlogtext'              => 'Lista di prutezzioni/sprutezzioni dî pàggini. Vidi macari la [[Special:ProtectedPages|lista dî pàggini prutetti]].',
 'protectedarticle'            => 'hà prutettu [[$1]]',
 'modifiedarticleprotection'   => 'canciàu lu liveddu di prutizzioni di "[[$1]]"',
 'unprotectedarticle'          => 'hà sprutettu [[$1]]',
@@ -1623,7 +1617,7 @@
 'badipaddress'                => 'Ndirizzu IP nun vàlidu.',
 'blockipsuccesssub'           => 'Bloccu esiquitu',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] fu bluccatu.<br />
-Pi maggiuri nfurmazzioni, talìa la [[Special:Ipblocklist|lista di l'IP bluccati]] .",
+Pi maggiuri nfurmazzioni, talìa la [[Special:IPBlockList|lista di l'IP bluccati]] .",
 'ipb-edit-dropdown'           => 'Mutivi pô bloccu',
 'ipb-unblock'                 => "Sblocca n'utenti o nu ndirizzu IP",
 'ipb-blocklist-addr'          => 'Alenca li blocchi attivi pi $1',
@@ -1651,7 +1645,7 @@
 'autoblocker'                 => 'Bluccatu automaticamenti pirchì lu ndirizzu IP è cundivisu cu l\'utenti "[[User:$1|$1]]". Lu bloccu di l\'utenti $1 fu mpostu pi lu siquenti mutivu: "\'\'\'$2\'\'\'".',
 'blocklogpage'                => 'Blocchi',
 'blocklogentry'               => 'hà bluccatu [[$1]]; scadenza $2 $3',
-'blocklogtext'                => "Chistu è l'alencu di l'azzioni di bloccu e sbloccu utenti. Li ndirizzi IP bluccati automaticamenti nun sunu alincati. Cunzurtari l'[[Special:Ipblocklist|alencu IP bluccati]] pi l'alencu dî ndirizzi e noma utenti lu cui bloccu è opirativu.",
+'blocklogtext'                => "Chistu è l'alencu di l'azzioni di bloccu e sbloccu utenti. Li ndirizzi IP bluccati automaticamenti nun sunu alincati. Cunzurtari l'[[Special:IPBlockList|alencu IP bluccati]] pi l'alencu dî ndirizzi e noma utenti lu cui bloccu è opirativu.",
 'unblocklogentry'             => 'hà sbluccatu "$1"',
 'block-log-flags-anononly'    => 'sulu utenti anònimi',
 'block-log-flags-nocreate'    => 'criazzioni account bluccata',
@@ -1681,7 +1675,7 @@
 'lockdbsuccesssub'    => 'Bloccu dû database esiquitu',
 'unlockdbsuccesssub'  => 'Sbloccu dû database esiquitu',
 'lockdbsuccesstext'   => "Lu database hà statu bluccatu. 
-<br />Arricorda di [[Special:Unlockdb|rimòviri lu bloccu]] doppu aviri accabbatu l'upirazzioni di manutinzioni.",
+<br />Arricorda di [[Special:UnlockDB|rimòviri lu bloccu]] doppu aviri accabbatu l'upirazzioni di manutinzioni.",
 'unlockdbsuccesstext' => 'Lu database hà statu sbluccatu.',
 'lockfilenotwritable' => "Mpussìbbili scrìviri supra lu file di ''lock'' dû database. L'accessu n scrittura a tali file di parti dû server web è nicissariu pi bluccari e sbluccari lu database.",
 'databasenotlocked'   => 'Lu database nun è bluccatu.',
@@ -1706,8 +1700,6 @@
 
 Nta sti casi, tu hai a spustari o agghiùnciri manuarmenti la pàggina di discussioni.",
 'movearticle'             => 'Sposta la pàggina',
-'movenologin'             => 'Accessu nun effittuatu',
-'movenologintext'         => "Lu spustamentu dî pàggini è cunzintitu sulu a l'utenti riggistrati c'hannu esiquitu l'[[Special:Userlogin|accessu]] a lu situ.",
 'movenotallowed'          => 'Nun hai li pirmessi nicissari a lu spustamentu dê pàggini supra {{SITENAME}}.',
 'newtitle'                => 'Cu lu tìtulu novu di',
 'move-watch'              => 'Talìa sta pàggina',
@@ -1725,7 +1717,7 @@
 'revertmove'              => 'riprìstina',
 'delete_and_move_text'    => '==Richiesta di cancillazzioni==
 
-La pàggina di distinazzioni "[[$1]]" asisti già. S\'addisìa cancillàrila pi rènniri pussìbbili lu spustamentu?',
+La pàggina di distinazzioni "[[:$1]]" asisti già. S\'addisìa cancillàrila pi rènniri pussìbbili lu spustamentu?',
 'delete_and_move_confirm' => 'Sì, suvrascrivi la pàggina asistenti',
 'delete_and_move_reason'  => 'Cancillata pi rènniri pussìbbili lu spustamentu',
 'selfmove'                => 'Lu tìtulu di distinazzioni nziritu è agguali a chiddu di pruvinenza; mpossibbili spustari la pàggina su idda stissa.',
@@ -1944,7 +1936,7 @@
 'show-big-image'       => 'Virsioni a àuta risuluzzioni',
 'show-big-image-thumb' => "<small>Diminzioni di st'antiprima: $1 × $2 pixel</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Gallarìa dî file novi',
 'imagelisttext'         => "Di sèquitu veni prisintata na lista di '''$1''' file urdinat{{PLURAL:$1|u|i}} pi $2.",
 'showhidebots'          => '($1 li bot)',
@@ -2220,7 +2212,7 @@
 
 # External editor support
 'edit-externally'      => 'Cancia stu file usannu un prugramma sternu',
-'edit-externally-help' => "Pi maiuri nfurmazzioni cunzurtari li [http://meta.wikimedia.org/wiki/Help:External_editors istruzzioni] ('n ngrisi)",
+'edit-externally-help' => "Pi maiuri nfurmazzioni cunzurtari li [http://www.mediawiki.org/wiki/Manual:External_editors istruzzioni] ('n ngrisi)",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tutti',
@@ -2271,7 +2263,7 @@
 'confirmrecreate'     => "L'utenti [[User:$1|$1]] ([[User talk:$1|discussioni]]) hà cancillatu sta pàggina doppu ca hai nizziatu a canciàrila, pi lu siquenti mutivu: ''$2'' Pi favuri, cunferma ca addisìi veramenti criari n'àutra vota sta pàggina.",
 
 # HTML dump
-'redirectingto' => 'Rinnirizzamentu a [[$1]]...',
+'redirectingto' => 'Rinnirizzamentu a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "S'addisìa puliri la cache di sta pàggina? $1",
@@ -2346,7 +2338,7 @@
 'version-software-product' => 'Prodottu',
 'version-software-version' => 'Virsioni',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Pircorsu di nu file',
 'filepath-page'   => 'Nnomu dô file:',
 'filepath-submit' => 'Pircorsu',
Index: languages/messages/MessagesNew.php
===================================================================
--- languages/messages/MessagesNew.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNew.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,6 @@
  * @file
  *
  * @author Eukesh
- * @author SPQRobin
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $namespaceNames = array(
@@ -183,7 +180,7 @@
 # Miscellaneous special pages
 'newpages-username' => 'छ्येलेमि नां:',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'    => 'सकल पौत',
 'nextpage'    => 'मेगु पौ ($1)',
 'allarticles' => 'सकल च्वसुत',
Index: languages/messages/MessagesXmf.php
===================================================================
--- languages/messages/MessagesXmf.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesXmf.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Dato deutschland
  * @author Alsandro
+ * @author Dato deutschland
  * @author Malafaya
- * @author Siebrand
- * @author M.M.S.
  */
 
 $fallback = 'ka';
@@ -355,7 +353,7 @@
 'uploadlogpage' => 'გიმოხარგუაშ რეგისტრაცია',
 'uploadedimage' => 'გეთებაა "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => 'სურათეფიშ ერკებულ',
 'imagelist_name' => 'სახელ',
 
@@ -412,7 +410,7 @@
 'log'                  => 'ჟურნალეფ',
 'all-logs-page'        => 'ირ ჟურნალ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ირ ხასილა',
 'alphaindexline' => '$1-იშე $2-შა',
 'nextpage'       => 'უკულ ხასილა ($1)',
@@ -589,7 +587,7 @@
 'show-big-image'       => 'რსული გარჩევადობა',
 'show-big-image-thumb' => '<small>ზომა ოწმახ ძირაშ დროს: $1 × $2 პიქსელ</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'ახალ სურათეფ',
 
 # Bad image list
@@ -607,7 +605,7 @@
 
 # External editor support
 'edit-externally'      => 'თე ფაილიშ რედაქტირაფა ბორჯის გიმირინეთ გალენ პროგრამა.',
-'edit-externally-help' => 'რსულ ინფორმაციაშენ ქოძირეთ [http://meta.wikimedia.org/wiki/Help:External_editors ჩადგმიშ ინსტრუქციეფ].',
+'edit-externally-help' => 'რსულ ინფორმაციაშენ ქოძირეთ [http://www.mediawiki.org/wiki/Manual:External_editors ჩადგმიშ ინსტრუქციეფ].',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'არძა',
Index: languages/messages/MessagesZh_tw.php
===================================================================
--- languages/messages/MessagesZh_tw.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh_tw.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
+ * @author BobChao
  * @author Roc michael
  * @author לערי ריינהארט
- * @author BobChao
  */
 
 $fallback = 'zh-hant';
@@ -148,12 +147,10 @@
 'dec'           => '12月',
 
 # Categories related messages
-'pagecategories'                => '個分類',
 'category_header'               => '類別「$1」中的頁面',
 'subcategories'                 => '子分類',
 'category-media-header'         => '"$1"分類中的媒體',
 'category-empty'                => "''這個分類中尚未包含任何頁面或媒體。''",
-'hidden-categories'             => '個隱藏分類',
 'hidden-category-category'      => '隱藏分類', # Name of the category where hidden categories will be listed
 'category-subcat-count'         => '{{PLURAL:$2|這個分類中只有以下的附分類。|這個分類中有以下的$1個附分類，共有$2個附分類。}}',
 'category-subcat-count-limited' => '這個分類下有$1個子分類。',
@@ -316,7 +313,7 @@
 'nosuchspecialpage' => '此特殊頁面不存在',
 'nospecialpagetext' => "<big>'''您請求的特殊頁面無效。'''</big>
 
-[[Special:Specialpages]]載有所有有效特殊頁面的列表。",
+[[Special:SpecialPages]]載有所有有效特殊頁面的列表。",
 
 # General errors
 'error'                => '錯誤',
@@ -532,10 +529,6 @@
 'blockededitsource'         => "你對'''$1'''進行'''編輯'''的文字如下:",
 'whitelistedittitle'        => '登入後才可編輯',
 'whitelistedittext'         => '您必須先$1才可編輯頁面。',
-'whitelistreadtitle'        => '登入後才可閱讀',
-'whitelistreadtext'         => '您必須先[[Special:Userlogin|登入]]才可閱讀頁面。',
-'whitelistacctitle'         => '您被禁止建立帳號',
-'whitelistacctext'          => '在本Wiki中建立帳號您必須先[[Special:Userlogin|登入]]並擁有相關許可權。',
 'confirmedittitle'          => '郵件確認後才可編輯',
 'confirmedittext'           => '在編輯此頁之前您必須確認您的電子郵件地址。請透過[[Special:Preferences|參數設定]]設定並驗証您的電子郵件地址。',
 'nosuchsectiontitle'        => '沒有這個段落',
@@ -549,7 +542,7 @@
 'newarticletext'            => '您進入了一個尚未建立的頁面。
 要建立該頁面，請在下面的編輯框中輸入內容(詳情參見[[Help:說明|說明]])。
 如果您是不小心來到此頁面，直接點擊您瀏覽器中的"返回"按鈕返回。',
-'anontalkpagetext'          => "---- ''這是一個還未建立帳號的匿名使用者的對話頁。我們因此只能用IP地址來與他／她聯絡。該IP地址可能由幾名使用者共享。如果您是一名匿名使用者並認為本頁上的評語與您無關，請[[Special:Userlogin|建立新帳號或登入]]以避免在未來於其他匿名使用者混淆。''",
+'anontalkpagetext'          => "---- ''這是一個還未建立帳號的匿名使用者的對話頁。我們因此只能用IP地址來與他／她聯絡。該IP地址可能由幾名使用者共享。如果您是一名匿名使用者並認為本頁上的評語與您無關，請[[Special:UserLogin|建立新帳號或登入]]以避免在未來於其他匿名使用者混淆。''",
 'noarticletext'             => '此頁目前沒有內容，您可以在其它頁[[Special:Search/{{PAGENAME}}|搜尋此頁標題]]或[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} 編輯此頁]。',
 'userpage-userdoesnotexist' => '使用者帳號「$1」未曾建立。請在建立／編輯這個頁面前先檢查一下。',
 'clearyourcache'            => "'''注意:''' 在儲存以後, 您必須清除瀏覽器的快取才能看到所作出的改變。 '''Mozilla / Firefox / Safari:''' 按著 ''Shift'' 再點擊''重新整理''(或按下''Ctrl-Shift-R''，在蘋果Mac上按下''Cmd-Shift-R'')；'''IE:''' 按著 ''Ctrl'' 再點擊 ''重新整理''，或按下 ''Ctrl-F5''；'''Konqueror:''' 只需點擊 ''重新整理''；'''Opera:''' 使用者需要在 ''工具-設定'' 中完整地清除它們的快取。",
@@ -602,7 +595,7 @@
 'template-semiprotected'    => '(半保護)',
 'edittools'                 => '<!-- 此處的文字將被顯示在以下編輯和上傳表單中。 -->',
 'nocreatetitle'             => '建立頁面受限',
-'nocreatetext'              => '此網站限制了建立新頁面的功能。你可以返回並編輯已有的頁面，或者[[Special:Userlogin|登錄或建立新賬戶]]。',
+'nocreatetext'              => '此網站限制了建立新頁面的功能。你可以返回並編輯已有的頁面，或者[[Special:UserLogin|登錄或建立新賬戶]]。',
 'nocreate-loggedin'         => '您在這個wiki中並無許可權去建立新頁面。',
 'permissionserrors'         => '權限錯誤',
 'permissionserrorstext'     => '根據以下的{{PLURAL:$1|原因|原因}}，您並無權限去做以下的動作:',
@@ -744,7 +737,7 @@
 'mypreferences'            => '我的偏好設定',
 'prefs-edits'              => '編輯數量:',
 'prefsnologin'             => '還未登入',
-'prefsnologintext'         => '您必須先[[Special:Userlogin|登入]]才能設置個人參數。',
+'prefsnologintext'         => '您必須先[[Special:UserLogin|登入]]才能設置個人參數。',
 'prefsreset'               => '參數已重新設置。',
 'qbsettings'               => '快速導航條',
 'qbsettings-none'          => '無',
@@ -874,13 +867,13 @@
 'reupload'                    => '重新上載',
 'reuploaddesc'                => '返回上載表單。',
 'uploadnologin'               => '未登入',
-'uploadnologintext'           => '您必須先[[Special:Userlogin|登入]]
+'uploadnologintext'           => '您必須先[[Special:UserLogin|登入]]
 才能上載檔案。',
 'upload_directory_read_only'  => '上傳目錄($1)不存在或無寫權限。',
 'uploaderror'                 => '上載錯誤',
 'uploadtext'                  => "使用下面的表單來上傳用在頁面內新的圖片檔案。
 要檢視或搜尋以前上傳的圖片
-可以進入[[Special:Imagelist|圖片清單]]，
+可以進入[[Special:ImageList|圖片清單]]，
 上傳和刪除將在[[Special:Log/upload|上傳日誌]]中記錄。
 
 要在頁面中加入圖片，使用以下形式的連接:
@@ -957,7 +950,7 @@
 'upload_source_url'  => ' (一個有效的，可公開訪問的 URL)',
 'upload_source_file' => ' (在您電腦上的一個檔案)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => '按圖片名稱搜尋:',
 'imgfile'               => '檔案',
 'imagelist'             => '檔案列表',
@@ -1051,7 +1044,7 @@
 即每頁平均編輯'''\$5'''次，各次編輯後頁面的每個版本平均瀏覽'''\$6'''次。
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue 工作隊列]的長度是'''\$7'''。",
-'userstatstext'          => "網站有'''$1'''位註冊[[Special:Listusers|使用者]]，其中
+'userstatstext'          => "網站有'''$1'''位註冊[[Special:ListUsers|使用者]]，其中
 '''$2''' (或 '''$4%''') 有$5許可權。",
 'statistics-mostpopular' => '被查閱次數最多的頁面',
 
@@ -1141,7 +1134,7 @@
 'logempty'             => '在日誌中不存在匹配項。',
 'log-title-wildcard'   => '搜尋以這個文字開始的標題',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '所有頁面',
 'alphaindexline'    => '$1 到 $2',
 'nextpage'          => '下一頁($1)',
@@ -1163,14 +1156,14 @@
 'special-categories-sort-count' => '按數量排列',
 'special-categories-sort-abc'   => '按字母排列',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '給定顯示使用者條件:',
 'listusers-submit'   => '顯示',
 'listusers-noresult' => '找不到使用者。',
 
 # E-mail user
 'mailnologin'     => '無E-mail地址',
-'mailnologintext' => '您必須先[[Special:Userlogin|登入]]
+'mailnologintext' => '您必須先[[Special:UserLogin|登入]]
 並在[[Special:Preferences|偏好設定]]
 中有一個有效的e-mail地址才可以E-mail其他使用者。',
 'emailuser'       => 'E-mail該使用者',
@@ -1198,12 +1191,12 @@
 'nowatchlist'          => '您的監視列表為空。',
 'watchlistanontext'    => '請$1以檢視或編輯您的監視列表。',
 'watchnologin'         => '未登入',
-'watchnologintext'     => '您必須先[[Special:Userlogin|登入]]
+'watchnologintext'     => '您必須先[[Special:UserLogin|登入]]
 才能更改您的監視列表',
 'addedwatch'           => '加入到監視列表',
 'addedwatchtext'       => "頁面\"[[:\$1]]\"已經被加入到您的[[Special:Watchlist|監視清單]]中。
 將來有關此頁面及其討論頁的任何修改將會在那裡列出，
-而且還會在[[Special:Recentchanges|近期變動]]中
+而且還會在[[Special:RecentChanges|近期變動]]中
 以'''粗體'''形式列出以使起更容易識別。
 
 如果您之後想將該頁面從監視清單中刪除，可點擊導航條中的\"停止監視\"連結。",
@@ -1311,7 +1304,7 @@
 'rollback-success'            => '復原由$1的編輯；更改回$2的最後一個版本。',
 'sessionfailure'              => '您的登入資訊似乎有問題，為防止此該訊息被攔截，本次操作已經取消，請按「上一頁」重新載入。',
 'protectlogpage'              => '保護日誌',
-'protectlogtext'              => '下面是頁面鎖定和取消鎖定的列表。請參考[[Special:Protectedpages|保護頁面清單]]以檢視當前進行的頁面保護。',
+'protectlogtext'              => '下面是頁面鎖定和取消鎖定的列表。請參考[[Special:ProtectedPages|保護頁面清單]]以檢視當前進行的頁面保護。',
 'protectedarticle'            => '已保護"[[$1]]"',
 'modifiedarticleprotection'   => '已經更改 "[[$1]]" 的保護等級',
 'unprotectedarticle'          => '已解除保護"[[$1]]"',
@@ -1456,7 +1449,7 @@
 'badipaddress'                => 'IP地址不正確。',
 'blockipsuccesssub'           => '封鎖成功',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]已經被封鎖。
-<br />參看[[Special:Ipblocklist|被封IP地址列表]]以覆審封鎖。',
+<br />參看[[Special:IPBlockList|被封IP地址列表]]以覆審封鎖。',
 'ipb-edit-dropdown'           => '編輯封鎖原因',
 'ipb-unblock-addr'            => '解除封鎖$1',
 'ipb-unblock'                 => '解除禁封使用者名或IP地址',
@@ -1486,7 +1479,7 @@
 'autoblocker'                 => '你的IP和被封了的 "$1" 是一樣的。封鎖原因： "$2".',
 'blocklogpage'                => '封鎖記錄',
 'blocklogentry'               => '[[$1]]已被封鎖 $3 ，終止時間為$2',
-'blocklogtext'                => '這是關於使用者封鎖和解除封鎖操作的記錄。被自動封鎖的IP地址沒有被列出。請參閱[[Special:Ipblocklist|被封鎖的IP地址和使用者列表]]。',
+'blocklogtext'                => '這是關於使用者封鎖和解除封鎖操作的記錄。被自動封鎖的IP地址沒有被列出。請參閱[[Special:IPBlockList|被封鎖的IP地址和使用者列表]]。',
 'unblocklogentry'             => '[[$1]]已被解封',
 'block-log-flags-anononly'    => '僅限匿名使用者',
 'block-log-flags-nocreate'    => '禁止此IP/使用者建立新帳號',
@@ -1549,9 +1542,6 @@
 
 在這些情況下，您在必要時必須手工移動或合併頁面。",
 'movearticle'             => '移動頁面:',
-'movenologin'             => '未登入',
-'movenologintext'         => '您必須是一名登記使用者並且[[Special:Userlogin|登入]]
-後才可移動一個頁面。',
 'movenotallowed'          => '您在這個wiki中度並沒有許可權去移動頁面。',
 'newtitle'                => '新標題:',
 'move-watch'              => '監視此頁',
@@ -1572,7 +1562,7 @@
 'delete_and_move'         => '刪除並移動',
 'delete_and_move_text'    => '==需要刪除==
 
-目標頁面"[[$1]]"已經存在。你確認需要刪除原頁面並以進行移動嗎？',
+目標頁面"[[:$1]]"已經存在。你確認需要刪除原頁面並以進行移動嗎？',
 'delete_and_move_confirm' => '是的，刪除此頁面',
 'delete_and_move_reason'  => '刪除以便移動',
 'selfmove'                => '原始標題與目標標題相同，您不能移動一頁覆蓋本身。',
@@ -1796,7 +1786,7 @@
 'show-big-image'       => '完整解像度',
 'show-big-image-thumb' => '<small>這幅縮圖的解像度: $1 × $2 像素</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新建圖片畫廊',
 'imagelisttext'         => '以下是按$2排列的$1個檔案列表。',
 'showhidebots'          => '($1機器人)',
@@ -2092,7 +2082,7 @@
 
 # External editor support
 'edit-externally'      => '用外部程式編輯此檔案',
-'edit-externally-help' => '請參見[http://meta.wikimedia.org/wiki/Help:External_editors 設定步驟]了解詳細資訊。',
+'edit-externally-help' => '請參見[http://www.mediawiki.org/wiki/Manual:External_editors 設定步驟]了解詳細資訊。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全部',
@@ -2152,7 +2142,7 @@
 'recreate'            => '重建',
 
 # HTML dump
-'redirectingto' => '重定向到[[$1]]...',
+'redirectingto' => '重定向到[[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '要清除此頁面的快取嗎?\\n\\n$1',
Index: languages/messages/MessagesZh_classical.php
===================================================================
--- languages/messages/MessagesZh_classical.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh_classical.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,10 +1,9 @@
 <?php
-/** Old Chinese / Late Middle Chinese (文言)
+/** Classical Chinese (文言)
  *
  * @ingroup Language
  * @file
  *
- * @author Siebrand
  * @author Itsmine
  * @comment Based on http://zh-classical.wikipedia.org/w/index.php?title=Wikipedia:%E7%94%A8%E6%88%B6%E4%BB%8B%E9%9D%A2%E7%BF%BB%E8%AD%AF/MessagesZh_classical.php&oldid=60161
  */
@@ -342,7 +341,7 @@
 'nosuchspecialpage' => '無此特查',
 'nospecialpagetext' => "'''<big>無此特查。</big>'''
 
-見[[Special:Specialpages|{{int:specialpages}}]]。",
+見[[Special:SpecialPages|{{int:specialpages}}]]。",
 
 # General errors
 'error'                => '有誤',
@@ -409,9 +408,9 @@
 # Login and logout pages
 'logouttitle'                => '去簿',
 'logouttext'                 => '<strong>子去簿矣</strong><br />
-子可匿名還覽{{SITENAME}}，或復登同簿、異簿。未清謄本，覽器文舊，且慎之。',
+子可匿名還覽{{SITENAME}}，或[[Special:UserLogin|復登]]同簿、異簿。未清謄本，覽器文舊，且慎之。',
 'welcomecreation'            => '== $1大駕光臨! ==
-子簿增矣，敬更簿註。',
+子簿增矣，敬更[[Special:Preferences|簿註]]。',
 'loginpagetitle'             => '合符節',
 'yourname'                   => '名',
 'yourpassword'               => '符節',
@@ -518,16 +517,24 @@
 'missingsummary'                   => "''''醒示：'''子未概之，復存則文倍焉。",
 'missingcommenttext'               => '請贊之',
 'blockedtitle'                     => '子見禁',
-'blockedtext'                      => "<big>'''子名、IP見禁。'''</big>禁者$1也，因''$2''故。* 始之時為：$8* 終之時為：$6* 見禁之人：$7存惑可詢$1，或[[{{MediaWiki:Grouppage-sysop}}|有秩]]，[[Special:Preferences|簿註]]無驛則信不遣。另，子IP為$3，其禁號為#$5。詢時切附之。",
-'autoblockedtext'                  => "爾之IP或簿自禁，因簿先用，禁者$1也。因故：:\\'\\'$2\\'\\'* 始之時為：$8* 終之時為：$6存惑可詢$1，或[[{{MediaWiki:Grouppage-sysop}}|有秩]]，[[Special:Preferences|簿註]]無驛則信不遣。另，子禁號為#$5。詢時切附之。",
+'blockedtext'                      => "<big>'''子名、IP見禁。'''</big>禁者$1也，因''$2''故。
+
+* 始之時為：$8
+* 終之時為：$6
+* 見禁之人：$7
+
+存惑可詢$1，或[[{{MediaWiki:Grouppage-sysop}}|有秩]]，[[Special:Preferences|簿註]]無驛則信不遣。另，子IP為$3，其禁號為#$5。詢時切附之。",
+'autoblockedtext'                  => "爾之IP或簿自禁，因簿先用，禁者$1也。因故：:\\'\\'$2\\'\\'
+
+* 始之時為：$8
+* 終之時為：$6
+* 見禁之人：$7
+
+存惑可詢$1，或[[{{MediaWiki:Grouppage-sysop}}|有秩]]，[[Special:Preferences|簿註]]無驛則信不遣。另，子用IP $3，禁號為#$5。詢時切附之。",
 'blockedoriginalsource'            => "'''$1'''本源如下：",
 'blockededitsource'                => "子'''$1纂文'''如下：",
 'whitelistedittitle'               => '登簿以纂',
 'whitelistedittext'                => '$1後方可纂文。',
-'whitelistreadtitle'               => '登簿以閱',
-'whitelistreadtext'                => '[[Special:Userlogin|登簿]]後方可閱。',
-'whitelistacctitle'                => '拒增此簿',
-'whitelistacctext'                 => '欲增此簿，[[Special:Userlogin|登簿]]求允',
 'confirmedittitle'                 => '證驛以纂',
 'confirmedittext'                  => '驛證方可纂文。惠見[[Special:Preferences|簿註]]。',
 'loginreqtitle'                    => '須登簿',
@@ -538,7 +545,7 @@
 'newarticle'                       => '撰',
 'newarticletext'                   => '此頁尚缺。欲補，撰於下，有惑見[[{{ns:help}}:Contents|助]]。
 誤入者，返前即可。',
-'anontalkpagetext'                 => "----''此匿論也，為未簿或不簿者設，IP俱錄以辨人焉。然IP不獨，恐生亂象，不喜惠[[Special:Userlogin|登簿]]遠之。",
+'anontalkpagetext'                 => "----''此匿論也，為未簿或不簿者設，IP俱錄以辨人焉。然IP不獨，恐生亂象，不喜惠[[Special:UserLogin/signup|增]][[Special:UserLogin|登簿]]遠之。",
 'noarticletext'                    => '此頁無文。子可 [[Special:Search/{{PAGENAME}}|尋同題]]，或[{{fullurl:{{FULLPAGENAME}}|action=edit}} 撰新文]。',
 'userpage-userdoesnotexist'        => '"$1"之簿未增也。請建纂本頁前查之。',
 'clearyourcache'                   => "'''註：'''重取頁面，文方新焉。
@@ -553,11 +560,11 @@
 'updated'                          => '（新）',
 'note'                             => '<strong>註</strong>',
 'previewnote'                      => '<strong>此乃預覽，尚未儲焉。</strong>',
-'session_fail_preview'             => '<strong>歉哉有變，子纂未存焉，惠再之。如復不成，重登再試也。</strong>',
+'session_fail_preview'             => '<strong>歉哉有變，子纂未存焉，惠再之。如復不成，[[Special:UserLogout|重登]]再試也。</strong>',
 'session_fail_preview_html'        => "<strong>歉哉有變，子纂未存焉</strong>
 
 ''此維基亦合純HTML，除預覽以遠惡JavaScript侵。''
-<strong>纂文若合，惠再之。如復不成，簿重登焉。</strong>",
+<strong>纂文若合，惠再之。如復不成，簿[[Special:UserLogout|重登]]焉。</strong>",
 'token_suffix_mismatch'            => '<strong>君修見拒，蓋因代理之故，亂事見兮。</strong>',
 'editing'                          => '纂$1',
 'editingsection'                   => '纂節$1',
@@ -584,7 +591,7 @@
 'template-semiprotected'           => '(半錮)',
 'hiddencategories'                 => '此頁屬隱類之員有$1：',
 'nocreatetitle'                    => '新題謝焉',
-'nocreatetext'                     => '舊題可修，新題謝焉。[[Special:Userlogin|登簿、增簿]]以逮權也。',
+'nocreatetext'                     => '舊題可修，新題謝焉。[[Special:UserLogin|登簿、增簿]]以逮權也。',
 'nocreate-loggedin'                => '子權未逮，新頁謝焉。',
 'permissionserrors'                => '權未逮也',
 'permissionserrorstext'            => '子權未逮，有{{PLURAL:$1|因|因}}如下：',
@@ -690,7 +697,7 @@
 # Suppression log
 'suppressionlog'     => '誌廢',
 'suppressionlogtext' => '下乃刪及錮物之列也。
-[[Special:Ipblocklist|IP之錮]]有現之閱。',
+[[Special:IPBlockList|IP之錮]]有現之閱。',
 
 # History merging
 'mergehistory'                     => '併頁之誌',
@@ -731,7 +738,7 @@
 # Search results
 'searchresults'             => '得尋',
 'searchresulttext'          => '何索{{SITENAME}}，詳見[[{{MediaWiki:Helppage}}|{{int:help}}]]。',
-'searchsubtitle'            => "'''[[:$1]]'''尋焉",
+'searchsubtitle'            => "'''[[:$1]]'''尋焉（[[Special:Prefixindex/$1|『$1』之全首頁]] | [[Special:WhatLinksHere/$1|『$1』之全取佐]]）",
 'searchsubtitleinvalid'     => "'''$1'''尋焉",
 'noexactmatch'              => "'''無題曰\"\$1\"。'''子可[[:\$1|撰之]]。",
 'noexactmatch-nocreate'     => "'''無題曰\"\$1\"。'''",
@@ -774,7 +781,7 @@
 'mypreferences'         => '簿註',
 'prefs-edits'           => '數纂：',
 'prefsnologin'          => '未登簿',
-'prefsnologintext'      => '註記須[[Special:Userlogin|登簿]]。',
+'prefsnologintext'      => '註記須[[Special:UserLogin|登簿]]。',
 'prefsreset'            => '簿註歸白',
 'changepassword'        => '易符節',
 'skin'                  => '面版',
@@ -836,7 +843,7 @@
 'userrights-reason'              => '因：',
 'userrights-no-interwiki'        => '爾無權改他山wiki之簿權也。',
 'userrights-nodatabase'          => '資料庫$1無存或非本地也。',
-'userrights-nologin'             => '爾以有秩乲簿[[Special:Userlogin|登]]後以定簿之權也。',
+'userrights-nologin'             => '爾以有秩乲簿[[Special:UserLogin|登]]後以定簿之權也。',
 'userrights-notallowed'          => '爾之簿無權定簿之權也。',
 'userrights-changeable-col'      => '爾可動之社',
 'userrights-unchangeable-col'    => '爾非動之社',
@@ -962,21 +969,22 @@
 'reupload'                   => '復獻之',
 'reuploaddesc'               => '消進乃返載獻',
 'uploadnologin'              => '未登簿',
-'uploadnologintext'          => '[[Special:Userlogin|登簿]]始可進獻',
+'uploadnologintext'          => '[[Special:UserLogin|登簿]]始可進獻',
 'upload_directory_missing'   => '目錄$1已失，無建之。',
 'upload_directory_read_only' => '目錄$1禁入，無可獻。',
 'uploaderror'                => '進獻有變',
-'uploadtext'                 => "下表以獻，[[Special:Imagelist|載獻]]覽之。或見[[Special:Log/upload|誌獻]]。
-欲嵌頁中，是格鏈之：
-'''<nowiki>[[</nowiki>{{ns:image}}:File.jpg]]'''、
-'''<nowiki>[[</nowiki>{{ns:image}}:File.png|名]]'''或
-'''<nowiki>[[</nowiki>{{ns:media}}:File.ogg]]'''",
+'uploadtext'                 => "下表以獻，[[Special:ImageList|載獻]]覽之。或見[[Special:Log/upload|誌獻]]與[[Special:Log/delete|誌刪]]。
+欲嵌頁中，是格鏈之其一：
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:File.jpg]]</tt>'''用此整獻
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:File.png||200px|thumb|left|名]]</tt>'''以二百像素置左框置『名』
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}:File.ogg]]</tt>'''直連獻，無示獻",
 'upload-permitted'           => '可之物類：$1。',
 'upload-preferred'           => '議之物類：$1。',
 'upload-prohibited'          => '禁之物類：$1。',
 'uploadlog'                  => '誌獻',
 'uploadlogpage'              => '誌獻',
-'uploadlogpagetext'          => '近獻如下：',
+'uploadlogpagetext'          => '近獻如下。
+看[[Special:NewImages|新畫獻]]示獻功。',
 'filename'                   => '名',
 'filedesc'                   => '概',
 'fileuploadsummary'          => '概：',
@@ -1014,7 +1022,7 @@
 
 'license-nopreview' => '（謝草覽）',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => '此奇頁示檔之全呈也。
 設最後之檔呈示於表頂。
 點題改其列之。',
@@ -1041,7 +1049,7 @@
 'imagelinks'                     => '圖鏈',
 'linkstoimage'                   => '下頁連本檔有$1：',
 'nolinkstoimage'                 => '無頁連本檔也。',
-'morelinkstoimage'               => '閱檔[[Special:Whatlinkshere/$1|接]]。',
+'morelinkstoimage'               => '閱檔[[Special:WhatLinksHere/$1|接]]。',
 'redirectstofile'                => '下檔轉到此檔有$1：',
 'duplicatesoffile'               => '下檔重此檔有$1：',
 'sharedupload'                   => '此檔為共傳，可另項用也。',
@@ -1057,22 +1065,22 @@
 # File reversion
 'filerevert'                => '還$1',
 'filerevert-legend'         => '還檔',
-'filerevert-intro'          => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'欲還回$2$3之版$4。</span>',
+'filerevert-intro'          => "'''[[Media:$1|$1]]'''欲還回$2$3之版$4。",
 'filerevert-comment'        => '註：',
 'filerevert-defaultcomment' => '還$1$2之版矣',
 'filerevert-submit'         => '還',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'，$2$3之版$4還矣。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''，$2$3之版$4還矣。",
 'filerevert-badversion'     => '該日無版也。',
 
 # File deletion
 'filedelete'                  => '刪$1',
 'filedelete-legend'           => '刪檔',
 'filedelete-intro'            => "欲刪'''[[Media:$1|$1]]'''。",
-'filedelete-intro-old'        => '<span class="plainlinks">欲刪\'\'\'[[Media:$1|$1]]\'\'\'$2$3之版$4。</span>',
+'filedelete-intro-old'        => "欲刪'''[[Media:$1|$1]]'''$2$3之版$4。",
 'filedelete-comment'          => '刪因：',
 'filedelete-submit'           => '刪',
 'filedelete-success'          => "'''$1'''刪矣。",
-'filedelete-success-old'      => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'$2$3之版刪矣。</span>',
+'filedelete-success-old'      => "'''[[Media:$1|$1]]'''$2$3之版刪矣。",
 'filedelete-nofile'           => "{{SITENAME}}無'''$1'''也。",
 'filedelete-nofile-old'       => "無合'''$1'''藏也。",
 'filedelete-iscurrent'        => '刪版乃新，先還舊焉。',
@@ -1115,22 +1123,24 @@
 'sitestatstext'          => "庫藏有頁'''$1'''，除議、釋、芻文、渡與不濟者，有足文$2、獻品'''$8'''。
 自{{SITENAME}}始焉，閱頁'''$3'''，纂文'''$4'''。均之則每頁'''$5'''覽，每文'''$6'''纂。
 [http://www.mediawiki.org/wiki/Manual:Job_queue job queue]長'''$7'''。",
-'userstatstext'          => "有[[Special:Listusers|簿]]者'''$1'''，內'''$2'''人掌$5權，據百分之'''$4'''。",
+'userstatstext'          => "有[[Special:ListUsers|簿]]者'''$1'''，內'''$2'''人掌$5權，據百分之'''$4'''。",
 'statistics-mostpopular' => '燴炙',
 
 'disambiguations'      => '釋義',
 'disambiguations-text' => '頁下引[[MediaWiki:Disambiguationspage]]模，求釋義，宜正題之。',
 
-'doubleredirects'     => '窮渡',
-'doubleredirectstext' => '頁下窮渡，迭列以示。首尾宿合，宜正渡之。',
+'doubleredirects'            => '窮渡',
+'doubleredirectstext'        => '頁下窮渡，迭列以示。首尾宿合，宜正渡之。',
+'double-redirect-fixed-move' => '[[$1]]遷畢，現渡至[[$2]]',
+'double-redirect-fixer'      => '修渡',
 
 'brokenredirects'        => '斷渡',
-'brokenredirectstext'    => '頁下斷渡：',
+'brokenredirectstext'    => '頁下斷渡。',
 'brokenredirects-edit'   => '(替)',
 'brokenredirects-delete' => '(刪)',
 
 'withoutinterwiki'         => '孤語',
-'withoutinterwiki-summary' => '頁下無鏈他語：',
+'withoutinterwiki-summary' => '頁下無鏈他語。',
 'withoutinterwiki-legend'  => '首',
 'withoutinterwiki-submit'  => '示',
 
@@ -1198,7 +1208,7 @@
 'logempty'             => '無合誌也。',
 'log-title-wildcard'   => '題以此始者，取之',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '全典',
 'alphaindexline'    => '自$1至$2',
 'nextpage'          => '次頁（$1）',
@@ -1221,12 +1231,12 @@
 'special-categories-sort-count' => '排數',
 'special-categories-sort-abc'   => '排字',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => '始簿：',
 'listusers-submit'   => '見',
 'listusers-noresult' => '尋無簿。',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => '簿組權',
 'listgrouprights-summary'  => '下乃wiki之簿權表及存取之權也。
 欲知權節，可望[[{{MediaWiki:Listgrouprights-helppage}}|此]]矣。',
@@ -1237,10 +1247,10 @@
 
 # E-mail user
 'mailnologin'     => '無驛',
-'mailnologintext' => '[[Special:Userlogin|登簿]]置郵，方可捎書。',
+'mailnologintext' => '[[Special:UserLogin|登簿]]置郵，方可捎書。',
 'emailuser'       => '捎君',
 'emailpage'       => '捎書',
-'emailpagetext'   => '若此君有郵，表下捎焉。署子簿郵以候往返。',
+'emailpagetext'   => '若此君有郵，表下捎焉。署[[Special:Preferences|子簿郵]]以候往返。',
 'usermailererror' => '驛報有誤：',
 'defemailsubject' => '{{SITENAME}}來書',
 'noemailtitle'    => '無郵',
@@ -1263,11 +1273,11 @@
 'nowatchlist'          => '無哨',
 'watchlistanontext'    => '$1以治哨',
 'watchnologin'         => '未登簿',
-'watchnologintext'     => '[[Special:Userlogin|登簿]]以治哨。',
+'watchnologintext'     => '[[Special:UserLogin|登簿]]以治哨。',
 'addedwatch'           => '派哨',
-'addedwatchtext'       => "\"[[:\$1]]\"哨派矣。後有易、議者可見於[[Special:Watchlist|哨站]]，且'''粗體'''列於[[Special:Recentchanges|近易]]。",
+'addedwatchtext'       => "\"[[:\$1]]\"哨派矣。後有易、議者可見於[[Special:Watchlist|哨站]]，且'''粗體'''列於[[Special:RecentChanges|近易]]。",
 'removedwatch'         => '撤哨',
-'removedwatchtext'     => '"[[:$1]]"哨撤矣。',
+'removedwatchtext'     => '"[[:$1]]"[[Special:Watchlist|哨]]撤矣。',
 'watch'                => '派哨',
 'watchthispage'        => '哨此報',
 'unwatch'              => '撤哨',
@@ -1356,13 +1366,13 @@
 'rollbacklink'                => '退',
 'rollbackfailed'              => '退未成',
 'cantrollback'                => '退修不成，作者獨也。',
-'alreadyrolled'               => '[[User:$2|$2]]（[[User talk:$2|議]]）作[[:$1]]，退不成也。有易或已退焉。新纂者為[[User:$3|$3]]（[[User talk:$3|議]]）',
+'alreadyrolled'               => '[[User:$2|$2]]（[[User talk:$2|議]] | [[Special:Contributions/$2|{{int:contribslink}}]]）作[[:$1]]，退不成也。有易或已退焉。新纂者為[[User:$3|$3]]（[[User talk:$3|議]] | [[Special:Contributions/$3|{{int:contribslink}}]]）',
 'editcomment'                 => '贊曰"<i>$1</i>"', # only shown if there is an edit comment
 'revertpage'                  => '去[[Special:Contributions/$2|$2]]之作（欲言之，可至[[User talk:$2|此]]）為[[User:$1|$1]]之本耳', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '去$1之作，復為$2之本耳。',
 'sessionfailure'              => '登簿有變。為防盜簿，返前重取再為之。',
 'protectlogpage'              => '誌緘',
-'protectlogtext'              => '誌緘如下；近緘見[[Special:Protectedpages|此]] 。',
+'protectlogtext'              => '誌緘如下；近緘見[[Special:ProtectedPages|此]] 。',
 'protectedarticle'            => '緘焉"[[$1]]"',
 'modifiedarticleprotection'   => '令"$1"',
 'unprotectedarticle'          => '啟焉"[[$1]]"',
@@ -1463,7 +1473,7 @@
 
 # What links here
 'whatlinkshere'            => '取佐',
-'whatlinkshere-title'      => '$1取佐',
+'whatlinkshere-title'      => '「$1」取佐',
 'whatlinkshere-page'       => '題',
 'linklistsub'              => '（列取佐）',
 'linkshere'                => "取佐'''[[:$1]]'''如下：",
@@ -1512,7 +1522,7 @@
 'ipbwatchuser'                    => '哨該簿之齋與議',
 'badipaddress'                    => 'IP不格',
 'blockipsuccesssub'               => '禁焉',
-'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]]禁焉。表禁<br />見[[Special:Ipblocklist|此]]。',
+'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]]禁焉。表禁<br />見[[Special:IPBlockList|此]]。',
 'ipb-edit-dropdown'               => '改證',
 'ipb-unblock-addr'                => '赦$1',
 'ipb-unblock'                     => '赦簿、址',
@@ -1542,7 +1552,7 @@
 'autoblocker'                     => '近日$1"$2"；同子IP址，故禁焉。',
 'blocklogpage'                    => '誌禁',
 'blocklogentry'                   => '禁[[$1]]屆$2$3',
-'blocklogtext'                    => '此誌禁赦；自禁不示。見[[Special:Ipblocklist|此]]列今禁者。',
+'blocklogtext'                    => '此誌禁赦；自禁不示。見[[Special:IPBlockList|此]]列今禁者。',
 'unblocklogentry'                 => '$1赦焉',
 'block-log-flags-anononly'        => '惟禁匿',
 'block-log-flags-nocreate'        => '禁增簿',
@@ -1572,7 +1582,7 @@
 'locknoconfirm'       => '未篤焉。',
 'lockdbsuccesssub'    => '庫已閉',
 'unlockdbsuccesssub'  => '庫已開',
-'lockdbsuccesstext'   => '庫閉矣。<br />檢畢切[[Special:Unlockdb|開之]]。',
+'lockdbsuccesstext'   => '庫閉矣。<br />檢畢切[[Special:UnlockDB|開之]]。',
 'unlockdbsuccesstext' => '庫開矣',
 'lockfilenotwritable' => '未准更鎖庫檔。欲開閉之，網頁伺服須得更也。',
 'databasenotlocked'   => '庫未閉焉。',
@@ -1580,15 +1590,13 @@
 # Move page
 'move-page'               => '遷$1',
 'move-page-legend'        => '遷頁',
-'movepagetext'            => "函下遷頁，誌隨新往、舊題作渡、取佐不移。保佐正，防窮、斷渡。
+'movepagetext'            => "函下遷頁，誌隨新往、舊題作渡、取佐欲移。保佐正，[[Special:DoubleRedirects|防窮]]、[[Special:BrokenRedirects|斷渡]]。
 
 囑之者，新題若非空、渡、缺誌，則舊'''不遷'''焉。存頁勿覆，而誤遷可悔也。
 
 <b>警示</b>
 膾炙遷焉，禍生不測；戒慎行之。",
 'movearticle'             => '遷文：',
-'movenologin'             => '未登簿',
-'movenologintext'         => '遷文須[[Special:Userlogin|登簿]]。',
 'movenotallowed'          => '無准遷文也。',
 'newtitle'                => '至新題：',
 'move-watch'              => '派哨',
@@ -1615,7 +1623,7 @@
 'delete_and_move'         => '刪遷',
 'delete_and_move_text'    => '==准刪==
 
-往遷"[[$1]]"存，刪之以替乎？',
+往遷"[[:$1]]"存，刪之以替乎？',
 'delete_and_move_confirm' => '刪之',
 'delete_and_move_reason'  => '為遷而刪之',
 'selfmove'                => '鄉遷同源，如未移也。',
@@ -1623,6 +1631,7 @@
 'imagenocrossnamespace'   => '非勳檔至非檔名間',
 'imagetypemismatch'       => '其新副檔名非配其類也',
 'imageinvalidfilename'    => '標之檔名乃無效也',
+'fix-double-redirects'    => '更指原題之任渡',
 
 # Export
 'export'            => '出匯',
@@ -1661,7 +1670,8 @@
 'import-interwiki-history'   => '審、誌同匯',
 'import-interwiki-submit'    => '入匯',
 'import-interwiki-namespace' => '入名冊：',
-'importtext'                 => '請[[Special:Export出匯]]儲之，再入匯於此。',
+'importtext'                 => '請[[Special:Export|出匯]]儲之。
+再入匯於此。',
 'importstart'                => '入匯…',
 'import-revision-count'      => '有審$1',
 'importnopages'              => '無可匯。',
@@ -1820,9 +1830,10 @@
 'markedaspatrollederror-noautopatrol' => '己易不可哨。',
 
 # Patrol log
-'patrol-log-page' => '誌哨',
-'patrol-log-line' => '令哨$2之$1$3',
-'patrol-log-auto' => '（自行）',
+'patrol-log-page'   => '誌哨',
+'patrol-log-header' => '此乃誌哨也。',
+'patrol-log-line'   => '令哨$2之$1$3',
+'patrol-log-auto'   => '（自行）',
 
 # Image deletion
 'deletedrevision'                 => '刪舊審$1',
@@ -1847,10 +1858,10 @@
 'show-big-image'       => '全幅',
 'show-big-image-thumb' => '<small>縮圖幅有像素$1矩$2</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新圖之廊',
 'imagelisttext'         => "下表乃按$2排之的'''$1'''檔。",
-'newimages-summary'     => '此奇頁示最後呈上之檔也',
+'newimages-summary'     => '此奇頁示最後呈上之檔也。',
 'showhidebots'          => '（$1僕）',
 'noimages'              => '無可見。',
 'ilsubmit'              => '尋檔',
@@ -1892,7 +1903,7 @@
 
 # External editor support
 'edit-externally'      => '以外部程式修此文',
-'edit-externally-help' => '請閱[http://meta.wikimedia.org/wiki/Help:External_editors 安裝指引]以知詳情。',
+'edit-externally-help' => '請閱[http://www.mediawiki.org/wiki/Manual:External_editors 安裝指引]以知詳情。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => '全',
@@ -1929,11 +1940,11 @@
 'deletedwhileediting' => '警：纂中見刪。',
 'confirmrecreate'     => "[[User:$1|$1]]（[[User talk:$1|議]]）刪之有由：
 ''$2''
-請審視之。",
+請爾審視之。",
 'recreate'            => '復',
 
 # HTML dump
-'redirectingto' => '渡至[[$1]]…',
+'redirectingto' => '渡至[[:$1]]…',
 
 # action=purge
 'confirm_purge'        => '清謄本？
@@ -2034,7 +2045,7 @@
 'version-software-product'         => '品',
 'version-software-version'         => '版',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => '檔路',
 'filepath-page'    => '檔名：',
 'filepath-submit'  => '尋路',
@@ -2072,7 +2083,7 @@
 'specialpages-group-redirects'   => '轉之特查',
 'specialpages-group-spam'        => '反垃圾之器',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => '白頁',
 'intentionallyblankpage' => '此頁為白也，試速之用',
 
Index: languages/messages/MessagesEo.php
===================================================================
--- languages/messages/MessagesEo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,17 +4,13 @@
  * @ingroup Language
  * @file
  *
- * @author Yekrats
- * @author לערי ריינהארט
- * @author Tlustulimu
- * @author Michawiki
- * @author Siebrand
  * @author Amikeco
  * @author ArnoLagrange
- * @author SPQRobin
- * @author Gangleri
  * @author Malafaya
- * @author Jon Harald Søby
+ * @author Michawiki
+ * @author Tlustulimu
+ * @author Yekrats
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -91,37 +87,37 @@
 'tog-numberheadings'          => 'Aŭtomate numerigi sekciojn',
 'tog-showtoolbar'             => 'Montri eldonilaron',
 'tog-editondblclick'          => 'Redakti per duobla alklako (JavaScript)',
-'tog-editsection'             => 'Montri [redaktu]-ligiloj por sekcioj',
+'tog-editsection'             => 'Montri [redakti]-ligilojn por sekcioj',
 'tog-editsectiononrightclick' => 'Redaktu sekciojn per dekstra musklako',
 'tog-showtoc'                 => 'Montri liston de enhavoj',
 'tog-rememberpassword'        => 'Rememori mian pasvorton',
 'tog-editwidth'               => 'Redaktilo estu plenlarĝa',
-'tog-watchcreations'          => 'Aldonu de mi kreitajn paĝojn al mia atentaro',
+'tog-watchcreations'          => 'Aldoni de mi kreitajn paĝojn al mia atentaro',
 'tog-watchdefault'            => 'Priatenti redaktintajn paĝojn de vi',
 'tog-watchmoves'              => 'Aldoni paĝojn, kiujn mi movas, al mia atentaro',
 'tog-watchdeletion'           => 'Aldoni paĝojn, kiujn mi forigas, al mia atentaro',
-'tog-minordefault'            => 'Marku ĉiujn redaktojn malgrandaj',
+'tog-minordefault'            => 'Marki defaŭlte ĉiujn redaktojn kiel etajn',
 'tog-previewontop'            => 'Montri antaŭrigardon antaŭ redaktilo',
-'tog-previewonfirst'          => 'Montru antaŭrigardon je unua redakto',
+'tog-previewonfirst'          => 'Montri antaŭrigardon je unua redakto',
 'tog-nocache'                 => 'Malaktivigu kaŝmemorigon de paĝoj',
 'tog-enotifwatchlistpages'    => 'Sendi al mi retmesaĝon kiam tiu paĝo estas ŝanĝita',
-'tog-enotifusertalkpages'     => 'Sendu al mi retmesaĝon kiam mia diskutpaĝo estas ŝanĝita',
-'tog-enotifminoredits'        => 'Sendu al mi ankaŭ retmesaĝojn por malgrandaj redaktoj de paĝoj',
-'tog-enotifrevealaddr'        => 'Malkaŝu mian retpoŝtan adreson en informaj retpoŝtaĵoj',
-'tog-shownumberswatching'     => 'Montru la nombron da priatentaj uzantoj',
+'tog-enotifusertalkpages'     => 'Sendi al mi retmesaĝon kiam mia diskutpaĝo estas ŝanĝita',
+'tog-enotifminoredits'        => 'Sendi al mi ankaŭ retmesaĝojn por malgrandaj redaktoj de paĝoj',
+'tog-enotifrevealaddr'        => 'Malkaŝi mian retadreson en informaj retpoŝtaĵoj',
+'tog-shownumberswatching'     => 'Montri la nombron da priatentaj uzantoj',
 'tog-fancysig'                => 'Simpla subskribo (sen aŭtomata ligo)',
-'tog-externaleditor'          => 'Uzu defaŭlte eksteran tekstprilaborilon',
-'tog-externaldiff'            => 'Uzu defaŭlte eksteran ŝanĝmontrilon',
+'tog-externaleditor'          => 'Uzi defaŭlte eksteran tekstprilaborilon',
+'tog-externaldiff'            => 'Uzi defaŭlte eksteran ŝanĝmontrilon',
 'tog-showjumplinks'           => 'Ebligi alirligojn "salti al"
 <!-- Bonvolu kontroli ĉu ĝustas la traduko de : Enable "jump to" accessibility links -->',
 'tog-uselivepreview'          => 'Uzu tujan antaŭrigardon (ĜavaSkripto) (Eksperimenta)',
-'tog-forceeditsummary'        => 'Informu min kiam aldonanta nulan redakto-resumon',
-'tog-watchlisthideown'        => 'Kaŝu miajn redaktojn de la atentaro',
+'tog-forceeditsummary'        => 'Averti min kiam mi konservas malplenan redaktoresumon',
+'tog-watchlisthideown'        => 'Kaŝi miajn redaktojn de la atentaro',
 'tog-watchlisthidebots'       => 'Kaŝu bot-redaktojn de la atentaro',
 'tog-watchlisthideminor'      => 'Kaŝu malgrandajn redaktojn de la atentaro',
 'tog-ccmeonemails'            => 'Sendu al mi kopiojn de retpoŝtaĵoj, kiujn mi sendis al aliaj uzuloj.',
-'tog-diffonly'                => 'Ne montru paĝan enhavon sub la ŝanĝoj',
-'tog-showhiddencats'          => 'Montru kaŝitajn kategoriojn',
+'tog-diffonly'                => 'Ne montri paĝan enhavon sub la ŝanĝoj',
+'tog-showhiddencats'          => 'Montri kaŝitajn kategoriojn',
 
 'underline-always'  => 'Ĉiam',
 'underline-never'   => 'Neniam',
@@ -245,15 +241,15 @@
 'edit'              => 'Redakti',
 'create'            => 'Krei',
 'editthispage'      => 'Redaktu la paĝon',
-'create-this-page'  => 'Kreu ĉi tiun paĝon',
+'create-this-page'  => 'Krei ĉi tiun paĝon',
 'delete'            => 'Forigi',
 'deletethispage'    => 'Forigi ĉi tiun paĝon',
-'undelete_short'    => 'Malforigu {{PLURAL:$1|redakton|$1 redaktojn}}',
+'undelete_short'    => 'Malforigi {{PLURAL:$1|redakton|$1 redaktojn}}',
 'protect'           => 'Protekti',
 'protect_change'    => 'ŝanĝi protekton',
 'protectthispage'   => 'Protekti la paĝon',
 'unprotect'         => 'Malprotekti',
-'unprotectthispage' => 'Malprotektu la paĝon',
+'unprotectthispage' => 'Malprotekti la paĝon',
 'newpage'           => 'Nova paĝo',
 'talkpage'          => 'Diskuti la paĝon',
 'talkpagelinktext'  => 'Diskuto',
@@ -267,11 +263,11 @@
 'userpage'          => 'Rigardi personan paĝon',
 'projectpage'       => 'Rigardi projektopaĝon',
 'imagepage'         => 'Rigardi dosieropaĝon',
-'mediawikipage'     => 'Vidu mesaĝopaĝon',
-'templatepage'      => 'Vidu ŝablonopaĝon',
-'viewhelppage'      => 'Vidu helpopaĝon',
-'categorypage'      => 'Rigardi kategorian paĝon',
-'viewtalkpage'      => 'Vidu diskutopaĝon',
+'mediawikipage'     => 'Vidi mesaĝopaĝon',
+'templatepage'      => 'Vidi ŝablonopaĝon',
+'viewhelppage'      => 'Vidi helpopaĝon',
+'categorypage'      => 'Vidi kategorian paĝon',
+'viewtalkpage'      => 'Vidi diskuton',
 'otherlanguages'    => 'Aliaj lingvoj',
 'redirectedfrom'    => '(Alidirektita el $1)',
 'redirectpagesub'   => 'Alidirektilo',
@@ -308,7 +304,7 @@
 'privacypage'          => 'Project:Respekto de la privateco',
 
 'badaccess'        => 'Vi ne havas sufiĉe da redaktorajtoj por tiu paĝo.',
-'badaccess-group0' => 'Vi ne havas permeson plenumi la agon, kiun vi petis.',
+'badaccess-group0' => 'Vi ne rajtas plenumi la agon, kiun vi petis.',
 'badaccess-group1' => 'La ago, kiun vi petis, estas limigita al uzuloj en la grupo $1.',
 'badaccess-group2' => 'La ago, kiun vi petis, estas limigita al uzuloj en unu el la grupoj $1.',
 'badaccess-groups' => 'La ago, kiun vi petis, estas limigita al uzuloj en unu el la grupoj $1.',
@@ -324,12 +320,12 @@
 'youhavenewmessagesmulti' => 'Vi havas novajn mesaĝojn ĉe $1',
 'editsection'             => 'redakti',
 'editold'                 => 'redakti',
-'viewsourceold'           => 'rigardu fonttekston',
-'editsectionhint'         => 'Redaktu sekcion: $1',
+'viewsourceold'           => 'vidi fonttekston',
+'editsectionhint'         => 'Redakti sekcion: $1',
 'toc'                     => 'Enhavo',
 'showtoc'                 => 'montri',
 'hidetoc'                 => 'kaŝi',
-'thisisdeleted'           => 'Vidu aŭ restarigu $1?',
+'thisisdeleted'           => 'Vidi aŭ restarigi $1?',
 'viewdeleted'             => 'Ĉu rigardi $1?',
 'restorelink'             => '{{PLURAL:$1|unu forigitan version|$1 forigitajn versiojn}}',
 'feedlinks'               => 'RSS-fonto:',
@@ -358,7 +354,7 @@
 'nosuchactiontext'  => "La agon ('action') nomitan de la URL
 ne agnoskas la programaro de {{SITENAME}}",
 'nosuchspecialpage' => 'Ne ekzistas tia speciala paĝo',
-'nospecialpagetext' => 'Vi petis [[Special:Specialpages|specialan paĝon]] kiun ne agnoskas la programaro de {{SITENAME}}.',
+'nospecialpagetext' => 'Vi petis [[Special:SpecialPages|specialan paĝon]] kiun ne agnoskas la programaro de {{SITENAME}}.',
 
 # General errors
 'error'                => 'Eraro',
@@ -393,7 +389,7 @@
 Ĉi tiel ofte estas kaŭzite de sekvado de malfreŝa \'\'diff\'\' aŭ historia ligilo al paĝo kiu estis forigita.
 
 Se ĉi tiel ne okazis, verŝajne vi trovis cimon en la softvaro.
-Bonvolu raporti ĉi tiun al administranto, notante la TTT-adreson.',
+Bonvolu raporti ĉi tiun al [[Special:ListUsers/sysop|administranto]], notante la TTT-adreson.',
 'missingarticle-rev'   => '(revizio#: $1)',
 'missingarticle-diff'  => '(Diferenco inter versioj: $1, $2)',
 'readonly_lag'         => 'La datumbazo estis aŭtomate ŝlosita dum la subdatumbazo atingas la ĉefan datumbazon.',
@@ -444,22 +440,24 @@
 
 # Login and logout pages
 'logouttitle'                => 'Elsaluti',
-'logouttext'                 => '<strong>Vi elsalutis kaj finis vian seancon.</strong><br />
-Vi rajtas daŭre vikiumi sennome, aŭ vi povas reensaluti kiel la sama aŭ kiel alia uzanto.',
+'logouttext'                 => '<strong>Vi nun estas elsalutita.</strong>
+
+Vi rajtas daŭre vikiumi sennome, aŭ vi povas [[Special:UserLogin|reensaluti]] kiel la sama aŭ kiel alia uzanto.
+Notu ke iuj paĝoj daŭre ŝajnos kvazaŭ vi ankoraŭ estas ensalutita, ĝis vi refreŝigu vian retumilan kaŝmemoron.',
 'welcomecreation'            => '== Bonvenon, $1! ==
 Via konto estas kreita.
-Ne forgesu fari viajn {{SITENAME}}-preferojn.',
+Ne forgesu fari viajn [[Special:Preferences|{{SITENAME}}-preferojn]].',
 'loginpagetitle'             => 'Ensaluti / enskribi',
 'yourname'                   => 'Salutnomo:',
 'yourpassword'               => 'Via pasvorto',
 'yourpasswordagain'          => 'Retajpu pasvorton',
 'remembermypassword'         => 'Rememori mian pasvorton',
 'yourdomainname'             => 'Via domajno',
-'externaldberror'            => 'Aŭ estis datenbaza eraro rilate al ekstera aŭtentikigado, aŭ vi ne permesas ĝisdatigi vian eksteran konton.',
+'externaldberror'            => 'Aŭ estis datenbaza eraro rilate al ekstera aŭtentikigado, aŭ vi ne rajtas ĝisdatigi vian eksteran konton.',
 'loginproblem'               => '<b>Okazis problemo dum via ensalutado.</b><br />Bonvolu reprovi!',
 'login'                      => 'Ensaluti',
 'nav-login-createaccount'    => 'Ensalutu / Kreu novan konton',
-'loginprompt'                => 'Necesas ke via foliumilo permesu kuketojn por ensaluti en la {{SITENAME}}.',
+'loginprompt'                => 'Via foliumilo nepre permesu kuketojn por ensaluti en la {{SITENAME}}.',
 'userlogin'                  => 'Ensaluti / Krei novan konton',
 'logout'                     => 'Elsaluti',
 'userlogout'                 => 'Elsaluti',
@@ -512,7 +510,7 @@
 registrita por "$1".
 Bonvolu saluti denove ricevinte ĝin.',
 'blocked-mailpassword'       => 'Via IP adreso estas forbarita de redaktado, kaj tial
-ne estas permesate uzi la pasvorto-rekovran funkcion por malebligi misuzon.',
+ne rajtas uzi la pasvorto-rekovran funkcion por malebligi misuzon.',
 'eauthentsent'               => 'Konfirma retmesaĝo estas sendita al la nomita retadreso. Antaŭ ol iu ajn alia mesaĝo estos sendita al la konto, vi devos sekvi la instrukciojn en la mesaĝo por konfirmi ke la konto ja estas la via.',
 'throttled-mailpassword'     => 'Pasvorta rememorigilo estis jam sendita, ene de la {{PLURAL:$1|lasta $1 horo|lastaj $1 horoj}}. Por preventi misuzo, nur unu pasvorto-rememorigilo estos sendita po {{PLURAL:$1|$1 horo|$1 horoj}}.',
 'mailerror'                  => 'Okazis eraro sendante retpoŝtaĵon: $1',
@@ -576,43 +574,43 @@
 'anoneditwarning'                  => 'Vi ne estas ensalutinta. Via IP-adreso enregistriĝos en la ŝango-historio de tiu ĉi paĝo.',
 'missingsummary'                   => "'''Rememorigilo:''' Vi ne provizis redaktan resumon. Se vi alklakos denove la savan butonon, via redaktaĵo estos storata sen resumo.",
 'missingcommenttext'               => 'Bonvolu entajpi komenton malsupre.',
-'missingcommentheader'             => "'''Atento:''' Vi ne donis temo/subtitolo por cxi tiu komento. Se vi klakos Konservu denove, via redakto estos konservita sen gxi.",
+'missingcommentheader'             => "'''Atento:''' Vi ne donis temo/subtitolo por cxi tiu komento. Se vi klakos Konservi denove, via redakto estos konservita sen gxi.",
 'summary-preview'                  => 'Resuma antaŭrigardo',
 'subject-preview'                  => 'Antaŭrigardo de Temo/Subitolo',
 'blockedtitle'                     => 'La uzanto estas forbarita.',
-'blockedtext'                      => "<big>'''Via konto aŭ IP-adreso estis forbarita'''</big> fare de $1.
-Kialo estas ''$2''.
+'blockedtext'                      => "<big>'''Via konto aŭ IP-adreso estis forbarita'''</big> 
 
+La forbaro estis farita de $1.
+La skribita kialo estas ''$2''.
+
+* Komenco de forbaro: $8
+* Findato de forbarado: $6
+* Intencita forbarito: $7
+
 Vi rajtas kontakti $1 aŭ alian [[{{MediaWiki:Grouppage-sysop}}|administranton]] por pridiskuti la forbaradon.
 Vi ne povas uzi la 'retpoŝtan' funkcion, escepte se vi indikis validan retpoŝtan adreson en viaj [[Special:Preferences|kontaj agordoj]] kaj vi ne estas blokita uzi ĝin.
-Via IP-adreso estas $3 kaj la ID de la forbarado ests $5. Bonvolu mencii jenajn indikojn en ĉiu plendo:
-* IP-adreso: $3
-* ID de forbarado: $5
-* Komenco de la forbarado: $8
-* Malvalidiĝo de la forbarado: $6
-* Forbaroto: $7",
-'autoblockedtext'                  => 'Via IP-adreso estas auxtomate forbarita, cxar uzis gxin alia uzanto, kiun baris $1.
+Via IP-adreso estas $3 kaj la ID de la forbarado ests $5. 
+Bonvolu mencii jenajn indikojn en viaj ĉi-temaj kontaktoj.",
+'autoblockedtext'                  => 'Via IP-adreso estas aŭtomate forbarita, cxar uzis ĝin alia uzanto, kiun baris $1.
 La donita kialo estas:
 
 :\'\'$2\'\'
 
 *Komenco de forbaro: $8
 *Limdato de la blokado: $6
+*Intencias forbari uzanton: $7
 
 Vi povas kontakti $1 aux iun ajn el la aliaj [[{{MediaWiki:Grouppage-sysop}}|administrantojn]] por diskuti la blokon.
 
-Notu, ke vi ne povas uzi la servon "Retposxtu cxi tiu uzanton" krom se vi havas validan retpost-adreson registritan en viaj [[Special:Preferences|vikipediistajn preferojn]], kaj vi estas ne blokita kontraux gxia uzado.
+Notu, ke vi ne povas uzi la servon "Retposxtu ĉi tiu uzanton" krom se vi havas validan retpost-adreson registritan en viaj [[Special:Preferences|preferojn]], kaj vi estas ne blokita kontraŭ ĝia uzado.
 
-Via forbaro-identigo estas $5.  Bonvolu inkluzivi tiun identigon en iuj ajn demandoj de vi farotaj.',
+Via nuna IP-adreso estas $3, kaj la forbaro-identigo estas $5.
+Bonvolu inkluzivi tiujn detalojn en iuj ajn demandoj kiun vi farus.',
 'blockednoreason'                  => 'nenia kialo donata',
 'blockedoriginalsource'            => "La fonto de '''$1''' estas montrata malsupre:",
 'blockededitsource'                => "La teksto de '''viaj redaktoj''' al '''$1''' estas montrata malsupre:",
 'whitelistedittitle'               => 'Ensalutado devigata por redakti',
 'whitelistedittext'                => 'Vi devas $1 por redakti paĝojn.',
-'whitelistreadtitle'               => 'Ensalutado devigata por legi',
-'whitelistreadtext'                => 'Vi devas [[Special:Userlogin|ensaluti]] por legi paĝojn.',
-'whitelistacctitle'                => 'Vi ne rajtas krei konton',
-'whitelistacctext'                 => 'Por rajti krei kontojn en {{SITENAME}} vi devas [[Special:Userlogin|ensaluti]] kaj havi la taŭgajn permesojn.',
 'confirmedittitle'                 => 'Nepras konfirmi per retpoŝto por redakti',
 'confirmedittext'                  => 'Vi devas konfirmi vian retpoŝtan adreson antaŭ ol redakti paĝojn. Bonvolu agordi kaj validigi vian retadreson per viaj [[Special:Preferences|preferoj]].',
 'nosuchsectiontitle'               => 'Ne tia sekcio',
@@ -624,7 +622,10 @@
 'accmailtext'                      => "La pasvorto por '$1' estis sendita al  $2.",
 'newarticle'                       => '(Nova)',
 'newarticletext'                   => 'Vi sekvis ligilon al paĝo jam ne ekzistanta. Se vi volas krei ĝin, ektajpu sube (vidu la [[{{MediaWiki:Helppage}}|helpopaĝo]] por klarigoj.) Se vi malintence alvenis ĉi tien, simple alklaku la retrobutonon de via retumilo.',
-'anontalkpagetext'                 => "---- ''Jen diskutopaĝo por iu anonima kontribuanto kiu ne jam kreis konton aŭ ne uzas ĝin. Ni tial devas uzi la cifran IP-adreso por identigi lin. la sama IP-adreso povas estis samtempte uzata de pluraj uzantoj. Se vi estas anonimulo kaj preferus eviti tiajn mistrafajn komentojn kaj konfuziĝon kun aliaj anonimuloj de via retejo, bonvolu [[Special:Userlogin|krei konton aŭ ensaluti]].''",
+'anontalkpagetext'                 => "---- ''Jen diskutopaĝo por iu anonima kontribuanto kiu ne jam kreis konton aŭ ne uzas ĝin. 
+Ni tial devas uzi la cifran IP-adreso por identigi lin. 
+La sama IP-adreso povas estis samtempte uzata de pluraj uzantoj.
+Se vi estas anonimulo kaj preferus eviti tiajn mistrafajn komentojn kaj konfuziĝon kun aliaj anonimuloj de via retejo, bonvolu [[Special:UserLogin|krei konton]] aŭ [[Special:UserLogin|ensaluti]] por eviti estontan konfuzon kun alia anonimaj uzantoj.''",
 'noarticletext'                    => 'La paĝo nune estas malplena. Vi povas [[Special:Search/{{PAGENAME}}|serĉi ĉi tiun paĝtitolon]] en aliaj paĝoj aŭ [{{fullurl:{{FULLPAGENAME}}|action=edit}} redakti ĉi tiun paĝon].',
 'userpage-userdoesnotexist'        => 'Uzanto-konto "$1" ne estas registrita. Bonvolu konfirmi se vi volas krei/redakti cxi tiu pagxo.',
 'clearyourcache'                   => "'''Notu:''' Post konservado vi forviŝu la kaŝmemoron de via foliumilo por vidi la ŝanĝojn : '''Mozilo:''' alklaku ''Reŝarĝi'' (aŭ ''Stir-Shift-R''), '''IE / Opera:''' ''Stir-F5'', '''Safari:''' ''Cmd-R'', '''Konqueror''' ''Stir-R''.",
@@ -638,14 +639,14 @@
 'previewconflict'                  => 'La jena antaŭrigardo montras la tekston el la supra tekstujo,
 kiel ĝi aperos se vi elektos konservi la paĝon.',
 'session_fail_preview'             => '<strong>Bedaŭrinde ne eblis trakti vian redakton pro manko de sesiaj datenoj. Bonvolu provi refoje. Se ankoraŭ ne efikas post tio, elsalutu kaj poste re-ensalutu.</strong>',
-'session_fail_preview_html'        => "<strong>Pardonu! Ne eblas procesi vian redakton pro manko de seanca datumo.</strong>
+'session_fail_preview_html'        => "<strong>Pardonu! Ne eblas procesi vian redakton pro manko de seancaj datenoj.</strong>
 
-''Cxar {{SITENAME}} ebligas krudan HTML, cxi tiu antauxrigardo estas kasxita kiel prevento kontraux Javascript-atakoj.
+''Ĉar {{SITENAME}} ebligas krudan HTML, cxi tiu antaŭrigardo estas kaŝita kiel prevento kontraŭ Javascript-atakoj.
 
-<strong>Se cxi tiu estas tauxga provo por redakti, bonvolu reprovi. Se ankoraux ne funkcias, provu elsaluti kaj reensaluti.</strong>",
-'token_suffix_mismatch'            => '<strong>Via redakto estis malpermesita cxar via klienta fusxis la interpunkcio en la redakto-signo.
-La redakto estis malpermesita por preventi koruptado de la teksto de la pagxo.
-Cxi tiel malofte okazas kiam vi uzas fusxan TTT-an anoniman prokurilon.</strong>',
+<strong>Se ĉi tiu estas taŭga provo por redakti, bonvolu reprovi. Se ankoraŭ ne funkcias, provu [[Special:UserLogout|elsaluti]] kaj reensaluti.</strong>",
+'token_suffix_mismatch'            => '<strong>Via redakto estis malpermesita ĉar via klienta fuŝis la interpunkcio en la redakto-signo.
+La redakto estis malpermesita por preventi koruptado de la teksto de la paĝo.
+Ĉi tiel malofte okazas kiam vi uzas fuŝan TTT-an anoniman prokurilon.</strong>',
 'editing'                          => 'Redaktante $1',
 'editingsection'                   => 'Redaktante $1 (sekcion)',
 'editingcomment'                   => 'Redaktante $1 (komenton)',
@@ -655,14 +656,14 @@
 Viaj ŝanĝoj estas en la malsupra tekstujo.
 Vi devas mem kunfandi viajn ŝanĝojn kaj la jaman tekston.
 <b>Nur</b> la teksto en la supra tekstujo estos konservita kiam
-vi alklakos "Konservu".<br />',
+vi alklakos "Konservi".<br />',
 'yourtext'                         => 'Via teksto',
 'storedversion'                    => 'Registrita versio',
 'nonunicodebrowser'                => '<strong>ATENTU: Via foliumilo ne eltenas unikodon, bonvolu ŝanĝi ĝin antaŭ ol redakti artikolon.</strong>',
 'editingold'                       => '<strong>AVERTO: Vi nun redaktas malnovan version de tiu ĉi artikolo.
 Se vi konservos vian redakton, ĉiuj ŝanĝoj faritaj post tiu versio perdiĝos.</strong>',
 'yourdiff'                         => 'Malsamoj',
-'copyrightwarning'                 => 'Bonvolu noti, ke ĉiu kontribuaĵo al la {{SITENAME}} estu rigardata kiel eldonita laŭ $2 (vidu je $1). Se vi volas, ke via verkaĵo ne estu redaktota senkompate kaj disvastigota laŭvole, ne alklaku "Konservu".<br />
+'copyrightwarning'                 => 'Bonvolu noti, ke ĉiu kontribuaĵo al la {{SITENAME}} estu rigardata kiel eldonita laŭ $2 (vidu je $1). Se vi volas, ke via verkaĵo ne estu redaktota senkompate kaj disvastigota laŭvole, ne alklaku "Konservi".<br />
 Vi ankaŭ ĵuras, ke vi mem verkis la tekston, aŭ ke vi kopiis ĝin el fonto senkopirajta.
 <strong>NE UZU KOPIRAJTAJN VERKOJN SENPERMESE!</strong>',
 'copyrightwarning2'                => 'Bonvolu noti ke ĉiuj kontribuoj al {{SITENAME}} povas esti reredaktita, ŝanĝita aŭ forigita de aliaj kontribuantoj. Se vi ne deziras ke viaj verkoj estu senkompate reredaktitaj, ne publikigu ilin ĉi tie.<br />
@@ -687,11 +688,11 @@
 'hiddencategories'                 => 'Ĉi paĝo estas membro de {{PLURAL:$1|1 kaŝita kategorio|$1 kaŝitaj kategorioj}}:',
 'edittools'                        => '<!-- Teksto ĉi tie estas montrata sub redaktaj kaj alŝutaj formularoj. -->',
 'nocreatetitle'                    => 'Paĝa kreado estas limigita',
-'nocreatetext'                     => '{{SITENAME}} restriktas la eblecon krei novajn paĝojn. Vi eblas reiri kaj redakti faritan paĝon, aŭ [[Special:Userlogin|ensaluti aŭ krei konton]].',
+'nocreatetext'                     => '{{SITENAME}} restriktas la eblecon krei novajn paĝojn. Vi eblas reiri kaj redakti faritan paĝon, aŭ [[Special:UserLogin|ensaluti aŭ krei konton]].',
 'nocreate-loggedin'                => 'Vi ne rajtas krei novajn paĝojn en {{SITENAME}}.',
-'permissionserrors'                => 'Eraroj pri permesoj',
+'permissionserrors'                => 'Eraroj pri rajtoj',
 'permissionserrorstext'            => 'Vi ne rajtas fari tion pro la {{PLURAL:$1|sekva kialo|sekvaj kialoj}}:',
-'permissionserrorstext-withaction' => 'Vi ne permesas $2, pro la {{PLURAL:$1|jena kialo|jenaj kialoj}}:',
+'permissionserrorstext-withaction' => 'Vi ne rajtas $2, pro la {{PLURAL:$1|jena kialo|jenaj kialoj}}:',
 'recreate-deleted-warn'            => "'''Averto: Vi rekreas paĝon tiu estis antaŭe forigita.'''
 
 Vi konsideru ĉu konvenas daŭre redakti ĉi paĝon.
@@ -710,13 +711,13 @@
 'post-expand-template-argument-category'  => 'Paĝoj enhavantaj forlasitajn argumentojn de ŝablonoj',
 
 # "Undo" feature
-'undo-success' => 'La redakto estas malfarebla. Bonvolu konfirmi la jenan komparajxon por verigi cxi tiel vi volas, kaj konservu la sxangxojn suben fini malfarante la redakton.',
+'undo-success' => 'La redakto estas malfarebla. Bonvolu konfirmi la jenan komparajxon por verigi cxi tiel vi volas, kaj konservi la sxangxojn suben fini malfarante la redakton.',
 'undo-failure' => 'Ne eblas nuligi redakton pro konfliktaj intermezaj redaktoj.',
 'undo-norev'   => 'La redakto ne eblis esti malfarita ĉar ĝi aŭ ne ekzistas aŭ estis forigita.',
-'undo-summary' => 'Nuligis revizion $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|diskuto]])',
+'undo-summary' => 'Nuligis revizion $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskuto]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
-'cantcreateaccounttitle' => 'Ne povas krei konton',
+'cantcreateaccounttitle' => 'Ne eblas krei konton',
 'cantcreateaccount-text' => "Konto-kreado de cxi tiu IP-adreso ('''$1''') estis forbarita de [[User:$3|$3]].
 
 La kialo donata de $3 estas ''$2''.",
@@ -795,7 +796,7 @@
 'pagehist'                    => 'Paĝa historio',
 'deletedhist'                 => 'Forigita historio',
 'revdelete-content'           => 'enhavo',
-'revdelete-summary'           => 'redaktu resumon',
+'revdelete-summary'           => 'redakti resumon',
 'revdelete-uname'             => 'salutnomo',
 'revdelete-restricted'        => 'aplikis limojn al administrantoj',
 'revdelete-unrestricted'      => 'forigis limojn por administrantoj',
@@ -807,7 +808,7 @@
 # Suppression log
 'suppressionlog'     => 'Loglibro pri subigado',
 'suppressionlogtext' => 'Jen listo de forigoj kaj forbaroj pri enhavo kaŝita per administrantoj. 
-Rigardu la [[Special:Ipblocklist|IP-forbarliston]] por la listo de nune operaciaj forbaroj kaj forigoj.',
+Rigardu la [[Special:IPBlockList|IP-forbarliston]] por la listo de nune operaciaj forbaroj kaj forigoj.',
 
 # History merging
 'mergehistory'                     => 'Kunfandigi historiojn de paĝoj',
@@ -818,7 +819,7 @@
 'mergehistory-into'                => 'Celpaĝo:',
 'mergehistory-list'                => 'Kunigebla redakthistorio',
 'mergehistory-merge'               => 'La jenaj revizioj de [[:$1]] povas esti kunigitaj en [[:$2]]. Uzu la radio-butonan kolumnon por enkunigi nur la reviziojn kreitajn cxe kaj antaux la specifigita tempo. Notu ke uzado de navigado-ligiloj restarigos ĉi kolumnon.',
-'mergehistory-go'                  => 'Montru kunigeblajn redaktojn',
+'mergehistory-go'                  => 'Montri kunigeblajn redaktojn',
 'mergehistory-submit'              => 'Kunigu reviziojn',
 'mergehistory-empty'               => 'Neniuj reviziojn eblas kunigi.',
 'mergehistory-success'             => '$3 {{PLURAL:$3|revizio|revizioj}} de [[:$1]] sukcese kunigita en [[:$2]].',
@@ -833,7 +834,7 @@
 # Merge log
 'mergelog'           => 'Protokolo de kunigoj',
 'pagemerge-logentry' => 'kunigis [[$1]] en [[$2]] (revizioj gxis $3)',
-'revertmerge'        => 'Malkunigu',
+'revertmerge'        => 'Malkunigi',
 'mergelogpagetext'   => 'Jen listo de la plej lastatempaj kunigoj de unu paĝhistorio en alian.',
 
 # Diffs
@@ -847,7 +848,7 @@
 # Search results
 'searchresults'             => 'Serĉrezultoj',
 'searchresulttext'          => 'Por pliaj informoj kiel priserĉi la {{SITENAME}}n, vidu [[{{MediaWiki:Helppage}}|serĉi en {{SITENAME}}]].',
-'searchsubtitle'            => 'Serĉmendo "[[$1]]"',
+'searchsubtitle'            => 'Vi serĉis "\'\'\'[[$1]]\'\'\'" ([[Special:Prefixindex/$1|ĉiuj paĝoj komence kun "$1"]] | [[Special:WhatLinksHere/$1|ĉiuj paĝoj ligantaj al "$1"]])',
 'searchsubtitleinvalid'     => 'Serĉmendo "$1"',
 'noexactmatch'              => '<b>Ne estas paĝo titolita "$1".</b> Vi povas [[:$1|krei la paĝon]].',
 'noexactmatch-nocreate'     => "'''Estas neniu paĝo titolita \"\$1\".'''",
@@ -894,7 +895,7 @@
 'mypreferences'            => 'Miaj preferoj',
 'prefs-edits'              => 'Nombro de redaktoj:',
 'prefsnologin'             => 'Ne jam salutis!',
-'prefsnologintext'         => '[[Special:Userlogin|Ensalutu]] kaj vi povos ŝanĝi viajn preferojn.',
+'prefsnologintext'         => '[[Special:UserLogin|Ensalutu]] kaj vi povos ŝanĝi viajn preferojn.',
 'prefsreset'               => 'Preferoj reprenitaj el la registro.',
 'qbsettings'               => 'Preferoj pri ilaro',
 'qbsettings-none'          => 'Nenia',
@@ -903,7 +904,7 @@
 'qbsettings-floatingleft'  => 'Ŝvebas maldekstre',
 'qbsettings-floatingright' => 'Ŝvebas dekstre',
 'changepassword'           => 'Ŝanĝu pasvorton',
-'skin'                     => 'Aspekto',
+'skin'                     => 'Etoso',
 'math'                     => 'Matematikaĵoj',
 'dateformat'               => 'Datformato',
 'datedefault'              => 'Nenia prefero',
@@ -947,7 +948,7 @@
 'timezoneoffset'           => 'Malsamo',
 'servertime'               => 'Horo de la servilo (UTC):',
 'guesstimezone'            => 'Plenigita el la foliumilo',
-'allowemail'               => 'Permesu retmesaĝojn de aliaj uzantoj',
+'allowemail'               => 'Rajtigi retmesaĝojn de aliaj uzantoj',
 'prefs-searchoptions'      => 'Serĉi opciojn',
 'prefs-namespaces'         => 'Nomspacoj',
 'defaultns'                => 'Traserĉu la jenajn nomspacojn:',
@@ -955,44 +956,44 @@
 'files'                    => 'Dosieroj',
 
 # User rights
-'userrights'                  => 'Administrado de uzantorajtoj', # Not used as normal message but as header for the special page itself
-'userrights-lookup-user'      => 'Administru uzantogrupojn',
+'userrights'                  => 'Administrado de rajtoj de uzantoj', # Not used as normal message but as header for the special page itself
+'userrights-lookup-user'      => 'Administri grupojn de uzantoj',
 'userrights-user-editname'    => 'Entajpu uzantonomon:',
-'editusergroup'               => 'Redaktu Uzantgrupojn',
+'editusergroup'               => 'Redakti grupojn de uzantoj',
 'editinguser'                 => "Redaktante uzanto-rajtojn de uzanto '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
-'userrights-editusergroup'    => 'Redaktu uzantogrupojn.',
-'saveusergroups'              => 'Konservu uzantogrupojn',
+'userrights-editusergroup'    => 'Redakti grupojn de uzantoj',
+'saveusergroups'              => 'Konservi grupojn de uzantoj',
 'userrights-groupsmember'     => 'Membro de:',
 'userrights-groups-help'      => 'Vi povas modifi la grupojn kiun ĉi uzanto enestas.
 * Markita markbutono signifas ke la uzanto estas en tiu grupo.
 * Nemarkita markbutono signifas ke la uzanto ne estas in tiu grupo.
 * Steleto (*) signifas ke vi ne povas forigi la grupon post vi aldonis ĝin, aŭ male.',
 'userrights-reason'           => 'Kialo por ŝanĝo:',
-'userrights-no-interwiki'     => 'Vi ne havas permeson redakti uzanto-rajtojn en aliaj vikioj.',
+'userrights-no-interwiki'     => 'Vi ne rajtas redakti uzanto-rajtojn en aliaj vikioj.',
 'userrights-nodatabase'       => 'Datumbazo $1 ne ekzistas aŭ ne estas loka.',
-'userrights-nologin'          => 'Vi nepre [[Special:Userlogin|ensalutu]] kun administranto-konto doni uzanto-rajtojn.',
-'userrights-notallowed'       => 'Via konto ne havas permeson doni uzanto-rajtojn.',
+'userrights-nologin'          => 'Vi nepre [[Special:UserLogin|ensalutu]] kun administranto-konto doni uzanto-rajtojn.',
+'userrights-notallowed'       => 'Via konto ne rajtas doni uzanto-rajtojn.',
 'userrights-changeable-col'   => 'Grupoj kiujn vi povas ŝanĝi',
 'userrights-unchangeable-col' => 'Grupoj kiujn vi ne povas ŝanĝi',
 
 # Groups
 'group'               => 'Grupo:',
-'group-user'          => 'Uzuloj',
+'group-user'          => 'Uzantoj',
 'group-autoconfirmed' => 'Aŭtomate konfirmitaj uzantoj',
 'group-bot'           => 'Robotoj',
-'group-sysop'         => 'Sisopoj',
+'group-sysop'         => 'Administrantoj',
 'group-bureaucrat'    => 'Burokratoj',
 'group-suppress'      => 'Superrigardoj',
 'group-all'           => '(ĉiuj)',
 
-'group-user-member'          => 'Uzulo',
+'group-user-member'          => 'uzanto',
 'group-autoconfirmed-member' => 'Aŭtomate konfirmita uzanto',
 'group-bot-member'           => 'Roboto',
-'group-sysop-member'         => 'Sisopo',
+'group-sysop-member'         => 'Administranto',
 'group-bureaucrat-member'    => 'Burokrato',
 'group-suppress-member'      => 'Superrigardo',
 
-'grouppage-user'          => '{{ns:project}}:Uzuloj',
+'grouppage-user'          => '{{ns:project}}:Uzantoj',
 'grouppage-autoconfirmed' => '{{ns:project}}:Aŭtomate konfirmitaj uzantoj',
 'grouppage-bot'           => '{{ns:project}}:Robotoj',
 'grouppage-sysop'         => '{{ns:project}}:Administrantoj',
@@ -1000,57 +1001,57 @@
 'grouppage-suppress'      => '{{ns:project}}:Superrigardo',
 
 # Rights
-'right-read'                 => 'Legu paĝojn',
-'right-edit'                 => 'Redaktu paĝojn',
+'right-read'                 => 'Legi paĝojn',
+'right-edit'                 => 'Redakti paĝojn',
 'right-createpage'           => 'Kreu paĝojn (kiuj ne estas diskuto-paĝoj)',
-'right-createtalk'           => 'Kreu diskuto-paĝojn',
-'right-createaccount'        => 'Kreu novajn uzanto-kontojn',
-'right-minoredit'            => 'Marku redaktojn kiel etajn',
-'right-move'                 => 'Movu paĝojn',
+'right-createtalk'           => 'Krei diskuto-paĝojn',
+'right-createaccount'        => 'Krei novajn uzanto-kontojn',
+'right-minoredit'            => 'Marki redaktojn kiel etajn',
+'right-move'                 => 'Movi paĝojn',
 'right-move-subpages'        => 'Alinomigi paĝojn kun ĝiaj subpaĝoj',
-'right-suppressredirect'     => 'Ne kreu alidirektilon de la malnova nomo kiam movante paĝon',
-'right-upload'               => 'Alŝutu dosierojn',
-'right-reupload'             => 'Anstataŭigu ekzistantan dosieron',
-'right-reupload-own'         => 'Anstataŭigu ekzistantan dosieron alŝutitan de la sama uzanto',
-'right-reupload-shared'      => 'Anstataŭigu dosierojn en la komuna bildprovizejo loke',
-'right-upload_by_url'        => 'Alŝutu dosieron de URL-adreso',
-'right-purge'                => 'Refreŝigu la retejan kaŝmemoron por paĝo sen konfirma paĝo',
-'right-autoconfirmed'        => 'Redaktu duone protektitajn paĝojn',
-'right-bot'                  => 'Traktiĝu kiel aŭtomata procezo',
+'right-suppressredirect'     => 'Ne krei alidirektilon de la malnova nomo kiam movante paĝon',
+'right-upload'               => 'Alŝuti dosierojn',
+'right-reupload'             => 'Anstataŭigi ekzistantan dosieron',
+'right-reupload-own'         => 'Anstataŭigi ekzistantan dosieron alŝutitan de la sama uzanto',
+'right-reupload-shared'      => 'Anstataŭigi dosierojn en la komuna bildprovizejo loke',
+'right-upload_by_url'        => 'Alŝuti dosieron de URL-adreso',
+'right-purge'                => 'Refreŝigi la retejan kaŝmemoron por paĝo sen konfirma paĝo',
+'right-autoconfirmed'        => 'Redakti duone protektitajn paĝojn',
+'right-bot'                  => 'Traktiĝi kiel aŭtomata procezo',
 'right-nominornewtalk'       => 'Ne kaŭzi etajn redaktojn en diskuto-paĝoj sproni la inviton por novaj mesaĝoj',
-'right-apihighlimits'        => 'Utiligu altajn limojn por API informmendoj',
-'right-writeapi'             => 'Uzo de la API por modifi la vikion',
-'right-delete'               => 'Forigu paĝojn',
-'right-bigdelete'            => 'Forigu paĝojn kun grandaj historioj',
-'right-deleterevision'       => 'Forigu kaj restarigu specifajn reviziojn de paĝoj',
-'right-deletedhistory'       => 'Rigardu listerojn de forigitaj historioj, sen ties asociaj tekstoj',
-'right-browsearchive'        => 'Serĉu forigitajn paĝojn',
-'right-undelete'             => 'Restarigu paĝon',
-'right-suppressrevision'     => 'Kontrolu kaj restarigu reviziojn kaŝitajn de administrantoj',
-'right-suppressionlog'       => 'Rigardu privatajn loglibrojn',
+'right-apihighlimits'        => 'Utiligu pli altajn limojn por API informmendoj',
+'right-writeapi'             => 'Uzi la API por modifi la vikion',
+'right-delete'               => 'Forigi paĝojn',
+'right-bigdelete'            => 'Forigi paĝojn kun grandaj historioj',
+'right-deleterevision'       => 'Forigi kaj restarigi specifajn reviziojn de paĝoj',
+'right-deletedhistory'       => 'Rigardi listanojn de forigitaj historioj, sen ties asociaj tekstoj',
+'right-browsearchive'        => 'Serĉi forigitajn paĝojn',
+'right-undelete'             => 'Restarigi paĝon',
+'right-suppressrevision'     => 'Kontroli kaj restarigi reviziojn kaŝitajn de administrantoj',
+'right-suppressionlog'       => 'Vidi privatajn protokolojn',
 'right-block'                => 'Forbaru aliajn uzantoj por redaktado',
 'right-blockemail'           => 'Forbaru uzanton de retpoŝta sendado',
 'right-hideuser'             => 'Forbaru salutnomon, kaŝante ĝin de la publiko',
 'right-ipblock-exempt'       => 'Preterpasu IP-forbarojn, aŭtomatajn forbarojn, kaj ĝeneralajn forbarojn',
 'right-proxyunbannable'      => 'Preterpasu aŭtomatajn forbarojn de prokuriloj',
-'right-protect'              => 'Ŝanĝu protektniveloj kaj redaktu protektitajn paĝojn',
-'right-editprotected'        => 'Redaktu protektitajn paĝojn (sen kaskada protestado)',
-'right-editinterface'        => 'Redaktu la uzanto-interfacon',
+'right-protect'              => 'Ŝanĝi protektniveloj kaj redakti protektitajn paĝojn',
+'right-editprotected'        => 'Redakti protektitajn paĝojn (sen kaskada protektado)',
+'right-editinterface'        => 'Redakti la uzulan interfacon',
 'right-editusercssjs'        => 'Redaktu CSS- kaj JS-dosierojn de aliaj uzantoj',
 'right-rollback'             => 'Tuj restarigu la lastan uzanton kiu redaktis specifan paĝon',
 'right-markbotedits'         => 'Marku restarigitajn redaktojn kiel robotajn redaktojn',
 'right-noratelimit'          => 'Ne influita de po-limoj',
-'right-import'               => 'Importu paĝojn de aliaj vikioj',
+'right-import'               => 'Importi paĝojn de aliaj vikioj',
 'right-importupload'         => 'Importu paĝojn de dosiera alŝuto',
 'right-patrol'               => 'Marku redaktojn kiel patrolitajn',
 'right-autopatrol'           => 'Faru redaktojn aŭtomate markitajn kiel patrolitajn',
 'right-patrolmarks'          => 'Rigardi patrolmarkojn de lastaj ŝanĝoj',
-'right-unwatchedpages'       => 'Vidu la liston de nepriatentitaj paĝoj',
+'right-unwatchedpages'       => 'Vidi la liston de nepriatentitaj paĝoj',
 'right-trackback'            => 'Enigu retrovojon',
 'right-mergehistory'         => 'Kunfandigu la historiojn de paĝoj',
 'right-userrights'           => 'Redaktu ĉiujn uzanto-rajtojn',
 'right-userrights-interwiki' => 'Redaktu la rajtojn de uzantoj en aliaj vikioj',
-'right-siteadmin'            => 'Ŝlosu kaj malŝlosu la datumbazo',
+'right-siteadmin'            => 'Ŝlosi kaj malŝlosi la datumbazon',
 
 # User rights log
 'rightslog'      => 'Protokolo de uzanto-rajtoj',
@@ -1061,7 +1062,7 @@
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|ŝanĝo|ŝanĝoj}}',
 'recentchanges'                     => 'Lastaj ŝanĝoj',
-'recentchangestext'                 => 'Sekvu la plej lastajn ŝanĝojn en la {{SITENAME}} per ĉi tiu paĝo.',
+'recentchangestext'                 => 'Sekvi la plej lastajn ŝanĝojn en la {{SITENAME}} per ĉi tiu paĝo.',
 'recentchanges-feed-description'    => 'Sekvi la plej lastatempajn ŝanĝojn al la vikio en ĉi tiu fonto.',
 'rcnote'                            => "Jen la {{PLURAL:$1|lasta '''1''' ŝanĝo|lastaj '''$1''' ŝanĝoj}} dum la {{PLURAL:$2|lasta tago|lastaj '''$2''' tagoj}}, ekde $5, $4.",
 'rcnotefrom'                        => "Jen la ŝanĝoj ekde '''$2''' (lastaj ĝis '''$1''').",
@@ -1097,21 +1098,21 @@
 # Upload
 'upload'                      => 'Alŝuti dosieron',
 'uploadbtn'                   => 'Alŝuti dosieron',
-'reupload'                    => 'Realŝutu',
-'reuploaddesc'                => 'Revenu al la alŝuta formularo.',
+'reupload'                    => 'Realŝuti',
+'reuploaddesc'                => 'Reveni al la alŝuta formularo.',
 'uploadnologin'               => 'Ne ensalutinta',
-'uploadnologintext'           => 'Se vi volas alŝuti dosierojn, vi devas [[Special:Userlogin|ensaluti]].',
+'uploadnologintext'           => 'Se vi volas alŝuti dosierojn, vi devas [[Special:UserLogin|ensaluti]].',
 'upload_directory_missing'    => 'La alŝuta dosierujo ($1) estas nek trovebla nek kreebla de la retservilo.',
 'upload_directory_read_only'  => 'La TTT-servilo ne povas alskribi la alŝuto-dosierujon ($1).',
 'uploaderror'                 => 'Eraro okazis dum alŝuto',
 'uploadtext'                  => "Uzu la jenan formon por alŝuti dosierojn.
-Okulumi aux serĉi antaŭe alŝutitajn bildojn, iru la [[Special:Imagelist|Listo de alŝutitaj dosieroj]]. Alŝutaĵoj ankaŭ estas registrita en la [[Special:Log/upload|Loglibro de alŝutoj]].
+Vidi aux serĉi antaŭe alŝutitajn bildojn, iru la [[Special:ImageList|Listo de alŝutitaj dosieroj]]; (re)alŝutaĵoj ankaŭ estas registrita en la [[Special:Log/upload|Protokolo de alŝutoj]], forigoj en la [[Special:Log/delete|protokolo de forigoj]].
 
 Por inkluzivi la dosieron en pagxon, skribu ligilon laŭ la formoj
 
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bildo.jpg]]</nowiki>''' aŭ
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bildo.png|teksto por retumiloj negrafikaj]]</nowiki>''' aŭ
-* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Dosiero.ogg]]</nowiki>''' por ligi rekte al la dosiero.",
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bildo.jpg]]</nowiki>''' por uzi la plena versio de la dosiero
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bildo.png|200px|thumb|left|alternativa teksto]]</nowiki>''' por uzi 200-rastrumera versio en kesto al la maldekstro (\"left\") kun \"alternativa teksto\" kiel la priskribo.
+* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Dosiero.ogg]]</nowiki>''' por ligi rekte al la dosiero ne montranta la dosieron.",
 'upload-permitted'            => 'Permesitaj dosiertipoj: $1.',
 'upload-preferred'            => 'Preferitaj dosiertipoj: $1.',
 'upload-prohibited'           => 'Malpermesitaj dosiero-tipoj: $1.',
@@ -1125,7 +1126,7 @@
 'filestatus'                  => 'Kopirajta statuso:',
 'filesource'                  => 'Fonto:',
 'uploadedfiles'               => 'Alŝutitaj dosieroj',
-'ignorewarning'               => 'Ignoru averton kaj konservu dosieron ĉiukaze',
+'ignorewarning'               => 'Ignori averton kaj konservi dosieron ĉiukaze',
 'ignorewarnings'              => 'Ignori ĉiajn avertojn',
 'minlength1'                  => 'Nomoj de dosieroj nepre havas almenaŭ unu literon.',
 'illegalfilename'             => 'La dosiernomo $1 entenas karaktrojn kiuj ne estas permesitaj en paĝaj titoloj. Bonvolu renomi la dosieron kaj provu denove alŝuti ĝin.',
@@ -1175,9 +1176,11 @@
 'upload-proto-error'      => 'Nevalida protokolo',
 'upload-proto-error-text' => 'Fora alŝuto devas URL-on komence de <code>http://</code> aŭ <code>ftp://</code>.',
 'upload-file-error'       => 'Interna eraro',
-'upload-file-error-text'  => 'Interna eraro okazis provante krei labordosieron ĉe la servilo. Bonvolu kontakti sistem-administranton.',
+'upload-file-error-text'  => 'Interna eraro okazis provante krei labordosieron ĉe la servilo. Bonvolu kontakti [[Special:ListUsers/sysop|sistem-administranton]].',
 'upload-misc-error'       => 'Nekonata eraro pri alŝutado.',
-'upload-misc-error-text'  => 'Nekonata eraro okazis dum la alŝuto. Bonvolu kontroli ke la URL-o estas valida kaj atingebla tiam reprovu. Se la problemo kontinuas, kontaku sisteman administranton.',
+'upload-misc-error-text'  => 'Nekonata eraro okazis dum la alŝuto. 
+Bonvolu kontroli ke la URL-o estas valida kaj atingebla tiam reprovu. 
+Se la problemo kontinuas, kontaku [[Special:ListUsers/sysop|sisteman administranton]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL-o ne estis atingebla',
@@ -1191,7 +1194,7 @@
 'upload_source_url'  => ' (valida, publike atingebla URL-o)',
 'upload_source_file' => ' (dosiero en via komputilo)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ĉi tiu speciala paĝo montras ĉiujn alŝutitajn dosierojn.
 Defaŭlte, la lasta alŝutitaj dosieroj estas montrataj supren.
 Klaku la kolumnan titolon por ŝanĝi la direkton de ordigo.',
@@ -1219,7 +1222,7 @@
 'imagelinks'                     => 'Ligiloj al la dosiero',
 'linkstoimage'                   => 'La {{PLURAL:$1|jena paĝo|jenaj paĝoj}} ligas al ĉi tiu dosiero:',
 'nolinkstoimage'                 => 'Neniu paĝo ligas al ĉi tiu dosiero.',
-'morelinkstoimage'               => 'Rigardi [[Special:Whatlinkshere/$1|pliajn ligilojn]] al ĉi tiu dosiero.',
+'morelinkstoimage'               => 'Rigardi [[Special:WhatLinksHere/$1|pliajn ligilojn]] al ĉi tiu dosiero.',
 'redirectstofile'                => 'Jen {{PLURAL:$1|dosiero liganta|dosieroj ligantaj}} al ĉi tiu dosiero:',
 'duplicatesoffile'               => 'La {{PLURAL:$1|jena dosiero estas duplikato|jenaj dosieroj estas duplikatoj}} de ĉi tiu dosiero:',
 'sharedupload'                   => 'Ĉi tiu dosiero estas komunuma alŝuto kaj estas uzebla de aliaj projektoj.',
@@ -1238,18 +1241,18 @@
 # File reversion
 'filerevert'                => 'Restarigi $1',
 'filerevert-legend'         => 'Restarigu dosieron',
-'filerevert-intro'          => '<span class="plainlinks">Vi restarigas \'\'\'[[Media:$1|$1]]\'\'\' al la [$4 versio de $3, $2].</span>',
+'filerevert-intro'          => "Vi restarigas '''[[Media:$1|$1]]''' al la [$4 versio de $3, $2].",
 'filerevert-comment'        => 'Komento:',
 'filerevert-defaultcomment' => 'Restarigita al versio ekde $2, $1',
 'filerevert-submit'         => 'Restarigi',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' estis restarigita al [$4 versio ekde $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' estis restarigita al [$4 versio ekde $3, $2].",
 'filerevert-badversion'     => 'Ne estas antaŭa loka versio de ĉi dosiero ĉe tiu tempo.',
 
 # File deletion
 'filedelete'                  => 'Forigi $1',
 'filedelete-legend'           => 'Forigi dosieron.',
 'filedelete-intro'            => "Vi forigas '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Vi forigas version de \'\'\'[[Media:$1|$1]]\'\'\' ekde [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Vi forigas version de '''[[Media:$1|$1]]''' ekde [$4 $3, $2].",
 'filedelete-comment'          => 'Kialo por forigo:',
 'filedelete-submit'           => 'Forigi',
 'filedelete-success'          => "'''$1''' estas forigita.",
@@ -1262,7 +1265,7 @@
 'filedelete-reason-dropdown'  => '* Oftaj kialoj de forigo
 ** Malobservo de kopirajto
 ** Duplikata dosiero',
-'filedelete-edit-reasonlist'  => 'Redaktu kialojn de forigo',
+'filedelete-edit-reasonlist'  => 'Redakti kialojn por forigo',
 
 # MIME search
 'mimesearch'         => 'MIME-serĉilo',
@@ -1278,7 +1281,8 @@
 
 # Unused templates
 'unusedtemplates'     => 'Neuzitaj ŝablonoj',
-'unusedtemplatestext' => 'Ĉi paĝo listigas ĉiujn paĝojn en la nomspaco "Ŝablono" kiuj ne estas enmetitaj en alia paĝo. Bonvolu kontroli aliajn ligilojn al la ŝablonoj antaŭ ol forigi ilin.',
+'unusedtemplatestext' => 'Ĉi tiu paĝo listas ĉiujn paĝojn en la nomspaco "Ŝablono" kiuj ne estas enmetitaj en alia paĝo. 
+Bonvolu kontroli aliajn ligilojn al la ŝablonoj antaŭ ol forigi ilin.',
 'unusedtemplateswlh'  => 'aliaj ligiloj',
 
 # Random page
@@ -1302,7 +1306,7 @@
 Tio estas meznombre po unu paĝo por '''\$5''' paĝoj viditaj, kaj por '''\$6''' redaktoj.
 
 La nuna longeco de la [http://www.mediawiki.org/wiki/Manual:Job_queue laborenda vico] estas '''\$7'''.",
-'userstatstext'          => "Enskribiĝis '''$1''' {{PLURAL:$1|[[Special:Listusers|uzanto]]|[[Special:Listusers|uzantoj]]}}. El tiuj, '''$2''' (aŭ '''$4%''') havas rajtojn de $5.",
+'userstatstext'          => "Enskribiĝis '''$1''' {{PLURAL:$1|[[Special:ListUsers|uzanto]]|[[Special:ListUsers|uzantoj]]}}. El tiuj, '''$2''' (aŭ '''$4%''') havas rajtojn de $5.",
 'statistics-mostpopular' => 'Plej ofte montrataj paĝoj',
 
 'disambiguations'      => 'Misligitaj apartigiloj',
@@ -1311,9 +1315,11 @@
 Ili devus anstataŭe alligi la ĝustan temon.<br />
 Paĝo estas traktata kiel apartigilo se ĝi uzas ŝablonon kiu estas ligita de [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Duoblaj alidirektadoj',
-'doubleredirectstext' => '<b>Atentu:</b> Eblas, ke la jena listo enhavas falsajn rezultojn. Ĝenerale, tio signifas, ke estas plua teksto kun ligiloj post la #REDIRECT.<br />
+'doubleredirects'            => 'Duoblaj alidirektadoj',
+'doubleredirectstext'        => '<b>Atentu:</b> Eblas, ke la jena listo enhavas falsajn rezultojn. Ĝenerale, tio signifas, ke estas plua teksto kun ligiloj post la #REDIRECT.<br />
 Ĉiu linio montras ligilojn ĉe la unua kaj dua alidirektadoj, kaj la unua linio de la teksto de la dua alidirektado, kiu ĝenerale montras la "veran" artikolon, kiu devus celi la unuan alidirektadon.',
+'double-redirect-fixed-move' => '[[$1]] estis alinomita; ĝi nun alidirektas al [[$2]]',
+'double-redirect-fixer'      => 'Alidirektila riparilo',
 
 'brokenredirects'        => 'Rompitaj alidirektadoj',
 'brokenredirectstext'    => 'La jenaj alidirektadoj ligas al neekzistantaj artikoloj.',
@@ -1331,7 +1337,7 @@
 'nbytes'                  => '$1 {{PLURAL:$1|bitoko|bitokoj}}',
 'ncategories'             => '{{PLURAL:$1|unu kategorio|$1 kategorioj}}',
 'nlinks'                  => '$1 {{PLURAL:$1|ligilo|ligiloj}}',
-'nmembers'                => '{{PLURAL:$1|unu membero|$1 memberoj}}',
+'nmembers'                => '{{PLURAL:$1|unu membro|$1 membroj}}',
 'nrevisions'              => '$1 {{PLURAL:$1|revizio|revizioj}}',
 'nviews'                  => '{{PLURAL:$1|unufoje|$1 fojojn}}',
 'specialpage-empty'       => 'Ne estas rezultoj por ĉi tiu raporto.',
@@ -1385,7 +1391,7 @@
 
 # Book sources
 'booksources'               => 'Libroservoj',
-'booksources-search-legend' => 'Serĉu pri librofontoj',
+'booksources-search-legend' => 'Serĉi librofontojn',
 'booksources-go'            => 'Ek',
 'booksources-text'          => 'Jen ligilaro al aliaj TTT-ejoj, kiuj vendas librojn,
 kaj/aŭ informumos pri la libro ligita.
@@ -1403,7 +1409,7 @@
 'logempty'             => 'Neniaj artikoloj en la loglibro.',
 'log-title-wildcard'   => 'Serĉu titolojn komencantajn kun ĉi teksto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Ĉiuj paĝoj',
 'alphaindexline'    => '$1 ĝis $2',
 'nextpage'          => 'Sekvanta paĝo ($1)',
@@ -1423,18 +1429,18 @@
 'categories'                    => 'Kategorioj',
 'categoriespagetext'            => 'La sekvantaj kategorioj ekzistas jam en la vikio.',
 'categoriesfrom'                => 'Montri kategoriojn komencante de:',
-'special-categories-sort-count' => 'oridigu laŭ nombrado',
-'special-categories-sort-abc'   => 'ordigu alfabete',
+'special-categories-sort-count' => 'oridigi laŭ nombrado',
+'special-categories-sort-abc'   => 'ordigi laŭ alfabeto',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Montru uzantojn ekde:',
 'listusers-submit'   => 'Montri',
 'listusers-noresult' => 'Neniu uzanto trovita.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Gruprajtoj de uzantoj',
 'listgrouprights-summary'  => 'Jen listo de uzanto-grupoj difinitaj en ĉi tiu vikio, kun ties asociaj atingrajtoj.
-Aldona informo pri individuaj rajtoj estas trovebla [[{{MediaWiki:Listgrouprights-helppage}}|ĉi tie]].',
+Estas [[{{MediaWiki:Listgrouprights-helppage}}|aldona informo]] pri individuaj rajtoj.',
 'listgrouprights-group'    => 'Grupo',
 'listgrouprights-rights'   => 'Rajtoj',
 'listgrouprights-helppage' => 'Help:Grupaj rajtoj',
@@ -1442,10 +1448,11 @@
 
 # E-mail user
 'mailnologin'     => 'Neniu alsendota adreso',
-'mailnologintext' => 'Vi nepre estu [[Special:Userlogin|salutanta]] kaj havanta validan retpoŝtadreson en viaj [[Special:Preferences|preferoj]] por retpoŝti al aliaj uzantoj.',
+'mailnologintext' => 'Vi nepre estu [[Special:UserLogin|salutanta]] kaj havanta validan retpoŝtadreson en viaj [[Special:Preferences|preferoj]] por retpoŝti al aliaj uzantoj.',
 'emailuser'       => 'Retpoŝti ĉi tiun uzanton',
 'emailpage'       => 'Retpoŝti uzanton',
-'emailpagetext'   => 'Se la alsendota uzanto donis validan retpoŝtadreson en la preferoj, vi povas sendi unu mesaĝon per la jena formulo. La retpoŝtadreso, kiun vi metis en la preferoj, aperos kiel "El"-adreso de la poŝto, por ke la alsendonto povos respondi.',
+'emailpagetext'   => 'Se la alsendota uzanto donis validan retpoŝtadreson en la preferoj, vi povas sendi unu mesaĝon per la jena formulo. 
+La retpoŝtadreso, kiun vi metis en [[Special:Preferences|la preferoj]], aperos kiel "El"-adreso de la poŝto, por ke la alsendonto povos respondi.',
 'usermailererror' => 'Resendita retmesaĝa erarsubjekto:',
 'defemailsubject' => '{{SITENAME}} ****-retmesaĝo',
 'noemailtitle'    => 'Neniu retpoŝtadreso',
@@ -1466,11 +1473,11 @@
 'mywatchlist'          => 'Atentaro',
 'watchlistfor'         => '(por <b>$1</b>)',
 'nowatchlist'          => 'Vi ne jam elektis priatenti iun ajn paĝon.',
-'watchlistanontext'    => 'Bonvolu $1 okulumi aŭ redakti la anojn de via atentaro.',
+'watchlistanontext'    => 'Bonvolu $1 por vidi aŭ redakti erojn en via atentaro.',
 'watchnologin'         => 'Ne ensalutinta',
-'watchnologintext'     => 'Nepras [[Special:Userlogin|ensaluti]] por ŝanĝi vian atentaron.',
+'watchnologintext'     => 'Nepras [[Special:UserLogin|ensaluti]] por ŝanĝi vian atentaron.',
 'addedwatch'           => 'Aldonis al atentaro',
-'addedwatchtext'       => "La paĝo \"[[:\$1]]\" estis aldonita al via [[Special:Watchlist|atentaro]]. Estontaj ŝanĝoj de tiu ĉi paĝo aperos en '''grasa tiparo''' en la [[Special:Recentchanges|listo de Lastaj Ŝanĝoj]], kaj estos listigitaj en via atentaro. Se vi poste volos forigi la paĝon el via atentaro, alklaku \"Malatentu paĝon\" en la ilobreto.",
+'addedwatchtext'       => "La paĝo \"[[:\$1]]\" estis aldonita al via [[Special:Watchlist|atentaro]]. Estontaj ŝanĝoj de tiu ĉi paĝo aperos en '''grasa tiparo''' en la [[Special:RecentChanges|listo de Lastaj Ŝanĝoj]], kaj estos listigitaj en via atentaro. Se vi poste volos forigi la paĝon el via atentaro, alklaku \"Malatentu paĝon\" en la ilobreto.",
 'removedwatch'         => 'Forigis el atentaro',
 'removedwatchtext'     => 'La paĝo "[[:$1]]" estas forigita el via atentaro.',
 'watch'                => 'Atenti',
@@ -1497,13 +1504,13 @@
 'watchlist-hide-minor' => 'Kaŝi redaktetojn',
 
 # Displayed when you click the "watch" button and it is in the process of watching
-'watching'   => 'Atentante...',
+'watching'   => 'Aldonanta al la atentaro...',
 'unwatching' => 'Malatentante...',
 
 'enotif_mailer'                => 'Averta retmesaĝo de {{SITENAME}}',
 'enotif_reset'                 => 'Marku ĉiujn vizititajn paĝojn',
 'enotif_newpagetext'           => 'Tiu ĉi estas nova paĝo',
-'enotif_impersonal_salutation' => '{{SITENAME}}-uzanto',
+'enotif_impersonal_salutation' => 'Uzanto de {{SITENAME}}',
 'changed'                      => 'ŝanĝita',
 'created'                      => 'kreita',
 'enotif_subject'               => 'la paĝo $PAGETITLE de {{SITENAME}} estis $CHANGEDORCREATED de $PAGEEDITOR',
@@ -1512,15 +1519,15 @@
 'enotif_anon_editor'           => 'anonima uzanto $1',
 'enotif_body'                  => 'Kara $WATCHINGUSERNAME,
 
-la paĝo $PAGETITLE de {{SITENAME}} estis $CHANGEDORCREATED je $PAGEEDITDATE de $PAGEEDITOR, vidu {{fullurl:$PAGETITLE RAWURL}} por la nuna versio.
+La paĝo $PAGETITLE de {{SITENAME}} estis $CHANGEDORCREATED je $PAGEEDITDATE de $PAGEEDITOR, vidu $PAGETITLE_URL por la nuna versio.
 
 $NEWPAGE
 
-Redakta resumo : $PAGESUMMARY $PAGEMINOREDIT
+Redakta resumo: $PAGESUMMARY $PAGEMINOREDIT
 
 Kontaktu la redaktinton:
-retpoŝto {{fullurl:Special:Emailuser/$PAGEEDITOR RAWURL}}
-vikio {{fullurl:User:$PAGEEDITOR RAWURL}}
+retpoŝte: $PAGEEDITOR_EMAIL
+vikie: $PAGEEDITOR_WIKI
 
 Ne estos aliaj avertoj kaze de sekvaj ŝanĝoj krom se vi vizitas la paĝon. Vi povas ankaŭ malaktivigi la avertsignalon por ĉiuj priatentitaj paĝoj de via atentaro.
 
@@ -1528,9 +1535,9 @@
 
 --
 Por ŝanĝi la elektojn de via atentaro, bv viziti
-{{fullurl:Special:Watchlist/edit}}
+{{fullurl:{{ns:special}}:Watchlist/edit}}
 
-Reagoj kaj plia helpo :
+Reagoj kaj plia helpo:
 {{fullurl:{{MediaWiki:Helppage}}}}',
 
 # Delete/protect/revert
@@ -1569,7 +1576,9 @@
 'rollbacklink'                => 'restarigi antaŭan',
 'rollbackfailed'              => 'Restarigo malsukcesis',
 'cantrollback'                => 'Neeblas restarigi antaŭan redakton; la redaktinto lasta estas la sola de la paĝo.',
-'alreadyrolled'               => 'Ne eblas restarigi la lastan redakton de [[$1]] de la [[User:$2|$2]] ([[User talk:$2|diskuto]]) pro tio, ke oni intertempe redaktis la paĝon. La lasta redaktinto estas [[User:$3|$3]] ([[User talk:$3|diskuto]]).',
+'alreadyrolled'               => 'Ne eblas restarigi la lastan redakton de [[:$1]] de la [[User:$2|$2]] ([[User talk:$2|diskuto]]) | [[Special:Contributions/$2|{{int:contribslink}}]]);
+pro tio, ke oni intertempe redaktis aŭ restarigis la paĝon. 
+La lasta redaktinto estas [[User:$3|$3]] ([[User talk:$3|diskuto]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => "La komento estis: '<i>$1</i>'.", # only shown if there is an edit comment
 'revertpage'                  => 'Malfaris redaktojn de [[Special:Contributions/$2|$2]] ([[User talk:$2|diskuto]]) al la lasta versio de [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Restaris redaktojn de $1; ŝanĝis al lasta versio de $2.',
@@ -1578,32 +1587,32 @@
 Bonvolu alklalki la reirbutonon kaj reŝarĝi la paĝon el kiu vi venas, kaj provu denove.',
 'protectlogpage'              => 'Protokolo de protektoj',
 'protectlogtext'              => 'Sube estas listo de paĝ-ŝlosoj kaj malŝlosoj.
-Vidu [[Special:Protectedpages|liston de protektitaj paĝoj]] por pli da informoj.',
+Vidu [[Special:ProtectedPages|liston de protektitaj paĝoj]] por pli da informoj.',
 'protectedarticle'            => 'protektita [[$1]]',
 'modifiedarticleprotection'   => 'ŝanĝis nivelon de protekto por "[[$1]]"',
 'unprotectedarticle'          => 'malprotektita [[$1]]',
 'protect-title'               => 'Protektante "$1"',
 'protect-legend'              => 'Konfirmu protektadon',
-'protectcomment'              => 'Komento:',
+'protectcomment'              => 'Kialo por protekti:',
 'protectexpiry'               => 'Eksvalidiĝas:',
 'protect_expiry_invalid'      => 'Nevalida findaŭro.',
 'protect_expiry_old'          => 'Eksvalidiĝa tempo jam pasis.',
-'protect-unchain'             => 'Malŝlosi movpermesojn',
+'protect-unchain'             => 'Malŝlosi movrajtojn',
 'protect-text'                => 'Vi povas ĉi tie vidi kaj ŝanĝi la protektnivelon de la paĝo <strong><nowiki>$1</nowiki></strong>.',
 'protect-locked-blocked'      => 'Vi ne povas ŝanĝi prokekto-nivelojn dum forbarita. Jen la nunaj ecoj de la paĝo <strong>$1</strong>:',
 'protect-locked-dblock'       => 'Ne eblas ŝanĝi nivelojn de protekto pro aktiva datumbaza ŝloso.
 Jen la nunaj ecoj de la paĝo <strong>$1</strong>:',
-'protect-locked-access'       => 'Via konto ne havas permeson ŝanĝi protekto-nivelojn.
+'protect-locked-access'       => 'Via konto ne havas rajton ŝanĝi protekto-nivelojn.
 Jen la aktualaj valoroj por la paĝo <strong>$1</strong>:',
 'protect-cascadeon'           => 'Ĉi paĝo estas nun protektita kontraŭ redaktado ĉar gxi estas inkluzivita en {{PLURAL:$1|jena paĝo, kiu mem estas protektita|jenaj paĝoj, kiuj mem estas protektitaj}} kun kaskada protekto. Vi povas ŝanĝi ties protektnivelon, sed tio ne ŝanĝos la kaskadan protekton.',
 'protect-default'             => '(defaŭlte)',
-'protect-fallback'            => '"$1" permeso bezonata',
+'protect-fallback'            => 'Rajto "$1" nepras.',
 'protect-level-autoconfirmed' => 'Bloki neensalutintajn uzantojn',
 'protect-level-sysop'         => 'Nur administrantoj',
 'protect-summary-cascade'     => 'kaskada',
 'protect-expiring'            => 'finiĝas je $1 (UTC)',
 'protect-cascade'             => 'Protekti ĉiujn paĝojn inkluzivitajn en ĉi paĝo (kaskada protekto)',
-'protect-cantedit'            => 'Vi ne povas ŝanĝi la protekt-nivelojn de ĉi tiu paĝo, ĉar vi ne havas permeson redakti ĝin.',
+'protect-cantedit'            => 'Vi ne povas ŝanĝi la protekt-nivelojn de ĉi tiu paĝo, ĉar vi ne rajtas redakti ĝin.',
 'restriction-type'            => 'Permeso:',
 'restriction-level'           => 'Nivelo de limigo:',
 'minimum-size'                => 'Minimuma pezo',
@@ -1680,7 +1689,7 @@
 'month'         => 'Ekde monato (kaj pli frue):',
 'year'          => 'Ekde jaro (kaj pli frue):',
 
-'sp-contributions-newbies'     => 'Montru kontribuojn nur de novaj kontoj',
+'sp-contributions-newbies'     => 'Montri nur kontribuojn de novaj kontoj',
 'sp-contributions-newbies-sub' => 'Kontribuoj de novaj uzantoj. Forigitaj paĝoj ne estas montritaj.',
 'sp-contributions-blocklog'    => 'Protokolo de forbaroj',
 'sp-contributions-search'      => 'Serĉado de kontribuoj',
@@ -1689,7 +1698,7 @@
 
 # What links here
 'whatlinkshere'            => 'Ligiloj ĉi tien',
-'whatlinkshere-title'      => 'Paĝoj ligantaj al $1',
+'whatlinkshere-title'      => 'Paĝoj ligantaj al "$1"',
 'whatlinkshere-page'       => 'Paĝo:',
 'linklistsub'              => '(Listo de ligiloj)',
 'linkshere'                => "La jenaj paĝoj ligas al '''[[:$1]]''':",
@@ -1737,7 +1746,7 @@
 'ipbwatchuser'                    => 'Kontroli la paĝojn por uzanto kaj diskuto de ĉi tiu uzanto.',
 'badipaddress'                    => 'Neniu uzanto, aŭ la IP-adreso estas misformita.',
 'blockipsuccesssub'               => 'Oni sukcese forbaris la adreson/nomon.',
-'blockipsuccesstext'              => '"$1" estas forbarita. <br />Vidu la [[Special:Ipblocklist|liston de IP-forbaroj]].',
+'blockipsuccesstext'              => '"$1" estas forbarita. <br />Vidu la [[Special:IPBlockList|liston de IP-forbaroj]].',
 'ipb-edit-dropdown'               => 'Redakti kialojn por forbaro.',
 'ipb-unblock-addr'                => 'Restarigi $1',
 'ipb-unblock'                     => 'Malforbaru uzantnomon aŭ IP-adreson',
@@ -1749,7 +1758,7 @@
 'ipusubmit'                       => 'Malforbaru la adreson',
 'unblocked'                       => '[[User:$1|$1]] estas restarigita.',
 'unblocked-id'                    => 'Forbaro $1 estas forigita.',
-'ipblocklist'                     => 'Listo de forbaritaj IP-adresoj/nomoj',
+'ipblocklist'                     => 'Forbaritaj IP-adresoj kaj salutnomoj',
 'ipblocklist-legend'              => 'Trovu forbaritan uzanton.',
 'ipblocklist-username'            => 'Salutnomo aŭ IP-adreso:',
 'ipblocklist-submit'              => 'Serĉi',
@@ -1768,7 +1777,7 @@
 'autoblocker'                     => 'Provizore forbarita aŭtomate pro tio, ke vi uzas la saman IP-adreson kiel "$1", kiu estis forbarita pro : "$2".',
 'blocklogpage'                    => 'Protokolo de forbaroj',
 'blocklogentry'                   => 'forbaris [[$1]] por daŭro de $2 $3',
-'blocklogtext'                    => 'Ĉi tio estas loglibro pri forbaraj kaj malforbaraj agoj. Aŭtomate forbaritaj IP adresoj ne estas listigitaj. Vidu la [[Special:Ipblocklist|IP forbarliston]] por ĉi-momente fobaritaj uzantoj kaj IP-adresoj.',
+'blocklogtext'                    => 'Ĉi tio estas loglibro pri forbaraj kaj malforbaraj agoj. Aŭtomate forbaritaj IP adresoj ne estas listigitaj. Vidu la [[Special:IPBlockList|IP forbarliston]] por ĉi-momente fobaritaj uzantoj kaj IP-adresoj.',
 'unblocklogentry'                 => '$1 estis restarigita',
 'block-log-flags-anononly'        => 'nur anonimaj uzantoj',
 'block-log-flags-nocreate'        => 'kreado de kontoj malebligita',
@@ -1788,10 +1797,10 @@
 'proxyblockreason'                => 'Via IP-adreso estis forbarita ĉar ĝi estas malferma prokurilo. Bonvolu kontakti vian provizanto de retservo aŭ komputika helpisto kaj informu ilin de ĉi serioza problemo pri sekureco.',
 'proxyblocksuccess'               => 'Farita.',
 'sorbsreason'                     => 'Via IP-adreso estas listigita kiel malferma prokurilo en la DNSBL uzata de {{SITENAME}}.',
-'sorbs_create_account_reason'     => 'Via IP-adreso estas listigita kiel malferma prokurilo en la DNSBL uzata de {{SITENAME}}. Vi ne estas permesita krei konton.',
+'sorbs_create_account_reason'     => 'Via IP-adreso estas listigita kiel malferma prokurilo en la DNSBL uzata de {{SITENAME}}. Vi ne rajtas krei konton.',
 
 # Developer tools
-'lockdb'              => 'Ŝlosi datumaron',
+'lockdb'              => 'Ŝlosi datumbazon',
 'unlockdb'            => 'Malŝlosi datumaron',
 'lockdbtext'          => 'Se vi ŝlosos la datumaron, tio malebligos al ĉiuj uzantoj
 redakti paĝojn, ŝanĝi preferojn, priumi atentarojn, kaj fari diversajn aliajn
@@ -1804,7 +1813,7 @@
 Bonvolu certigu, ke vi efektive intencas tion fari.',
 'lockconfirm'         => 'Jes, mi vere volas ŝlosi la datumaron.',
 'unlockconfirm'       => 'Jes, mi vere volas malŝlosi la datumaron.',
-'lockbtn'             => 'Ŝlosi datumaron',
+'lockbtn'             => 'Ŝlosi datumbazon',
 'unlockbtn'           => 'Malŝlosi datumaron',
 'locknoconfirm'       => 'Vi ne konfirmis.',
 'lockdbsuccesssub'    => 'Datumaro ŝlosita',
@@ -1843,9 +1852,7 @@
 
 Tiujokaze, vi nepre permane kunigu la diskuto-paĝojn se vi tion deziras.",
 'movearticle'             => 'Alinomigi paĝon',
-'movenologin'             => 'Ne ensalutinta',
-'movenologintext'         => 'Vi nepre estu registrita uzanto kaj [[Special:Userlogin|ensalutu]] por rajti movi paĝojn.',
-'movenotallowed'          => 'Vi ne havas permeson movi paĝojn en {{SITENAME}}.',
+'movenotallowed'          => 'Vi ne rajtas movi paĝojn en {{SITENAME}}.',
 'newtitle'                => 'Al nova titolo',
 'move-watch'              => 'Atenti ĉi tiun paĝon',
 'movepagebtn'             => 'Alinomigi paĝon',
@@ -1874,7 +1881,7 @@
 'delete_and_move'         => 'Forigi kaj alinomigi',
 'delete_and_move_text'    => '==Forigo nepras==
 
-La celartikolo "[[$1]]" jam ekzistas. Ĉu vi volas forigi ĝin por krei spacon por la movo?',
+La celartikolo "[[:$1]]" jam ekzistas. Ĉu vi volas forigi ĝin por krei spacon por la movo?',
 'delete_and_move_confirm' => 'Jes, forigu la paĝon',
 'delete_and_move_reason'  => 'Forigita por ebligi movon',
 'selfmove'                => 'Font- kaj cel-titoloj samas; ne eblas movi paĝon sur ĝin mem.',
@@ -1882,6 +1889,7 @@
 'imagenocrossnamespace'   => 'Ne eblas movi dosieron al nedosiera nomspaco',
 'imagetypemismatch'       => 'La nova dosierfinaĵo ne kongruas ĝian dosiertipon.',
 'imageinvalidfilename'    => 'La cela dosiernomo estas nevalida',
+'fix-double-redirects'    => 'Ĝisdatigi iujn alidirektilojn kiuj direktas al la originala titolo',
 
 # Export
 'export'            => 'Eksporti paĝojn',
@@ -1975,7 +1983,7 @@
 'tooltip-ca-move'                 => 'Alinomigi tiun ĉi paĝon',
 'tooltip-ca-watch'                => 'Aldoni tiun ĉi paĝon al via atentaro',
 'tooltip-ca-unwatch'              => 'Forigi tiun ĉi paĝon el via atentaro',
-'tooltip-search'                  => 'Traserĉu ĉi tiun vikion',
+'tooltip-search'                  => 'Traserĉi {{SITENAME}}',
 'tooltip-search-go'               => 'Iru al paĝo kun ĉi preciza nomo se ĝi ekzistas',
 'tooltip-search-fulltext'         => 'Serĉi la paĝojn por ĉi tiu teksto',
 'tooltip-p-logo'                  => 'Ĉefpaĝo',
@@ -1988,16 +1996,16 @@
 'tooltip-t-whatlinkshere'         => 'Listo de ĉiuj vikiaj paĝoj kij ligas ĉi tien',
 'tooltip-t-recentchangeslinked'   => 'Lastaj ŝanĝoj en paĝoj kiuj ligas al tiu ĉi paĝo',
 'tooltip-feed-rss'                => 'RSS-fonto por tiu ĉi paĝo',
-'tooltip-feed-atom'               => 'Atom-fonto por ĉi paĝo',
+'tooltip-feed-atom'               => 'Atom-fonto por ĉi tiu paĝo',
 'tooltip-t-contributions'         => 'Rigardi la liston de kontribuoj de tiu ĉi uzanto',
 'tooltip-t-emailuser'             => 'Sendi retmesaĝon al tiu ĉi uzanto',
 'tooltip-t-upload'                => 'Alŝuti bildojn aŭ dosierojn',
 'tooltip-t-specialpages'          => 'Listo de ĉiuj specialaj paĝoj',
 'tooltip-t-print'                 => 'Printebla versio de ĉi paĝo',
 'tooltip-t-permalink'             => 'Konstanta ligilo al ĉi versio de la paĝo',
-'tooltip-ca-nstab-main'           => 'Vidu la artikolon',
-'tooltip-ca-nstab-user'           => 'Vidu la personan paĝon de la uzanto',
-'tooltip-ca-nstab-media'          => 'Vidu la paĝon de la dosiero',
+'tooltip-ca-nstab-main'           => 'Vidi la artikolon',
+'tooltip-ca-nstab-user'           => 'Vidi la personan paĝon de la uzanto',
+'tooltip-ca-nstab-media'          => 'Vidi la paĝon de la dosiero',
 'tooltip-ca-nstab-special'        => 'Estas speciala paĝo, vi ne rajtas redakti ĝin.',
 'tooltip-ca-nstab-project'        => 'Rigardi la paĝon de la projekto',
 'tooltip-ca-nstab-image'          => 'Rigardi la dosierpaĝon',
@@ -2008,11 +2016,11 @@
 'tooltip-minoredit'               => 'Marki tiun ŝanĝon kiel etan',
 'tooltip-save'                    => 'Konservi viajn ŝanĝojn',
 'tooltip-preview'                 => 'Antaŭrigardi viajn ŝanĝojn. Bonvolu uzi tion antaŭ ol konservi ilin!',
-'tooltip-diff'                    => 'Montru la ŝanĝojn kiujn vi faris de la teksto.',
+'tooltip-diff'                    => 'Montri la ŝanĝojn kiujn vi faris de la teksto.',
 'tooltip-compareselectedversions' => 'Rigardi la malsamojn inter ambaŭ selektitaj versioj de ĉi tiu paĝo.',
 'tooltip-watch'                   => 'Aldoni ĉi paĝon al via atentaro',
-'tooltip-recreate'                => 'Rekreu la paĝon malgraŭ ĝi estis forigita',
-'tooltip-upload'                  => 'Ekalŝutu',
+'tooltip-recreate'                => 'Rekrei la paĝon malgraŭ ĝi estis forigita',
+'tooltip-upload'                  => 'Ekalŝuti',
 
 # Metadata
 'nodublincore'      => 'Dublin Core RDF metadatumo estas malebligita por ĉi servilo.',
@@ -2062,12 +2070,13 @@
 'rcpatroldisabledtext'                => 'La funkcio patrolado de la lastaj ŝanĝoj estas nun malaktivigita.',
 'markedaspatrollederror'              => 'Ne povas marki kiel patrolitan',
 'markedaspatrollederrortext'          => 'Vi devas specifi revizion por marki kiel patrolitan.',
-'markedaspatrollederror-noautopatrol' => 'Vi ne estas permesita marki viajn proprajn ŝanĝojn kiel patrolitajn.',
+'markedaspatrollederror-noautopatrol' => 'Vi ne rajtas marki viajn proprajn ŝanĝojn kiel patrolitajn.',
 
 # Patrol log
-'patrol-log-page' => 'Loglibro pri patrolado',
-'patrol-log-line' => 'markis $1 el $2 patrolitajn $3',
-'patrol-log-auto' => '(aŭtomata)',
+'patrol-log-page'   => 'Loglibro pri patrolado',
+'patrol-log-header' => 'Jen protokolo de patrolitaj revizioj.',
+'patrol-log-line'   => 'markis $1 el $2 patrolitajn $3',
+'patrol-log-auto'   => '(aŭtomata)',
 
 # Image deletion
 'deletedrevision'                 => 'Forigita malnova versio $1',
@@ -2097,10 +2106,10 @@
 'show-big-image'       => 'Plena distingivo',
 'show-big-image-thumb' => '<small>Grandeco de ĉi antaŭvido: $1 × $2 rastrumeroj</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Aro da novaj bildoj',
 'imagelisttext'         => "Jen listo de '''$1''' {{PLURAL:$1|dosiero|dosieroj}}, ordigitaj laŭ $2.",
-'newimages-summary'     => 'Ĉi tiu paĝo montras la lastajn alŝutitajn dosierojn',
+'newimages-summary'     => 'Ĉi tiu speciala paĝo montras la lastajn alŝutitajn dosierojn.',
 'showhidebots'          => '($1 robotojn)',
 'noimages'              => 'Nenio videbla.',
 'ilsubmit'              => 'Serĉi',
@@ -2112,7 +2121,7 @@
 
 Nur listeroj (kun linio komence de steleto *) estas konsiderata.
 La komenca ligilo de linio devas esti ligilo al malbona bildo.
-Sekvaj ligilo en la sama linio estas konsiderata kiel esceptoj (paĝoj kiel la bildo estas permesita esti montrata.)',
+Sekvaj ligilo en la sama linio estas konsiderata kiel esceptoj (paĝoj kiel la bildo rajtas esti montrata.)',
 
 # Metadata
 'metadata'          => 'Metadatenoj',
@@ -2165,7 +2174,7 @@
 'exif-componentsconfiguration'     => 'Signifo de ĉiu kompono',
 'exif-compressedbitsperpixel'      => 'Reĝimo de bilda densigado',
 'exif-pixelydimension'             => 'Valida larĝeco de bildo',
-'exif-pixelxdimension'             => 'Valind image height',
+'exif-pixelxdimension'             => 'Valida alteco de bildo',
 'exif-makernote'                   => 'Notoj de fabrikejo',
 'exif-usercomment'                 => 'Komentoj de uzanto',
 'exif-relatedsoundfile'            => 'Rilata son-dosiero',
@@ -2381,7 +2390,7 @@
 
 # External editor support
 'edit-externally'      => 'Ŝanĝu ĉi dosieron per ekstera softvaro',
-'edit-externally-help' => "Vidu la [http://meta.wikimedia.org/wiki/Help:External_editors instalinstrukciojn] por pliaj informoj ''(angle)''.",
+'edit-externally-help' => "Vidu la [http://www.mediawiki.org/wiki/Manual:External_editors instalinstrukciojn] por pliaj informoj ''(angle)''.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ĉiuj',
@@ -2391,7 +2400,7 @@
 'monthsall'        => 'ĉiuj',
 
 # E-mail address confirmation
-'confirmemail'             => 'Konfirmu retpoŝtadreson',
+'confirmemail'             => 'Konfirmi retadreson',
 'confirmemail_noemail'     => 'Vi ne havas validan retpoŝtan adreson notitan en viaj [[Special:Preferences|Preferoj]].',
 'confirmemail_text'        => 'Ĉi tiu vikio postulas ke vi validigu vian retadreson antaŭ ol uzadi la retmesaĝpreferojn. Bonvolu alklaki la suban butonon por sendi konfirmesaĝon al via adreso. La mesaĝo entenos ligilon kun kodo; bonvolu alŝuti la ligilon en vian foliumilon por konfirmi ke via retadreso validas.',
 'confirmemail_pending'     => '<div class="error">Konfirma kodo estis jam repoŝtis al vi; se vi lastatempe kreis vian konton, vi eble volus atenti kelkajn minutojn por ĝi aliĝi antaŭ vi petus novan kodon.</div>',
@@ -2407,7 +2416,7 @@
 'confirmemail_success'     => 'Via retadreso estas konfirmita. Vi povas nun ensaluti kaj ĝui la vikion.',
 'confirmemail_loggedin'    => 'Via retadreso estas nun konfirmita.',
 'confirmemail_error'       => 'Io misokazis dum konservo de via konfirmo.',
-'confirmemail_subject'     => '{{SITENAME}} konfirmado de retadreso',
+'confirmemail_subject'     => 'Konfirmo de retadreso por {{SITENAME}}',
 'confirmemail_body'        => 'Iu, verŝajne vi, ĉe la IP-adreso $1, 
 enregistrigis konton "$2" ĉe {{SITENAME}} kun ĉi retadreso ĉe {{SITENAME}}.
 
@@ -2448,10 +2457,10 @@
 'recreate'            => 'Rekrei',
 
 # HTML dump
-'redirectingto' => 'Redirektante al [[$1]]...',
+'redirectingto' => 'Redirektante al [[:$1]]...',
 
 # action=purge
-'confirm_purge'        => 'Ĉu forviŝigu la kaŝmemoron de tiu ĉi paĝo?
+'confirm_purge'        => 'Ĉu forviŝigi la kaŝmemoron de tiu ĉi paĝo?
 
 $1',
 'confirm_purge_button' => 'Ek!',
@@ -2461,7 +2470,7 @@
 'searchnamed'      => "Serĉo de paĝoj nomataj ''$1''.",
 'articletitles'    => "Artikoloj komencante de ''$1''",
 'hideresults'      => 'Kaŝi rezultojn',
-'useajaxsearch'    => 'Uzu AJAX serĉon',
+'useajaxsearch'    => 'Uzi AJAX serĉon',
 
 # Multipage image navigation
 'imgmultipageprev' => '← antaŭa paĝo',
@@ -2493,8 +2502,8 @@
 'livepreview-error'   => 'Malsukcesis konekti: $1 "$2". Provu norman antaŭvidon.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Ŝanĝoj pli novaj ol $1 sekundoj eble ne estos montrataj en ĉi listo.',
-'lag-warn-high'   => 'Pro malrapideco de la servila datumbazo, ŝanĝoj pli novaj ol $1 sekundoj eble ne montriĝos en ĉi listo.',
+'lag-warn-normal' => 'Ŝanĝoj pli novaj ol $1 {{PLURAL:$1|sekundo|sekundoj}} eble ne estos montrataj en ĉi tiu listo.',
+'lag-warn-high'   => 'Pro malrapideco de la servila datumbazo, ŝanĝoj pli novaj ol $1 {{PLURAL:$1|sekundo|sekundoj}} eble ne montriĝos en ĉi tiu listo.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Via atentaro enhavas {{PLURAL:$1|1 titolon|$1 titolojn}}, escepte de diskuto-paĝoj.',
@@ -2511,7 +2520,7 @@
 'watchlistedit-raw-explain'    => 'Titoloj en via atentaro estas montrata sube, kaj povas esti redaktita de aldono aŭ forigo de la listo: unu titolo por linio. Kiam finite, klaku Ĝisdatigu Atentaron.
 Vi povas ankaŭ [[Special:Watchlist/edit|uzu la norman redaktilon]].',
 'watchlistedit-raw-titles'     => 'Titoloj:',
-'watchlistedit-raw-submit'     => 'Ĝisdatigu atentaron',
+'watchlistedit-raw-submit'     => 'Ĝisdatigi atentaron',
 'watchlistedit-raw-done'       => 'Via atentaro estas ĝisdatigita.',
 'watchlistedit-raw-added'      => '{{PLURAL:$1|1 titolo estis aldonita|$1 titoloj estis aldonitaj}}:',
 'watchlistedit-raw-removed'    => '{{PLURAL:$1|1 titolo estis forigita|$1 titoloj estis forigitaj}}:',
@@ -2545,8 +2554,8 @@
 'version-software-product'         => 'Produkto',
 'version-software-version'         => 'Versio',
 
-# Special:Filepath
-'filepath'         => 'Dosiera pado',
+# Special:FilePath
+'filepath'         => 'Vojo al dosiero',
 'filepath-page'    => 'Dosiero:',
 'filepath-submit'  => 'Pado',
 'filepath-summary' => 'Ĉi tiu speciala paĝo redonas la kompletan padon por dosiero. Bildoj estas montrataj en alta distingivo, aliaj dosieraj tipoj estas rekte startataj per ties asociita programo.',
@@ -2570,7 +2579,7 @@
 * <span class="mw-specialpagerestricted">Limigitaj specialaj paĝoj.</span>',
 'specialpages-group-maintenance' => 'Raportoj pri prizorgado',
 'specialpages-group-other'       => 'Aliaj specialaj paĝoj',
-'specialpages-group-login'       => 'Ensalutu / Kreu novan konton',
+'specialpages-group-login'       => 'Ensaluti / Krei novan konton',
 'specialpages-group-changes'     => 'Lastaj ŝanĝoj kaj loglibroj',
 'specialpages-group-media'       => 'Gazetaj raportoj kaj alŝutoj',
 'specialpages-group-users'       => 'Uzantoj kaj rajtoj',
@@ -2581,7 +2590,7 @@
 'specialpages-group-redirects'   => 'Alidirektantaj specialaj paĝoj',
 'specialpages-group-spam'        => 'Kontraŭspamiloj',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Malplena paĝo',
 'intentionallyblankpage' => 'Ĉi tiu paĝo intencie estas malplena kaj estas uzata por testado, ktp.',
 
Index: languages/messages/MessagesMi.php
===================================================================
--- languages/messages/MessagesMi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,6 +3,8 @@
  *
  * @ingroup Language
  * @file
+ *
+ * @author Kiharoa
  */
 
 $messages = array(
@@ -46,12 +48,15 @@
 'toolbox'          => 'Pouaka utauta',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'aboutsite'            => 'Mo {{SITENAME}}',
 'currentevents'        => 'Kōrero',
 'currentevents-url'    => 'Project:Kōrero',
 'mainpage'             => 'Hau Kāinga',
 'mainpage-description' => 'Hau Kāinga',
 'portal'               => 'Tomokanga hapori',
 'portal-url'           => 'Project:Tomokanga hapori',
+'privacy'              => 'Tikanga tūmataiti',
+'privacypage'          => 'Project:Tikanga tūmataiti',
 
 'toc'     => 'Rārangi kōrero',
 'showtoc' => 'whakakite',
@@ -90,7 +95,7 @@
 # Miscellaneous special pages
 'move' => 'Nekehia',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Ngā whārangi katoa',
 'allpagessubmit' => 'Haere',
 
Index: languages/messages/MessagesMdf.php
===================================================================
--- languages/messages/MessagesMdf.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMdf.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Khazar II
  * @author Kranch
  * @author Numulunj pilgae
- * @author Khazar II
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $fallbak = 'ru';
@@ -23,7 +20,7 @@
 'tog-extendwatchlist'         => 'Келептемс ванома сёрмалувомать сембе полафтоматнень няфтемга',
 'tog-usenewrc'                => 'Цебярьгофтф од илякстоптомат (JavaScript)',
 'tog-numberheadings'          => 'Сёрмадома коняксс лувомтяшксне эслек путовихть',
-'tog-showtoolbar'             => 'Кядьйонкс седяфксть няфтемс сёрмадомбачк (JavaScript)',
+'tog-showtoolbar'             => 'Кядьёнкс седяфксть няфтемс сёрмадомбачк (JavaScript)',
 'tog-editondblclick'          => 'Кафксть люпштазь сувамс сёрматфть петнема (JavaScript)',
 'tog-editsection'             => 'Няфтемс сюлмафксть [петемс] эрь пяльксонди',
 'tog-editsectiononrightclick' => 'Петнемс пялькстне: люпштамс сёрмадомбяльксть лемонц лангс видешире пуняса (JavaScript)',
@@ -44,9 +41,9 @@
 'tog-enotifrevealaddr'        => 'Штафтомс монь электрононь адресозе пачфтема сёрмаса',
 'tog-shownumberswatching'     => 'Няфтемс мъзяра сувайда конат арафтозь лопать эсь ванома сёрмалувомазост',
 'tog-fancysig'                => 'Казяма кядьтяшкст (эслек тиеви сюлмафксфтома)',
-'tog-externaleditor'          => 'Нолдамс тевс ушеширень петнить мъзярс илякс изь мярьгов (аньцек тевонь содайхненди, сяс мес эрявихть башка кядьйонкст-арафнемат содама машинаса)',
-'tog-externaldiff'            => 'Нолдамс тевс ушеширень програм верзиень ваксс путоманкса мъзярс илякс изь мярьгов (аньцек тевонь содайхненди, сяс мес эрявихть башка кядьйонкст-арафнемат содама машинаса)',
-'tog-showjumplinks'           => 'Мярьгомс "йупадемс" сатовома сюлмафкстненди',
+'tog-externaleditor'          => 'Нолдамс тевс ушеширень петнить мъзярс илякс изь мярьгов (аньцек тевонь содайхненди, сяс мес эрявихть башка кядьёнкст-арафнемат содама машинаса)',
+'tog-externaldiff'            => 'Нолдамс тевс ушеширень програм верзиень ваксс путоманкса мъзярс илякс изь мярьгов (аньцек тевонь содайхненди, сяс мес эрявихть башка кядьёнкст-арафнемат содама машинаса)',
+'tog-showjumplinks'           => 'Мярьгомс "юпадемс" сатовома сюлмафкстненди',
 'tog-uselivepreview'          => 'Максомс эряй васень няфтемась (JavaScript) (Варжамань)',
 'tog-forceeditsummary'        => 'Няфтемс мондине мезе сёрмадомс шава петнема вальмас сувамста',
 'tog-watchlisthideown'        => 'Кяшемс монь петнематне ванома лопаста',
@@ -69,27 +66,27 @@
 'wednesday'     => 'Вержи',
 'thursday'      => 'Шуваланя',
 'friday'        => 'Шумордамши (Пяденця)',
-'saturday'      => 'Йоткши',
+'saturday'      => 'Ёткши',
 'sun'           => 'Тр',
 'mon'           => 'Вд',
 'tue'           => 'Шв',
 'wed'           => 'Вр',
 'thu'           => 'Швл',
 'fri'           => 'Шм',
-'sat'           => 'Йот',
-'january'       => 'Йанварьгов',
+'sat'           => 'Ёт',
+'january'       => 'Январьгов',
 'february'      => 'Февральков',
 'march'         => 'Марков',
 'april'         => 'Апрельков',
 'may_long'      => 'Майгов',
-'june'          => 'Ийуньков',
-'july'          => 'Ийульков',
+'june'          => 'Июньков',
+'july'          => 'Июльков',
 'august'        => 'Августков',
 'september'     => 'Сентябрьков',
 'october'       => 'Октябрьков',
 'november'      => 'Ноябрьков',
 'december'      => 'Декабрьков',
-'january-gen'   => 'Йандварень',
+'january-gen'   => 'Январьговонь',
 'february-gen'  => 'Февральковонь',
 'march-gen'     => 'Марковонь',
 'april-gen'     => 'Апрельковонь',
@@ -101,7 +98,7 @@
 'october-gen'   => 'Октябрьковонь',
 'november-gen'  => 'Ноябрьковонь',
 'december-gen'  => 'Декабрьковонь',
-'jan'           => 'Йан',
+'jan'           => 'Янв',
 'feb'           => 'Фев',
 'mar'           => 'Мар',
 'apr'           => 'Апр',
@@ -191,12 +188,12 @@
 'talkpage'          => 'Корхтамс тя лопать колга',
 'talkpagelinktext'  => 'Корхтама',
 'specialpage'       => 'Башка тевонь лопа',
-'personaltools'     => 'Эсь кядьйонкст',
+'personaltools'     => 'Эсь кядьёнкст',
 'postcomment'       => 'Кучемс арьсемат',
 'articlepage'       => 'Ваномс потмакслопать',
 'talk'              => 'Корхнема',
 'views'             => 'Ванфт',
-'toolbox'           => 'Кядьйонкс кярькс',
+'toolbox'           => 'Кядьёнкс кярькс',
 'userpage'          => 'Ваномс тиить лопанц',
 'projectpage'       => 'Ваномс проектть лопанц',
 'imagepage'         => 'Ваномс медиа лопать',
@@ -206,12 +203,12 @@
 'categorypage'      => 'Ваномс категориень лопать',
 'viewtalkpage'      => 'Ваномс корхнемат',
 'otherlanguages'    => 'Иля кяльса',
-'redirectedfrom'    => '(Йотафтф $1-ста)',
+'redirectedfrom'    => '(Ётафтф $1-ста)',
 'redirectpagesub'   => 'Иля вастс йотафтф лопа',
 'lastmodifiedat'    => 'Тя лопать мекольцеда петнезь $2, $1.', # $1 date, $2 time
 'viewcount'         => 'Тя лопас сувасть {{PLURAL:$1|весть|$1-ксть}}.',
 'protectedpage'     => 'Тя лопать аралаф',
-'jumpto'            => 'Йупадемс тязк:',
+'jumpto'            => 'Юпадемс тязк:',
 'jumptonavigation'  => 'навигацие',
 'jumptosearch'      => 'вешендема',
 
@@ -292,7 +289,7 @@
 'nosuchspecialpage' => 'Стама башка лопа аш',
 'nospecialpagetext' => "<big>'''Аш стама башка лопа.'''</big>
 
-Ванк [[Special:Specialpages|{{int:specialpages}}]].",
+Ванк [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Эльбятькс',
@@ -323,7 +320,7 @@
 Тя сидеста лиси мъзярда молят сирелготф верзиева эли историянь сюлмафксова, кона вяти нардаф лопас.
 
 Лисендяряй аф тяфта, тонь програмкярькссот, улема, эвондась си (эльбятькс).
-Пачфтть тянь колга системонь вятиксонди, URL адресть тяштезь.',
+Пачфтть тянь колга [[Special:ListUsers/sysop|системонь вятиксонди]] URL адресть тяштезь.',
 'missingarticle-rev'   => '(верзие#: $1)',
 'missingarticle-diff'  => '(Верзиенза: $1, $2)',
 'readonly_lag'         => 'Датабазась эслек пякстась мъзярс кядяла датабаза серверхт сотни прясерверть мархта',
@@ -373,10 +370,10 @@
 # Login and logout pages
 'logouttitle'                => 'Тиить лисема',
 'logouttext'                 => '<strong>Тон лисеть.</strong><br />
-Тондейть ули кода ащемс {{SITENAME}}-са апак содак эли сувак тага весть кода сяка эли иля тиись. Кой-кона лопатне илядсть стамкс кодамкс синь ульсть тонь лисемада инголе мъзярс тонь интернет поладксце изь аруяфтов эслек ванфневи файлхнень эзда.',
+Тондейть ули кода ащемс {{SITENAME}}са апак содак эли [[Special:UserLogin|сувак тага весть]] кода сяка эли иля тиись. Кой-кона лопатне илядсть стамкс кодамкс синь ульсть тонь лисемада инголе мъзярс тонь интернет поладксце изь аруяфтов эсь ванфневи файлхнень эзда.',
 'welcomecreation'            => '== Сувак, $1! ==
 
-Тонь сёрматфтомаце анок. Тят йукста полафнемс эсь {{SITENAME}} арафнематне.',
+Тонь сёрматфтомаце анок. Тят юкста полафнемс эсь [[Special:Preferences|{{SITENAME}} латцематне]].',
 'loginpagetitle'             => 'Тиить сувама лемоц',
 'yourname'                   => 'Тиить лемоц:',
 'yourpassword'               => 'Сувама валце:',
@@ -387,7 +384,7 @@
 'loginproblem'               => '<b>Тиись аф содаф.</b><br />',
 'login'                      => 'Сувама',
 'nav-login-createaccount'    => 'Сувама / сёрматфтома',
-'loginprompt'                => '{{SITENAME}}-с сувамда инголе тондейть эряви нолдамс тевс cookies.',
+'loginprompt'                => 'Тондейть эряви нолдамс тевс cookies {{SITENAME}}с суваманди.',
 'userlogin'                  => 'Сувама / сёрматфтома',
 'logout'                     => 'Лисема',
 'userlogout'                 => 'Лисема',
@@ -503,40 +500,40 @@
 'summary-preview'                  => 'Нюрьхкяня лихтемать сядынголень  няфтема',
 'subject-preview'                  => 'Тема/конякс сядынгольдень няфтема',
 'blockedtitle'                     => 'Тиить сёлгозь',
-'blockedtext'                      => "<big>'''Тонь тиить лемонц эли IP адресцень сёлгозь.'''</big>
+'blockedtext'                      => '\'\'\'Тонь тиить лемцень эли IP адресцень сёлгозь.\'\'\'</big>
 
-$1 тонь сёлгозе. Туфталсь ''$2''.
+Тонь сёлгозе $1. 
+Туфталсь \'\'$2\'\'.
 
-* Сёлгозь: $8
+* Сёлгомать ушеткссь: $8
 * Сёлгомать валхтсазь: $6
 * Сёлкфсь: $7
 
-Тондейть ули кода корхтамс $1 мархта эли иля [[{{MediaWiki:Grouppage-sysop}}|оцюня]] сёлгомать колга.
-Тондейть аш кода кучемс сёрма оцюнянди мъзярс тонь электрононь адресце изь кемокста тонь [[Special:Preferences|тиить арафнемасонза]] эли тондейть изь мярьгов кучемс сёрмат сёлгома пингста.
-Тонь IP адресце тяни $3, сёлгомать ID #$5. Сувафтт фкя эли кафцьке тонь вешфксот.",
-'autoblockedtext'                  => "Тонь IP адресце эсезонза сёлговсь сяс мес тя адреста сувась иля тиись, конань $1 сёлкфтозе.
+Тондейть ули кода корхтамс $1 мархта эли иля [[{{MediaWiki:Grouppage-sysop}}|системонь вятикс]] сёлгомать колга.
+Тондейть аш кода нолдамс тевс "кучт электрононь сёрма тя тиинди" функциесь мъзярс тонь электрононь адресце изь кемокста тонь [[Special:Preferences|тиить латцемасонза]] эли тондейть изь мярьгов кучемс сёрмат сёлгома пингста.
+Тонь IP адресце тяни $3, сёлгомать ID #$5. 
+Сувафтт ся анциянятне эрь кодама тонь вешфксот.',
+'autoblockedtext'                  => 'Тонь IP адресце эсезонза сёлговсь сяс мес тя адреста сувась иля тиись, конань $1 сёлкфтозе.
 Туфталсь:
 
-:''$2''
+:\'\'$2\'\'
 
-* Сёлгозь: $8
+* Сёлгомать ушеткссь: $8
 * Сёлгомать валхтсазь: $6
+* Сёлкфсь: $7
 
-Тондейть ули кода корхтамс $1 эли иля
-[[{{MediaWiki:Grouppage-sysop}}|оцюня]] мархта сёлгомать колга.
 
-Тят йукста тондейть аш кода кучемс сёрма оцюнянди мъзярс тон изеть кемокста эсь электрононь адресцень тонь [[Special:Preferences|тиить арафнемасонза]] эли тондейть изь мярьгов кучемс сёрмат сёлгома пингста.
+Тондейть ули кода корхтамс $1 эли иля [[{{MediaWiki:Grouppage-sysop}}|системонь вятикс]] мархта сёлгомать колга.
 
-Тонь сёлгофтомать ID $5. Сувафтк тя ID тонь вешфксот.",
+Тят юкста тондейть аш кода нодамс тевс "кучт электрононь сёрма тя тиинди" функциесь мъзярс тон изеть кемокста эсь электрононь адресцень тонь [[Special:Preferences|тиить латцемасонза]] эли тондейть изь мярьгов кучемс сёрмат сёлгома пингста.
+
+Тонь ID тяни $5, сёлгомать ID #$5. 
+Сувафтт ся анцяйнятне эрь кодама тонь вешфксот.',
 'blockednoreason'                  => 'туфтал апак макст',
 'blockedoriginalsource'            => "Ванк '''$1'''-ть лисьмоц ала:",
 'blockededitsource'                => "'''$1''' лопанди '''тонь петнематнень''' текстсна ала:",
-'whitelistedittitle'               => 'Эряви сувама лемсь петнема тиеманкса',
+'whitelistedittitle'               => 'Петнема тиеманди эряви сувама лемсь',
 'whitelistedittext'                => 'Лопань петнеманкса эряви $1.',
-'whitelistreadtitle'               => 'Эряви сувама лемсь тянь морафтоманкса',
-'whitelistreadtext'                => 'Тондейть эряви [[Special:Userlogin|сёрматфтомс]] лопатнень морафтоманкса.',
-'whitelistacctitle'                => 'Тондейть аф мярьгови сёрматфтомс',
-'whitelistacctext'                 => '{{SITENAME}}-са сёрматфтомась тиеманкса эряви [[Special:Userlogin|сёрматфтомс]] эди сявомс мярьгомась.',
 'confirmedittitle'                 => 'Эряви электрононь адресть кемокстама лопань петнеманкса',
 'confirmedittext'                  => 'Тондейть эряви кемокстамс тонь электрононь адресцень лопань петнемада инголе. Эняльттяма, путт эди кемокстак тонь электрононь адресце тонь [[Special:Preferences|тиить арафнематне|тиить арафнематнень]] вельде.',
 'nosuchsectiontitle'               => 'Аш стама секцие',
@@ -551,7 +548,9 @@
 Сёрматк паксяв алу тя лопать тиеманкса
 (ванк [[{{MediaWiki:Helppage}}|лезкс лопа]] лездама информациенкса).
 Саньдярять тяза эльбядезь, люпштак пунять '''меки''' тонь интернет поладксонь вальмасонза.",
-'anontalkpagetext'                 => "----''Тя корхтама лопать тизе лемфтома тиись кона нинге аф сёрматфтф эли кона эсь сёрматфтомас аф кунци. Тяса минь нолдамс сонь лувомтяшкснень IP адресонц тиить содафтоманкса. Тя IP адресть вельде ули кода сашендомс иля тиихненди. Уляндяряйхть иля тиинь мяльполадксонза конатнень аф видекста лувозь тоннекс, тондейть пароль [[Special:Userlogin|сёрматфтомс эли сувамс]] сай пингста иля лемфтома тиихнень марс аф шовореманкса.''",
+'anontalkpagetext'                 => "----''Тя корхтама лопать тизе лемфтома тиись кона нинге аф сёрматфтф эли кона эсь сёрматфтомас аф кунци. Тяса минь нолдамс сонь лувомтяшкснень IP адресонц тиить содафтоманкса. 
+Тя IP адресть вельде ули кода сашендомс иля тиихненди. 
+Уляндяряйхть иля тиинь мяльполадксонза конатнень аф видекста лувозь тоннекс, тондейть пароль сай пингста [[Special:UserLogin/signup|сёрматфтомс/сувамс]] иля лемфтома тиихнень марс аф шовореманкса.''",
 'noarticletext'                    => 'Тяни аш текст тя лопаса, тондейть ули кода [[Special:Search/{{PAGENAME}}|вешендемс тя лопать коняксонц]] иля лопава эли [{{fullurl:{{FULLPAGENAME}}|action=edit}} кармамс тя лопать тиема].',
 'userpage-userdoesnotexist'        => 'Сёрматфтомась «$1» лемса аш. Арьсек лацкаста, афкукс тонь улендяряй мяльце тиемс эли полафтомс тя лопать.',
 'clearyourcache'                   => "'''Шарфтк мяльце:''' Ванфтомада меле од полафнематнень ваноманкса тондейть эряви нардамс эслек ванфневи файлхнень тонь интернет поладксонь вальмастонза. '''Mozilla / Firefox / Safari:''' ''Shift'' кирдезь, люпштак ''Reload'', эли люпштак ''Ctrl-Shift-F5'' эли ''Ctrl-R'' (''Command-Shift-R'' Macintosh машинаса); '''Konqueror: '''люпштак ''Reload'' эли люпштак ''F5;'' '''Opera:''' програмса тондейть эрявксты нардамс сембе эслек ванфневи файлхт  ''Tools→Preferences'' вельде; '' '''Internet Explorer:''' ''Ctrl'' кирдезь люпштакшнек ''Refresh'' эли люпштак ''Ctrl-F5.''",
@@ -563,14 +562,15 @@
 'note'                             => '<strong>Шарфтк мяльце:</strong>',
 'previewnote'                      => '<strong>Тя аньцек васень няфтемась; полафнематне нинге исть ванфтов!</strong>',
 'previewconflict'                  => 'Текстсь тя васень няфтемаса няфтеви вярдень петнема паксяса стамкс кодамкс сон няеволь ванфтомада меле.',
-'session_fail_preview'             => '<strong>Ужялькс! Аш кода тонь петнемаце сувафтомс мекольце информациень йумафтомать сюнеда.
-Тик одукс. Тага лисентьфтяряй листь лопаста ди сувак тага весть.</strong>',
-'session_fail_preview_html'        => "<strong>Ужялькс! Аш кода тонь петнемацень сувафтомс мекольце информациень йумафтомать сюнеда.</strong>
+'session_fail_preview'             => '<strong>Ужялькс! Аш кода тонь петнемаце сувафтомс мекольце информациень юмафтомать сюнеда.
+Тик одукс. 
+Тага лисентьфтяряй - [[Special:UserLogout|листь]] лопаста ди сувак тага весть.</strong>',
+'session_fail_preview_html'        => "<strong>Ужялькс! Аш кода тонь петнемацень сувафтомс мекольце информациень юмафтомать сюнеда.</strong>
 
-''{{SITENAME}}-са мярьгови казяма HTML форматсь, васень няфтемась кяшф JavaScript програпть зиянда аралама туфталонкса.''
+''{{SITENAME}}са мярьгови казяма HTML форматсь, васень няфтемась кяшф JavaScript програпть зиянда аралама туфталонкса.''
 
-<strong>Улендяряй тя петнемась мярьговикс, эняльттяма тянь тиемс одукс. Тага лисентьфтяряй листь лопаста ди сувак тага весть.</strong>",
-'token_suffix_mismatch'            => '<strong>Тонь петнемацень кардазь сяс мес тонь програмце аф лац няфнесы китькскя тяшксне петнема паксять эса. Петнемаце кардазь текстть араламанкса. Стама колавома лисеви интернет лемфтома йотка йакай серверонь эзда конань якамаса ульсть эльбятькст.</strong>',
+<strong>Улендяряль тя петнемась мярьговикс, эняльттяма тянь тиемс одукс. Тага лисентьфтяряй - [[Special:UserLogout|листь]] лопаста ди сувак тага весть.</strong>",
+'token_suffix_mismatch'            => '<strong>Тонь петнемацень кардазь сяс мес тонь програмце аф лац няфнесы китькскя тяшксне петнема паксять эса. Петнемаце кардазь текстть араламанкса. Стама колавома лисеви интернет лемфтома ётка якай серверонь эзда конань якамаса ульсть эльбятькст.</strong>',
 'editing'                          => 'Петнемс $1',
 'editingsection'                   => 'Петнемс $1 (пялькс)',
 'editingcomment'                   => 'Петнемс $1 (мяльполадкс)',
@@ -578,14 +578,14 @@
 'explainconflict'                  => "Кати-кие тя лопать полафтозе мъзярс тон сонь петнить.
 Вярдень паксяса тон няйсак текстть стамкс конакс сон кармай няеви «Ванфтомс лопа» пунять люпштамда меле.
 Тонь полафнематне няевихть ала, петнема паксять эса.
-Тонь полафнематнень текстс нолдаманкса тондейть эряви синь йотафтомс алудонь петнема паксяста вярденнес.
+Тонь полафнематнень текстс нолдаманкса тондейть эряви синь ётафтомс алудонь петнема паксяста вярденнес.
 '''Аньцек''' вярдень паксястонь текстть ванфтови \"Ванфтомс лопа\" пунять люпштамда меле\".",
 'yourtext'                         => 'Тонь текстце',
 'storedversion'                    => 'Ванфтф верзие',
 'nonunicodebrowser'                => '<strong>ИНГОЛЕ КАРДАМА: Тонь интернет поладксце аф кирдьсы Unicode. Лопань петемста сембе аф-ASCII тяштьксне кармайхть арама синь кемготувонькърда лувксокс.</strong>',
 'editingold'                       => '<strong>ИНГОЛЕ КАРДАМА: Тон петнесак лопать сирелготф верзиенц.
 Сембе полафнематне тифт тя верзиеда меле кармайхть йумафтома.</strong>',
-'yourdiff'                         => 'Мезьса йавовихть',
+'yourdiff'                         => 'Мезьса явовихть',
 'copyrightwarning'                 => 'Эняльттяма, шарфтк мяльце сянь лангс, мес сембе поладоматне ди полафтоматне {{SITENAME}}-с лувовихть нолдафокс $2 коряс (ванк $1). Улефтяряй мяльце тонь сёрмадоматнень петнелезь седи апак маряк эди срадолезь эрь кодама вастова, тяза синь тят путне.<br />
 Тон стане ина максат вал сянь колга мес сембе тонь сёрмадоматне тиить тонць эли синь сявить марстонь эли иля панжада лисьмаста.
 <strong>ТЯТ СУВАФНЕ КОПИЯМА ВИДЕКССА АРАЛАФ МАТЕРИАЛХТ МЯРЬГОМАФТОМА!</strong>',
@@ -594,7 +594,7 @@
 Тон стане ина максат вал сянь колга мес сембе тонь сёрмадоматне тиить тонць эли синь сявить марстонь эли иля панжада лисьмаста. (ванк $1).<br />
 <strong>ТЯТ СУВАФНЕ КОПИЯМА ВИДЕКССА АРАЛАФ МАТЕРИАЛХТ МЯРЬГОМАФТОМА!</strong>',
 'longpagewarning'                  => '<strong>ИНГОЛЕ КАРДАМА: Тя лопать кувалмоц $1 килобайтт; кодамога интернет поладксонь вальмава стакаста петнемс лопат 32 килобайтти мала эли сяда кувака.
-Эняльттяма, арьсек улендяряй кода лопать йавфтомс сяда йомла пяльксова.</strong>',
+Эняльттяма, арьсек улендяряй кода лопать явфтомс сяда ёмла пяльксова.</strong>',
 'longpageerror'                    => '<strong>ЭЛЬБЯТЬКС: Тонь текстцень кувалмоц $1 килобайтт, тя максимупть $2 килобайтта лама. Сонь аш кода ванфтомс.</strong>',
 'readonlywarning'                  => '<strong>ИНГОЛЕ КАРДАМА: датабазась пякстаф петема покаматнень сюнеда, тя пингста тондейть аш кода ванфтомс тонь петнематнень. Шятьта тондейть пароль синь ванфтомс текст файлс ди путомс тяза меле.</strong>',
 'protectedpagewarning'             => '<strong>ИНГОЛЕ КАРДАМА:  Тя лопать пякстаф петнемада, сонь петнема мярьгови аньцек системонь вийксненди.</strong>',
@@ -609,7 +609,7 @@
 'hiddencategories'                 => 'Тя лопась {{PLURAL:$1|1 кяшф катериень|$1 кяшф категориень}} полаец:',
 'nocreatetitle'                    => 'Лопань тиемац оторонзаф',
 'nocreatetext'                     => '{{SITENAME}}-са од лопатнень тиемац оторонзаф.
-Тондейть ули кода мърдамс меки ди петнемс тиф ни лопать, эли [[Special:Userlogin|сувамс эли сёрматфтомс одукс]].',
+Тондейть ули кода мърдамс меки ди петнемс тиф ни лопать, эли [[Special:UserLogin|сувамс эли сёрматфтомс одукс]].',
 'nocreate-loggedin'                => 'Тондейть аф мярьгови тиемс од лопатне {{SITENAME}}-са.',
 'permissionserrors'                => 'Мярьговома Эльбятькст',
 'permissionserrorstext'            => 'Тондейть аф мярьгови тянь тиемс {{PLURAL:$1|туфтал|туфталхнень}} коряс:',
@@ -659,8 +659,8 @@
 'page_first'          => 'васенце',
 'page_last'           => 'мекольце',
 'histlegend'          => 'Верзиень кочкама: путт тяшкскат верзиетнень конякскяснон эди люпштак алудонь пунять эли Enter пунять.<br />
-Шарьхкотьфтема: (тян.) = тяниень верзиеда йавомась,
-(сяд.) = сядынгольдень верзияда йавомась, Й = йомла петнема.',
+Шарьхкотьфтема: (тян.) = тяниень верзиеда явомась,
+(сяд.) = сядынгольдень верзияда явомась, Ё = ёмла петнема.',
 'deletedrev'          => '[нардаф]',
 'histfirst'           => 'Кунардонь',
 'histlast'            => 'Улхкомбань',
@@ -729,8 +729,8 @@
 
 # Suppression log
 'suppressionlog'     => 'Кяшемань лувомась',
-'suppressionlogtext' => 'Ала нардаматнень ди пякстафкснень лувомась системонь вятикста кяшф потмоть мархта.
-Ванк [[Special:Ipblocklist|IP пякстафкснень лувомась]] улхкомбань якафнемань кардафкснень ди пякстаматнень мархта.',
+'suppressionlogtext' => 'Ала нардаматнень ди сёлгоматнень лувомась системонь вятикста кяшф потмоть мархта.
+Ванк [[Special:IPBlockList|IP сёлгоматнень лувомась]] улхкомбань якафнемань кардафкснень ди сёлгоматнень мархта.',
 
 # History merging
 'mergehistory'                     => 'Шоворемс лопатнень историяснон',
@@ -761,7 +761,7 @@
 
 # Diffs
 'history-title'           => '"$1"-нь верзиетнень историясна',
-'difference'              => '(Йавомась верзиетнень йоткова)',
+'difference'              => '(Явомась верзиетнень ёткова)',
 'lineno'                  => 'Линия $1:',
 'compareselectedversions' => 'Путомс кочкаф верзиетнень ваксс',
 'editundo'                => 'валхтомс',
@@ -770,7 +770,7 @@
 # Search results
 'searchresults'             => 'Мезе мувсь',
 'searchresulttext'          => '{{SITENAME}}-са вешендемань колга лама содаманкса ватт [[{{MediaWiki:Helppage}}|кизефтемань пялькссь]].',
-'searchsubtitle'            => "Тон вешить '''[[:$1]]'''",
+'searchsubtitle'            => 'Тон вешить \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|сембе лопат "$1"ста ушедомс]] | [[Special:WhatLinksHere/$1|сембе лопат сюлмафт "$1" мархта]])',
 'searchsubtitleinvalid'     => "Тон вешить '''$1'''",
 'noexactmatch'              => "'''\"\$1\" конякс мархта лопа аш.''' Тондейть ули кода [[:\$1|тиемс лопать]].",
 'noexactmatch-nocreate'     => "'''\"\$1\" конякс мархта лопа аш.'''",
@@ -813,7 +813,7 @@
 'mypreferences'            => 'Монь арафнемане',
 'prefs-edits'              => 'Петнематнень лувсна:',
 'prefsnologin'             => 'Апак сувак',
-'prefsnologintext'         => 'Тондейть эряви [[Special:Userlogin|сувамс]] тонь арафнематнень латцеманкса.',
+'prefsnologintext'         => 'Тондейть эряви [[Special:UserLogin|сувамс]] тонь арафнематнень латцеманкса.',
 'prefsreset'               => 'Ингольдень арафнематне мърдасть меки.',
 'qbsettings'               => 'Навигациень седяфкс',
 'qbsettings-none'          => 'Аф няфтемс',
@@ -859,9 +859,9 @@
 'recentchangescount'       => 'Мъзяра петнемат няфтемс улхкомбань полафнемаса, история ди сувама лувома лопаса:',
 'savedprefs'               => 'Тонь арафнемане ванфтсть.',
 'timezonelegend'           => 'Ойень (часонь) каркс',
-'timezonetext'             => '¹Мъзяра ойда (часта) тястонь пинге йави серверонь пингта (UTC - Гринвич пинге).',
+'timezonetext'             => '¹Мъзяра ойда (часта) тястонь пинге яви серверонь пингта (UTC - Гринвич пинге).',
 'localtime'                => 'Тястонь пинге',
-'timezoneoffset'           => 'Йавома',
+'timezoneoffset'           => 'Явома',
 'servertime'               => 'Серверонь пинге',
 'guesstimezone'            => 'Сёрмадомс интернет поладксста',
 'allowemail'               => 'Электрононь сёрматнень иля тиихнень эзда тиемс мярьговикс',
@@ -881,13 +881,13 @@
 'saveusergroups'              => 'Ванфтомс тиить полганзон',
 'userrights-groupsmember'     => 'Сувси полгас:',
 'userrights-groups-help'      => 'Тондейть ули кода полафнемс полгат конат эса ули тя тиись.
-* Тяште мархта кудня няфнесы тя тиись ся полгаса.
-* Тяштьфтома кудня няфнесытя тиись  аш ся полгаса.
+* Тяште мархта кудня няфнесы тя тиись ащи ся полгаса.
+* Тяштьфтома кудня няфнесы тя тиись аш ся полгаса.
 * Тяштькс * няфнесы тондейть аш кода нардамс полгать сонь поладомада меле эли меколанкт.',
 'userrights-reason'           => 'Полафтома туфтал:',
 'userrights-no-interwiki'     => 'Тондейть аф мярьгови полафтомс тиихнень видекссна иля Викива.',
 'userrights-nodatabase'       => 'Датабаза $1 аш эли сон аф тястоконь.',
-'userrights-nologin'          => 'Тондейть эряви [[Special:Userlogin|сувамс]] оцюнянь сёрматфтомать вельде тиихнень видексснон макссеманкса.',
+'userrights-nologin'          => 'Тондейть эряви [[Special:UserLogin|сувамс]] оцюнянь сёрматфтомать вельде тиихнень видексснон макссеманкса.',
 'userrights-notallowed'       => 'Тонь сёрматфтомацень вельде аф мярьгови макссемс видекст иля тиихненди.',
 'userrights-changeable-col'   => 'Полгатне конатнень тондейть ули кода полафтомс',
 'userrights-unchangeable-col' => 'Полгатне, конатнень тондейть аш кода полафтомс',
@@ -945,11 +945,11 @@
 'right-undelete'             => 'Мърдафтомс лопа',
 'right-suppressrevision'     => 'Ваномс ди мърдафтомс верзиетне кяшфт системонь вятикснень эзда',
 'right-suppressionlog'       => 'Няфтемс ломанень лувомаснон',
-'right-block'                => 'Кардамс иля тиихнень петнемада',
-'right-blockemail'           => 'Кардамс тиить электрононь сёрматнень кучемада',
-'right-hideuser'             => 'Пякстамс тиить лемоц, сонь кяшезь иля тиида',
-'right-ipblock-exempt'       => 'Йотамс IP пякстафкснень вакс, эсь тиеви пякстафкснень ди оцю пякстафкснень',
-'right-proxyunbannable'      => 'Йотамс ваксс эсь тиеви йотка йакай серверонь кардафксонза',
+'right-block'                => 'Сёлгомс иля тиихнень петнемада',
+'right-blockemail'           => 'Сёлгомс тиить электрононь сёрматнень кучемада',
+'right-hideuser'             => 'Сёлгомс тиить лемоц, сонь кяшезь иля тиида',
+'right-ipblock-exempt'       => 'Ётамс IP сёлгоматнень ваксс, эсь тиеви сёлгоматнень ди оцю сёлгоматнень',
+'right-proxyunbannable'      => 'Ётамс ваксс эсь тиеви ётка якай серверонь сёлгоматне',
 'right-protect'              => 'Полафтомс араламань куцеманянзон ди петнемс аралаф лопатнень',
 'right-editprotected'        => 'Петнемс аралаф лопатнень (какскадонь араламада башка)',
 'right-editinterface'        => 'Петнемс тиить лопанц арафнеманзон',
@@ -990,7 +990,7 @@
 'rcshowhidepatr'                    => '$1 ванондоф петнемат',
 'rcshowhidemine'                    => '$1 эсь петнемат',
 'rclinks'                           => 'Няфтемс $1 йотай полафнемат мекольце $2 шис<br />$3',
-'diff'                              => 'йав.',
+'diff'                              => 'яв.',
 'hist'                              => 'ист.',
 'hide'                              => 'Кяшемс',
 'show'                              => 'Няфтемс',
@@ -998,7 +998,7 @@
 'newpageletter'                     => 'О',
 'boteditletter'                     => 'р',
 'number_of_watching_users_pageview' => '[$1 ваны {{PLURAL:$1|тии|тиихть}}]',
-'rc_categories'                     => 'Аньцек категориеста (йавфтомс "|" вельде)',
+'rc_categories'                     => 'Аньцек категориеста (явфтомс "|" вельде)',
 'rc_categories_any'                 => 'Эрь кодама',
 'newsectionsummary'                 => '/* $1 */ од пялькс',
 
@@ -1016,22 +1016,24 @@
 'reupload'                    => 'Тонгомс тага весть',
 'reuploaddesc'                => 'Валхтомс тонгомать ди мърдамс тонгома формс.',
 'uploadnologin'               => 'Апак сувак',
-'uploadnologintext'           => 'Тондейть эряви [[Special:Userlogin|сувамс]] файл тонгоманкса.',
+'uploadnologintext'           => 'Тондейть эряви [[Special:UserLogin|сувамс]] файл тонгоманкса.',
 'upload_directory_missing'    => 'Аш тонгома директорие ($1) ди интернет серверти аш кода сонь тиемс.',
 'upload_directory_read_only'  => 'Аш кода сёрмадомс ($1) директориес web-сервер вельде.',
 'uploaderror'                 => 'Тонгодема эльбятькс',
-'uploadtext'                  => "Форм ала тондейть эрявксты файлонь тонгоманди ди ваноманди. Инголе тонкф файлхнень няфтеманкса ванк [[Special:Imagelist|тонкф архтофкснень лувомась]]. Файлонь тонгомасна ди нардамасна тяштевихть [[Special:Log/upload|файлонь тонгома лувомас]].
+'uploadtext'                  => "Форм ала тондейть эрявксты файлонь тонгоманди ди ваноманди. 
+Инголе тонкф файлхнень няфтеманкса ванк [[Special:ImageList|тонкф архтофкснень лувомась]], файлонь одукс тонгомасна тяштевихть [[Special:Log/upload|тонгома лувомас]], файлонь нардамасна тяштевихть [[Special:Log/upload|нардама лувомас]].
 
-Архтофкс азондомбяльксс сувафтоманкса эряви путомс кикс
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''' эли
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' файл мархта видеста сюлмамста.",
+Архтофкс сёрматфксс сувафтоманкса эряви путомс ки:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' пяшксе файлонь верзинц тевс нолдаманди
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alt text]]</nowiki></tt>''' 200 пиксель кели верзие ёмла кудняса лопань кержи ширеса тевс нолдаманди, 'alt text' вастс путозь архтофкс колга тяштемась
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' файлть мархта видеста сюлмамонди ся файлть апак няфнек.",
 'upload-permitted'            => 'Мярьговикс файл форматт: $1.',
 'upload-preferred'            => 'Сембода пара файл форматт: $1.',
 'upload-prohibited'           => 'Кардама файл форматт: $1.',
 'uploadlog'                   => 'файлонь тонгома лувома',
 'uploadlogpage'               => 'Файлонь тонгома лувомас',
-'uploadlogpagetext'           => 'Ватт ала улхкомбань файлонь тонгома лувомась.',
+'uploadlogpagetext'           => 'Ватт ала улхкомбань файлонь тонгома лувомась.
+Ватт [[Special:NewImages|од файлхнень няфтема]] содамс кодапт синь.',
 'filename'                    => 'Файлонь лем',
 'filedesc'                    => 'Нюрьхкяняста файлть колга',
 'fileuploadsummary'           => 'Нюрьхкяняста файлть колга:',
@@ -1087,9 +1089,9 @@
 'upload-proto-error'      => 'Аф кондясти протокол',
 'upload-proto-error-text' => 'Ичкоздень тонгодеманди эряви URL-т ушедыхть <code>http://</code>-са эли <code>ftp://</code>-са.',
 'upload-file-error'       => 'Потмонь эльбятькс',
-'upload-file-error-text'  => 'Потмонь эльбятькс лиссь йоткопингонь файл серверса тиемста. Эряви сотомс системонь оцюня мархта.',
+'upload-file-error-text'  => 'Потмонь эльбятькс лиссь ёткопингонь файл серверса тиемста. Эряви сотомс [[Special:ListUsers/sysop|системонь вятиксть]] мархта.',
 'upload-misc-error'       => 'Аф содаф тонгодема эльбятькс',
-'upload-misc-error-text'  => 'Аф содаф эльбятькс лиссь тонгодембачк.  Ванк кондясти ди сатови эли аф URL-сь эди тик сембе одукс. Лисендяряй стама эльбятькс тага весть, сотт системонь оцюнять мархта.',
+'upload-misc-error-text'  => 'Аф содаф эльбятькс лиссь тонгодембачк. Ванк кондясти ди сатови эли аф URL-сь эди тик сембе одукс. Лисендяряй стама эльбятькс тага весть, сотт [[Special:ListUsers/sysop|системонь вятиксть]] мархта.',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL-сь аф сатови',
@@ -1103,7 +1105,7 @@
 'upload_source_url'  => ' (кондясти, сембонди панжада URL)',
 'upload_source_file' => ' (файлсь тонь содама машинасот)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Тя башка тевонь лопаса няфневихть сембе тонкф файлхне.
 Мъзярс апак полафтт мекольце тонкф файлхне лувомаса няфневихть вяре.
 Палмань коняксонцты люпштамась полафнесы кикснень арафнемать.',
@@ -1131,7 +1133,7 @@
 'imagelinks'                     => 'Сюлмафкст',
 'linkstoimage'                   => 'Ся {{PLURAL:$1|лопась сюлмаф|$1 лопатне сюлмафт}} вага тя файлть мархта:',
 'nolinkstoimage'                 => 'Лопат сюлмафт тя файлть мархта ашет.',
-'morelinkstoimage'               => 'Ванк [[Special:Whatlinkshere/$1|сяда лама сюлмафкст]] тя файлонди.',
+'morelinkstoimage'               => 'Ванк [[Special:WhatLinksHere/$1|сяда лама сюлмафкст]] тя файлонди.',
 'redirectstofile'                => 'Вага {{PLURAL:$1|файл|$1 файлхт}} йотафтсаськ тя файлонди:',
 'duplicatesoffile'               => 'Вага {{PLURAL:$1|файл ащи кафонзафксокс|$1 файлхне ащихть кафонзафксокс}} тя файлонди:',
 'sharedupload'                   => 'Тя файлсь тонгозь марстонь файл пърдафксс ди сонь ули кода сувафтомс иля проектс.',
@@ -1150,18 +1152,18 @@
 # File reversion
 'filerevert'                => 'Мърдафтомс $1',
 'filerevert-legend'         => 'Мърдафтомс файл',
-'filerevert-intro'          => '<span class="plainlinks">Тон мърдафнесак \'\'\'[[Media:$1|$1]]\'\'\' [$4 верзиенза $3, $2-с].</span>',
+'filerevert-intro'          => "Тон мърдафнесак '''[[Media:$1|$1]]''' [$4 верзиенза $3, $2-с].",
 'filerevert-comment'        => 'Мяльполаткс:',
 'filerevert-defaultcomment' => 'Мърдаф верзиес $2, $1',
 'filerevert-submit'         => 'Мърдафтомс',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' мърдаф [$4 верзиенза $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' мърдаф [$4 верзиенза $3, $2].",
 'filerevert-badversion'     => 'Тя файлть сядынгольдень верзинц вешф пингоняфкс мархта тяса аш.',
 
 # File deletion
 'filedelete'                  => 'Нардамс $1',
 'filedelete-legend'           => 'Нардамс файлть',
 'filedelete-intro'            => "Тон нардасак '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Тон нардасак   \'\'\'[[Media:$1|$1]]\'\'\'-ть верзиенза [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Тон нардасак   '''[[Media:$1|$1]]'''-ть верзиенза [$4 $3, $2].",
 'filedelete-comment'          => 'Нардама туфтал:',
 'filedelete-submit'           => 'Нардамс',
 'filedelete-success'          => "'''$1''' нардаф.",
@@ -1216,15 +1218,17 @@
 Сякобасом тя малады кучкалувкса '''\$5''' петнемати фкя лопас эди '''\$6''' ваномати фкя петнемас.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue тефнень пулоснон] кувалмоц '''\$7'''.",
-'userstatstext'          => "{{PLURAL:$1|'''1''' сёрматфтф [[Special:Listusers|тии]]| '''$1''' сёрматфтфт [[Special:Listusers|тиихть]]}}, '''$2'''-нь (эли '''$4%''') {{PLURAL:$2|ули|улихть}} $5-нь видексонза.",
+'userstatstext'          => "{{PLURAL:$1|'''1''' сёрматфтф [[Special:ListUsers|тии]]| '''$1''' сёрматфтфт [[Special:ListUsers|тиихть]]}}, '''$2'''-нь (эли '''$4%''') {{PLURAL:$2|ули|улихть}} $5-нь видексонза.",
 'statistics-mostpopular' => 'Сидеста сувсеви лопат',
 
 'disambiguations'      => 'Лама смузьса лопат',
 'disambiguationspage'  => 'Template:лама смусть',
 'disambiguations-text' => "Ся лопатне сюлмафт '''лама смузень лопа''' мархта. Синьдеест эрявихть сюлмамс иля башка азондомбялькст мархта.<br />Лопась лувови лама смузеннекс мъзярда сон сюлмаф [[MediaWiki:Disambiguationspage]] кепотькс мархта.",
 
-'doubleredirects'     => 'Кафксть йотафтома',
-'doubleredirectstext' => 'Тя лопань лувомаса няфтевихть йотафтомат сюлмафт иля йотафтоматнень мархта. Эрь линияса улихть васенце ди омбоце йотафтоматнень сюлмафкссна, тяса тага ули омбоце йотафтомать васенце киксонцты сюлмафкссь, тоса ули няфтемась лопань лемонц лангс конань мархта эряволь васенце йотафтомать сюлмафтомс.',
+'doubleredirects'            => 'Кафксть йотафтома',
+'doubleredirectstext'        => 'Тя лопань лувомаса няфтевихть йотафтомат сюлмафт иля йотафтоматнень мархта. Эрь линияса улихть васенце ди омбоце йотафтоматнень сюлмафкссна, тяса тага ули омбоце йотафтомать васенце киксонцты сюлмафкссь, тоса ули няфтемась лопань лемонц лангс конань мархта эряволь васенце йотафтомать сюлмафтомс.',
+'double-redirect-fixed-move' => '[[$1]] ётафтфоль иля вастс, сон тяни ётафтфкс [[$2]]нди',
+'double-redirect-fixer'      => 'Ётафтфксонь латцема',
 
 'brokenredirects'        => 'Синтьф йотафтомат',
 'brokenredirectstext'    => 'Ся йотафтомат сюлмафт лопат мархта конат ашет:',
@@ -1311,7 +1315,7 @@
 'logempty'             => 'Стапт сувамот лувомаса ашет.',
 'log-title-wildcard'   => 'Мумс конякст конат ушедыхть стама тяшкста',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Сембе лопат',
 'alphaindexline'    => '$1-ста $2-с',
 'nextpage'          => 'Сай лопа ($1)',
@@ -1334,15 +1338,15 @@
 'special-categories-sort-count' => 'арафтомс луфть коряс',
 'special-categories-sort-abc'   => 'арафтомс алфавитонь коряс',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Няфтемс тиихть ушедомс:',
 'listusers-submit'   => 'Няфтемс',
 'listusers-noresult' => 'Тиихть исть мув.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Тиихнень полгаснон видексонза',
-'listgrouprights-summary'  => 'Тоса тиихнень полгасна конатне сувсихть тя Викис синь сувама видексснон мархта.
-Поладомань информациесь эсь видекснень колга ули кода мумс [[{{MediaWiki:Listgrouprights-helppage}}|тяса]].',
+'listgrouprights-summary'  => 'Тяса тиихнень полгасна конатне сувсихть тя Викис синь сувама видексснон мархта.
+Тяса ули кода мумс [[{{MediaWiki:Listgrouprights-helppage}}|поладомань информациесь]] эсь башка видекснень колга.',
 'listgrouprights-group'    => 'Полга',
 'listgrouprights-rights'   => 'Видексне',
 'listgrouprights-helppage' => 'Help:Полгань видексонза',
@@ -1350,12 +1354,12 @@
 
 # E-mail user
 'mailnologin'     => 'Аш кучема адрес',
-'mailnologintext' => 'Тондейть эряви [[Special:Userlogin|сувамс]]
+'mailnologintext' => 'Тондейть эряви [[Special:UserLogin|сувамс]]
 ди эряви кондясти электрононь адресце тонь [[Special:Preferences|арафнемасот]] иля тиихненди электрононь сёрмат кучемаснонды.',
 'emailuser'       => 'Кучемс электрононь сёрма тя тиинди',
 'emailpage'       => 'Кучемс электрононь сёрма тиинди',
-'emailpagetext'   => 'Путондярясь тя тиись сонь кондясти электрононь адресонц сонь арафнемасонза, the form below will send a single message.
-Электрононь адрессь тон путыть тонь тиить арафнемасот кармай эвондама тонь сёрмасот "Киста" паксява ди сёрмань кундайти ули кода кучемс сонь сёрма тя адресс.',
+'emailpagetext'   => 'Путондярясь тя тиись сонь кондясти электрононь адресонц сонь латцемасонза, сон кундай фкя сёрма.
+Электрононь адрессь тон путыть [[Special:Preferences|тонь тиить латцемасост]] кармай эвондама тонь сёрмасот "Киста" паксява ди сёрмань кундайти ули кода кучемс сонь сёрма тя адресс.',
 'usermailererror' => 'Электрононь адрес эльбятькссь:',
 'defemailsubject' => '{{SITENAME}}-нь электрононь сёрма',
 'noemailtitle'    => 'Аш электрононь адрес',
@@ -1381,11 +1385,11 @@
 'watchnologintext'     => 'Тондейть эряви [[Special:Сувамс|сувамс]] тонь ванома сёрмалувомазень петнеманкса.',
 'addedwatch'           => 'Полатф ванома сёрмалувомазот',
 'addedwatchtext'       => "Лопась \"[[:\$1]]\" сувафнезь тонь [[Special:Watchlist|Ванома сёрмалувомасот]].
-Сяда тов тя лопать ди мархтонза сюлмаф Корхнема лопать полафнематне кармайхть тякшстафтовома   тя лувомас, сяда тёждяень няевомаснонды синь тага кармайхть сёрмадовома  [[Special:Recentchanges|улхкомбань полафнематнень лувомас]] '''эчке тяшксса'''.
+Сяда тов тя лопать ди мархтонза сюлмаф Корхнема лопать полафнематне кармайхть тякшстафтовома   тя лувомас, сяда тёждяень няевомаснонды синь тага кармайхть сёрмадовома  [[Special:RecentChanges|улхкомбань полафнематнень лувомас]] '''эчке тяшксса'''.
 
 Улендяряй тонь мяльце тя лопать нардамс тонь ванома сёрмалувомастот, люпштак \"аф ваномс мельге\" лопань вярдень виде ужеса.",
 'removedwatch'         => 'Нардаф ванома сёрмалувомаста',
-'removedwatchtext'     => 'Лопась "[[:$1]]" нардафоль тонь ванома сёрмалувомастот.',
+'removedwatchtext'     => 'Лопась "[[:$1]]" нардафоль [[Special:Watchlist|тонь мельгеванома лувомастот]].',
 'watch'                => 'Ватт мельге',
 'watchthispage'        => 'Ваномс тя лопать мельге',
 'unwatch'              => 'Аф ваномс тянь мельге',
@@ -1482,15 +1486,16 @@
 'rollbacklink'                => 'кевордамс меки',
 'rollbackfailed'              => 'Меки кевордамась изь лисе',
 'cantrollback'                => 'Аш кода петнемать мърдафтомс; мекольце путысь ульсь тя лопать анцек фкя тиикс.',
-'alreadyrolled'               => 'Аш кода кевордамс [[:$1]]-нь мекольце петнемать, конань тись [[User:$2|$2]] ([[User talk:$2|Корхнема]]); иля тиись сонь петезе ни эли кевордазе.
+'alreadyrolled'               => 'Аш кода меки кевордамс [[:$1]]нь мекольце петнемать, конань тись [[User:$2|$2]] ([[User talk:$2|Корхнема]] | [[Special:Contributions/$2|{{int:contribslink}}]]);
+иля тиись сонь петезе эли кевордазе ни.
 
-Мекольце петнема  тись [[User:$3|$3]] ([[User talk:$3|Корхнема]]).',
+Мекольце петнема  тизе [[User:$3|$3]] ([[User talk:$3|Корхнема]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Петнема мяльполаткс ульсь: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Петнематнень мърдафтозь [[Special:Contributions/$2|$2]] ([[User talk:$2|Корхнема]]) сядынгольдень верзиес мърдафтозе [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Петнематнень мърдафтозе $1; сядынгольдень верзиес мърдафтозе $2.',
 'sessionfailure'              => 'Улема, лиссь прябала тонь сувама пингста; програмонь якамась лотказевсь сувамать върьгятемада аралама туфталонкса. Эняльттяма, люпштак "меки" ди одонзафтт лопать, конаста тон сать, меле тик сембе одукс.',
 'protectlogpage'              => 'Аралама лувома',
-'protectlogtext'              => 'Ала лопань пякстама-панжема лувомась. Ванк [[Special:Protectedpages|аралаф лопатнень лувомась]] тя пингонь системонь лопать араламанкса.',
+'protectlogtext'              => 'Ала лопань пякстама-панжема лувомась. Ванк [[Special:ProtectedPages|аралаф лопатнень лувомась]] тя пингонь системонь лопать араламанкса.',
 'protectedarticle'            => 'аралаф "[[$1]]"',
 'modifiedarticleprotection'   => '"[[$1]]"-нь араламань виенц полафтсь',
 'unprotectedarticle'          => '"[[$1]]" аф аралаф',
@@ -1599,7 +1604,7 @@
 
 # What links here
 'whatlinkshere'            => 'Сюлмафкст тяза',
-'whatlinkshere-title'      => 'Лопат конат сюлмафт $1 мархта',
+'whatlinkshere-title'      => 'Лопат конат сюлмафт "$1" мархта',
 'whatlinkshere-page'       => 'Лопа:',
 'linklistsub'              => '(Сюлмафкснень лувомась)',
 'linkshere'                => "Ся лопатне сюлмафт '''[[:$1]]''' мархта:",
@@ -1639,7 +1644,7 @@
 'ipbanononly'                     => 'Сёлгомс аньцек лемфтома тиихнень',
 'ipbcreateaccount'                => 'Кардамс сёрматфтомась тиема',
 'ipbemailban'                     => 'Кардамс тиинди кучемс электрононь сёрмат',
-'ipbenableautoblock'              => 'Эсезонза сёлгомсм тя тиить мекольце IP адресть эди иля IP адрест конань эста сон тяряфни петнемат тиемс',
+'ipbenableautoblock'              => 'Эсезонза сёлгомс тя тиить мекольце IP адресть эди иля IP адрест конань эста сон тяряфни петнемат тиемс',
 'ipbsubmit'                       => 'Сёлгомс тя тиить',
 'ipbother'                        => 'Иля пинге:',
 'ipboptions'                      => '2 ойхть (част):2 hours,1 ши:1 day,3 шит:3 days,1 тарга (недля):1 week,2 таргат (недлят):2 weeks,1 ков:1 month,3 кофт:3 months,6 кофт:6 months,1 киза:1 year,пефтома:infinite', # display1:time1,display2:time2,...
@@ -1650,7 +1655,7 @@
 'badipaddress'                    => 'Аф кондясти IP адрес',
 'blockipsuccesssub'               => 'Сёлгома йотафтф',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] сёлгозь.<br />
-Ванк [[Special:Ipblocklist|IP сёлгома лувомать]] сёлгомат ваноманкса.',
+Ванк [[Special:IPBlockList|IP сёлгома лувомать]] сёлгомат ваноманкса.',
 'ipb-edit-dropdown'               => 'Полафтомс сёлгома туфталхт',
 'ipb-unblock-addr'                => 'Валхтомс $1-нь сёлгома',
 'ipb-unblock'                     => 'Тиинь эли IP адресонь сёлгома валхтомс',
@@ -1661,7 +1666,7 @@
 'ipusubmit'                       => 'Валхтомс сёлгома тя адресста',
 'unblocked'                       => '[[User:$1|$1]]-ть сёлгомац валхтф',
 'unblocked-id'                    => '$1-нь сёлгомац валхтф',
-'ipblocklist'                     => 'Пякстаф IP адресонь эди тиинь лепнень лувомась',
+'ipblocklist'                     => 'Сёлкф IP адреснень эди тиинь лепнень лувомась',
 'ipblocklist-legend'              => 'Мумс сёлкф тиить',
 'ipblocklist-username'            => 'Тиить лемоц эли IP адрес:',
 'ipblocklist-submit'              => 'Вешендема',
@@ -1682,7 +1687,7 @@
 'blocklogentry'                   => '[[$1]] сёлкф $2 $3 пингс',
 'blocklogtext'                    => 'Тя лувомас сувсихть тиихнень сембе пякстамань ди панжемань тефне.
 Эсь сёлгови IP адресне тязк аф сувсихть.
-Ванк [[Special:Ipblocklist|IP пякстаматнень лувомать]] тяниень йакамань кардафкснень ди пякстаматнень мархта.',
+Ванк [[Special:IPBlockList|IP пякстаматнень лувомать]] тяниень йакамань кардафкснень ди пякстаматнень мархта.',
 'unblocklogentry'                 => 'кардафкста нолдазь $1',
 'block-log-flags-anononly'        => 'аньцек лемфтома тиихне',
 'block-log-flags-nocreate'        => 'од сёрматфтомась аф тиеви',
@@ -1722,7 +1727,7 @@
 'lockdbsuccesssub'    => 'Датабазать пякстамась мольсь лац',
 'unlockdbsuccesssub'  => 'Датабазонь пякстамать панжевсь',
 'lockdbsuccesstext'   => 'Датабазать пякстазь.<br />
-Киртть мяльсот тейть эряви [[Special:Unlockdb|пякстамать панжемс]] тонь латцематнень шумордамда меле.',
+Киртть мяльсот тейть эряви [[Special:UnlockDB|пякстамать панжемс]] тонь латцематнень шумордамда меле.',
 'unlockdbsuccesstext' => 'Датабазать пякстамась панжевсь.',
 'lockfilenotwritable' => 'Датабазонь пякстама файл аф сёрмадови.
 Датабазонь панжема-пякстама инголе эряви тянь тиемс web-серверса сёрмадовикс.',
@@ -1731,24 +1736,22 @@
 # Move page
 'move-page'               => 'Йотафтомс $1 од вастс',
 'move-page-legend'        => 'Йотафтомс лопа иля вастс',
-'movepagetext'            => "Форм ала тевс нолдамста тон лопать одс лемдесак, сембе сонь историяц ули йотафтф мархтонза од вастс.
-Сире лемоц арай од лопать лемонц йотафтомакс.
-Сире лемонц мархта сюлмафксне илядыхть апак полафтт; эряви нама ваномс мезь ашет синтьф эли кафонзаф йотафтомат.
-Тондейть сави лацкаста ваномс мезь сюлмафксне илядсть арафт виде йону.
+'movepagetext'            => "Форм ала тевс нолдамста тон лопать одс лемдесак, сембе сонь историяц ули ётафтф мархтонза од лем лопас.
+Сире лемоц арай од лем лопас ётафтфксокс.
+Лемть мархта йотафтфксне улихть кода эслек одонзамс. Улефтяряй мяльце синь эслек одонзальхть, эряви нама варжамс[[Special:DoubleRedirects|кафонзаф]] эли [[Special:BrokenRedirects|синтьф ётафтфксне]].
+Тондейть сави лацкаста варжамс сюлмафксне илядсть арафнефокс виде ёну.
 
-Шарфтк мяльце улендярясь ни тя од лемса иля сёрматфсь, лопась '''аф''' йотафтови мъзярс од вастсь аф шава эли йотафтф эди тоса аш йотай петнема история. Сякокс тондейть ули кода йотафтомс лопать меки коса сон инголе ульсь, эди тондейть аш кода нардамс лопать кона ульсь ни.
+Шарфтк мяльце улендярясь ни тя од лемса иля сёрматфсь, лопась '''аф''' ётафтови мъзярс од вастсь арай шавакс эли ётафтфксокс эди тоса аш ётай петнема история. Сякокс тондейть ули кода ётафтомс лопать меки коса сон инголе ульсь, эди тондейть аш кода тага весть тиемс лопать кона ули ни.
 
 '''ИНГОЛЕ МЯРЬГОМА!'''
-Одс лемдемась канни сембонди содаф лопати апак учт эди вакска аф йотави полафтомать;
-эняльттяма арьсек инголе мес тон шарьхкодят эли мезе лиси тонь тиемада меле.",
+Одс лемдемась канни содаф лопанди апак учт эди вакска аф ётави полафтомась;
+эняльттяма арьсек тевда инголе мес тон шарьхкодят мезе лиси тонь тиемада меле.",
 'movepagetalktext'        => "Сотф корхнема лопась ули эслек йотафтф мархтонза  '''кафта тевда башка:'''
 *Аф шава корхнема лопась ульсь ни иля лемса, эли
 *Тон аф йорат варжамс паксять ала.
 
 Ся тефнень сюнеда тондейть сави кядьвельде лопать йотафтомс эли шоворемс кода эряви.",
 'movearticle'             => 'Йотафтомс лопать иля вастс:',
-'movenologin'             => 'Апак сувак',
-'movenologintext'         => 'Эряви улемс сёрматфтф тиикс ди васенда [[Special:Userlogin|сувамс]] од вастс лопатнень йотафтоманди.',
 'movenotallowed'          => 'Тондейть аф мярьгови йотафтомс лопат од вастс {{SITENAME}}-са.',
 'newtitle'                => 'Од лемс:',
 'move-watch'              => 'Ваномс тя лопать мельге',
@@ -1775,7 +1778,7 @@
 'revertmove'              => 'веляфтомс',
 'delete_and_move'         => 'Нардамс эди од вастс йотафтомс',
 'delete_and_move_text'    => '==Нардамась вешф==
-Эрявкстовсь лопа "[[$1]]" ульсь ни.
+Эрявкстовсь лопа "[[:$1]]" ульсь ни.
 Мяльце нардамонза од вастс йотафтомань шумордаманкса?',
 'delete_and_move_confirm' => 'Ина, нардак лопать',
 'delete_and_move_reason'  => 'Нардаф од вастс йотафтомань шумордамонкса',
@@ -1786,6 +1789,7 @@
 'imagenocrossnamespace'   => 'Аш кода йотафтомс архтофкссь аф архтофксонь лемботмос',
 'imagetypemismatch'       => 'Файлть од келептемац явови сонь сортодонза',
 'imageinvalidfilename'    => 'Вешеви файллемсь аф кондясти',
+'fix-double-redirects'    => 'Одонзамс сембе ётафтфксне конат сюлмафт ушедомань лем мархта',
 
 # Export
 'export'            => 'Вимс лопатнень файлс',
@@ -1833,7 +1837,7 @@
 'import-interwiki-history'   => 'Копияфтомс тя лопать сембе историянь верзиенза',
 'import-interwiki-submit'    => 'Ускомс',
 'import-interwiki-namespace' => 'Йотафтомс лопатнень тя лемботмос:',
-'importtext'                 => 'Эняльттяма ускт файлть лисьмаста Викиса тевс нолдазь Special:Export лезкссь, ванфтт тянь тонь покам шранязот (содама машинаса) ди тонк тязк.',
+'importtext'                 => 'Эняльттяма ускт файлть Вики лисьмаста [[Special:Export|ускома лезкссь]] тевс нолдазь, ванфтт тянь тонь содама машинаса ди тонк тязк.',
 'importstart'                => 'Лопатне усксевихть...',
 'import-revision-count'      => '$1 {{PLURAL:$1|илякстоптома|илякстоптомат}}',
 'importnopages'              => 'Ашет лопат ускоманди.',
@@ -1940,11 +1944,11 @@
 'nocredits'        => 'Аш полайамань информациесь тя лопанди.',
 
 # Spam protection
-'spamprotectiontitle' => 'Шукшеда араламать фильтрась',
-'spamprotectiontext'  => 'Лопать тонь мялецоль ванфтомс пякстафоль шукшеда араламань фильтрать.
+'spamprotectiontitle' => 'Луднада араламань педямась',
+'spamprotectiontext'  => 'Лопать тонь мялецоль ванфтомс пякстафоль луднада араламань педямать.
 Тя, улема, лиссь ушеширень лопас сюлмафксть эзда.',
-'spamprotectionmatch' => 'Тя текстть эзда нолдавсь минек шукшеда фильтраньке: $1',
-'spambot_username'    => 'MediaWiki-ть шукшеда аруйафтомась',
+'spamprotectionmatch' => 'Тя текстть эзда нолдавсь минек луднада араламань педяманьке: $1',
+'spambot_username'    => 'MediaWiki-ть луднада аруяфтомась',
 'spam_reverting'      => 'Мърдафни мекольце $1-ти сюлмафкстома верзиес',
 'spam_blanking'       => 'Сембе илякстоптомат $1-ти сюлмафкснень мархта, лотксема',
 
@@ -1976,9 +1980,10 @@
 'markedaspatrollederror-noautopatrol' => 'Тондейть аф мярьгови тяштемс эсь полфнемацень кода патрулень варжафт.',
 
 # Patrol log
-'patrol-log-page' => 'Патрулень лувомась',
-'patrol-log-line' => 'тяштьфольхть $2-ста $1 патрулень варжафксокс $3',
-'patrol-log-auto' => '(эсь тиеви)',
+'patrol-log-page'   => 'Патрулень лувомась',
+'patrol-log-header' => 'Патруль ала верзиетнень лувомась.',
+'patrol-log-line'   => 'тяштьфольхть $2-ста $1 патрулень варжафксокс $3',
+'patrol-log-auto'   => '(эсь тиеви)',
 
 # Image deletion
 'deletedrevision'                 => 'Нардаф сире илякстоптома $1',
@@ -2007,10 +2012,10 @@
 'show-big-image'       => 'Няфтемс пяшксе кувалмонц',
 'show-big-image-thumb' => '<small>Сядынголе ваномать кувалмоц: $1 × $2 пикселхть</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Од файлхнень пърдафкс',
 'imagelisttext'         => "Ала'''$1''' {{PLURAL:$1|файлонь|файлхнень}} лувомась кочкаф $2.",
-'newimages-summary'     => 'Тя башка тевонь лопась няфнесыне мекольце тонкф файлхт',
+'newimages-summary'     => 'Тя башка тевонь лопась няфнесыне мекольце тонкф файлхт.',
 'showhidebots'          => '($1 робот програпт)',
 'noimages'              => 'Мезеге аш.',
 'ilsubmit'              => 'Вешендемс',
@@ -2289,7 +2294,7 @@
 
 # External editor support
 'edit-externally'      => 'Петнемс тя файлть ушеширень програмонь вельде',
-'edit-externally-help' => 'Ванк [http://meta.wikimedia.org/wiki/Help:External_editors арафнемань вятемовал] сяда лама содаманкса.',
+'edit-externally-help' => 'Ванк [http://www.mediawiki.org/wiki/Manual:External_editors арафнемань вятемовал] сяда лама содаманкса.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'сембе',
@@ -2358,7 +2363,7 @@
 'recreate'            => 'Тиемс одукс',
 
 # HTML dump
-'redirectingto' => 'Йотафневи [[$1]]-с...',
+'redirectingto' => 'Йотафневи [[:$1]]-с...',
 
 # action=purge
 'confirm_purge'        => 'Нардамс тя лопать копияфтома пингонь файлснон?
@@ -2403,8 +2408,8 @@
 'livepreview-error'   => 'Аш кода сотомс: $1 "$2" мархта. Тяряфтт кундамс кърдань васень няфтемас.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Полафнематне $1 фавда сяда од аш кода няфтемс лувомаса.',
-'lag-warn-high'   => 'Серверонь вельф стака йаксеманкса $1 фавда од полафнематне аш кода няфтемс тя лувомаса.',
+'lag-warn-normal' => 'Полафнематне $1 {{PLURAL:$1|фавда|фавда}} од аш кода няфтемс лувомаса.',
+'lag-warn-high'   => 'Серверонь вельф стака яксеманкса $1 {{PLURAL:$1|фавда|фавда}} од полафнематне аш кода няфтемс тя лувомаса.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Тонь сёрмалувомазост {{PLURAL:$1|1 конякс|$1 конякст}} корхнема лопафтома.',
@@ -2457,7 +2462,7 @@
 'version-software-product'         => 'Нолдафкс',
 'version-software-version'         => 'Верзие',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Файлти ян',
 'filepath-page'    => 'Файл:',
 'filepath-submit'  => 'Ян',
@@ -2491,12 +2496,12 @@
 'specialpages-group-users'       => 'Тиихне ди видексне',
 'specialpages-group-highuse'     => 'Пяк эрявикс лопат',
 'specialpages-group-pages'       => 'Лопатнень кярькссь',
-'specialpages-group-pagetools'   => 'Лопань кядьйонкст',
-'specialpages-group-wiki'        => 'Викинь дата ди кядьйонксне',
-'specialpages-group-redirects'   => 'Башка лопатнень иля вастс йотафтома',
-'specialpages-group-spam'        => 'Шукша пачфтематнень каршес кядьйонксне',
+'specialpages-group-pagetools'   => 'Лопань кядьёнкст',
+'specialpages-group-wiki'        => 'Викинь дата ди кядьёнксне',
+'specialpages-group-redirects'   => 'Башка лопатнень иля вастс ётафтома',
+'specialpages-group-spam'        => 'Лудна пачфтематнень каршес кядьёнксне',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Шава лопа',
 'intentionallyblankpage' => 'Тя лопать арьсезефоль кадомс шавакс',
 
Index: languages/messages/MessagesEs.php
===================================================================
--- languages/messages/MessagesEs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,36 +4,34 @@
  * @ingroup Language
  * @file
  *
- * @author Icvav
- * @author Titoxd
- * @author Piolinfax
- * @author Boivie
- * @author Drini
- * @author Platonides
- * @author Lin linao
- * @author Siebrand
- * @author Dmcdevit
- * @author לערי ריינהארט
- * @author Spacebirdy
- * @author Jurock
- * @author Baiji
- * @author Sanbec
- * @author Cvmontuy
  * @author Alhen
- * @author Jatrobat
+ * @author Alpertron
  * @author Ascánder
+ * @author Baiji
  * @author Bengoa
- * @author Orgullomoore
+ * @author Better
+ * @author Boivie
+ * @author Cvmontuy
+ * @author Dmcdevit
+ * @author Drini
  * @author Dvortygirl
- * @author Toniher
+ * @author Fluence
+ * @author Icvav
+ * @author Jatrobat
+ * @author Jurock
+ * @author Lin linao
+ * @author Mahadeva
+ * @author McDutchie
  * @author Omnipaedista
- * @author McDutchie
- * @author Mahadeva
- * @author Alpertron
- * @author Fluence
- * @author Better
- * @author SPQRobin
+ * @author Orgullomoore
+ * @author Piolinfax
+ * @author Platonides
+ * @author Sanbec
+ * @author Spacebirdy
  * @author Technorum
+ * @author Titoxd
+ * @author Toniher
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -369,13 +367,13 @@
 'readonlytext'         => 'La base de datos de {{SITENAME}} no permite nuevas entradas u otras modificaciones de forma temporal, probablemente por mantenimiento rutinario, tras de lo cual volverá a la normalidad.
 La explicación dada por el administrador que la bloqueó fue:
 <p>$1',
-'missing-article'      => 'La base de datos no encuentra el texto de una página que debería hallarse, titulada "$1" $2.
+'missing-article'      => "La base de datos no encuentra el texto de una página que debería hallarse, titulada \"\$1\" \$2.
 
-La causa de esto suele deberse a un diff anacrónico o un enlace al historial de una página que ha sido borrada.
+La causa de esto suele deberse a un ''diff'' anacrónico o un enlace al historial de una página que ha sido borrada.
 
-Si no fuera el caso, puedes haber encontrado un \'\'bug\'\' en el software. 
+Si no fuera el caso, puedes haber encontrado un ''bug'' en el software. 
 
-Por favor, avisa a un bibliotecario, tomando nota de la URL.',
+Por favor, avisa a un  [[Special:ListUsers/sysop|administrador]], tomando nota de la URL.",
 'missingarticle-rev'   => '(no. de revisión: $1)',
 'missingarticle-diff'  => '(Dif.: $1, $2)',
 'readonly_lag'         => 'La base de datos se ha bloqueado temporalmente mientras los servidores se sincronizan.',
@@ -418,13 +416,20 @@
 'titleprotected'       => "Esta página ha sido protegida contra creación por [[User:$1|$1]].
 La motivo dado fue: ''$2''",
 
+# Virus scanner
+'virus-badscanner'     => 'Error de configuración: Antivirus desconocido: <i>$1</i>',
+'virus-scanfailed'     => 'Escaneo fallido (código $1)',
+'virus-unknownscanner' => 'antivirus desconocido:',
+
 # Login and logout pages
 'logouttitle'                => 'Fin de sesión',
 'logouttext'                 => 'Ha terminado su sesión.
 Puede continuar navegando por {{SITENAME}} de forma anónima, o puede iniciar sesión otra vez con el mismo u otro usuario.',
 'welcomecreation'            => '== ¡Bienvenido(a), $1! ==
 
-Tu cuenta ha sido creada. No olvides personalizar [[Special:Preferences|tus preferencias]].',
+Tu cuenta ha sido creada. 
+
+No olvides personalizar [[Special:Preferences|tus preferencias]].',
 'loginpagetitle'             => 'Registrarse/Entrar',
 'yourname'                   => 'Su nombre de usuario',
 'yourpassword'               => 'Su contraseña',
@@ -475,7 +480,7 @@
 'nouserspecified'            => 'Debes especificar un nombre de usuario.',
 'wrongpassword'              => 'La contraseña indicada es incorrecta. Por favor, inténtelo de nuevo.',
 'wrongpasswordempty'         => 'No ha escrito una contraseña, inténtelo de nuevo.',
-'passwordtooshort'           => 'Su contraseña es muy corta. Debe tener al menos $1 caracteres.',
+'passwordtooshort'           => 'Tu contraseña no es válida o es muy corta. Debe tener al menos {{PLURAL:$1|un carácter|$1 caracteres}} y ser diferente de tu nombre de usuario.',
 'mailmypassword'             => 'Envíame una nueva contraseña por correo electrónico',
 'passwordremindertitle'      => 'Recordatorio de contraseña de {{SITENAME}}',
 'passwordremindertext'       => 'Alguien (probablemente tú, desde la dirección IP $1) solicitó que te enviáramos una nueva contraseña para su cuenta en {{SITENAME}} ($4).
@@ -557,9 +562,9 @@
 'summary-preview'                  => 'Previsualización del resumen',
 'subject-preview'                  => 'Previsualización del tema/título',
 'blockedtitle'                     => 'El usuario está bloqueado',
-'blockedtext'                      => '<big>\'\'\'Tu nombre de usuario o dirección IP ha sido bloqueada.\'\'\'</big>
+'blockedtext'                      => "<big>'''Tu nombre de usuario o dirección IP ha sido bloqueada.'''</big>
 
-El bloqueo fue hecho por $1. La razón dada es \'\'$2\'\'.
+El bloqueo fue hecho por $1. La razón dada es ''$2''.
 
 * Inicio del bloqueo: $8
 * Caducidad del bloqueo: $6
@@ -567,31 +572,29 @@
 
 Puedes contactar con $1 o con otro [[{{MediaWiki:Grouppage-sysop}}|administrador]] para discutir el bloqueo.
 
-No puedes usar el enlace "enviar correo electrónico a este usuario" si no has registrado una dirección válida de correo electrónico en tus [[Special:Preferences|preferencias]]. Tu dirección IP actual es $3, y el identificador del bloqueo es #$5. Por favor incluye uno o ambos datos en cualquier consulta que hagas.',
-'autoblockedtext'                  => 'Tu dirección IP ha sido bloqueada automáticamente porque fue utilizada por otro usuario que fue bloqueado por $1.
+No puedes utilizar la función «enviar correo electrónico a este usuario»  a menos que tengas una dirección de correo electrónico válida registrada en tus [[Special:Preferences|preferencias de usuario]] y que el bloqueo no haya inhabilitado esta función.
 
+Tu dirección IP actual es $3, y el identificador del bloqueo es #$5. Por favor incluye todos los datos aquí mostrados en cualquier consulta que hagas.",
+'autoblockedtext'                  => "Tu dirección IP ha sido bloqueada automáticamente porque fue utilizada por otro usuario que fue bloqueado por $1.
+
 La razón dada es esta:
 
-:\'\'$2\'\'
+:''$2''
 
 * Inicio del bloqueo: $8
 * Caducidad del bloqueo: $6
+* Bloqueo destinado a: $7 
 
 Puedes contactar con $1 o con otro de los [[{{MediaWiki:Grouppage-sysop}}|administradores]] para discutir el bloqueo.
 
-Nota que no puedes utilizar la función "Enviar correo electrónico a este usuario" a menos que tengas una dirección de correo electrónico válida registrada en tus [[Special:Preferences|preferencias de usuario]].
+No puedes utilizar la función «enviar correo electrónico a este usuario»  a menos que tengas una dirección de correo electrónico válida registrada en tus [[Special:Preferences|preferencias de usuario]] y que el bloqueo no haya inhabilitado esta función.
 
-Tu identificador de bloqueo es $5.
-Por favor, incluye este identificador en cualquier petición que hagas.',
+Tu dirección IP actual es $3, y el identificador del bloqueo es #$5. Por favor incluye todos los datos aquí mostrados en cualquier consulta que hagas.",
 'blockednoreason'                  => 'No se da ninguna razón',
 'blockedoriginalsource'            => "El código fuente de '''$1''' se muestra a continuación:",
 'blockededitsource'                => "El texto de '''tus ediciones''' a '''$1''' se muestran a continuación:",
 'whitelistedittitle'               => 'Se requiere identificación para editar.',
 'whitelistedittext'                => 'Tienes que $1 para editar artículos.',
-'whitelistreadtitle'               => 'Se requiere identificación para leer',
-'whitelistreadtext'                => 'Tienes que [[Special:Userlogin|registrarte]] para leer artículos.',
-'whitelistacctitle'                => 'No se le permite crear una cuenta',
-'whitelistacctext'                 => 'Para poder crear cuentas en {{SITENAME}} se ha de [[Special:Userlogin|iniciar sesión]] y tener los permisos apropiados.',
 'confirmedittitle'                 => 'Se requiere confirmación de dirección electrónica para editar',
 'confirmedittext'                  => 'Debes confirmar tu dirección electrónica antes de editar páginas. Por favor, establece y valida una dirección electrónica a través de tus [[Special:Preferences|preferencias de usuario]].',
 'nosuchsectiontitle'               => 'No existe tal sección',
@@ -603,7 +606,7 @@
 'accmailtext'                      => "La contraseña para '$1' se ha enviado a $2.",
 'newarticle'                       => '(Nuevo)',
 'newarticletext'                   => 'Ha seguido un enlace a una página que aún no existe. Si lo que quiere es crear esta página, escriba a continuación. Para más información consulte la [[{{MediaWiki:Helppage}}|página de ayuda]]. Si llegó aquí por error, vuelva a la página anterior.',
-'anontalkpagetext'                 => "---- ''Esta es la página de discusión de un usuario anónimo que aún no ha creado una cuenta, o no la usa. Por lo tanto, tenemos que usar su dirección IP para identificarlo. Una dirección IP puede ser compartida por varios usuarios. Si eres un usuario anónimo y crees que se han dirigido a ti con comentarios improcedentes, por favor [[Special:Userlogin|crea una cuenta o entra]] para evitar confusiones futuras con otros usuarios anónimos.''",
+'anontalkpagetext'                 => "---- ''Esta es la página de discusión de un usuario anónimo que aún no ha creado una cuenta, o no la usa. Por lo tanto, tenemos que usar su dirección IP para identificarlo. Una dirección IP puede ser compartida por varios usuarios. Si eres un usuario anónimo y crees que se han dirigido a ti con comentarios improcedentes, por favor [[Special:UserLogin/signup|crea una cuenta]] o si ya la tienes [[Special:UserLogin/log in|identifícate]] para evitar confusiones futuras con otros usuarios anónimos.''",
 'noarticletext'                    => 'En este momento no hay texto en esta página, puedes [[Special:Search/{{PAGENAME}}|buscar por el título de esta página]] en otras páginas o [{{fullurl:{{FULLPAGENAME}}|action=edit}} editar esta página].',
 'userpage-userdoesnotexist'        => 'La cuenta de usuario "$1" no está registrada. Por favor comprueba si quieres crear o editar esta página.',
 'clearyourcache'                   => "'''Nota:''' Tras guardar el archivo, debe refrescar la caché de su navegador para ver los cambios:
@@ -662,7 +665,7 @@
 'hiddencategories'                 => 'Esta página es un miembro de {{PLURAL:$1|1 categoría oculta|$1 categorías ocultas}}:',
 'edittools'                        => '<!-- Este texto aparecerá bajo los formularios de edición y subida. -->',
 'nocreatetitle'                    => 'Creación de páginas limitada',
-'nocreatetext'                     => 'Este wiki ha restringido la posibilidad de crear nuevas páginas. Puede volver atrás y editar una página existente, [[Special:Userlogin|identificarse o crear una cuenta]].',
+'nocreatetext'                     => 'Este wiki ha restringido la posibilidad de crear nuevas páginas. Puede volver atrás y editar una página existente, [[Special:UserLogin|identificarse o crear una cuenta]].',
 'nocreate-loggedin'                => 'No tienes permiso para crear páginas nuevas en {{SITENAME}}.',
 'permissionserrors'                => 'Errores de permisos',
 'permissionserrorstext'            => 'No tienes permiso para hacer eso, por {{PLURAL:$1|el siguiente motivo|los siguientes motivos}}:',
@@ -673,14 +676,21 @@
 Consulte a continuación el registro de borrados:",
 
 # Parser/template warnings
-'expensive-parserfunction-warning'  => 'Aviso: Esta página contiene demasiadas llamadas a funciones de preproceso costosas
+'expensive-parserfunction-warning'        => 'Aviso: Esta página contiene demasiadas llamadas a funciones de preproceso costosas
 
 Debería tener menos de $2, por ahora tiene $1.',
-'expensive-parserfunction-category' => 'Páginas con demasiadas llamadas a funciones de preproceso (parser functions) costosas',
+'expensive-parserfunction-category'       => 'Páginas con llamadas a funciones sintácticas demasiado costosas',
+'post-expand-template-inclusion-warning'  => 'Aviso: El tamaño de las plantillas incluidas es muy grande.
+Algunas plantillas no serán incluidas',
+'post-expand-template-inclusion-category' => 'Páginas con sobrecarga de plantillas',
+'post-expand-template-argument-warning'   => 'Aviso: Esta página contiene al menos un parámetro de plantilla que tiene un tamaño de expansión demasiado grande. 
+Ese o esos parámetros han sido omitidos.',
+'post-expand-template-argument-category'  => 'Páginas que contienen plantillas con parámetros descartados',
 
 # "Undo" feature
 'undo-success' => 'La edición puede deshacerse. Antes de deshacer la edición, comprueba la siguiente comparación para verificar que realmente es lo que quiere hacer, y entonces guarde los cambios para así deshacer la edición.',
 'undo-failure' => 'No se puede deshacer la edición ya que otro usuario ha realizado una edición intermedia.',
+'undo-norev'   => 'La edición no puede ser deshecha porque no existe o ha sido borrada.',
 'undo-summary' => 'Deshecha la edición $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|disc.]])',
 
 # Account creation failure
@@ -776,7 +786,7 @@
 # Suppression log
 'suppressionlog'     => 'Log de supresiones',
 'suppressionlogtext' => 'Debajo está una lista de borrados y bloqueos relacionados con contenido oculto a los sysops.
-Mira [[Special:Ipblocklist|el registro de bloqueos]] para una lista de bloqueos activos.',
+Mira [[Special:IPBlockList|el registro de bloqueos]] para una lista de bloqueos activos.',
 
 # History merging
 'mergehistory'                     => 'Fusionar historiales de páginas',
@@ -816,46 +826,55 @@
 'diff-multi'              => '({{PLURAL:$1|Una edición intermedia no se muestra|$1 ediciones intermedias no se muestran}}.)',
 
 # Search results
-'searchresults'            => 'Resultados de la búsqueda',
-'searchresulttext'         => 'Para más información acerca de las búsquedas en {{SITENAME}}, consulte la [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'           => "Has consultado por '''[[:$1]]'''",
-'searchsubtitleinvalid'    => 'Para consulta "$1"',
-'noexactmatch'             => "'''No existe una página llamada \"\$1\".''' Puedes [[:\$1|crearla]].",
-'noexactmatch-nocreate'    => "'''No existe la página \"\$1\".'''",
-'toomanymatches'           => 'Los resultados fueron demasiado extensos, por favor intente una consulta diferente',
-'titlematches'             => 'Coincidencias de título de artículo',
-'notitlematches'           => 'No hay coincidencias de título de artículo',
-'textmatches'              => 'Coincidencias de texto de artículo',
-'notextmatches'            => 'No hay coincidencias de texto de artículo',
-'prevn'                    => '$1 previas',
-'nextn'                    => '$1 siguientes',
-'viewprevnext'             => 'Ver ($1) ($2) ($3).',
-'search-result-size'       => '$1 ({{PLURAL:$2|1 palabra|$2 palabras}})',
-'search-result-score'      => 'Relevancia: $1%',
-'search-section'           => '(sección $1)',
-'search-suggest'           => 'Dice usted: $1',
-'search-interwiki-default' => '$1 resultados:',
-'mwsuggest-disable'        => 'No usar AJAX al realizar búsquedas',
-'searchall'                => 'todos',
-'showingresults'           => "Abajo se {{PLURAL:$1|muestra '''1''' resultado|muestran hasta '''$1''' resultados}} empezando por el nº '''$2'''.",
-'showingresultsnum'        => "Abajo se {{PLURAL:$3|muestra '''1''' resultado|muestran los '''$3''' resultados}} empezando por el nº '''$2'''.",
-'showingresultstotal'      => "Debajo se muestran {{PLURAL:$3|la resultado '''$1''' de un resultado total|los resultados entre el número '''$1''' y el '''$2''', de un total de $3 resultados totales}}.",
-'nonefound'                => '<strong>Nota</strong>: las búsquedas fallidas suelen producirse al buscar palabras comunes como "la" o "de", que no están en el índice, o por especificar más de una palabra a buscar (sólo las páginas
-que contengan todos los términos de búsqueda aparecerán en el resultado).',
-'powersearch'              => 'Búsqueda',
-'powersearch-legend'       => 'Búsqueda avanzada',
-'powersearch-ns'           => 'Buscar en los espacios de nombres:',
-'powersearch-redir'        => 'Listar redirecciones',
-'powersearch-field'        => 'Buscar',
-'search-external'          => 'Búsqueda externa',
-'searchdisabled'           => 'Las búsquedas en {{SITENAME}} está temporalmente deshabilitadas. Mientras tanto puede buscar mediante buscadores externos, pero tenga en cuenta que sus índices relativos a {{SITENAME}} pueden estar desactualizados.',
+'searchresults'             => 'Resultados de la búsqueda',
+'searchresulttext'          => 'Para más información acerca de las búsquedas en {{SITENAME}}, consulte la [[{{MediaWiki:Helppage}}|{{int:help}}]].',
+'searchsubtitle'            => "Has consultado por '''[[:$1]]''' ([[Special:Prefixindex/$1|todas las páginas que empiezan por «$1»]] | [[Special:WhatLinksHere/$1|todas la páginas que enlazan con «$1»]])",
+'searchsubtitleinvalid'     => 'Para consulta "$1"',
+'noexactmatch'              => "'''No existe una página llamada \"\$1\".''' Puedes [[:\$1|crearla]].",
+'noexactmatch-nocreate'     => "'''No existe la página \"\$1\".'''",
+'toomanymatches'            => 'Los resultados fueron demasiado extensos, por favor intente una consulta diferente',
+'titlematches'              => 'Coincidencias de título de artículo',
+'notitlematches'            => 'No hay coincidencias de título de artículo',
+'textmatches'               => 'Coincidencias de texto de artículo',
+'notextmatches'             => 'No hay coincidencias de texto de artículo',
+'prevn'                     => '$1 previas',
+'nextn'                     => '$1 siguientes',
+'viewprevnext'              => 'Ver ($1) ($2) ($3).',
+'search-result-size'        => '$1 ({{PLURAL:$2|1 palabra|$2 palabras}})',
+'search-result-score'       => 'Relevancia: $1%',
+'search-redirect'           => '(redirige a $1)',
+'search-section'            => '(sección $1)',
+'search-suggest'            => 'Dice usted: $1',
+'search-interwiki-caption'  => 'Proyectos hermanos',
+'search-interwiki-default'  => '$1 resultados:',
+'search-interwiki-more'     => '(más)',
+'search-mwsuggest-enabled'  => 'con sugerencias',
+'search-mwsuggest-disabled' => 'sin sugerencias',
+'search-relatedarticle'     => 'Relacionado',
+'mwsuggest-disable'         => 'No usar AJAX al realizar búsquedas',
+'searchrelated'             => 'relacionado',
+'searchall'                 => 'todos',
+'showingresults'            => "Abajo se {{PLURAL:$1|muestra '''1''' resultado|muestran hasta '''$1''' resultados}} empezando por el nº '''$2'''.",
+'showingresultsnum'         => "Abajo se {{PLURAL:$3|muestra '''1''' resultado|muestran los '''$3''' resultados}} empezando por el nº '''$2'''.",
+'showingresultstotal'       => "Debajo se muestran {{PLURAL:$3|la resultado '''$1''' de un resultado total|los resultados entre el número '''$1''' y el '''$2''', de un total de $3 resultados totales}}.",
+'nonefound'                 => "'''Nota''': Por defecto sólo se busca en algunos espacios de nombre.
+Prueba a usar el prefijo ''all:'' para buscar en todo el contenido (incluyendo páginas de discusión, plantillas, etc.) o usa el espacio de nombre que quieras como prefijo. También puedes usar el formulario de búsqueda avanzada que aparece abajo.
 
+Las búsquedas fallidas suelen producirse al buscar palabras comunes como «la» o «de», que no están en el índice, o por especificar más de una palabra a buscar (sólo las páginas que contengan todos los términos de búsqueda aparecerán en el resultado).",
+'powersearch'               => 'Búsqueda',
+'powersearch-legend'        => 'Búsqueda avanzada',
+'powersearch-ns'            => 'Buscar en los espacios de nombres:',
+'powersearch-redir'         => 'Listar redirecciones',
+'powersearch-field'         => 'Buscar',
+'search-external'           => 'Búsqueda externa',
+'searchdisabled'            => 'Las búsquedas en {{SITENAME}} está temporalmente deshabilitadas. Mientras tanto puede buscar mediante buscadores externos, pero tenga en cuenta que sus índices relativos a {{SITENAME}} pueden estar desactualizados.',
+
 # Preferences page
 'preferences'              => 'Preferencias',
 'mypreferences'            => 'Mis preferencias',
 'prefs-edits'              => 'Cantidad de ediciones:',
 'prefsnologin'             => 'No está identificado',
-'prefsnologintext'         => 'Debes [[Special:Userlogin|entrar]] para cambiar las preferencias de usuario.',
+'prefsnologintext'         => 'Debes [[Special:UserLogin|entrar]] para cambiar las preferencias de usuario.',
 'prefsreset'               => 'Las preferencias han sido restauradas a los valores por defecto.',
 'qbsettings'               => 'Preferencias de "Quickbar"',
 'qbsettings-none'          => 'Ninguna',
@@ -908,6 +927,7 @@
 'guesstimezone'            => 'Obtener la hora del navegador',
 'allowemail'               => 'Habilitar la recepción de correo de otros usuarios',
 'prefs-searchoptions'      => 'Opciones de búsqueda',
+'prefs-namespaces'         => 'Espacios de nombres',
 'defaultns'                => 'Buscar en estos espacios de nombres por defecto:',
 'default'                  => 'por defecto',
 'files'                    => 'Archivos',
@@ -921,10 +941,14 @@
 'userrights-editusergroup'    => 'Modificar grupos de usuarios',
 'saveusergroups'              => 'Guardar grupos de usuarios',
 'userrights-groupsmember'     => 'Miembro de:',
+'userrights-groups-help'      => 'Puedes modificar los grupos a los que pertenece este usuario:
+* Un recuadro marcado significa que el usuario está en ese grupo.
+* Un recuadro marcado significa que el usuario está en ese grupo.
+* Un * indica que no podrás retirar el grupo una vez que lo pongas, o viceversa.',
 'userrights-reason'           => 'Motivo para el cambio:',
 'userrights-no-interwiki'     => 'No tienes permiso para editar los grupos a los que pertenece un usuario en otros wikis.',
 'userrights-nodatabase'       => 'La base de datos $1 no existe o no es local.',
-'userrights-nologin'          => 'Debes [[Special:Userlogin|iniciar sesión]] con una cuenta de administrador para poder editar los grupos de los usuarios.',
+'userrights-nologin'          => 'Debes [[Special:UserLogin|iniciar sesión]] con una cuenta de administrador para poder editar los grupos de los usuarios.',
 'userrights-notallowed'       => 'No tienes permiso para realizar cambios de grupos a usuarios.',
 'userrights-changeable-col'   => 'Grupos que puede cambiar',
 'userrights-unchangeable-col' => 'Grupos que no puede cambiar',
@@ -936,6 +960,7 @@
 'group-bot'           => 'Bots',
 'group-sysop'         => 'Administradores',
 'group-bureaucrat'    => 'Burócratas',
+'group-suppress'      => 'Supervisores',
 'group-all'           => '(todos)',
 
 'group-user-member'          => 'Usuario',
@@ -943,12 +968,14 @@
 'group-bot-member'           => 'Bot',
 'group-sysop-member'         => 'Administrador',
 'group-bureaucrat-member'    => 'Burócrata',
+'group-suppress-member'      => 'supervisor',
 
 'grouppage-user'          => '{{ns:project}}:Usuarios',
 'grouppage-autoconfirmed' => '{{ns:project}}:Usuarios autoconfirmados',
 'grouppage-bot'           => '{{ns:project}}:Bot',
 'grouppage-sysop'         => '{{ns:project}}:Administradores',
 'grouppage-bureaucrat'    => '{{ns:project}}:Burócratas',
+'grouppage-suppress'      => '{{ns:project}}:Supervisor',
 
 # Rights
 'right-read'             => 'Leer páginas',
@@ -958,10 +985,12 @@
 'right-createaccount'    => 'Crear cuentas de usuario nuevas',
 'right-minoredit'        => 'Marcar ediciones como «menores»',
 'right-move'             => 'Trasladar páginas',
+'right-move-subpages'    => 'Trasladar páginas con sus subpáginas',
 'right-suppressredirect' => 'No crear una redirección en el viejo nombre al trasladar una página',
 'right-upload'           => 'Subir archivos',
 'right-reupload'         => 'Subir una nueva versión de un archivo existente',
 'right-reupload-own'     => 'Subir una nueva versión de un archivo creado por uno mismo',
+'right-reupload-shared'  => 'Sobreescribir localmente ficheros del repositorio multimedia',
 'right-upload_by_url'    => 'Subir un archivo a traves de un URL',
 'right-purge'            => 'Purgar la caché en el servidor sin tener que dar confirmación',
 'right-autoconfirmed'    => 'Editar páginas semiprotegidas',
@@ -974,6 +1003,7 @@
 'right-deletedhistory'   => 'Ver el historial de páginas borradas, sin el texto asociado',
 'right-browsearchive'    => 'Buscar páginas borradas',
 'right-undelete'         => 'Deshacer el borrado de una página',
+'right-suppressionlog'   => 'Ver registros privados',
 'right-block'            => 'Bloquear a otros usuarios para que no editen',
 'right-blockemail'       => 'Bloquear a un usuario para que no pueda mandar correos electrónicos',
 'right-hideuser'         => 'Bloquear un nombre de usuario, haciéndolo invisible',
@@ -984,6 +1014,7 @@
 'right-import'           => 'Importar páginas desde otras wikis',
 'right-autopatrol'       => 'Marcar como patrulladas sus ediciones automáticamente',
 'right-unwatchedpages'   => 'Ver una lista de páginas no vigiladas',
+'right-mergehistory'     => 'Fusionar historiales',
 'right-siteadmin'        => 'Bloquear y desbloquear la base de datos',
 
 # User rights log
@@ -997,7 +1028,7 @@
 'recentchanges'                     => 'Cambios recientes',
 'recentchangestext'                 => 'Sigue los cambios más recientes de la wiki en esta página.',
 'recentchanges-feed-description'    => 'Seguir los cambios más recientes en el wiki en este feed.',
-'rcnote'                            => "Debajo {{PLURAL:$1|hay '''1''' cambio efectuado|están los últimos '''$1''' cambios efectuados}} en  {{PLURAL:$2|el último día|los últimos '''$2''' días}}, actualizados a fecha de $3",
+'rcnote'                            => "Debajo {{PLURAL:$1|hay '''1''' cambio efectuado|están los últimos '''$1''' cambios efectuados}} en  {{PLURAL:$2|el último día|los últimos '''$2''' días}}, hasta el $4, $5.",
 'rcnotefrom'                        => 'A continuación se muestran los cambios desde <b>$2</b> (hasta <b>$1</b>).',
 'rclistfrom'                        => 'Mostrar nuevos cambios desde $1',
 'rcshowhideminor'                   => '$1 ediciones menores',
@@ -1033,24 +1064,26 @@
 'reupload'                    => 'Subir otra vez',
 'reuploaddesc'                => 'Regresar al formulario para subir.',
 'uploadnologin'               => 'No ha iniciado sesión',
-'uploadnologintext'           => 'Tienes que [[Special:Userlogin|iniciar sesión]] para poder subir archivos.',
+'uploadnologintext'           => 'Tienes que [[Special:UserLogin|iniciar sesión]] para poder subir archivos.',
 'upload_directory_missing'    => 'El directorio de subida de archivos ($1) no existe, y no puede ser creado por el servidor.',
 'upload_directory_read_only'  => 'El servidor web no puede escribir en el directorio de subida de archivos ($1).',
 'uploaderror'                 => 'Error al intentar subir archivo',
 'uploadtext'                  => "Utilize el siguiente formulario para subir archivos.
-Para ver o buscar archivos subidos con anterioridad, ir a [[Special:Imagelist|lista de archivos subidos]].
-Lo que haya subido o borrado quedará registrado además en el [[Special:Log/upload|registro de archivos subidos]].
+Para ver o buscar archivos subidos con anterioridad, ve a la [[Special:ImageList|lista de archivos subidos]].
+Los archivos subidos quedarán registrado además en el [[Special:Log/upload|registro de archivos subidos]] y los borrados en el [[Special:Log/delete|registro de borrados]].
 
-Para incluir un archivo en una página, utilice en el formulario los enlaces
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alt text]]</nowiki>''', o
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''', para vincular directamente el archivo.",
+Para incluir un archivo en una página, use un enlace como los que siguen
+
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' para usar el fichero en tamaño completo
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|texto descriptivo]]</nowiki></tt>''' para una versión de 200 pixeles de ancho en una caja en el margen izquierdo con 'texto descriptivo' como descripción
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' para enlazar directamente al fichero sin mostrarlo.",
 'upload-permitted'            => 'Tipos de archivo permitidos: $1.',
 'upload-preferred'            => 'Tipos de archivo preferidos: $1.',
 'upload-prohibited'           => 'Tipos de archivo prohibidos: $1.',
 'uploadlog'                   => 'registro de subidas',
 'uploadlogpage'               => 'Subidas de archivos',
-'uploadlogpagetext'           => 'Abajo hay una lista de los últimos archivos subidos. Todas las horas son del servidor.',
+'uploadlogpagetext'           => 'Abajo hay una lista de los últimos archivos subidos.
+Mira la [[Special:NewImages|galería de archivos nuevos]] para una descripción visual',
 'filename'                    => 'Nombre del archivo',
 'filedesc'                    => 'Sumario',
 'fileuploadsummary'           => 'Descripción:',
@@ -1063,6 +1096,10 @@
 'illegalfilename'             => 'El nombre de archivo «$1» contiene caracteres que no están permitidos en títulos de páginas. Por favor, renombra el archivo e intenta volver a subirlo.',
 'badfilename'                 => 'El nombre de la imagen se ha cambiado a "$1".',
 'filetype-badmime'            => 'No se permite subir archivos de tipo MIME "$1".',
+'filetype-unwanted-type'      => "'''«.$1»''' no está entre los tipos de fichero aconsejados.
+{{PLURAL:$3|El único tipo aconsejado es|Los tipos aconsejados son}} $2.",
+'filetype-banned-type'        => "'''«.$1»''' no está entre los tipos de fichero permitidos.
+{{PLURAL:$3|El único tipo permitido es|Los tipos permitidos son}} $2.",
 'filetype-missing'            => 'El archivo no tiene extensión (como ".jpg").',
 'large-file'                  => 'Se recomienda que los archivos no sean mayores de $1; este archivo ocupa $2.',
 'largefileserver'             => 'El tamaño de este archivo es mayor del que este servidor admite por configuración.',
@@ -1081,10 +1118,12 @@
 Si tienes esta imagen a toda resolución súbela, si no, por favor cambia el nombre del archivo.',
 'fileexists-forbidden'        => 'Ya existe un archivo con este nombre. Por favor, cambie el nombre del archivo y vuelva a subirlo. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Ya existe un archivo con este nombre en el repositorio compartido; por favor, regresa a la página anterior y sube tu archivo con otro nombre. [[Image:$1|thumb|center|$1]]',
+'file-exists-duplicate'       => 'Este archivo es un duplicado {{PLURAL:$1|del siguiente|de los siguientes}}:',
 'successfulupload'            => 'Subida con éxito',
 'uploadwarning'               => 'Advertencia de subida de archivo',
 'savefile'                    => 'Guardar archivo',
 'uploadedimage'               => '«[[$1]]» subido.',
+'overwroteimage'              => 'subida una nueva versión de «[[$1]]»',
 'uploaddisabled'              => 'Subida de archivos deshabilitada',
 'uploaddisabledtext'          => 'No es posible subir archivos en {{SITENAME}}.',
 'uploadscripted'              => 'Este archivo contiene script o código HTML que puede ser interpretado erróneamente por un navegador.',
@@ -1099,13 +1138,16 @@
 
 Debería considerar si resulta apropiado continuar cargándolo.
 A continuación se muestra el registro de borrado de este archivo:",
+'filename-bad-prefix'         => 'El nombre del archivo que estás subiendo comienza por <strong>«$1»</strong>, un nombre nada descriptivo de su contenido. Es un típico nombre de los que asignan automáticamente las cámaras digitales.
 
+Por favor, elige un nombre más descriptivo.',
+
 'upload-proto-error'      => 'Protocolo incorrecto',
 'upload-proto-error-text' => 'Para subir archivos desde otra página la URL debe comenzar por <code>http://</code> o <code>ftp://</code>.',
 'upload-file-error'       => 'Error interno',
-'upload-file-error-text'  => 'Ha ocurrido un error interno mientras se intentaba crear un fichero temporal en el servidor. Por favor, contacta con un administrador del sistema.',
+'upload-file-error-text'  => 'Ha ocurrido un error interno mientras se intentaba crear un fichero temporal en el servidor. Por favor, contacta con un [[Special:ListUsers/sysop|administrador del sistema]].',
 'upload-misc-error'       => 'Error desconocido en la subida',
-'upload-misc-error-text'  => 'Ha ocurrido un error durante la subida. Por favor verifica que la URL es válida y accesible e inténtalo de nuevo. Si el problema persiste, contacta con un administrador del sistema.',
+'upload-misc-error-text'  => 'Ha ocurrido un error durante la subida. Por favor verifica que la URL es válida y accesible e inténtalo de nuevo. Si el problema persiste, contacta con un [[Special:ListUsers/sysop|administrador del sistema]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'No se pudo alcanzar la URL',
@@ -1119,7 +1161,7 @@
 'upload_source_url'  => ' (una URL válida y accesible públicamente)',
 'upload_source_file' => ' (un archivo en su ordenador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Esta página muestra todos los archivos subidos.
 Por defecto, el último subido se muestra al principio de la lista.
 Un click sobre el encabezamiento de la columna cambia el orden.',
@@ -1133,52 +1175,67 @@
 'imagelist_description' => 'Descripción',
 
 # Image description page
-'filehist'                  => 'Historial del archivo',
-'filehist-help'             => 'Haga clic sobre una fecha/hora para ver el
+'filehist'                       => 'Historial del archivo',
+'filehist-help'                  => 'Haga clic sobre una fecha/hora para ver el
 archivo a esa fecha.',
-'filehist-deleteall'        => 'borrar todo',
-'filehist-deleteone'        => 'borrar esto',
-'filehist-revert'           => 'revertir',
-'filehist-current'          => 'act',
-'filehist-datetime'         => 'Fecha/Hora',
-'filehist-user'             => 'Usuario',
-'filehist-dimensions'       => 'Dimesiones',
-'filehist-filesize'         => 'Tamaño',
-'filehist-comment'          => 'Comentario',
-'imagelinks'                => 'Enlaces a la imagen',
-'linkstoimage'              => 'Las siguientes páginas enlazan a esta imagen:',
-'nolinkstoimage'            => 'No hay páginas que enlacen a esta imagen.',
-'morelinkstoimage'          => 'Vea [[Special:Whatlinkshere/$1|más enlaces]] a este archivo.',
-'sharedupload'              => 'Este archivo está compartido y puede usarse desde otros proyectos.',
-'shareduploadwiki'          => 'Puede consultar $1 para más información.',
-'shareduploadwiki-linktext' => 'página de descripción del archivo',
-'noimage'                   => 'No existe un archivo con ese nombre, puede $1.',
-'noimage-linktext'          => 'subirlo',
-'uploadnewversion-linktext' => 'Subir una nueva versión de este archivo',
-'imagepage-searchdupe'      => 'Buscar archivos duplicados',
+'filehist-deleteall'             => 'borrar todo',
+'filehist-deleteone'             => 'borrar esto',
+'filehist-revert'                => 'revertir',
+'filehist-current'               => 'act',
+'filehist-datetime'              => 'Fecha/Hora',
+'filehist-user'                  => 'Usuario',
+'filehist-dimensions'            => 'Dimesiones',
+'filehist-filesize'              => 'Tamaño',
+'filehist-comment'               => 'Comentario',
+'imagelinks'                     => 'Enlaces a la imagen',
+'linkstoimage'                   => '{{PLURAL:$1|La siguiente página enlaza|Las siguientes páginas enlazan}} a este archivo:',
+'nolinkstoimage'                 => 'No hay páginas que enlacen a esta imagen.',
+'morelinkstoimage'               => 'Vea [[Special:WhatLinksHere/$1|más enlaces]] a este archivo.',
+'redirectstofile'                => '{{PLURAL:$1|El siguiente fichero redirige|Los siguientes $1 ficheros redirigen}} a este:',
+'duplicatesoffile'               => '{{PLURAL:$1|El siguiente archivo es un duplicado|Los siguientes $1 archivos son duplicados}} de este:',
+'sharedupload'                   => 'Este archivo está compartido y puede usarse desde otros proyectos.',
+'shareduploadwiki'               => 'Puede consultar $1 para más información.',
+'shareduploadwiki-linktext'      => 'página de descripción del archivo',
+'shareduploadduplicate-linktext' => 'otro fichero',
+'shareduploadconflict-linktext'  => 'otro fichero',
+'noimage'                        => 'No existe un archivo con ese nombre, puede $1.',
+'noimage-linktext'               => 'subirlo',
+'uploadnewversion-linktext'      => 'Subir una nueva versión de este archivo',
+'imagepage-searchdupe'           => 'Buscar archivos duplicados',
 
 # File reversion
-'filerevert'            => 'Revertir $1',
-'filerevert-intro'      => '<span class="plainlinks">Estás revirtiendo \'\'\'[[Media:$1|$1]]\'\'\' a la [version $4 desde la $3, $2].</span>',
-'filerevert-comment'    => 'Comentario:',
-'filerevert-submit'     => 'Revertir',
-'filerevert-success'    => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ha sido revertido a la [version $4 desde la $3, $2].</span>',
-'filerevert-badversion' => 'No existe version local previa de este archivo con esa marca de tiempo.',
+'filerevert'                => 'Revertir $1',
+'filerevert-legend'         => 'Reversión de archivos',
+'filerevert-intro'          => "Estás revirtiendo '''[[Media:$1|$1]]''' a la [version $4 desde la $3, $2].",
+'filerevert-comment'        => 'Comentario:',
+'filerevert-defaultcomment' => 'Revirtiendo a la versión subida el $1 a las $2',
+'filerevert-submit'         => 'Revertir',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ha sido revertido a la [version $4 desde la $3, $2].",
+'filerevert-badversion'     => 'No existe version local previa de este archivo con esa marca de tiempo.',
 
 # File deletion
 'filedelete'                  => 'Borrar $1',
 'filedelete-legend'           => 'Borrar archivo',
 'filedelete-intro'            => "Estás borrando '''[[Media:$1|$1]]'''.",
+'filedelete-intro-old'        => "Estás borrando la versión de '''[[Media:$1|$1]]''' del [$4 $2 a las $3].",
 'filedelete-comment'          => 'Motivo:',
 'filedelete-submit'           => 'Borrar',
 'filedelete-success'          => "'''$1''' ha sido borrado.",
+'filedelete-nofile'           => "El archivo '''$1''' no existe en {{SITENAME}}.",
 'filedelete-nofile-old'       => "No existe una versión guardada de '''$1''' con los atributos especificados.",
+'filedelete-otherreason'      => 'Otra razón:',
 'filedelete-reason-otherlist' => 'Otra razón',
+'filedelete-reason-dropdown'  => '*Razones de borrado habituales
+** Violación de copyright
+** Fichero duplicado',
+'filedelete-edit-reasonlist'  => 'Editar razones de borrado',
 
 # MIME search
-'mimesearch' => 'Búsqueda MIME',
-'mimetype'   => 'Tipo MIME:',
-'download'   => 'descargar',
+'mimesearch'         => 'Búsqueda MIME',
+'mimesearch-summary' => 'Esta página permite el filtrado de ficheros por su tipo MIME.
+Entrada: contenttype/subtype, p. ej. <tt>image/jpeg</tt>.',
+'mimetype'           => 'Tipo MIME:',
+'download'           => 'descargar',
 
 # Unwatched pages
 'unwatchedpages' => 'Páginas no vigiladas',
@@ -1223,9 +1280,11 @@
 En lugar de ello deberían enlazar con  el tema apropiado.<br />
 Una página es considerada página de desambiguación si utiliza la plantilla que está enlazada desde [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Redirecciones dobles',
-'doubleredirectstext' => '<b>Atención:</b> Esta lista puede contener falsos positivos. Eso significa usualmente que hay texto adicional con enlaces bajo el primer #REDIRECT.<br />
+'doubleredirects'            => 'Redirecciones dobles',
+'doubleredirectstext'        => '<b>Atención:</b> Esta lista puede contener falsos positivos. Eso significa usualmente que hay texto adicional con enlaces bajo el primer #REDIRECT.<br />
 Cada fila contiene enlaces al segundo y tercer redirect, así como la primera línea del segundo redirect, en la que usualmente se encontrará el artículo "real" al que el primer redirect debería apuntar.',
+'double-redirect-fixed-move' => '[[$1]] ha sido trasladado, ahora es una redirección a [[$2]]',
+'double-redirect-fixer'      => 'Corrector de redirecciones',
 
 'brokenredirects'        => 'Redirecciones incorrectas',
 'brokenredirectstext'    => 'Las redirecciones siguientes enlazan a un artículo que no existe.',
@@ -1234,6 +1293,7 @@
 
 'withoutinterwiki'         => 'Páginas sin interwikis',
 'withoutinterwiki-summary' => 'Las siguientes páginas no enlazan a versiones en otros idiomas:',
+'withoutinterwiki-legend'  => 'Prefijo',
 'withoutinterwiki-submit'  => 'Mostrar',
 
 'fewestrevisions' => 'Artículos con menos ediciones',
@@ -1257,6 +1317,7 @@
 'popularpages'            => 'Páginas populares',
 'wantedcategories'        => 'Categorías requeridas',
 'wantedpages'             => 'Páginas requeridas',
+'missingfiles'            => 'Ficheros que faltan',
 'mostlinked'              => 'Artículos más enlazados',
 'mostlinkedcategories'    => 'Categorías más enlazadas',
 'mostlinkedtemplates'     => 'Plantillas más enlazadas',
@@ -1289,6 +1350,7 @@
 'nopagetext'              => 'La página destino que ha especificado no existe.',
 'pager-newer-n'           => '{{PLURAL:$1|1 siguiente|$1 siguientes}}',
 'pager-older-n'           => '{{PLURAL:$1|1 anterior|$1 anteriores}}',
+'suppress'                => 'Supervisor',
 
 # Book sources
 'booksources'               => 'Fuentes de libros',
@@ -1308,7 +1370,7 @@
 'logempty'             => 'No hay elementos en el registro con esas condiciones.',
 'log-title-wildcard'   => 'Buscar títulos que empiecen con este texto',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Todas las páginas',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Siguiente página ($1)',
@@ -1331,15 +1393,15 @@
 'special-categories-sort-count' => 'ordenar por conteo',
 'special-categories-sort-abc'   => 'ordenar alfabéticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mostrar usuarios que empiecen por:',
 'listusers-submit'   => 'Mostrar',
 'listusers-noresult' => 'No se encontró al usuario.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Permisos del grupo de usuarios',
 'listgrouprights-summary'  => 'La siguiente es una lista de los grupos de usuario definidos en esta wiki, y de sus privilegios de acceso asociados.
-Información adicional sobre privilegios individuales pueden ser hallados en [[{{MediaWiki:Listgrouprights-helppage}}]]',
+Puede haber información adicional sobre privilegios individuales en [[{{MediaWiki:Listgrouprights-helppage}}]]',
 'listgrouprights-group'    => 'Grupo',
 'listgrouprights-rights'   => 'Derechos',
 'listgrouprights-helppage' => 'Help:Derechos de grupos',
@@ -1347,7 +1409,7 @@
 
 # E-mail user
 'mailnologin'     => 'No enviar dirección',
-'mailnologintext' => 'Debes [[Special:Userlogin|iniciar sesión]] y tener una dirección electrónica válida en tus [[Special:Preferences|preferencias]] para enviar un correo electrónico a otros usuarios.',
+'mailnologintext' => 'Debes [[Special:UserLogin|iniciar sesión]] y tener una dirección electrónica válida en tus [[Special:Preferences|preferencias]] para enviar un correo electrónico a otros usuarios.',
 'emailuser'       => 'Enviar correo electrónico a este usuario',
 'emailpage'       => 'Correo electrónico a usuario',
 'emailpagetext'   => 'Si este usuario ha registrado una dirección electrónica válida en sus preferencias de usuario, el siguiente formulario sirve para enviarle un mensaje.
@@ -1365,6 +1427,7 @@
 'emailccsubject'  => 'Copia de tu mensaje a $1: $2',
 'emailsent'       => 'Correo electrónico enviado',
 'emailsenttext'   => 'Su correo electrónico ha sido enviado.',
+'emailuserfooter' => 'Este correo electrónico fue enviado por $1 a $2 a través de la función «Enviar correo electrónico a este usuario» en {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Lista de seguimiento',
@@ -1373,9 +1436,9 @@
 'nowatchlist'          => 'No tiene ninguna página en su lista de seguimiento.',
 'watchlistanontext'    => 'Para ver o editar las entradas de tu lista de seguimiento es necesario $1.',
 'watchnologin'         => 'No ha iniciado sesión',
-'watchnologintext'     => 'Debes [[Special:Userlogin|iniciar sesión]] para modificar tu lista de seguimiento.',
+'watchnologintext'     => 'Debes [[Special:UserLogin|iniciar sesión]] para modificar tu lista de seguimiento.',
 'addedwatch'           => 'Añadido a la lista de seguimiento',
-'addedwatchtext'       => "La página «[[:\$1]]» ha sido añadida a tu [[Special:Watchlist|lista se seguimiento]]. Cambios futuros en esta página y su página de discusión asociada se indicarán ahí, y la página aparecerá '''en negritas''' en la [[Special:Recentchanges|lista de cambios recientes]] para hacerla más fácil de detectar. <p>Cuando quieras eliminar la página de tu lista de seguimiento, presiona \"Dejar de vigilar\" en el menú.",
+'addedwatchtext'       => "La página «[[:\$1]]» ha sido añadida a tu [[Special:Watchlist|lista se seguimiento]]. Cambios futuros en esta página y su página de discusión asociada se indicarán ahí, y la página aparecerá '''en negritas''' en la [[Special:RecentChanges|lista de cambios recientes]] para hacerla más fácil de detectar. <p>Cuando quieras eliminar la página de tu lista de seguimiento, presiona \"Dejar de vigilar\" en el menú.",
 'removedwatch'         => 'Eliminada de la lista de seguimiento',
 'removedwatchtext'     => 'La página "[[:$1]]" ha sido eliminada de su lista de seguimiento.',
 'watch'                => 'Vigilar',
@@ -1458,26 +1521,29 @@
 'deletedtext'                 => '"<nowiki>$1</nowiki>" ha sido borrado.
 Véase $2 para un registro de los borrados recientes.',
 'deletedarticle'              => 'borró "$1"',
+'suppressedarticle'           => 'se ha suprimido «[[$1]]»',
 'dellogpage'                  => 'Registro de borrados',
 'dellogpagetext'              => 'A continuación se muestra una lista de los borrados más recientes. Todos los tiempos se muestran en hora del servidor (UTC).',
 'deletionlog'                 => 'registro de borrados',
 'reverted'                    => 'Recuperar una revisión anterior',
 'deletecomment'               => 'Motivo del borrado',
-'deleteotherreason'           => 'Otra/adicional razón:',
+'deleteotherreason'           => 'Otra razón:',
 'deletereasonotherlist'       => 'Otra razón',
 'deletereason-dropdown'       => '*Razones comunes de borrado
 ** A petición del mismo autor
 ** Violación de copyright
 ** Vandalismo',
 'delete-edit-reasonlist'      => 'Editar razones de borrado',
-'delete-toobig'               => 'Esta página tiene un historial muy grande, de unas $1 revisiones. Borrar este tipo de páginas ha sido restringido para prevenir accidentes en {{SITENAME}}.',
-'delete-warning-toobig'       => 'Esta página tiene un historial de más de $1 revisiones. Eliminarla puede perturbar las operaciones de la base de datos de {{SITENAME}}. Ten cuidado al borrar.',
+'delete-toobig'               => 'Esta página tiene un historial muy grande, con más de $1 {{PLURAL:$1|revisión|revisiones}}. Borrar este tipo de páginas ha sido restringido para prevenir posibles problemas en {{SITENAME}}.',
+'delete-warning-toobig'       => 'Esta página tiene un historial de más de {{PLURAL:$1|revisión|revisiones}}. Eliminarla puede perturbar las operaciones de la base de datos de {{SITENAME}}. Ten cuidado al borrar.',
 'rollback'                    => 'Revertir ediciones',
 'rollback_short'              => 'Revertir',
 'rollbacklink'                => 'Revertir',
 'rollbackfailed'              => 'No se pudo revertir',
 'cantrollback'                => 'No se pueden revertir las ediciones; el último colaborador es el único autor de este artículo.',
-'alreadyrolled'               => 'No se puede revertir la última edición de [[$1]] por [[User:$2|$2]] ([[User talk:$2|discusión]]); alguien más ya ha editado o revertido esa página. La última edición fue hecha por [[User:$3|$3]] ([[User talk:$3|discusión]]).',
+'alreadyrolled'               => 'No se puede revertir la última edición de [[:$1]] hecha por [[User:$2|$2]] ([[User talk:$2|discusión]] | [[Special:Contributions/$2|{{int:contribslink}}]]); alguien más ya ha editado o revertido esa página.
+
+La última edición fue hecha por [[User:$3|$3]] ([[User talk:$3|discusión]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'El resumen de la edición es: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Revertidas las ediciones de [[Special:Contributions/$2|$2]] ([[User talk:$2|Discusión]]) a la última edición de [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Revertidas las ediciones de $1; recuperada la última versión de $2.',
@@ -1485,7 +1551,7 @@
 esta acción ha sido cancelada como medida de precaución contra secuestros de sesión.
 Por favor, pulsa "Atrás", recarga la página de la que viniste e inténtalo de nuevo.',
 'protectlogpage'              => 'Protecciones de páginas',
-'protectlogtext'              => 'Abajo se presenta una lista de protección y desprotección de página. Véase [[Special:Protectedpages|Esta página está protegida]] para más información.',
+'protectlogtext'              => 'Abajo se presenta una lista de protección y desprotección de página. Véase [[Special:ProtectedPages|Esta página está protegida]] para más información.',
 'protectedarticle'            => 'protegió [[$1]]',
 'modifiedarticleprotection'   => 'Cambiado el nivel de protección de "[[$1]]"',
 'unprotectedarticle'          => 'desprotegió [[$1]]',
@@ -1521,6 +1587,7 @@
 'restriction-edit'   => 'Pueden editar',
 'restriction-move'   => 'Pueden trasladar',
 'restriction-create' => 'Crear',
+'restriction-upload' => 'Subir',
 
 # Restriction levels
 'restriction-level-sysop'         => 'completamente protegida',
@@ -1533,6 +1600,7 @@
 'undeletepagetitle'        => "'''Las siguientes son las revisiones borradas de [[:$1|$1]]'''.",
 'viewdeletedpage'          => 'Ver páginas borradas',
 'undeletepagetext'         => 'Las siguientes páginas han sido borradas pero aún están en el archivo y pueden ser restauradas. El archivo se puede limpiar periódicamente.',
+'undelete-fieldset-title'  => 'Restaurar revisiones',
 'undeleteextrahelp'        => "Para restaurar todas las revisiones, deja todas las casillas sin seleccionar y pulsa '''¡Restaurar!'''. Para restaurar sólo algunas revisiones, marca las revisiones que quieres restaurar y pulsa '''¡Restaurar!'''. Haciendo clic en al botón '''Nada''', se deseleccionarán todas las casillas y eliminará el comentario actual.",
 'undeleterevisions'        => '$1 {{PLURAL:$1|revisión|revisiones}} archivadas',
 'undeletehistory'          => 'Si restaura una página, todas sus revisiones serán restauradas al historial. Si una nueva página con el mismo nombre ha sido creada desde que se borró la original, las versiones restauradas aparecerán como historial anterior, y la revisión actual de la página actual no se reemplazará automáticamente.',
@@ -1580,7 +1648,7 @@
 'year'          => 'Desde el año (y anterior):',
 
 'sp-contributions-newbies'     => 'Mostrar solo las contribuciones de usuarios nuevos',
-'sp-contributions-newbies-sub' => 'Para nuevos',
+'sp-contributions-newbies-sub' => 'Para cuentas nuevas',
 'sp-contributions-blocklog'    => 'Registro de bloqueos',
 'sp-contributions-search'      => 'Buscar contribuciones',
 'sp-contributions-username'    => 'Dirección IP o nombre de usuario:',
@@ -1588,7 +1656,7 @@
 
 # What links here
 'whatlinkshere'            => 'Lo que enlaza aquí',
-'whatlinkshere-title'      => 'Páginas que enlazan a $1',
+'whatlinkshere-title'      => 'Páginas que enlazan con «$1»',
 'whatlinkshere-page'       => 'Página:',
 'linklistsub'              => '(Lista de enlaces)',
 'linkshere'                => "Las siguientes páginas enlazan a '''[[:$1]]''':",
@@ -1596,6 +1664,7 @@
 'nolinkshere-ns'           => "Ninguna página enlaza con '''[[:$1]]''' en el espacio de nombres elegido.",
 'isredirect'               => 'página redirigida',
 'istemplate'               => 'inclusión',
+'isimage'                  => 'Enlace de imagen',
 'whatlinkshere-prev'       => '{{PLURAL:$1|previa|previas $1}}',
 'whatlinkshere-next'       => '{{PLURAL:$1|siguiente|siguientes $1}}',
 'whatlinkshere-links'      => '← enlaces',
@@ -1603,22 +1672,23 @@
 'whatlinkshere-hidetrans'  => '$1 inclusiones',
 'whatlinkshere-hidelinks'  => '$1 enlaces',
 'whatlinkshere-hideimages' => '$1 enlaces a imágenes',
+'whatlinkshere-filters'    => 'Filtros',
 
 # Block/unblock
-'blockip'                     => 'Bloquear usuario',
-'blockip-legend'              => 'Bloquear usuario',
-'blockiptext'                 => 'Usa el formulario siguiente para bloquear el
+'blockip'                         => 'Bloquear usuario',
+'blockip-legend'                  => 'Bloquear usuario',
+'blockiptext'                     => 'Usa el formulario siguiente para bloquear el
 acceso de escritura desde una dirección IP específica o un nombre de usuario.
 Esto debería hacerse sólo para prevenir vandalismos, y de
 acuerdo a las [[{{MediaWiki:Policy-url}}|políticas]].
 Explica la razón específica del bloqueo (por ejemplo, citando
 las páginas en particular que han sido objeto de vandalismo).',
-'ipaddress'                   => 'Dirección IP',
-'ipadressorusername'          => 'Dirección IP o nombre de usuario',
-'ipbexpiry'                   => 'Caduca dentro de',
-'ipbreason'                   => 'Razón',
-'ipbreasonotherlist'          => 'Otra razón',
-'ipbreason-dropdown'          => '
+'ipaddress'                       => 'Dirección IP',
+'ipadressorusername'              => 'Dirección IP o nombre de usuario',
+'ipbexpiry'                       => 'Caduca dentro de',
+'ipbreason'                       => 'Razón',
+'ipbreasonotherlist'              => 'Otra razón',
+'ipbreason-dropdown'              => '
 *Motivos comunes de bloqueo
 ** Añadir información falsa
 ** Eliminar contenido de las páginas
@@ -1627,66 +1697,69 @@
 ** Comportamiento intimidatorio/acoso sexual
 ** Abusar de múltiples cuentas
 ** Nombre de usuario inaceptable',
-'ipbanononly'                 => 'Bloquear usuarios anónimos solamente',
-'ipbcreateaccount'            => 'Prevenir creación de cuenta de usuario.',
-'ipbemailban'                 => 'Prevenir que los usuarios envien correo electrónico',
-'ipbenableautoblock'          => 'Bloquear automáticamente la dirección IP usada por este usuario, y cualquier IP posterior desde la cual intente editar',
-'ipbsubmit'                   => 'Bloquear a este usuario',
-'ipbother'                    => 'Especificar caducidad',
-'ipboptions'                  => '2 horas:2 hours,1 día:1 day,3 días:3 days,1 semana:1 week,2 semanas:2 weeks,1 mes:1 month,3 meses:3 months,6 meses:6 months,1 año:1 year,Para siempre:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'otro',
-'ipbotherreason'              => 'Otro/adicional motivo:',
-'ipbhidename'                 => 'Ocultar usuario/IP en el registro de bloqueos, la lista de bloqueos activos y la lista de usuarios',
-'ipbwatchuser'                => 'Vigilar las páginas de usuario y de discusión de este usuario',
-'badipaddress'                => 'La dirección IP no tiene el formato correcto.',
-'blockipsuccesssub'           => 'Bloqueo realizado con éxito',
-'blockipsuccesstext'          => 'La dirección IP "$1" ha sido bloqueada. <br />Ver [[Special:Ipblocklist|lista de IP bloqueadas]] para revisar bloqueos.',
-'ipb-edit-dropdown'           => 'Editar motivo del bloqueo',
-'ipb-unblock-addr'            => 'Desbloquear $1',
-'ipb-unblock'                 => 'Desbloquear un usuario o una IP',
-'ipb-blocklist-addr'          => 'Muestra bloqueos vigentes de $1',
-'ipb-blocklist'               => 'Ver bloqueos vigentes',
-'unblockip'                   => 'Desbloquear usuario',
-'unblockiptext'               => 'Use el formulario a continuación para devolver los permisos de escritura a una dirección IP que ha sido bloqueada.',
-'ipusubmit'                   => 'Desbloquear esta dirección',
-'unblocked'                   => '[[User:$1|$1]] ha sido desbloqueado',
-'unblocked-id'                => 'Se ha eliminado el bloqueo $1',
-'ipblocklist'                 => 'Lista de direcciones IP bloqueadas',
-'ipblocklist-legend'          => 'Encontrar a un usuario bloqueado',
-'ipblocklist-username'        => 'Nombre de usuario o dirección IP:',
-'ipblocklist-submit'          => 'Buscar',
-'blocklistline'               => '$1, $2 bloquea a $3 ($4)',
-'infiniteblock'               => 'infinito',
-'expiringblock'               => 'expira $1',
-'anononlyblock'               => 'sólo anón.',
-'noautoblockblock'            => 'Bloqueo automático deshabilitado',
-'createaccountblock'          => 'Creación de cuenta bloqueada.',
-'emailblock'                  => 'correo electrónico bloqueado',
-'ipblocklist-empty'           => 'La lista de bloqueos está vacía.',
-'ipblocklist-no-results'      => 'El nombre de usuario o IP indicado no está bloqueado.',
-'blocklink'                   => 'bloquear',
-'unblocklink'                 => 'desbloquear',
-'contribslink'                => 'contribuciones',
-'autoblocker'                 => 'Has sido bloqueado automáticamente porque tu dirección IP ha sido usada recientemente por "[[User:$1|$1]]". La razón esgrimida para bloquear a "[[User:$1|$1]]" fue "$2".',
-'blocklogpage'                => 'Bloqueos de usuarios',
-'blocklogentry'               => 'bloqueó a "$1" $3 durante un plazo de "$2".',
-'blocklogtext'                => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:Ipblocklist|lista de direcciones IP bloqueadas]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
-'unblocklogentry'             => 'desbloqueó a "$1"',
-'block-log-flags-anononly'    => 'sólo anónimos',
-'block-log-flags-nocreate'    => 'desactivada la creación de cuentas',
-'block-log-flags-noautoblock' => 'bloqueo automático desactivado',
-'block-log-flags-noemail'     => 'correo electrónico deshabilitado',
-'range_block_disabled'        => 'La facultad de administrador de crear bloqueos por rangos está deshabilitada.',
-'ipb_expiry_invalid'          => 'El tiempo de caducidad no es válido.',
-'ipb_already_blocked'         => '"$1" ya se encuentra bloqueado.',
-'ipb_cant_unblock'            => "'''Error''': Número ID $1 de bloqueo no encontrado. Pudo haber sido desbloqueado ya.",
-'ip_range_invalid'            => 'El rango de IP no es válido.',
-'proxyblocker'                => 'Bloqueador de proxies',
-'proxyblocker-disabled'       => 'Esta función está deshabilitada.',
-'proxyblockreason'            => 'Su dirección IP ha sido bloqueada porque es un proxy abierto. Por favor, contacte con su proveedor de servicios de Internet o con su servicio de asistencia técnica e infórmeles de este grave problema de seguridad.',
-'proxyblocksuccess'           => 'Hecho.',
-'sorbsreason'                 => 'Su dirección IP está listada como proxy abierto en DNSBL.',
-'sorbs_create_account_reason' => 'Su dirección IP está listada como proxy abierto en DNSBL. No puede crear una cuenta',
+'ipbanononly'                     => 'Bloquear usuarios anónimos solamente',
+'ipbcreateaccount'                => 'Prevenir creación de cuenta de usuario.',
+'ipbemailban'                     => 'Prevenir que los usuarios envien correo electrónico',
+'ipbenableautoblock'              => 'Bloquear automáticamente la dirección IP usada por este usuario, y cualquier IP posterior desde la cual intente editar',
+'ipbsubmit'                       => 'Bloquear a este usuario',
+'ipbother'                        => 'Especificar caducidad',
+'ipboptions'                      => '2 horas:2 hours,1 día:1 day,3 días:3 days,1 semana:1 week,2 semanas:2 weeks,1 mes:1 month,3 meses:3 months,6 meses:6 months,1 año:1 year,Para siempre:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'otro',
+'ipbotherreason'                  => 'Otra razón:',
+'ipbhidename'                     => 'Ocultar usuario/IP en el registro de bloqueos, la lista de bloqueos activos y la lista de usuarios',
+'ipbwatchuser'                    => 'Vigilar las páginas de usuario y de discusión de este usuario',
+'badipaddress'                    => 'La dirección IP no tiene el formato correcto.',
+'blockipsuccesssub'               => 'Bloqueo realizado con éxito',
+'blockipsuccesstext'              => 'La dirección IP "$1" ha sido bloqueada. <br />Ver [[Special:IPBlockList|lista de IP bloqueadas]] para revisar bloqueos.',
+'ipb-edit-dropdown'               => 'Editar motivo del bloqueo',
+'ipb-unblock-addr'                => 'Desbloquear $1',
+'ipb-unblock'                     => 'Desbloquear un usuario o una IP',
+'ipb-blocklist-addr'              => 'Muestra bloqueos vigentes de $1',
+'ipb-blocklist'                   => 'Ver bloqueos vigentes',
+'unblockip'                       => 'Desbloquear usuario',
+'unblockiptext'                   => 'Use el formulario a continuación para devolver los permisos de escritura a una dirección IP que ha sido bloqueada.',
+'ipusubmit'                       => 'Desbloquear esta dirección',
+'unblocked'                       => '[[User:$1|$1]] ha sido desbloqueado',
+'unblocked-id'                    => 'Se ha eliminado el bloqueo $1',
+'ipblocklist'                     => 'Lista de direcciones IP bloqueadas',
+'ipblocklist-legend'              => 'Encontrar a un usuario bloqueado',
+'ipblocklist-username'            => 'Nombre de usuario o dirección IP:',
+'ipblocklist-submit'              => 'Buscar',
+'blocklistline'                   => '$1, $2 bloquea a $3 ($4)',
+'infiniteblock'                   => 'infinito',
+'expiringblock'                   => 'expira $1',
+'anononlyblock'                   => 'sólo anón.',
+'noautoblockblock'                => 'Bloqueo automático deshabilitado',
+'createaccountblock'              => 'Creación de cuenta bloqueada.',
+'emailblock'                      => 'correo electrónico bloqueado',
+'ipblocklist-empty'               => 'La lista de bloqueos está vacía.',
+'ipblocklist-no-results'          => 'El nombre de usuario o IP indicado no está bloqueado.',
+'blocklink'                       => 'bloquear',
+'unblocklink'                     => 'desbloquear',
+'contribslink'                    => 'contribuciones',
+'autoblocker'                     => 'Has sido bloqueado automáticamente porque tu dirección IP ha sido usada recientemente por "[[User:$1|$1]]". La razón esgrimida para bloquear a "[[User:$1|$1]]" fue "$2".',
+'blocklogpage'                    => 'Bloqueos de usuarios',
+'blocklogentry'                   => 'bloqueó a "$1" $3 durante un plazo de "$2".',
+'blocklogtext'                    => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:IPBlockList|lista de direcciones IP bloqueadas]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
+'unblocklogentry'                 => 'desbloqueó a "$1"',
+'block-log-flags-anononly'        => 'sólo anónimos',
+'block-log-flags-nocreate'        => 'desactivada la creación de cuentas',
+'block-log-flags-noautoblock'     => 'bloqueo automático desactivado',
+'block-log-flags-noemail'         => 'correo electrónico deshabilitado',
+'block-log-flags-angry-autoblock' => 'activado el autobloqueo avanzado',
+'range_block_disabled'            => 'La facultad de administrador de crear bloqueos por rangos está deshabilitada.',
+'ipb_expiry_invalid'              => 'El tiempo de caducidad no es válido.',
+'ipb_expiry_temp'                 => 'Los bloqueos a nombres de usuario ocultos deben ser permanentes.',
+'ipb_already_blocked'             => '"$1" ya se encuentra bloqueado.',
+'ipb_cant_unblock'                => "'''Error''': Número ID $1 de bloqueo no encontrado. Pudo haber sido desbloqueado ya.",
+'ip_range_invalid'                => 'El rango de IP no es válido.',
+'blockme'                         => 'Bloqueame',
+'proxyblocker'                    => 'Bloqueador de proxies',
+'proxyblocker-disabled'           => 'Esta función está deshabilitada.',
+'proxyblockreason'                => 'Su dirección IP ha sido bloqueada porque es un proxy abierto. Por favor, contacte con su proveedor de servicios de Internet o con su servicio de asistencia técnica e infórmeles de este grave problema de seguridad.',
+'proxyblocksuccess'               => 'Hecho.',
+'sorbsreason'                     => 'Su dirección IP está listada como proxy abierto en DNSBL.',
+'sorbs_create_account_reason'     => 'Su dirección IP está listada como proxy abierto en DNSBL. No puede crear una cuenta',
 
 # Developer tools
 'lockdb'              => 'Bloquear la base de datos',
@@ -1716,12 +1789,12 @@
 Tú eres responsable de hacer que los enlaces sigan apuntando adonde se supone que deberían hacerlo.
 
 
-Recuerda que la página '''no''' será renombrada si ya existe una página con el nuevo título, a no ser que sea una página vacía o un ''redirect'' sin historial.
+Recuerda que la página '''no''' será renombrada si ya existe una página con el nuevo título, a no ser que sea una página vacía o una redirección sin historial.
 Esto significa que podrás renombrar una página a su título original si has cometido un error, pero que no podrás sobreescribir una página existente.
 
 '''¡ADVERTENCIA!'''
 Este puede ser un cambio drástico e inesperado para una página popular;
-por favor, asegúrate de entender las consecuencias que acarreará antes de seguir adelante.",
+por favor, asegúrate de entender las consecuencias del procedimiento antes de seguir adelante.",
 'movepagetalktext'        => "La página de discusión asociada, si existe, será renombrada automáticamente '''a menos que:'''
 *Esté moviendo la página entre espacios de nombres diferentes,
 *Una página de discusión no vacía ya exista con el nombre nuevo, o
@@ -1729,8 +1802,6 @@
 
 En estos casos, deberá trasladar manualmente el contenido de la página de discusión.",
 'movearticle'             => 'Renombrar página',
-'movenologin'             => 'No ha iniciado sesión',
-'movenologintext'         => 'Es necesario ser usuario registrado y [[Special:Userlogin|haber iniciado sesión]] para renombrar una página.',
 'movenotallowed'          => 'No tienes permiso para trasladar páginas en {{SITENAME}}.',
 'newtitle'                => 'A título nuevo',
 'move-watch'              => 'Vigilar este artículo',
@@ -1757,11 +1828,13 @@
 'delete_and_move'         => 'Borrar y trasladar',
 'delete_and_move_text'    => '==Se necesita borrado==
 
-La página de destino ("[[$1]]") ya existe. ¿Quiere borrarla para permitir al traslado?',
+La página de destino ("[[:$1]]") ya existe. ¿Quiere borrarla para permitir al traslado?',
 'delete_and_move_confirm' => 'Sí, borrar la página',
 'delete_and_move_reason'  => 'Borrada para permitir el traslado',
 'selfmove'                => 'Los títulos de origen y destino son los mismos. No se puede trasladar un página sobre sí misma.',
 'immobile_namespace'      => 'El título de destino es de un tipo especial. No se pueden trasladar páginas a ese espacio de nombres.',
+'imageinvalidfilename'    => 'El nombre del fichero de destino no es válido',
+'fix-double-redirects'    => 'Actualizar las redirecciones que apuntan al título original',
 
 # Export
 'export'            => 'Exportar páginas',
@@ -1776,6 +1849,7 @@
 'export-submit'     => 'Exportar',
 'export-addcattext' => 'Añadir páginas desde la categoría:',
 'export-addcat'     => 'Añadir',
+'export-download'   => 'Guardar como fichero',
 'export-templates'  => 'Incluir plantillas',
 
 # Namespace 8 related
@@ -1819,6 +1893,7 @@
 'importhistoryconflict'      => 'Existen revisiones en conflicto en el historial (puede que se haya importado esta página antes)',
 'importnosources'            => 'No hay fuentes de importación transwiki y no está permitido subir directamente el historial.',
 'importnofile'               => 'No se subieron archivos de importación.',
+'import-noarticle'           => '¡No hay páginas para importar!',
 
 # Import log
 'importlogpage'                    => 'Registro de importaciones',
@@ -1952,10 +2027,14 @@
 'patrol-log-auto' => '(automático)',
 
 # Image deletion
-'deletedrevision'       => 'Borrada revisión antigua $1',
-'filedeleteerror-short' => 'Se produjo un error al borrar el archivo: $1',
-'filedelete-missing'    => 'No se pudo borrar el archivo "$1" porque no existe.',
+'deletedrevision'                 => 'Borrada revisión antigua $1',
+'filedeleteerror-short'           => 'Se produjo un error al borrar el archivo: $1',
+'filedeleteerror-long'            => 'Se han producido errores mientras se borraba el fichero:
 
+$1',
+'filedelete-missing'              => 'No se pudo borrar el archivo "$1" porque no existe.',
+'filedelete-current-unregistered' => 'El archivo «$1» no existe en la base de datos.',
+
 # Browsing diffs
 'previousdiff' => '← Ir a diferencias anteriores',
 'nextdiff'     => 'Ir a las siguientes diferencias →',
@@ -1972,9 +2051,10 @@
 'show-big-image'       => 'Resolución original',
 'show-big-image-thumb' => '<small>Tamaño de esta vista previa: $1 × $2 píxeles</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galería de imágenes nuevas',
 'imagelisttext'         => "Debajo hay una lista de '''$1''' {{PLURAL:$1|imagen|imágenes}} ordenadas $2.",
+'newimages-summary'     => 'Esta página especial muestra una galería de los últimos ficheros subidos.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'No hay nada que ver.',
 'ilsubmit'              => 'Búsqueda',
@@ -2063,6 +2143,7 @@
 'exif-subjectdistance'             => 'Distancia al sujeto',
 'exif-meteringmode'                => 'Modo de medición',
 'exif-lightsource'                 => 'Fuente de luz',
+'exif-flash'                       => 'Flash',
 'exif-focallength'                 => 'Longitud de la lente focal',
 'exif-subjectarea'                 => 'Área del sujeto',
 'exif-flashenergy'                 => 'Energía del flash',
@@ -2165,6 +2246,7 @@
 'exif-lightsource-1'   => 'Luz diurna',
 'exif-lightsource-2'   => 'Fluorescente',
 'exif-lightsource-3'   => 'Tungsteno (luz incandescente)',
+'exif-lightsource-4'   => 'Flash',
 'exif-lightsource-9'   => 'Buen tiempo',
 'exif-lightsource-10'  => 'Tiempo nublado',
 'exif-lightsource-11'  => 'Penumbra',
@@ -2211,16 +2293,20 @@
 'exif-gaincontrol-3' => 'Baja disminución de ganancia',
 'exif-gaincontrol-4' => 'Alta disminución de ganancia',
 
+'exif-contrast-0' => 'Normal',
 'exif-contrast-1' => 'Suave',
 'exif-contrast-2' => 'Duro',
 
+'exif-saturation-0' => 'Normal',
 'exif-saturation-1' => 'Baja saturación',
 'exif-saturation-2' => 'Alta saturación',
 
+'exif-sharpness-0' => 'Normal',
 'exif-sharpness-1' => 'Suave',
 'exif-sharpness-2' => 'Dura',
 
 'exif-subjectdistancerange-0' => 'Desconocida',
+'exif-subjectdistancerange-1' => 'Macro',
 'exif-subjectdistancerange-2' => 'Vista cercana',
 'exif-subjectdistancerange-3' => 'Vista lejana',
 
@@ -2249,7 +2335,7 @@
 
 # External editor support
 'edit-externally'      => 'Editar este archivo usando una aplicación externa',
-'edit-externally-help' => 'Lee las [http://meta.wikimedia.org/wiki/Help:External_editors instrucciones de configuración] (en inglés) para más información.',
+'edit-externally-help' => 'Lee las [http://www.mediawiki.org/wiki/Manual:External_editors instrucciones de configuración] (en inglés) para más información.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'todos',
@@ -2259,27 +2345,27 @@
 'monthsall'        => '(todos)',
 
 # E-mail address confirmation
-'confirmemail'            => 'Confirmar dirección E-mail',
-'confirmemail_noemail'    => 'No tienes una dirección de correo electrónico válida en tus [[Special:Preferences|preferencias de usuario]].',
-'confirmemail_text'       => 'Este wiki requiere que valide su dirección de correo antes de usarlo. Pulse el botón de abajo para enviar la confirmación.
+'confirmemail'             => 'Confirmar dirección E-mail',
+'confirmemail_noemail'     => 'No tienes una dirección de correo electrónico válida en tus [[Special:Preferences|preferencias de usuario]].',
+'confirmemail_text'        => 'Este wiki requiere que valide su dirección de correo antes de usarlo. Pulse el botón de abajo para enviar la confirmación.
 El correo incluirá un enlace con un código. Introdúzcalo para confirmar la validez de su dirección.',
-'confirmemail_pending'    => '<div class="error">
+'confirmemail_pending'     => '<div class="error">
 Ya se te ha enviado un código de confirmación; si creaste una cuenta recientemente, puede que tengas que esperar unos minutos para que te llegue antes de intentar pedir un nuevo código.
 </div>',
-'confirmemail_send'       => 'Envíar el código de confimación.',
-'confirmemail_sent'       => 'Confirmación de correo enviada.',
-'confirmemail_oncreate'   => 'Se ha enviado un código de confirmación a tu dirección de correo electrónico.
+'confirmemail_send'        => 'Envíar el código de confimación.',
+'confirmemail_sent'        => 'Confirmación de correo enviada.',
+'confirmemail_oncreate'    => 'Se ha enviado un código de confirmación a tu dirección de correo electrónico.
 Este código no es necesario para entrar, pero necesitarás darlo antes de activar cualquier función basada en correo electrónico en el wiki.',
-'confirmemail_sendfailed' => 'No fue posible enviar el correo de confirmación. Por favor, compruebe que no haya caracteres inválidos en la dirección de correo indicada.
+'confirmemail_sendfailed'  => 'No fue posible enviar el correo de confirmación. Por favor, compruebe que no haya caracteres inválidos en la dirección de correo indicada.
 
 Correo devuelto: $1',
-'confirmemail_invalid'    => 'Código de confirmación incorrecto. El código debe haber expirado.',
-'confirmemail_needlogin'  => 'Necesitas $1 para confirmar tu dirección electrónica.',
-'confirmemail_success'    => 'Su dirección de correo ha sido confirmada. Ahora puedes registrarse y colaborar en el wiki.',
-'confirmemail_loggedin'   => 'Tu dirección e-mail ha sido confirmada.',
-'confirmemail_error'      => 'Algo salió mal al guardar su confirmación.',
-'confirmemail_subject'    => 'confirmación de la dirección de correo de {{SITENAME}}',
-'confirmemail_body'       => 'Alguien, probablemente usted mismo, ha registrado una cuenta "$2" con esta dirección de correo en {{SITENAME}}, desde la dirección IP $1.
+'confirmemail_invalid'     => 'Código de confirmación incorrecto. El código debe haber expirado.',
+'confirmemail_needlogin'   => 'Necesitas $1 para confirmar tu dirección electrónica.',
+'confirmemail_success'     => 'Su dirección de correo ha sido confirmada. Ahora puedes registrarse y colaborar en el wiki.',
+'confirmemail_loggedin'    => 'Tu dirección e-mail ha sido confirmada.',
+'confirmemail_error'       => 'Algo salió mal al guardar su confirmación.',
+'confirmemail_subject'     => 'confirmación de la dirección de correo de {{SITENAME}}',
+'confirmemail_body'        => 'Alguien, probablemente usted mismo, ha registrado una cuenta "$2" con esta dirección de correo en {{SITENAME}}, desde la dirección IP $1.
 
 Para confirmar que esta cuenta realmente le pertenece y activar el correo en {{SITENAME}}, siga este enlace:
 
@@ -2290,6 +2376,8 @@
 $5
 
 El código de confirmación expirará en $4.',
+'confirmemail_invalidated' => 'La confirmación de la dirección de correo electrónico ha sido cancelada',
+'invalidateemail'          => 'Cancelar confirmación de correo electrónico',
 
 # Scary transclusion
 'scarytranscludedisabled' => '[Transclusión interwiki está deshabilitada]',
@@ -2310,7 +2398,7 @@
 'recreate'            => 'Crear de nuevo',
 
 # HTML dump
-'redirectingto' => 'Redirigiendo a [[$1]]...',
+'redirectingto' => 'Redirigiendo a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => '¿Limpiar la caché de esta página?
@@ -2329,8 +2417,11 @@
 'imgmultipageprev' => '← página anterior',
 'imgmultipagenext' => 'siguiente página →',
 'imgmultigo'       => '¡Ir!',
+'imgmultigoto'     => 'Ir a la página $1',
 
 # Table pager
+'ascending_abbrev'         => 'asc',
+'descending_abbrev'        => 'desc',
 'table_pager_next'         => 'Página siguiente',
 'table_pager_prev'         => 'Página anterior',
 'table_pager_first'        => 'Primera página',
@@ -2354,8 +2445,8 @@
 Intenta la previsualización normal.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Los cambios realizados en los últimos $1 segundos pueden no ser mostrados en esta lista.',
-'lag-warn-high'   => 'Debido a una alta latencia el servidor de base de datos, los cambios realizados en los últimos $1 segundos pueden no ser mostrados en esta lista.',
+'lag-warn-normal' => 'Los cambios realizados en {{PLURAL:$1|el último segundo|los últimos $1 segundos}} pueden no ser mostrados en esta lista.',
+'lag-warn-high'   => 'Debido a una alta latencia el servidor de base de datos, los cambios realizados en {{PLURAL:$1|el último segundo|los últimos $1 segundos}} pueden no ser mostrados en esta lista.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Tu lista de seguimiento tiene {{PLURAL:$1|una página |$1 páginas}}, excluyendo las páginas de discusión.',
@@ -2385,15 +2476,20 @@
 'watchlisttools-raw'  => 'Editar lista de seguimiento en crudo',
 
 # Special:Version
-'version'                  => 'Versión', # Not used as normal message but as header for the special page itself
-'version-extensions'       => 'Extensiones instaladas',
-'version-specialpages'     => 'Páginas especiales',
-'version-parserhooks'      => "Lligams de l'analitzador",
-'version-version'          => 'Versión',
-'version-license'          => 'Licencia',
-'version-software-version' => 'Versión',
+'version'                     => 'Versión', # Not used as normal message but as header for the special page itself
+'version-extensions'          => 'Extensiones instaladas',
+'version-specialpages'        => 'Páginas especiales',
+'version-parserhooks'         => 'Extensiones del analizador sintáctico',
+'version-variables'           => 'Variables',
+'version-other'               => 'Otro',
+'version-extension-functions' => 'Funciones de extensiones',
+'version-version'             => 'Versión',
+'version-license'             => 'Licencia',
+'version-software'            => 'Software instalado',
+'version-software-product'    => 'Producto',
+'version-software-version'    => 'Versión',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Ruta de archivo',
 'filepath-page'    => 'Archivo:',
 'filepath-submit'  => 'Ruta',
@@ -2410,11 +2506,13 @@
 'fileduplicatesearch-legend'   => 'Busca duplicados',
 'fileduplicatesearch-filename' => 'Nombre del fichero:',
 'fileduplicatesearch-submit'   => 'Buscar',
+'fileduplicatesearch-info'     => '$1 × $2 píxeles<br />Tamaño: $3<br />Tipo MIME: $4',
 'fileduplicatesearch-result-1' => 'El archivo "$1" no tiene duplicados idénticos.',
 'fileduplicatesearch-result-n' => 'El archivo "$1" tiene {{PLURAL:$2|1 duplicado idéntico|$2 duplicados idénticos}}.',
 
 # Special:SpecialPages
 'specialpages'                   => 'Páginas especiales',
+'specialpages-note'              => '<p>&nbsp;</p><p style="margin-left:1cm; font-size:110%; padding:1px; text-align:center; border:1px solid blue;">Las páginas <span class="mw-specialpagerestricted">destacadas</span> son páginas especiales restringidas.</p>',
 'specialpages-group-maintenance' => 'Reportes de mantenimiento',
 'specialpages-group-other'       => 'Otras páginas especiales',
 'specialpages-group-login'       => 'Registrarse / entrar',
@@ -2428,7 +2526,8 @@
 'specialpages-group-redirects'   => 'Búsquedas y redirecciones',
 'specialpages-group-spam'        => 'Herramientas anti-SPAM',
 
-# Special:Blankpage
-'blankpage' => 'Página vacía',
+# Special:BlankPage
+'blankpage'              => 'Página vacía',
+'intentionallyblankpage' => 'Esta pagina está en blanco intencionadamente',
 
 );
Index: languages/messages/MessagesAln.php
===================================================================
--- languages/messages/MessagesAln.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAln.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,8 +6,6 @@
  *
  * @author Cradel
  * @author Dardan
- * @author Siebrand
- * @author M.M.S.
  */
 
 $fallback = 'sq';
@@ -484,7 +482,7 @@
 'nmembers' => '$1 anëtarë',
 'move'     => 'Zhvendose',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 deri në $2',
 'allpagessubmit' => 'Shko',
 
@@ -602,7 +600,7 @@
 
 # External editor support
 'edit-externally'      => 'Ndryshoni kët figurë/skedë me një mjet të jashtëm',
-'edit-externally-help' => 'Shikoni [http://meta.wikimedia.org/wiki/Help:External_editors udhëzimet e instalimit] për ma shumë informacion.',
+'edit-externally-help' => 'Shikoni [http://www.mediawiki.org/wiki/Manual:External_editors udhëzimet e instalimit] për ma shumë informacion.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'krejt',
Index: languages/messages/MessagesFrc.php
===================================================================
--- languages/messages/MessagesFrc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFrc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author RoyAlcatraz
  * @author JeanVoisin
- * @author Siebrand
- * @author SPQRobin
+ * @author RoyAlcatraz
  */
 
 $messages = array(
@@ -260,7 +258,7 @@
 'nosuchaction'      => 'Action inconnue',
 'nosuchactiontext'  => "L'action demandée dans l'adresse URL est pas reconnue par le wiki.",
 'nosuchspecialpage' => 'Page espéciale inconnue',
-'nospecialpagetext' => 'La page que vous avez demandée est pas une bonne page espéciale.  Vous pouvez trouver une liste des bonnes pages espéciales dans la [[Special:Specialpages|liste des pages espéciales]].',
+'nospecialpagetext' => 'La page que vous avez demandée est pas une bonne page espéciale.  Vous pouvez trouver une liste des bonnes pages espéciales dans la [[Special:SpecialPages|liste des pages espéciales]].',
 
 # General errors
 'error'                => 'Erreur',
@@ -470,10 +468,6 @@
 'blockededitsource'         => "Le texte de '''votres changements''' à '''$1''' est montré en bas.",
 'whitelistedittitle'        => 'Il faut connecter pour faire des changements.',
 'whitelistedittext'         => 'Il faut $1 pour faire des changements.',
-'whitelistreadtitle'        => 'Il faut connecter pour lire.',
-'whitelistreadtext'         => 'Il faut [[Special:Userlogin|connecter]] pour lire.',
-'whitelistacctitle'         => 'Vous avez pas la permission de créer un compte.',
-'whitelistacctext'          => 'Pour être capable de créer des comptes dans ce wiki, il faut [[Special:Userlogin|connecter]] et avoir la permission.',
 'confirmedittitle'          => 'Il faut confirmer votre adresse e-mail pour faire des changements.',
 'confirmedittext'           => "Il faut confirmer votre adresse e-mail pour faire des changements.  Mettez et confirmez un adresse e-mail dans votre [[Special:Preferences|réglage de compte]], s'il vous plaît.",
 'nosuchsectiontitle'        => 'Aucune section pareille',
@@ -487,7 +481,7 @@
 'newarticletext'            => "Vous avez suit un lien à une page qu'existe pas encore. 
 Pour créer la page, mettez des mots dans la boëte en bas (voyez la [[{{MediaWiki:Helppage}}|page d'aide]] pour plus d'information). 
 Si vous êtes ici par erreur, cliquez le bouton \"back\" sus votre navigateur.",
-'anontalkpagetext'          => "----''Ça ici, c'est la page de discussion pour un useur sans nom qu'a pas encore créé un compte ou qui l'use pas.  Ça fait, il faut user l'adresse IP numérique pour l'identifier.  Une adresse comme ça pourrait être usée par plusieurs useurs.  Si vous êtes un useur sans nom et vous croyez que des messages sans rapport ont été envoyés à vous, [[Special:Userlogin|créer un compte ou connecter]] pour empêcher la confusion avec des autres useurs sans nom dans l'avenir.''",
+'anontalkpagetext'          => "----''Ça ici, c'est la page de discussion pour un useur sans nom qu'a pas encore créé un compte ou qui l'use pas.  Ça fait, il faut user l'adresse IP numérique pour l'identifier.  Une adresse comme ça pourrait être usée par plusieurs useurs.  Si vous êtes un useur sans nom et vous croyez que des messages sans rapport ont été envoyés à vous, [[Special:UserLogin|créer un compte ou connecter]] pour empêcher la confusion avec des autres useurs sans nom dans l'avenir.''",
 'noarticletext'             => 'À présent, y a pas de texte sus cette page. Vous pouvez [[Special:Search/{{PAGENAME}}|charcher pour le titre de cette page]] dans des autres pages ou [{{fullurl:{{FULLPAGENAME}}|action=edit}} changer cette page].',
 'clearyourcache'            => "'''Notez:''' Après que vous avez sauvé votres changements, il foudra peut-être dépasser le cache de votre navigateur pour voir les changements.  '''Mozilla / Firefox / Safari:''' Tenez le bouton ''Shift'' en pèsant ''Reload'', ou pèsez ''Ctrl-Shift-R'' (''Cmd-Shift-R'' sus Apple Mac); '''IE:''' Tenez ''Ctrl'' en pèsant ''Refresh'', ou pèsez ''Ctrl-F5''; '''Konqueror:''' Simplement pèsez le bouton ''Reload'', ou pèsez ''F5''; Pour les useurs de '''Opera''', il foudra peut-être vider complètement le cache dans ''Tools→Preferences''.",
 'usercssjsyoucanpreview'    => '<strong>Conseil:</strong> Usez le bouton "Vue d\'avance" pour tester votre nouvelle feuille CSS/JS avant de la sauver.',
@@ -535,7 +529,7 @@
 'template-semiprotected'    => '(demi-protégé)',
 'edittools'                 => "<!-- Le texte que vous mettez ici va être montré sous les boëttes de changements ou d'import de dossier. -->",
 'nocreatetitle'             => 'Création de page limitée',
-'nocreatetext'              => "La création des pages est limitée.  Vous pouvez changer une page qu'a été déjà créée ou [[Special:Userlogin|connecter ou créer un compte]].",
+'nocreatetext'              => "La création des pages est limitée.  Vous pouvez changer une page qu'a été déjà créée ou [[Special:UserLogin|connecter ou créer un compte]].",
 'nocreate-loggedin'         => 'Vous avez pas la permission de créer des nouvelles pages sus ce wiki.',
 'permissionserrors'         => 'Erreur de permissions',
 'permissionserrorstext'     => 'Vous avez pas la permission de faire ça pour {{PLURAL:$1|cette raison|ces raisons}}:',
Index: languages/messages/MessagesUg.php
===================================================================
--- languages/messages/MessagesUg.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesUg.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -72,7 +72,7 @@
 # Special:Log
 'log-search-submit' => 'Kuchush',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Kuchush',
 
 # Watchlist
@@ -103,7 +103,7 @@
 'tooltip-search'  => 'Izdash {{SITENAME}}',
 'tooltip-p-logo'  => 'Bash Bet',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Izdash',
 
 # Trackbacks
Index: languages/messages/MessagesUk.php
===================================================================
--- languages/messages/MessagesUk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesUk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,13 @@
  * @ingroup Language
  * @file
  *
- * @author Ahonc
  * @author AS
- * @author Siebrand
- * @author Innv
- * @author EugeneZelenko
+ * @author Ahonc
  * @author Dubyk
- * @author Kalan
+ * @author EugeneZelenko
  * @author Gutsul (Gutsul.ua at Google Mail)
+ * @author Innv
+ * @author Kalan
  */
 
 /*
@@ -164,8 +163,8 @@
 	'img_bottom'          => array( '1', 'bottom', 'знизу' ),
 	'img_text_bottom'     => array( '1', 'text-bottom', 'текст-знизу' ),
 	'int'                 => array( '0', 'INT:', 'ВНУТР:' ),
-	'sitename'            => array( '1', 'SITENAME', 'НАЗВА_САЙТУ' ),
-	'ns'                  => array( '0', 'NS:', 'ПІ:' ),
+	'sitename'            => array( '1', 'SITENAME', 'НАЗВА_САЙТА' ),
+	'ns'                  => array( '0', 'NS:', 'ПН:' ),
 	'localurl'            => array( '0', 'LOCALURL:', 'ЛОКАЛЬНА_АДРЕСА:' ),
 	'localurle'           => array( '0', 'LOCALURLE:', 'ЛОКАЛЬНА_АДРЕСА_2:' ),
 	'server'              => array( '0', 'SERVER', 'СЕРВЕР' ),
@@ -187,10 +186,10 @@
 	'plural'              => array( '0', 'PLURAL:', 'МНОЖИНА:' ),
 	'fullurl'             => array( '0', 'FULLURL:', 'ПОВНА_АДРЕСА:' ),
 	'fullurle'            => array( '0', 'FULLURLE:', 'ПОВНА_АДРЕСА_2:' ),
-	'lcfirst'             => array( '0', 'LCFIRST:', 'ПЕРША_БУКВА_МАЛА:' ),
-	'ucfirst'             => array( '0', 'UCFIRST:', 'ПЕРША_БУКВА_ВЕЛИКА:' ),
-	'lc'                  => array( '0', 'LC:', 'МАЛИМИ_БУКВАМИ:' ),
-	'uc'                  => array( '0', 'UC:', 'ВЕЛИКИМИ_БУКВАМИ:' ),
+	'lcfirst'             => array( '0', 'LCFIRST:', 'НР_ПЕРША:' ),
+	'ucfirst'             => array( '0', 'UCFIRST:', 'ВР_ПЕРША:' ),
+	'lc'                  => array( '0', 'LC:', 'НР:', 'НИЖНІЙ_РЕГІСТР:' ),
+	'uc'                  => array( '0', 'UC:', 'ВР:', 'ВЕРХНІЙ_РЕГІСТР:' ),
 	'raw'                 => array( '0', 'RAW:', 'НЕОБРОБ:' ),
 	'displaytitle'        => array( '1', 'DISPLAYTITLE', 'ПОКАЗАТИ_ЗАГОЛОВОК' ),
 	'rawsuffix'           => array( '1', 'R', 'Н' ),
@@ -199,11 +198,11 @@
 	'urlencode'           => array( '0', 'URLENCODE:', 'ЗАКОДОВАНА_АДРЕСА:' ),
 	'anchorencode'        => array( '0', 'ANCHORENCODE', 'КОДУВАТИ_МІТКУ' ),
 	'currenttimestamp'    => array( '1', 'CURRENTTIMESTAMP', 'МІТКА_ПОТОЧНОГО_ЧАСУ' ),
-	'localtimestamp'      => array( '1', 'LOCALTIMESTAMP', 'МІТКА_ЛОКОЛЬН_ЧАСУ' ),
+	'localtimestamp'      => array( '1', 'LOCALTIMESTAMP', 'МІТКА_ЛОКАЛЬН_ЧАСУ' ),
 	'directionmark'       => array( '1', 'DIRECTIONMARK', 'DIRMARK', 'НАПРЯМОК_ПИСЬМА' ),
 	'language'            => array( '0', '#LANGUAGE:', '#МОВА:' ),
 	'contentlanguage'     => array( '1', 'CONTENTLANGUAGE', 'CONTENTLANG', 'МОВА_ЗМІСТУ' ),
-	'pagesinnamespace'    => array( '1', 'PAGESINNAMESPACE:', 'PAGESINNS:', 'СТОРІНОК_У_ПРОСТОРІ_НАЗВ:' ),
+	'pagesinnamespace'    => array( '1', 'PAGESINNAMESPACE:', 'PAGESINNS:', 'СТОРІНОК_У_ПРОСТОРІ_НАЗВ:', 'СТОР_У_ПН' ),
 	'numberofadmins'      => array( '1', 'NUMBEROFADMINS', 'КІЛЬКІСТЬ_АДМІНІСТРАТОРІВ' ),
 	'formatnum'           => array( '0', 'FORMATNUM', 'ФОРМАТУВАТИ_ЧИСЛО' ),
 	'padleft'             => array( '0', 'PADLEFT', 'ЗАПОВНИТИ_ЛІВОРУЧ' ),
@@ -214,6 +213,7 @@
 	'tag'                 => array( '0', 'tag', 'тег' ),
 	'hiddencat'           => array( '1', '__HIDDENCAT__', '__ПРИХОВ_КАТ__' ),
 	'pagesincategory'     => array( '1', 'PAGESINCATEGORY', 'PAGESINCAT', 'СТОР_В_КАТ' ),
+	'pagesize'            => array( '1', 'PAGESIZE', 'РОЗМІР' ),
 );
 
 $linkTrail = '/^([a-zабвгґдеєжзиіїйклмнопрстуфхцчшщьєюяёъы“»]+)(.*)$/sDu';
@@ -498,7 +498,7 @@
 'nosuchspecialpage' => 'Такої спеціальної сторінки нема',
 'nospecialpagetext' => "<big>'''Така спеціальна сторінка не існує.'''</big>
 
-Див. [[Special:Specialpages|список спеціальних сторінок]].",
+Див. [[Special:SpecialPages|список спеціальних сторінок]].",
 
 # General errors
 'error'                => 'Помилка',
@@ -525,10 +525,10 @@
 Адміністратор, що заблокував базу, дав наступне пояснення: $1',
 'missing-article'      => 'У базі даних не знайдений запитаний текст сторінки «$1» $2.
 
-Подібна ситуація зазвичай виникає при спробі переходу по застарілому поиалнню на історію змін сторінки, яка була вилучена.
+Подібна ситуація зазвичай виникає при спробі переходу по застарілому посиланню на історію змін сторінки, яка була вилучена.
 
 Якщо справа не в цьому, то, швидше за все, ви виявили помилку у програмному забезпеченні.
-Будь ласка, повідомте про це адміністратора, заначивши URL.',
+Будь ласка, повідомте про це [[Special:ListUsers/sysop|адміністратора]], заначивши URL.',
 'missingarticle-rev'   => '(версія № $1)',
 'missingarticle-diff'  => '(Різниця: $1, $2)',
 'readonly_lag'         => 'База даних автоматично заблокована від змін, доки вторинний сервер БД не синхронізується з первинним.',
@@ -578,13 +578,12 @@
 
 # Login and logout pages
 'logouttitle'                => 'Вийти з системи',
-'logouttext'                 => '<strong>Ви працюєте в тому ж режимі, який був до вашого входу до системи.</strong>
-Ви ідентифікуєтесь не з іменем, а з IP-адресою.
+'logouttext'                 => '<strong>Тепер ви працюєте в тому ж режимі, який був до вашого входу до системи.</strong>
 
-Ви можете продовжувати використовувати проект анонімно або почати новий сеанс як той самий чи інший користувач. Деякі сторінки можуть відображатися, ніби ви ще представлені системі під іменем, щоб уникнути цього, оновіть кеш браузера.',
+Ви можете продовжувати використовувати {{grammar:accusative|{{SITENAME}}}} анонімно або знову [[Special:UserLogin|ввійти у систему]] як той самий чи інший користувач. Деякі сторінки можуть відображатися, ніби ви ще представлені системі під іменем, щоб уникнути цього, оновіть кеш браузера.',
 'welcomecreation'            => '== Вітаємо вас, $1! ==
-Ви зареєстровані.
-Не забудьте змінити налаштування сайту.',
+Ваш обліковий запис створено.
+Не забудьте змінити свої [[Special:Preferences|налаштування для сайту]].',
 'loginpagetitle'             => 'Вхід до системи',
 'yourname'                   => "Ім'я користувача:",
 'yourpassword'               => 'Пароль:',
@@ -595,7 +594,7 @@
 'loginproblem'               => '<b>Проблема при вході до системи.</b><br />Спробуйте ще раз!',
 'login'                      => 'Вхід до системи',
 'nav-login-createaccount'    => 'Вхід / реєстрація',
-'loginprompt'                => 'Ви повинні активувати куки (cookies) для входу до системи.',
+'loginprompt'                => 'Ви повинні активувати куки (cookies) для [[Special:UserLogin|входу до системи]] {{grammar:accusative|{{SITENAME}}}}.',
 'userlogin'                  => 'Вхід / реєстрація',
 'logout'                     => 'Вихід із системи',
 'userlogout'                 => 'Вихід із системи',
@@ -755,10 +754,6 @@
 'blockededitsource'                => "Текст '''ваших редагувань''' сторінки «$1» наведено нижче:",
 'whitelistedittitle'               => 'Для редагування необхідно ввійти в систему',
 'whitelistedittext'                => 'Ви повинні $1 щоб редагувати сторінки.',
-'whitelistreadtitle'               => 'Для перегляду необхідно ввійти в систему',
-'whitelistreadtext'                => 'Ви повинні [[Special:Userlogin|зареєструватися]] для перегляду цих сторінок.',
-'whitelistacctitle'                => 'У вас немає прав для створення облікового запису',
-'whitelistacctext'                 => 'Щоб мати можливість створення облікових записів в цій вікі, ви повинні [[Special:Userlogin|зареєструватися]] й мати відповідні права.',
 'confirmedittitle'                 => 'Для редагування необхідно підтвердити адресу ел. пошти',
 'confirmedittext'                  => 'Ви повинні підтвердити вашу адресу електронної пошти перед редагуванням сторінок.
 Будь-ласка зазначте і підтвердіть вашу електронну адресу на [[Special:Preferences|сторінці налаштувань]].',
@@ -777,7 +772,7 @@
 'anontalkpagetext'                 => "----''Це сторінка обговорення, що належить анонімному користувачу, який ще не зареєструвався або не скористався зареєстрованим ім'ям.
 Тому ми вимушені використовувати IP-адресу для його ідентифікації.
 Одна IP-адреса може використовуватися декількома користувачами.
-Якщо ви — анонімний користувач і вважаєте, що отримали коментарі, адресовані не вам, будь ласка [[Special:Userlogin|зареєструйтесь або увійдіть до системи]], щоб у майбутньому уникнути можливої плутанини з іншими анонімними користувачами.''",
+Якщо ви — анонімний користувач і вважаєте, що отримали коментарі, адресовані не вам, будь ласка [[Special:UserLogin/signup|зареєструйтесь]] або [[Special:UserLogin|увійдіть до системи]], щоб у майбутньому уникнути можливої плутанини з іншими анонімними користувачами.''",
 'noarticletext'                    => "Зараз на цій сторінці нема тексту. Ви можете [[Special:Search/{{PAGENAME}}|пошукати цю назву]] в інших статтях або '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} створити сторінку з такою назвою]'''.",
 'userpage-userdoesnotexist'        => 'Користувач під назвою "$1" не зареєстрований. Перевірте, якщо ви хочете створити/редагувати цю сторінку.',
 'clearyourcache'                   => "'''Зауваження:''' Після зберігання, ви маєте відновити кеш вашого браузера, щоб побачити зміни. '''Mozilla / Firefox / Safari:''' тримайте ''Shift'' коли натискаєте ''Reload'', або натисніть ''Ctrl-Shift-R'' (''Cmd-Shift-R'' на Apple Mac); '''IE:''' тримайте ''Ctrl'' коли натискаєте ''Refresh'', або натисніть ''Ctrl-F5''; '''Konqueror:''': натисніть кнопку ''Reload'', або натисніть ''F5''; '''Opera''' користувачам може знадобитись повністю очистити кеш у ''Tools→Preferences''.",
@@ -794,9 +789,9 @@
 </strong>',
 'session_fail_preview_html'        => "<sstrong>Вибачте! Неможливо зберегти ваші зміни через втрату даних HTML-сесії.</sstrong>
 
-''Так як дана вікі дозволяє використовувати чистий HTML, попередній перегляд відключено, щоб попередити JavaScript-атаки.''
+''Оскільки {{SITENAME}} дозволяє використовувати чистий HTML, попередній перегляд відключено, щоб попередити JavaScript-атаки.''
 
-<sstrong>Якщо це доброякісна спроба редагування, будь ласка, спробуйте ще раз. Якщо не вийде знову, - спробуйте завершити сеанс роботи й ще раз ввійти до системи.</sstrong>",
+<sstrong>Якщо це доброякісна спроба редагування, будь ласка, спробуйте ще раз. Якщо не вийде знову, - спробуйте [[Special:UserLogout|завершити сеанс роботи]] й ще раз ввійти до системи.</sstrong>",
 'token_suffix_mismatch'            => '<strong>Ваше редагування було відхилене, оскільки ваша програма не правильно обробляє знаки пунктуації у вікні редагування. Редагування було скасоване для запобігання спотворенню тексту статті.
 Подібні проблеми можуть виникати при використанні анонімізуючих веб-проксі, що містять помилки.</strong>',
 'editing'                          => 'Редагування $1',
@@ -842,7 +837,7 @@
 'edittools'                        => '<!-- Розміщений тут текст буде відображатися під формою редагування і формою завантаження. -->',
 'nocreatetitle'                    => 'Створення сторінок обмежено',
 'nocreatetext'                     => 'На цьому сайті обмежено можливість створення нових сторінок.
-Ви можете повернуться назад й змінити існуючу сторінку, [[Special:Userlogin|ввійти в систему, або створити новий обліковий запис]].',
+Ви можете повернуться назад й змінити існуючу сторінку, [[Special:UserLogin|ввійти в систему, або створити новий обліковий запис]].',
 'nocreate-loggedin'                => 'У вас нема дозволу створювати нові сторінки у {{grammar:genitive|{{SITENAME}}}}.',
 'permissionserrors'                => 'Помилки прав доступу',
 'permissionserrorstext'            => 'У вас нема прав на виконання цієї операції з {{PLURAL:$1|наступної причини|наступних причин}}:',
@@ -964,7 +959,7 @@
 # Suppression log
 'suppressionlog'     => 'Журнал приховувань',
 'suppressionlogtext' => 'Нижче наведений список останніх вилучень та блокувань, які стосуються матеріалів, прихованих від адміністраторів.
-Див. [[Special:Ipblocklist|список IP-блокувань]], щоб переглянути список поточних блокувань.',
+Див. [[Special:IPBlockList|список IP-блокувань]], щоб переглянути список поточних блокувань.',
 
 # History merging
 'mergehistory'                     => "Об'єднання історій редагувань",
@@ -1048,7 +1043,7 @@
 'mypreferences'            => 'Налаштування',
 'prefs-edits'              => 'Кількість редагувань:',
 'prefsnologin'             => 'Ви не ввійшли в систему',
-'prefsnologintext'         => 'Щоб змінити налаштування користувача, ви повинні [[Special:Userlogin|ввійти в систему]].',
+'prefsnologintext'         => 'Щоб змінити налаштування користувача, ви повинні [[Special:UserLogin|ввійти в систему]].',
 'prefsreset'               => 'Відновлено стандартні налаштування.',
 'qbsettings'               => 'Панель навігації',
 'qbsettings-none'          => 'Не показувати панель',
@@ -1122,7 +1117,7 @@
 'userrights-reason'           => 'Причина зміни:',
 'userrights-no-interwiki'     => 'У вас нема дозволу змінювати права користувачів на інших вікі.',
 'userrights-nodatabase'       => 'База даних $1 не існує або не є локальною.',
-'userrights-nologin'          => 'Ви повинні [[Special:Userlogin|ввійти до системи]] з обліковим записом адміністратора, щоб призначати права користувачам.',
+'userrights-nologin'          => 'Ви повинні [[Special:UserLogin|ввійти до системи]] з обліковим записом адміністратора, щоб призначати права користувачам.',
 'userrights-notallowed'       => 'Із вашого облікового запису не дозволено призначати права користувачам.',
 'userrights-changeable-col'   => 'Групи, які ви можете змінити',
 'userrights-unchangeable-col' => 'Групи, які ви не можете змінити',
@@ -1252,7 +1247,7 @@
 'reupload'                    => 'Повторно завантажити',
 'reuploaddesc'                => 'Повернутися до форми завантаження',
 'uploadnologin'               => 'Ви не ввійшли в систему',
-'uploadnologintext'           => 'Ви повинні [[Special:Userlogin|ввійти до системи]], щоб завантажувати файли.',
+'uploadnologintext'           => 'Ви повинні [[Special:UserLogin|ввійти до системи]], щоб завантажувати файли.',
 'upload_directory_missing'    => 'Директорія для завантажень ($1) відсутня і не може бути створена веб-сервером.',
 'upload_directory_read_only'  => 'Веб-сервер не має прав запису в папку ($1), в якій планується зберігати завантажувані файли.',
 'uploaderror'                 => 'Помилка завантаження файлу',
@@ -1262,9 +1257,9 @@
 було б непогано перевірити, чи такий файл вже існує.
 
 Щоби переглянути вже завантажені файли,
-зайдіть на: [[Special:Imagelist|список завантажених файлів]].
+зайдіть на: [[Special:ImageList|список завантажених файлів]].
 
-Завантаження й вилучення відображаються в [[Special:Log|протоколі завантажень]].
+Завантаження й вилучення відображаються в [[Special:Log/upload|протоколі завантажень]].
 
 Для вставки зображень в статті можна використовувати такі рядки:
 * <nowiki>[[</nowiki>{{ns:image}}:Назва_зображення.jpg<nowiki>]]</nowiki>
@@ -1277,7 +1272,8 @@
 'upload-prohibited'           => 'Заборонені типи файлів: $1.',
 'uploadlog'                   => 'журнал завантажень',
 'uploadlogpage'               => 'Журнал завантажень',
-'uploadlogpagetext'           => 'Нижче наведено список останніх завантажених файлів.',
+'uploadlogpagetext'           => 'Нижче наведено список останніх завантажених файлів.
+Гляньте [[Special:NewImages|галерею нових зображень]] для більш візуального огляду.',
 'filename'                    => 'Назва файлу',
 'filedesc'                    => 'Опис файлу',
 'fileuploadsummary'           => 'Короткий опис:',
@@ -1354,7 +1350,7 @@
 'upload_source_url'  => ' (вірна, публічно доступна інтернет-адреса)',
 'upload_source_file' => " (файл на вашому комп'ютері)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ця спеціальна сторінка показує всі завантажені файли.
 За замовчуванням останні завантажені файли показані зверху.
 Натисніть на заголовок стовпчика, щоб відсортувати.',
@@ -1382,7 +1378,7 @@
 'imagelinks'                     => 'Посилання',
 'linkstoimage'                   => '{{PLURAL:$1|Наступна сторінка посилається|Наступні сторінки посилаються}} на цей файл:',
 'nolinkstoimage'                 => 'Статті, що посилаються на дане зображення, відсутні.',
-'morelinkstoimage'               => 'Переглянути [[Special:Whatlinkshere/$1|інші посилання]] на цей файл.',
+'morelinkstoimage'               => 'Переглянути [[Special:WhatLinksHere/$1|інші посилання]] на цей файл.',
 'redirectstofile'                => '{{PLURAL:$1|Наступний файл перенаправляється|Наступні файли перенаправляються}} на цей файл:',
 'duplicatesoffile'               => '{{PLURAL:$1|Наступний файл|Наступні файли}} є дублікатами цього файлу:',
 'sharedupload'                   => 'Цей файл завантажений до спільного для багатьох проектів сховища.',
@@ -1401,18 +1397,18 @@
 # File reversion
 'filerevert'                => 'Повернення до старої версії $1',
 'filerevert-legend'         => 'Повернути версію файлу',
-'filerevert-intro'          => '<span class="plainlinks">Ви повертаєте \'\'\'[[Media:$1|$1]]\'\'\' до [$4 версії від $3, $2].</span>',
+'filerevert-intro'          => "Ви повертаєте '''[[Media:$1|$1]]''' до [$4 версії від $3, $2].",
 'filerevert-comment'        => 'Примітка:',
 'filerevert-defaultcomment' => 'Повернення до версії від $2, $1',
 'filerevert-submit'         => 'Повернути',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' був повернутий до [$4 версії від $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' був повернутий до [$4 версії від $3, $2].",
 'filerevert-badversion'     => 'Немає локальної версії цього файлу з вказаною поміткою дати і часу.',
 
 # File deletion
 'filedelete'                  => 'Вилучення $1',
 'filedelete-legend'           => 'Вилучити файл',
 'filedelete-intro'            => "Ви вилучаєте '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Ви вилучаєте версію \'\'\'[[Media:$1|$1]]\'\'\' від [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Ви вилучаєте версію '''[[Media:$1|$1]]''' від [$4 $3, $2].",
 'filedelete-comment'          => 'Причина вилучення:',
 'filedelete-submit'           => 'Вилучити',
 'filedelete-success'          => "'''$1''' було вилучено.",
@@ -1473,9 +1469,11 @@
 'disambiguationspage'  => 'Template:disambig',
 'disambiguations-text' => "Наступні сторінки посилаються на '''багатозначні сторінки'''. Однак вони, ймовірно, повинні вказувати на відповідну конкретну статтю.<br />Сторінка вважається багатозначною, якщо на ній розміщений шаблон, назва якого є на сторінці [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Подвійні перенаправлення',
-'doubleredirectstext' => '<b>Увага:</b> Цей список може містити невірні елементи. Це значить, що після першої директиви #REDIRECT йде додатковий текст з посиланнями.<br />
+'doubleredirects'            => 'Подвійні перенаправлення',
+'doubleredirectstext'        => '<b>Увага:</b> Цей список може містити невірні елементи. Це значить, що після першої директиви #REDIRECT йде додатковий текст з посиланнями.<br />
 Кожен рядок містить посилання на перше та друге перенаправлення, а також перший рядок тексту другого перенаправлення, що, звичайно, містить "реальне" перенаправлення на необхідну статтю, куди повинно вказувати й перше перенаправлення.',
+'double-redirect-fixed-move' => 'Сторінка «[[$1]]» була перейменована, зараз вона є перенаправленням на «[[$2]]»',
+'double-redirect-fixer'      => 'Redirect fixer',
 
 'brokenredirects'        => 'Розірвані перенаправлення',
 'brokenredirectstext'    => 'Наступні перенаправлення вказують на неіснуючі статті:',
@@ -1560,7 +1558,7 @@
 'logempty'             => 'В журналі немає подібних записів.',
 'log-title-wildcard'   => 'Знайти заголовки, що починаються з цих символів',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Усі сторінки',
 'alphaindexline'    => 'від $1 до $2',
 'nextpage'          => 'Наступна сторінка ($1)',
@@ -1583,12 +1581,12 @@
 'special-categories-sort-count' => 'упорядкувати за кількістю',
 'special-categories-sort-abc'   => 'упорядкувати за алфавітом',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Показати користувачів, починаючи з:',
 'listusers-submit'   => 'Показати',
 'listusers-noresult' => 'Не знайдено користувачів.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Права груп користувачів',
 'listgrouprights-summary'  => 'Нижче наведений список груп користувачів у цій вікі і права для кожної групи.
 Додаткову інформацію про права користувачів можна знайти [[{{MediaWiki:Listgrouprights-helppage}}|тут]].',
@@ -1599,11 +1597,11 @@
 
 # E-mail user
 'mailnologin'     => 'Відсутня адреса для відправки',
-'mailnologintext' => 'Ви повинні [[Special:Userlogin|ввійти до системи]] і мати підтверджену адресу електронної пошти у ваших [[Special:Preferences|налаштуваннях]], щоб мати змогу надсилати електронну пошту іншим користувачам.',
+'mailnologintext' => 'Ви повинні [[Special:UserLogin|ввійти до системи]] і мати підтверджену адресу електронної пошти у ваших [[Special:Preferences|налаштуваннях]], щоб мати змогу надсилати електронну пошту іншим користувачам.',
 'emailuser'       => 'Надіслати листа цьому користувачеві',
 'emailpage'       => 'Лист користувачеві',
 'emailpagetext'   => 'Якщо цей користувач зазначив справжню адресу електронної пошти у своїх налаштуваннях, то, заповнивши наведену нижче форму, можна надіслати йому повідомлення.
-Електронна адреса, яку ви вказали у своїх налаштуваннях, буде зазначена в полі «Від кого» листа, тому одержувач матиме можливість відповісти.',
+Електронна адреса, яку ви вказали у своїх [[Special:Preferences|налаштуваннях]], буде зазначена в полі «Від кого» листа, тому одержувач матиме можливість відповісти.',
 'usermailererror' => 'При відправці повідомлення електронної пошти сталася помилка:',
 'defemailsubject' => '{{SITENAME}}: лист',
 'noemailtitle'    => 'Відсутня адреса електронної пошти',
@@ -1626,12 +1624,12 @@
 'nowatchlist'          => 'Ваш список спостереження порожній.',
 'watchlistanontext'    => 'Вам необхідно $1, щоб переглянути чи редагувати список спостереження.',
 'watchnologin'         => 'Ви не ввійшли до системи',
-'watchnologintext'     => 'Ви повинні [[Special:Userlogin|ввійти до системи]], щоб мати можливість змінювати список спостереження.',
+'watchnologintext'     => 'Ви повинні [[Special:UserLogin|ввійти до системи]], щоб мати можливість змінювати список спостереження.',
 'addedwatch'           => 'Додана до списку спостереження',
 'addedwatchtext'       => "Сторінка «[[:$1]]» додана до вашого [[Special:Watchlist|списку спостереження]].
-Наступні редагування цієї статті і пов'язаної з нею сторінки обговорення будуть відображатися в цьому списку, а також будуть виділені '''жирним шрифтом''' на сторінці зі [[Special:Recentchanges|списком останніх редагувань]], щоб їх було легше помітити.",
+Наступні редагування цієї статті і пов'язаної з нею сторінки обговорення будуть відображатися в цьому списку, а також будуть виділені '''жирним шрифтом''' на сторінці зі [[Special:RecentChanges|списком останніх редагувань]], щоб їх було легше помітити.",
 'removedwatch'         => 'Вилучена зі списку спостереження',
-'removedwatchtext'     => 'Сторінка «[[:$1]]» вилучена з вашого списку спостереження.',
+'removedwatchtext'     => 'Сторінка «[[:$1]]» вилучена з вашого [[Special:Watchlist|списку спостереження]].',
 'watch'                => 'Спостерігати',
 'watchthispage'        => 'Спостерігати за цією сторінкою',
 'unwatch'              => 'Скасувати спостереження',
@@ -1731,9 +1729,9 @@
 'rollbacklink'                => 'відкинути',
 'rollbackfailed'              => 'Відкинути зміни не вдалося',
 'cantrollback'                => 'Неможливо відкинути редагування, останній хто редагував є єдиним автором цієї статті.',
-'alreadyrolled'               => 'Неможливо відкинути останні редагування [[:$1]], зроблені [[User:$2|$2]] ([[User talk:$2|обговорення]]); хтось інший уже змінив чи відкинув редагування цієї статті.
+'alreadyrolled'               => 'Неможливо відкинути останні редагування [[:$1]], зроблені [[User:$2|$2]] ([[User talk:$2|обговорення]] | [[Special:Contributions/$2|{{int:contribslink}}]]); хтось інший уже змінив чи відкинув редагування цієї статті.
 
-Останні редагування зробив [[User:$3|$3]] ([[User talk:$3|обговорення]]).',
+Останні редагування зробив [[User:$3|$3]] ([[User talk:$3|обговорення]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Редагування прокоментовано так: <em>«$1»</em>.', # only shown if there is an edit comment
 'revertpage'                  => 'Редагування користувача [[Special:Contributions/$2|$2]] ([[User talk:$2|обговорення]]) відкинуті до версії користувача [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Відкинуті редагування користувача $1; повернення до версії користувача $2.',
@@ -1742,7 +1740,7 @@
 Будь ласка, натисніть кнопку «Назад» і перезавантажте сторінку, з якої ви прийшли.',
 'protectlogpage'              => 'Журнал захисту',
 'protectlogtext'              => 'Нижче наведено список установлень і знять захисту зі сторінки.
-Ви також можете переглянути [[Special:Protectedpages|список захищених сторінок]].',
+Ви також можете переглянути [[Special:ProtectedPages|список захищених сторінок]].',
 'protectedarticle'            => 'захист на [[$1]] встановлено',
 'modifiedarticleprotection'   => 'змінено рівень захисту сторінки «[[$1]]»',
 'unprotectedarticle'          => 'знято захист зі сторінки «[[$1]]»',
@@ -1900,7 +1898,7 @@
 'badipaddress'                    => 'IP-адреса записана в невірному форматі, або користувача з таким іменем не існує.',
 'blockipsuccesssub'               => 'Блокування проведено',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|«$1»]] заблоковано.<br />
-Див. [[Special:Ipblocklist|список заблокованих IP-адрес]].',
+Див. [[Special:IPBlockList|список заблокованих IP-адрес]].',
 'ipb-edit-dropdown'               => 'Редагувати причини блокувань',
 'ipb-unblock-addr'                => 'Розблокувати $1',
 'ipb-unblock'                     => 'Розблокувати користувача або IP-адресу',
@@ -1932,7 +1930,7 @@
 'blocklogentry'                   => 'заблокував [[$1]] на термін $2 $3',
 'blocklogtext'                    => 'Журнал блокування й розблокування користувачів.
 IP-адреси, що блокуються автоматично тут не вказуються. Див.
-[[Special:Ipblocklist|список поточних заборон і блокувань]].',
+[[Special:IPBlockList|список поточних заборон і блокувань]].',
 'unblocklogentry'                 => '«$1» розблоковано',
 'block-log-flags-anononly'        => 'тільки анонімні користувачі',
 'block-log-flags-nocreate'        => 'заборонена реєстрація облікових записів',
@@ -1971,7 +1969,7 @@
 'lockdbsuccesssub'    => 'Базу даних заблоковано',
 'unlockdbsuccesssub'  => 'Базу даних розблоковано',
 'lockdbsuccesstext'   => 'Базу даних проекту заблоковано.<br />
-Не забудьте її [[Special:Unlockdb|розблокувати]] після завершення обслуговування.',
+Не забудьте її [[Special:UnlockDB|розблокувати]] після завершення обслуговування.',
 'unlockdbsuccesstext' => 'Базу даних проекту розблоковано.',
 'lockfilenotwritable' => 'Немає права на запис в файл блокування бази даних. Щоб заблокувати чи розблокувати БД, веб-сервер повинен мати дозвіл на запис в цей файл.',
 'databasenotlocked'   => 'База даних не заблокована.',
@@ -1982,7 +1980,7 @@
 'movepagetext'            => "За допомогою форми, що нижче, ви можете перейменувати сторінку, одночасно перемістивши на нове місце і журнал її редагувань.
 Стара назва стане перенаправленням на нову.
 Посилання на стару назву не будуть змінені;
-обов'язково перевірте, чи не з'явилося подвійних чи розірваних перенаправлень.
+обов'язково перевірте, чи не з'явилося [[Special:DoubleRedirects|подвійних]] чи [[Special:BrokenRedirects|розірваних перенаправлень]].
 Ви відповідаєте за те, щоб переконатися, що посилання далі вказують туди, куди припускалося.
 
 Зверніть увагу, що сторінка '''не''' буде перейменована, якщо сторінка з новою назвою вже існує, окрім випадків, коли вона порожня або є перенаправленням, а журнал її редагувань порожній.
@@ -1997,8 +1995,6 @@
 
 У цих випадках ви будете змушені перейменувати чи об'єднати сторінки вручну в разі необхідності",
 'movearticle'             => 'Перейменувати сторінку',
-'movenologin'             => 'Ви не ввійшли в систему',
-'movenologintext'         => 'Ви повинні [[Special:Userlogin|ввійти до системи]], щоб перейменувати сторінку.',
 'movenotallowed'          => 'У вас нема дозволу перейменовувати сторінки у {{GRAMMAR:genitive|{{SITENAME}}}}.',
 'newtitle'                => 'Нова назва',
 'move-watch'              => 'Спостерігати за цією сторінкою',
@@ -2025,7 +2021,7 @@
 'revertmove'              => 'відкинути',
 'delete_and_move'         => 'Вилучити і перейменувати',
 'delete_and_move_text'    => '== Потрібне вилучення ==
-Сторінка з назвою [[$1|«$1»]] вже існує.
+Сторінка з назвою [[:$1|«$1»]] вже існує.
 Бажаєте вилучити її для можливості перейменування?',
 'delete_and_move_confirm' => 'Так, вилучити цю сторінку',
 'delete_and_move_reason'  => 'Вилучена для можливості перейменування',
@@ -2034,6 +2030,7 @@
 'imagenocrossnamespace'   => 'Неможливо дати зображенню назву з іншого простору назв',
 'imagetypemismatch'       => 'Нове розширення файлу не співпадає з його типом',
 'imageinvalidfilename'    => 'Назва цільового файлу неправильна',
+'fix-double-redirects'    => 'Виправити всі перенаправлення на попередню назву',
 
 # Export
 'export'            => 'Експорт статей',
@@ -2080,7 +2077,7 @@
 'import-interwiki-history'   => 'Копіювати всю історію змін цієї сторінки',
 'import-interwiki-submit'    => 'Імпортувати',
 'import-interwiki-namespace' => 'Розміщати сторінки в просторі імен:',
-'importtext'                 => 'Будь ласка, експортуйте сторінку з іншої вікі, використовуючи інструмент Special:Export, збережіть файл, а потім завантажте його сюди.',
+'importtext'                 => 'Будь ласка, експортуйте сторінку з іншої вікі, використовуючи [[Special:Export|засіб експорту]], збережіть файл, а потім завантажте його сюди.',
 'importstart'                => 'Імпорт сторінок…',
 'import-revision-count'      => '$1 {{PLURAL:$1|версія|версії|версій}}',
 'importnopages'              => 'Сторінки для імпорту відсутні.',
@@ -2242,9 +2239,10 @@
 'markedaspatrollederror-noautopatrol' => 'Вам не дозволено позначати власні редагування як перевірені.',
 
 # Patrol log
-'patrol-log-page' => 'Журнал патрулювання',
-'patrol-log-line' => 'перевірена $1 з $2 $3',
-'patrol-log-auto' => '(автоматично)',
+'patrol-log-page'   => 'Журнал патрулювання',
+'patrol-log-header' => 'Це журнал перевірених змін.',
+'patrol-log-line'   => 'перевірена $1 з $2 $3',
+'patrol-log-auto'   => '(автоматично)',
 
 # Image deletion
 'deletedrevision'                 => 'Вилучена стара версія $1',
@@ -2274,10 +2272,10 @@
 'show-big-image'       => 'Повна роздільність',
 'show-big-image-thumb' => '<small>Розмір при попередньому перегляді: $1 × $2 пікселів</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Галерея нових файлів',
 'imagelisttext'         => "Нижче подано список з '''$1''' {{PLURAL:$1|файлу|файлів|файлів}}, відсортованих $2.",
-'newimages-summary'     => 'Ця спеціальна сторінка показує останні завантажені файли',
+'newimages-summary'     => 'Ця спеціальна сторінка показує останні завантажені файли.',
 'showhidebots'          => '($1 ботів)',
 'noimages'              => 'Файли відсутні.',
 'ilsubmit'              => 'Шукати',
@@ -2562,7 +2560,7 @@
 
 # External editor support
 'edit-externally'      => 'Редагувати цей файл, використовуючи зовнішню програму',
-'edit-externally-help' => 'Подробиці див. на сторінці [http://meta.wikimedia.org/wiki/Help:External_editors Meta:Help:External_editors].',
+'edit-externally-help' => 'Подробиці див. на сторінці [http://www.mediawiki.org/wiki/Manual:External_editors Meta:Help:External_editors].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'всі',
@@ -2631,7 +2629,7 @@
 'unit-pixel' => ' пікс.',
 
 # HTML dump
-'redirectingto' => 'Перенаправлення на сторінку [[$1]]…',
+'redirectingto' => 'Перенаправлення на сторінку [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Очистити кеш цієї сторінки?
@@ -2734,7 +2732,7 @@
 'version-software-product'         => 'Продукт',
 'version-software-version'         => 'Версія',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Шлях до файлу',
 'filepath-page'    => 'Файл:',
 'filepath-submit'  => 'Шлях',
@@ -2772,7 +2770,7 @@
 'specialpages-group-redirects'   => 'Перенаправлення',
 'specialpages-group-spam'        => 'Інструменти проти спаму',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Порожня сторінка',
 'intentionallyblankpage' => 'Цю сторінку навмисне залишили порожньою',
 
Index: languages/messages/MessagesTokipona.php
===================================================================
--- languages/messages/MessagesTokipona.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTokipona.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -136,7 +136,7 @@
 'move'         => 'o tawa',
 'movethispage' => 'o pana e nimi sin',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'lipu ale',
 
 # Special:Categories
Index: languages/messages/MessagesMy.php
===================================================================
--- languages/messages/MessagesMy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesMy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -8,7 +8,46 @@
  * @author Hintha
  */
 
+$digitTransformTable = array(
+	'0' => '၀',
+	'1' => '၁',
+	'2' => '၂',
+	'3' => '၃',
+	'4' => '၄',
+	'5' => '၅',
+	'6' => '၆',
+	'7' => '၇',
+	'8' => '၈',
+	'9' => '၉',
+);
+
+$datePreferences = array(
+	'default',
+	'my normal',
+	'my long',
+	'ISO 8601',
+);
+ 
+$defaultDateFormat = 'my normal';
+ 
+$dateFormats = array(
+	'my normal time' => 'H:i',
+	'my normal date' => 'j F Y',
+	'my normal both' => ' H:i"၊" j F Y',
+ 
+	'my long time' => 'H:i',
+	'my long date' => 'Y "ဇန်နဝါရီ" F"လ" j "ရက်"',
+	'my long both' => 'H:i"၊" Y "ဇန်နဝါရီ" F"လ" j "ရက်"',
+);
+
 $messages = array(
+# User preference toggles
+'tog-watchcreations' => 'ကျွန်တော်ထွင်သည့်စာမျက်နှာများကို စောင့်​ကြည့်​စာ​ရင်း​ထဲ ပေါင်းထည့်ပါ',
+
+'underline-always' => 'အမြဲ',
+
+'skinpreview' => '(နမူနာ)',
+
 # Dates
 'sunday'        => 'တ​နင်္ဂ​နွေ​',
 'monday'        => 'တ​နင်္လာ​',
@@ -17,6 +56,13 @@
 'thursday'      => 'ကြာ​သာ​ပ​တေး​',
 'friday'        => 'သော​ကြာ​',
 'saturday'      => 'စ​နေ​',
+'sun'           => 'တနင်္ဂနွေ',
+'mon'           => 'တနင်္ဂလာ',
+'tue'           => 'အင်္ဂါ',
+'wed'           => 'ဗုဒ္ဓဟူး',
+'thu'           => 'ကြာသပတေး',
+'fri'           => 'သောကြာ',
+'sat'           => 'စနေ',
 'january'       => 'ဇန်​န​ဝါ​ရီ​',
 'february'      => 'ဖေ​ဖော်​ဝါ​ရီ​',
 'march'         => 'မတ်​',
@@ -112,12 +158,18 @@
 'gotaccountlink'          => 'မှတ်​ပုံ​တင်​ဖြင့်​ဝင်​ပါ​',
 'youremail'               => 'အီ​မေး:',
 'username'                => 'မှတ်​ပုံ​တင်​အ​မည်:',
+'uid'                     => 'မှတ်​ပုံ​တင်​ID:',
 'yourrealname'            => 'နာမည်ရင်း:',
+'yourlanguage'            => 'ဘာသာ:',
+'yournick'                => 'ဆိုင်း:',
 'email'                   => 'အီ​မေး​',
+'loginsuccesstitle'       => 'မှတ်​ပုံ​တင်​ဖြင့်​ဝင်​ခြင်းအောင်မြင်သည်။',
+'loginlanguagelabel'      => 'ဘာသာ: $1',
 
 # Edit page toolbar
 'italic_sample' => 'စာသားဆောင်း',
 'italic_tip'    => 'စာသားဆောင်း',
+'math_sample'   => 'သည်မှာသင်္ချာပုံသေနည်းအားထည့်',
 'math_tip'      => 'သင်္ချာပုံသေနည်း (LaTeX)',
 'hr_tip'        => 'မျဉ်းလဲ',
 
@@ -128,17 +180,22 @@
 'savearticle'        => 'သိမ်း​ပါ​',
 'preview'            => 'နမူနာ',
 'showpreview'        => 'န​မူ​နာ​ပြ​ပါ​',
+'showlivepreview'    => 'နမူနာအရှင်',
 'showdiff'           => 'ပြင်​ဆင်​ထား​သည်​များ​ကို​ပြ​ပါ​',
 'summary-preview'    => 'အ​ကျဉ်း​ချုပ်​န​မူ​နာ',
 'whitelistedittitle' => 'ပြင်​ဆင်​ခြင်း​သည်​မှတ်​ပုံ​တင်​ရန်​လို​သည်​',
 'loginreqtitle'      => 'မှတ်​ပုံ​တင်​ဖြင့်​ဝင်​ဖို့လိုပါတယ်',
 'loginreqlink'       => 'မှတ်​ပုံ​တင်​ဖြင့်​ဝင်​ပါ​',
+'accmailtitle'       => 'ဝှက်​စ​ကား​လုံးကိုပို့ပြီးပြီ',
 'newarticle'         => '(အသစ်)',
 
 # History pages
 'page_first' => 'ပထမဆုံး',
 'page_last'  => 'အနောက်ဆုံး',
 
+# Revision deletion
+'rev-delundel' => 'ပြ/ဝှက်',
+
 # Search results
 'powersearch' => 'ရှာ​ဖွေ​ရန်​',
 
@@ -146,8 +203,17 @@
 'preferences'       => 'ကျွန်​တော့​ရွေး​ချယ်​စ​ရာ​များ​',
 'mypreferences'     => 'ကျွန်​တော့​ရွေး​ချယ်​စ​ရာ​များ​',
 'prefsnologin'      => 'မှတ်​ပုံ​တင်​ဖြင့်​မ​ဝင်​ရ​သေး​ပါ​',
+'changepassword'    => 'ဝှက်​စ​ကား​လုံးကိုပြောင်းပါ',
+'math'              => 'သင်္ချာ',
+'datetime'          => 'နေ့စွဲနှင့် အချိန်',
+'oldpassword'       => 'ဝှက်​စ​ကား​လုံးအဟောင်း:',
+'newpassword'       => 'ဝှက်​စ​ကား​လုံးအသစ်:',
+'retypenew'         => 'ဝှက်​စ​ကား​လုံးပအသစ်ကိုထပ်ရိုက်ပါ:',
 'searchresultshead' => 'ရှာ​ဖွေ​ရန်​',
 
+# Groups
+'group-all' => '(အားလုံး)',
+
 # Recent changes
 'recentchanges'   => 'လတ်​တ​လော​အ​ပြောင်း​အ​လဲ​များ​',
 'rcshowhideminor' => 'အသေးအမွှာပြင်ဆင်ရန်$1',
@@ -155,6 +221,7 @@
 'hide'            => 'ဝှက်',
 'show'            => 'ပြ',
 'newpageletter'   => 'သစ်',
+'boteditletter'   => 'ဆ',
 
 # Recent changes linked
 'recentchangeslinked' => 'ဆက်​ဆပ်​သော​အ​ပြောင်း​အ​လဲ​များ​',
@@ -163,25 +230,44 @@
 'upload'            => 'ဖိုင်​တင်​ရန်​',
 'uploadbtn'         => 'ဖိုင်​တင်​ရန်​',
 'uploadnologin'     => 'မှတ်​ပုံ​တင်​ဖြင့်​မ​ဝင်​ရ​သေး​ပါ​',
+'filename'          => 'ဖိုင်အမည်',
 'filedesc'          => 'အ​ကျဉ်း​ချုပ်​',
 'fileuploadsummary' => 'အ​ကျဉ်း​ချုပ်:',
 'watchthisupload'   => 'ဤ​စာ​မျက်​နှာ​အား​စောင့်​ကြည့်​ပါ​',
 
-# Special:Imagelist
-'imagelist' => 'ဖိုင်စာရင်း',
+# Special:ImageList
+'imgfile'        => 'ဖိုင်',
+'imagelist'      => 'ဖိုင်စာရင်း',
+'imagelist_date' => 'နေ့စွဲ',
 
 # Image description page
-'filehist' => 'ဖိုင်မှတ်တမ်း',
+'filehist'           => 'ဖိုင်မှတ်တမ်း',
+'filehist-deleteall' => 'အားလုံးဖျက်',
+'filehist-deleteone' => 'ဖျက်',
+'filehist-current'   => 'ကာလပေါ်',
+'filehist-datetime'  => 'နေ့စွဲ/အချိန်',
+'filehist-filesize'  => 'ဖိုင်ဆိုက်',
 
+# File deletion
+'filedelete'        => '$1 ကိုဖျက်ပါ',
+'filedelete-legend' => 'ဖိုင်ကိုဖျက်ပါ',
+'filedelete-submit' => 'ဖျက်',
+
+# Unused templates
+'unusedtemplateswlh' => 'အခြားလိပ်စာများ',
+
 # Random page
 'randompage' => 'ကျ​ပန်း​စာ​မျက်​နှာ​',
 
 # Statistics
 'statistics' => 'စာရင်းအင်း',
+'sitestats'  => '{{SITENAME}} စာရင်းအင်းများ',
 
 'brokenredirects-edit'   => '(ပြင်​ဆင်​ရန်)',
 'brokenredirects-delete' => '(ဖျက်​ပါ)',
 
+'withoutinterwiki-submit' => 'ပြ',
+
 # Miscellaneous special pages
 'shortpages'        => 'စာမျက်နှာတို',
 'newpages'          => 'စာမျက်နှာအသစ်',
@@ -196,23 +282,35 @@
 # Special:Log
 'log-search-submit' => 'သွား​ပါ​',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'စာမျက်နှာအားလုံး',
 'allarticles'    => 'စာမျက်နှာအားလုံး',
 'allpagessubmit' => 'သွား​ပါ​',
 
+# Special:ListUsers
+'listusers-submit' => 'ပြ',
+
+# E-mail user
+'emailsend' => 'ပို့',
+
 # Watchlist
 'watchlist'     => 'စောင့်​ကြည့်​စာ​ရင်း​',
 'mywatchlist'   => 'စောင့်​ကြည့်​စာ​ရင်း​',
+'watchlistfor'  => "('''$1'''အတွက်)",
 'watch'         => 'စောင့်​ကြည့်​ပါ​',
 'watchthispage' => 'ဤ​စာ​မျက်​နှာ​အား​စောင့်​ကြည့်​ပါ​',
 
 # Delete/protect/revert
+'deletepage'       => 'စာမျက်နှာကိုဖျက်ပါ',
+'confirm'          => 'အတည်ပြု',
+'delete-confirm'   => '"$1"ကို ဖျက်ပါ',
+'delete-legend'    => 'ဖျက်',
 'restriction-type' => 'အခွင့်:',
 
 # Restrictions (nouns)
-'restriction-edit' => 'ပြင်​ဆင်​ရန်​',
-'restriction-move' => 'ရွေ့​ပြောင်း​ပါ​',
+'restriction-edit'   => 'ပြင်​ဆင်​ရန်​',
+'restriction-move'   => 'ရွေ့​ပြောင်း​ပါ​',
+'restriction-create' => 'ထွင်',
 
 # Undelete
 'undelete-search-submit' => 'ရှာ​ဖွေ​ရန်​',
@@ -220,6 +318,8 @@
 # Contributions
 'contributions' => 'မှတ်​ပုံ​တင်​အ​သုံး​ပြု​သူ​:ပံ​ပိုး​မှု​များ​',
 'mycontris'     => 'ကျွန်​တော်​ပေး​သော​ပံ​ပိုး​မှု​များ​',
+'contribsub2'   => '$1အတွက် ($2)',
+'uctop'         => '(အထိပ်)',
 
 'sp-contributions-submit' => 'ရှာ​ဖွေ​ရန်​',
 
@@ -228,41 +328,79 @@
 
 # Block/unblock
 'ipbreason'          => 'အ​ကြောင်း​ပြ​ချက်:',
+'ipbother'           => 'အခြားအချိန်:',
 'ipboptions'         => '၂ နာရီ:2 hours,၁ နေ့:1 day,၃ နေ့:3 days,၁ ပတ်:1 week,၂ ပတ်:2 weeks,၁ လ:1 month,၃ လ:3 months,၆ လ:6 months,၁ နှစ်:1 year,အနန္တ:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'     => 'အခြား',
 'ipblocklist-submit' => 'ရှာ​ဖွေ​ရန်​',
+'expiringblock'      => '$1 ဆုံးမည်',
 
 # Move page
 'move-page-legend' => 'စာ​မျက်​နှာ​အား​ရွေ့​ပြောင်း​ပါ​',
 'movearticle'      => 'စာ​မျက်​နှာ​အား​ရွေ့​ပြောင်း​ပါ​',
-'movenologin'      => 'မှတ်​ပုံ​တင်​ဖြင့်​မ​ဝင်​ရ​သေး​ပါ​',
 'movepagebtn'      => 'စာ​မျက်​နှာ​အား​ရွေ့​ပြောင်း​ပါ​',
+'pagemovedsub'     => 'ပြောင်းရွှေ့ခြင်းအောင်မြင်သည်',
 'movedto'          => 'ရွေ့​ပြောင်း​ရန်​နေ​ရာ​',
 '1movedto2'        => '[[$1]]  မှ​ [[$2]] သို့​',
 'movereason'       => 'အ​ကြောင်း​ပြ​ချက်​',
 
 # Namespace 8 related
-'allmessages' => 'စ​နစ်​၏​သ​တင်း​များ​',
+'allmessages'     => 'စ​နစ်​၏​သ​တင်း​များ​',
+'allmessagesname' => 'အမည်',
 
+# Thumbnails
+'thumbnail-more' => 'ချဲ့',
+
 # Tooltip help for the actions
-'tooltip-pt-logout' => 'ထွက်​ပါ​',
-'tooltip-ca-delete' => 'ဤစာမျက်နှာဖျက်ပါ',
-'tooltip-ca-move'   => 'ဤ​စာ​မျက်​နှာ​အား​ရွေ့​ပြောင်း​ပါ​',
-'tooltip-save'      => 'ပြင်ဆင်ရန်သိမ်းပါ',
+'tooltip-pt-userpage'    => 'ကျွန်တော့စာမျက်နှာ',
+'tooltip-pt-mytalk'      => 'ကျွန်​တော့​ပြော​ရေး​ဆို​ရာ​',
+'tooltip-pt-preferences' => 'ကျွန်​တော့​ရွေး​ချယ်​စ​ရာ​များ​',
+'tooltip-pt-logout'      => 'ထွက်​ပါ​',
+'tooltip-ca-protect'     => 'ဤစာမျက်နှာကို ထိန်းသိမ်းပါ',
+'tooltip-ca-delete'      => 'ဤစာမျက်နှာဖျက်ပါ',
+'tooltip-ca-move'        => 'ဤ​စာ​မျက်​နှာ​အား​ရွေ့​ပြောင်း​ပါ​',
+'tooltip-t-upload'       => 'ဖိုင်တင်ပါ',
+'tooltip-save'           => 'ပြင်ဆင်ရန်သိမ်းပါ',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ရှာ​ဖွေ​ရန်​',
 
+# EXIF tags
+'exif-exposuretime-format' => '$1 စက္ကန့် ($2)',
+'exif-gpsaltitude'         => 'အမြင့်',
+
+'exif-meteringmode-255' => 'အခြား',
+
+'exif-lightsource-1' => 'နေ့အလင်း',
+
+'exif-focalplaneresolutionunit-2' => 'လက်မှတ်',
+
+'exif-scenecapturetype-3' => 'ညနေပုံ',
+
 # 'all' in various places, this might be different for inflected languages
-'watchlistall2' => 'အားလုံး',
-'namespacesall' => 'အားလုံး',
-'monthsall'     => 'အားလုံး',
+'recentchangesall' => 'အားလုံး',
+'imagelistall'     => 'အားလုံး',
+'watchlistall2'    => 'အားလုံး',
+'namespacesall'    => 'အားလုံး',
+'monthsall'        => 'အားလုံး',
 
+# E-mail address confirmation
+'confirmemail' => 'အီးမေးကိုအတည်ပြုပါ',
+
 # Multipage image navigation
 'imgmultigo' => 'သွား​ပါ!',
 
 # Table pager
 'table_pager_limit_submit' => 'သွား​ပါ​',
 
+# Auto-summaries
+'autosumm-new' => 'စာမျက်နှာအသစ်: $1',
+
+# Special:Version
+'version-other' => 'အခြား',
+
+# Special:FilePath
+'filepath-page' => 'ဖိုင်:',
+
 # Special:SpecialPages
 'specialpages' => 'အ​ထူး​စာ​မျက်​နှာ​',
 
Index: languages/messages/MessagesBg.php
===================================================================
--- languages/messages/MessagesBg.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBg.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,13 @@
  * @ingroup Language
  * @file
  *
+ * @author BloodIce
+ * @author Borislav
  * @author DCLXVI
- * @author Borislav
+ * @author Daggerstab
  * @author Spiritia
- * @author Siebrand
- * @author BloodIce
+ * @author Петър Петров
  * @author לערי ריינהארט
- * @author Петър Петров
- * @author Daggerstab
  */
 
 $fallback8bitEncoding = 'windows-1251';
@@ -133,6 +132,7 @@
 	'newsectionlink'      => array( '1', '__NEWSECTIONLINK__', '__ВРЪЗКА_ЗА_НОВ_РАЗДЕЛ__' ),
 	'language'            => array( '0', '#LANGUAGE:', '#ЕЗИК:' ),
 	'numberofadmins'      => array( '1', 'NUMBEROFADMINS', 'БРОЙАДМИНИСТРАТОРИ' ),
+	'defaultsort'         => array( '1', 'DEFAULTSORT:', 'DEFAULTSORTKEY:', 'DEFAULTCATEGORYSORT:', 'СОРТКАТ:' ),
 	'hiddencat'           => array( '1', '__HIDDENCAT__', '__СКРИТАКАТЕГОРИЯ__' ),
 );
 
@@ -502,7 +502,7 @@
 'nosuchspecialpage' => 'Няма такава специална страница',
 'nospecialpagetext' => "<big>'''Отправихте заявка за невалидна специална страница.'''</big>
 
-Списък с валидните специални страници може да бъде видян на [[Special:Specialpages|{{int:specialpages}}]].",
+Списък с валидните специални страници може да бъде видян на [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Грешка',
@@ -614,7 +614,7 @@
 'yourrealname'               => 'Истинско име:',
 'yourlanguage'               => 'Език:',
 'yourvariant'                => 'Вариант',
-'yournick'                   => 'Псевдоним (за подписи чрез ~~~~):',
+'yournick'                   => 'Псевдоним',
 'badsig'                     => 'Избраният подпис не е валиден. Проверете HTML-етикетите!',
 'badsiglength'               => 'Подписът е твърде дълъг.
 Максимално допустимата дължина на подпис е $1 {{PLURAL:$1|знак|знака}}.',
@@ -726,29 +726,26 @@
 
 Можете да използвате услугата „Пращане писмо на потребител“ само ако не ви е забранена употребата й и ако сте посочили валидна електронна поща в [[Special:Preferences|настройките]] си.
 
-Вашият IP адрес е $3, а номерът на блокирането е #$5. Включвайте едно от двете или и двете във всяко запитване, което правите.",
+Вашият IP адрес е $3, а номерът на блокирането е $5. Включвайте едно от двете или и двете във всяко запитване, което правите.",
 'autoblockedtext'                  => "Вашият IP-адрес беше блокиран автоматично, защото е бил използван от друг потребител, който е бил блокиран от $1.
 Посочената причина е:
 
 :''$2''
 
-*Начало на блокирането: $8
-*Край на блокирането: $6
+* Начало на блокирането: $8
+* Край на блокирането: $6
+* Блокирането се отнася за: $7
 
 Можете да се свържете с $1 или с някой от останалите [[{{MediaWiki:Grouppage-sysop}}|администратори]], за да обсъдите блокирането.
 
 Можете да използвате услугата „Пращане писмо на потребител“ само ако не ви е забранена употребата й и ако сте посочили валидна електронна поща в [[Special:Preferences|настройките]] си.
 
-Номерът на блокирането ви е #$5. Включвайте го във всяко питане, което правите.",
+Текущият ви IP-адрес е $3, а номерът на блокирането ви е $5. Включвайте ги във всяко питане, което правите.",
 'blockednoreason'                  => 'не е указана причина',
 'blockedoriginalsource'            => "По-долу е показано съдържанието на '''$1''':",
 'blockededitsource'                => "По-долу е показан текстът на '''вашите редакции''' на '''$1''':",
 'whitelistedittitle'               => 'Необходимо е да влезете, за да може да редактирате',
 'whitelistedittext'                => 'Редактирането на страници изисква $1 в системата.',
-'whitelistreadtitle'               => 'Необходимо е да влезете, за да може да четете страници',
-'whitelistreadtext'                => 'За преглеждане на страници в уикито е необходимо [[Special:Userlogin|влизане]] в системата.',
-'whitelistacctitle'                => 'Не ви е позволено да създавате сметка',
-'whitelistacctext'                 => 'За да ви бъде позволено създаването на сметки, трябва да [[Special:Userlogin|влезете]] и да имате подходящото разрешение.',
 'confirmedittitle'                 => 'Необходимо е потвърждение на адреса ви за електронна поща',
 'confirmedittext'                  => 'Необходимо е да потвърдите електронната си поща, преди да редактирате страници.
 Въведете и потвърдете адреса си на [[Special:Preferences|страницата с настройките]].',
@@ -765,7 +762,7 @@
 (вижте [[{{MediaWiki:Helppage}}|помощната страница]] за повече информация).',
 'anontalkpagetext'                 => "----''Това е дискусионната страница на анонимен потребител, който все още няма регистрирана сметка или не я използва, затова се налага да използваме IP-адрес, за да го идентифицираме. Такъв адрес може да се споделя от няколко потребители.''
 
-''Ако сте анонимен потребител и мислите, че тези неуместни коментари са отправени към вас, [[Special:Userlogin|регистрирайте се или влезте в системата]], за да избегнете евентуално бъдещо объркване с други анонимни потребители.''",
+''Ако сте анонимен потребител и мислите, че тези неуместни коментари са отправени към вас, [[Special:UserLogin/signup|регистрирайте се]] или [[Special:UserLogin|влезте в системата]], за да избегнете евентуално бъдещо объркване с други анонимни потребители.''",
 'noarticletext'                    => "(Тази страница все още не съществува. Можете да [[Special:Search/{{PAGENAME}}|потърсите за заглавието на страницата]] в други страници или да създадете страницата като щракнете на '''Редактиране'''.)",
 'userpage-userdoesnotexist'        => 'Няма регистрирана потребителска сметка за „$1“. Изисква се потвърждение, че желаете да създадете/редактирате тази страница?',
 'clearyourcache'                   => "'''Бележка:''' След съхранението е необходимо да изтриете кеша на браузъра, за да видите промените:
@@ -781,7 +778,7 @@
 'note'                             => '<strong>Забележка:</strong>',
 'previewnote'                      => '<strong>Това е само предварителен преглед. Промените все още не са съхранени!</strong>',
 'previewconflict'                  => 'Този предварителен преглед отразява текста в горната текстова кутия така, както би се показал, ако съхраните.',
-'session_fail_preview'             => '<strong>За съжаление редакцията ви не успя да бъде обработена, поради загуба на данните за текущата сесия. Опитайте отново. Ако все още не работи, опитайте да излезете и да влезете наново.</strong>',
+'session_fail_preview'             => '<strong>За съжаление редакцията ви не успя да бъде обработена поради загуба на данните за текущата сесия. Опитайте отново. Ако все още не работи, опитайте да [[Special:UserLogout|излезете]] и да влезете наново.</strong>',
 'session_fail_preview_html'        => "<strong>За съжаление редакцията ви не беше записана поради изтичането на сесията ви.</strong>
 
 ''Тъй като уикито приема обикновен HTML, предварителният преглед е скрит като предпазна мярка срещу атаки чрез Джаваскрипт.''
@@ -830,7 +827,7 @@
 'hiddencategories'                 => 'Тази страница е включена в {{PLURAL:$1|Една скрита категория|$1 скрити категории}}:',
 'edittools'                        => '<!-- Евентуален текст тук ще бъде показван под формулярите за редактиране и качване. -->',
 'nocreatetitle'                    => 'Създаването на страници е ограничено',
-'nocreatetext'                     => 'Създаването на нови страници в {{SITENAME}} е ограничено. Можете да се върнете назад и да редактирате някоя от съществуващите страници, [[Special:Userlogin|да се регистрирате или да създадете нова потребителска сметка]].',
+'nocreatetext'                     => 'Създаването на нови страници в {{SITENAME}} е ограничено. Можете да се върнете назад и да редактирате някоя от съществуващите страници, [[Special:UserLogin|да се регистрирате или да създадете нова потребителска сметка]].',
 'nocreate-loggedin'                => 'Нямате необходимите права да създавате нови страници в {{SITENAME}}.',
 'permissionserrors'                => 'Грешки при правата на достъп',
 'permissionserrorstext'            => 'Нямате правата да извършите това действие по {{PLURAL:$1|следната причина|следните причини}}:',
@@ -841,6 +838,10 @@
 За ваша информация по-долу е посочена причината за предишното изтриване на страницата:",
 
 # Parser/template warnings
+'expensive-parserfunction-warning'       => 'Внимание: Тази страница прекалено много пъти използва ресурсоемки парсерни функции.
+
+В момента има $1, трябва да са по-малко от $2.',
+'expensive-parserfunction-category'      => 'Страници, които прекалено много пъти използват ресурсоемки парсерни функции',
 'post-expand-template-inclusion-warning' => 'Внимание: Размерът за включване на този шаблон е твърде голям.
 Някои шаблони няма да бъдат включени.',
 'post-expand-template-argument-category' => 'Страници, съдържащи шаблони с пропуснати параметри',
@@ -849,7 +850,7 @@
 'undo-success' => 'Редакцията може да бъде върната. Прегледайте долното сравнение и се уверете, че наистина искате да го направите. След това съхранете страницата, за да извършите връщането.',
 'undo-failure' => 'Редакцията не може да бъде върната поради конфликтни междинни редакции.',
 'undo-norev'   => 'Редакцията не може да бъде върната тъй като не съществува или е била изтрита.',
-'undo-summary' => 'Премахната редакция $1 на [[Special:Contributions/$2|$2]] ([[User talk:$2|беседа]])',
+'undo-summary' => 'Премахната редакция $1 на [[Special:Contributions/$2|$2]] ([[User talk:$2|беседа]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]]))',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Невъзможно е да бъде създадена потребителска сметка.',
@@ -940,7 +941,7 @@
 # Suppression log
 'suppressionlog'     => 'Дневник на премахванията',
 'suppressionlogtext' => 'По-долу е посочен списък на изтривания и блокирания, свързан със съдържание, скрито от администраторите.
-За текущите блокирания и забрани, вижте [[Special:Ipblocklist|списъка с блокираните IP адреси]].',
+За текущите блокирания и забрани, вижте [[Special:IPBlockList|списъка с блокираните IP адреси]].',
 
 # History merging
 'mergehistory'                     => 'Сливане на редакционни истории',
@@ -1022,7 +1023,7 @@
 'mypreferences'            => 'Моите настройки',
 'prefs-edits'              => 'Брой редакции:',
 'prefsnologin'             => 'Не сте влезли',
-'prefsnologintext'         => 'Необходимо е да [[Special:Userlogin|влезете]], за да може да променяте потребителските си настройки.',
+'prefsnologintext'         => 'Необходимо е да [[Special:UserLogin|влезете]], за да може да променяте потребителските си настройки.',
 'prefsreset'               => 'Текущите промени бяха отменени.',
 'qbsettings'               => 'Лента за бърз избор',
 'qbsettings-none'          => 'Без меню',
@@ -1096,7 +1097,7 @@
 'userrights-reason'           => 'Причина за промяната:',
 'userrights-no-interwiki'     => 'Нямате права да редактирате потребителските групи на други уикита.',
 'userrights-nodatabase'       => 'Базата данни $1 не съществува или не е на локалния сървър.',
-'userrights-nologin'          => 'За управление на потребителските права е необходимо [[Special:Userlogin|влизане]] с администраторска сметка.',
+'userrights-nologin'          => 'За управление на потребителските права е необходимо [[Special:UserLogin|влизане]] с администраторска сметка.',
 'userrights-notallowed'       => 'Не ви е позволено да променяте потребителски права.',
 'userrights-changeable-col'   => 'Групи, които можете да променяте',
 'userrights-unchangeable-col' => 'Групи, които не можете да променяте',
@@ -1223,12 +1224,12 @@
 'reupload'                    => 'Повторно качване',
 'reuploaddesc'                => 'Връщане към формуляра за качване.',
 'uploadnologin'               => 'Не сте влезли',
-'uploadnologintext'           => 'Необходимо е да [[Special:Userlogin|влезете]], за да може да качвате файлове.',
+'uploadnologintext'           => 'Необходимо е да [[Special:UserLogin|влезете]], за да може да качвате файлове.',
 'upload_directory_missing'    => 'Директорията за качване ($1) липсва и не може да бъде създадена на сървъра.',
 'upload_directory_read_only'  => 'Сървърът няма достъп за писане в директорията за качване „$1“.',
 'uploaderror'                 => 'Грешка при качване',
 'uploadtext'                  => "Формулярът по-долу служи за качване на файлове, които ще могат да се използват в страниците.
-За преглеждане и търсене на вече качените файлове може да се използва [[Special:Imagelist|списъка с качени файлове]]. Качванията и изтриванията се записват в [[Special:Log/upload|дневника на качванията]].
+За преглеждане и търсене на вече качените файлове може да се използва [[Special:ImageList|списъка с качени файлове]]. Качванията и изтриванията се записват в [[Special:Log/upload|дневника на качванията]].
 
 За включване на файл в страница, може да се използва една от следните препратки: '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:картинка.jpg|алтернативен текст]]</nowiki>''' за изображения или '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:звук.ogg]]</nowiki>''' за звукови файлове.",
 'upload-permitted'            => 'Разрешени файлови формати: $1.',
@@ -1294,9 +1295,9 @@
 'upload-proto-error'      => 'Неправилен протокол',
 'upload-proto-error-text' => 'Изисква се адрес започващ с <code>http://</code> или <code>ftp://</code>.',
 'upload-file-error'       => 'Вътрешна грешка',
-'upload-file-error-text'  => 'Вътрешна грешка при опит да се създаде временен файл на сървъра. Обърнете се към системен администратор.',
+'upload-file-error-text'  => 'Вътрешна грешка при опит да се създаде временен файл на сървъра. Обърнете се към [[Special:ListUsers/sysop|администратор]].',
 'upload-misc-error'       => 'Неизвестна грешка при качване',
-'upload-misc-error-text'  => 'Неизвестна грешка при качване. Убедете се, че адресът е верен и опитайте отново. Ако отново имате проблем, обърнете се към системен администратор.',
+'upload-misc-error-text'  => 'Неизвестна грешка при качване. Убедете се, че адресът е верен и опитайте отново. Ако отново имате проблем, обърнете се към [[Special:ListUsers/sysop|администратор]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Не е възможно достигането на указания URL адрес',
@@ -1310,7 +1311,7 @@
 'upload_source_url'  => ' (правилен, публично достъпен интернет-адрес)',
 'upload_source_file' => ' (файл на вашия компютър)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Тази специална страница показва всички качени файлове.
 По подразбиране последно качените файлове се показват най-високо в списъка.
 Сортирането се променя с щракване в заглавна клетка на колоната.',
@@ -1338,7 +1339,7 @@
 'imagelinks'                     => 'Препратки към файла',
 'linkstoimage'                   => '{{PLURAL:$1|Следната страница сочи|Следните $1 страници сочат}} към файла:',
 'nolinkstoimage'                 => 'Няма страници, сочещи към файла.',
-'morelinkstoimage'               => 'Можете да видите [[Special:Whatlinkshere/$1|още препратки]] към този файл.',
+'morelinkstoimage'               => 'Можете да видите [[Special:WhatLinksHere/$1|още препратки]] към този файл.',
 'redirectstofile'                => '{{PLURAL:$1|Следният файл пренасочва|Следните $1 файла пренасочват}} към този файл:',
 'duplicatesoffile'               => '{{PLURAL:$1|Следният файл се повтаря|Следните $1 файла се повтарят}} с този файл:',
 'sharedupload'                   => 'Този файл е споделен и може да бъде използван от други проекти.',
@@ -1357,18 +1358,18 @@
 # File reversion
 'filerevert'                => 'Възвръщане на $1',
 'filerevert-legend'         => 'Възвръщане на файла',
-'filerevert-intro'          => '<span class="plainlinks">Възвръщане на \'\'\'[[Media:$1|$1]]\'\'\' към [$4 версията от $3, $2].</span>',
+'filerevert-intro'          => "Възвръщане на '''[[Media:$1|$1]]''' към [$4 версията от $3, $2].",
 'filerevert-comment'        => 'Коментар:',
 'filerevert-defaultcomment' => 'Възвръщане към версия от $2, $1',
 'filerevert-submit'         => 'Възвръщане',
-'filerevert-success'        => '<span class="plainlinks">Файлът \'\'\'[[Media:$1|$1]]\'\'\' беше възвърнат към [$4 версия от $3, $2].</span>',
+'filerevert-success'        => "Файлът '''[[Media:$1|$1]]''' беше възвърнат към [$4 версия от $3, $2].",
 'filerevert-badversion'     => 'Не съществува предишна локална версия на файла със зададения времеви отпечатък.',
 
 # File deletion
 'filedelete'                  => 'Изтриване на $1',
 'filedelete-legend'           => 'Изтриване на файл',
 'filedelete-intro'            => "На път сте да изтриете '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Изтривате версията на \'\'\'[[Media:$1|$1]]\'\'\' към [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Изтривате версията на '''[[Media:$1|$1]]''' към [$4 $3, $2].",
 'filedelete-comment'          => 'Коментар:',
 'filedelete-submit'           => 'Изтриване',
 'filedelete-success'          => "Файлът '''$1''' беше изтрит.",
@@ -1421,15 +1422,17 @@
 Това прави средно по '''$5''' редакции на страница и по '''$6''' прегледа на редакция.
 
 Дължината на [http://www.mediawiki.org/wiki/Manual:Job_queue работната опашка] е '''$7'''.",
-'userstatstext'          => "Има {{PLURAL:$1|'''1''' [[Special:Listusers|регистриран потребител]]|'''$1''' [[Special:Listusers|регистрирани потребители]]}} и '''$2''' {{PLURAL:$2|потребител|потребители}} (или '''$4%''') с права на $5.",
+'userstatstext'          => "Има {{PLURAL:$1|'''1''' [[Special:ListUsers|регистриран потребител]]|'''$1''' [[Special:ListUsers|регистрирани потребители]]}} и '''$2''' {{PLURAL:$2|потребител|потребители}} (или '''$4%''') с права на $5.",
 'statistics-mostpopular' => 'Най-преглеждани страници',
 
 'disambiguations'      => 'Пояснителни страници',
 'disambiguationspage'  => 'Template:Пояснение',
 'disambiguations-text' => "Следните страници сочат към '''пояснителна страница''', вместо към истинската тематична страница.<br />Една страница се смята за пояснителна, ако ползва шаблон, към който се препраща от [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Двойни пренасочвания',
-'doubleredirectstext' => 'Всеки ред съдържа препратки към първото и второто пренасочване, както и целта на второто пренасочване, която обикновено е „истинската“ страница, към която първото пренасочване би трябвало да сочи.',
+'doubleredirects'            => 'Двойни пренасочвания',
+'doubleredirectstext'        => 'Всеки ред съдържа препратки към първото и второто пренасочване, както и целта на второто пренасочване, която обикновено е „истинската“ страница, към която първото пренасочване би трябвало да сочи.',
+'double-redirect-fixed-move' => 'Страницата [[$1]] беше преместена, сега е пренасочване към [[$2]]',
+'double-redirect-fixer'      => 'Оправяч на пренасочания',
 
 'brokenredirects'        => 'Невалидни пренасочвания',
 'brokenredirectstext'    => 'Следните пренасочващи страници сочат към несъществуващи страници:',
@@ -1515,7 +1518,7 @@
 'logempty'             => 'Дневникът не съдържа записи, отговарящи на избрания критерий.',
 'log-title-wildcard'   => 'Търсене на заглавия, започващи със',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Всички страници',
 'alphaindexline'    => 'от $1 до $2',
 'nextpage'          => 'Следваща страница ($1)',
@@ -1538,14 +1541,14 @@
 'special-categories-sort-count' => 'сортиране по брой',
 'special-categories-sort-abc'   => 'сортиране по азбучен ред',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Показване на потребителите, започвайки от:',
 'listusers-submit'   => 'Показване',
 'listusers-noresult' => 'Няма намерени потребители.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Права по потребителски групи',
-'listgrouprights-summary'  => 'Следва списък на групите потребители в това уики с асоциираните им права за достъп. Допълнителна информация за отделните права може да бъде намерена [[{{MediaWiki:Listgrouprights-helppage}}|тук]].',
+'listgrouprights-summary'  => 'По-долу на тази страница е показан списък на групите потребители в това уики с асоциираните им права за достъп. Допълнителна информация за отделните права може да бъде намерена [[{{MediaWiki:Listgrouprights-helppage}}|тук]].',
 'listgrouprights-group'    => 'Група',
 'listgrouprights-rights'   => 'Права',
 'listgrouprights-helppage' => 'Help:Права на групите',
@@ -1553,8 +1556,8 @@
 
 # E-mail user
 'mailnologin'     => 'Няма електронна поща',
-'mailnologintext' => 'Необходимо е да [[Special:Userlogin|влезете]] и да посочите валидна електронна поща в [[Special:Preferences|настройките]] си, за да може да пращате писма на други потребители.',
-'emailuser'       => 'Писмо на потребителя',
+'mailnologintext' => 'Необходимо е да [[Special:UserLogin|влезете]] и да посочите валидна електронна поща в [[Special:Preferences|настройките]] си, за да може да пращате писма на други потребители.',
+'emailuser'       => 'Писмо до потребителя',
 'emailpage'       => 'Пращане писмо на потребител',
 'emailpagetext'   => 'Ако потребителят е посочил валидна електронна поща в настройките си, чрез долния формуляр можете да му изпратите съобщение. Адресът, записан в настройките ви, ще се появи в полето „От“ на изпратеното писмо, така че получателят ще е в състояние да ви отговори.',
 'usermailererror' => 'Пощенският обект даде грешка:',
@@ -1570,7 +1573,7 @@
 'emailccsubject'  => 'Копие на писмото ви до $1: $2',
 'emailsent'       => 'Писмото е изпратено',
 'emailsenttext'   => 'Писмото ви беше изпратено.',
-'emailuserfooter' => 'Това писмо беше изпратено от $1 на $2 чрез функцията „Изпращане на писмо на потребителя“ на {{SITENAME}}.',
+'emailuserfooter' => 'Това писмо беше изпратено от $1 на $2 чрез функцията „Изпращане на писмо до потребителя“ на {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Моят списък за наблюдение',
@@ -1579,10 +1582,10 @@
 'nowatchlist'          => 'Списъкът ви за наблюдение е празен.',
 'watchlistanontext'    => 'За преглеждане и редактиране на списъка за наблюдение се изисква $1 в системата.',
 'watchnologin'         => 'Не сте влезли',
-'watchnologintext'     => 'Необходимо е да [[Special:Userlogin|влезете]], за да може да променяте списъка си за наблюдение.',
+'watchnologintext'     => 'Необходимо е да [[Special:UserLogin|влезете]], за да може да променяте списъка си за наблюдение.',
 'addedwatch'           => 'Добавено в списъка за наблюдение',
 'addedwatchtext'       => "Страницата „'''[[:$1]]'''“ беше добавена към [[Special:Watchlist|списъка ви за наблюдение]].
-Нейните бъдещи промени, както и на съответната й дискусионна страница, ще се описват там, а тя ще се появява в '''получер''' в [[Special:Recentchanges|списъка на последните промени]], което ще направи по-лесно избирането й.",
+Нейните бъдещи промени, както и на съответната й дискусионна страница, ще се описват там, а тя ще се появява в '''получер''' в [[Special:RecentChanges|списъка на последните промени]], което ще направи по-лесно избирането й.",
 'removedwatch'         => 'Премахнато от списъка за наблюдение',
 'removedwatchtext'     => 'Страницата „<nowiki>$1</nowiki>“ беше премахната от списъка ви за наблюдение.',
 'watch'                => 'Наблюдаване',
@@ -1659,7 +1662,7 @@
 Потвърдете, че искате това, разбирате последствията и правите това в съответствие с [[{{MediaWiki:Policy-url}}|линията на поведение]].',
 'actioncomplete'              => 'Действието беше изпълнено',
 'deletedtext'                 => 'Страницата „<nowiki>$1</nowiki>“ беше изтрита. Вижте $2 за запис на последните изтривания.',
-'deletedarticle'              => 'изтрита „[[$1]]“',
+'deletedarticle'              => 'изтри „[[$1]]“',
 'suppressedarticle'           => 'премахна "[[$1]]"',
 'dellogpage'                  => 'Дневник на изтриванията',
 'dellogpagetext'              => 'Списък на последните изтривания.',
@@ -1680,22 +1683,22 @@
 'rollbacklink'                => 'отмяна',
 'rollbackfailed'              => 'Отмяната не сполучи',
 'cantrollback'                => 'Не може да се извърши отмяна на редакциите. Последният редактор е и единствен автор на страницата.',
-'alreadyrolled'               => 'Редакцията на [[:$1]], направена от [[User:$2|$2]] ([[User talk:$2|Беседа]]), не може да бъде отменена. Някой друг вече е редактирал страницата или е отменил промените.
+'alreadyrolled'               => 'Редакцията на [[:$1]], направена от [[User:$2|$2]] ([[User talk:$2|Беседа]] | [[Special:Contributions/$2|{{int:contribslink}}]]), не може да бъде отменена. Някой друг вече е редактирал страницата или е отменил промените.
 
-Последната редакция е на [[User:$3|$3]] ([[User talk:$3|Беседа]]).',
+Последната редакция е на [[User:$3|$3]] ([[User talk:$3|Беседа]] | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => "Коментарът на редакцията е бил: „''$1''“.", # only shown if there is an edit comment
 'revertpage'                  => 'Премахване на [[Special:Contributions/$2|редакции на $2]] ([[User talk:$2|беседа]]); възвръщане към последната версия на [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Отменени редакции на $1; възвръщане към последната версия на $2.',
 'sessionfailure'              => 'Изглежда има проблем със сесията ви; действието беше отказано като предпазна мярка срещу крадене на сесията. Натиснете бутона за връщане на браузъра, презаредете страницата, от която сте дошли, и опитайте отново.',
 'protectlogpage'              => 'Дневник на защитата',
 'protectlogtext'              => 'Списък на защитите и техните сваляния за страницата.
-Можете да прегледате и [[Special:Protectedpages|списъка на текущо защитените страници]].',
+Можете да прегледате и [[Special:ProtectedPages|списъка на текущо защитените страници]].',
 'protectedarticle'            => 'защитаване на „[[$1]]“',
 'modifiedarticleprotection'   => 'смяна на нивото на защита на „[[$1]]“',
 'unprotectedarticle'          => 'сваляне на защитата на „[[$1]]“',
 'protect-title'               => 'Защитаване на „$1“',
 'protect-legend'              => 'Потвърждение на защитата',
-'protectcomment'              => 'Причина за защитата:',
+'protectcomment'              => 'Коментар:',
 'protectexpiry'               => 'Изтичане:',
 'protect_expiry_invalid'      => 'Времето на изтичане е невалидно.',
 'protect_expiry_old'          => 'Времето на изтичане лежи в миналото.',
@@ -1798,7 +1801,7 @@
 
 # What links here
 'whatlinkshere'            => 'Какво сочи насам',
-'whatlinkshere-title'      => 'Страници, които сочат към $1',
+'whatlinkshere-title'      => 'Страници, които сочат към „$1“',
 'whatlinkshere-page'       => 'Страница:',
 'linklistsub'              => '(Списък с препратки)',
 'linkshere'                => "Следните страници сочат към '''[[:$1]]''':",
@@ -1817,92 +1820,92 @@
 'whatlinkshere-filters'    => 'Филтри',
 
 # Block/unblock
-'blockip'                     => 'Блокиране',
-'blockip-legend'              => 'Блокиране на потребител',
-'blockiptext'                 => 'Формулярът по-долу се използва за да се забрани правото на писане
+'blockip'                         => 'Блокиране',
+'blockip-legend'                  => 'Блокиране на потребител',
+'blockiptext'                     => 'Формулярът по-долу се използва за да се забрани правото на писане
 на определен IP-адрес или потребител.
 Това трябва да се направи само за да се предотвратят прояви на вандализъм
 и в съответствие с [[{{MediaWiki:Policy-url}}|политиката за поведение]] в {{SITENAME}}.
 Необходимо е да се посочи и причина за блокирането (например заглавия на страници, станали обект на вандализъм).',
-'ipaddress'                   => 'IP-адрес:',
-'ipadressorusername'          => 'IP-адрес или потребител:',
-'ipbexpiry'                   => 'Срок:',
-'ipbreason'                   => 'Причина:',
-'ipbreasonotherlist'          => 'Друга причина',
-'ipbreason-dropdown'          => '
-* Основни причини за блокиране
-** Вмъкване на грешна информация
-** Изтриване на съдържание
-** Пускане на спам
-** Вмъкване на глупости
-** Заплашително поведение
-** Злупотреба с потребителски сметки
-** Недопустимо потребителско име',
-'ipbanononly'                 => 'Блокиране само на анонимни потребители',
-'ipbcreateaccount'            => 'Забрана за създаване на потребителски сметки',
-'ipbemailban'                 => 'Забрана на потребителя да праща е-поща',
-'ipbenableautoblock'          => 'Автоматично блокиране на последния IP-адрес, използван от потребителя, както и на всички останали адреси, от които се опита да редактира',
-'ipbsubmit'                   => 'Блокиране на потребителя',
-'ipbother'                    => 'Друг срок:',
-'ipboptions'                  => 'Два часа:2 hours,Един ден:1 day,Три дни:3 days,Една седмица:1 week,Две седмици:2 weeks,Един месец:1 month,Три месеца:3 months,Шест месеца:6 months,Една година:1 year,Докато свят светува:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'друг',
-'ipbotherreason'              => 'Друга/допълнителна причина:',
-'ipbhidename'                 => 'Скриване на потребителското име/IP-адрес в дневника на блокиранията, в списъка с текущите блокирания и в списъка на потребителите',
-'ipbwatchuser'                => 'Наблюдаване на потребителската страница и беседата на този потребител',
-'badipaddress'                => 'Невалиден IP-адрес',
-'blockipsuccesssub'           => 'Блокирането беше успешно',
-'blockipsuccesstext'          => '„[[Special:Contributions/$1|$1]]“ беше блокиран.<br />
-Вижте [[Special:Ipblocklist|списъка на блокираните потребители]], за да прегледате всички блокирания.',
-'ipb-edit-dropdown'           => 'Причини за блокиране',
-'ipb-unblock-addr'            => 'Отблокиране на $1',
-'ipb-unblock'                 => 'Отблокиране на потребителско име IP-адрес',
-'ipb-blocklist-addr'          => 'Преглед на текущите блокирания на $1',
-'ipb-blocklist'               => 'Преглед на текущите блокирания',
-'unblockip'                   => 'Отблокиране на потребител',
-'unblockiptext'               => 'Използвайте долния формуляр, за да възстановите правото на писане на по-рано блокиран IP-адрес или потребител.',
-'ipusubmit'                   => 'Отблокиране на адреса',
-'unblocked'                   => '[[User:$1|$1]] беше отблокиран.',
-'unblocked-id'                => 'Блок № $1 беше премахнат',
-'ipblocklist'                 => 'Списък на блокирани IP-адреси и потребители',
-'ipblocklist-legend'          => 'Откриване на блокиран потребител',
-'ipblocklist-username'        => 'Потребителско име или IP адрес:',
-'ipblocklist-submit'          => 'Търсене',
-'blocklistline'               => '$1, $2 е блокирал $3 ($4)',
-'infiniteblock'               => 'неограничено',
-'expiringblock'               => 'изтича на $1',
-'anononlyblock'               => 'само анон.',
-'noautoblockblock'            => 'автоблокировката е изключена',
-'createaccountblock'          => 'създаването на сметки е блокирано',
-'emailblock'                  => 'е-пощенската услуга е блокирана',
-'ipblocklist-empty'           => 'Списъкът на блокиранията е празен.',
-'ipblocklist-no-results'      => 'Указаният IP-адрес или потребител не е блокиран.',
-'blocklink'                   => 'блокиране',
-'unblocklink'                 => 'отблокиране',
-'contribslink'                => 'приноси',
-'autoblocker'                 => 'Бяхте блокиран автоматично, тъй като неотдавна IP-адресът ви е бил ползван от блокирания в момента потребител [[User:$1|$1]]. Причината за неговото блокиране е: „$2“.',
-'blocklogpage'                => 'Дневник на блокиранията',
-'blocklogentry'               => 'блокиране на „[[$1]]“ със срок на изтичане $2 $3',
-'blocklogtext'                => 'Тази страница съдържа дневник на блокиранията и отблокиранията, извършени от този потребител.
+'ipaddress'                       => 'IP-адрес:',
+'ipadressorusername'              => 'IP-адрес или потребител:',
+'ipbexpiry'                       => 'Срок:',
+'ipbreason'                       => 'Причина:',
+'ipbreasonotherlist'              => 'Друга причина',
+'ipbreason-dropdown'              => '* Общи причини за блокиране
+** Въвеждане на невярна информация
+** Премахване на съдържание от страниците
+** Добавяне на спам/нежелани външни препратки
+** Въвеждане на безсмислици в страниците
+** Заплашително поведение/тормоз
+** Злупотреба с няколко потребителски сметки
+** Неприемливо потребителско име',
+'ipbanononly'                     => 'Блокиране само на анонимни потребители',
+'ipbcreateaccount'                => 'Забрана за създаване на потребителски сметки',
+'ipbemailban'                     => 'Забрана на потребителя да праща е-поща',
+'ipbenableautoblock'              => 'Автоматично блокиране на последния IP-адрес, използван от потребителя, както и на всички останали адреси, от които се опита да редактира',
+'ipbsubmit'                       => 'Блокиране на потребителя',
+'ipbother'                        => 'Друг срок:',
+'ipboptions'                      => 'два часа:2 hours,един ден:1 day,три дни:3 days,една седмица:1 week,две седмици:2 weeks,един месец:1 month,три месеца:3 months,шест месеца:6 months,една година:1 year,безсрочно:infinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'друг',
+'ipbotherreason'                  => 'Друга/допълнителна причина:',
+'ipbhidename'                     => 'Скриване на потребителското име/IP-адрес в дневника на блокиранията, в списъка с текущите блокирания и в списъка на потребителите',
+'ipbwatchuser'                    => 'Наблюдаване на потребителската страница и беседата на този потребител',
+'badipaddress'                    => 'Невалиден IP-адрес',
+'blockipsuccesssub'               => 'Блокирането беше успешно',
+'blockipsuccesstext'              => '„[[Special:Contributions/$1|$1]]“ беше блокиран.<br />
+Вижте [[Special:IPBlockList|списъка на блокираните потребители]], за да прегледате всички блокирания.',
+'ipb-edit-dropdown'               => 'Причини за блокиране',
+'ipb-unblock-addr'                => 'Отблокиране на $1',
+'ipb-unblock'                     => 'Отблокиране на потребителско име IP-адрес',
+'ipb-blocklist-addr'              => 'Преглед на текущите блокирания на $1',
+'ipb-blocklist'                   => 'Преглед на текущите блокирания',
+'unblockip'                       => 'Отблокиране на потребител',
+'unblockiptext'                   => 'Използвайте долния формуляр, за да възстановите правото на писане на по-рано блокиран IP-адрес или потребител.',
+'ipusubmit'                       => 'Отблокиране на адреса',
+'unblocked'                       => '[[User:$1|$1]] беше отблокиран.',
+'unblocked-id'                    => 'Блок № $1 беше премахнат',
+'ipblocklist'                     => 'Списък на блокирани IP-адреси и потребители',
+'ipblocklist-legend'              => 'Откриване на блокиран потребител',
+'ipblocklist-username'            => 'Потребителско име или IP адрес:',
+'ipblocklist-submit'              => 'Търсене',
+'blocklistline'                   => '$1, $2 е блокирал $3 ($4)',
+'infiniteblock'                   => 'неограничено',
+'expiringblock'                   => 'изтича на $1',
+'anononlyblock'                   => 'само анон.',
+'noautoblockblock'                => 'автоблокировката е изключена',
+'createaccountblock'              => 'създаването на сметки е блокирано',
+'emailblock'                      => 'е-пощенската услуга е блокирана',
+'ipblocklist-empty'               => 'Списъкът на блокиранията е празен.',
+'ipblocklist-no-results'          => 'Указаният IP-адрес или потребител не е блокиран.',
+'blocklink'                       => 'блокиране',
+'unblocklink'                     => 'отблокиране',
+'contribslink'                    => 'приноси',
+'autoblocker'                     => 'Бяхте блокиран автоматично, тъй като неотдавна IP-адресът ви е бил ползван от блокирания в момента потребител [[User:$1|$1]]. Причината за неговото блокиране е: „$2“.',
+'blocklogpage'                    => 'Дневник на блокиранията',
+'blocklogentry'                   => 'блокиране на „[[$1]]“ със срок на изтичане $2 $3',
+'blocklogtext'                    => 'Тази страница съдържа дневник на блокиранията и отблокиранията, извършени от този потребител.
 Автоматично блокираните IP-адреси не са показани.
-Вижте [[Special:Ipblocklist|списъка на блокираните IP-адреси]] за текущото състояние на блокиранията.',
-'unblocklogentry'             => 'отблокиране на „$1“',
-'block-log-flags-anononly'    => 'само анонимни потребители',
-'block-log-flags-nocreate'    => 'създаването на сметки е изключено',
-'block-log-flags-noautoblock' => 'автоблокировката е изключена',
-'block-log-flags-noemail'     => 'е-пощенската услуга е блокирана',
-'range_block_disabled'        => 'Възможността на администраторите да задават интервали при IP-адресите е изключена.',
-'ipb_expiry_invalid'          => 'Невалиден срок на изтичане.',
-'ipb_already_blocked'         => '„$1“ е вече блокиран',
-'ipb_cant_unblock'            => 'Грешка: Не е намерен блок с номер $1. Вероятно потребителят е вече отблокиран.',
-'ipb_blocked_as_range'        => 'Грешка: IP-адресът $1 не може да бъде разблокиран, тъй като е част от блокирания регистър $2. Можете да разблокирате адреса, като разблокирате целия регистър.',
-'ip_range_invalid'            => 'Невалиден интервал за IP-адреси.',
-'blockme'                     => 'Самоблокиране',
-'proxyblocker'                => 'Блокировач на проксита',
-'proxyblocker-disabled'       => 'Тази функция е деактивирана.',
-'proxyblockreason'            => 'Вашият IP адрес беше блокиран, тъй като е анонимно достъпен междинен сървър. Свържете се с доставчика ви на интернет и го информирайте за този сериозен проблем в сигурността.',
-'proxyblocksuccess'           => 'Готово.',
-'sorbsreason'                 => 'Вашият IP-адрес е записан като анонимно достъпен междинен сървър в DNSBL на {{SITENAME}}.',
-'sorbs_create_account_reason' => 'Вашият IP-адрес е записан като анонимно достъпен междинен сървър в DNSBL на {{SITENAME}}. Не можете да създадете сметка.',
+Вижте [[Special:IPBlockList|списъка на блокираните IP-адреси]] за текущото състояние на блокиранията.',
+'unblocklogentry'                 => 'отблокиране на „$1“',
+'block-log-flags-anononly'        => 'само анонимни потребители',
+'block-log-flags-nocreate'        => 'създаването на сметки е изключено',
+'block-log-flags-noautoblock'     => 'автоблокировката е изключена',
+'block-log-flags-noemail'         => 'е-пощенската услуга е блокирана',
+'block-log-flags-angry-autoblock' => 'разширената автоблокировка е включена',
+'range_block_disabled'            => 'Възможността на администраторите да задават интервали при IP-адресите е изключена.',
+'ipb_expiry_invalid'              => 'Невалиден срок на изтичане.',
+'ipb_already_blocked'             => '„$1“ е вече блокиран',
+'ipb_cant_unblock'                => 'Грешка: Не е намерен блок с номер $1. Вероятно потребителят е вече отблокиран.',
+'ipb_blocked_as_range'            => 'Грешка: IP-адресът $1 не може да бъде разблокиран, тъй като е част от блокирания регистър $2. Можете да разблокирате адреса, като разблокирате целия регистър.',
+'ip_range_invalid'                => 'Невалиден интервал за IP-адреси.',
+'blockme'                         => 'Самоблокиране',
+'proxyblocker'                    => 'Блокировач на проксита',
+'proxyblocker-disabled'           => 'Тази функция е деактивирана.',
+'proxyblockreason'                => 'Вашият IP адрес беше блокиран, тъй като е анонимно достъпен междинен сървър. Свържете се с доставчика ви на интернет и го информирайте за този сериозен проблем в сигурността.',
+'proxyblocksuccess'               => 'Готово.',
+'sorbsreason'                     => 'Вашият IP-адрес е записан като анонимно достъпен междинен сървър в DNSBL на {{SITENAME}}.',
+'sorbs_create_account_reason'     => 'Вашият IP-адрес е записан като анонимно достъпен междинен сървър в DNSBL на {{SITENAME}}. Не можете да създадете сметка.',
 
 # Developer tools
 'lockdb'              => 'Заключване на базата от данни',
@@ -1919,7 +1922,7 @@
 'lockdbsuccesssub'    => 'Заключването на базата от данни беше успешно',
 'unlockdbsuccesssub'  => 'Отключването на базата от данни беше успешно',
 'lockdbsuccesstext'   => 'Базата данни на {{SITENAME}} беше заключена.
-<br />Не забравяйте да я [[Special:Unlockdb|отключите]] когато привършите с работата по поддръжката.',
+<br />Не забравяйте да я [[Special:UnlockDB|отключите]] когато привършите с работата по поддръжката.',
 'unlockdbsuccesstext' => 'Базата от данни на {{SITENAME}} беше отключена.',
 'lockfilenotwritable' => 'Няма права за писане върху файла за заключване на базата данни. За да заключи или отключи базата данни, уеб-сървърът трябва да има тези права.',
 'databasenotlocked'   => 'Базата от данни не е заключена.',
@@ -1942,8 +1945,6 @@
 
 В тези случаи, ако желаете, ще е необходимо да преместите страницата ръчно.",
 'movearticle'             => 'Преместване на страница:',
-'movenologin'             => 'Не сте влезли',
-'movenologintext'         => 'Необходимо е да [[Special:Userlogin|влезете]], за да може да премествате страници.',
 'movenotallowed'          => 'Нямате права за преместване на страници в {{SITENAME}}.',
 'newtitle'                => 'Към ново заглавие:',
 'move-watch'              => 'Наблюдаване на страницата',
@@ -1970,7 +1971,7 @@
 'delete_and_move'         => 'Изтриване и преместване',
 'delete_and_move_text'    => '== Наложително изтриване ==
 
-Целевата страница „[[$1]]“ вече съществува. Искате ли да я изтриете, за да освободите място за преместването?',
+Целевата страница „[[:$1]]“ вече съществува. Искате ли да я изтриете, за да освободите място за преместването?',
 'delete_and_move_confirm' => 'Да, искам да изтрия тази страница.',
 'delete_and_move_reason'  => 'Изтрита, за да се освободи място за преместване',
 'selfmove'                => 'Страницата не може да бъде преместена, тъй като целевото име съвпада с първоначалното й заглавие.',
@@ -1978,6 +1979,7 @@
 'imagenocrossnamespace'   => 'Невъзможно е да се преместват картинки извън това именно пространство',
 'imagetypemismatch'       => 'Новото разширение на файла не съвпада с типа му',
 'imageinvalidfilename'    => 'Целевото име на файл е невалидно',
+'fix-double-redirects'    => 'Обновяване на всички пренасочвания, които сочат към оригиналното заглавие',
 
 # Export
 'export'            => 'Изнасяне на страници',
@@ -2024,7 +2026,7 @@
 'import-interwiki-history'   => 'Копиране на всички версии на страницата',
 'import-interwiki-submit'    => 'Внасяне',
 'import-interwiki-namespace' => 'Прехвърляне на страници към именно пространство:',
-'importtext'                 => 'Изнесете файла от изходното уики, използвайки инструмента „{{ns:special}}:Export“, съхранете го на диска си и го качете тук.',
+'importtext'                 => 'Изнесете файла от изходното уики чрез инструмента „[[Special:Export]]“, съхранете го на диска си и го качете тук.',
 'importstart'                => 'Внасяне на страници…',
 'import-revision-count'      => '$1 {{PLURAL:$1|версия|версии}}',
 'importnopages'              => 'Няма страници за внасяне.',
@@ -2091,7 +2093,7 @@
 'tooltip-feed-rss'                => 'RSS feed за страницата',
 'tooltip-feed-atom'               => 'Atom feed за страницата',
 'tooltip-t-contributions'         => 'Показване на приносите на потребителя',
-'tooltip-t-emailuser'             => 'Изпращане на писмо на потребителя',
+'tooltip-t-emailuser'             => 'Изпращане на писмо до потребителя',
 'tooltip-t-upload'                => 'Качване на файлове',
 'tooltip-t-specialpages'          => 'Списък на всички специални страници',
 'tooltip-t-print'                 => 'Версия за печат на страницата',
@@ -2174,10 +2176,11 @@
 'markedaspatrollederror-noautopatrol' => 'Не е разрешено да маркирате своите редакции като проверени.',
 
 # Patrol log
-'patrol-log-page' => 'Дневник на патрула',
-'patrol-log-line' => 'отбеляза $1 от $2 като проверена $3',
-'patrol-log-auto' => '(автоматично)',
-'patrol-log-diff' => 'версия $1',
+'patrol-log-page'   => 'Дневник на патрула',
+'patrol-log-header' => 'Тази страница съдържа дневник на проверените версии.',
+'patrol-log-line'   => 'отбеляза $1 от $2 като проверена $3',
+'patrol-log-auto'   => '(автоматично)',
+'patrol-log-diff'   => 'версия $1',
 
 # Image deletion
 'deletedrevision'                 => 'Изтрита стара версия $1',
@@ -2207,7 +2210,7 @@
 'show-big-image'       => 'Пълна разделителна способност',
 'show-big-image-thumb' => '<small>Размер на предварителния преглед: $1 × $2 пиксела</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Галерия на новите файлове',
 'imagelisttext'         => "Списък от {{PLURAL:$1|един файл|'''$1''' файла, сортирани $2}}.",
 'newimages-summary'     => 'Тази специална страница показва последно качените файлове.',
@@ -2245,8 +2248,8 @@
 'exif-samplesperpixel'           => 'Редица от компоненти',
 'exif-planarconfiguration'       => 'Принцип на организация на данните',
 'exif-ycbcrpositioning'          => 'Y и C позициониране',
-'exif-xresolution'               => 'Хоризонтална резолюция',
-'exif-yresolution'               => 'Вертикална резолюция',
+'exif-xresolution'               => 'Хоризонтална разделителна способност',
+'exif-yresolution'               => 'Вертикална разделителна способност',
 'exif-rowsperstrip'              => 'Брой редове на ивица',
 'exif-stripbytecounts'           => 'Байтове на компресирана ивица',
 'exif-transferfunction'          => 'Функция по пренос',
@@ -2463,7 +2466,7 @@
 
 # External editor support
 'edit-externally'      => 'Редактиране на файла чрез външно приложение',
-'edit-externally-help' => 'За повече информация прегледайте [http://meta.wikimedia.org/wiki/Help:External_editors указанията за настройките].',
+'edit-externally-help' => 'За повече информация прегледайте [http://www.mediawiki.org/wiki/Manual:External_editors указанията за настройките].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'всички',
@@ -2527,7 +2530,7 @@
 'recreate'            => 'Ново създаване',
 
 # HTML dump
-'redirectingto' => 'Пренасочване към [[$1]]…',
+'redirectingto' => 'Пренасочване към [[:$1]]…',
 
 # action=purge
 'confirm_purge'        => 'Изчистване на складираното копие на страницата?
@@ -2622,7 +2625,7 @@
 'version-software-product'         => 'Продукт',
 'version-software-version'         => 'Версия',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Път към файл',
 'filepath-page'    => 'Файл:',
 'filepath-submit'  => 'Път',
@@ -2658,7 +2661,7 @@
 'specialpages-group-redirects'   => 'Пренасочващи специални страници',
 'specialpages-group-spam'        => 'Инструменти против спам',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Празна страница',
 'intentionallyblankpage' => 'Тази страница умишлено е оставена празна',
 
Index: languages/messages/MessagesJa.php
===================================================================
--- languages/messages/MessagesJa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesJa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,19 +4,19 @@
  * @ingroup Language
  * @file
  *
- * @author Suisui
- * @author Marine-Blue
- * @author JtFuruhata
+ * @author Alexsh
+ * @author Aotake
  * @author Broad-Sky
- * @author Siebrand
- * @author Kahusi
  * @author Emk
- * @author Mzm5zbC3
+ * @author Hatukanezumi
  * @author Iwai.masaharu
- * @author לערי ריינהארט
- * @author Aotake
+ * @author JtFuruhata
+ * @author Kahusi
  * @author Kkkdc
- * @author Hatukanezumi
+ * @author Marine-Blue
+ * @author Mzm5zbC3
+ * @author Suisui
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -336,7 +336,7 @@
 'nosuchaction'      => 'そのような動作はありません',
 'nosuchactiontext'  => 'このURIで指定された動作は{{SITENAME}}で認識できません。',
 'nosuchspecialpage' => 'そのような特別ページはありません',
-'nospecialpagetext' => '要求された特別ページは存在しません。有効な特別ページの一覧は[[Special:Specialpages]]にあります。',
+'nospecialpagetext' => '要求された特別ページは存在しません。有効な特別ページの一覧は[[Special:SpecialPages]]にあります。',
 
 # General errors
 'error'                => 'エラー',
@@ -416,7 +416,7 @@
 <p>※いくつかのページはブラウザのキャッシュをクリアするまでログインしているかのように表示されることがあります。</p>',
 'welcomecreation'            => '== $1 さん、ようこそ！ ==
 あなたのアカウントができました。
-お好みに合わせてオプションを変更することができます。',
+お好みに合わせて[[Special:Preferences|オプション（{{SITENAME}}）]]を変更することができます。',
 'loginpagetitle'             => 'ログイン',
 'yourname'                   => '利用者名',
 'yourpassword'               => 'パスワード',
@@ -554,7 +554,7 @@
 *ブロック解除予定: $6
 *ブロック対象: $7
 
-$1 または他の[[{{MediaWiki:Grouppage-sysop}}|管理者]]にこの件についてメールで問い合わせることができます。ただし、[[Special:Preferences|オプション]]に正しいメールアドレスが登録されていない場合、メール送信機能が使えないことに注意してください。
+$1 または他の[[{{int:Grouppage-sysop}}|管理者]]にこの件についてメールで問い合わせることができます。ただし、[[Special:Preferences|オプション]]に正しいメールアドレスが登録されていない場合、メール送信機能が使えないことに注意してください。
 
 あなたのIPアドレスは「$3」、ブロックIDは &#x23;$5 です。問い合わせを行う際には、この情報を必ず書いてください。',
 'autoblockedtext'                  => 'ご利用のIPアドレスは $1 によって投稿をブロックされています。理由は次の通りです。
@@ -574,10 +574,6 @@
 'blockededitsource'                => "'''$1''' への '''あなたの編集''' を以下に示します:",
 'whitelistedittitle'               => '編集にはログインが必要',
 'whitelistedittext'                => 'このページを編集するには $1 する必要があります。',
-'whitelistreadtitle'               => '閲覧にはログインが必要',
-'whitelistreadtext'                => 'このページを閲覧するには[[Special:Userlogin|ログイン]]する必要があります。',
-'whitelistacctitle'                => 'アカウントの作成は許可されていません',
-'whitelistacctext'                 => '{{SITENAME}}のアカウントを作成するには、適切な権限を持った利用者名で[[Special:Userlogin|ログイン]]する必要があります。',
 'confirmedittitle'                 => '編集にはメールアドレスの確認が必要です。',
 'confirmedittext'                  => 'ページの編集を始める前にメールアドレスの確認をする必要があります。[[Special:Preferences|オプション]]でメールアドレスを設定し、確認を行ってください。',
 'nosuchsectiontitle'               => 'セクションが存在しません',
@@ -590,7 +586,7 @@
 'newarticle'                       => '（新規）',
 'newarticletext'                   => 'ページを新規に作成するには新しい内容を書き込んでください。',
 'anontalkpagetext'                 => "----
-''これはアカウントをまだ作成していないか、あるいは使っていない匿名利用者のための会話ページです。{{SITENAME}}では匿名利用者の識別は利用者名のかわりにIPアドレスを用います。IPアドレスは何人かで共有されることがあります。もしも、あなたが匿名利用者で無関係なコメントがここに寄せられる場合は、[[Special:Userlogin|アカウントを作成するかログインして]]他の匿名利用者と間違えられないようにしてくださるようお願いします。",
+''これはアカウントをまだ作成していないか、あるいは使っていない匿名利用者のための会話ページです。匿名利用者の識別は利用者名のかわりにIPアドレスを用います。IPアドレスは何人かで共有されることがあります。もしあなたが匿名利用者で無関係なコメントが寄せられているとお考えの場合は、[[Special:UserLogin/signup|アカウントを作成する]]か[[Special:UserLogin|ログインして]]他の匿名利用者と間違えられないようにしてくださるようお願いします。''",
 'noarticletext'                    => '現在このページには内容がありません。他のページから[[Special:Search/{{PAGENAME}}|このページタイトルを検索する]]か、[{{fullurl:{{FULLPAGENAME}}|action=edit}} このページを編集]できます。',
 'userpage-userdoesnotexist'        => '"$1" という名前のアカウントは登録されていません。このページを編集することが適切かどうか確認してください。',
 'clearyourcache'                   => "'''お知らせ:''' 保存した後、ブラウザのキャッシュをクリアする必要があります。
@@ -612,7 +608,7 @@
 
 ''{{SITENAME}}ではHTMLタグの使用に制限を設けておらず、JavaScript でのアタックを予防するためにプレビューを隠しています。''
 
-<strong>この編集が問題ないものであるならば再度保存してください。それでもうまくいかない際には一度ログアウトして、もう一度ログインしてみてください。</strong>",
+<strong>この編集が問題ないものであるならば再度保存してください。それでもうまくいかない際には一度[[Special:UserLogout|ログアウト]]して、もう一度ログインしてみてください。</strong>",
 'token_suffix_mismatch'            => '<strong>あなたの使用しているクライアントが、エディット・トークン内の句読点を正しく処理していないことを確認しました。
 このページの文章が破損するのを防ぐため、あなたの編集は反映されません。
 問題のある匿名プロキシサービスを利用していると、この問題が起こることがあります。</strong>',
@@ -648,7 +644,7 @@
 'hiddencategories'                 => 'このページは1個の非公開カテゴリに属しています:',
 'edittools'                        => '<!-- ここに書いたテキストは編集及びアップロードのフォームの下に表示されます。 -->',
 'nocreatetitle'                    => 'ページを作成できません',
-'nocreatetext'                     => '{{SITENAME}} ではページの新規作成を制限しています。元のページに戻って既存のページを編集するか、[[Special:Userlogin|ログインまたはアカウントを作成]]してください。',
+'nocreatetext'                     => '{{SITENAME}} ではページの新規作成を制限しています。元のページに戻って既存のページを編集するか、[[Special:UserLogin|ログインまたはアカウントを作成]]してください。',
 'nocreate-loggedin'                => '{{SITENAME}}で新しいページを作成する権限がありません。',
 'permissionserrors'                => '認証エラー',
 'permissionserrorstext'            => 'あなたにはこのページの編集権限がありません。理由は以下の通りです:',
@@ -667,7 +663,7 @@
 # "Undo" feature
 'undo-success' => '編集の取り消しに成功しました。保存ボタンを押すと変更が確定されます。',
 'undo-failure' => '中間の版での編集と競合したため、自動取り消しできませんでした。',
-'undo-summary' => '[[Special:Contributions/$2|$2]] ([[User talk:$2|会話]]) の $1 版の編集を取り消し',
+'undo-summary' => '[[Special:Contributions/$2|$2]] ([[User talk:$2|会話]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]]) による $1 版の編集を取り消し',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'アカウントを作成できません',
@@ -780,7 +776,7 @@
 # Search results
 'searchresults'            => '検索結果',
 'searchresulttext'         => '{{SITENAME}}の検索に関する詳しい情報は、[[{{MediaWiki:Helppage}}|{{int:help}}]]をご覧ください。',
-'searchsubtitle'           => "検索語: '''[[:$1]]'''",
+'searchsubtitle'           => '検索語: \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|"$1" から始まるページ]] | [[Special:WhatLinksHere/$1|"$1" のリンク元]])',
 'searchsubtitleinvalid'    => "検索語: '''$1'''",
 'noexactmatch'             => '"$1" というタイトルのページは存在しませんでした。[[:$1|新規作成する]]。',
 'noexactmatch-nocreate'    => "''\"\$1\"'' というタイトルのページは存在しませんでした。",
@@ -817,7 +813,7 @@
 'mypreferences'            => 'オプション',
 'prefs-edits'              => '編集回数:',
 'prefsnologin'             => 'ログインしていません',
-'prefsnologintext'         => 'オプションを変更するためには、[[Special:Userlogin|ログイン]]する必要があります。',
+'prefsnologintext'         => 'オプションを変更するためには、[[Special:UserLogin|ログイン]]する必要があります。',
 'prefsreset'               => 'オプションは初期化されました。',
 'qbsettings'               => 'クイックバー設定',
 'qbsettings-none'          => 'なし',
@@ -887,7 +883,7 @@
 'userrights-reason'           => '変更理由:',
 'userrights-no-interwiki'     => '他ウィキ上における利用者情報の編集権限はありません。',
 'userrights-nodatabase'       => 'データベース $1は存在しないか、ローカル上にありません。',
-'userrights-nologin'          => '利用者情報を変更するには[[Special:Userlogin|ログイン]]する必要があります。',
+'userrights-nologin'          => '利用者情報を変更するには[[Special:UserLogin|ログイン]]する必要があります。',
 'userrights-notallowed'       => '利用者情報を変更する権限がありません。',
 'userrights-changeable-col'   => '変更可能なグループ',
 'userrights-unchangeable-col' => '変更できないグループ',
@@ -985,15 +981,15 @@
 'reupload'                    => '再アップロード',
 'reuploaddesc'                => 'アップロードのフォームへ戻る',
 'uploadnologin'               => 'ログインしていません',
-'uploadnologintext'           => 'ファイルをアップロードするには[[Special:Userlogin|ログイン]]する必要があります。',
+'uploadnologintext'           => 'ファイルをアップロードするには[[Special:UserLogin|ログイン]]する必要があります。',
 'upload_directory_read_only'  => 'アップロード先のディレクトリ ($1) にウェブサーバーが書き込めません。',
 'uploaderror'                 => 'アップロード エラー',
-'uploadtext'                  => "ファイルを新しくアップロードする場合には、以下のフォームを利用してください。過去にアップロードされたファイルは[[Special:Imagelist|{{int:imagelist}}]]で閲覧したり探したりできます。アップロードや削除は[[Special:Log/upload|アップロードログ]]に記録されます。
+'uploadtext'                  => "ファイルを新しくアップロードする場合には、以下のフォームを利用してください。過去にアップロードされたファイルの閲覧・検索には[[Special:ImageList|{{int:imagelist}}]]をご利用ください。アップロードの記録は[[Special:Log/upload|アップロードログ]]、削除の記録は[[Special:Log/delete|削除ログ]]にも記録されます。
 
-以下の書式で、ページ上にファイル内容を表示（上2例）、またはファイルへ直接リンク（下1例）できます。
-* '''<nowiki>[[</nowiki>{{ns:image}}:<nowiki>File.jpg]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:image}}:<nowiki>File.png|代替テキスト]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:media}}:<nowiki>File.ogg]]</nowiki>'''",
+ページにファイルを挿入するには以下の書式のリンクを使います。
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:<nowiki>File.jpg]]</nowiki></tt>''' とするとファイルをもとのサイズのまま表示します
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}:<nowiki>File.png|200px|thumb|left|代替テキスト]]</nowiki></tt>''' とすると左寄せの枠内に200px幅に縮小した画像を説明文（代替テキスト）を添えて表示します
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}:<nowiki>File.ogg]]</nowiki></tt>''' とするとファイルを表示せずに直接ファイルへリンクします",
 'upload-permitted'            => '許可されているファイル形式： $1',
 'upload-preferred'            => '推奨されているファイル形式： $1',
 'upload-prohibited'           => '禁止されているファイル形式： $1',
@@ -1072,7 +1068,7 @@
 'upload_source_url'  => '（インターネット上のURL）',
 'upload_source_file' => '（あなたのコンピューター上のファイル）',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'この特別ページではすべてのアップロードされたファイルの一覧を表示します。
 
 ソートのデフォルトでは新しい順です。ヘッダのクリックでソート順と種類を変更できます。',
@@ -1100,7 +1096,7 @@
 'imagelinks'                => 'リンク',
 'linkstoimage'              => 'このファイルを使用している{{PLURAL:$1|ページ|&nbsp;$1 ページ}}の一覧:',
 'nolinkstoimage'            => 'このファイルを使用しているページはありません。',
-'morelinkstoimage'          => 'このファイルの[[Special:Whatlinkshere/$1|リンク元]]を見る。',
+'morelinkstoimage'          => 'このファイルの[[Special:WhatLinksHere/$1|リンク元]]を見る。',
 'redirectstofile'           => 'このファイルへ{{PLURAL:$1|リダイレクトされているファイル|リダイレクトされている $1 ファイル}}の一覧:',
 'duplicatesoffile'          => '以下にこのファイルと同一のファイル $1 件を表示しています:',
 'sharedupload'              => 'このファイルは共有されており、他のプロジェクトで使用されている可能性があります。',
@@ -1115,18 +1111,18 @@
 # File reversion
 'filerevert'                => '$1 を差し戻す',
 'filerevert-legend'         => 'ファイルを差し戻す',
-'filerevert-intro'          => '<span class="plainlinks">あなたは\'\'\'[[Media:$1|$1]]\'\'\'の[$4 $3, $2]の版を差し戻そうとしています。</span>',
+'filerevert-intro'          => "あなたは'''[[Media:$1|$1]]'''の[$4 $3, $2]の版を差し戻そうとしています。",
 'filerevert-comment'        => 'コメント:',
 'filerevert-defaultcomment' => '$1 $2 の版へ差し戻し',
 'filerevert-submit'         => '差し戻す',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\'は[$4 $3, $2]の版に差し戻されました。</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]'''は[$4 $3, $2]の版に差し戻されました。",
 'filerevert-badversion'     => '指定されたタイムスタンプより前の版のファイルはありません。',
 
 # File deletion
 'filedelete'                  => '$1の削除',
 'filedelete-legend'           => 'ファイルの削除',
 'filedelete-intro'            => "あなたは'''[[Media:$1|$1]]'''を削除しようとしています。",
-'filedelete-intro-old'        => '<span class="plainlinks">あなたは\'\'\'[[Media:$1|$1]]\'\'\'の[$4 $3, $2]の版を削除しようとしています。</span>',
+'filedelete-intro-old'        => "あなたは'''[[Media:$1|$1]]'''の[$4 $3, $2]の版を削除しようとしています。",
 'filedelete-comment'          => 'コメント:',
 'filedelete-submit'           => '削除する',
 'filedelete-success'          => "'''$1''' は削除されました。",
@@ -1185,8 +1181,9 @@
 'disambiguations-text' => "以下のページは'''曖昧さ回避ページ'''へリンクしています。これらのページはより適した主題のページへリンクされるべきです。<br />
 [[MediaWiki:Disambiguationspage]] からリンクされたテンプレートを使用しているページは曖昧さ回避ページと見なされます。",
 
-'doubleredirects'     => '二重リダイレクト',
-'doubleredirectstext' => '各列は最初及び2つ目のリダイレクトへのリンクが記されています。2つ目のそれ同様、最初のものを本来のページへリダイレクトしなおしてください。',
+'doubleredirects'            => '二重リダイレクト',
+'doubleredirectstext'        => '各列は最初及び2つ目のリダイレクトへのリンクが記されています。2つ目のそれ同様、最初のものを本来のページへリダイレクトしなおしてください。',
+'double-redirect-fixed-move' => '[[$1]] が移動されているため、リダイレクト先を移動先の [[$2]] へ変更しました。',
 
 'brokenredirects'        => '迷子のリダイレクト',
 'brokenredirectstext'    => '以下は存在しないページにリンクしているリダイレクトです。',
@@ -1265,7 +1262,7 @@
 'logempty'             => '条件にマッチする記録はありません。',
 'log-title-wildcard'   => 'この文字列で始まるタイトルを検索する',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => '全ページ',
 'alphaindexline'    => '$1―$2',
 'nextpage'          => '次のページ（$1）',
@@ -1286,12 +1283,12 @@
 'categoriespagetext'            => '{{SITENAME}}には以下のカテゴリが存在します。',
 'special-categories-sort-count' => '項目数順',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'この文字から表示:',
 'listusers-submit'   => '表示',
 'listusers-noresult' => '利用者が見つかりませんでした。大文字・小文字の区別を確認してください。',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'ユーザのグループと権限',
 'listgrouprights-summary'  => '以下はこのウィキに登録されているユーザのグループと権限の一覧です。
 個々の権限に関する更なる情報は[[{{MediaWiki:Listgrouprights-helppage}}]]を見てください。',
@@ -1302,11 +1299,11 @@
 
 # E-mail user
 'mailnologin'     => 'メールアドレスの記載がありません。',
-'mailnologintext' => '他の利用者宛てにメールを送信するためには、[[Special:Userlogin|ログイン]]し、あなたのメールアドレスを[[Special:Preferences|オプション]]に設定する必要があります。',
+'mailnologintext' => '他の利用者宛てにメールを送信するためには、[[Special:UserLogin|ログイン]]し、あなたのメールアドレスを[[Special:Preferences|オプション]]に設定する必要があります。',
 'emailuser'       => 'この利用者にメールを送信',
 'emailpage'       => 'メール送信ページ',
 'emailpagetext'   => 'メールを送る先の利用者が有効なメールアドレスを{{int:preferences}}で登録していれば、下のフォームを通じてメールを送ることができます。
-あなたが登録したご自分のメールアドレスはFrom:の欄に自動的に組み込まれ、受け取った相手が返事を出せるようになっています。',
+あなたが [[Special:Preferences|{{int:preferences}}]]で登録したご自分のメールアドレスは送るメールのFrom:の欄に自動的に組み込まれ、受け取った相手が返事を出せるようになっています。',
 'usermailererror' => 'メール送信時に以下のエラーが発生しました:',
 'defemailsubject' => '{{SITENAME}} 電子メール',
 'noemailtitle'    => '送り先のメールアドレスがありません。',
@@ -1328,11 +1325,11 @@
 'nowatchlist'          => 'あなたのウォッチリストは空です。',
 'watchlistanontext'    => 'ウォッチリストを確認あるいは編集するには $1 してください。',
 'watchnologin'         => 'ログインしていません',
-'watchnologintext'     => 'ウォッチリストを変更するためには、[[Special:Userlogin|ログイン]]している必要があります。',
+'watchnologintext'     => 'ウォッチリストを変更するためには、[[Special:UserLogin|ログイン]]している必要があります。',
 'addedwatch'           => 'ウォッチリストに追加しました',
 'addedwatchtext'       => "ページ \"\$1\" をあなたの[[Special:Watchlist|ウォッチリスト]]に追加しました。
 
-このページと、付属のノートのページに変更があった際にはそれをウォッチリストで知ることができます。また、[[Special:Recentchanges|最近更新したページ]]ではウォッチリストに含まれているページは'''ボールド体'''で表示され、見つけやすくなります。
+このページと、付属のノートのページに変更があった際にはそれをウォッチリストで知ることができます。また、[[Special:RecentChanges|最近更新したページ]]ではウォッチリストに含まれているページは'''ボールド体'''で表示され、見つけやすくなります。
 
 ウォッチリストから特定のページを削除したい場合には、サイドバーかタブにある \"{{int:unwatch}}\" のリンクをクリックしてください。",
 'removedwatch'         => 'ウォッチリストから削除しました',
@@ -1438,10 +1435,9 @@
 'rollbacklink'                => '差し戻し',
 'rollbackfailed'              => '差し戻しに失敗しました',
 'cantrollback'                => '投稿者がただ一人であるため、編集を差し戻せません。',
-'alreadyrolled'               => 'ページ [[:$1]] の [[User:$2|$2]] ([[User talk:$2|会話]])
-による編集の差し戻しに失敗しました。誰か他の利用者が編集を行ったか差し戻しされたのかもしれません。
+'alreadyrolled'               => 'ページ [[:$1]] の [[User:$2|$2]] ([[User talk:$2|会話]] | [[Special:Contributions/$2|{{int:contribslink}}]])による編集のロールバックに失敗しました。他の利用者がすでに編集を行ったかロールバックしたためです。
 
-このページの最後の編集は [[User:$3|$3]] ([[User talk:$3|会話]]) によるものです。',
+このページの最後の編集は [[User:$3|$3]] ([[User talk:$3|会話]] | [[Special:Contributions/$3|{{int:contribslink}}]]) によるものです。',
 'editcomment'                 => '編集内容の要約: <i>$1</i>', # only shown if there is an edit comment
 'revertpage'                  => '[[Special:Contributions/$2|$2]] ([[User talk:$2|会話]]) による編集を [[User:$1|$1]] による版へ差し戻し', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => '$1 による編集を取り消して $2 による直前の版へ差し戻しました。',
@@ -1602,7 +1598,7 @@
 'badipaddress'                => 'IPアドレスが異常です。',
 'blockipsuccesssub'           => 'ブロックに成功しました。',
 'blockipsuccesstext'          => '利用者またはIPアドレス [[Special:Contributions/$1|$1]] の投稿をブロックしました。<br />
-[[Special:Ipblocklist|投稿ブロック中の利用者やIPアドレス]]で確認できます。',
+[[Special:IPBlockList|投稿ブロック中の利用者やIPアドレス]]で確認できます。',
 'ipb-edit-dropdown'           => 'ブロック理由を編集する',
 'ipb-unblock-addr'            => '$1 のブロックを解除',
 'ipb-unblock'                 => '利用者またはIPアドレスのブロックを解除する',
@@ -1632,7 +1628,7 @@
 'autoblocker'                 => '投稿ブロックされている利用者 "$1" と同じIPアドレスのため、自動的にブロックされています。ブロックの理由は "$2" です。',
 'blocklogpage'                => '投稿ブロック記録',
 'blocklogentry'               => '"$1" を $2 ブロックしました $3',
-'blocklogtext'                => 'このページは投稿ブロックと解除の記録です。自動的に投稿ブロックされたIPアドレスは記録されていません。現時点で有効な投稿ブロックは[[Special:Ipblocklist|{{int:ipblocklist}}]]をご覧ください。',
+'blocklogtext'                => 'このページは投稿ブロックと解除の記録です。自動的に投稿ブロックされたIPアドレスは記録されていません。現時点で有効な投稿ブロックは[[Special:IPBlockList|{{int:ipblocklist}}]]をご覧ください。',
 'unblocklogentry'             => '"$1" をブロック解除しました',
 'block-log-flags-anononly'    => '匿名のみ',
 'block-log-flags-nocreate'    => 'アカウント作成のブロック',
@@ -1667,7 +1663,7 @@
 'lockdbsuccesssub'    => 'データベースはロックされました。',
 'unlockdbsuccesssub'  => 'データベースのロックは解除されました',
 'lockdbsuccesstext'   => 'データベースをロックしました。<br />
-メンテナンスが終了したら忘れずに[[Special:Unlockdb|ロックを解除]]してください。',
+メンテナンスが終了したら忘れずに[[Special:UnlockDB|ロックを解除]]してください。',
 'unlockdbsuccesstext' => 'データベースのロックは解除されました。',
 'lockfilenotwritable' => 'データベースのロックファイルに書き込めません。データベースのロック・解除をするには、サーバー上のロックファイルに書き込める必要があります。',
 'databasenotlocked'   => 'データベースはロックされていません。',
@@ -1675,13 +1671,13 @@
 # Move page
 'move-page'               => '$1 の移動',
 'move-page-legend'        => 'ページの移動',
-'movepagetext'            => "下のフォームを利用すると、ページ名を変更し、その履歴も変更先へ移動することができます。
+'movepagetext'            => "下のフォームを利用すると、ページ名が変更され、その履歴も変更先へ移動します。
 古いページは変更先へのリダイレクトページとなります。
-ページの中身と変更前のページに張られたリンクは変わりません。
-ですから、二重になったり壊れてしまったリダイレクトをチェックする必要があります。
+変更前のページへのリダイレクトは自動的に修正することができます。
+自動的な修正を選択しない場合は、[[Special:DoubleRedirects|二重リダイレクト]]や[[Special:BrokenRedirects|迷子のリダイレクト]]を確認する必要があります。リンクを正しく維持するのはあなたの責任です。
 
 移動先がすでに存在する場合には、履歴が移動元ページへのリダイレクトただ一つである場合を除いて移動できません。
-つまり、間違えてページ名を変更した場合には元に戻せます。
+つまり、間違えてページ名を変更した場合には元に戻せます。また移動によって既存のページを上書きしてしまうことはありません。
 
 '''注意！'''
 よく閲覧されるページや、他の多くのページからリンクされているページを移動すると予期せぬ結果が起こるかもしれません。
@@ -1695,8 +1691,6 @@
 
 これらの場合、ノートページを移動する場合には、別に作業する必要があります。',
 'movearticle'             => '移動するページ',
-'movenologin'             => 'ログインしていません',
-'movenologintext'         => 'ページを移動するためには、アカウント作成の上、[[Special:Userlogin|ログイン]]している必要があります。',
 'movenotallowed'          => '{{SITENAME}}でページを移動する権限がありません。',
 'newtitle'                => '新しいページ名',
 'move-watch'              => '移動するページをウォッチ',
@@ -1722,19 +1716,20 @@
 'revertmove'              => '差し戻し',
 'delete_and_move'         => '削除して移動する',
 'delete_and_move_text'    => '== 削除が必要です ==
-移動先 "[[$1]]" は既に存在しています。このページを移動のために削除しますか?',
+移動先 "[[:$1]]" は既に存在しています。このページを移動のために削除しますか?',
 'delete_and_move_confirm' => 'ページ削除の確認',
 'delete_and_move_reason'  => '移動のための削除',
 'selfmove'                => '移動元と移動先のページ名が同じです。自分自身へは移動できません。',
 'immobile_namespace'      => '移動先のページ名は特別なページです。その名前空間にページを移動することはできません。',
+'fix-double-redirects'    => 'このページへのリダイレクトがあればそのリダイレクトを修正する',
 
 # Export
 'export'            => 'ページデータの書き出し',
-'exporttext'        => 'ここでは単独のまたは複数のページのテキストと編集履歴をXMLの形で書き出すことができます。書き出されたXML文書は他のMediaWikiで動いているウィキに取り込んだり、変換したり、個人的な楽しみに使ったりできます。
+'exporttext'        => 'ここでは単独のまたは複数のページのテキストと編集履歴をXMLの形で書き出すことができます。書き出されたXML文書は他のMediaWikiで動いているウィキに[[Special:Import|インポートページ]]を使って取り込めます。
 
 ページデータを書き出すには下のテキストボックスに書き出したいページのタイトルを一行に一ページずつ記入してください。また編集履歴とともに全ての古い版を含んで書き出すのか、最新版のみを書き出すのか選択してください。
 
-後者のケースではリンクの形で使うこともできます。例: [[メインページ]]の最新版を取得するには[[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]]を使用します"[[{{MediaWiki:Mainpage}}]]"。',
+後者のケースではリンクの形で使うこともできます。例: "[[{{MediaWiki:Mainpage}}]]"の最新版を取得するには[[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]]を使用します。',
 'exportcuronly'     => 'すべての履歴を含ませずに、最新版のみを書き出す',
 'exportnohistory'   => "'''お知らせ:''' パフォーマンス上の理由により、このフォームによるページの完全な履歴の書き出しは行えません。",
 'export-submit'     => '書き出し',
@@ -1770,7 +1765,7 @@
 'import-interwiki-history'   => 'このページの全ての版を複製する',
 'import-interwiki-submit'    => '取り込み',
 'import-interwiki-namespace' => '次の名前空間に取り込む:',
-'importtext'                 => '元となるウィキから {{ns:special}}:Export を使ってXMLファイルを書き出し、ここでアップロードしてください。',
+'importtext'                 => '書き出し元となるウィキから [[Special:Export|書き出し用ユーティリティ]]を使ってXMLファイルを書き出してください。あなたのコンピューターに保存した後、ここにアップロードしてください。',
 'importstart'                => 'ページを取り込んでいます...',
 'import-revision-count'      => '$1 版',
 'importnopages'              => 'インポートするページがありません',
@@ -1950,7 +1945,7 @@
 'show-big-image'       => '高解像度での画像',
 'show-big-image-thumb' => '<small>このプレビューのサイズ: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => '新規画像展示室',
 'imagelisttext'         => "'''$1''' 個のファイルを $2 に表示しています",
 'newimages-summary'     => 'この特別ページでは最近、アップロードされたファイルを表示します。',
@@ -2251,7 +2246,7 @@
 
 # External editor support
 'edit-externally'      => '外部アプリケーションを使ってこのファイルを編集する',
-'edit-externally-help' => '詳しい情報は[http://meta.wikimedia.org/wiki/Help:External_editors 外部エディタに関する説明（英語）]をご覧ください。',
+'edit-externally-help' => '詳しい情報は[http://www.mediawiki.org/wiki/Manual:External_editors 外部エディタに関する説明（英語）]をご覧ください。',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'すべて',
@@ -2320,7 +2315,7 @@
 'recreate'            => '新規作成する',
 
 # HTML dump
-'redirectingto' => '[[$1]]へ転送しています...',
+'redirectingto' => '[[:$1]]へ転送しています...',
 
 # action=purge
 'confirm_purge'        => 'ページのキャッシュを破棄します。よろしいですか?
@@ -2435,7 +2430,7 @@
 'version-software-product'         => 'ソフトウェア名',
 'version-software-version'         => 'バージョン',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'パスの取得',
 'filepath-page'    => 'ファイル名:',
 'filepath-submit'  => 'パスを取得',
Index: languages/messages/MessagesFf.php
===================================================================
--- languages/messages/MessagesFf.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFf.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -47,13 +47,13 @@
 # Random page
 'randompage' => 'Ɗerewol kawral',
 
-# Special:Allpages
+# Special:AllPages
 'allarticles' => 'Winndannde hesere',
 
 # Watchlist
 'watch' => 'Rewindaande',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Yiilaade',
 
 );
Index: languages/messages/MessagesKaa.php
===================================================================
--- languages/messages/MessagesKaa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKaa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,9 @@
  * @ingroup Language
  * @file
  *
- * @author Atabek
  * @author AlefZet
+ * @author Atabek
  * @author Jiemurat
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $fallback = 'kk-latn';
@@ -366,7 +363,7 @@
 'nosuchspecialpage' => 'Bunday arnawlı bet joq',
 'nospecialpagetext' => "<big>'''Siz sorag'an bunday arnawlı bet joq.'''</big>
 
-Arnawlı betlerdin' dizimin [[Special:Specialpages|{{int:specialpages}}]] betinen tabıwın'ızg'a boladı.",
+Arnawlı betlerdin' dizimin [[Special:SpecialPages|{{int:specialpages}}]] betinen tabıwın'ızg'a boladı.",
 
 # General errors
 'error'                => "Qa'telik",
@@ -590,10 +587,6 @@
 'blockededitsource'         => "'''$1''' degennin' '''siz ozgertken''' teksti to'mende ko'rsetilgen:",
 'whitelistedittitle'        => "O'zgertiw ushın sistemag'a kiriwin'iz kerek",
 'whitelistedittext'         => "Betterdi o'zgertiw ushın $1 sha'rt.",
-'whitelistreadtitle'        => "Oqıw ushın sistemag'a kiriwin'iz kerek",
-'whitelistreadtext'         => "Betterdi oqıw ushın [[Special:Userlogin|kiriwin'iz]] kerek.",
-'whitelistacctitle'         => "Sizin' akkaunt jaratıwg'a ruxsatın'ız joq",
-'whitelistacctext'          => "{{SITENAME}} saytında akkaunt jaratıw ushın [[Special:Userlogin|kirwin'iz]] kerek ha'mde kerekli ruqsatların'ız bolıwı kerek.",
 'confirmedittitle'          => "O'zgertiw ushın e-mail tastıyıqlaması kerek",
 'confirmedittext'           => "Betlerge o'zgeris kiritiwin'iz ushın aldın E-pochta adresin'izdi tastıyıqlawın'ız kerek.
 E-pochta adresin'izdi [[Special:Preferences|paydalanıwshı sazlawları bo'limi]] arqalı ko'rsetin' ha'm jaramlılıg'ın tekserin'.",
@@ -634,7 +627,7 @@
 'template-semiprotected'    => "(yarım-qorg'alg'an)",
 'nocreatetitle'             => 'Bet jaratıw sheklengen',
 'nocreatetext'              => "{{SITENAME}} saytında taza betlerdi jaratıw sheklengen.
-Arqag'a qaytıp bar betti o'zgertiwin'izge yamasa [[Special:Userlogin|kiriwin'izge / akkaunt jaratıwın'ızg'a]] boladı.",
+Arqag'a qaytıp bar betti o'zgertiwin'izge yamasa [[Special:UserLogin|kiriwin'izge / akkaunt jaratıwın'ızg'a]] boladı.",
 'nocreate-loggedin'         => "{{SITENAME}} proyektinde taza betler jaratıwın'ızg'a ruxsatın'ız joq.",
 'permissionserrors'         => 'Ruxsatnamalar Qatelikleri',
 'recreate-deleted-warn'     => "'''Esletpe: Aldın o'shirilgen betti qayta jaratajaqsız.'''
@@ -870,7 +863,7 @@
 'nolicense'          => "Hesh na'rse saylanbag'an",
 'upload_source_file' => " (sizin' kompyuterin'izdegi fayl)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Media atamasın izlew:',
 'imgfile'               => 'fayl',
 'imagelist'             => 'Fayllar dizimi',
@@ -907,7 +900,7 @@
 'filedelete'             => "$1 degendi o'shiriw",
 'filedelete-legend'      => "Fayldı o'shiriw",
 'filedelete-intro'       => "'''[[Media:$1|$1]]''' o'shirilmekte.",
-'filedelete-intro-old'   => "<span class=\"plainlinks\"> [\$4 \$3, \$2] waqtındag'ı '''[[Media:\$1|\$1]]''' nusqası o'shirilmekte.</span>",
+'filedelete-intro-old'   => "[$4 $3, $2] waqtındag'ı '''[[Media:$1|$1]]''' nusqası o'shirilmekte.",
 'filedelete-comment'     => 'Kommentariy:',
 'filedelete-submit'      => "O'shiriw",
 'filedelete-success'     => "'''$1''' o'shirildi.",
@@ -951,7 +944,7 @@
 Bunın' na'tiyjesinde ortasha esap penen ha'r bir betke '''$5''' o'zgeris tuwrı keledi, ha'mde ha'r bir o'zgeriske '''$6''' qaraw tuwrı  keledi.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Tapsırımalar gezeginin'] uzınlıg'ı: '''$7'''.",
-'userstatstext'          => "Bul jerde '''$1''' [[Special:Listusers|esapqa alıng'an paydalanıwshı]] bar, solardın' ishinen '''$2''' (yag'nıy '''$4 %''') paydalanıwshısında $5 huquqları bar.",
+'userstatstext'          => "Bul jerde '''$1''' [[Special:ListUsers|esapqa alıng'an paydalanıwshı]] bar, solardın' ishinen '''$2''' (yag'nıy '''$4 %''') paydalanıwshısında $5 huquqları bar.",
 'statistics-mostpopular' => "En' ko'p ko'rilgen betler",
 
 'disambiguations'     => "Ko'p ma'nisli betler",
@@ -1020,7 +1013,7 @@
 'log-search-submit'    => "O'tin'",
 'log-title-wildcard'   => "Usı tekstten baslang'an atamalardı izlew",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => "Ha'mme betler",
 'alphaindexline'    => '$1 — $2',
 'nextpage'          => 'Keyingi bet ($1)',
@@ -1039,7 +1032,7 @@
 'categories'         => 'Kategoriyalar',
 'categoriespagetext' => 'Kelesi kategoriyalar ishinde betler yamasa media bar.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "Mına paydalanıwshıdan baslap ko'rsetiw:",
 'listusers-submit'   => "Ko'rset",
 'listusers-noresult' => 'Paydalanıwshı tabılmadı.',
@@ -1065,10 +1058,10 @@
 'nowatchlist'          => "Baqlaw dizimin'iz bos.",
 'watchlistanontext'    => "Baqlaw dizimin'izdegilerdi qaraw yamasa o'zgertiw ushın $1 kerek.",
 'watchnologin'         => 'Kirilmegen',
-'watchnologintext'     => "Baqlaw dizimin'izdi o'zgertiw ushın [[Special:Userlogin|kiriwin'iz]] kerek.",
+'watchnologintext'     => "Baqlaw dizimin'izdi o'zgertiw ushın [[Special:UserLogin|kiriwin'iz]] kerek.",
 'addedwatch'           => 'Baqlaw dizimine qosıldı',
 'addedwatchtext'       => "\"[[:\$1]]\" beti [[Special:Watchlist|baqlaw dizimin'izge]] qosıldı.
-Usı ha'm og'an baylanıslı bolg'an sa'wbet betlerinde bolatug'ın keleshektegi o'zgerisler usı dizimde ko'rsetiledi ha'mde betti tabıwdı an'satlastırıw ushın [[Special:Recentchanges|taza o'zgerisler diziminde]] '''juwan ha'ripte''' ko'rsetiledi.
+Usı ha'm og'an baylanıslı bolg'an sa'wbet betlerinde bolatug'ın keleshektegi o'zgerisler usı dizimde ko'rsetiledi ha'mde betti tabıwdı an'satlastırıw ushın [[Special:RecentChanges|taza o'zgerisler diziminde]] '''juwan ha'ripte''' ko'rsetiledi.
 Eger siz bul betti baqlaw dizimin'izden o'shirmekshi bolsan'ız bettin' joqarg'ı on' jag'ındag'ı \"Baqlamaw\" jazıwın basın'.",
 'removedwatch'         => "Baqlaw diziminen o'shirildi",
 'removedwatchtext'     => '"[[:$1]]" beti baqlaw dizimin\'izden o\'shirildi.',
@@ -1231,7 +1224,7 @@
 'badipaddress'                => 'Jaramsız IP adres',
 'blockipsuccesssub'           => 'Tabıslı qulplaw',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] bloklang'an.<br />
-Basqa bloklawlar ushın [[Special:Ipblocklist|IP bloklaw dizimin]] ko'rip shıg'ın'iz.",
+Basqa bloklawlar ushın [[Special:IPBlockList|IP bloklaw dizimin]] ko'rip shıg'ın'iz.",
 'ipb-edit-dropdown'           => "Bloklaw sebeplerin o'zgertiw",
 'ipb-unblock-addr'            => '$1 degennin qulpın sheshiw',
 'ipb-unblock'                 => "Paydalanıwshının' yamasa IP adrestin' qulpın shesh",
@@ -1296,7 +1289,6 @@
 
 Bul jag'daylarda eger qa'lesen'iz betti qoldan ko'shiriwin'iz yamasa qosıwın'izg'a boladı.",
 'movearticle'             => "Ko'shiriletug'ın bet:",
-'movenologin'             => 'Kirilmegen',
 'newtitle'                => 'Taza atama:',
 'move-watch'              => 'Bul betti baqlaw',
 'movepagebtn'             => "Betti ko'shir",
@@ -1447,7 +1439,7 @@
 'show-big-image'       => 'Joqarı imkaniyatlı',
 'show-big-image-thumb' => "<small>Bul aldinnan ko'riwdin' ha'jmi: $1 × $2 piksel</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Taza fayllar galereyasi',
 'showhidebots'          => '(botlardı $1)',
 'noimages'              => "Ko'riwge su'wret joq.",
@@ -1488,7 +1480,7 @@
 
 # External editor support
 'edit-externally'      => "Bul fayldı sırtqı bag'darlama arqalı o'zgertiw",
-'edit-externally-help' => "Ko'birek mag'lıwmat ushın [http://meta.wikimedia.org/wiki/Help:External_editors ornatıw jolların] qaran'.",
+'edit-externally-help' => "Ko'birek mag'lıwmat ushın [http://www.mediawiki.org/wiki/Manual:External_editors ornatıw jolların] qaran'.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => "ha'mmesin",
@@ -1538,7 +1530,7 @@
 'unit-pixel' => ' px',
 
 # HTML dump
-'redirectingto' => '[[$1]] degenge burılmaqta...',
+'redirectingto' => '[[:$1]] degenge burılmaqta...',
 
 # action=purge
 'confirm_purge_button' => 'OK',
@@ -1596,7 +1588,7 @@
 # Special:Version
 'version' => "MediaWikidin' nusqası", # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'Fayl jolı',
 
 # Special:SpecialPages
Index: languages/messages/MessagesGag.php
===================================================================
--- languages/messages/MessagesGag.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGag.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Cuman
- * @author Siebrand
  */
 
 $fallback = 'tr';
@@ -271,7 +270,7 @@
 'nosuchaction'      => 'Bölä bir işlem yok',
 'nosuchactiontext'  => 'URL tarafınnan tanınan işlem Viki tarafınnan kabledilmedi.',
 'nosuchspecialpage' => 'Bu adda bir maasus sayfa yok',
-'nospecialpagetext' => 'Bir maasus sayfaya girdiniz angısı bulunmêêr. Var olan hepsi maasus sayfaları yakışêr sizä görmää [[Special:Specialpages|{{int:specialpages}}]] sayfasında.',
+'nospecialpagetext' => 'Bir maasus sayfaya girdiniz angısı bulunmêêr. Var olan hepsi maasus sayfaları yakışêr sizä görmää [[Special:SpecialPages|{{int:specialpages}}]] sayfasında.',
 
 # General errors
 'error'              => 'Kusurluk',
@@ -443,7 +442,7 @@
 'template-protected'     => '(korumaa)',
 'template-semiprotected' => '(yarı-korunmaa)',
 'nocreatetext'           => '{{SITENAME}} eni yazılar yaratmaa yasaklandı.
-Sizä yakışêr geeri dönmää hem düzmää var olan yapraa, yaki [[Special:Userlogin|sessiya açmaa yaki esap yaratmaa]].',
+Sizä yakışêr geeri dönmää hem düzmää var olan yapraa, yaki [[Special:UserLogin|sessiya açmaa yaki esap yaratmaa]].',
 'permissionserrors'      => 'İzin yannışları',
 'recreate-deleted-warn'  => "'''Bak: Siz yarattınız o sayfayı angısı ilerdän silindi.'''
 
@@ -551,7 +550,7 @@
 'uploadlogpage' => 'Fayl üklemäk jurnalları',
 'uploadedimage' => 'Üklenen: "[[$1]]"',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Pätret listası',
 
 # Image description page
@@ -638,7 +637,7 @@
 'log'                  => 'Jurnallar',
 'all-logs-page'        => 'Hepsi jurnallar',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Hepsi sayfalar',
 'alphaindexline' => '$1den $2e',
 'nextpage'       => 'Geeriki sayfa ($1)',
@@ -663,7 +662,7 @@
 
 Gelecektä, bu sayfaya hem ilgili konuşmaa sayfasına yapılacêk diişmäkler burada yazılacêk.
 
-[[Special:Recentchanges|Bitki diişmäkler listası]] başlıı altında yazılacêk kalın bukvalarnan neçin ki kolayca seçilsin.
+[[Special:RecentChanges|Bitki diişmäkler listası]] başlıı altında yazılacêk kalın bukvalarnan neçin ki kolayca seçilsin.
 
 Ne zaman neetlendiniz sayfayı bakmaa listasınnan çıkarmaa tuşlayın "sayfaya bakmaa durgun" baalantısına.',
 'removedwatch'         => 'Bakmaa listanızdan silindi',
@@ -860,7 +859,7 @@
 'show-big-image'       => 'Taman aydınnık',
 'show-big-image-thumb' => '<small>Ön siir ölçüsü: $1 × $2 piksel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Eni pätretler',
 
 # Bad image list
@@ -884,7 +883,7 @@
 
 # External editor support
 'edit-externally'      => 'Kompyuterinizdäki uygulamaklarlan faylı düz',
-'edit-externally-help' => 'Taa çok bilgi için var nicä bakmaa metadaki [http://meta.wikimedia.org/wiki/Help:External_editors dış uygulama instrumentläri] (angliyça) sayfasına.',
+'edit-externally-help' => 'Taa çok bilgi için var nicä bakmaa metadaki [http://www.mediawiki.org/wiki/Manual:External_editors dış uygulama instrumentläri] (angliyça) sayfasına.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'Hepsini göster',
Index: languages/messages/MessagesFj.php
===================================================================
--- languages/messages/MessagesFj.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFj.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -149,7 +149,7 @@
 'move'              => 'Toso',
 'movethispage'      => 'Toso na tabana oqo',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Lako',
 
 # E-mail user
@@ -190,7 +190,7 @@
 'tooltip-search'         => 'Vaqaqara {{SITENAME}}',
 'tooltip-p-logo'         => 'Tabana levu',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Vaqaqara',
 
 # Multipage image navigation
Index: languages/messages/MessagesBcl.php
===================================================================
--- languages/messages/MessagesBcl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBcl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,12 +5,8 @@
  * @file
  *
  * @author Filipinayzd
- * @author Steven*fung
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  * @author Siebrand Mazeland
- * @author Niklas Laxström
+ * @author Steven*fung
  */
 
 $skinNames = array(
@@ -321,7 +317,7 @@
 'nosuchspecialpage' => 'Mayong siring na espesyal na páhina',
 'nospecialpagetext' => "<big>'''Dai pwede an pahinang espesyal na pinilî mo.'''</big>
 
-Pwede mong mahiling an lista nin mga marhay na pahina sa [[Special:Specialpages|{{int:specialpages}}]].",
+Pwede mong mahiling an lista nin mga marhay na pahina sa [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Salâ',
@@ -546,10 +542,6 @@
 'blockededitsource'         => "An teksto kan '''mga hira mo''' sa '''$1''' mahihiling sa babâ:",
 'whitelistedittitle'        => 'Kaipuhan an paglaog tangarig makahirá',
 'whitelistedittext'         => 'Kaipuhan mong $1 tangarig makahirá nin mga páhina.',
-'whitelistreadtitle'        => 'Kaipuhan maglaog tangarig makabasa',
-'whitelistreadtext'         => 'Kaipuhan an [[Special:Userlogin|entrada]] para mabasa mo ining mga páhina.',
-'whitelistacctitle'         => 'Dai ka tinotogotan na maggibo nin account',
-'whitelistacctext'          => "Tangarig togotan na maggibo nin ''account'' sa ining wiki kaipuhan mong [[Special:Userlogin|maglaog]] asin dapat igwa kang mga hustong permiso.",
 'confirmedittitle'          => 'Kaipuhan nin kompirmasyon nin e-koreo tangarig makahirá',
 'confirmedittext'           => "Kaipuhan mong kompirmaron an saimong ''e''-surat. Ipwesto tabî asin patunayan an saimong ''e''-surat sa [[Special:Preferences|mga kabôtan kan parágamit]].",
 'nosuchsectiontitle'        => 'Mayong siring na seksyón',
@@ -564,7 +556,7 @@
 Tangarig magibo an pahina, magpoon pagsurat sa kahon sa babâ
 (hilingón an [[{{MediaWiki:Helppage}}|pahina nin tabang]] para sa iba pang impormasyon).
 Kun dai tinuyong nakaabot ka digdi, pindoton sana an back sa browser mo.',
-'anontalkpagetext'          => "----''Ini an pahina kan olay kan sarong parágamit na dai bisto na dai pa naggibo nin account o dai naggagamit kaini. Entonces, piggagamit mi an numero nin IP tangarig mabisto siya. Ining IP pwede gamiton kan manlain-lain na mga parágamit. Kun ika sarong paraágamit na dai bisto asin konbensido ka sa pigsasabi ka ining mga komento bakô man dapit saimo,  [[Special:Userlogin|maggibo nin'' account ''o maglaog]] tabì tangarig maibitaran an pagkaribong saimo asin sa ibang mga parágamit na dai bisto.''",
+'anontalkpagetext'          => "----''Ini an pahina kan olay kan sarong parágamit na dai bisto na dai pa naggibo nin account o dai naggagamit kaini. Entonces, piggagamit mi an numero nin IP tangarig mabisto siya. Ining IP pwede gamiton kan manlain-lain na mga parágamit. Kun ika sarong paraágamit na dai bisto asin konbensido ka sa pigsasabi ka ining mga komento bakô man dapit saimo,  [[Special:UserLogin|maggibo nin'' account ''o maglaog]] tabì tangarig maibitaran an pagkaribong saimo asin sa ibang mga parágamit na dai bisto.''",
 'noarticletext'             => 'Mayo man na teksto sa páhinang ini, pwede mong [[Special:Search/{{PAGENAME}}|hanápon ining titulo nin páhina]] sa ibang mga páhina o [{{fullurl:{{FULLPAGENAME}}|action=edit}} hirahon ining páhina].',
 'clearyourcache'            => "'''Pagiromdom:''' Pagkatapos kan pagtagama, pwede ser na kaipuhan mong lawigawan an abang kan ''browser'' para mahiling mo an mga pagbabâgo. '''Mozilla / Firefox / Safari:''' doonan an ''shift'' an ''Shift'' sabay an pagpindot sa ''Reload'', o pindoton an ''Ctrl-Shift-R'' (''Cmd-Shift-R'' sa Apple Mac); '''IE:''' doonan (dai halion an muro) an ''Ctrl'' mientras sabay an pagpindot sa  ''Refresh'', o pindoton an ''Ctrl-F5''; '''Konqueror:''': pindoton sana ''Reload'', o pindoton  an ''F5''; '''Opera''' pwede ser na kaipuhan na halîon an gabos na laog kan abang sa ''Tools→Preferences''.",
 'usercssjsyoucanpreview'    => "<strong>Tip:</strong> Gamiton an 'Show preview' para testingon an bâgong CSS/JS bago magtagama.",
@@ -620,7 +612,7 @@
 'edittools'                 => '<!-- An teksto digdi mahihiling sa babâ kan mga pormang pighihirá asin pigkakarga. -->',
 'nocreatetitle'             => 'Limitado an paggibo nin pahina',
 'nocreatetext'              => 'Igwang pagpogol sa paggibo nin bàgong pahina sa site na ini.
-Pwede kang bumalik dangan maghirá nin presenteng pahina, o [[Special:Userlogin|maglaog o magbukas nin account]].',
+Pwede kang bumalik dangan maghirá nin presenteng pahina, o [[Special:UserLogin|maglaog o magbukas nin account]].',
 'nocreate-loggedin'         => 'Mayò ka nin permiso na maggibo nin mga bàgong pahina sa wiki na ini.',
 'permissionserrors'         => 'Mga saláng Permiso',
 'permissionserrorstext'     => 'Mayò ka nin permiso na gibohon yan, sa minasunod na {{PLURAL:$1|rason|mga rason}}:',
@@ -690,6 +682,7 @@
 'revisiondelete'              => 'Paraon/bawion an mga pagpakaraháy',
 'revdelete-nooldid-title'     => 'Mayong tunggit pagpakaraháy',
 'revdelete-nooldid-text'      => 'Dai ka nagpili nin target na pagpakarhay o mga pagpakarhay tangarig magamit ini.',
+'revdelete-selected'          => "{{PLURAL:$2|Selected revision|Selected revisions}} kan '''$1:'''",
 'revdelete-text'              => "An mga pagpakarhay asin mga panyayari na pigparâ mahihiling pa sa historya asin mga historial kan páhina, pero an ibang parte kan mga laog kaini dai na ipapahiling sa publiko.
 
 An ibang mga administrador sa ining wiki pwede pang maghiling kan mga nakatagong laog asin pwede pa nindang bawîon an pagparâ kaini sa paggamit kan parehong ''interface'', kun mayô pang mga ibang restriksyón.",
@@ -745,7 +738,7 @@
 'mypreferences'            => 'Mga kabòtan ko',
 'prefs-edits'              => 'Bilang kan mga hirá:',
 'prefsnologin'             => 'Dai nakalaog',
-'prefsnologintext'         => 'Ika dapat si [[Special:Userlogin|nakalaog]] para makapwesto nin mga kabôtan nin parágamit.',
+'prefsnologintext'         => 'Ika dapat si [[Special:UserLogin|nakalaog]] para makapwesto nin mga kabôtan nin parágamit.',
 'prefsreset'               => 'Napwesto giraray an mga kabôtan hali sa bodega.',
 'qbsettings'               => 'Quickbar',
 'qbsettings-none'          => 'Mayô',
@@ -874,11 +867,11 @@
 'reupload'                    => 'Ikargá giraray',
 'reuploaddesc'                => 'Magbalik sa pormulario kan pagkarga.',
 'uploadnologin'               => 'Dai nakalaog',
-'uploadnologintext'           => "Kaipuhan ika si [[Special:Userlogin|nakadagos]]
+'uploadnologintext'           => "Kaipuhan ika si [[Special:UserLogin|nakadagos]]
 para makakarga nin mga ''file''.",
 'upload_directory_read_only'  => 'An directoriong pagkarga na ($1) dai puedeng suratan kan serbidor nin web.',
 'uploaderror'                 => 'Salâ an pagkarga',
-'uploadtext'                  => "Gamiton tabî an pormulario sa babâ para magkarga nin mga ''file'', para maghiling o maghanap kan mga ladawan na dating kinarga magduman tabi sa [[Special:Imagelist|lista nin mga pigkargang ''file'']], an mga kinarga asin mga pinarâ nakalista man sa [[Special:Log/upload|historial nin pagkarga]].
+'uploadtext'                  => "Gamiton tabî an pormulario sa babâ para magkarga nin mga ''file'', para maghiling o maghanap kan mga ladawan na dating kinarga magduman tabi sa [[Special:ImageList|lista nin mga pigkargang ''file'']], an mga kinarga asin mga pinarâ nakalista man sa [[Special:Log/upload|historial nin pagkarga]].
 
 Kun boot mong ikaag an ladawan sa páhina, gamiton tabî an takod arog kan
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -954,7 +947,7 @@
 'upload_source_url'  => ' (sarong tama, na bukas sa publikong URL)',
 'upload_source_file' => " (sarong ''file'' sa kompyuter mo)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'Hanápon an pangaran kan retrato:',
 'imgfile'               => 'dokumento',
 'imagelist'             => 'Lista kan dokumento',
@@ -989,18 +982,18 @@
 # File reversion
 'filerevert'                => 'Ibalik an $1',
 'filerevert-legend'         => 'Ibalik an dokumento',
-'filerevert-intro'          => '<span class="plainlinks">Pigbabalik mo an \'\'\'[[Media:$1|$1]]\'\'\' sa [$4 version as of $3, $2].</span>',
+'filerevert-intro'          => "Pigbabalik mo an '''[[Media:$1|$1]]''' sa [$4 version as of $3, $2].",
 'filerevert-comment'        => 'Komento:',
 'filerevert-defaultcomment' => 'Pigbalik sa bersyon sa ngonyan $2, $1',
 'filerevert-submit'         => 'Ibalik',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' binalik sa [$4 version as of $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' binalik sa [$4 version as of $3, $2].",
 'filerevert-badversion'     => "Mayong dating bersyón na lokal kaining ''file'' na may taták nin oras na arog sa tinao.",
 
 # File deletion
 'filedelete'             => 'Parâon an $1',
 'filedelete-legend'      => 'Parâon an dokumento',
 'filedelete-intro'       => "Pigpaparâ mo an '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'   => '<span class="plainlinks">Pigpaparâ mo an bersyon kan \'\'\'[[Media:$1|$1]]\'\'\' sa ngonyan [$4 $3, $2].</span>',
+'filedelete-intro-old'   => "Pigpaparâ mo an bersyon kan '''[[Media:$1|$1]]''' sa ngonyan [$4 $3, $2].",
 'filedelete-comment'     => 'Komento:',
 'filedelete-submit'      => 'Parâon',
 'filedelete-success'     => "An '''$1''' pinarâ na.",
@@ -1050,7 +1043,7 @@
 Maabot sa '''\$5''' na hira kada páhina sa medio, asin '''\$6''' na paghiling kada hirá.
 
 '''\$7''' an labâ kan [http://www.mediawiki.org/wiki/Manual:Job_queue job queue].",
-'userstatstext'          => "{{PLURAL:$1|is '''1''' registered [[Special:mga paragamit|paragamit]]| '''$1''' an nakarehistrong [[Special:Listusers|users]]}}, '''$2''' (or '''$4%''') kaini {{PLURAL:$2|has|may}} $5 na derechos.",
+'userstatstext'          => "{{PLURAL:$1|is '''1''' registered [[Special:mga paragamit|paragamit]]| '''$1''' an nakarehistrong [[Special:ListUsers|users]]}}, '''$2''' (or '''$4%''') kaini {{PLURAL:$2|has|may}} $5 na derechos.",
 'statistics-mostpopular' => 'mga pinaka pighiling na pahina',
 
 'disambiguations'      => 'Mga pahinang klaripikasyon',
@@ -1134,7 +1127,7 @@
 'logempty'             => 'Mayong angay na bagay sa historial.',
 'log-title-wildcard'   => 'Hanapon an mga titulong napopoon sa tekstong ini',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Gabos na pahina',
 'alphaindexline'    => '$1 sagkod sa $2',
 'nextpage'          => 'Sunod na pahina ($1)',
@@ -1154,18 +1147,18 @@
 'categories'         => 'Mga Kategorya',
 'categoriespagetext' => 'Igwa nin laog ang mga minasunod na kategorya.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Ipahiling an mga paragamit poon sa:',
 'listusers-submit'   => 'Ipahiling',
 'listusers-noresult' => 'Mayong nakuang parágamit.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'  => 'Grupo',
 'listgrouprights-rights' => 'Derechos',
 
 # E-mail user
 'mailnologin'     => 'Mayong direksyón nin destino',
-'mailnologintext' => "Kaipuhan ika si [[Special:Userlogin|nakalaog]]
+'mailnologintext' => "Kaipuhan ika si [[Special:UserLogin|nakalaog]]
 asin may marhay na ''e''-surat sa saimong [[Special:Preferences|Mga kabôtan]]
 para makapadara nin ''e''-surat sa ibang parágamit.",
 'emailuser'       => 'E-koreohan ining paragamit',
@@ -1194,11 +1187,11 @@
 'nowatchlist'          => 'Mayo ka man na mga bagay saimong lista nin pigbabantayan.',
 'watchlistanontext'    => 'Mag $1 tabi para mahiling o maghira nin mga bagay saimong lista nin mga pigbabantayan.',
 'watchnologin'         => 'Mayô sa laog',
-'watchnologintext'     => 'Dapat ika si [[Special:Userlogin|nakalaog]] para puede kang magribay kan saimong lista nin mga pigbabantayán.',
+'watchnologintext'     => 'Dapat ika si [[Special:UserLogin|nakalaog]] para puede kang magribay kan saimong lista nin mga pigbabantayán.',
 'addedwatch'           => 'Idinugang sa pigbabantayan',
 'addedwatchtext'       => "Ining pahina \"[[:\$1]]\" dinugang sa saimong mga [[Special:Watchlist|Pigbabantayan]].
 An mga pagbabâgo sa páhinang ini asin sa mga páhinang olay na kapadis kaini ililista digdi,
-asin an páhina isusurat nin '''mahîbog''' sa [[Special:Recentchanges|lista nin mga kaaagi pa sanang pagbabâgo]] para madalî ining mahiling.
+asin an páhina isusurat nin '''mahîbog''' sa [[Special:RecentChanges|lista nin mga kaaagi pa sanang pagbabâgo]] para madalî ining mahiling.
 
 Kun boot mong halîon an páhina sa pigbabantayan mo sa maabot na panahon, pindoton an \"Pabayaan\" ''side bar''.",
 'removedwatch'         => 'Pigtanggal sa pigbabantayan',
@@ -1302,7 +1295,7 @@
 kinanselár ining aksyón bilang sarong paglikay kontra sa ''session hijacking''.
 Pindotón tabî an \"back\" asin ikarga giraray an páhinang ginikanan mo, dangan probarán giraray.",
 'protectlogpage'              => 'Usip nin proteksyon',
-'protectlogtext'              => 'May lista sa baba nin mga kandado asin panbawi kan kandado kan mga páhina. Hilingon an [[Special:Protectedpages|lista kan mga pigproprotektarán na mga páhina]] para mahiling an lista kan mga proteksión nin mga páhina sa ngunyan na nakabuká.',
+'protectlogtext'              => 'May lista sa baba nin mga kandado asin panbawi kan kandado kan mga páhina. Hilingon an [[Special:ProtectedPages|lista kan mga pigproprotektarán na mga páhina]] para mahiling an lista kan mga proteksión nin mga páhina sa ngunyan na nakabuká.',
 'protectedarticle'            => 'protektado "[[$1]]"',
 'modifiedarticleprotection'   => 'binago an nibel nin proteksión para sa "[[$1]]"',
 'unprotectedarticle'          => 'Warang proteksión an "[[$1]]"',
@@ -1452,7 +1445,7 @@
 'badipaddress'                => 'Dai pwede ining IP',
 'blockipsuccesssub'           => 'Nagibo na an pagbagát',
 'blockipsuccesstext'          => 'Binagat si [[Special:Contributions/$1|$1]].
-<br />Hilingon an [[Special:Ipblocklist|lista nin mga binagat na IP]] para marepaso an mga binagat.',
+<br />Hilingon an [[Special:IPBlockList|lista nin mga binagat na IP]] para marepaso an mga binagat.',
 'ipb-edit-dropdown'           => 'Hirahón an mga rasón sa pagbabagát',
 'ipb-unblock-addr'            => 'Paagihon $1',
 'ipb-unblock'                 => 'Bawion an pagbagat nin ngaran nin paragamit o direccion nin IP',
@@ -1483,7 +1476,7 @@
 'blocklogpage'                => 'Usip nin pagbagat',
 'blocklogentry'               => 'binagat na [[$1]] na may oras nin pagpaso na $2 $3',
 'blocklogtext'                => 'Ini an historial kan pagbagat asin pagbawi sa pagbagat nin mga paragamit. An mga enseguidang binagat na direccion nin
-IP dai nakalista digdi. Hilingon an [[Special:Ipblocklist|IP lista nin mga binagat]] para sa lista nin mga nakaandar na mga pagpangalad buda mga pagbagat.',
+IP dai nakalista digdi. Hilingon an [[Special:IPBlockList|IP lista nin mga binagat]] para sa lista nin mga nakaandar na mga pagpangalad buda mga pagbagat.',
 'unblocklogentry'             => 'binawi an pagbagat $1',
 'block-log-flags-anononly'    => 'Mga paragamit na anónimo sana',
 'block-log-flags-nocreate'    => "pigpopondohán an paggibo nin ''account'",
@@ -1511,7 +1504,7 @@
 'lockdbsuccesssub'    => 'Kinandado na an base nin datos',
 'unlockdbsuccesssub'  => 'Hinalî an kandado nin base nin datos',
 'lockdbsuccesstext'   => 'Pigkandado na an base kan datos.
-<br />Giromdomon na [[Special:Unlockdb|halîon an kandado]] pagkatapos kan pagmantenir.',
+<br />Giromdomon na [[Special:UnlockDB|halîon an kandado]] pagkatapos kan pagmantenir.',
 'unlockdbsuccesstext' => 'Pigbukasan na an base nin datos.',
 'lockfilenotwritable' => "An ''file'' na kandado kan base nin datos dai nasusuratan. Para makandado o mabukasan an bse nin datos, kaipuhan na nasusuratan ini kan web server.",
 'databasenotlocked'   => 'Dai nakakandado an base nin datos.',
@@ -1534,8 +1527,6 @@
 
 Sa mga kasong iyan, kaipuhan mong ibalyo o isalak an páhina nin mano-mano kun boot mo.",
 'movearticle'             => 'Ibalyó an pahina:',
-'movenologin'             => 'Mayô sa laog',
-'movenologintext'         => 'Kaipuhan na rehistradong parágamit ka asin si [[Special:Userlogin|nakalaog]] tangarig makabalyó ka nin páhina.',
 'movenotallowed'          => 'Mayô kang permiso na ibalyó an mga pahina sa wiki na ini.',
 'newtitle'                => 'Sa bàgong titulong:',
 'move-watch'              => 'Bantayán ining pahina',
@@ -1556,7 +1547,7 @@
 'delete_and_move'         => 'Parâon asin ibalyó',
 'delete_and_move_text'    => '==Kaipuhan na parâon==
 
-Igwa nang páhina na "[[$1]]". Gusto mong parâon ini tangarig maibalyó?',
+Igwa nang páhina na "[[:$1]]". Gusto mong parâon ini tangarig maibalyó?',
 'delete_and_move_confirm' => 'Iyo, parâon an pahina',
 'delete_and_move_reason'  => 'Pinarâ tangarig maibalyó',
 'selfmove'                => 'Pareho an páhinang ginikanan asin destinasyon; dai pwedeng ibalyó an sarong páhina sa sadiri.',
@@ -1772,7 +1763,7 @@
 'show-big-image'       => 'Todong resolusyon',
 'show-big-image-thumb' => '<small>Sokol kan patânaw: $1 × $2  na pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria nin mga bàgong file',
 'imagelisttext'         => "Mahihiling sa baba an lista nin mga  '''$1''' {{PLURAL:$1|file|files}} na linain $2.",
 'showhidebots'          => '($1 na bots)',
@@ -1844,7 +1835,7 @@
 
 # External editor support
 'edit-externally'      => 'Hirahón an file gamit an panluwas na aplikasyon',
-'edit-externally-help' => 'Hilingón an  [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] para sa iba pang mga impormasyon.',
+'edit-externally-help' => 'Hilingón an  [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] para sa iba pang mga impormasyon.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'gabos',
@@ -1905,7 +1896,7 @@
 'recreate'            => 'Gibohón giraray',
 
 # HTML dump
-'redirectingto' => 'Piglilikay sa [[$1]]...',
+'redirectingto' => 'Piglilikay sa [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Halîon an an aliho kaining páhina?
Index: languages/messages/MessagesBo.php
===================================================================
--- languages/messages/MessagesBo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -184,7 +184,7 @@
 # Book sources
 'booksources-go' => 'སོང་།',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'དྲ་ངོས་ཡོངས།',
 'allpagessubmit' => 'སོང་།',
 
@@ -218,7 +218,6 @@
 
 # Move page
 'movearticle' => 'སྤོར་ངོས།',
-'movenologin' => 'ནང་འཛུལ་བྱས་མེད།',
 'move-watch'  => 'དྲ་ངོས་འདི་ལ་མཉམ་འཇོག་པ།',
 'movereason'  => 'རྒྱུ་མཚན།',
 
@@ -231,7 +230,7 @@
 'tooltip-ca-move'        => 'ཨཾོབེ༹་ ཐིས་ པགེ་',
 'tooltip-p-logo'         => 'གཙོ་ངོས།',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'འཚོལ།',
 
 # Multipage image navigation
Index: languages/messages/MessagesBs.php
===================================================================
--- languages/messages/MessagesBs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesBs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
+ * @author CERminator
  * @author Demicx
  * @author Kal-El
- * @author Siebrand
  * @author לערי ריינהארט
- * @author CERminator
- * @author Gangleri
  */
 
 $namespaceNames = array(
@@ -482,11 +480,7 @@
 'blockedtext'              => "Vaše korisničko ime ili IP adresa je blokirana od strane $1.
 Dati razlog je sledeći:<br />''$2''<p>Možete kontaktirati $1 ili nekog drugog [[{{MediaWiki:Grouppage-sysop}}|administratora]] da biste razgovarili o blokadi.",
 'whitelistedittitle'       => 'Obavezno je prijavljivanje za uređivanje',
-'whitelistedittext'        => 'Morate da se [[Special:Userlogin|prijavite]] da bi ste uređivali stranice.',
-'whitelistreadtitle'       => 'Obavezno je prijavljivanje za čitanje',
-'whitelistreadtext'        => 'Morate da se [[Special:Userlogin|prijavite]] da bi ste čitali članke.',
-'whitelistacctitle'        => 'Nije vam dozvoljeno da napravite nalog',
-'whitelistacctext'         => 'Da bi vam bilo dozvoljeno da napravite naloge na ovom Vikiju, morate da se [[Special:Userlogin|prijavite]] i imate odgovarajuća ovlašćenja.',
+'whitelistedittext'        => 'Morate da se [[Special:UserLogin|prijavite]] da bi ste uređivali stranice.',
 'loginreqtitle'            => 'Potrebno je prijavljivanje',
 'accmailtitle'             => 'Lozinka poslata.',
 'accmailtext'              => "Lozinka za nalog '$1' je poslata na adresu $2.",
@@ -495,11 +489,11 @@
 *Ako želite unijeti sadržaj, počnite tipkati u prozor ispod ovog teksta.
 *Ako vam treba pomoć, idite na [[{{MediaWiki:Helppage}}|stranicu za pomoć]].
 *Ako ste ovamo dospjeli slučajno, kliknite dugme \"Nazad\" (''Back'') u svom internet pregledaču.",
-'anontalkpagetext'         => "----''Ovo je stranica za razgovor za anonimnog korisnika koji još nije napravio nalog ili ga ne koristi.  Zbog toga moramo da koristimo brojčanu IP adresu kako bismo odentifikovali njega ili nju.  Takvu adresu može dijeliti više korisnika.  Ako ste anonimni korisnik i mislite da su vam upućene nebitne primjedbe, molimo Vas da [[Special:Userlogin|napravite nalog ili se prijavite]] da biste izbjegli buduću zabunu sa ostalim anonimnim korisnicima.''",
+'anontalkpagetext'         => "----''Ovo je stranica za razgovor za anonimnog korisnika koji još nije napravio nalog ili ga ne koristi.  Zbog toga moramo da koristimo brojčanu IP adresu kako bismo odentifikovali njega ili nju.  Takvu adresu može dijeliti više korisnika.  Ako ste anonimni korisnik i mislite da su vam upućene nebitne primjedbe, molimo Vas da [[Special:UserLogin|napravite nalog ili se prijavite]] da biste izbjegli buduću zabunu sa ostalim anonimnim korisnicima.''",
 'noarticletext'            => "<div style=\"border: 1px solid #ccc; padding: 7px;\">'''{{SITENAME}} još nema ovaj članak.'''
 * Da započnete članak, kliknite '''[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} uredite ovu stranicu]'''.
 * [[Special:Search/{{PAGENAME}}|Pretraži {{PAGENAME}}]] u ostalim člancima
-* [[Special:Whatlinkshere/{{NAMESPACE}}:{{PAGENAME}}|Stranice koje su povezane za]] {{PAGENAME}} članak
+* [[Special:WhatLinksHere/{{NAMESPACE}}:{{PAGENAME}}|Stranice koje su povezane za]] {{PAGENAME}} članak
 ----
 * '''Ukoliko ste napravili ovaj članak u poslednjih nekoliko minuta i još se nije pojavio, postoji mogućnost da je server u zastoju zbog osvježavanja baze podataka.''' Molimo Vas da probate sa <span class=\"plainlinks\">[{{fullurl:{{NAMESPACE}}:{{PAGENAME}}|action=purge}} osvježavanjem]<span> ili sačekajte i provjerite kasnije ponovo prije ponovnog pravljenja članka.
 * Ako ste napravili članak pod ovim imenom ranije, moguće je da je bio izbrisan.  Potražite '''{{FULLPAGENAME}}''' [{{fullurl:Special:Log|type=delete&page={{FULLPAGENAMEE}}}} u spisku brisanja].
@@ -532,19 +526,19 @@
 nemojte ih slati ovdje. Takođe, slanje članka podrazumijeva i vašu izjavu da ste ga napisali sami, ili da ste ga kopirali iz izvora u javnom domenu ili sličnog slobodnog izvora.
 
 <strong>NEMOJTE SLATI RAD ZAŠTIĆEN AUTORSKIM PRAVIMA BEZ DOZVOLE AUTORA!</strong>',
-'longpagewarning'          => '<strong>PAŽNJA:  Ova stranica ima $1 kilobajta; niki
-brauzeri mogu imati problema kad uređujete stranice skoro ili veće od 32 kilobajta.
+'longpagewarning'          => '<strong>PAŽNJA: Ova stranica ima $1 kilobajta; neki
+preglednici mogu imati problema kad uređujete stranice skoro ili veće od 32 kilobajta.
 Molimo Vas da razmotrite razbijanje stranice na manje dijelove.</strong>',
 'readonlywarning'          => '<strong>PAŽNJA:  Baza je zaključana zbog održavanja,
 tako da nećete moći da sačuvate svoje izmjene za sada.  Možda želite da kopirate
 i nalijepite tekst u tekst editor i sačuvate ga za kasnije.</strong>',
-'protectedpagewarning'     => '<strong>PAŽNJA: Ova stranica je zaključana tako da samo korisnici sa administratorkim privilegijama mogu da je mijenjaju.</strong>',
+'protectedpagewarning'     => '<strong>PAŽNJA: Ova stranica je zaključana tako da samo korisnici sa administratorskim privilegijama mogu da je mijenjaju.</strong>',
 'semiprotectedpagewarning' => "'''Pažnja:''' Ova stranica je zaključana tako da je samo registrovani korisnici mogu uređivati.",
 'templatesused'            => 'Šabloni koji su upotrebljeni na ovoj stranici:',
 'template-protected'       => '(zaštićeno)',
 'template-semiprotected'   => '(polu-zaštićeno)',
 'nocreatetext'             => 'Na {{SITENAME}} je zabranjeno postavljanje novih stranica. 
-Možete se vratiti i uređivati već postojeće stranice ili se [[Special:Userlogin|prijaviti ili otvoriti korisnički račun]].',
+Možete se vratiti i uređivati već postojeće stranice ili se [[Special:UserLogin|prijaviti ili otvoriti korisnički račun]].',
 'recreate-deleted-warn'    => "'''Upozorenje: Postavljate stranicu koja je prethodno brisana.'''
 
 Razmotrite je li nastavljanje uređivanja ove stranice u skladu s pravilima. Za vašu informaciju slijedi evidencija brisanja s obrazloženjem za prethodno brisanje:",
@@ -578,9 +572,9 @@
 'searchresulttext'      => 'Za više informacija o pretraživanju {{SITENAME}}, pogledajte [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle'        => "Tražili ste '''[[:$1]]'''",
 'searchsubtitleinvalid' => 'Tražili ste $1',
-'noexactmatch'          => "Nema stranice sa takvim imenom.
+'noexactmatch'          => "Nema stranice sa imenom \"\$1\".
 
-Možete '''[[:$1|da napravite članak sa tim naslovom]]''' ili [[{{MediaWiki:Helppage}}|da stavite zahtjev za ovaj članak]] ili [[Special:Allpages/$1|potražite na drugim stranicama]].
+Možete '''[[:\$1|da napravite članak sa tim naslovom]]''' ili [[{{MediaWiki:Helppage}}|da stavite zahtjev za ovaj članak]] ili [[Special:Allpages/\$1|potražite na drugim stranicama]].
 
 ::*'''''<u>Opomena: Nemojte da kopirate materijale za koje nemate dozvolu!</u>'''''",
 'titlematches'          => 'Naslov članka odgovara',
@@ -603,7 +597,7 @@
 'preferences'             => 'Podešavanja',
 'mypreferences'           => 'Moje postavke',
 'prefsnologin'            => 'Niste prijavljeni',
-'prefsnologintext'        => 'Morate biti [[Special:Userlogin|prijavljeni]] da biste podešavali korisnička podešavanja.',
+'prefsnologintext'        => 'Morate biti [[Special:UserLogin|prijavljeni]] da biste podešavali korisnička podešavanja.',
 'prefsreset'              => 'Podešavanja su vraćena na prvotne vrijednosti.',
 'qbsettings'              => 'Podešavanja brze palete',
 'qbsettings-none'         => 'Nikakva',
@@ -686,7 +680,7 @@
 'reupload'                    => 'Ponovo pošaljite',
 'reuploaddesc'                => 'Vratite se na upitnik za slanje.',
 'uploadnologin'               => 'Niste prijavljeni',
-'uploadnologintext'           => 'Morate biti [[Special:Userlogin|prijavljeni]]
+'uploadnologintext'           => 'Morate biti [[Special:UserLogin|prijavljeni]]
 da bi ste slali fajlove.',
 'uploaderror'                 => 'Greška pri slanju',
 'uploadlog'                   => 'log slanja',
@@ -709,7 +703,7 @@
 'uploaddisabled'              => 'Slanje fajlova je isključeno',
 'uploadvirus'                 => 'Fajl sadrži virus!  Detalji:  $1',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Spisak slika',
 
 # Image description page
@@ -722,7 +716,7 @@
 'filehist-filesize'   => 'Veličina datoteke',
 'filehist-comment'    => 'Komentar',
 'imagelinks'          => 'Upotreba slike',
-'linkstoimage'        => 'Sledeće stranice koriste ovu sliku:',
+'linkstoimage'        => '{{PLURAL:$1|Slijedeća stranica koristi|Slijedećih $1 stranica koriste}} ovu sliku:',
 'nolinkstoimage'      => 'Nema stranica koje koriste ovu sliku.',
 'sharedupload'        => 'Ova datoteka se nalazi na [[Commons:Početna strana|Wikimedia Commons]] i može se koristiti i na drugim projektima.',
 
@@ -799,7 +793,7 @@
 'speciallogtitlelabel' => 'Naslov:',
 'log'                  => 'Protokoli',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Sve stranice',
 'alphaindexline' => '$1 do $2',
 'prevpage'       => 'Prethodna stranica ($1)',
@@ -814,7 +808,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nema adrese za slanje',
-'mailnologintext' => 'Morate biti [[Special:Userlogin|prijavljeni]]
+'mailnologintext' => 'Morate biti [[Special:UserLogin|prijavljeni]]
 i imati ispravnu adresu e-pošte u vašim [[Special:Preferences|podešavanjima]]
 da biste slali e-poštu drugim korisnicima.',
 'emailuser'       => 'Pošalji e-poštu ovom korisniku',
@@ -841,9 +835,9 @@
 'mywatchlist'          => 'Praćeni članci',
 'nowatchlist'          => 'Nemate ništa na svom spisku praćenih članaka.',
 'watchnologin'         => 'Niste prijavljeni',
-'watchnologintext'     => 'Morate biti [[Special:Userlogin|prijavljeni]] da bi ste mijenjali spisak praćenih članaka.',
+'watchnologintext'     => 'Morate biti [[Special:UserLogin|prijavljeni]] da bi ste mijenjali spisak praćenih članaka.',
 'addedwatch'           => 'Dodato u spisak praćenih članaka',
-'addedwatchtext'       => 'Stranica "[[:$1]]" je dodata vašem [[Special:Watchlist|spisku praćenih članaka]]. Buduće promjene ove stranice i njoj pridružene stranice za razgovor će biti navedene ovde, i stranica će biti <b>podebljana</b> u [[Special:Recentchanges|spisku]] nedavnih izmjena da bi se lakše uočila.
+'addedwatchtext'       => 'Stranica "[[:$1]]" je dodata vašem [[Special:Watchlist|spisku praćenih članaka]]. Buduće promjene ove stranice i njoj pridružene stranice za razgovor će biti navedene ovde, i stranica će biti <b>podebljana</b> u [[Special:RecentChanges|spisku]] nedavnih izmjena da bi se lakše uočila.
 
 Ako kasnije želite da uklonite stranicu sa vašeg spiska praćenih članaka, kliknite na "prekini praćenje" na paleti.',
 'removedwatch'         => 'Uklonjeno iz spiska praćenih članaka',
@@ -992,7 +986,7 @@
 'badipaddress'         => 'Pogrešna IP adresa',
 'blockipsuccesssub'    => 'Blokiranje je uspjelo',
 'blockipsuccesstext'   => '[[Special:Contributions/$1|$1]] je blokiran.
-<br />Pogledajte [[Special:Ipblocklist|IP spisak blokiranih korisnika]] za pregled blokiranja.',
+<br />Pogledajte [[Special:IPBlockList|IP spisak blokiranih korisnika]] za pregled blokiranja.',
 'unblockip'            => 'Odblokiraj korisnika',
 'unblockiptext'        => 'Upotrebite donji upitnik da bi ste vratili
 pravo pisanja ranije blokiranoj IP adresi
@@ -1006,7 +1000,7 @@
 'autoblocker'          => 'Automatski ste blokirani jer dijelite IP adresu sa "$1".  Razlog za blokiranje je: "\'\'\'$2\'\'\'"',
 'blocklogpage'         => 'Evidencija blokiranja',
 'blocklogentry'        => 'je blokirao "$1" sa vremenom isticanja blokade od $2',
-'blocklogtext'         => 'Ovo je istorija blokiranja i deblokiranja korisnika.  Automatsko blokirane IP adrese nisu uspisane ovde.  Pogledajte [[Special:Ipblocklist|blokirane IP adrese]] za spisak trenutnih zabrana i blokiranja.',
+'blocklogtext'         => 'Ovo je istorija blokiranja i deblokiranja korisnika.  Automatsko blokirane IP adrese nisu uspisane ovde.  Pogledajte [[Special:IPBlockList|blokirane IP adrese]] za spisak trenutnih zabrana i blokiranja.',
 'unblocklogentry'      => 'deblokiran $1',
 'range_block_disabled' => 'Administratorska mogućnost da blokira grupe je isključena.',
 'ipb_expiry_invalid'   => 'Pogrešno vrijeme trajanja.',
@@ -1047,7 +1041,7 @@
 starim imenom neće biti preusmjereni. Vaša je dužnost da se 
 pobrinete da svi linkovi koji vode na članak sa starim imenom 
 budu adekvatno preusmjereni (stranica posebne namjene za 
-[[Special:Maintenance|održavanje]] je korisna za obavještenje 
+održavanje je korisna za obavještenje 
 o mrtvim i duplim preusmjerenjima).
 
 Imajte na umu da članak '''neće''' biti preusmjeren ukoliko 
@@ -1064,9 +1058,6 @@
 
 U tim slučajevima, moraćete ručno da premjestite stranicu ukoliko to želite.",
 'movearticle'      => 'Premjestite stranicu',
-'movenologin'      => 'Niste prijavljeni',
-'movenologintext'  => 'Morate biti registrovani korisnik i [[Special:Userlogin|prijavljeni]]
-da biste premjestili stranicu.',
 'newtitle'         => 'Novi naslov',
 'movepagebtn'      => 'premjestite stranicu',
 'pagemovedsub'     => 'Premještanje uspjelo',
@@ -1093,7 +1084,7 @@
 # Namespace 8 related
 'allmessages'               => 'Sve sistemske poruke',
 'allmessagestext'           => 'Ovo je spisak svih sistemskih poruka u {{ns:mediawiki}} imenskom prostoru.',
-'allmessagesnotsupportedDB' => '[[{{ns:special}}:Allmessages|sistemske poruke]] nisu podržane zato što je <i>wgUseDatabaseMessages</i> isključen.',
+'allmessagesnotsupportedDB' => 'Ova stranica ne može biti korištena jer je <i>wgUseDatabaseMessages</i> isključen.',
 
 # Thumbnails
 'thumbnail-more'  => 'uvećajte',
@@ -1201,7 +1192,7 @@
 'show-big-image'       => 'Vidi sliku u punoj veličini (rezoluciji)',
 'show-big-image-thumb' => '<small>Veličina ovoga prikaza: $1 × $2 piksela</small>',
 
-# Special:Newimages
+# Special:NewImages
 'imagelisttext' => 'Ispod je spisak $1 slika poređanih $2.',
 'showhidebots'  => '($1 botove)',
 'ilsubmit'      => 'Traži',
@@ -1229,7 +1220,7 @@
 
 # External editor support
 'edit-externally'      => 'Izmjeni ovu sliku koristeći vanjski program',
-'edit-externally-help' => 'Pogledajte [http://meta.wikimedia.org/wiki/Help:External_editors instrukcije za podešavanje] za više informacija.',
+'edit-externally-help' => 'Pogledajte [http://www.mediawiki.org/wiki/Manual:External_editors instrukcije za podešavanje] za više informacija.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'sve',
Index: languages/messages/MessagesStq.php
===================================================================
--- languages/messages/MessagesStq.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesStq.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,9 +6,6 @@
  *
  * @author Maartenvdbent
  * @author Pyt
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $fallback = 'de';
@@ -329,7 +326,7 @@
 Ju Siede is muugelkerwiese läsked of ferschäuwen wuuden.
 
 Fals dit nit die Fal is, hääst du eventuäl n Failer in ju Software fuunen.
-Mäld dit n administrator unner Naamenge fon ju URL.',
+Mäld dit n [[Special:ListUsers/sysop|Administrator]] unner Naamenge fon ju URL.',
 'missingarticle-rev'   => '(Versionsnuumer: $1)',
 'missingarticle-diff'  => '(Unnerscheed twiske Versione: $1, $2)',
 'readonly_lag'         => 'Dät Spiekerjen fon Annerengen wuude foar ne kuute Tied automatisk speerd, uum doo Doatenboank-Servere fon dän Wikipedia Tied tou reeken, do Inhoolde unnernunner outouglieken. Fersäik dät jädden in n poor Minuten noch moal.',
@@ -380,11 +377,11 @@
 
 # Login and logout pages
 'logouttitle'                => 'Benutser-Oumäldenge',
-'logouttext'                 => 'Du bäst nu oumälded.
-Du koast {{SITENAME}} nu anonym fääre benutsje, of die fonnäien unner dän sälwe of n uur Benutsernoome wier anmäldje.',
+'logouttext'                 => '<strong>Du bäst nu oumälded.</strong>
+Du koast {{SITENAME}} nu anonym fääre benutsje, of die fonnäien unner dän sälwe of n uur Benutsernoome wier [[Special:UserLogin|anmäldje]].',
 'welcomecreation'            => '== Wäilkuumen, $1 ==
 
-Dien Benutserkonto wuude mäd Ärfoulch iengjucht. Ferjeet nit, dien Ienstaalengen antoupaasjen.',
+Dien Benutserkonto wuude iengjucht. Ferjeet nit, dien Ienstaalengen antoupaasjen.',
 'loginpagetitle'             => 'Benutser-Anmäldenge',
 'yourname'                   => 'Benutsernoome:',
 'yourpassword'               => 'Paaswoud:',
@@ -547,10 +544,6 @@
 'blockededitsource'                => "Die Wältext '''fon dien Annerengen''' an '''$1''':",
 'whitelistedittitle'               => 'Toun Beoarbaidjen is dät nöödich, anmälded tou weesen',
 'whitelistedittext'                => 'Du moast die $1, uum Artikkele beoarbaidje tou konnen.',
-'whitelistreadtitle'               => 'Toun Leesen is dät nöödich, anmälded tou weesen',
-'whitelistreadtext'                => 'Du moast die [[Special:Userlogin|hier anmäldje]], uum Artikkele leese tou konnen.',
-'whitelistacctitle'                => 'Du hääst neen Gjucht, n Benutserkonto tou moakjen.',
-'whitelistacctext'                 => 'Uum in {{SITENAME}} Benutserkonten anlääse tou muugen, moast du die eerste [[Special:Userlogin|hier anmäldje]], un do nöödige Begjuchtigengen hääbe.',
 'confirmedittitle'                 => 'Toun Beoarbaidjen is ju E-Mail-Anärkannenge nöödich.',
 'confirmedittext'                  => 'Du moast dien E-Mail-Adresse eerste anärkanne, eer du beoarbaidje koast. Fäl dien E-Mail uut un ärkanne ju an in do [[Special:Preferences|Ienstaalengen]].',
 'nosuchsectiontitle'               => 'Oudeelenge bestoant nit',
@@ -565,7 +558,7 @@
 'anontalkpagetext'                 => "----''Dit is ju Diskussionssiede fon n uunbekoanden Benutser, die sik nit anmälded häd.
 Wail naan Noome deer is, wäd ju nuumeriske IP-Adrässe tou Identifizierenge ferwoand.
 Man oafte wäd sunne Adrässe fon moorere Benutsere ferwoand.
-Wan du n uunbekoanden Benutser bääst un du toankst dät du Kommentare krichst do nit foar die meend sunt, dan koast du ap bääste dien [[Special:Userlogin|anmäldje]], uum sukke Fertuusengen tou fermieden.''",
+Wan du n uunbekoanden Benutser bääst un du toankst dät du Kommentare krichst do nit foar die meend sunt, dan koast du ap bääste dien [[Special:UserLogin|anmäldje]], uum sukke Fertuusengen tou fermieden.''",
 'noarticletext'                    => 'Deer is apstuuns naan Text ap disse Siede. Du koast [[Special:Search/{{PAGENAME}}|disse Siedenoome säike]] in uur Sieden of [{{fullurl:{{FULLPAGENAME}}|action=edit}} disse Siede beoarbaidje].',
 'userpage-userdoesnotexist'        => 'Dät Benutserkonto „$1“ is nit deer. Pröif, of du disse Siede wuddelk moakje/beoarbaidje wolt.',
 'clearyourcache'                   => "'''Bemäärkenge: Ätter dät Fäästlääsen kon dät nöödich weese, dän Browser-Cache loostoumoakjen, uum do Annerengen sjo tou konnen.'''
@@ -579,7 +572,9 @@
 'note'                             => '<strong>Waiwiesenge:</strong>',
 'previewnote'                      => '<strong>Dit is man ne Foarschau, die Artikkel wuude noch nit spiekerd!</strong>',
 'previewconflict'                  => 'Disse Foarschau rakt dän Inhoold fon dät buppere Täkstfäild wier; so wol die Artikkel uutsjo, wan du nu spiekerjen dääst.',
-'session_fail_preview'             => '<strong>Dien Beoarbaidenge kuud nit spiekerd wäide, deer dien Sitsengsdoaten ferlädden geen sunt. Fersäik dät jädden fonnäien. Schuul dät Problem bestounden blieuwe, logge die kuut uut un wier ien.</strong>',
+'session_fail_preview'             => '<strong>Dien Beoarbaidenge kuud nit spiekerd wäide, deer dien Sitsengsdoaten ferlädden geen sunt. 
+Fersäik dät jädden fonnäien, deertruch dät du unner ju foulgjende Foarschau nochmoal ap "Siede spiekerje" klikst. 
+Schuul dät Problem bestounden blieuwe, mäldje die ou un deerätter wier an.</strong>',
 'session_fail_preview_html'        => "<strong>Dien Beoarbaidenge kuud nit spiekerd wäide, deer dien Sitsengsdoaten ferlädden geen sunt.</strong>
 
 ''Deer in dissen Wiki scheen HTML aktivierd is, wuude ju Foarschau uutblended uum JavaScript Angriepe tou ferhinnerjen.''
@@ -622,7 +617,7 @@
 'hiddencategories'                 => 'Disse Siede is Meeglid fon {{PLURAL:$1|1 ferstatte Kategorie|$1 ferstatte Kategorien}}:',
 'edittools'                        => '<!-- Text hier stoant unner Beoarbaidengsfäildere un Hoochleedefäildere. -->',
 'nocreatetitle'                    => 'Dät Moakjen fon näie Sieden is begränsed',
-'nocreatetext'                     => 'Ap {{SITENAME}} wuude dät Moakjen fon näie Sieden begränsed. Du koast al bestoundene Sieden beoarbaidje of die [[Special:Userlogin|anmäldje]].',
+'nocreatetext'                     => 'Ap {{SITENAME}} wuude dät Moakjen fon näie Sieden begränsed. Du koast al bestoundene Sieden beoarbaidje of die [[Special:UserLogin|anmäldje]].',
 'nocreate-loggedin'                => 'Du hääst neen Begjuchtigenge, näie Sieden in {{SITENAME}} antoulääsen.',
 'permissionserrors'                => 'Begjuchtigengs-Failere',
 'permissionserrorstext'            => 'Du bäst nit begjuchtiged, ju Aktion uuttoufieren. {{PLURAL:$1|Gruund|Gruunde}}:',
@@ -818,7 +813,7 @@
 'mypreferences'            => 'Ienstaalengen',
 'prefs-edits'              => 'Antaal Beoarbaidengen:',
 'prefsnologin'             => 'Nit anmälded',
-'prefsnologintext'         => 'Du moast [[Special:Userlogin|anmälded]] weese, uum dien Ienstaalengen tou annerjen.',
+'prefsnologintext'         => 'Du moast [[Special:UserLogin|anmälded]] weese, uum dien Ienstaalengen tou annerjen.',
 'prefsreset'               => 'Ienstaalengen wuuden ap Standoard touräächsät.',
 'qbsettings'               => 'Siedenlieste',
 'qbsettings-none'          => 'Naan',
@@ -891,7 +886,7 @@
 'userrights-reason'           => 'Gruund:',
 'userrights-no-interwiki'     => 'Du hääst neen Begjuchtigenge, do Benutsergjuchte in uur Wikis tou annerjen.',
 'userrights-nodatabase'       => 'Ju Doatenboank $1 is nit deer of nit lokoal.',
-'userrights-nologin'          => 'Du moast die mäd n Administrator-Benutserkonto [[Special:Userlogin|anmäldje]], uum Benutsergjuchte tou annerjen.',
+'userrights-nologin'          => 'Du moast die mäd n Administrator-Benutserkonto [[Special:UserLogin|anmäldje]], uum Benutsergjuchte tou annerjen.',
 'userrights-notallowed'       => 'Du hääst neen Begjuchtigenge, uum Benutsergjuchte tou reeken.',
 'userrights-changeable-col'   => 'Gruppentouheeregaid, ju du annerje koast',
 'userrights-unchangeable-col' => 'Gruppentouheeregaid, ju du nit annerje koast',
@@ -1021,12 +1016,12 @@
 'reupload'                    => 'Fonnäien hoochleede',
 'reuploaddesc'                => 'Oubreeke un tourääch tou ju Hoochleede-Siede.',
 'uploadnologin'               => 'Nit anmälded',
-'uploadnologintext'           => 'Du moast [[Special:Userlogin|anmälded weese]], uum Doatäie hoochleede tou konnen.',
+'uploadnologintext'           => 'Du moast [[Special:UserLogin|anmälded weese]], uum Doatäie hoochleede tou konnen.',
 'upload_directory_missing'    => 'Dät Upload-Ferteeknis ($1) failt un kuud truch dän Webserver uk nit moaked wäide.',
 'upload_directory_read_only'  => 'Die Webserver häd neen Schrieuwgjuchte foar dät Upload-Ferteeknis ($1).',
 'uploaderror'                 => 'Failer bie dät Hoochleeden',
 'uploadtext'                  => "Bruuk dät Formular hier unner uum Doatäie hoochtouleeden.
-Gung, uum eer hoochleedene Doatäie tou bekiekjen of tou säiken, ätter ju [[Special:Imagelist|Lieste fon hoochleedene Doatäie]]. Hoochleedengen un Läskengen sunt uk apnuumen in dät [[Special:Log/upload|Hoochleede-Logbouk]]. 
+Gung, uum eer hoochleedene Doatäie tou bekiekjen of tou säiken, ätter ju [[Special:ImageList|Lieste fon hoochleedene Doatäie]]. Hoochleedengen un Läskengen sunt uk apnuumen in dät [[Special:Log/upload|Hoochleede-Logbouk]]. 
 
 Uum ne Doatäi in n Artikkel tou ferweenden, benutsje ne Ferbiendenge in ju Foarm 
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
@@ -1117,7 +1112,7 @@
 'upload_source_url'  => ' (gultige, eepentelk tougongelke URL)',
 'upload_source_file' => ' (ne Doatäi ap Jou Computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Disse Spezialsiede liestet aal hoochleedene Doatäie ap. Standoardmäitich wäide do toulääst hoochleedene Doatäie toueerst anwiesd. Truch n Klik ap do Spaltenuurschrifte kon ju Sortierenge uumetroald wäide of der kon ätter ne uur Spalte sortierd wäide.',
 'imagelist_search_for'  => 'Säik ätter Doatäi:',
 'imgfile'               => 'Doatäi',
@@ -1143,7 +1138,7 @@
 'imagelinks'                     => 'Bieldeferwiese',
 'linkstoimage'                   => '{{PLURAL:$1|Ju foulgjende Siede ferwoant|Do foulgjende $1 Sieden ferweende}} disse Doatäi:',
 'nolinkstoimage'                 => 'Naan Artikkel benutset disse Bielde.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Wiedere Ferbiendengen]] foar disse Doatäi.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Wiedere Ferbiendengen]] foar disse Doatäi.',
 'redirectstofile'                => '{{PLURAL:$1|Ju foulgjende Doatäi laitet|Do foulgjende $1 Doatäie laitje}} ap disse Doatäi fääre:',
 'duplicatesoffile'               => '{{PLURAL:$1|Ju foulgjende Doatäi is n Duplikoat|Do foulgjende $1 Doatäie sunt Duplikoate}} fon disse Doatäi:',
 'sharedupload'                   => 'Disse Doatäi is ne deelde Hoochleedenge un duur fon uur Projekte anwoand wäide.',
@@ -1162,18 +1157,18 @@
 # File reversion
 'filerevert'                => 'Touräächsätte fon "$1"',
 'filerevert-legend'         => 'Doatäi touräächsätte',
-'filerevert-intro'          => '<span class="plainlinks">Du sätst ju Doatäi \'\'\'[[Media:$1|$1]]\'\'\' ap ju [$4 Version fon $2, $3 Uure] tourääch.</span>',
+'filerevert-intro'          => "Du sätst ju Doatäi '''[[Media:$1|$1]]''' ap ju [$4 Version fon $2, $3 Uure] tourääch.",
 'filerevert-comment'        => 'Kommentoar:',
 'filerevert-defaultcomment' => 'touräächsät ap ju Version fon $1, $2 Uure',
 'filerevert-submit'         => 'Touräächsätte',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' wuud ap ju [$4 Version fon $2, $3 Uure] touräächsät.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' wuud ap ju [$4 Version fon $2, $3 Uure] touräächsät.",
 'filerevert-badversion'     => 'Et rakt neen Version fon ju Doatäi tou dän ounroate Tiedpunkt.',
 
 # File deletion
 'filedelete'                  => 'Läskje "$1"',
 'filedelete-legend'           => 'Läskje Doatäi',
 'filedelete-intro'            => "Du läskest ju Doatäi '''„[[Media:$1|$1]]“'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Du läskest fon ju Doatäi \'\'\'„[[Media:$1|$1]]“\'\'\' ju [$4 Version fon $2, $3 Uur].</span>',
+'filedelete-intro-old'        => "Du läskest fon ju Doatäi '''„[[Media:$1|$1]]“''' ju [$4 Version fon $2, $3 Uur].",
 'filedelete-comment'          => 'Gruund:',
 'filedelete-submit'           => 'Läskje',
 'filedelete-success'          => "'''\"\$1\"''' wuude läsked.",
@@ -1229,7 +1224,7 @@
 Deeruut reeke sik '''$5''' Beoarbaidengen pro Siede un '''$6''' Siedenouroupe pro Beoarbaidenge.
 
 Laangte fon ju [http://www.mediawiki.org/wiki/Manual:Job_queue „Job queue“]: '''$7'''",
-'userstatstext'          => "Dät rakt '''$1''' {{PLURAL:$1|registrierde|registrierde}} [[Special:Listusers|Benutsere]].
+'userstatstext'          => "Dät rakt '''$1''' {{PLURAL:$1|registrierde|registrierde}} [[Special:ListUsers|Benutsere]].
 Deerfon {{PLURAL:$2|häd|hääbe}} '''$2''' {{PLURAL:$2|Benutser|Benutsere}} (=$4 %) $5-Gjuchte.",
 'statistics-mostpopular' => 'Maast besoachte Sieden',
 
@@ -1328,7 +1323,7 @@
 'logempty'             => 'Neen paasende Iendraage.',
 'log-title-wildcard'   => 'Tittel fangt oun mäd …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Aal Artikkele',
 'alphaindexline'    => '$1 bit $2',
 'nextpage'          => 'Naiste Siede ($1)',
@@ -1351,12 +1346,12 @@
 'special-categories-sort-count' => 'Sortierenge ätter Antaal',
 'special-categories-sort-abc'   => 'Sortierenge ätter Alphabet',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Wies Benutsere fon:',
 'listusers-submit'   => 'Wies',
 'listusers-noresult' => 'Naan Benutser fuunen.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Benutsergruppen-Gjuchte',
 'listgrouprights-summary'  => 'Dit is ne Lieste fon do in dissen Wiki definierde Benutsergruppen un do deermäd ferbuundene Gjuchte.
 Informatione uurhäär uur eenpelde Gjuchte konnen [[{{MediaWiki:Listgrouprights-helppage}}|hier]] fuunen wäide.',
@@ -1367,7 +1362,7 @@
 
 # E-mail user
 'mailnologin'     => 'Du bäst nit anmälded.',
-'mailnologintext' => 'Du moast [[Special:Userlogin|anmälded weese]] un sälwen ne [[Special:Preferences|gultige E-Mail-Adrässe]] anroat hääbe, uum uur Benutsere ne E-Mail tou seenden.',
+'mailnologintext' => 'Du moast [[Special:UserLogin|anmälded weese]] un sälwen ne [[Special:Preferences|gultige E-Mail-Adrässe]] anroat hääbe, uum uur Benutsere ne E-Mail tou seenden.',
 'emailuser'       => 'Seende E-Mail an dissen Benutser',
 'emailpage'       => 'E-mail an Benutser',
 'emailpagetext'   => 'Wan disse Benutser ne gultige Email-Adrässe anroat häd, konnen Jie him mäd dän unnerstoundene Formuloar ne E-mail seende. As Ouseender wäd ju E-mail-Adrässe uut Jou Ienstaalengen iendrain, deermäd die Benutser Jou oantwoudje kon.',
@@ -1393,11 +1388,11 @@
 'nowatchlist'          => 'Du hääst neen Iendraage ap dien Beooboachtengslieste. Du moast anmälded weese, dät die een Beooboachtengslieste tou Ferföigenge stoant.',
 'watchlistanontext'    => 'Du moast die $1, uum dien Beooboachtengslieste tou sjoon of Iendraage ap hier tou beoarbaidjen.',
 'watchnologin'         => 'Du bäst nit anmälded',
-'watchnologintext'     => 'Du moast [[Special:Userlogin|anmälded]] weese, uum dien Beooboachtengslieste tou beoarbaidjen.',
+'watchnologintext'     => 'Du moast [[Special:UserLogin|anmälded]] weese, uum dien Beooboachtengslieste tou beoarbaidjen.',
 'addedwatch'           => 'An Foulgelieste touföiged.',
 'addedwatchtext'       => "Die Artikkel \"[[:\$1]]\" wuude an dien [[Special:Watchlist|Foulgelieste]] touföiged.
 Leetere Annerengen an dissen Artikkel un ju touheerende Diskussionssiede wäide deer liested
-un die Artikkel wäd in ju [[Special:Recentchanges|fon do lääste Annerengen]] in '''Fatschrift''' anroat.
+un die Artikkel wäd in ju [[Special:RecentChanges|fon do lääste Annerengen]] in '''Fatschrift''' anroat.
 
 Wan du die Artikkel wier fon ju Foulgelieste ou hoalje moatest, klik ap ju Siede ap \"Ferjeet disse Siede\".",
 'removedwatch'         => 'Fon ju Beooboachtengsslieste ou hoald',
@@ -1507,7 +1502,7 @@
 'sessionfailure'              => 'Dät roat n Problem mäd ju Uurdreegenge fon dien Benutserdoaten. Disse Aktion wuude deeruum sicherheidshoolwe oubreeken, uum ne falske Touoardnenge fon dien Annerengen tou n uur Benutser tou ferhinnerjen. Gung jädden tourääch un fersäik dän Foargong fonnäien uuttoufieren.',
 'protectlogpage'              => 'Siedenschuts-Logbouk',
 'protectlogtext'              => 'Dit is ne Lieste fon do blokkierde Sieden.
-Sjuch [[Special:Protectedpages|Schutsede Siede]] foar moor Informatione.',
+Sjuch [[Special:ProtectedPages|Schutsede Siede]] foar moor Informatione.',
 'protectedarticle'            => 'schutsede „[[$1]]“',
 'modifiedarticleprotection'   => 'annerde dän Schuts fon „[[$1]]“',
 'unprotectedarticle'          => 'hieuwede dän Schuts fon "[[$1]]" ap',
@@ -1670,7 +1665,7 @@
 'badipaddress'                    => 'Dissen Benutser bestoant nit, d.h. die Noome is falsk',
 'blockipsuccesssub'               => 'Blokkoade geloangen',
 'blockipsuccesstext'              => 'Ju IP-Adrässe [[Special:Contributions/$1|$1]] wuude blokkierd.
-<br />[[Special:Ipblocklist|Lieste fon Blokkoaden]].',
+<br />[[Special:IPBlockList|Lieste fon Blokkoaden]].',
 'ipb-edit-dropdown'               => 'Speergruunde beoarbaidje',
 'ipb-unblock-addr'                => '"$1" fräireeke',
 'ipb-unblock'                     => 'IP-Adrässe/Benutser fräireeke',
@@ -1735,7 +1730,7 @@
 'lockdbsuccesssub'    => 'Doatenboank wuude mäd Ärfoulch speerd',
 'unlockdbsuccesssub'  => 'Doatenboank wuude mäd Ärfoulch fräiroat',
 'lockdbsuccesstext'   => 'Ju Doatenboank wuude speerd.<br />
-Reek jädden [[Special:Unlockdb|ju Doatenboank wier fräi]], so gau ju Fersuurgenge ousleeten is.',
+Reek jädden [[Special:UnlockDB|ju Doatenboank wier fräi]], so gau ju Fersuurgenge ousleeten is.',
 'unlockdbsuccesstext' => 'Ju {{SITENAME}}-Doatenboank wuude fräiroat.',
 'lockfilenotwritable' => 'Ju Doatenboank-Speerdoatäi is nit beschrieuwboar. Toun Speeren of Fräireeken fon ju Doatenboank mout ju foar dän Webserver beschrieuwboar weese.',
 'databasenotlocked'   => 'Ju Doatenboank is nit speerd.',
@@ -1760,8 +1755,6 @@
 
 In disse Falle moast du ju Siede, wan wonsked, fon Hounde ferschuuwe. Jädden dän '''näie''' Tittel unner '''Siel''' iendreege, deerunner ju Uumnaamenge jädden '''begründje'''.",
 'movearticle'             => 'Siede ferschuuwe:',
-'movenologin'             => 'Du bäst nit anmälded',
-'movenologintext'         => 'Du moast n registrierden Benutser un [[Special:Userlogin|anmälded]] weese, uum ne Siede ferschuuwe tou konnen.',
 'movenotallowed'          => 'Du hääst in {{SITENAME}} neen Begjuchtigenge, Sieden tou ferschuuwen.',
 'newtitle'                => 'Tou dän näie Tittel:',
 'move-watch'              => 'Disse Siede beooboachtje',
@@ -1788,7 +1781,7 @@
 'revertmove'              => 'tourääch ferschuuwe',
 'delete_and_move'         => 'Läskje un ferschuuwe',
 'delete_and_move_text'    => '==Sielartikkel is al deer, läskje?==
-Die Artikkel "[[$1]]" existiert al.
+Die Artikkel "[[:$1]]" existiert al.
 Moatest du him foar ju Ferschuuwenge läskje?',
 'delete_and_move_confirm' => 'Jee, Sielartikkel foar ju Ferschuuwenge läskje',
 'delete_and_move_reason'  => 'Läsked uum Plats tou moakjen foar Ferschuuwenge',
@@ -2021,7 +2014,7 @@
 'show-big-image'       => 'Bielde in hooge Aplöösenge',
 'show-big-image-thumb' => '<small>Grööte fon disse Foarschau: $1 × $2 Pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Näie Bielden',
 'imagelisttext'         => "Hier is ne Lieste fon '''$1''' {{PLURAL:$1|Doatäi|Doatäie}}, sortierd $2.",
 'newimages-summary'     => 'Disse Spezioalsiede wiest do toulääst hoochleedene Doatäie an.',
@@ -2377,7 +2370,7 @@
 'recreate'            => 'Wierhäärstaale',
 
 # HTML dump
-'redirectingto' => 'Fäärelaited ätter [[$1]]',
+'redirectingto' => 'Fäärelaited ätter [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Dän Cache fon disse Siede loosmoakje?
@@ -2473,7 +2466,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Doatäipaad',
 'filepath-page'    => 'Doatäi:',
 'filepath-submit'  => 'Paad säike',
@@ -2509,7 +2502,7 @@
 'specialpages-group-redirects'   => 'Fäärelaitjende Spezioalsieden',
 'specialpages-group-spam'        => 'Spam-Reewen',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Loose Siede',
 'intentionallyblankpage' => 'Disse Siede is apsichtelk sunner Inhoold. Ju wäd foar Benchmarks ferwoand.',
 
Index: languages/messages/MessagesFr.php
===================================================================
--- languages/messages/MessagesFr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesFr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,29 +4,26 @@
  * @ingroup Language
  * @file
  *
+ * @author Cedric31
+ * @author ChrisPtDe
+ * @author Dereckson
+ * @author Esbardu
  * @author Grondin
- * @author Urhixidur
- * @author Meithal
- * @author IAlex
- * @author Verdy p
  * @author Guillom
- * @author Seb35
- * @author לערי ריינהארט
- * @author Sherbrooke
- * @author Siebrand
  * @author Hégésippe Cormier
- * @author Dereckson
- * @author Cedric31
+ * @author IAlex
+ * @author JeanVoisin
  * @author Korg
  * @author Louperivois
  * @author McDutchie
+ * @author Meithal
  * @author Omnipaedista
- * @author JeanVoisin
- * @author SPQRobin
- * @author ChrisPtDe
- * @author Esbardu
- * @author Jon Harald Søby
+ * @author Seb35
+ * @author Sherbrooke
+ * @author Urhixidur
+ * @author Verdy p
  * @author Горан Анђелковић
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -505,7 +502,7 @@
 'nosuchspecialpage' => 'Page spéciale inexistante',
 'nospecialpagetext' => "<big>'''Vous avez demandé une page spéciale non reconnue par ce wiki.'''</big>
 
-Une liste des pages spéciales valides peut être trouvée sur [[Special:Specialpages|{{int:specialpages}}]].",
+Une liste des pages spéciales valides peut être trouvée sur [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erreur',
@@ -531,7 +528,7 @@
 Ceci est habituellement causé en suivant le lien périmé d’un diff ou de l’historique vers une page ayant été supprimée.
 
 Si cela n’est pas le cas, vous pouvez avoir trouvé un bogue dans le programme.
-Veuillez en faire part à un administrateur et lui noter l’adresse cible du lien.',
+Veuillez en faire part à un [[Special:ListUsers/sysop|administrateur]] et lui noter l’adresse cible du lien.',
 'missingarticle-rev'   => '(révision # : $1)',
 'missingarticle-diff'  => '(Diff : $1, $2)',
 'readonly_lag'         => 'La base de donnée a été automatiquement verrouillée pendant que les serveurs secondaires rattrapent leur retard sur le serveur principal.',
@@ -584,7 +581,8 @@
 Vous pouvez continuer à utiliser {{SITENAME}} de façon anonyme, vous reconnecter sous le même nom ou un autre.",
 'welcomecreation'            => '== Bienvenue, $1 ! ==
 
-Votre compte a été créé. N’oubliez pas de personnaliser vos préférences sur {{SITENAME}}.',
+Votre compte a été créé.
+N’oubliez pas de personnaliser vos [[Special:Preferences|préférences sur {{SITENAME}}]].',
 'loginpagetitle'             => 'Connexion',
 'yourname'                   => 'Votre nom d’utilisateur :',
 'yourpassword'               => 'Votre mot de passe :',
@@ -595,7 +593,7 @@
 'loginproblem'               => '<b>Problème d’identification.</b><br />Essayez à nouveau !',
 'login'                      => 'Identification',
 'nav-login-createaccount'    => 'Créer un compte ou se connecter',
-'loginprompt'                => "Vous devez activer les témoins (''cookies'') pour vous connecter à {{SITENAME}}.",
+'loginprompt'                => "Vous devez activer les témoins (''cookies'') pour vous [[Special:UserLogin|connecter à {{SITENAME}}]].",
 'userlogin'                  => 'Créer un compte ou se connecter',
 'logout'                     => 'Se déconnecter',
 'userlogout'                 => 'Déconnexion',
@@ -715,37 +713,39 @@
 'summary-preview'                  => 'Prévisualiser le résumé',
 'subject-preview'                  => 'Prévisualisation du sujet/titre',
 'blockedtitle'                     => 'L’utilisateur est bloqué.',
-'blockedtext'                      => "<big>'''Votre compte utilisateur (ou votre adresse IP) a été bloqué.'''</big>
+'blockedtext'                      => "<big>'''Votre compte utilisateur ou votre adresse IP a été bloqué.'''</big>
 
-Le blocage a été effectué par $1 pour la raison suivante : ''$2''.
+Le blocage a été effectué par $1.
+La raison invoquée est la suivante : ''$2''.
 
-Vous pouvez contacter $1 ou un autre [[{{MediaWiki:Grouppage-sysop}}|administrateur]] pour en discuter. Vous ne pouvez utiliser la fonction « Envoyer un courriel à cet utilisateur » que si une adresse de courriel valide est spécifiée dans vos [[Special:Preferences|préférences]]. Votre adresse IP actuelle est $3 et votre identifiant de blocage est #$5. Veuillez inclure cette adresse dans toute requête.
 * Début du blocage : $8
 * Expiration du blocage : $6
-* Compte bloqué : $7.",
+* Compte bloqué : $7.
+
+Vous pouvez contacter $1 ou un autre [[{{MediaWiki:Grouppage-sysop}}|administrateur]] pour en discuter.
+Vous ne pouvez utiliser la fonction « Envoyer un courriel à cet utilisateur » que si une adresse de courriel valide est spécifiée dans vos [[Special:Preferences|préférences]].
+Votre adresse IP actuelle est $3 et votre identifiant de blocage est #$5.
+Veuillez inclure cette adresse dans toute requête.",
 'autoblockedtext'                  => "Votre adresse IP a été bloquée automatiquement car elle a été utilisée par un autre utilisateur, lui-même bloqué par $1.
-La raison donnée est :
+La raison invoquée est :
 
 :''$2''
 
 * Début du blocage : $8
 * Expiration du blocage : $6
+* Compte bloqué : $7
 
 Vous pouvez contacter $1 ou l’un des autres [[{{MediaWiki:Grouppage-sysop}}|administrateurs]] pour discuter de ce blocage.
 
 Notez que vous ne pouvez pas utiliser la fonctionnalité d’envoyer un courriel à cet utilisateur tant que vous n’aurez pas une adresse courriel enregistrée dans vos [[Special:Preferences|préférences utilisateur]] et tant que vous ne serez pas bloqué pour son utilisation.
 
-Votre numéro de blocage est $5.
-Veuillez préciser cet identifiant dans toutes les requêtes que vous ferez.",
+Votre adresse IP actuelle est $3, et le numéro de blocage est $5.
+Veuillez préciser ces indications dans toutes les requêtes que vous ferez.",
 'blockednoreason'                  => 'Aucune raison donnée',
 'blockedoriginalsource'            => "Le code source de  '''$1''' est indiqué ci-dessous :",
 'blockededitsource'                => "Le contenu de '''vos modifications''' apportées à '''$1''' est indiqué ci-dessous :",
-'whitelistedittitle'               => 'Connexion nécessaire pour modifier le contenu',
+'whitelistedittitle'               => '[[Special:UserLogin|Connexion nécessaire]] pour modifier le contenu',
 'whitelistedittext'                => 'Vous devez être $1 pour avoir la permission de modifier le contenu.',
-'whitelistreadtitle'               => 'Connexion nécessaire pour lire le contenu',
-'whitelistreadtext'                => 'Vous devez être [[Special:Userlogin|connecté]] pour lire le contenu.',
-'whitelistacctitle'                => 'Vous n’êtes pas autorisé à créer un compte.',
-'whitelistacctext'                 => 'Pour pouvoir créer un compte sur ce Wiki, vous devez être [[Special:Userlogin|connecté]] et avoir les permissions appropriées.',
 'confirmedittitle'                 => 'Validation de l’adresse de courriel nécessaire pour modifier le contenu',
 'confirmedittext'                  => 'Vous devez confirmer votre adresse courriel avant de modifier {{SITENAME}}. Veuillez entrer et valider votre adresse électronique à l’aide de la page [[Special:Preferences|préférences]].',
 'nosuchsectiontitle'               => 'Section manquante',
@@ -760,7 +760,7 @@
 'newarticletext'                   => "Vous avez suivi un lien vers une page qui n’existe pas encore ou qui a été [{{fullurl:Special:Log|type=delete&page={{FULLPAGENAMEE}}}} effacée].
 Pour créer cette page, entrez votre texte dans la boîte ci-dessous (vous pouvez consulter [[{{MediaWiki:Helppage}}|la page d’aide]] pour plus d’informations).
 Si vous êtes arrivé ici par erreur, cliquez sur le bouton '''retour''' de votre navigateur.",
-'anontalkpagetext'                 => "---- ''Vous êtes sur la page de discussion d’un utilisateur anonyme qui n’a pas encore créé de compte ou qui n’en utilise pas. Pour cette raison, nous devons utiliser son adresse IP pour l’identifier. Une adresse IP peut être partagée par plusieurs utilisateurs. Si vous êtes un utilisateur anonyme et si vous constatez que des commentaires qui ne vous concernent pas vous ont été adressés, vous pouvez [[Special:Userlogin|créer un compte ou vous connecter]] afin d’éviter toute confusion future avec d’autres contributeurs anonymes.''",
+'anontalkpagetext'                 => "---- ''Vous êtes sur la page de discussion d’un utilisateur anonyme qui n’a pas encore créé de compte ou qui n’en utilise pas. Pour cette raison, nous devons utiliser son adresse IP pour l’identifier. Une adresse IP peut être partagée par plusieurs utilisateurs. Si vous êtes un utilisateur anonyme et si vous constatez que des commentaires qui ne vous concernent pas vous ont été adressés, vous pouvez [[Special:UserLogin/signup|créer un compte]] ou [[Special:UserLogin|vous connecter]] afin d’éviter toute confusion future avec d’autres contributeurs anonymes.''",
 'noarticletext'                    => 'Il n’y a pour l’instant aucun texte sur cette page ; vous pouvez [[Special:Search/{{PAGENAME}}|lancer une recherche sur ce titre de page]], vérifier qu’elle n’a pas été [{{fullurl:Special:Log|type=delete&page={{FULLPAGENAMEE}}}} supprimée] ou [{{fullurl:{{FULLPAGENAME}}|action=edit}} créer cette page].',
 'userpage-userdoesnotexist'        => 'Le compte utilisateur « $1 » n’est pas enregistré. Veuillez vérifier que vous voulez créer cette page.',
 'clearyourcache'                   => "'''Note :''' après avoir enregistré vos préférences, vous devrez forcer son rechargement complet en ignorant le contenu actuel du cache de votre explorateur pour voir les changements : '''Mozilla / Firefox / Konqueror / Safari :''' maintenez la touche ''Majuscule'' (''Shift'') en cliquant le bouton ''Actualiser'' (''Reload,'') ou pressez ''Maj-Ctrl-R'' (''Maj-Cmd-R'' sur Apple Mac) ; '''Internet Explorer / Opera :''' maintenez la touche ''Ctrl'' en cliquant le bouton ''Actualiser'' ou pressez ''Ctrl-F5''.",
@@ -813,7 +813,7 @@
 'hiddencategories'                 => '{{PLURAL:$1|Catégorie cachée|Catégories cachées}} dont cette page fait partie :',
 'edittools'                        => '<!-- Tout texte entré ici sera affiché sous les boîtes de modification ou d’import de fichier. -->',
 'nocreatetitle'                    => 'Création de page limitée',
-'nocreatetext'                     => 'Ce site a restreint la possibilité de créer de nouvelles pages. Vous pouvez revenir en arrière et modifier une page existante, [[Special:Userlogin|vous connecter ou créer un compte]].',
+'nocreatetext'                     => 'Ce site a restreint la possibilité de créer de nouvelles pages. Vous pouvez revenir en arrière et modifier une page existante, [[Special:UserLogin|vous connecter ou créer un compte]].',
 'nocreate-loggedin'                => 'Vous n’avez pas la permission de créer de nouvelles pages sur ce wiki.',
 'permissionserrors'                => 'Erreur de permissions',
 'permissionserrorstext'            => 'Vous n’avez pas la permission d’effectuer l’opération demandée pour {{PLURAL:$1|la raison suivante|les raisons suivantes}} :',
@@ -836,7 +836,7 @@
 'undo-success' => 'Cette modification va être défaite. Veuillez confirmer les changements (visibles en bas de cette page), puis publier si vous êtes d’accord. Merci de motiver l’annulation dans la boîte de résumé.',
 'undo-failure' => 'Cette modification ne peut pas être défaite : cela entrerait en conflit avec les modifications intermédiaires.',
 'undo-norev'   => 'La modification n’a pas pu être défaite parce qu’elle est soit inexistante soit qu’elle a été supprimée.',
-'undo-summary' => 'Annulation des modifications $1 par [[Special:Contributions/$2|$2]] ([[User talk:$2|Discuter]])',
+'undo-summary' => 'Annulation des modifications $1 par [[Special:Contributions/$2|$2]] ([[User talk:$2|Discuter]] | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Vous ne pouvez pas créer de compte.',
@@ -920,7 +920,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Journal des suppressions',
-'suppressionlogtext' => 'Ci-dessous, se trouve la liste des suppressions et des blocages comprenant les révisions cachées aux administrateurs. Voyez [[Special:Ipblocklist|la liste des blocages des IP]] pour la liste des bannissements et des blocages opérationels.',
+'suppressionlogtext' => 'Ci-dessous, se trouve la liste des suppressions et des blocages comprenant les révisions cachées aux administrateurs. Voyez [[Special:IPBlockList|la liste des blocages des IP]] pour la liste des bannissements et des blocages opérationels.',
 
 # History merging
 'mergehistory'                     => 'Fusionner les historiques',
@@ -960,7 +960,7 @@
 # Search results
 'searchresults'             => 'Résultats de la recherche',
 'searchresulttext'          => 'Pour plus d’informations sur la recherche dans {{SITENAME}}, voir [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => 'Vous avez recherché « [[:$1]] »',
+'searchsubtitle'            => "Vous avez recherché « '''[[:$1]]''' » ([[Special:Prefixindex/$1|toutes les pages commençant par « $1 »]] | [[Special:WhatLinksHere/$1|toutes les pages qui ont un lien vers « $1 »]])",
 'searchsubtitleinvalid'     => 'Vous avez recherché « $1 »',
 'noexactmatch'              => "'''Aucune page intitulée « $1 » n’existe.''' Vous pouvez [[:$1|créer cet article]].",
 'noexactmatch-nocreate'     => "'''Il n’existe aucune page intitulée « $1 ».'''",
@@ -1003,7 +1003,7 @@
 'mypreferences'            => 'Préférences',
 'prefs-edits'              => 'Nombre d’éditions :',
 'prefsnologin'             => 'Non connecté',
-'prefsnologintext'         => 'Vous devez être [[Special:Userlogin|connecté]] pour modifier vos préférences d’utilisateur.',
+'prefsnologintext'         => 'Vous devez être [[Special:UserLogin|connecté]] pour modifier vos préférences d’utilisateur.',
 'prefsreset'               => 'Les préférences ont été rétablies à partir de la version enregistrée.',
 'qbsettings'               => 'Barre d’outils',
 'qbsettings-none'          => 'Aucune',
@@ -1074,11 +1074,11 @@
 'userrights-groups-help'      => "Vous pouvez modifier les groupes auxquels appartient cet utilisateur.
 * Une case cochée signifie que l’utilisateur se trouve dans ce groupe.
 * Une case non cochée signifie qu'il ne s’y trouve pas.
-* Une * indique que vous ne pouvez pas retirer ce groupe une fois que vous l'ayez ajouté et vice-versa.",
+* Un astérisque (*) indique que vous ne pouvez pas retirer ce groupe une fois que vous l'avez ajouté et vice-versa.",
 'userrights-reason'           => 'Motif du changement :',
 'userrights-no-interwiki'     => 'Vous n’avez pas la permission de modifier des droits d’utilisateurs sur d’autres wikis.',
 'userrights-nodatabase'       => 'La base de donnée « $1 » n’existe pas ou n’est pas locale.',
-'userrights-nologin'          => 'Vous devez vous [[Special:Userlogin|connecter]] avec un compte d’administrateur pour modifier des droits d’utilisateur.',
+'userrights-nologin'          => 'Vous devez vous [[Special:UserLogin|connecter]] avec un compte d’administrateur pour modifier des droits d’utilisateur.',
 'userrights-notallowed'       => 'Votre compte n’a pas la permission de modifier des droits d’utilisateur.',
 'userrights-changeable-col'   => 'Les groupes que vous pouvez modifier',
 'userrights-unchangeable-col' => 'Les groupes que vous ne pouvez pas modifier',
@@ -1126,7 +1126,7 @@
 'right-autoconfirmed'        => 'Modifier les pages semi-protégées',
 'right-bot'                  => 'Être traité comme un processus automatisé',
 'right-nominornewtalk'       => 'Ne pas déclencher bandeau "Vous avez de nouveaux messages" lors d\'une modification mineure sur une page de discussion d\'un utilisateur',
-'right-apihighlimits'        => 'Utiliser les limites supérieures dans les requêtes API',
+'right-apihighlimits'        => 'Utiliser des limites plus élevées dans les requêtes API',
 'right-writeapi'             => 'Utilisation de l’API de modification du wiki',
 'right-delete'               => 'Supprimer des pages',
 'right-bigdelete'            => 'Supprimer des pages avec des grands historiques',
@@ -1207,23 +1207,24 @@
 'reupload'                    => 'Importer à nouveau',
 'reuploaddesc'                => 'Retour au formulaire.',
 'uploadnologin'               => 'Non connecté(e)',
-'uploadnologintext'           => 'Vous devez être [[Special:Userlogin|connecté]] pour envoyer des fichiers sur le serveur.',
+'uploadnologintext'           => 'Vous devez être [[Special:UserLogin|connecté]] pour envoyer des fichiers sur le serveur.',
 'upload_directory_missing'    => 'Le répertoire d’import ($1) est manquant et n’a pas pu être créé par le serveur web.',
 'upload_directory_read_only'  => 'Le serveur Web ne peut écrire dans le dossier cible ($1).',
 'uploaderror'                 => 'Erreur',
-'uploadtext'                  => 'Utilisez ce formulaire pour importer des fichiers sur le serveur.
-Pour voir ou rechercher des images précédemment envoyées, consultez la [[Special:Imagelist|liste de images]]. Les copies et suppressions sont aussi enregistrées dans l’[[Special:Log/upload|historique des imports]].
+'uploadtext'                  => "Utilisez ce formulaire pour importer des fichiers sur le serveur.
+Pour voir ou rechercher des images précédemment envoyées, consultez la [[Special:ImageList|liste de images]]. Les imports sont aussi enregistrés dans l’[[Special:Log/upload|historique des imports]], les suppressions dans l’[[Special:Log/delete|historique des suppressions]].
 
-Pour inclure une image dans une page, utilisez un lien de la forme
-<b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichier.jpg]]</nowiki></b>,
-<b><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichier.png|texte descriptif]]</nowiki></b> ou
-<b><nowiki>[[</nowiki>{{ns:media}}<nowiki>:fichier.ogg]]</nowiki></b> pour lier directement vers le fichier.',
+Pour inclure une image dans une page, utilisez un lien de la forme :
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichier.jpg]]</nowiki></tt>''' pour afficher le fichier en pleine résolution ;
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichier.png|200px|thumb|left|texte descriptif]]</nowiki></tt>''' pour utiliser une miniature de 200 pixels de large dans une boîte à gauche avec 'texte descriptif' comme description ;
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:fichier.ogg]]</nowiki></tt>''' pour lier directement vers le fichier sans l'afficher.",
 'upload-permitted'            => 'Formats de fichiers autorisés : $1.',
 'upload-preferred'            => 'Formats de fichiers préférés : $1.',
 'upload-prohibited'           => 'Formats de fichiers interdits : $1.',
 'uploadlog'                   => 'Historique des imports',
 'uploadlogpage'               => 'Historique des imports de fichiers multimédia',
-'uploadlogpagetext'           => 'Voici la liste des derniers fichiers importés sur le serveur.',
+'uploadlogpagetext'           => 'Voici la liste des derniers fichiers importés sur le serveur.
+Voyez la [[Special:NewImages|gallerie des nouvelles images]] pour une présentation plus visuelle.',
 'filename'                    => 'Nom du fichier',
 'filedesc'                    => 'Description',
 'fileuploadsummary'           => 'Description :',
@@ -1298,7 +1299,9 @@
 'upload-file-error'       => 'Erreur interne',
 'upload-file-error-text'  => 'Une erreur interne est survenue en voulant créer un fichier temporaire sur le serveur. Veuillez contacter un administrateur système.',
 'upload-misc-error'       => 'Erreur inconnue lors de l’import',
-'upload-misc-error-text'  => 'Une erreur inconnue est survenue pendant l’import. Veuillez vérifier que l’URL est valide et accessible, puis essayer à nouveau. Si le problème persiste, contactez un administrateur système.',
+'upload-misc-error-text'  => 'Une erreur inconnue est survenue pendant l’import.
+Veuillez vérifier que l’URL est valide et accessible, puis essayer à nouveau.
+Si le problème persiste, contactez un [[Special:ListUsers/sysop|administrateur]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Ne peut pas atteindre l’URL',
@@ -1312,7 +1315,7 @@
 'upload_source_url'  => ' (une URL valide et accessible publiquement)',
 'upload_source_file' => ' (un fichier sur votre ordinateur)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Cette page spéciale montre tous les fichiers importés.
 Par défaut, les derniers fichiers importés sont affichés en haut de la liste.
 Un clic en tête de colonne change l’ordre d’affichage.',
@@ -1340,7 +1343,7 @@
 'imagelinks'                     => 'Pages contenant l’image',
 'linkstoimage'                   => '{{PLURAL:$1|La page ci-dessous contient|Les pages ci-dessous contiennent}} cette image :',
 'nolinkstoimage'                 => 'Aucune page ne contient cette image.',
-'morelinkstoimage'               => 'Voir [[Special:Whatlinkshere/$1|plus de liens]] vers cette image.',
+'morelinkstoimage'               => 'Voir [[Special:WhatLinksHere/$1|plus de liens]] vers cette image.',
 'redirectstofile'                => '{{PLURAL:$1|Le fichier suivant redirige|Les fichiers suivants redirigent}} vers celui-ci :',
 'duplicatesoffile'               => '{{PLURAL:$1|Le fichier suivant est un duplicata|Les fichiers suivants sont des duplicatas}} de celui-ci :',
 'sharedupload'                   => 'Ce fichier est partagé et peut-être utilisé par d’autres projets.',
@@ -1370,7 +1373,7 @@
 'filedelete'                  => 'Supprimer $1',
 'filedelete-legend'           => 'Supprimer le fichier',
 'filedelete-intro'            => "Vous êtes en train de supprimer '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Vous êtes en train d’effacer la version de \'\'\'[[Media:$1|$1]]\'\'\' du [$4 $2 à $3].</span>',
+'filedelete-intro-old'        => "Vous êtes en train d’effacer la version de '''[[Media:$1|$1]]''' du [$4 $2 à $3].",
 'filedelete-comment'          => 'Commentaire :',
 'filedelete-submit'           => 'Supprimer',
 'filedelete-success'          => "'''$1''' a été supprimé.",
@@ -1425,7 +1428,7 @@
 Cela représente une moyenne de '''$5''' modification{{PLURAL:$5||s}} par page et de '''$6''' consultation{{PLURAL:$6||s}} pour une modification.
 
 Il y a '''$7''' article{{PLURAL:$7||s}} dans [http://www.mediawiki.org/wiki/Manual:Job_queue/fr la file des tâches].",
-'userstatstext'          => "Il y a {{PLURAL:$1|'''$1''' [[Special:Listusers|utilisateur enregistré]]|'''$1''' [[Special:Listusers|utilisateurs enregistrés]]}} dont '''$2''' (ou '''$4%''') {{PLURAL:$2|dispose|disposent}} des droits $5.",
+'userstatstext'          => "Il y a {{PLURAL:$1|'''$1''' [[Special:ListUsers|utilisateur enregistré]]|'''$1''' [[Special:ListUsers|utilisateurs enregistrés]]}} dont '''$2''' (ou '''$4%''') {{PLURAL:$2|dispose|disposent}} des droits $5.",
 'statistics-mostpopular' => 'Pages les plus consultées',
 
 'disambiguations'      => 'Pages d’homonymie',
@@ -1434,8 +1437,10 @@
 Elles devraient plutôt pointer le sujet approprié.<br />
 Une page est traitée comme une page d’homonymie si elle utilise un modèle qui est lié à partir de [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Doubles redirections',
-'doubleredirectstext' => 'Chaque case contient des liens vers la première et la seconde redirection, ainsi que la première ligne de texte de la seconde page, ce qui fournit habituellement la « vraie » page cible, vers laquelle la première redirection devrait rediriger.',
+'doubleredirects'            => 'Doubles redirections',
+'doubleredirectstext'        => 'Chaque case contient des liens vers la première et la seconde redirection, ainsi que la première ligne de texte de la seconde page, ce qui fournit habituellement la « vraie » page cible, vers laquelle la première redirection devrait rediriger.',
+'double-redirect-fixed-move' => '[[$1]] a été renommé, ceci est maintenant une redirection vers [[$2]]',
+'double-redirect-fixer'      => 'Correcteur de redirection',
 
 'brokenredirects'        => 'Redirections cassées',
 'brokenredirectstext'    => 'Ces redirections mènent vers des pages qui n’existent pas :',
@@ -1520,7 +1525,7 @@
 'logempty'             => 'Il n’y a rien dans l’historique pour cette page.',
 'log-title-wildcard'   => 'Chercher les titres commençant par le texte suivant',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Toutes les pages',
 'alphaindexline'    => '$1 à $2',
 'nextpage'          => 'Page suivante ($1)',
@@ -1543,14 +1548,15 @@
 'special-categories-sort-count' => 'tri par compte',
 'special-categories-sort-abc'   => 'tri alphabétique',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Afficher les utilisateurs à partir de :',
 'listusers-submit'   => 'Montrer',
 'listusers-noresult' => 'Aucun utilisateur trouvé. Vérifiez aussi les variantes de casse.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Droits des groupes utilisateur',
-'listgrouprights-summary'  => "Cette page contient une liste des groupes définis sur ce wiki ainsi que les droits d'accès qui y sont associés. Des informations complémentaires sur les droits peuvent être trouvés sur [[{{MediaWiki:Listgrouprights-helppage}}]].",
+'listgrouprights-summary'  => "Cette page contient une liste des groupes définis sur ce wiki ainsi que les droits d'accès qui y sont associés.
+Il peut y avoir des [[{{MediaWiki:Listgrouprights-helppage}}|informations additionnelles]] a propos des droits.",
 'listgrouprights-group'    => 'Groupe',
 'listgrouprights-rights'   => 'Droits associés',
 'listgrouprights-helppage' => 'Help:Droits des groupes',
@@ -1558,10 +1564,11 @@
 
 # E-mail user
 'mailnologin'     => 'Pas d’adresse',
-'mailnologintext' => 'Vous devez être [[Special:Userlogin|connecté]] et avoir indiqué une adresse électronique valide dans vos [[Special:Preferences|préférences]] pour avoir la permission d’envoyer un message à un autre utilisateur.',
+'mailnologintext' => 'Vous devez être [[Special:UserLogin|connecté]] et avoir indiqué une adresse électronique valide dans vos [[Special:Preferences|préférences]] pour avoir la permission d’envoyer un message à un autre utilisateur.',
 'emailuser'       => 'Envoyer un message à cet utilisateur',
 'emailpage'       => 'Envoyer un courriel à l’utilisateur',
-'emailpagetext'   => 'Si cet utilisateur a indiqué une adresse électronique valide dans ses préférences, le formulaire ci-dessous lui enverra un message. L’adresse électronique que vous avez indiquée dans vos préférences apparaîtra dans le champ « Expéditeur » de votre message afin que le destinataire puisse vous répondre.',
+'emailpagetext'   => 'Si cet utilisateur a indiqué une adresse électronique valide dans ses préférences, le formulaire ci-dessous lui enverra un message.
+L’adresse électronique que vous avez indiquée dans [[Special:Preferences|vos préférences]] apparaîtra dans le champ « Expéditeur » de votre message afin que le destinataire puisse vous répondre.',
 'usermailererror' => 'Erreur dans le sujet du courriel :',
 'defemailsubject' => 'Courriel envoyé depuis {{SITENAME}}',
 'noemailtitle'    => 'Pas d’adresse électronique',
@@ -1586,11 +1593,11 @@
 'nowatchlist'          => 'Votre liste de suivi ne contient aucun article.',
 'watchlistanontext'    => 'Pour pouvoir afficher ou éditer les éléments de votre liste de suivi, vous devez vous $1.',
 'watchnologin'         => 'Non connecté',
-'watchnologintext'     => 'Vous devez être [[Special:Userlogin|connecté]] pour modifier votre liste.',
+'watchnologintext'     => 'Vous devez être [[Special:UserLogin|connecté]] pour modifier votre liste.',
 'addedwatch'           => 'Ajouté à la liste de suivi',
 'addedwatchtext'       => 'La page « <nowiki>$1</nowiki> » a été ajoutée à votre [[Special:Watchlist|liste de suivi]].',
 'removedwatch'         => 'Retirée de la liste de suivi',
-'removedwatchtext'     => 'La page « [[:$1]] » a été retirée de votre liste de suivi.',
+'removedwatchtext'     => 'La page « [[:$1]] » a été retirée de votre [[Special:Watchlist|liste de suivi]].',
 'watch'                => 'Suivre',
 'watchthispage'        => 'Suivre cette page',
 'unwatch'              => 'Ne plus suivre',
@@ -1694,7 +1701,7 @@
 'sessionfailure'              => 'Votre session de connexion semble avoir des problèmes ; cette action a été annulée en prévention d’un piratage de session. Cliquez sur « Précédent » et rechargez la page d’où vous venez, puis réessayez.',
 'protectlogpage'              => 'Historique des protections',
 'protectlogtext'              => 'Voici une liste des protections et des déprotections.
-Consultez la [[Special:Protectedpages|liste des pages protégées]] pour la liste des protections actuelles.',
+Consultez la [[Special:ProtectedPages|liste des pages protégées]] pour la liste des protections actuelles.',
 'protectedarticle'            => 'a protégé « [[$1]] »',
 'modifiedarticleprotection'   => 'a modifié le niveau de protection de « [[$1]] »',
 'unprotectedarticle'          => 'a déprotégé « [[$1]] »',
@@ -1807,7 +1814,7 @@
 
 # What links here
 'whatlinkshere'            => 'Pages liées',
-'whatlinkshere-title'      => 'Pages ayant un lien vers $1',
+'whatlinkshere-title'      => 'Pages qui pointent vers « $1 »',
 'whatlinkshere-page'       => 'Page :',
 'linklistsub'              => '(Liste de liens)',
 'linkshere'                => 'Les pages ci-dessous contiennent un lien vers <b>[[:$1]]</b> :',
@@ -1861,7 +1868,7 @@
 'badipaddress'                    => 'L’adresse IP n’est pas correcte.',
 'blockipsuccesssub'               => 'Blocage réussi',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] a été bloqué.<br />
-Vous pouvez consulter la [[Special:Ipblocklist|liste des comptes et des adresses IP bloqués]].',
+Vous pouvez consulter la [[Special:IPBlockList|liste des comptes et des adresses IP bloqués]].',
 'ipb-edit-dropdown'               => 'Modifier les motifs de blocage par défaut',
 'ipb-unblock-addr'                => 'Débloquer $1',
 'ipb-unblock'                     => 'Débloquer un compte utilisateur ou une adresse IP',
@@ -1872,7 +1879,7 @@
 'ipusubmit'                       => 'Débloquer cette adresse',
 'unblocked'                       => '[[User:$1|$1]] a été débloqué',
 'unblocked-id'                    => 'Le blocage $1 a été enlevé',
-'ipblocklist'                     => 'Liste des utilisateurs bloqués',
+'ipblocklist'                     => 'Liste adresses IP et des utilisateurs bloqués',
 'ipblocklist-legend'              => 'Chercher un utilisateur bloqué',
 'ipblocklist-username'            => 'Nom de l’utilisateur ou adresse IP :',
 'ipblocklist-submit'              => 'Chercher',
@@ -1891,7 +1898,7 @@
 'autoblocker'                     => 'Vous avez été bloqué automatiquement parce que votre adresse IP a été récemment utilisée par « $1 ». La raison fournie pour le blocage de $1 est : « $2 ».',
 'blocklogpage'                    => 'Historique des blocages',
 'blocklogentry'                   => 'a bloqué « [[$1]] » - durée : $2 $3',
-'blocklogtext'                    => 'Ceci est la trace des blocages et déblocages des utilisateurs. Les adresses IP automatiquement bloquées ne sont pas listées. Consultez la [[Special:Ipblocklist|liste des utilisateurs bloqués]] pour voir qui est actuellement effectivement bloqué.',
+'blocklogtext'                    => 'Ceci est la trace des blocages et déblocages des utilisateurs. Les adresses IP automatiquement bloquées ne sont pas listées. Consultez la [[Special:IPBlockList|liste des utilisateurs bloqués]] pour voir qui est actuellement effectivement bloqué.',
 'unblocklogentry'                 => 'a débloqué « $1 »',
 'block-log-flags-anononly'        => 'utilisateurs anonymes seulement',
 'block-log-flags-nocreate'        => 'création de compte interdite',
@@ -1941,11 +1948,11 @@
 'movepagetext'            => "Utilisez le formulaire ci-dessous pour renommer une page, en déplaçant tout son historique vers le nouveau nom.
 L’ancien titre deviendra une page de redirection vers le nouveau titre.
 Les liens vers le titre de l’ancienne page ne seront pas changés ;
-veuillez vérifier que ce déplacement n’a pas créé de double redirection.
-Vous devez vous assurer que les liens continuent de pointer vers leur destination supposée.
+veuillez vérifier que ce déplacement n’a pas créé de [[Special:DoubleRedirects|double redirection]] ou de [[Special:BrokenRedirects|redirection cassée]].
+Vous avez la responsabilité de vous assurer que les liens continuent de pointer vers leur destination supposée.
 
 Une page ne sera pas déplacée si la page du nouveau titre existe déjà, à moins que cette dernière soit vide ou en redirection, et qu’elle n’ait pas d’historique.
-Ce qui veut dire que vous pouvez renommer une page vers sa position d’origine si vous avez commis une erreur, mais que vous ne pouvez effacer une page déjà existante par ce procédé.
+Ce qui veut dire que vous pouvez renommer une page vers sa position d’origine si vous avez commis une erreur, mais que vous ne pouvez écraser une page déjà existante par ce procédé.
 
 '''ATTENTION !'''
 Ceci peut provoquer un changement radical et imprévu pour une page souvent consultée.
@@ -1957,8 +1964,6 @@
 
 Dans ce cas, vous devrez renommer ou fusionner la page manuellement si vous le désirez.',
 'movearticle'             => 'Renommer l’article',
-'movenologin'             => 'Non connecté',
-'movenologintext'         => 'Pour pouvoir renommer une page, vous devez être [[Special:Userlogin|connecté]] en tant qu’utilisateur enregistré et votre compte doit avoir une ancienneté suffisante.',
 'movenotallowed'          => 'Vous n’avez pas la permission de renommer des pages sur ce wiki.',
 'newtitle'                => 'Nouveau titre',
 'move-watch'              => 'Suivre cette page',
@@ -1985,7 +1990,7 @@
 'delete_and_move'         => 'Supprimer et renommer',
 'delete_and_move_text'    => '==Suppression requise==
 
-L’article de destination « [[$1]] » existe déjà. Voulez-vous le supprimer pour permettre le renommage ?',
+L’article de destination « [[:$1]] » existe déjà. Voulez-vous le supprimer pour permettre le renommage ?',
 'delete_and_move_confirm' => 'Oui, j’accepte de supprimer la page de destination pour permettre le renommage.',
 'delete_and_move_reason'  => 'Page supprimée automatiquement pour permettre un renommage',
 'selfmove'                => 'Les titres d’origine et de destination sont les mêmes : impossible de renommer une page sur elle-même.',
@@ -1993,6 +1998,7 @@
 'imagenocrossnamespace'   => 'Ne peut déplacer une image vers un espace de nommage qui ne soit pas une image.',
 'imagetypemismatch'       => 'La nouvelle extension de ce fichier ne reconnaît pas ce format.',
 'imageinvalidfilename'    => 'Le nom du fichier cible est incorrect',
+'fix-double-redirects'    => 'Mettre à jour les redirections pointant vers l’ancien titre',
 
 # Export
 'export'            => 'Exporter des pages',
@@ -2189,10 +2195,11 @@
 'markedaspatrollederror-noautopatrol' => 'Vous n’avez pas le droit de marquer vos propres modifications comme surveillées.',
 
 # Patrol log
-'patrol-log-page' => 'Historique des versions patrouillées',
-'patrol-log-line' => 'a marqué la version $1 de $2 comme vérifiée $3',
-'patrol-log-auto' => '(automatique)',
-'patrol-log-diff' => 'v$1',
+'patrol-log-page'   => 'Historique des versions patrouillées',
+'patrol-log-header' => 'Voici un journal des versions patrouillées.',
+'patrol-log-line'   => 'a marqué la version $1 de $2 comme vérifiée $3',
+'patrol-log-auto'   => '(automatique)',
+'patrol-log-diff'   => 'v$1',
 
 # Image deletion
 'deletedrevision'                 => 'L’ancienne version $1 a été supprimée',
@@ -2222,10 +2229,10 @@
 'show-big-image'       => 'Image en plus haute résolution',
 'show-big-image-thumb' => '<small>Taille de cet aperçu : $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerie des nouveaux fichiers',
 'imagelisttext'         => "Voici une liste de '''$1''' {{PLURAL:$1|fichier|fichiers}} classée $2.",
-'newimages-summary'     => 'Cette page spéciale affiche les derniers fichiers importés',
+'newimages-summary'     => 'Cette page spéciale affiche les derniers fichiers importés.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Aucune image à afficher.',
 'ilsubmit'              => 'Chercher',
@@ -2509,7 +2516,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifier ce fichier en utilisant une application externe',
-'edit-externally-help' => 'Voir [http://meta.wikimedia.org/wiki/Help:External_editors les instructions] pour plus d’informations.',
+'edit-externally-help' => "Consulter [http://meta.wikimedia.org/wiki/Aide:Éditeurs_externes les instructions d'installation] pour plus d’informations.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'toutes',
@@ -2568,7 +2575,7 @@
 'recreate'            => 'Recréer',
 
 # HTML dump
-'redirectingto' => 'Redirection vers [[$1]]',
+'redirectingto' => 'Redirection vers [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Voulez-vous rafraîchir cette page (purger le cache) ? $1',
@@ -2675,7 +2682,7 @@
 'version-software-product'         => 'Produit',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Chemin d’accès d’un fichier',
 'filepath-page'    => 'Fichier :',
 'filepath-submit'  => 'Chemin d’accès',
@@ -2713,7 +2720,7 @@
 'specialpages-group-redirects'   => 'Redirection de pages spéciales',
 'specialpages-group-spam'        => 'Outils anti-pourriel',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Page vide',
 'intentionallyblankpage' => 'Cette page est intentionellement vide et elle est usée comme un test de performance, etc.',
 
Index: languages/messages/MessagesNl.php
===================================================================
--- languages/messages/MessagesNl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesNl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,18 +4,18 @@
  * @ingroup Language
  * @file
  *
- * @author Siebrand
- * @author SPQRobin
- * @author GerardM
- * @author Hamaryns
  * @author Annabel
  * @author Effeietsanders
+ * @author Erwin85
+ * @author Extended by Hendrik Maryns <hendrik.maryns@uni-tuebingen.de>, March 2007.
  * @author Galwaygirl
+ * @author GerardM
+ * @author Hamaryns
+ * @author McDutchie
+ * @author SPQRobin
+ * @author Siebrand
  * @author Troefkaart
  * @author לערי ריינהארט
- * @author Erwin85
- * @author McDutchie
- * @author Extended by Hendrik Maryns <hendrik.maryns@uni-tuebingen.de>, March 2007.
  */
 
 $separatorTransformTable = array(',' => '.', '.' => ',' );
@@ -185,6 +185,7 @@
 	'hiddencat'           => array( '1', '__HIDDENCAT__', '__VERBORGENCAT__' ),
 	'pagesincategory'     => array( '1', 'PAGESINCATEGORY', 'PAGESINCAT', 'PAGINASINCATEGORIE', 'PAGINASINCAT' ),
 	'pagesize'            => array( '1', 'PAGESIZE', 'PAGINAGROOTTE' ),
+	'noindex'             => array( '1', '__NOINDEX__', '__GEENINDEX__' ),
 );
 
 $specialPageAliases = array(
@@ -281,7 +282,7 @@
 'tog-highlightbroken'         => 'Verwijzingen naar lege pagina’s <a href="" class="new">zo weergeven</a> (alternatief: zo weergeven<a href="" class="internal">?</a>).',
 'tog-justify'                 => 'Paragrafen uitvullen',
 'tog-hideminor'               => 'Kleine wijzigingen verbergen in recente wijzigingen',
-'tog-extendwatchlist'         => 'Uitgebreide volglijst',
+'tog-extendwatchlist'         => 'Uitgebreide volglijst gebruiken om alle toepasselijke wijzigingen te bekijken',
 'tog-usenewrc'                => 'Uitgebreide Recente Wijzigingen-pagina gebruiken (vereist JavaScript)',
 'tog-numberheadings'          => 'Koppen automatisch nummeren',
 'tog-showtoolbar'             => 'Bewerkingswerkbalk weergeven (vereist JavaScript)',
@@ -554,7 +555,7 @@
 'nosuchspecialpage' => 'Deze speciale pagina bestaat niet',
 'nospecialpagetext' => "<big>'''U hebt een onbestaande speciale pagina opgevraagd.'''</big>
 
-Een lijst met bestaande speciale pagina’s staat op [[Special:Specialpages|speciale pagina’s]].",
+Een lijst met bestaande speciale pagina’s staat op [[Special:SpecialPages|speciale pagina’s]].",
 
 # General errors
 'error'                => 'Fout',
@@ -585,7 +586,8 @@
 Dit kan voorkomen als u een verouderde verwijzing naar het verschil tussen twee versies van een pagina volgt of een versie opvraagt die is verwijderd.
 
 Als dit niet het geval is, hebt u wellicht een fout in de software gevonden.
-Maak hiervan melding bij een systeembeheerder van {{SITENAME}} en vermeld daarbij de URL van deze pagina.',
+Maak hiervan melding bij een [[Special:ListUsers/sysop|systeembeheerder]] van {{SITENAME}} en vermeld daarbij de URL van deze pagina.
+sv',
 'missingarticle-rev'   => '(versienummer: $1)',
 'missingarticle-diff'  => '(Wijziging: $1, $2)',
 'readonly_lag'         => 'De database is automatisch vergrendeld terwijl de ondergeschikte databaseservers synchroniseren met de hoofdserver.',
@@ -638,10 +640,10 @@
 # Login and logout pages
 'logouttitle'                => 'Gebruiker afmelden',
 'logouttext'                 => "<strong>U bent nu afgemeld.</strong><br />
-U kunt {{SITENAME}} nu anoniem gebruiken of weer aanmelden als dezelfde of een andere gebruiker.
+U kunt {{SITENAME}} nu anoniem gebruiken of weer [[Special:UserLogin|aanmelden]] als dezelfde of een andere gebruiker.
 Mogelijk worden nog een aantal pagina's weergegeven alsof u aangemeld bent totdat u de cache van uw browser leegt.",
 'welcomecreation'            => '== Welkom, $1! ==
-Uw gebruiker is geregistreerd. Vergeet niet uw voorkeuren voor {{SITENAME}} aan te passen.',
+Uw gebruiker is geregistreerd. Vergeet niet uw [[Special:Preferences|voorkeuren voor {{SITENAME}}]] aan te passen.',
 'loginpagetitle'             => 'Gebruikersnaam',
 'yourname'                   => 'Gebruikersnaam:',
 'yourpassword'               => 'Wachtwoord:',
@@ -779,41 +781,39 @@
 'summary-preview'                  => 'Samenvatting nakijken',
 'subject-preview'                  => 'Nakijken onderwerp/kop',
 'blockedtitle'                     => 'Gebruiker is geblokkeerd',
-'blockedtext'                      => "<big>'''Uw gebruiker of IP-adres is geblokkeerd.'''</big>
+'blockedtext'                      => '<big>\'\'\'Uw gebruiker of IP-adres is geblokkeerd.\'\'\'</big>
 
 De blokkade is uitgevoerd door $1.
-De opgegeven reden is ''$2''.
+De opgegeven reden is \'\'$2\'\'.
 
 * Aanvang blokkade: $8
 * Einde blokkade: $6
 * Bedoeld te blokkeren: $7
 
 U kunt contact opnemen met $1 of een andere [[{{MediaWiki:Grouppage-sysop}}|beheerder]] om de blokkade te bespreken.
-U kunt geen gebruik maken van de functie 'e-mail deze gebruiker', tenzij u een geldig e-mailadres hebt opgegeven in uw [[Special:Preferences|voorkeuren]] en het gebruik van deze functie niet geblokkeerd is.
-Uw huidige IP-adres is $3 en het blokkadenummer is #$5. Vermeld beide gegevens als u ergens op deze blokkade reageert.",
-'autoblockedtext'                  => "Uw IP-adres is automatisch geblokkeerd, omdat het is gebruikt door een andere gebruiker, die is geblokkeerd door $1.
+U kunt geen gebruik maken van de functie "Deze gebruiker e-mailen", tenzij u een geldig e-mailadres hebt opgegeven in uw [[Special:Preferences|voorkeuren]] en het gebruik van deze functie niet geblokkeerd is.
+Uw huidige IP-adres is $3 en het blokkadenummer is #$5.
+Vermeld alle bovenstaande gegevens als u ergens op deze blokkade reageert.',
+'autoblockedtext'                  => 'Uw IP-adres is automatisch geblokkeerd, omdat het is gebruikt door een andere gebruiker, die is geblokkeerd door $1.
 De opgegeven reden is:
 
-:''$2''
+:\'\'$2\'\'
 
 * Aanvang blokkade: $8
 * Einde blokkade: $6
+* Bedoeld te blokkeren: $7
 
 U kunt deze blokkade bespreken met $1 of een andere [[{{MediaWiki:Grouppage-sysop}}|beheerder]].
 
-U kunt geen gebruik maken van de functie 'e-mail deze gebruiker', tenzij u een geldig e-mailadres hebt opgegeven in uw [[Special:Preferences|voorkeuren]] en het gebruik van deze functie niet is geblokkeerd.
+U kunt geen gebruik maken van de functie "Deze gebruiker e-mailen", tenzij u een geldig e-mailadres hebt opgegeven in uw [[Special:Preferences|voorkeuren]] en het gebruik van deze functie niet is geblokkeerd.
 
-Uw blokkadenummer is $5.
-Vermeld beide gegevens als u ergens over deze blokkade reageert.",
+Uw huidige IP-adres is $3 en het blokkadenummer is #$5.
+Vermeld alle bovenstaande gegevens als u ergens op deze blokkade reageert.',
 'blockednoreason'                  => 'geen reden opgegeven',
 'blockedoriginalsource'            => "Hieronder staat de brontekst van '''$1''':",
 'blockededitsource'                => "Hieronder staat de tekst van '''uw bewerkingen''' aan '''$1''':",
 'whitelistedittitle'               => 'Voor bewerken is aanmelden verplicht',
 'whitelistedittext'                => "U moet $1 om pagina's te bewerken.",
-'whitelistreadtitle'               => 'Voor leestoegang is aanmelden verplicht',
-'whitelistreadtext'                => "[[Special:Userlogin|Meld u aan]] voor leestoegang tot pagina's.",
-'whitelistacctitle'                => 'U kunt geen gebruiker registreren',
-'whitelistacctext'                 => 'U dient [[Special:Userlogin|aangemeld]] te zijn en de juiste rechten te hebben om gebruikers aan te maken in {{SITENAME}}.',
 'confirmedittitle'                 => 'E-mailbevestiging is verplicht voordat u kunt bewerken',
 'confirmedittext'                  => 'U moet uw e-mailadres bevestigen voor u kunt bewerken.
 Voer uw e-mailadres in en bevestig het via [[Special:Preferences|uw voorkeuren]].',
@@ -831,7 +831,7 @@
 Daarom wordt het IP-adres ter identificatie gebruikt.
 Het is mogelijk dat meerdere personen hetzelfde IP-adres gebruiken.
 Mogelijk ontvangt u hier berichten die niet voor u bedoeld zijn.
-Als u dat wilt voorkomen, [[Special:Userlogin|meld u aan]] om verwarring met andere anonieme gebruikers te voorkomen.''",
+Als u dat wilt voorkomen, [[Special:UserLogin/signup|registreer u]] of [[Special:UserLogin|meld u aan]] om verwarring met andere anonieme gebruikers te voorkomen.''",
 'noarticletext'                    => 'Deze pagina bevat geen tekst.
 U kunt [[Special:Search/{{PAGENAME}}|naar deze term zoeken]] in andere pagina\'s of <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} deze pagina bewerken]</span>.',
 'userpage-userdoesnotexist'        => 'U bewerkt een gebruikerspagina van een gebruiker die niet bestaat (gebruiker "$1"). Controleer of u deze pagina wel wilt aanmaken/bewerken.',
@@ -847,12 +847,14 @@
 'previewnote'                      => '<strong>Let op: dit is een controlepagina; uw tekst is niet opgeslagen!</strong>',
 'previewconflict'                  => 'Deze voorvertoning geeft aan hoe de tekst in het bovenste veld eruit ziet als u deze opslaat.',
 'session_fail_preview'             => '<strong>Sorry! Uw bewerking is niet verwerkt, omdat de sessiegegevens verloren zijn gegaan.
-Probeer het opnieuw. Als het dan nog niet lukt, meld u zich dan af en weer aan.</strong>',
+Probeer het opnieuw.
+Als het dan nog niet lukt, [[Special:UserLogout|meld u zich dan af]] en weer aan.</strong>',
 'session_fail_preview_html'        => "<strong>Sorry! Uw bewerking is niet verwerkt, omdat sessiegegevens verloren zijn gegaan.</strong>
 
 ''Omdat in {{SITENAME}} ruwe HTML is ingeschakeld, is een voorvertoning niet mogelijk als bescherming tegen aanvallen met JavaScript.''
 
-<strong>Als dit een legitieme bewerking is, probeer het dan opnieuw. Als het dan nog niet lukt, meld u zich dan af en weer aan.</strong>",
+<strong>Als dit een legitieme bewerking is, probeer het dan opnieuw.
+Als het dan nog niet lukt, [[Special:UserLogout|meld u zich dan af]] en weer aan.</strong>",
 'token_suffix_mismatch'            => '<strong>Uw bewerking is geweigerd omdat uw browser de leestekens in het bewerkingstoken onjuist heeft behandeld.
 De bewerking is geweigerd om verminking van de paginatekst te voorkomen.
 Dit gebeurt soms als er een webgebaseerde proxydienst wordt gebruikt die fouten bevat.</strong>',
@@ -899,7 +901,7 @@
 'edittools'                        => '<!-- Deze tekst wordt weergegeven onder bewerkings- en uploadformulieren. -->',
 'nocreatetitle'                    => "Het aanmaken van pagina's is beperkt",
 'nocreatetext'                     => "{{SITENAME}} heeft de mogelijkheid om nieuwe pagina's te maken beperkt.
-U kunt reeds bestaande pagina's wijzigen, of u kunt [[Special:Userlogin|zich aanmelden of registreren]].",
+U kunt reeds bestaande pagina's wijzigen, of u kunt [[Special:UserLogin|zich aanmelden of registreren]].",
 'nocreate-loggedin'                => "U kunt geen nieuwe pagina's maken op {{SITENAME}}.",
 'permissionserrors'                => 'Fouten in rechten',
 'permissionserrorstext'            => 'U hebt geen rechten om dit te doen wegens de volgende {{PLURAL:$1|reden|redenen}}:',
@@ -1016,7 +1018,7 @@
 # Suppression log
 'suppressionlog'     => 'Verbergingslogboek',
 'suppressionlogtext' => 'De onderstaande lijst bevat de verwijderingen en blokkades die voor beheerders verborgen zijn.
-In de [[Special:Ipblocklist|IP-blokkeerlijst]] zijn de huidige blokkades te bekijken.',
+In de [[Special:IPBlockList|IP-blokkeerlijst]] zijn de huidige blokkades te bekijken.',
 
 # History merging
 'mergehistory'                     => "Geschiedenis van pagina's samenvoegen",
@@ -1058,7 +1060,7 @@
 # Search results
 'searchresults'             => 'Zoekresultaten',
 'searchresulttext'          => 'Voor meer informatie over zoeken op {{SITENAME}}, zie [[{{MediaWiki:Helppage}}|{{int:help}}]].',
-'searchsubtitle'            => "U zocht naar '''[[:$1]]'''",
+'searchsubtitle'            => 'U zocht naar \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|pagina\'s die beginnen met "$1"]] | [[Special:WhatLinksHere/$1|pagina\'s die verwijzen naar "$1"]])',
 'searchsubtitleinvalid'     => 'Voor zoekopdracht "$1"',
 'noexactmatch'              => "'''Er bestaat geen pagina genaamd \"\$1\".''' U kunt deze [[:\$1|aanmaken]].",
 'noexactmatch-nocreate'     => "'''Er bestaat geen pagina genaamd \"\$1\".'''",
@@ -1103,7 +1105,7 @@
 'mypreferences'            => 'Mijn voorkeuren',
 'prefs-edits'              => 'Aantal bewerkingen:',
 'prefsnologin'             => 'Niet aangemeld',
-'prefsnologintext'         => 'U moet [[Special:Userlogin|aangemeld]] zijn om uw voorkeuren te kunnen instellen.',
+'prefsnologintext'         => 'U moet [[Special:UserLogin|aangemeld]] zijn om uw voorkeuren te kunnen instellen.',
 'prefsreset'               => 'Standaardvoorkeuren zijn hersteld.',
 'qbsettings'               => 'Menubalk',
 'qbsettings-none'          => 'Uitgeschakeld',
@@ -1177,7 +1179,7 @@
 'userrights-reason'           => 'Reden voor het veranderen:',
 'userrights-no-interwiki'     => "U hebt geen rechten om gebruikersrechten op andere wiki's te wijzigen.",
 'userrights-nodatabase'       => 'Database $1 bestaat niet of is geen plaatselijke database.',
-'userrights-nologin'          => 'U moet zich [[Special:Userlogin|aanmelden]] met een gebruiker met de juiste rechten om gebruikersrechten toe te wijzen.',
+'userrights-nologin'          => 'U moet zich [[Special:UserLogin|aanmelden]] met een gebruiker met de juiste rechten om gebruikersrechten toe te wijzen.',
 'userrights-notallowed'       => 'U hebt geen rechten om gebruikersrechten toe te wijzen.',
 'userrights-changeable-col'   => 'Groepen die u kunt beheren',
 'userrights-unchangeable-col' => 'Groepen die u niet kunt beheren',
@@ -1194,9 +1196,9 @@
 
 'group-user-member'          => 'Gebruiker',
 'group-autoconfirmed-member' => 'Geregistreerde gebruiker',
-'group-bot-member'           => 'Bot',
-'group-sysop-member'         => 'Beheerder',
-'group-bureaucrat-member'    => 'Bureaucraat',
+'group-bot-member'           => 'bot',
+'group-sysop-member'         => 'beheerder',
+'group-bureaucrat-member'    => 'bureaucraat',
 'group-suppress-member'      => 'Toezichthouder',
 
 'grouppage-user'          => '{{ns:project}}:Gebruikers',
@@ -1296,7 +1298,7 @@
 'recentchangeslinked'          => 'Verwante wijzigingen',
 'recentchangeslinked-title'    => 'Wijzigingen verwant aan "$1"',
 'recentchangeslinked-noresult' => "Er zijn in de opgegeven periode geen bewerkingen geweest op de pagina's waarheen vanaf hier verwezen wordt.",
-'recentchangeslinked-summary'  => "Deze speciale pagina geeft de laatste bewerkingen weer op pagina's die waarheen verwezen wordt vanaf een aangegeven pagina, of vanuit pagina's in een aangegeven pagina een categorie.
+'recentchangeslinked-summary'  => "Deze speciale pagina geeft de laatste bewerkingen weer op pagina's waarheen verwezen wordt vanaf een aangegeven pagina, of vanuit pagina's in een aangegeven pagina een categorie.
 Pagina's die op [[Special:Watchlist|uw volglijst]] staan worden '''vet''' weergegeven.",
 'recentchangeslinked-page'     => 'Paginanaam:',
 'recentchangeslinked-to'       => "Wijzigingen aan pagina's met verwijzingen naar deze pagina bekijken",
@@ -1307,19 +1309,20 @@
 'reupload'                    => 'Opnieuw uploaden',
 'reuploaddesc'                => 'Upload annuleren en terugkeren naar het uploadformulier',
 'uploadnologin'               => 'Niet aangemeld',
-'uploadnologintext'           => 'U moet [[Special:Userlogin|aangemeld]] zijn
+'uploadnologintext'           => 'U moet [[Special:UserLogin|aangemeld]] zijn
 om bestanden te uploaden.',
 'upload_directory_missing'    => 'De uploadmap ($1) is niet aanwezig en kon niet aangemaakt worden door de webserver.',
 'upload_directory_read_only'  => 'De webserver kan niet schrijven in de uploadmap ($1).',
 'uploaderror'                 => 'Uploadfout',
 'uploadtext'                  => "Gebruik het onderstaande formulier om bestanden te uploaden.
-Om eerder toegevoegde bestanden te bekijken of te zoeken kunt u naar de [[Special:Imagelist|bestandslijst]] gaan.
-Uploads en verwijderingen worden bijgehouden in het [[Special:Log/upload|uploadlogboek]].
+Om eerder toegevoegde bestanden te bekijken of te zoeken kunt u naar de [[Special:ImageList|bestandslijst]] gaan.
+Uploads en bestanden die na verwijdering opnieuw worden toegevoegd zijn na te zien in het [[Special:Log/upload|uploadlogboek]].
+Verwijderde bestanden worden bijgehouden in het [[Special:Log/delete|verwijderingslogboek]].
 
-Om het bestand in te voegen in een pagina kunt u een van de volgende codes gebruiken, al naar gelang het bestandsformaat dat van toepassing is:
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bestand.jpg]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bestand.png|alternatieve tekst]]</nowiki>'''
-* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Bestand.ogg]]</nowiki>'''
+Om het bestand in te voegen in een pagina kunt u een van de volgende vormen gebruiken, al naar gelang het bestandsformaat dat van toepassing is:
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bestand.jpg]]</nowiki>''' om de volledige versie van het bestand te gebruiken
+* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Bestand.png|200px|thumb|left|alternatieve tekst]]</nowiki>''' om een 200-pixel brede afbeelding links weer te geven met een rand en met \"alternatieve tekst\" als beschrijving
+* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Bestand.ogg]]</nowiki>''' om gewoon naar het bestand te verwijzen zonder het weer te geven
 
 De laatste verwijzing is bedoeld voor mediabestanden die geen afbeelding zijn.",
 'upload-permitted'            => 'Toegelaten bestandstypes: $1.',
@@ -1327,7 +1330,8 @@
 'upload-prohibited'           => 'Verboden bestandstypes: $1.',
 'uploadlog'                   => 'uploadlogboek',
 'uploadlogpage'               => 'Uploadlogboek',
-'uploadlogpagetext'           => 'Hieronder staan de nieuwste bestanden.',
+'uploadlogpagetext'           => 'Hieronder staan de nieuwste bestanden.
+Zie de [[Special:NewImages|galerij met nieuwe bestanden]] voor een visueler overzicht.',
 'filename'                    => 'Bestandsnaam',
 'filedesc'                    => 'Samenvatting',
 'fileuploadsummary'           => 'Samenvatting:',
@@ -1407,9 +1411,9 @@
 'upload-proto-error'      => 'Verkeerd protocol',
 'upload-proto-error-text' => "Uploads via deze methode vereisen URL's die beginnen met <code>http://</code> of <code>ftp://</code>.",
 'upload-file-error'       => 'Interne fout',
-'upload-file-error-text'  => 'Een interne fout vond plaats toen een tijdelijk bestand op de server werd aangemaakt. Neem aub contact op met een systeembeheerder.',
+'upload-file-error-text'  => 'Een interne fout vond plaats toen een tijdelijk bestand op de server werd aangemaakt. Neem aub contact op met een [[Special:ListUsers/sysop|systeembeheerder]].',
 'upload-misc-error'       => 'Onbekende uploadfout',
-'upload-misc-error-text'  => 'Er is tijdens het uploaden een onbekende fout opgetreden. Controleer of de URL correct en beschikbaar is en probeer het opnieuw. Als het probleem aanhoudt, neem dan contact op met een systeembeheerder.',
+'upload-misc-error-text'  => 'Er is tijdens het uploaden een onbekende fout opgetreden. Controleer of de URL correct en beschikbaar is en probeer het opnieuw. Als het probleem aanhoudt, neem dan contact op met een [[Special:ListUsers/sysop|systeembeheerder]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Kon de URL niet bereiken',
@@ -1425,7 +1429,7 @@
 'upload_source_url'  => ' (een geldige, publiek toegankelijke URL)',
 'upload_source_file' => ' (een bestand op uw computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Op deze speciale pagina zijn alle toegevoegde bestanden te bekijken.
 Standaard worden de laatst toegevoegde bestanden bovenaan de lijst weergegeven.
 Klikken op een kolomkop verandert de sortering.',
@@ -1453,7 +1457,7 @@
 'imagelinks'                     => 'Bestandsverwijzingen',
 'linkstoimage'                   => "Dit bestand wordt op de volgende {{PLURAL:$1|pagina|$1 pagina's}} gebruikt:",
 'nolinkstoimage'                 => 'Geen enkele pagina gebruikt dit bestand.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Meer verwijzingen]] naar dit bestand bekijken.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Meer verwijzingen]] naar dit bestand bekijken.',
 'redirectstofile'                => '{{PLURAL:$1|Het volgende bestand verwijst|De volgende $1 bestanden verwijzen}} door naar dit bestand:',
 'duplicatesoffile'               => '{{PLURAL:$1|Het volgende bestand is|De volgende $1 bestanden zijn}} identiek aan dit bestand:',
 'sharedupload'                   => 'Dit bestand is een gedeelde upload en kan ook door andere projecten gebruikt worden.',
@@ -1473,18 +1477,18 @@
 # File reversion
 'filerevert'                => '$1 terugdraaien',
 'filerevert-legend'         => 'Bestand terugdraaien',
-'filerevert-intro'          => '<span class="plainlinks">U bent \'\'\'[[Media:$1|$1]]\'\'\' aan het terugdraaien tot de [$4 versie op $2, $3]</span>.',
+'filerevert-intro'          => "U bent '''[[Media:$1|$1]]''' aan het terugdraaien tot de [$4 versie op $2, $3].",
 'filerevert-comment'        => 'Opmerking:',
 'filerevert-defaultcomment' => 'Teruggedraaid tot de versie op $1, $2',
 'filerevert-submit'         => 'Terugdraaien',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' is teruggedraaid tot de [$4 versie op $2, $3]</span>.',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' is teruggedraaid tot de [$4 versie op $2, $3].",
 'filerevert-badversion'     => 'Er is geen vorige plaatselijke versie van dit bestand met van het opgegeven tijdstip.',
 
 # File deletion
 'filedelete'                  => '"$1" verwijderen',
 'filedelete-legend'           => 'Bestand verwijderen',
 'filedelete-intro'            => "U bent '''[[Media:$1|$1]]''' aan het verwijderen.",
-'filedelete-intro-old'        => '<span class="plainlinks">U bent de versie van \'\'\'[[Media:$1|$1]]\'\'\' van [$4 $3, $2] aan het verwijderen.</span>',
+'filedelete-intro-old'        => "U bent de versie van '''[[Media:$1|$1]]''' van [$4 $3, $2] aan het verwijderen.",
 'filedelete-comment'          => 'Opmerking:',
 'filedelete-submit'           => 'Verwijderen',
 'filedelete-success'          => "'''$1''' is verwijderd.",
@@ -1561,7 +1565,7 @@
 'brokenredirects-delete' => '(verwijderen)',
 
 'withoutinterwiki'         => "Pagina's zonder verwijzingen naar andere talen",
-'withoutinterwiki-summary' => "De volgende pagina's verwijzen niet naar versies in een andere taal:",
+'withoutinterwiki-summary' => "De volgende pagina's verwijzen niet naar versies in een andere taal.",
 'withoutinterwiki-legend'  => 'Voorvoegsel',
 'withoutinterwiki-submit'  => 'Bekijken',
 
@@ -1641,7 +1645,7 @@
 'logempty'             => 'Er zijn geen regels in het logboek die voldoen aan deze criteria.',
 'log-title-wildcard'   => "Pagina's zoeken die met deze naam beginnen",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => "Alle pagina's",
 'alphaindexline'    => '$1 tot $2',
 'nextpage'          => 'Volgende pagina ($1)',
@@ -1664,14 +1668,14 @@
 'special-categories-sort-count' => 'op aantal sorteren',
 'special-categories-sort-abc'   => 'alfabetisch sorteren',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Gebruikers bekijken vanaf:',
 'listusers-submit'   => 'Weergeven',
 'listusers-noresult' => 'Geen gebruiker(s) gevonden.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Rechten van gebruikersgroepen',
-'listgrouprights-summary'  => 'Op deze pagina staan de gebruikersgroepen in deze wiki beschreven, met hun bijbehorende rechten. Voor meer informatie over individuele rechten, zie [[{{MediaWiki:Listgrouprights-helppage}}]].',
+'listgrouprights-summary'  => 'Op deze pagina staan de gebruikersgroepen in deze wiki beschreven, met hun bijbehorende rechten. Er kan [[{{MediaWiki:Listgrouprights-helppage}}|extra informatie]] over individuele rechten aanwezig zijn.',
 'listgrouprights-group'    => 'Groep',
 'listgrouprights-rights'   => 'Rechten',
 'listgrouprights-helppage' => 'Help:Gebruikersrechten',
@@ -1679,11 +1683,11 @@
 
 # E-mail user
 'mailnologin'     => 'Geen verzendadres beschikbaar',
-'mailnologintext' => 'U moet [[Special:Userlogin|aangemeld]] zijn en een geldig e-mailadres in uw [[Special:Preferences|voorkeuren]] vermelden om andere gebruikers te kunnen e-mailen.',
+'mailnologintext' => 'U moet [[Special:UserLogin|aangemeld]] zijn en een geldig e-mailadres in uw [[Special:Preferences|voorkeuren]] vermelden om andere gebruikers te kunnen e-mailen.',
 'emailuser'       => 'Deze gebruiker e-mailen',
 'emailpage'       => 'Gebruiker e-mailen',
 'emailpagetext'   => 'Als deze gebruiker een geldig e-mailadres heeft opgegeven, dan kunt u via dit formulier een bericht verzenden.
-Het e-mailadres dat u hebt opgegeven bij uw voorkeuren wordt als afzender gebruikt.',
+Het e-mailadres dat u hebt opgegeven bij [[Special:Preferences|uw voorkeuren]] wordt als afzender gebruikt.',
 'usermailererror' => 'Foutmelding bij het verzenden:',
 'defemailsubject' => 'E-mail van {{SITENAME}}',
 'noemailtitle'    => 'Van deze gebruiker is geen e-mailadres bekend',
@@ -1706,13 +1710,12 @@
 'nowatchlist'          => 'Uw volglijst is leeg.',
 'watchlistanontext'    => '$1 is verplicht om uw volglijst in te zien of te wijzigen.',
 'watchnologin'         => 'U bent niet aangemeld',
-'watchnologintext'     => 'U dient [[Special:Userlogin|aangemeld]] te zijn om uw volglijst te bewerken.',
+'watchnologintext'     => 'U dient [[Special:UserLogin|aangemeld]] te zijn om uw volglijst te bewerken.',
 'addedwatch'           => 'Toegevoegd aan volglijst',
-'addedwatchtext'       => "De pagina \"[[:\$1]]\" is toegevoegd aan uw [[Special:Watchlist|volglijst]]. Toekomstige bewerkingen van deze pagina en de bijbehorende overlegpagina worden op [[Special:Watchlist|uw volglijst]] vermeld en worden '''vet''' weergegeven in de [[Special:Recentchanges|lijst van recente wijzigingen]].
-
-Indien u een pagina niet langer wilt volgen, ga dan naar de pagina en klik op \"Niet volgen\" in het menu.",
+'addedwatchtext'       => "De pagina \"[[:\$1]]\" is toegevoegd aan uw [[Special:Watchlist|volglijst]].
+Toekomstige bewerkingen van deze pagina en de bijbehorende overlegpagina worden op [[Special:Watchlist|uw volglijst]] vermeld en worden '''vet''' weergegeven in de [[Special:RecentChanges|lijst van recente wijzigingen]].",
 'removedwatch'         => 'Verwijderd van volglijst',
-'removedwatchtext'     => 'De pagina "[[:$1]]" is van uw volglijst verwijderd.',
+'removedwatchtext'     => 'De pagina "[[:$1]]" is van [[Special:Watchlist|uw volglijst]] verwijderd.',
 'watch'                => 'Volgen',
 'watchthispage'        => 'Pagina volgen',
 'unwatch'              => 'Niet volgen',
@@ -1810,16 +1813,16 @@
 'rollbacklink'                => 'terugdraaien',
 'rollbackfailed'              => 'Ongedaan maken van wijzigingen mislukt.',
 'cantrollback'                => 'Ongedaan maken van wijzigingen onmogelijk: deze pagina heeft slechts 1 auteur.',
-'alreadyrolled'               => 'Het is niet mogelijk om de bewerking van de pagina [[:$1]] door [[User:$2|$2]] ([[User talk:$2|overleg]]) ongedaan te maken.
+'alreadyrolled'               => 'Het is niet mogelijk om de bewerking van de pagina [[:$1]] door [[User:$2|$2]] ([[User talk:$2|overleg]] | [[Special:Contributions/$2|bijdragen]]) ongedaan te maken.
 Iemand anders heeft deze pagina al bewerkt of hersteld naar een eerdere versie.
 
-De meest recente bewerking is gemaakt door [[User:$3|$3]] ([[User talk:$3|overleg]]).',
+De meest recente bewerking is gemaakt door [[User:$3|$3]] ([[User talk:$3|overleg]]| [[Special:Contributions/$3|bijdragen]]).',
 'editcomment'                 => 'Bewerkingssamenvatting: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Wijzigingen door [[Special:Contributions/$2|$2]] ([[User talk:$2|Overleg]]) hersteld tot de laatste versie door [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Wijzigingen door $1 teruggedraaid; laatste versie van $2 hersteld.',
 'sessionfailure'              => 'Er lijkt een probleem te zijn met uw aanmeldsessie. Uw handeling is gestopt uit voorzorg tegen een beveiligingsrisico (dat bestaat uit mogelijke "hijacking" van deze sessie). Ga een pagina terug, laad die pagina opnieuw en probeer het nog eens.',
 'protectlogpage'              => 'Beveiligingslogboek',
-'protectlogtext'              => "Hieronder staan pagina's die recentelijk beveiligd zijn, of waarvan de beveiliging is opgeheven. Zie de [[Special:Protectedpages|lijst met beveiligde pagina's]] voor alle beveiligde pagina's.",
+'protectlogtext'              => "Hieronder staan pagina's die recentelijk beveiligd zijn, of waarvan de beveiliging is opgeheven. Zie de [[Special:ProtectedPages|lijst met beveiligde pagina's]] voor alle beveiligde pagina's.",
 'protectedarticle'            => '"[[$1]]" beveiligd',
 'modifiedarticleprotection'   => 'wijzigde beveiligingsniveau voor "[[$1]]"',
 'unprotectedarticle'          => 'beveiliging "[[$1]]" opgeheven',
@@ -1912,7 +1915,7 @@
 'blanknamespace' => '(Hoofdnaamruimte)',
 
 # Contributions
-'contributions' => 'Bijdragen gebruiker',
+'contributions' => 'Gebruikersbijdragen',
 'mycontris'     => 'Mijn bijdragen',
 'contribsub2'   => 'Voor $1 ($2)',
 'nocontribs'    => 'Geen wijzigingen gevonden die aan de gestelde criteria voldoen.',
@@ -1929,7 +1932,7 @@
 
 # What links here
 'whatlinkshere'            => 'Verwijzingen naar deze pagina',
-'whatlinkshere-title'      => "Pagina's die verwijzen naar $1",
+'whatlinkshere-title'      => 'Pagina\'s die verwijzen naar "$1"',
 'whatlinkshere-page'       => 'Pagina:',
 'linklistsub'              => '(Lijst van verwijzingen)',
 'linkshere'                => "De volgende pagina's verwijzen naar '''[[:$1]]''':",
@@ -1979,7 +1982,7 @@
 'badipaddress'                    => 'Geen geldig IP-adres',
 'blockipsuccesssub'               => 'Blokkering geslaagd',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] is geblokkeerd.<br />
-Zie de [[Special:Ipblocklist|Lijst van geblokkeerde IP-adressen]] voor recente blokkades.',
+Zie de [[Special:IPBlockList|Lijst van geblokkeerde IP-adressen]] voor recente blokkades.',
 'ipb-edit-dropdown'               => 'lijst van redenen bewerken',
 'ipb-unblock-addr'                => '$1 deblokkeren',
 'ipb-unblock'                     => 'een gebruiker of IP-adres deblokkeren',
@@ -1990,7 +1993,7 @@
 'ipusubmit'                       => 'Blokkade van dit adres opheffen.',
 'unblocked'                       => 'Blokkade van [[User:$1|$1]] is opgeheven',
 'unblocked-id'                    => 'Blokkade $1 is opgeheven',
-'ipblocklist'                     => 'Lijst van geblokkeerde gebruikers en IP-adressen',
+'ipblocklist'                     => 'Geblokkeerde IP-adressen en gebruikers',
 'ipblocklist-legend'              => 'Een geblokkeerde gebruiker zoeken',
 'ipblocklist-username'            => 'Gebruikersnaam of IP-adres:',
 'ipblocklist-submit'              => 'Zoeken',
@@ -2009,7 +2012,7 @@
 'autoblocker'                     => "Automatisch geblokkeerd omdat het IP-adres overeenkomt met dat van [[User:\$1|\$1]], die geblokkeerd is om de volgende reden: \"'''\$2'''\"",
 'blocklogpage'                    => 'Blokkeerlogboek',
 'blocklogentry'                   => 'blokkeerde "[[$1]]" voor de duur van $2 $3',
-'blocklogtext'                    => 'Hier ziet u een lijst van de recente blokkeringen en deblokkeringen. Automatische blokkeringen en deblokkeringen komen niet in het logboek. Zie de [[Special:Ipblocklist|Ipblocklist]] voor geblokkeerde adressen.',
+'blocklogtext'                    => 'Hier ziet u een lijst van de recente blokkeringen en deblokkeringen. Automatische blokkeringen en deblokkeringen komen niet in het logboek. Zie de [[Special:IPBlockList|Ipblocklist]] voor geblokkeerde adressen.',
 'unblocklogentry'                 => 'heeft de blokkade van $1 opgeheven',
 'block-log-flags-anononly'        => 'alleen anoniemen',
 'block-log-flags-nocreate'        => 'registreren gebruikers geblokkeerd',
@@ -2050,7 +2053,7 @@
 'lockdbsuccesssub'    => 'Blokkeren database geslaagd',
 'unlockdbsuccesssub'  => 'Database vrijgegeven.',
 'lockdbsuccesstext'   => 'De database is geblokkeerd.<br />
-Vergeet niet de [[Special:Unlockdb|database vrij te geven]] zodra u klaar bent met uw onderhoud.',
+Vergeet niet de [[Special:UnlockDB|database vrij te geven]] zodra u klaar bent met uw onderhoud.',
 'unlockdbsuccesstext' => 'De database is vrijgegeven.',
 'lockfilenotwritable' => 'Geen schrijfrechten op het databaselockbestand. Om de database te kunnen blokkeren of vrij te geven, dient de webserver schrijfrechten op dit bestand te hebben.',
 'databasenotlocked'   => 'De database is niet geblokkeerd.',
@@ -2060,14 +2063,11 @@
 'move-page-legend'        => 'Pagina hernoemen',
 'movepagetext'            => "Door middel van het onderstaande formulier kunt u een pagina hernoemen.
 De geschiedenis gaat mee naar de nieuwe pagina.
-De oude naam wordt automatisch een doorverwijzing naar de nieuwe pagina.
-Verwijzingen naar de oude pagina worden niet aangepast.
-Controleer na het hernoemen of er geen dubbele of onjuiste doorverwijzingen zijn onstaan.
-U bent verantwoordelijk voor de doorverwijzingen.
+* De oude naam wordt automatisch een doorverwijzing naar de nieuwe pagina.
+* Verwijzingen naar de oude pagina worden niet aangepast.
+* De pagina's die doorverwijzen naar de oorspronkelijke titel worden automatisch bijgewerkt. Als u dit niet wenst, controleer dan of er geen [[Special:DoubleRedirects|dubbele]] of [[Special:BrokenRedirects|onjuiste doorverwijzingen]] zijn ontstaan.
 
-Een pagina kan '''alleen''' hernoemd worden als de nieuwe paginanaam:
-* niet bestaat, of
-* een doorverwijspagina zonder verdere geschiedenis is.
+Een pagina kan '''alleen''' hernoemd worden als de nieuwe paginanaam niet bestaat of een doorverwijspagina zonder verdere geschiedenis is.
 
 '''WAARSCHUWING!'''
 Voor populaire pagina's kan het hernoemen drastische en onvoorziene gevolgen hebben.
@@ -2076,8 +2076,6 @@
 * De overlegpagina onder de nieuwe naam al bestaat;
 * U het onderstaande vinkje deselecteert.",
 'movearticle'             => 'Te hernoemen pagina:',
-'movenologin'             => 'Niet aangemeld',
-'movenologintext'         => 'U moet [[Special:Userlogin|aangemeld]] zijn om een pagina te hernoemen.',
 'movenotallowed'          => "U kunt geen pagina's hernoemen op {{SITENAME}}.",
 'newtitle'                => 'Naar de nieuwe paginanaam:',
 'move-watch'              => 'Deze pagina volgen',
@@ -2105,7 +2103,7 @@
 'revertmove'              => 'terugdraaien',
 'delete_and_move'         => 'Verwijderen en hernoemen',
 'delete_and_move_text'    => '==Verwijdering nodig==
-Onder de naam "[[$1]]" bestaat al een pagina.
+Onder de naam "[[:$1]]" bestaat al een pagina.
 Wilt u deze verwijderen om plaats te maken voor de te hernoemen pagina?',
 'delete_and_move_confirm' => 'Ja, de pagina verwijderen',
 'delete_and_move_reason'  => 'Verwijderd in verband met hernoeming',
@@ -2162,7 +2160,7 @@
 'import-interwiki-history'   => 'Volledige geschiedenis van deze pagina ook kopiëren',
 'import-interwiki-submit'    => 'Importeren',
 'import-interwiki-namespace' => 'Pagina in de volgende naamruimte plaatsen:',
-'importtext'                 => 'Gebruik de functie Special:Export in de wiki waar de informatie vandaan komt, sla de uitvoer op uw eigen systeem op, en voeg die daarna hier toe.',
+'importtext'                 => 'Gebruik de [[Special:Export|exportfunctie]] in de wiki waar de informatie vandaan komt, sla de uitvoer op uw eigen systeem op, en voeg die daarna hier toe.',
 'importstart'                => "Pagina's aan het importeren ...",
 'import-revision-count'      => '$1 {{PLURAL:$1|versie|versies}}',
 'importnopages'              => "Geen pagina's te importeren.",
@@ -2328,10 +2326,11 @@
 'markedaspatrollederror-noautopatrol' => 'U kunt uw eigen wijzigingen niet als gecontroleerd markeren.',
 
 # Patrol log
-'patrol-log-page' => 'Markeerlogboek',
-'patrol-log-line' => 'markeerde versie $1 van $2 als gecontroleerd $3',
-'patrol-log-auto' => '(automatisch)',
-'patrol-log-diff' => '$1',
+'patrol-log-page'   => 'Markeerlogboek',
+'patrol-log-header' => 'Dit logboek bevat versies die gemarkeerd zijn als gecontroleerd.',
+'patrol-log-line'   => 'markeerde versie $1 van $2 als gecontroleerd $3',
+'patrol-log-auto'   => '(automatisch)',
+'patrol-log-diff'   => '$1',
 
 # Image deletion
 'deletedrevision'                 => 'Oude versie $1 verwijderd.',
@@ -2361,10 +2360,10 @@
 'show-big-image'       => 'Hogere resolutie',
 'show-big-image-thumb' => '<small>Grootte van deze afbeelding: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Nieuwe bestanden',
 'imagelisttext'         => "Hier volgt een lijst met '''$1''' {{PLURAL:$1|bestand|bestanden}} gesorteerd $2.",
-'newimages-summary'     => 'Op deze speciale pagina worden de meest recent toegevoegde bestanden weergegeven',
+'newimages-summary'     => 'Op deze speciale pagina worden de meest recent toegevoegde bestanden weergegeven.',
 'showhidebots'          => '(Bots $1)',
 'noimages'              => 'Niets te zien.',
 'ilsubmit'              => 'Zoeken',
@@ -2649,7 +2648,7 @@
 
 # External editor support
 'edit-externally'      => 'Dit bestand in een extern programma bewerken',
-'edit-externally-help' => 'In de [http://meta.wikimedia.org/wiki/Help:External_editors handleiding voor instellingen] staat meer informatie.',
+'edit-externally-help' => 'In de [http://www.mediawiki.org/wiki/Manual:External_editors handleiding voor instellingen] staat meer informatie.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alles',
@@ -2716,7 +2715,7 @@
 'recreate'            => 'Opnieuw aanmaken',
 
 # HTML dump
-'redirectingto' => 'Aan het doorverwijzen naar [[$1]] ...',
+'redirectingto' => 'Aan het doorverwijzen naar [[:$1]] ...',
 
 # action=purge
 'confirm_purge'        => 'De cache van deze pagina legen?
@@ -2766,8 +2765,8 @@
 Probeer normale voorvertoning.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Veranderingen die nieuwer zijn dan $1 seconden worden misschien niet weergegeven in deze lijst.',
-'lag-warn-high'   => 'Door een hoge database-servertoevoer zijn wijzigingen nieuwer dan $1 seconden mogelijk niet beschikbaar in de lijst.',
+'lag-warn-normal' => 'Veranderingen die nieuwer zijn dan $1 {{PLURAL:$1|seconde|seconden}} worden misschien niet weergegeven in deze lijst.',
+'lag-warn-high'   => 'Door een hoge database-servertoevoer zijn wijzigingen nieuwer dan $1 {{PLURAL:$1|seconde|seconden}} mogelijk niet beschikbaar in de lijst.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Uw volglijst bevat {{PLURAL:$1|1 pagina|$1 pagina’s}}, zonder overlegpagina’s.',
@@ -2835,7 +2834,7 @@
 'version-software-product'         => 'Product',
 'version-software-version'         => 'Versie',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Bestandslocatie',
 'filepath-page'    => 'Bestand:',
 'filepath-submit'  => 'Zoeken',
@@ -2873,7 +2872,7 @@
 'specialpages-group-redirects'   => "Doorverwijzende speciale pagina's",
 'specialpages-group-spam'        => 'Spamhulpmiddelen',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Lege pagina',
 'intentionallyblankpage' => 'Deze pagina is bewust leeg gelaten en wordt gebruikt voor benchmarks, enzovoort.',
 
Index: languages/messages/MessagesZa.php
===================================================================
--- languages/messages/MessagesZa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,8 +1,10 @@
 <?php
-/** Zhuang (壮语)
+/** Zhuang ((Cuengh))
  *
  * @ingroup Language
  * @file
+ *
+ * @author Hakka
  */
 
 $fallback = 'zh-hans';
@@ -130,7 +132,6 @@
 # Move page
 'move-page-legend' => 'Caen doengh mae',
 'movearticle'      => 'Caen doengh mae:',
-'movenologin'      => 'Maengx laezhaej',
 'move-watch'       => 'Demq mae-nej',
 'movepagebtn'      => 'Caen doengh mae',
 'movedto'          => 'Caen bei',
@@ -141,7 +142,7 @@
 'tooltip-pt-preferences' => 'Doenghgaeq gou hae',
 'tooltip-p-logo'         => 'Mae meh',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Cwmh',
 
 # Multipage image navigation
Index: languages/messages/MessagesIke_cans.php
===================================================================
--- languages/messages/MessagesIke_cans.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesIke_cans.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author M.M.S.
- * @author Siebrand
  * @author Max sonnelid
  */
 
@@ -267,7 +264,7 @@
 # Special:Log
 'log-search-submit' => 'ᐊᐃᕗᖅ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ᓱᓇᒥᑦᑐᖅ ᒪᑉᐱᑕᖅ',
 'nextpage'       => 'ᑕᒡᒐ ᒪᑉᐱᑕᖅ ($1)',
 'allpagesprev'   => 'ᑐᓄᓪᓕᐹᖅ',
@@ -368,7 +365,7 @@
 'previousdiff' => '← ᑐᓄᓪᓕᐹᖅ ᐊᓯᐊᙳᑐᖅ',
 'nextdiff'     => 'ᑕᒡᒐ ᐊᓯᐊᙳᑐᖅ ᒪᑉᐱᑕᖅ →',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ᐃᕚᖅᐳᖅ',
 'bydate'   => 'ᐱᑖᕈᑦᑐᖅ ᐃᓅᓕᕐᕕᒃ',
 
@@ -385,7 +382,7 @@
 'monthsall' => 'ᓱᓇᒥᑦᑐᖅ',
 
 # HTML dump
-'redirectingto' => 'ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ [[$1]]...',
+'redirectingto' => 'ᖃᓂᖓᓂ ᑲᒪᒋᔭᖅ ᐋᓯᑦ ᓇᑭᑦ [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'ᐊᑲᐅᔪᖅ',
Index: languages/messages/MessagesRo.php
===================================================================
--- languages/messages/MessagesRo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesRo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,14 +5,12 @@
  * @file
  *
  * @author Emily
+ * @author Firilacroco
  * @author KlaudiuMihaila
  * @author Laurap
+ * @author Mihai
  * @author SCriBu
- * @author Firilacroco
  * @author לערי ריינהארט
- * @author Siebrand
- * @author SPQRobin
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -209,8 +207,14 @@
 'category-file-count-limited'    => '{{PLURAL:$1|Următorul fişier|Următoarele $1 fişiere}} se află în categoria curentă.',
 'listingcontinuesabbrev'         => ' cont.',
 
-'mainpagetext' => "<big>'''Programul Wiki a fost instalat cu succes.'''</big>",
+'mainpagetext'      => "<big>'''Programul Wiki a fost instalat cu succes.'''</big>",
+'mainpagedocfooter' => 'Consultă [http://meta.wikimedia.org/wiki/Help:Contents Ghidul utilizatorului (en)] pentru informaţii despre utilizarea programului wiki.
 
+== Primii paşi ==
+* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Lista parametrilor configurabili (en)]
+* [http://www.mediawiki.org/wiki/Manual:FAQ Întrebări frecvente despre MediaWiki (en)]
+* [http://lists.wikimedia.org/mailman/listinfo/mediawiki-announce Listă discuţii MediaWiki (en)]',
+
 'about'          => 'Despre',
 'article'        => 'Articol',
 'newwindow'      => '(se deschide într-o fereastră nouă)',
@@ -339,6 +343,7 @@
 'restorelink'             => '{{PLURAL:$1|o modificare ştearsă|$1 modificări şterse}}',
 'feedlinks'               => 'Întreţinere:',
 'feed-invalid'            => 'Tip de abonament invalid',
+'feed-unavailable'        => 'Fluxul de redifuzare nu este disponibil în {{SITENAME}}',
 'site-rss-feed'           => '$1 Abonare RSS',
 'site-atom-feed'          => '$1 Abonare Atom',
 'page-rss-feed'           => '"$1" Abonare RSS',
@@ -361,7 +366,7 @@
 'nosuchaction'      => 'Această acţiune nu există',
 'nosuchactiontext'  => 'Acţiunea specificată în adresă nu este recunoscută de {{SITENAME}}.',
 'nosuchspecialpage' => 'Această pagină specială nu există',
-'nospecialpagetext' => 'Ai cerut o [[Special:Specialpages|pagină specială]] care nu este recunoscută de {{SITENAME}}.',
+'nospecialpagetext' => 'Ai cerut o [[Special:SpecialPages|pagină specială]] care nu este recunoscută de {{SITENAME}}.',
 
 # General errors
 'error'                => 'Eroare',
@@ -382,6 +387,12 @@
 'readonlytext'         => 'Baza de date {{SITENAME}} este momentan blocată la scriere, probabil pentru o operaţiune de rutină, după care va fi deblocată şi se va reveni la starea normală.
 
 Administratorul care a blocat-o a oferit această explicaţie: $1',
+'missing-article'      => 'Baza de date nu găseşte textul unei pagini care ar fi trebuit găsit, numit "$1" $2.
+
+În mod normal faptul este cauzat de urmărirea unui dif neactualizat sau a unei legături din istoric spre o pagină care a fost ştearsă.
+
+Dacă nu acesta e motivul, s-ar putea să fi găsit un bug în program.
+Te rog anunţă acest aspect unui [[Special:ListUsers/sysop|administrator]], indicându-i adresa URL.',
 'missingarticle-rev'   => '(versiunea#: $1)',
 'missingarticle-diff'  => '(Dif: $1, $2)',
 'readonly_lag'         => 'Baza de date a fost închisă automatic în timp ce serverele secundare ale bazei de date îl urmează pe cel principal.',
@@ -408,6 +419,9 @@
 Interogarea: $2',
 'viewsource'           => 'Vezi sursa',
 'viewsourcefor'        => 'pentru $1',
+'actionthrottled'      => 'Acţiune limitată',
+'actionthrottledtext'  => 'Ca o măsură anti-spam, ai permisiuni limitate în efectua această acţiune de prea multe ori într-o perioadă scurtă de timp, iar tu tocmai ai depăşit această limită.
+Te rog încearcă din nou în câteva minute.',
 'protectedpagetext'    => 'Această pagină este protejată împotriva modificărilor.',
 'viewsourcetext'       => 'Se poate vizualiza şi copia conţinutul acestei pagini:',
 'protectedinterface'   => 'Această pagină asigură textul interfeţei pentru software şi este protejată pentru a preveni abuzurile.',
@@ -428,10 +442,10 @@
 
 # Login and logout pages
 'logouttitle'                => 'Sesiune închisă',
-'logouttext'                 => 'Sesiunea ta în {{SITENAME}} a fost închisă. Poţi continua să foloseşti {{SITENAME}} anonim, sau poţi să te reautentifici ca acelaşi sau ca alt utilizator.',
+'logouttext'                 => 'Sesiunea ta în {{SITENAME}} a fost încheiată. Poţi continua să foloseşti {{SITENAME}} anonim, sau poţi să te [[Special:UserLogin|reautentifici]] ca acelaşi sau ca alt utilizator.',
 'welcomecreation'            => '==Bun venit, $1!==
 
-Contul dumneavoatră a fost creat. Nu uitaţi să vă personalizaţi preferinţele în {{SITENAME}}.',
+Contul dumneavoatră a fost creat. Nu uitaţi să vă personalizaţi [[Special:Preferences|preferinţele]] în {{SITENAME}}.',
 'loginpagetitle'             => 'Autentificare utilizator',
 'yourname'                   => 'Nume de utilizator:',
 'yourpassword'               => 'Parola',
@@ -545,25 +559,26 @@
 'hr_tip'          => 'Linie orizontală (folosiţi-o cumpătat)',
 
 # Edit pages
-'summary'                   => 'Sumar',
-'subject'                   => 'Subiect / titlu',
-'minoredit'                 => 'Aceasta este o editare minoră',
-'watchthis'                 => 'Urmăreşte această pagină',
-'savearticle'               => 'Salvează pagina',
-'preview'                   => 'Previzualizare',
-'showpreview'               => 'Arată previzualizare',
-'showlivepreview'           => 'Previzualizare live',
-'showdiff'                  => 'Arată diferenţele',
-'anoneditwarning'           => "'''Avertizare:''' Nu sunteţi logat(ă). Adresa IP vă va fi înregistrată în istoricul acestei pagini.",
-'missingsummary'            => "'''Atenţie:''' Nu aţi completat caseta \"descriere modificări\". Dacă apăsaţi din nou butonul \"salvează pagina\" modificările vor fi salvate fără descriere.",
-'missingcommenttext'        => 'Vă rugăm să introduceţi un comentariu.',
-'missingcommentheader'      => "'''Atenţie:''' Nu aţi furnizat un titlu/subiect pentru acest comentariu. Dacă daţi click pe \"Salvaţi din nou\", modificarea va fi salvată fără titlu.",
-'summary-preview'           => 'Previzualizare descriere',
-'subject-preview'           => 'Previzualizare subiect/titlu:',
-'blockedtitle'              => 'Utilizatorul este blocat',
-'blockedtext'               => "<big>'''Adresa IP sau contul dumneavoastră de utilizator a fost blocat.'''</big>
+'summary'                          => 'Sumar',
+'subject'                          => 'Subiect / titlu',
+'minoredit'                        => 'Aceasta este o editare minoră',
+'watchthis'                        => 'Urmăreşte această pagină',
+'savearticle'                      => 'Salvează pagina',
+'preview'                          => 'Previzualizare',
+'showpreview'                      => 'Arată previzualizare',
+'showlivepreview'                  => 'Previzualizare live',
+'showdiff'                         => 'Arată diferenţele',
+'anoneditwarning'                  => "'''Avertizare:''' Nu sunteţi logat(ă). Adresa IP vă va fi înregistrată în istoricul acestei pagini.",
+'missingsummary'                   => "'''Atenţie:''' Nu aţi completat caseta \"descriere modificări\". Dacă apăsaţi din nou butonul \"salvează pagina\" modificările vor fi salvate fără descriere.",
+'missingcommenttext'               => 'Vă rugăm să introduceţi un comentariu.',
+'missingcommentheader'             => "'''Atenţie:''' Nu aţi furnizat un titlu/subiect pentru acest comentariu. Dacă daţi click pe \"Salvaţi din nou\", modificarea va fi salvată fără titlu.",
+'summary-preview'                  => 'Previzualizare descriere',
+'subject-preview'                  => 'Previzualizare subiect/titlu:',
+'blockedtitle'                     => 'Utilizatorul este blocat',
+'blockedtext'                      => "<big>'''Adresa IP sau contul dumneavoastră de utilizator a fost blocat.'''</big>
 
-Blocarea a fost făcută de $1. Motivul blocării este ''$2''.
+Blocarea a fost făcută de $1.
+Motivul blocării este ''$2''.
 
 * Începutul blocării: $8
 * Sfârşitul blocării: $6
@@ -572,103 +587,123 @@
 Îl puteţi contacta pe $1 sau pe alt [[{{MediaWiki:Grouppage-sysop}}|administrator]] pentru a discuta blocarea.
 Nu puteţi folosi opţiunea 'trimite un e-mai utilizatorului' decât dacă o adresă de e-mail validă este specificată în [[Special:Preferences|preferinţele contului]] şi nu sunteţi blocat la folosirea ei.
 Adresa dumneavoastră IP curentă este $3, iar ID-ul blocării este $5. Vă rugăm să includeţi oricare sau ambele informaţii în orice interogări.",
-'autoblockedtext'           => 'Această adresă IP a fost blocată automat deoarece a fost folosită de către un alt utilizator, care a fost blocat de $1.
+'autoblockedtext'                  => 'Această adresă IP a fost blocată automat deoarece a fost folosită de către un alt utilizator, care a fost blocat de $1.
 Motivul blocării este:
 
 :\'\'$2\'\'
 
 * Începutul blocării: $8
 * Sfârşitul blocării: $6
+* Intervalul blocării: $7
 
 Puteţi contacta pe $1 sau pe unul dintre ceilalţi [[{{MediaWiki:Grouppage-sysop}}|administratori]] pentru a discuta blocarea.
 
 Nu veţi putea folosi opţiunea de "trimite e-mail" decât dacă aveţi înregistrată o adresă de e-mail validă la [[Special:Preferences|preferinţe]] şi nu sunteţi blocat la folosirea ei.
 
-Identificatorul dumneavoastră de blocare este $5. Vă rugăm să îl includeţi în orice interogări pe care le faceţi.',
-'blockednoreason'           => 'nici un motiv oferit',
-'blockedoriginalsource'     => "Sursa pentru '''$1''' apare mai jos:",
-'blockededitsource'         => "Textul '''modificărilor tale''' la  '''$1''' este redat mai jos:",
-'whitelistedittitle'        => 'Este necesară autentificarea pentru a edita',
-'whitelistedittext'         => 'Trebuie să $1 pentru a edita articole.',
-'whitelistreadtitle'        => 'Este necesară autentificarea pentru a citi',
-'whitelistreadtext'         => 'Trebuie să te [[Special:Userlogin|autentifici]] pentru a citi articole.',
-'whitelistacctitle'         => 'Nu ai dreptul de a crea conturi',
-'whitelistacctext'          => 'Pentru a putea crea conturi pe {{SITENAME}}, trebuie să te [[Special:Userlogin|autentifici]] şi să ai permisiunile corecte.',
-'confirmedittitle'          => 'Pentru a edita e necesară confirmarea adresei de e-mail',
-'confirmedittext'           => 'Trebuie să vă confirmaţi adresa de e-mail înainte de a edita pagini. Vă rugăm să vă setaţi şi să vă validaţi adresa de e-mail cu ajutorul [[Special:Preferences|preferinţelor utilizatorului]].',
-'nosuchsectiontitle'        => 'Nu există o astfel de secţiune',
-'nosuchsectiontext'         => 'Aţi încercat să modificaţi o secţiune care nu există. Deoarece nu există secţiunea $1, modificarea nu va fi salvată.',
-'loginreqtitle'             => 'Necesită autentificare',
-'loginreqlink'              => 'autentifici',
-'loginreqpagetext'          => 'Trebuie să te $1 pentru a vizualiza alte pagini.',
-'accmailtitle'              => 'Parola a fost trimisă.',
-'accmailtext'               => "Parola pentru '$1' a fost trimisă la $2.",
-'newarticle'                => '(Nou)',
-'newarticletext'            => 'Ai ajuns la o pagină care nu există. Pentru a o crea, începe să scrii în caseta de mai jos (vezi [[{{MediaWiki:Helppage}}|pagina de ajutor]] pentru mai multe informaţii). Dacă ai ajuns aici din greşeală, întoarce-te folosind controalele browser-ului tău',
-'anontalkpagetext'          => "---- ''Aceasta este pagina de discuţii pentru un utilizator care nu şi-a creat un cont încă, sau care nu s-a autentificat. De aceea trebuie să folosim adresă IP pentru a identifica această persoană. O adresă IP poate fi folosită în comun de mai mulţi utilizatori. Dacă sunteţi un astfel de utilizator şi credeţi că vă sunt adresate mesaje irelevante, vă rugăm să [[Special:Userlogin|vă creaţi un cont sau să vă autentificaţi]] pentru a evita confuzii cu alţi utilizatori anonimi în viitor.''",
-'noarticletext'             => '{{SITENAME}} nu are încă un articol referitor la această pagină. Puteţi [[Special:Search/{{PAGENAME}}|căuta titlul paginii cu acest nume]] în alte pagini sau [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita această pagină].',
-'userpage-userdoesnotexist' => 'Contul de utilizator "$1" nu este înregistrat. Verificaţi dacă doriţi să creaţi/modificaţi această pagină.',
-'clearyourcache'            => "'''Notă:''' După salvare, trebuie să treceţi peste cache-ul browser-ului pentru a vedea modificările. '''Mozilla/Safari/Konqueror:''' ţineţi apăsat ''Shift'' în timp ce apăsaţi ''Reload'' (sau apăsaţi ''Ctrl-Shift-R''), '''IE:''' apăsaţi ''Ctrl-F5'', '''Opera:''' apăsaţi ''F5''.",
-'usercssjsyoucanpreview'    => "<strong>Sfat:</strong> Foloseşte butonul 'Arată previzualizare' pentru a testa noul tău css/js înainte de a salva.",
-'usercsspreview'            => "'''Reţine că urmăreşti doar o previzualizare a css-ului tău de utilizator, acesta nu este încă salvat!'''",
-'userjspreview'             => "'''Reţine că urmăreşti doar un test/o previzualizare a javascript-ului tău de utilizator, acesta nu este încă salvat!'''",
-'userinvalidcssjstitle'     => '<b>Avertizare:</b> Nu există skin "$1". Aminteşte-ţi că paginile .css and .js specifice utilizatorilor au titluri care încep cu literă mică, de exemplu {{ns:user}}:Foo/monobook.css în comparaţie cu {{ns:user}}:Foo/Monobook.css.',
-'updated'                   => '(Actualizat)',
-'note'                      => '<strong>Notă:</strong>',
-'previewnote'               => 'Aceasta este doar o previzualizare! Pentru a salva pagina în forma actuală, descrieţi succint modificările efectuate şi apăsaţi butonul <strong>Salvează pagina</strong>.',
-'previewconflict'           => 'Această pre-vizualizare reflectă textul din caseta de sus, respectiv felul în care va arăta articolul dacă alegeţi să-l salvaţi acum.',
-'session_fail_preview'      => '<strong>Ne pare rău! Nu am putut procesa modificarea dumneavoastră din cauza pierderii datelor sesiunii. Vă rugăm să încercaţi din nou. Dacă tot nu funcţionează, încercaţi să închideţi sesiunea şi să vă autentificaţi din nou.</strong>',
-'session_fail_preview_html' => "<strong>Ne pare rău! Modificările tale nu au putut fi procesate din cauza pierderii datelor sesiunii.</strong> 
+Aveţi adresa IP $3, iar identificatorul dumneavoastră de blocare este $5.
+Vă rugăm să includeţi detaliile de mai sus în orice interogări pe care le faceţi.',
+'blockednoreason'                  => 'nici un motiv oferit',
+'blockedoriginalsource'            => "Sursa pentru '''$1''' apare mai jos:",
+'blockededitsource'                => "Textul '''modificărilor tale''' la  '''$1''' este redat mai jos:",
+'whitelistedittitle'               => 'Este necesară autentificarea pentru a putea modifica',
+'whitelistedittext'                => 'Trebuie să $1 pentru a edita articole.',
+'confirmedittitle'                 => 'Pentru a edita e necesară confirmarea adresei de e-mail',
+'confirmedittext'                  => 'Trebuie să vă confirmaţi adresa de e-mail înainte de a edita pagini. Vă rugăm să vă setaţi şi să vă validaţi adresa de e-mail cu ajutorul [[Special:Preferences|preferinţelor utilizatorului]].',
+'nosuchsectiontitle'               => 'Nu există o astfel de secţiune',
+'nosuchsectiontext'                => 'Aţi încercat să modificaţi o secţiune care nu există. Deoarece nu există secţiunea $1, modificarea nu va fi salvată.',
+'loginreqtitle'                    => 'Necesită autentificare',
+'loginreqlink'                     => 'autentifici',
+'loginreqpagetext'                 => 'Trebuie să te $1 pentru a vizualiza alte pagini.',
+'accmailtitle'                     => 'Parola a fost trimisă.',
+'accmailtext'                      => "Parola pentru '$1' a fost trimisă la $2.",
+'newarticle'                       => '(Nou)',
+'newarticletext'                   => 'Ai ajuns la o pagină care nu există. Pentru a o crea, începe să scrii în caseta de mai jos (vezi [[{{MediaWiki:Helppage}}|pagina de ajutor]] pentru mai multe informaţii). Dacă ai ajuns aici din greşeală, întoarce-te folosind controalele browser-ului tău',
+'anontalkpagetext'                 => "---- ''Aceasta este pagina de discuţii pentru un utilizator care nu şi-a creat un cont încă, sau care nu s-a autentificat.
+De aceea trebuie să folosim adresă IP pentru a identifica această persoană.
+O adresă IP poate fi folosită în comun de mai mulţi utilizatori.
+Dacă sunteţi un astfel de utilizator şi credeţi că vă sunt adresate mesaje irelevante, vă rugăm să [[Special:UserLogin/signup|vă creaţi un cont]] sau să [[Special:UserLogin|vă autentificaţi]] pentru a evita confuzii cu alţi utilizatori anonimi în viitor.''",
+'noarticletext'                    => '{{SITENAME}} nu are încă un articol referitor la această pagină. Puteţi [[Special:Search/{{PAGENAME}}|căuta titlul paginii cu acest nume]] în alte pagini sau [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita această pagină].',
+'userpage-userdoesnotexist'        => 'Contul de utilizator "$1" nu este înregistrat. Verificaţi dacă doriţi să creaţi/modificaţi această pagină.',
+'clearyourcache'                   => "'''Notă:''' După salvare, trebuie să treceţi peste cache-ul browser-ului pentru a vedea modificările. '''Mozilla/Safari/Konqueror:''' ţineţi apăsat ''Shift'' în timp ce apăsaţi ''Reload'' (sau apăsaţi ''Ctrl-Shift-R''), '''IE:''' apăsaţi ''Ctrl-F5'', '''Opera:''' apăsaţi ''F5''.",
+'usercssjsyoucanpreview'           => "<strong>Sfat:</strong> Foloseşte butonul 'Arată previzualizare' pentru a testa noul tău css/js înainte de a salva.",
+'usercsspreview'                   => "'''Reţine că urmăreşti doar o previzualizare a css-ului tău de utilizator, acesta nu este încă salvat!'''",
+'userjspreview'                    => "'''Reţine că urmăreşti doar un test/o previzualizare a javascript-ului tău de utilizator, acesta nu este încă salvat!'''",
+'userinvalidcssjstitle'            => '<b>Avertizare:</b> Nu există skin "$1". Aminteşte-ţi că paginile .css and .js specifice utilizatorilor au titluri care încep cu literă mică, de exemplu {{ns:user}}:Foo/monobook.css în comparaţie cu {{ns:user}}:Foo/Monobook.css.',
+'updated'                          => '(Actualizat)',
+'note'                             => '<strong>Notă:</strong>',
+'previewnote'                      => 'Aceasta este doar o previzualizare! Pentru a salva pagina în forma actuală, descrieţi succint modificările efectuate şi apăsaţi butonul <strong>Salvează pagina</strong>.',
+'previewconflict'                  => 'Această pre-vizualizare reflectă textul din caseta de sus, respectiv felul în care va arăta articolul dacă alegeţi să-l salvaţi acum.',
+'session_fail_preview'             => '<strong>Ne pare rău! Nu am putut procesa modificarea dumneavoastră din cauza pierderii datelor sesiunii.
+Vă rugăm să încercaţi din nou.
+Dacă tot nu funcţionează, încercaţi să [[Special:UserLogout|închideţi sesiunea]] şi să vă autentificaţi din nou.</strong>',
+'session_fail_preview_html'        => "<strong>Ne pare rău! Modificările tale nu au putut fi procesate din cauza pierderii datelor sesiunii.</strong> 
 
-''Deoarece acest wiki are activat raw HTML, previzualizarea este ascunsă ca măsură de precauţie împotriva atacurilor JavaScript.''
+''Deoarece {{SITENAME}} are activat HTML brut, previzualizarea este ascunsă ca măsură de precauţie împotriva atacurilor JavaScript.''
 
-<strong>Dacă această încercare de modificare este legitimă, te rugăm să încerci din nou. Dacă nu funcţionează nici în acest fel, închide sesiunea şi încearcă să te autentifici din nou.</strong>",
-'editing'                   => 'modificare $1',
-'editingsection'            => 'modificare $1 (secţiune)',
-'editingcomment'            => 'modificare $1 (comentariu)',
-'editconflict'              => 'Conflict de modificare: $1',
-'explainconflict'           => "Altcineva a modificat această pagină de când ai început să o editezi.
+<strong>Dacă această încercare de modificare este legitimă, te rugăm să încerci din nou. Dacă nu funcţionează nici în acest fel, [[Special:UserLogout|închide sesiunea]] şi încearcă să te autentifici din nou.</strong>",
+'token_suffix_mismatch'            => '<strong>Modificarea ta a fost refuzată pentru că clientul tău a deformat caracterele de punctuatie în modificarea semnului.
+Modificarea a fost respinsă pentru a preveni deformarea textului paginii.
+Acest fapt se poate întâmpla atunci când foloseşti un serviciu proxy anonim.</strong>',
+'editing'                          => 'modificare $1',
+'editingsection'                   => 'modificare $1 (secţiune)',
+'editingcomment'                   => 'modificare $1 (comentariu)',
+'editconflict'                     => 'Conflict de modificare: $1',
+'explainconflict'                  => "Altcineva a modificat această pagină de când ai început să o editezi.
 Caseta de text de sus conţine pagina aşa cum este ea acum (după editarea celeilalte persoane).
 Pagina cu modificările tale (aşa cum ai încercat să o salvezi) se află în caseta de jos.
 Va trebui să editezi manual caseta de sus pentru a reflecta modificările pe care tocmai le-ai făcut în cea de jos.
 '''Numai''' textul din caseta de sus va fi salvat atunci când vei apăsa pe \"Salvează pagina\".",
-'yourtext'                  => 'Textul tău',
-'storedversion'             => 'Versiunea curentă',
-'nonunicodebrowser'         => '<strong>ATENŢIE: Browser-ul dumneavoastră nu este compilant unicode, vă rugăm să îl schimbaţi înainte de a începe modificarea unui articol.</strong>',
-'editingold'                => '<strong>ATENŢIE! Modifici o variantă mai veche a acestei pagini! Orice modificări care s-au făcut de la această versiune şi până la cea curentă se vor pierde!</strong>',
-'yourdiff'                  => 'Diferenţe',
-'copyrightwarning'          => "<!-- Gol deocamdată. Avertismentul se află în MediaWiki:Summary -->
+'yourtext'                         => 'Textul tău',
+'storedversion'                    => 'Versiunea curentă',
+'nonunicodebrowser'                => '<strong>ATENŢIE: Browser-ul dumneavoastră nu este compilant unicode, vă rugăm să îl schimbaţi înainte de a începe modificarea unui articol.</strong>',
+'editingold'                       => '<strong>ATENŢIE! Modifici o variantă mai veche a acestei pagini! Orice modificări care s-au făcut de la această versiune şi până la cea curentă se vor pierde!</strong>',
+'yourdiff'                         => 'Diferenţe',
+'copyrightwarning'                 => "<!-- Gol deocamdată. Avertismentul se află în MediaWiki:Summary -->
 Please note that all contributions to {{SITENAME}} are considered to be released under the $2 (see $1 for details). If you don't want your writing to be edited mercilessly and redistributed at will, then don't submit it here.<br /> You are also promising us that you wrote this yourself, or copied it from a public domain or similar free resource. <strong>DO NOT SUBMIT COPYRIGHTED WORK WITHOUT PERMISSION!</strong>",
-'copyrightwarning2'         => 'Reţineţi că toate contribuţiile la {{SITENAME}} pot fi modificate, alterate sau şterse de alţi contribuitori.
+'copyrightwarning2'                => 'Reţineţi că toate contribuţiile la {{SITENAME}} pot fi modificate, alterate sau şterse de alţi contribuitori.
 Dacă nu doriţi ca ceea ce scrieţi să fie modificat fără milă şi redistribuit în voie, atunci nu trimiteţi materialele respective aici.<br />
 De asemenea, ne asiguraţi că ceea ce aţi scris a fost compoziţie proprie sau copie dintr-o resursă publică sau liberă (vedeţi $1 pentru detalii).
 <strong>NU INTRODUCEŢI MATERIALE CU DREPTURI DE AUTOR FĂRĂ PERMISIUNE!</strong>',
-'longpagewarning'           => '<strong>ATENŢIE! Conţinutul acestei pagini are $1 KB; unele browsere au probleme la modificarea paginilor în jur de 32 KB sau mai mari. Te rugăm să iei în considerare posibilitatea de a împărţi pagina în mai multe secţiuni.</strong>',
-'longpageerror'             => '<strong>EROARE: Textul pe care vrei să-l salvezi are $1 kilobytes,
+'longpagewarning'                  => '<strong>ATENŢIE! Conţinutul acestei pagini are $1 KB; unele browsere au probleme la modificarea paginilor în jur de 32 KB sau mai mari. Te rugăm să iei în considerare posibilitatea de a împărţi pagina în mai multe secţiuni.</strong>',
+'longpageerror'                    => '<strong>EROARE: Textul pe care vrei să-l salvezi are $1 kilobytes,
 ceea ce înseamnă mai mult decât maximum de $2 kilobytes. Salvarea nu este posibilă.</strong>',
-'readonlywarning'           => '<strong>ATENŢIE! Baza de date a fost blocată pentru întreţinere, deci nu vei putea să salvezi editările în acest moment. Poţi copia textul într-un fişier text local pentru a modifica conţinutul în {{SITENAME}} când va fi posibil.</strong>',
-'protectedpagewarning'      => '<strong>ATENŢIE! Această pagină a fost protejată la scriere şi numai utilizatorii cu privilegii de administrator o pot modifica.</strong>',
-'semiprotectedpagewarning'  => "'''Atenţie:''' Această pagină poate fi modificată numai de utilizatorii înregistraţi.",
-'cascadeprotectedwarning'   => "'''Atenţie:''' Această pagină a fost blocată astfel încât numai administratorii o pot modifica, deoarece este inclusă în {{PLURAL:$1|următoarea pagină protejată|următoarele pagini protejate}} în cascadă:",
-'templatesused'             => 'Formate folosite în această pagină:',
-'templatesusedpreview'      => 'Formate utilizate în această previzualizare:',
-'templatesusedsection'      => 'Formate utilizate în această secţiune:',
-'template-protected'        => '(protejat)',
-'template-semiprotected'    => '(semi-protejat)',
-'edittools'                 => '<!-- Acest text va apărea după caseta de editare şi formularele de trimitere fişier. -->',
-'nocreatetitle'             => 'Creare de pagini limitată',
-'nocreatetext'              => '{{SITENAME}} a restricţionat abilitatea de a crea pagini noi.
-Puteţi edita o pagină deja existentă sau puteţi să vă [[Special:Userlogin|autentificaţi/creaţi]] un cont de utilizator.',
-'nocreate-loggedin'         => 'Nu ai permisiunea să creezi pagini noi pe această wiki.',
-'permissionserrors'         => 'Erori de permisiune',
-'permissionserrorstext'     => 'Nu aveţi permisiune pentru a face acest lucru, din următoarele {{PLURAL:$1|motiv|motive}}:',
-'recreate-deleted-warn'     => "'''Atenție: Recreaţi o pagină care a fost ştearsă anterior.'''
+'readonlywarning'                  => '<strong>ATENŢIE! Baza de date a fost blocată pentru întreţinere, deci nu vei putea să salvezi editările în acest moment. Poţi copia textul într-un fişier text local pentru a modifica conţinutul în {{SITENAME}} când va fi posibil.</strong>',
+'protectedpagewarning'             => '<strong>ATENŢIE! Această pagină a fost protejată la scriere şi numai utilizatorii cu privilegii de administrator o pot modifica.</strong>',
+'semiprotectedpagewarning'         => "'''Atenţie:''' Această pagină poate fi modificată numai de utilizatorii înregistraţi.",
+'cascadeprotectedwarning'          => "'''Atenţie:''' Această pagină a fost blocată astfel încât numai administratorii o pot modifica, deoarece este inclusă în {{PLURAL:$1|următoarea pagină protejată|următoarele pagini protejate}} în cascadă:",
+'titleprotectedwarning'            => '<strong>ATENŢIE:  Această pagină a fost blocată, doar anumiţi utilizatori o pot crea.</strong>',
+'templatesused'                    => 'Formate folosite în această pagină:',
+'templatesusedpreview'             => 'Formate utilizate în această previzualizare:',
+'templatesusedsection'             => 'Formate utilizate în această secţiune:',
+'template-protected'               => '(protejat)',
+'template-semiprotected'           => '(semi-protejat)',
+'hiddencategories'                 => 'Această pagină este membrul {{PLURAL:$1|unei categorii ascunse|a $1 categorii ascunse}}:',
+'edittools'                        => '<!-- Acest text va apărea după caseta de editare şi formularele de trimitere fişier. -->',
+'nocreatetitle'                    => 'Creare de pagini limitată',
+'nocreatetext'                     => '{{SITENAME}} a restricţionat abilitatea de a crea pagini noi.
+Puteţi edita o pagină deja existentă sau puteţi să vă [[Special:UserLogin|autentificaţi/creaţi]] un cont de utilizator.',
+'nocreate-loggedin'                => 'Nu ai permisiunea să creezi pagini noi pe această wiki.',
+'permissionserrors'                => 'Erori de permisiune',
+'permissionserrorstext'            => 'Nu aveţi permisiune pentru a face acest lucru, din următoarele {{PLURAL:$1|motiv|motive}}:',
+'permissionserrorstext-withaction' => 'Nu ai permisiunea să $2, din {{PLURAL:$1|următorul motivul|următoarele motive}}:',
+'recreate-deleted-warn'            => "'''Atenție: Recreaţi o pagină care a fost ştearsă anterior.'''
 
 Pentru a verifica dacă recrearea paginii este într-adevăr oportună iată aici jurnalul ştergerilor:",
 
+# Parser/template warnings
+'expensive-parserfunction-category'       => 'Pagini cu prea multe apelări costisitoare de funcţii parser',
+'post-expand-template-inclusion-warning'  => 'Atenţie: Formatele incluse sunt prea mari.
+Unele formate nu vor fi incluse.',
+'post-expand-template-inclusion-category' => 'Paginile în care este inclus formatul are o dimensiune prea mare',
+'post-expand-template-argument-warning'   => 'Atenţie: Această pagină conţine cel puţin un argument al unui format care are o mărime prea mare atunci când este expandat.
+Acsete argumente au fost omise.',
+'post-expand-template-argument-category'  => 'Pagini care conţin formate cu argumente omise',
+
 # "Undo" feature
 'undo-success' => 'Modificarea poate fi anulată. Verificaţi diferenţa de dedesupt şi apoi salvaţi pentru a termina anularea modificării.',
-'undo-summary' => 'Anularea modificării $1 făcute de [[Special:Contributions/$2|$2]] ([[User talk:$2|discuţie]])',
+'undo-failure' => 'Modificarea nu poate fi reversibilă datorită conflictului de modificări intermediare.',
+'undo-norev'   => 'Modificarea nu poate fi reversibilă pentru că nu există sau pentru că a fost ştearsă.',
+'undo-summary' => 'Anularea modificării $1 făcute de [[Special:Contributions/$2|$2]] ([[User talk:$2|Discuţie]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Crearea contului nu poate fi realizată',
@@ -720,6 +755,9 @@
 </div>',
 'rev-delundel'                => 'arată/ascunde',
 'revisiondelete'              => 'Şterge/recuperează revizii',
+'revdelete-nooldid-title'     => 'Revizie invalidă',
+'revdelete-nooldid-text'      => 'Nu ai specificat revizie pentru a efectua această
+funcţie, revizia specificată nu există, sau eşti pe cale să ascunzi revizia curentă.',
 'revdelete-selected'          => '{{PLURAL:$2|Revizia aleasă|Reviziile alese}} pentru [[:$1]]:',
 'logdelete-selected'          => '{{PLURAL:$2|Revizia aleasă|Reviziile alese}} pentru [[:$1]]:',
 'revdelete-text'              => 'Reviziile şterse vor apărea în istoricul paginii, dar conţinutul lor nu va fi accesibil publicului.
@@ -727,33 +765,63 @@
 Alţi administratori de pe acest wiki vor putea accesa conţinutul ascuns şi îl pot recupera prin aceeaşi interfaţă, dacă nu este impusă o altă restricţie de către operatorii sitului.',
 'revdelete-legend'            => 'Setează restricţii pentru vizualizare',
 'revdelete-hide-text'         => 'Ascunde textul reviziei',
+'revdelete-hide-name'         => 'Ascunde acţiunea şi destinaţia',
 'revdelete-hide-comment'      => 'Ascunde descrierea modificării',
 'revdelete-hide-user'         => 'Ascunde numele de utilizator/IP-ul editorului',
 'revdelete-hide-restricted'   => 'Aplică aceste restricţii administratorilor şi închide această interfaţă',
+'revdelete-suppress'          => 'Ascunde de asemenea reviziile faţă de administratori',
 'revdelete-hide-image'        => 'Ascunde conţinutul fişierului',
+'revdelete-unsuppress'        => 'Elimină restricţiile în reviziile restaurate',
 'revdelete-log'               => 'Comentariu log:',
 'revdelete-submit'            => 'Aplică reviziilor selectate',
 'revdelete-logentry'          => 'vizibilitatea reviziei pentru [[$1]] a fost modificată',
+'logdelete-logentry'          => 'a fost modificată vizibilitatea evenimentului [[$1]]',
+'revdelete-success'           => "'''Vizibilitatea versiunilor a fost schimbată cu succes.'''",
+'logdelete-success'           => "'''Jurnalul vizibilităţii a fost configurat cu succes.'''",
 'revdel-restore'              => 'Schimbă vizibilitatea',
 'pagehist'                    => 'Istoricul paginii',
 'deletedhist'                 => 'Istoric şters',
+'revdelete-content'           => 'conţinut',
+'revdelete-summary'           => 'sumarul modificărilor',
 'revdelete-uname'             => 'nume de utilizator',
+'revdelete-restricted'        => 'restricţii aplicate administratorilor',
+'revdelete-unrestricted'      => 'restricţii eliminate pentru administratori',
+'revdelete-hid'               => 'ascuns $1',
+'revdelete-unhid'             => 'arată $1',
 'revdelete-log-message'       => '$1 pentru $2 {{PLURAL:$2|versiune|versiuni}}',
 'logdelete-log-message'       => '$1 pentru $2 {{PLURAL:$2|eveniment|evenimente}}',
 
+# Suppression log
+'suppressionlog'     => 'Înlătură jurnalul',
+'suppressionlogtext' => 'Mai jos este afişată o listă a ştergerilor şi a blocărilor care implică conţinutul ascuns de administratori.
+Vezi [[Special:IPBlockList|adresele IP blocate]] pentru o listă a interzicerilor operaţionale sau a blocărilor.',
+
 # History merging
 'mergehistory'                     => 'Uneşte istoricul paginilor',
+'mergehistory-box'                 => 'Combină reviziile a două pagini:',
 'mergehistory-from'                => 'Pagina sursă:',
 'mergehistory-into'                => 'Pagina destinaţie:',
+'mergehistory-list'                => 'Istoricul la care se aplică combinarea',
+'mergehistory-merge'               => 'Ulmătoarele revizii ale [[:$1]] pot fi combinate în [[:$2]].
+Foloseşte butonul pentru a combina reviziile create la şi după momentul specificat.
+Folosirea linkurilor de navigare va reseta această coloană.',
+'mergehistory-go'                  => 'Vezi modificările care pot fi combinate',
 'mergehistory-submit'              => 'Uneşte reviziile',
+'mergehistory-empty'               => 'Reviziile nu pot fi combinate.',
 'mergehistory-success'             => '$3 {{PLURAL:$3|revizie|revizii}} ale [[:$1]] au fost unite cu succes în [[:$2]].',
+'mergehistory-fail'                => 'Nu se poate executa combinarea istoricului, te rog verifică parametrii pagină şi timp.',
 'mergehistory-no-source'           => 'Pagina sursă $1 nu există.',
 'mergehistory-no-destination'      => 'Pagina de destinaţie $1 nu există.',
 'mergehistory-invalid-source'      => 'Pagina sursă trebuie să aibă un titlu valid.',
 'mergehistory-invalid-destination' => 'Pagina de destinaţie trebuie să aibă un titlu valid.',
+'mergehistory-autocomment'         => 'Combinat [[:$1]] în [[:$2]]',
+'mergehistory-comment'             => 'Combinat [[:$1]] în [[:$2]]: $3',
 
 # Merge log
-'mergelog' => 'Uneşte jurnalul',
+'mergelog'           => 'Jurnal unificări',
+'pagemerge-logentry' => 'combină [[$1]] cu [[$2]] (revizii până la $3)',
+'revertmerge'        => 'Anulează îmbinarea',
+'mergelogpagetext'   => 'Mai jos este o listă a celor mai recente combinări ale istoricului unei pagini cu al alteia.',
 
 # Diffs
 'history-title'           => 'Istoria reviziilor pentru "$1"',
@@ -766,10 +834,11 @@
 # Search results
 'searchresults'             => 'Rezultatele căutării',
 'searchresulttext'          => 'Pentru mai multe detalii despre căutarea în {{SITENAME}}, vezi [[Project:Căutare]].',
-'searchsubtitle'            => 'Pentru căutarea "[[$1]]"',
+'searchsubtitle'            => 'Ai căutat \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|toate paginile care încep cu "$1"]] | [[Special:WhatLinksHere/$1|toate paginile care se leagă de "$1"]])',
 'searchsubtitleinvalid'     => 'Pentru căutarea "$1"',
 'noexactmatch'              => "'''Pagina cu titlul \"\$1\" nu există.''' Poţi [[:\$1|crea această pagină]].",
 'noexactmatch-nocreate'     => "'''Nu există nici o pagină cu titlul \"\$1\".'''",
+'toomanymatches'            => 'Prea multe rezultate au fost întoarse, încercă o căutare diferită',
 'titlematches'              => 'Rezultate în titluri de articole',
 'notitlematches'            => 'Nici un rezultat în titlurile articolelor',
 'textmatches'               => 'Rezultate în textele articolelor',
@@ -780,12 +849,15 @@
 'search-result-size'        => '$1 ({{PLURAL:$2|1 cuvânt|$2 cuvinte}})',
 'search-result-score'       => 'Relevanţă: $1%',
 'search-section'            => '(secţiunea $1)',
+'search-suggest'            => 'Te-ai referit la: $1',
 'search-interwiki-caption'  => 'Proiecte înrudite',
 'search-interwiki-default'  => '$1 rezultate:',
 'search-interwiki-more'     => '(mai mult)',
 'search-mwsuggest-enabled'  => 'cu sugestii',
 'search-mwsuggest-disabled' => 'fără sugestii',
+'search-relatedarticle'     => 'Relaţionat',
 'mwsuggest-disable'         => 'Dezactivează sugestiile AJAX',
+'searchrelated'             => 'relaţionat',
 'searchall'                 => 'toate',
 'showingresults'            => "Mai jos {{PLURAL:$1|apare '''1''' rezultat|apar '''$1''' rezultate}} începând cu #<b>$2</b>.",
 'showingresultsnum'         => "Mai jos {{PLURAL:$3|apare '''1''' rezultat|apar '''$3''' rezultate}} cu #<b>$2</b>.",
@@ -795,6 +867,7 @@
 'powersearch-legend'        => 'Căutare avansată',
 'powersearch-ns'            => 'Căutare în spaţiile de nume:',
 'powersearch-redir'         => 'Afişează redirectările',
+'powersearch-field'         => 'Caută',
 'search-external'           => 'Căutare externă',
 'searchdisabled'            => '<p>Ne pare rău! Căutarea după text a fost dezactivată temporar, din motive de performanţă. Între timp puteţi folosi căutarea prin Google mai jos, însă aceasta poate să dea rezultate învechite.</p>',
 
@@ -803,7 +876,7 @@
 'mypreferences'            => 'preferinţe',
 'prefs-edits'              => 'Număr de modificări:',
 'prefsnologin'             => 'Neautentificat',
-'prefsnologintext'         => 'Trebuie să fii [[Special:Userlogin|autentificat]] pentru a-ţi putea salva preferinţele.',
+'prefsnologintext'         => 'Trebuie să fii [[Special:UserLogin|autentificat]] pentru a-ţi putea salva preferinţele.',
 'prefsreset'               => 'Preferinţele au fost resetate.',
 'qbsettings'               => 'Setări pentru bara rapidă',
 'qbsettings-none'          => 'Fără',
@@ -844,6 +917,7 @@
 'resultsperpage'           => 'Numărul de rezultate per pagină',
 'contextlines'             => 'Numărul de linii per rezultat',
 'contextchars'             => 'Numărul de caractere per linie',
+'stub-threshold'           => 'Valoarea minimă pentru un <a href="#" class="stub">ciot</a> (octeţi):',
 'recentchangesdays'        => 'Numărul de zile afişate în schimbări recente:',
 'recentchangescount'       => 'Numărul de articole pentru schimbări recente:',
 'savedprefs'               => 'Preferinţele tale au fost salvate.',
@@ -872,6 +946,8 @@
 'userrights-reason'           => 'Motivul schimbării:',
 'userrights-no-interwiki'     => 'Nu aveţi permisiunea de a modifica drepturi de utilizatori pe alte wiki.',
 'userrights-nodatabase'       => 'Baza de date $1 nu există sau nu este locală.',
+'userrights-nologin'          => 'Trebuie să te [[Special:UserLogin|autentifici]] cu un cont de administrator pentru a atribui drepturi utilizatorilor.',
+'userrights-notallowed'       => 'Contul tău nu îţi permite să aloci drepturi speciale utilizatorilor.',
 'userrights-changeable-col'   => 'Grupuri pe care le puteţi schimba',
 'userrights-unchangeable-col' => 'Grupuri pe care nu le puteţi schimba',
 
@@ -882,6 +958,7 @@
 'group-bot'           => 'Roboţi',
 'group-sysop'         => 'Administratori',
 'group-bureaucrat'    => 'Birocraţi:',
+'group-suppress'      => 'Oversights',
 'group-all'           => '(toţi)',
 
 'group-user-member'          => 'Utilizator',
@@ -889,12 +966,14 @@
 'group-bot-member'           => 'Robot',
 'group-sysop-member'         => 'Administrator',
 'group-bureaucrat-member'    => 'Birocrat',
+'group-suppress-member'      => 'oversight',
 
 'grouppage-user'          => '{{ns:project}}:Utilizatori',
 'grouppage-autoconfirmed' => '{{ns:project}}:Utilizator autoconfirmaţi',
 'grouppage-bot'           => '{{ns:project}}:Boţi',
 'grouppage-sysop'         => '{{ns:project}}:Administratori',
 'grouppage-bureaucrat'    => '{{ns:project}}:Birocraţi',
+'grouppage-suppress'      => '{{ns:proiect}}:Oversight',
 
 # Rights
 'right-read'                 => 'Citeşte paginile',
@@ -909,26 +988,31 @@
 'right-reupload'             => 'Suprascrie un fişier existent',
 'right-reupload-own'         => 'Suprascrie un fişier existent propriu',
 'right-upload_by_url'        => 'Încarcă un fişier de la o adresă URL',
+'right-purge'                => 'Curăţă memoria cache pentru o pagină fără confirmare',
 'right-autoconfirmed'        => 'Modifică paginile semi-protejate',
 'right-bot'                  => 'Tratare ca proces automat',
 'right-delete'               => 'Şterge pagini',
 'right-bigdelete'            => 'Şterge pagini cu istoric lung',
 'right-deleterevision'       => 'Şterge şi recuperează versiuni specifice ale paginilor',
+'right-deletedhistory'       => 'Vezi intrările şterse din istoric, fără textul asociat',
 'right-browsearchive'        => 'Caută pagini şterse',
 'right-undelete'             => 'Recuperează pagini',
 'right-suppressionlog'       => 'Vizualizează jurnale private',
 'right-block'                => 'Blocare utilizatori la modificare',
 'right-blockemail'           => 'Blocare utilizatori la trimitere email',
 'right-hideuser'             => 'Blochează un nume de utilizator, ascunzându-l de public',
+'right-ipblock-exempt'       => 'Nu au fost afectaţi de blocarea făcută IP-ului.',
 'right-protect'              => 'Schimbă nivelurile de protejare şi modifică pagini protejate',
 'right-editprotected'        => 'Modificare pagini protejate (fără protejare în cascadă)',
 'right-editinterface'        => 'Modificare interfaţa cu utilizatorul',
+'right-rollback'             => 'Revocarea rapidă a editărilor ultimului utilizator care a modificat o pagină particulară',
 'right-import'               => 'Importă pagini de la alte wiki',
 'right-importupload'         => 'Importă pagini dintr-o încărcare de fişier',
 'right-patrol'               => 'Marchează modificările altora ca patrulate',
 'right-autopatrol'           => 'Modificările proprii marcate ca patrulate',
 'right-patrolmarks'          => 'Vizualizează pagini recent patrulate',
 'right-unwatchedpages'       => 'Vizualizezaă listă de pagini neurmărite',
+'right-trackback'            => 'Trimite un urmăritor',
 'right-mergehistory'         => 'Uneşte istoricele paginilor',
 'right-userrights'           => 'Modifică toate drepturile de utilizator',
 'right-userrights-interwiki' => 'Modifică drepturile de utilizator pentru utilizatorii de pe alte wiki',
@@ -982,23 +1066,23 @@
 'reupload'                    => 'Re-trimite',
 'reuploaddesc'                => 'Revocare încărcare şi întoarcere la formularul de trimitere.',
 'uploadnologin'               => 'Nu sunteţi autentificat',
-'uploadnologintext'           => 'Trebuie să fiţi [[Special:Userlogin|autentificat]] pentru a putea trimite fişiere.',
+'uploadnologintext'           => 'Trebuie să fiţi [[Special:UserLogin|autentificat]] pentru a putea trimite fişiere.',
 'upload_directory_read_only'  => 'Directorul de trimitere ($1) nu are drepturi de scriere de către server.',
 'uploaderror'                 => 'Eroare la trimitere fişier',
 'uploadtext'                  => "Foloseşte formularul de mai jos pentru a trimite fişiere. 
-Pentru a vizualiza sau căuta imagini deja trimise, mergi la [[Special:Imagelist|lista de imagini]], încărcările şi ştergerile sunt de asemenea înregistrate în [[Special:Log/upload|jurnalul fişierelor trimise]].
+Pentru a vizualiza sau căuta imagini deja trimise, mergi la [[Special:ImageList|lista de imagini]], încărcările şi ştergerile sunt de asemenea înregistrate în [[Special:Log/upload|jurnalul fişierelor trimise]], ştergerile în [[Special:Log/delete|jurnalul fişierelor şterse]].
 
-Pentru a include un fişier de sunet într-un articol, foloseşti o legătură de forma
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fişier.jpg]]</nowiki>''',
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.Fişier|text alternativ]]</nowiki>''' sau
-pentru a include un fişier de sunet într-un articol, foloseşti o legătură de forma
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>'''.",
+Pentru a include un fişier de sunet într-un articol, foloseşti o legătură de forma:
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fişier.jpg]]</nowiki></tt>''' pentru a include versiunea integrală a unui fişier
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fişier.png|200px|thumb|left|alt text]]</nowiki></tt>''' pentru a introduce o imagine de 200px într-un chenar cu textul 'alt text' în partea stângă ca descriere
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:Fişier.ogg]]</nowiki></tt>''' pentru a lega direct fişierul fără a-l afişa",
 'upload-permitted'            => 'Tipuri de fişiere permise: $1.',
 'upload-preferred'            => 'Tipuri de fişiere preferate: $1.',
 'upload-prohibited'           => 'Tipuri de fişiere interzise: $1.',
 'uploadlog'                   => 'Raportul fişierelor trimise',
 'uploadlogpage'               => 'Raportul fişierelor trimise',
-'uploadlogpagetext'           => 'Găseşti mai jos lista ultimelor fişiere trimise.',
+'uploadlogpagetext'           => 'Mai jos este afişată lista ultimelor fişiere trimise.
+Vezi [[Special:NewImages|galeria fişierelor noi]] pentru o mai bună vizualizare.',
 'filename'                    => 'Nume fişier',
 'filedesc'                    => 'Descriere fişier',
 'fileuploadsummary'           => 'Descriere:',
@@ -1018,9 +1102,23 @@
 'largefileserver'             => 'Fişierul este mai mare decât este configurat serverul să permită.',
 'emptyfile'                   => 'Fişierul pe care l-aţi încărcat pare a fi gol. Aceasta poate fi datorită unei greşeli în numele fişierului. Verificaţi dacă într-adevăr doriţi să încărcaţi acest fişier.',
 'fileexists'                  => 'Un fişier cu acelaşi nume există deja, vă rugăm verificaţi <strong><tt>$1</tt></strong> dacă nu sunteţi sigur dacă doriţi să îl modificaţi.',
+'filepageexists'              => 'Pagina cu descrierea fişierului a fost deja creată la <strong><tt>$1</tt></strong>, dar niciun fişier cu acest nume nu există în acest moment.
+Sumarul pe care l-ai introdus nu va apărea în pagina cu descriere.
+Pentru ca sumarul tău să apară, va trebui să îl adaugi manual',
+'fileexists-extension'        => 'Un fişier cu un nume similar există:<br />
+Numele fişierului de încărcat: <strong><tt>$1</tt></strong><br />
+Numele fişierului existent: <strong><tt>$2</tt></strong><br />
+Te rog alege alt nume.',
 'fileexists-thumb'            => "<center>'''Imagine existentă'''</center>",
+'fileexists-thumbnail-yes'    => 'Fişierul pare a fi o imagine cu o rezoluţie scăzută <i>(thumbnail)</i>.
+Verifică fişierul<strong><tt>$1</tt></strong>.<br />
+Dacă fişierul verificat este identic cu imaginea originală nu este necesară încărcarea altui thumbnail.',
+'file-thumbnail-no'           => 'Numele fişierului începe cu <strong><tt>$1</tt></strong>.
+Se pare că este o imagine cu dimensiune redusă<i>(thumbnail)</i>.
+Dacă ai această imagine la rezoluţie mare încarc-o pe aceasta, altfel schimbă numele fişierului.',
 'fileexists-forbidden'        => 'Un fişier cu acest nume există deja; mergeţi înapoi şi încărcaţi acest fişier sub un nume nou. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Un fişier cu acest nume există deja în magazia de imagini comune; mergeţi înapoi şi încărcaţi fişierul sub un nou nume. [[Image:$1|thumb|center|$1]]',
+'file-exists-duplicate'       => 'Acest fişier este dublura {{PLURAL:$1|fişierului|fişierelor}}:',
 'successfulupload'            => 'Fişierul a fost trimis',
 'uploadwarning'               => 'Avertizare la trimiterea fişierului',
 'savefile'                    => 'Salvează fişierul',
@@ -1036,16 +1134,31 @@
 'upload-maxfilesize'          => 'Mărimea maximă a unui fişier: $1',
 'watchthisupload'             => 'Urmăreşte această pagină',
 'filewasdeleted'              => 'Un fişier cu acest nume a fost anterior încărcat şi apoi şters. Ar trebui să verificaţi $1 înainte să îl încărcaţi din nou.',
+'upload-wasdeleted'           => "'''Atenţie: Eşti pe cale să încarci un fişier şters anterior.'''
 
-'upload-proto-error'     => 'Protocol incorect',
-'upload-file-error'      => 'Eroare internă',
-'upload-file-error-text' => 'A apărut o eroare internă la crearea unui fişier temporar pe server. Vă rugăm să contactaţi un administrator.',
-'upload-misc-error'      => 'Eroare de încărcare necunoscută',
-'upload-misc-error-text' => 'A apărut o eroare necunoscută în timpul încărcării. Vă rugăm să verificaţi dacă adresa URL este validă şi accesibilă şi îcnercaţi din nou. Dacă problema persistă, contactaţi un administrator.',
+Te rog să ai în vedere dacă este utilă reîncărcarea acestuia.
+Raportul pentru această ştergere este disponibil aici:",
+'filename-bad-prefix'         => 'Numele fişierului pe care îl încarci începe cu <strong>"$1"</strong>, care este un nume non-descriptiv alocat automat în general de camerele digitale.
+Te rog alege un nume mai descriptiv pentru fişerul tău.',
 
+'upload-proto-error'      => 'Protocol incorect',
+'upload-proto-error-text' => 'Importul de la distanţă necesită adrese URL care încep cu <code>http://</code> sau <code>ftp://</code>.',
+'upload-file-error'       => 'Eroare internă',
+'upload-file-error-text'  => 'A apărut o eroare internă la crearea unui fişier temporar pe server.
+Vă rugăm să contactaţi un [[Special:ListUsers/sysop|administrator]].',
+'upload-misc-error'       => 'Eroare de încărcare necunoscută',
+'upload-misc-error-text'  => 'A apărut o eroare necunoscută în timpul încărcării.
+Vă rugăm să verificaţi dacă adresa URL este validă şi accesibilă şi încercaţi din nou.
+Dacă problema persistă, contactaţi un [[Special:ListUsers/sysop|administrator]].',
+
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
-'upload-curl-error6-text' => 'Adresa URL introdusă nu a putut fi atinsă.
+'upload-curl-error6'       => 'Nu pot găsi adresa URL',
+'upload-curl-error6-text'  => 'Adresa URL introdusă nu a putut fi atinsă.
 Vă rugăm, verificaţi că adresa URL este corectă şi că situl este funcţional.',
+'upload-curl-error28'      => 'Încărcarea a expirat',
+'upload-curl-error28-text' => 'Sitelui îi ia prea mult timp pentru a răspunde.
+Te rog verifică dacă situl este activ, aşteaptă puţin şi încearcă apoi.
+Poate doreşti să încerci la o oră mai puţin ocupată.',
 
 'license'            => 'Licenţiere:',
 'nolicense'          => 'Nici una selectată',
@@ -1053,7 +1166,10 @@
 'upload_source_url'  => ' (un URL valid, accesibil public)',
 'upload_source_file' => ' (un fişier de pe computerul tău)',
 
-# Special:Imagelist
+# Special:ImageList
+'imagelist-summary'     => 'Această pagină specială arată toate fişierele încărcate.
+În mod normal ultimul fişier încărcat este aşezat în capul listei.
+O apăsare pe antetul coloanei schimbă sortarea.',
 'imagelist_search_for'  => 'Caută imagine după nume:',
 'imgfile'               => 'fişier',
 'imagelist'             => 'Lista imaginilor',
@@ -1078,13 +1194,17 @@
 'imagelinks'                     => 'Legăturile imaginii',
 'linkstoimage'                   => '{{PLURAL:$1|Următoarea pagină trimite spre|Următoarele $1 pagini trimit spre}} această imagine:',
 'nolinkstoimage'                 => 'Nici o pagină nu se leagă la această imagine.',
+'morelinkstoimage'               => 'Vedeţi [[Special:Whatlinkshere/$1|mai multe legături]] către acest fişier.',
 'redirectstofile'                => 'The following {{PLURAL:$1|file redirects|$1 files redirect}} to this file:
 {{PLURAL:$1|Fişierul următor|Următoarele $1 fişiere}} redirectează la acest fişier:',
 'duplicatesoffile'               => '{{PLURAL:$1|Fişierul următor este duplicat|Următoarele $1 fişiere sunt duplciate}} ale acestui fişier:',
 'sharedupload'                   => 'Acest fişier transferat (upload) poate fi folosit în comun de către alte proiecte.',
 'shareduploadwiki'               => 'Vă rugăm citiţi [$1 pagina de descriere a fişierului] pentru alte informaţii.',
+'shareduploadwiki-desc'          => 'Mai jos, găsiţi $1 provenind de la repertoarul partajat.',
 'shareduploadwiki-linktext'      => 'pagina descriptivă a fişierului',
+'shareduploadduplicate'          => 'Acest fişier este un duplicat al $1 disponibil la depozitul partajat.',
 'shareduploadduplicate-linktext' => 'alt fişier',
+'shareduploadconflict'           => 'Acest fişier are acelaşi nume ca $1 disponibil la depozitul partajat.',
 'shareduploadconflict-linktext'  => 'alt fişier',
 'noimage'                        => 'Nu există nici un fişier cu acest nume, puteţi să îl $1.',
 'noimage-linktext'               => 'trimiteţi',
@@ -1093,19 +1213,26 @@
 
 # File reversion
 'filerevert'                => 'Revenire $1',
+'filerevert-legend'         => 'Revenirea la o versiune anterioară',
+'filerevert-intro'          => "Pentru a readuce fişierul '''[[Media:$1|$1]]''' la versiunea din [$4 $2 $3] apasă butonul de mai jos.",
 'filerevert-comment'        => 'Comentariu:',
 'filerevert-defaultcomment' => 'Revenire la versiunea din $2, $1',
 'filerevert-submit'         => 'Revenire',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' a fost readus [la versiunea $4 din $3, $2].",
+'filerevert-badversion'     => 'Nu există o versiune mai veche a fişierului care să corespundă cu data introdusă.',
 
 # File deletion
 'filedelete'                  => 'Şterge $1',
 'filedelete-legend'           => 'Şterge fişierul',
 'filedelete-intro'            => "Ştergi '''[[Media:$1|$1]]'''.",
+'filedelete-intro-old'        => "Ştergi versiunea fişierului '''[[Media:$1|$1]]''' din [$4 $3, $2].",
 'filedelete-comment'          => 'Motiv pentru ştergere:',
 'filedelete-submit'           => 'Şterge',
 'filedelete-success'          => "'''$1''' a fost şters.",
+'filedelete-success-old'      => '<span class="plainlinks">Versiunea fişierului \'\'\'[[Media:$1|$1]]\'\'\' din $3, $2 a fost ştearsă.</span>',
 'filedelete-nofile'           => "'''$1''' nu există pe acest sit.",
 'filedelete-nofile-old'       => "Nu există nicio versiune arhivată a '''$1''' cu atributele specificate.",
+'filedelete-iscurrent'        => 'Eşti pe cale să ştergi cea mai recentă versiune a acestui fişier. Te rog să revii la o versiune mai veche.',
 'filedelete-otherreason'      => 'Alt motiv (adiţional):',
 'filedelete-reason-otherlist' => 'Alt motiv',
 'filedelete-reason-dropdown'  => '*Motive uzuale
@@ -1114,10 +1241,23 @@
 'filedelete-edit-reasonlist'  => 'Modifică motivele ştergerii',
 
 # MIME search
-'mimesearch' => 'Căutare MIME',
-'mimetype'   => 'Tip MIME:',
-'download'   => 'descarcă',
+'mimesearch'         => 'Căutare MIME',
+'mimesearch-summary' => 'This page enables the filtering of files for its MIME-type.
+Input: contenttype/subtype, e.g. <tt>image/jpeg</tt>.
 
+
+Această pagină specială permite căutarea fişierelor în funcţie de tipul MIME (Multipurpose Internet Mail Extensions). Cele mai des întâlnite sunt:
+* Imagini : <code>image/jpeg</code> 
+* Diagrame : <code>image/png</code>, <code>image/svg+xml</code> 
+* Imagini animate : <code>image/gif</code> 
+* Fişiere sunet : <code>audio/ogg</code>, <code>audio/x-ogg</code> 
+* Fişiere video : <code>video/ogg</code>, <code>video/x-ogg</code> 
+* Fişiere PDF : <code>application/pdf</code>
+
+Lista tipurilor MIME recunoscute de MediaWiki poate fi găsită la [http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/includes/mime.types?view=markup fişiere mime.types].',
+'mimetype'           => 'Tip MIME:',
+'download'           => 'descarcă',
+
 # Unwatched pages
 'unwatchedpages' => 'Pagini neurmărite',
 
@@ -1151,14 +1291,18 @@
 În medie, rezultă <b>\$5</b> modificări per pagină şi <b>\$6</b> vizualizări la fiecare modificare.
 
 Mărimea [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] este <b>\$7</b>.",
-'userstatstext'          => "Există {{PLURAL:$1|'''1''' [[Special:Listusers|utilizator]] înregistrat|un număr de '''$1''' [[Special:Listusers|utilizatori]] înregistraţi}}. Dintre aceştia '''$2''' (sau '''$4%''') {{PLURAL:$2|are|au}} drepturi de $5.",
+'userstatstext'          => "Există {{PLURAL:$1|'''1''' [[Special:ListUsers|utilizator]] înregistrat|un număr de '''$1''' [[Special:ListUsers|utilizatori]] înregistraţi}}. Dintre aceştia '''$2''' (sau '''$4%''') {{PLURAL:$2|are|au}} drepturi de $5.",
 'statistics-mostpopular' => 'Paginile cele mai vizualizate',
 
-'disambiguations'     => 'Pagini de dezambiguizare',
-'disambiguationspage' => 'Template:Dezambiguizare',
+'disambiguations'      => 'Pagini de dezambiguizare',
+'disambiguationspage'  => 'Template:Dezambiguizare',
+'disambiguations-text' => "Paginile următoare conţin legături către o '''pagină de dezambiguizare'''.
+În locul acesteia ar trebui să conţină legături către un articol.<br />
+O pagină este considerată o pagină de dezambiguizare dacă foloseşte formate care apar la [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redirecţionări duble',
-'doubleredirectstext' => '<b>Atenţie:</b> Această listă poate conţine articole care nu sunt în fapt duble rediriecţionări. Acest lucru înseamnă de obicei că există text adiţional sub primul #REDIRECT.<br />',
+'doubleredirects'       => 'Redirecţionări duble',
+'doubleredirectstext'   => '<b>Atenţie:</b> Această listă poate conţine articole care nu sunt în fapt duble rediriecţionări. Acest lucru înseamnă de obicei că există text adiţional sub primul #REDIRECT.<br />',
+'double-redirect-fixer' => 'Corector de redirecţionări',
 
 'brokenredirects'        => 'Redirecţionări greşite',
 'brokenredirectstext'    => 'Următoarele redirecţionări conduc spre articole inexistente.',
@@ -1167,6 +1311,7 @@
 
 'withoutinterwiki'         => 'Pagini fără legături interwiki',
 'withoutinterwiki-summary' => 'Următoarele pagini nu se leagă la versiuni ale lor în alte limbi:',
+'withoutinterwiki-legend'  => 'Prefix',
 'withoutinterwiki-submit'  => 'Arată',
 
 'fewestrevisions' => 'Articole cu cele mai puţine revizii',
@@ -1206,6 +1351,8 @@
 'protectedpagestext'      => 'Următoarele pagini sunt protejate la mutare sau editare',
 'protectedpagesempty'     => 'Nu există pagini protejate',
 'protectedtitles'         => 'Titluri protejate',
+'protectedtitlestext'     => 'Următoarele titluri sunt protejate la creare',
+'protectedtitlesempty'    => 'Nu există titluri protejate cu aceşti parametri.',
 'listusers'               => 'Lista de utilizatori',
 'newpages'                => 'Pagini noi',
 'newpages-username'       => 'Nume de utilizator:',
@@ -1216,23 +1363,30 @@
 'unusedcategoriestext'    => 'Următoarele categorii de pagini există şi totuşi nici un articol sau categorie nu le foloseşte.',
 'notargettitle'           => 'Lipsă ţintă',
 'notargettext'            => 'Nu ai specificat nici o pagină sau un utilizator ţintă pentru care să se efectueze această operaţiune.',
+'nopagetitle'             => 'Nu există pagina destinaţie',
+'nopagetext'              => 'Pagina destinaţie specificată nu există.',
 'pager-newer-n'           => '{{PLURAL:$1|1 mai nou|$1 mai noi}}',
 'pager-older-n'           => '{{PLURAL:$1|1|$1}} mai vechi',
+'suppress'                => 'Oversight',
 
 # Book sources
 'booksources'               => 'Surse de cărţi',
 'booksources-search-legend' => 'Caută surse pentru cărţi',
+'booksources-go'            => 'Du-te',
+'booksources-text'          => 'Mai jos se află o listă de legături înspre alte situri care vând cărţi noi sau vechi, şi care pot oferi informaţii suplimentare despre cărţile pe care le căutaţi:',
 
 # Special:Log
 'specialloguserlabel'  => 'Utilizator:',
 'speciallogtitlelabel' => 'Titlu:',
 'log'                  => 'Rapoarte',
 'all-logs-page'        => 'Toate jurnalele',
+'log-search-legend'    => 'Caută jurnale',
+'log-search-submit'    => 'Du-te',
 'alllogstext'          => 'Afişare combinată a încărcărilor, ştergerilor, protecţiilor, blocărilor şi a rapoartelor administratorilor. Puteţi limita vizualizarea selectând tipul raportului, numele de utilizator sau pagina afectată.',
 'logempty'             => 'Nici o înregistrare în raport.',
 'log-title-wildcard'   => 'Caută titluri care încep cu acest text',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Toate paginile',
 'alphaindexline'    => '$1 către $2',
 'nextpage'          => 'Pagina următoare ($1)',
@@ -1251,25 +1405,27 @@
 # Special:Categories
 'categories'                    => 'Categorii',
 'categoriespagetext'            => 'Următoarele categorii conţin pagini sau fişiere.',
+'categoriesfrom'                => 'Arată categoriile pornind de la:',
 'special-categories-sort-count' => 'ordonează după număr',
 'special-categories-sort-abc'   => 'sortează alfabetic',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Afişează utilizatori începând cu:',
 'listusers-submit'   => 'Arată',
 'listusers-noresult' => 'Nici un utilizator găsit.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
+'listgrouprights'         => 'Permisiunile grupurilor de utilizatori',
 'listgrouprights-group'   => 'Grup',
 'listgrouprights-rights'  => 'Drepturi',
 'listgrouprights-members' => '(listă de membri)',
 
 # E-mail user
 'mailnologin'     => 'Nu există adresă de trimitere',
-'mailnologintext' => 'Trebuie să fii [[Special:Userlogin|autentificat]] şi să ai o adresă validă de e-mail în [[Special:Preferences|preferinţe]] pentru a trimite e-mail altor utilizatori.',
+'mailnologintext' => 'Trebuie să fii [[Special:UserLogin|autentificat]] şi să ai o adresă validă de e-mail în [[Special:Preferences|preferinţe]] pentru a trimite e-mail altor utilizatori.',
 'emailuser'       => 'Trimite e-mail',
 'emailpage'       => 'E-mail către utilizator',
-'emailpagetext'   => 'Dacă acest utilizator a introdus o adresă de e-mail validă în pagina de preferinţe atunci formularul de mai jos poate fi folosit pentru a-i trimite un mesaj prin e-mail. Adresa pe care ai introdus-o în pagina ta de preferinţe va apărea ca adresa de origine a mesajului, astfel încât destinatarul să îţi poată răspunde direct.',
+'emailpagetext'   => 'Dacă acest utilizator a introdus o adresă de e-mail validă în pagina de preferinţe atunci formularul de mai jos poate fi folosit pentru a-i trimite un mesaj prin e-mail. Adresa pe care ai introdus-o în [[Special:Preferences|pagina ta de preferinţe]] va apărea ca adresa de origine a mesajului, astfel încât destinatarul să îţi poată răspunde direct.',
 'usermailererror' => 'Obiectul de mail a dat eroare:',
 'defemailsubject' => 'E-mail {{SITENAME}}',
 'noemailtitle'    => 'Fără adresă de e-mail',
@@ -1283,6 +1439,7 @@
 'emailccsubject'  => 'O copie a mesajului la $1: $2',
 'emailsent'       => 'E-mail trimis',
 'emailsenttext'   => 'E-mailul tău a fost trimis.',
+'emailuserfooter' => 'Acest mesaj a fost trimis de $1 către $2 prin intermediul funcţiei „Trimite e-mail” de la {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Pagini urmărite',
@@ -1291,9 +1448,9 @@
 'nowatchlist'          => 'Nu aţi ales să urmăriţi nici o pagină.',
 'watchlistanontext'    => 'Te rugăm să $1 pentru a vizualiza sau edita itemii de pe lista ta de urmărire.',
 'watchnologin'         => 'Nu sunteţi autentificat',
-'watchnologintext'     => 'Trebuie să fiţi [[Special:Userlogin|autentificat]] pentru a vă modifica lista de pagini urmărite.',
+'watchnologintext'     => 'Trebuie să fiţi [[Special:UserLogin|autentificat]] pentru a vă modifica lista de pagini urmărite.',
 'addedwatch'           => 'Adăugată la lista de pagini urmărite',
-'addedwatchtext'       => 'Pagina "[[:$1]]" a fost adăugată la lista ta de [[Special:Watchlist|articole urmărite]]. Modificările viitoare ale acestei pagini şi a paginii asociate de discuţii vor fi listate aici, şi în plus ele vor apărea cu <b>caractere îngroşate</b> în pagina de [[Special:Recentchanges|modificări recente]] pentru evidenţiere.
+'addedwatchtext'       => 'Pagina "[[:$1]]" a fost adăugată la lista ta de [[Special:Watchlist|articole urmărite]]. Modificările viitoare ale acestei pagini şi a paginii asociate de discuţii vor fi listate aici, şi în plus ele vor apărea cu <b>caractere îngroşate</b> în pagina de [[Special:RecentChanges|modificări recente]] pentru evidenţiere.
 
 Dacă doreşti să elimini această pagină din lista ta de pagini urmărite în viitor, apasă pe "Nu mai urmări" în bara de comenzi în timp ce această pagină este vizibilă.',
 'removedwatch'         => 'Ştearsă din lista de pagini urmărite',
@@ -1333,6 +1490,7 @@
 'created'                      => 'creat',
 'enotif_subject'               => 'Pagina $PAGETITLE de la {{SITENAME}} a fost $CHANGEDORCREATED de $PAGEEDITOR',
 'enotif_lastvisited'           => 'Vedeţi $1 pentru toate modificările de la ultima dvs. vizită.',
+'enotif_lastdiff'              => 'Apasă $1 pentru a vedea această schimbare.',
 'enotif_anon_editor'           => 'utilizator anonim $1',
 'enotif_body'                  => 'Domnule/Doamnă $WATCHINGUSERNAME,
 
@@ -1383,20 +1541,23 @@
 ** Violare drepturi de autor
 ** Vandalism',
 'delete-edit-reasonlist'      => 'Modifică motivele ştergerii',
+'delete-toobig'               => 'Această pagină are un istoric al modificărilor mare, mai mult de $1 {{PLURAL:$1|revizie|revizii}}.
+Ştergerea unei astfel de pagini a fost restricţionată pentru a preveni apariţia unor erori în {{SITENAME}}.',
 'rollback'                    => 'Editări de revenire',
 'rollback_short'              => 'Revenire',
 'rollbacklink'                => 'revenire',
 'rollbackfailed'              => 'Revenirea nu s-a putut face',
 'cantrollback'                => 'Nu se poate reveni; ultimul contribuitor este autorul acestui articol.',
-'alreadyrolled'               => 'Nu se poate reveni peste ultima modificare a articolului [[$1]]
-făcută de către [[User:$2|$2]] ([[User talk:$2|discuţie]]); altcineva a modificat articolul sau a revenit deja.
+'alreadyrolled'               => 'Nu se poate reveni peste ultima modificare a articolului [[:$1]] făcută de către [[User:$2|$2]] ([[User talk:$2|discuţie]]) | [[Special:Contributions/$2|{{int:contribslink}}]]); altcineva a modificat articolul sau a revenit deja.
 
-Ultima editare a fost făcută de către [[User:$3|$3]] ([[User talk:$3|discuţie]]).',
+Ultima editare a fost făcută de către [[User:$3|$3]] ([[User talk:$3|discuţie]]) | [[Special:Contributions/$3|{{int:contribslink}}]]).',
 'editcomment'                 => 'Comentariul de modificare a fost: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Anularea modificărilor efectuate de către [[Special:Contributions/$2|$2]] ([[User talk:$2|discuţie]]) şi revenire la ultima versiune de către [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'rollback-success'            => 'Anularea modificărilor făcute de $1;
+revenire la ultima versiune de $2.',
 'sessionfailure'              => 'Se pare că este o problemă cu sesiunea de autentificare; această acţiune a fost oprită ca o precauţie împotriva hijack. Apăsaţi "back" şi reîncărcaţi pagina de unde aţi venit, apoi reîncercaţi.',
 'protectlogpage'              => 'Jurnal protecţii',
-'protectlogtext'              => 'Mai jos se află lista de blocări/deblocări a paginilor. Vezi [[Special:Protectedpages]] pentru mai multe informaţii.',
+'protectlogtext'              => 'Mai jos se află lista de blocări/deblocări a paginilor. Vezi [[Special:ProtectedPages]] pentru mai multe informaţii.',
 'protectedarticle'            => 'a protejat "[[$1]]"',
 'modifiedarticleprotection'   => 'schimbat nivelul de protecţie pentru "[[$1]]"',
 'unprotectedarticle'          => 'a deprotejat "[[$1]]"',
@@ -1408,6 +1569,10 @@
 'protect_expiry_old'          => 'Timpul de expirare este în trecut.',
 'protect-unchain'             => 'Deblochează permisiunile de mutare',
 'protect-text'                => 'Poţi vizualiza sau modifica nivelul de protecţie pentru pagina <strong><nowiki>$1</nowiki></strong>.',
+'protect-locked-blocked'      => 'Nu poţi schimba nivelurile de protecţie fiind blocat.
+Iată configuraţia curentă a paginii <strong>$1</strong>:',
+'protect-locked-dblock'       => 'Nivelurile de protecţie nu pot fi aplicate deoarece baza de date este închisă.
+Iată configuraţia curentă a paginii <strong>$1</strong>:',
 'protect-locked-access'       => 'Contul dumneavoastră nu are dreptul de a schimba nivelurile de protejare.
 Aici sunt setările curente pentru pagina <strong>$1</strong>:',
 'protect-cascadeon'           => 'Această pagină este protejată deoarece este inclusă în {{PLURAL:$1|următoarea pagină, ce are|următoarele pagini ce au}} activată protejarea la modificare în cascadă.
@@ -1438,34 +1603,46 @@
 'restriction-level-all'           => 'orice nivel',
 
 # Undelete
-'undelete'                 => 'Recuperează pagina ştearsă',
-'undeletepage'             => 'Vizualizează şi recuperează pagini şterse',
-'viewdeletedpage'          => 'Vezi paginile şterse',
-'undeletepagetext'         => 'Următoarele pagini au fost şterse, dar încă se află în arhivă şi pot fi recuperate. Reţine că arhiva se poate şterge din timp în timp.',
-'undelete-fieldset-title'  => 'Recuperează versiuni',
-'undeleteextrahelp'        => "Pentru a recupera întreaga pagină lăsaţi toate căsuţele nebifate şi apăsaţi butonul '''''Recuperează'''''. Pentru a realiza o recuperare selectivă bifaţi versiunile pe care doriţi să le recuperaţi şi apăsaţi butonul '''''Recuperează'''''. Butonul '''''Resetează'''''  va şterge comentariul şi toate bifările.",
-'undeleterevisions'        => '$1 {{PLURAL:$1|versiune arhivată|versiuni arhivate}}',
-'undeletehistory'          => 'Dacă recuperaţi pagina, toate versiunile asociate vor fi adăugate retroactiv în istorie. Dacă o pagină nouă cu acelaşi nume a fost creată de la momentul ştergerii acesteia, versiunile recuperate vor apărea în istoria paginii, iar versiunea curentă a paginii nu va fi înlocuită automat de către versiunea recuperată.',
-'undeletehistorynoadmin'   => 'Acest articol a fost şters. Motivul ştergerii apare mai jos, alături de detaliile utilzatorilor care au editat această pagină înainte de ştergere. Textul prorpiu-zis al reviziilor şterse este disponibil doar administratorilor.',
-'undelete-revision'        => 'Ştergere revizia $1 (din $2) de către $3:',
-'undelete-nodiff'          => 'Nu s-a găsit vreo revizie anterioară.',
-'undeletebtn'              => 'Recuperează',
-'undeletelink'             => 'recuperează',
-'undeletereset'            => 'Resetează',
-'undeletecomment'          => 'Comentariu:',
-'undeletedarticle'         => '"[[$1]]" a fost recuperat',
-'undeletedrevisions'       => '{{PLURAL:$1|o revizie restaurată|$1 revizii restaurate}}',
-'undeletedrevisions-files' => '$1 {{PLURAL:$1|revizie|revizii}} şi $2 {{PLURAL:$2|fişier|fişiere}} recuperate',
-'undeletedfiles'           => '$1 {{PLURAL:$1|revizie recuperată|revizii recuperate}}',
-'cannotundelete'           => 'Recuperarea a eşuat; este posibil ca altcineva să fi recuperat pagina deja.',
-'undeletedpage'            => "<big>'''$1 a fost recuperat'''</big>
+'undelete'                     => 'Recuperează pagina ştearsă',
+'undeletepage'                 => 'Vizualizează şi recuperează pagini şterse',
+'undeletepagetitle'            => "'''Această listă cuprinde versiuni şterse ale paginii [[:$1|$1]].'''",
+'viewdeletedpage'              => 'Vezi paginile şterse',
+'undeletepagetext'             => 'Următoarele pagini au fost şterse, dar încă se află în arhivă şi pot fi recuperate. Reţine că arhiva se poate şterge din timp în timp.',
+'undelete-fieldset-title'      => 'Recuperează versiuni',
+'undeleteextrahelp'            => "Pentru a recupera întreaga pagină lăsaţi toate căsuţele nebifate şi apăsaţi butonul '''''Recuperează'''''. Pentru a realiza o recuperare selectivă bifaţi versiunile pe care doriţi să le recuperaţi şi apăsaţi butonul '''''Recuperează'''''. Butonul '''''Resetează'''''  va şterge comentariul şi toate bifările.",
+'undeleterevisions'            => '$1 {{PLURAL:$1|versiune arhivată|versiuni arhivate}}',
+'undeletehistory'              => 'Dacă recuperaţi pagina, toate versiunile asociate vor fi adăugate retroactiv în istorie. Dacă o pagină nouă cu acelaşi nume a fost creată de la momentul ştergerii acesteia, versiunile recuperate vor apărea în istoria paginii, iar versiunea curentă a paginii nu va fi înlocuită automat de către versiunea recuperată.',
+'undeleterevdel'               => 'Restaurarea unui revizii nu va fi efectuată dacă ea va apărea în capul listei de revizii parţial şterse.
+În acest caz, trebuie să debifezi sau să arăţi (unhide) cea mai recentă versiune ştearsă.',
+'undeletehistorynoadmin'       => 'Acest articol a fost şters. Motivul ştergerii apare mai jos, alături de detaliile utilzatorilor care au editat această pagină înainte de ştergere. Textul prorpiu-zis al reviziilor şterse este disponibil doar administratorilor.',
+'undelete-revision'            => 'Ştergere revizia $1 (din $2) de către $3:',
+'undeleterevision-missing'     => 'Revizie lipsă sau invalidă.
+S-ar putea ca această legătură să fie greşită, sau revizia a fost restaurată ori ştearsă din arhivă.',
+'undelete-nodiff'              => 'Nu s-a găsit vreo revizie anterioară.',
+'undeletebtn'                  => 'Recuperează',
+'undeletelink'                 => 'recuperează',
+'undeletereset'                => 'Resetează',
+'undeletecomment'              => 'Comentariu:',
+'undeletedarticle'             => '"[[$1]]" a fost recuperat',
+'undeletedrevisions'           => '{{PLURAL:$1|o revizie restaurată|$1 revizii restaurate}}',
+'undeletedrevisions-files'     => '$1 {{PLURAL:$1|revizie|revizii}} şi $2 {{PLURAL:$2|fişier|fişiere}} recuperate',
+'undeletedfiles'               => '$1 {{PLURAL:$1|revizie recuperată|revizii recuperate}}',
+'cannotundelete'               => 'Recuperarea a eşuat; este posibil ca altcineva să fi recuperat pagina deja.',
+'undeletedpage'                => "<big>'''$1 a fost recuperat'''</big>
 
 Consultaţi [[Special:Log/delete|raportul ştergerilor]] pentru a vedea toate ştergerile şi recuperările recente.",
-'undelete-header'          => 'Vezi [[Special:Log/delete|logul de ştergere]] pentru paginile şterse recent.',
-'undelete-search-box'      => 'Caută pagini şterse',
-'undelete-search-prefix'   => 'Arată paginile care încep cu:',
-'undelete-search-submit'   => 'Caută',
-'undelete-error-long'      => 'S-au găsit erori la ştergerea fişierului:
+'undelete-header'              => 'Vezi [[Special:Log/delete|logul de ştergere]] pentru paginile şterse recent.',
+'undelete-search-box'          => 'Caută pagini şterse',
+'undelete-search-prefix'       => 'Arată paginile care încep cu:',
+'undelete-search-submit'       => 'Caută',
+'undelete-no-results'          => 'Nicio pagină potrivită nu a fost găsită în arhiva paginilor şterse.',
+'undelete-filename-mismatch'   => 'Nu poate fi restaurată revizia fişierului din data $1: nume nepotrivit',
+'undelete-bad-store-key'       => 'Nu poate fi restaurată revizia fişierului din data $1: fişierul lipsea înainte de ştergere.',
+'undelete-cleanup-error'       => 'Eroare la ştergerea arhivei nefolosite "$1".',
+'undelete-missing-filearchive' => 'Nu poate fi restaurată arhiva fişierul cu ID-ul $1 pentru că nu există în baza de date.
+S-ar putea ca ea să fie deja restaurată.',
+'undelete-error-short'         => 'Eroare la restaurarea fişierului: $1',
+'undelete-error-long'          => 'S-au găsit erori la ştergerea fişierului:
 
 $1',
 
@@ -1491,20 +1668,23 @@
 'sp-contributions-submit'      => 'Caută',
 
 # What links here
-'whatlinkshere'           => 'Ce se leagă aici',
-'whatlinkshere-title'     => 'Pagini care se leagă de $1',
-'whatlinkshere-page'      => 'Pagină:',
-'linklistsub'             => '(Lista de legături)',
-'linkshere'               => "Următoarele pagini conţin legături către '''[[:$1]]''':",
-'nolinkshere'             => "Nici o pagină nu se leagă la '''[[:$1]]'''.",
-'nolinkshere-ns'          => "Nici o pagină din spaţiul de nume ales nu se leagă la '''[[:$1]]'''.",
-'isredirect'              => 'pagină de redirecţionare',
-'istemplate'              => 'prin includerea formatului',
-'whatlinkshere-prev'      => '{{PLURAL:$1|anterioara|anterioarele $1}}',
-'whatlinkshere-next'      => '{{PLURAL:$1|următoarea|urmatoarele $1}}',
-'whatlinkshere-links'     => '← legături',
-'whatlinkshere-hidelinks' => '$1 legături',
-'whatlinkshere-filters'   => 'Filtre',
+'whatlinkshere'            => 'Ce se leagă aici',
+'whatlinkshere-title'      => 'Pagini care se leagă de "$1"',
+'whatlinkshere-page'       => 'Pagină:',
+'linklistsub'              => '(Lista de legături)',
+'linkshere'                => "Următoarele pagini conţin legături către '''[[:$1]]''':",
+'nolinkshere'              => "Nici o pagină nu se leagă la '''[[:$1]]'''.",
+'nolinkshere-ns'           => "Nici o pagină din spaţiul de nume ales nu se leagă la '''[[:$1]]'''.",
+'isredirect'               => 'pagină de redirecţionare',
+'istemplate'               => 'prin includerea formatului',
+'isimage'                  => 'legătura fişierului',
+'whatlinkshere-prev'       => '{{PLURAL:$1|anterioara|anterioarele $1}}',
+'whatlinkshere-next'       => '{{PLURAL:$1|următoarea|urmatoarele $1}}',
+'whatlinkshere-links'      => '← legături',
+'whatlinkshere-hideredirs' => '$1 redirecturile',
+'whatlinkshere-hidetrans'  => '$1 transcluderile',
+'whatlinkshere-hidelinks'  => '$1 legături',
+'whatlinkshere-filters'    => 'Filtre',
 
 # Block/unblock
 'blockip'                     => 'Blochează utilizator / IP',
@@ -1534,10 +1714,12 @@
 'ipboptions'                  => '15 minute:15 minutes,1 oră:1 hour,3 ore:3 hours,24 ore:24 hours,48 ore:48 hours,1 săptămână:1 week,1 lună:1 month,nelimitat:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'              => 'altul',
 'ipbotherreason'              => 'Alt motiv sau suplimentar:',
+'ipbhidename'                 => 'Ascunde numele de utilizator din jurnalul blocărilor, lista activă a blocărilor şi lista utilizatorilor',
+'ipbwatchuser'                => 'Urmăreşte pagina sa de utilizator şi de discuţii',
 'badipaddress'                => 'Adresa IP este invalidă.',
 'blockipsuccesssub'           => 'Utilizatorul a fost blocat',
 'blockipsuccesstext'          => 'Adresa IP "$1" a fost blocată.
-<br />Vezi [[Special:Ipblocklist|lista de adrese IP şi conturi blocate]] pentru a revizui adresele blocate.',
+<br />Vezi [[Special:IPBlockList|lista de adrese IP şi conturi blocate]] pentru a revizui adresele blocate.',
 'ipb-edit-dropdown'           => 'Modifică motivele blocării',
 'ipb-unblock-addr'            => 'Deblochează $1',
 'ipb-unblock'                 => 'Deblochează un cont de utilizator sau o adresă IP',
@@ -1548,7 +1730,8 @@
 drepturile de scriere pentru o adresă IP blocată anterior..',
 'ipusubmit'                   => 'Deblochează adresa',
 'unblocked'                   => '[[User:$1|$1]] a fost deblocat',
-'ipblocklist'                 => 'Lista de adrese IP şi conturi blocate',
+'unblocked-id'                => 'Blocarea $1 a fost eliminată',
+'ipblocklist'                 => 'Lista adreselor IP şi a conturilor blocate',
 'ipblocklist-legend'          => 'Găseşte un utilizator blocat',
 'ipblocklist-username'        => 'Nume de utilizator sau adresă IP:',
 'ipblocklist-submit'          => 'Caută',
@@ -1560,13 +1743,14 @@
 'createaccountblock'          => 'crearea de conturi blocată',
 'emailblock'                  => 'e-mail blocat',
 'ipblocklist-empty'           => 'Lista blocărilor este goală.',
+'ipblocklist-no-results'      => 'Nu există blocare pentru adresa IP sau numele de utilizator.',
 'blocklink'                   => 'blochează',
 'unblocklink'                 => 'deblochează',
 'contribslink'                => 'contribuţii',
 'autoblocker'                 => 'Autoblocat fiindcă foloseşti aceeaşi adresă IP ca şi "$1". Motivul este "$2".',
 'blocklogpage'                => 'Jurnal blocări',
 'blocklogentry'               => 'a blocat "[[$1]]" pe o perioadă de $2 $3',
-'blocklogtext'                => 'Acesta este un raport al acţiunilor de blocare şi deblocare. Adresele IP blocate automat nu sunt afişate. Vizitaţi [[Special:Ipblocklist|lista de adrese blocate]] pentru o listă explicită a adreselor blocate în acest moment.',
+'blocklogtext'                => 'Acesta este un raport al acţiunilor de blocare şi deblocare. Adresele IP blocate automat nu sunt afişate. Vizitaţi [[Special:IPBlockList|lista de adrese blocate]] pentru o listă explicită a adreselor blocate în acest moment.',
 'unblocklogentry'             => 'a deblocat $1',
 'block-log-flags-anononly'    => 'doar utilizatorii anonimi',
 'block-log-flags-nocreate'    => 'creare de conturi dezactivată',
@@ -1576,7 +1760,10 @@
 'ipb_expiry_invalid'          => 'Dată de expirare invalidă.',
 'ipb_already_blocked'         => '"$1" este deja blocat',
 'ipb_cant_unblock'            => 'Eroare: nu găsesc identificatorul $1. Probabil a fost deja deblocat.',
+'ipb_blocked_as_range'        => 'Eroare: Adresa IP $1 nu este blocată direct deci nu poate fi deblocată.
+Face parte din area de blocare $2, care nu poate fi deblocată.',
 'ip_range_invalid'            => 'Serie IP invalidă.',
+'blockme'                     => 'Blochează-mă',
 'proxyblocker'                => 'Blocaj de proxy',
 'proxyblocker-disabled'       => 'Această funcţie este dezactivată.',
 'proxyblockreason'            => 'Adresa ta IP a fost blocată pentru că este un proxy deschis. Te rog, contactează provider-ul tău de servicii Internet sau tehnicieni IT şi informează-i asupra acestei probleme serioase de securitate.',
@@ -1604,18 +1791,19 @@
 'lockdbsuccesstext'   => 'Baza de date {{SITENAME}} a fost blocată la scriere.<br />
 Nu uita să o deblochezi după ce termini operaţiunile administrative pentru care ai blocat-o.',
 'unlockdbsuccesstext' => 'Baza de date a fost deblocată.',
+'lockfilenotwritable' => 'Fişierul bazei de date închise nu poate fi scris.
+Pentru a închide sau deschide baza de date, acesta trebuie să poată fi scris de serverul web.',
 'databasenotlocked'   => 'Baza de date nu este blocată.',
 
 # Move page
 'move-page'               => 'Mută $1',
 'move-page-legend'        => 'Mută pagina',
-'movepagetext'            => "Puteţi folosi formularul de mai jos pentru a redenumi
-o pagină, mutându-i toată istoria sub noul nume.
+'movepagetext'            => "Puteţi folosi formularul de mai jos pentru a redenumi o pagină, mutându-i toată istoria sub noul nume.
 Pagina veche va deveni o pagină de redirecţionare către pagina nouă.
 Legăturile către pagina veche nu vor fi redirecţionate către cea nouă;
-nu uitaţi să verificaţi dacă nu există redirecţionări duble sau invalide.
+nu uitaţi să verificaţi dacă nu există redirecţionări [[Special:DoubleRedirects|duble]] sau [[Special:BrokenRedirects|invalide]].
 
-Te rugăm să reţineţi că sunteţi responsabil(ă) pentru a face legăturile vechi să rămână valide.
+Vă rugăm să reţineţi că sunteţi responsabil(ă) pentru a face legăturile vechi să rămână valide.
 
 Reţineţi că pagina '''nu va fi mutată''' dacă există deja o pagină cu noul titlu, în afară de cazul că este complet goală sau este
 o redirecţionare şi în plus nu are nici o istorie de modificare.
@@ -1633,18 +1821,20 @@
 În oricare din cazurile de mai sus va trebui să muţi sau să unifici
 manual paginile de discuţii, dacă doreşti acest lucru.",
 'movearticle'             => 'Mută pagina',
-'movenologin'             => 'Nu eşti autentificat',
-'movenologintext'         => 'Trebuie să fii un utilizator înregistrat şi să te [[Special:Userlogin|autentifici]] pentru a muta o pagină.',
+'movenotallowed'          => 'Nu ai permisiunea să muţi pagini în {{SITENAME}}.',
 'newtitle'                => 'Titlul nou',
 'move-watch'              => 'Urmăreşte această pagină',
 'movepagebtn'             => 'Mută pagina',
 'pagemovedsub'            => 'Pagina a fost mutată',
 'movepage-moved'          => '<big>\'\'\'Pagina "$1" a fost mutată la pagina "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'O pagină cu acelaşi nume există deja, sau numele pe care l-ai ales este invalid. Te rugăm să alegi un alt nume.',
+'cantmove-titleprotected' => 'Nu poţi muta o pagina în această locaţie, pentru că noul titlu a fost protejat la creare',
 'talkexists'              => "'''Pagina în sine a fost mutată, dar pagina de discuţii nu a putut fi mutată deoarece deja există o alta cu acelaşi nume. Te rugăm să unifici manual cele două pagini de discuţii.'''",
 'movedto'                 => 'mutată la',
 'movetalk'                => 'Mută şi pagina de "discuţii" dacă se poate.',
 'move-subpages'           => 'Mută toate subpaginile, dacă este nevoie',
+'move-talk-subpages'      => 'Mută toate subpaginile paginii de discuţii, dacă se poate',
+'movepage-page-exists'    => 'Pagina $1 există deja şi nu poate fi rescrisă automat.',
 'movepage-page-moved'     => 'Pagina $1 a fost mutată la $2.',
 'movepage-page-unmoved'   => 'Pagina $1 nu a putut fi mutată la $2.',
 '1movedto2'               => 'a mutat [[$1]] la [[$2]]',
@@ -1656,11 +1846,15 @@
 'delete_and_move'         => 'Şterge şi mută',
 'delete_and_move_text'    => '==Ştergere necesară==
 
-Articolul de destinaţie "[[$1]]" există deja. Doriţi să îl ştergeţi pentru a face loc mutării?',
+Articolul de destinaţie "[[:$1]]" există deja. Doriţi să îl ştergeţi pentru a face loc mutării?',
 'delete_and_move_confirm' => 'Da, şterge pagina.',
 'delete_and_move_reason'  => 'Şters pentru a face loc mutării',
 'selfmove'                => 'Titlurile sursei şi ale destinaţiei sunt aceleaşi; nu puteţi muta o pagină peste ea însăşi.',
 'immobile_namespace'      => 'Titlul destinaţiei este al unui tip special; nu se pot muta pagini în acel spaţiu de nume.',
+'imagenocrossnamespace'   => 'Fişierul nu poate fi mutat la un spaţiu de nume care nu este destinat fişierelor',
+'imagetypemismatch'       => 'Extensia nouă a fişierului nu se potriveşte cu tipul acestuia',
+'imageinvalidfilename'    => 'Numele fişierului destinaţie este invalid',
+'fix-double-redirects'    => 'Actualizează toate redirecţionările care trimit la titlul original',
 
 # Export
 'export'            => 'Exportă pagini',
@@ -1670,6 +1864,7 @@
 'export-submit'     => 'Exportă',
 'export-addcattext' => 'Adaugă pagini din categoria:',
 'export-addcat'     => 'Adaugă',
+'export-download'   => 'Salvează ca fişier',
 'export-templates'  => 'Include formate',
 
 # Namespace 8 related
@@ -1684,9 +1879,13 @@
 'allmessagesmodified'       => 'Arată doar mesajele modificate.',
 
 # Thumbnails
-'thumbnail-more'  => 'Extinde',
-'filemissing'     => 'Fişier lipsă',
-'thumbnail_error' => 'Eroare la generarea previzualizării: $1',
+'thumbnail-more'           => 'Extinde',
+'filemissing'              => 'Fişier lipsă',
+'thumbnail_error'          => 'Eroare la generarea previzualizării: $1',
+'djvu_page_error'          => 'Numărul paginii DjVu eronat',
+'djvu_no_xml'              => 'Imposibil de obţinut XML-ul pentru fişierul DjVu',
+'thumbnail_invalid_params' => 'Parametrii invalizi ai imaginii miniatură',
+'thumbnail_dest_directory' => 'Nu poate fi creat directorul destinaţie',
 
 # Special:Import
 'import'                     => 'Importă pagini',
@@ -1695,7 +1894,8 @@
 'import-interwiki-history'   => 'Copiază toate versiunile istoricului acestei pagini',
 'import-interwiki-submit'    => 'Importă',
 'import-interwiki-namespace' => 'Transferă paginile la spaţiul de nume:',
-'importtext'                 => 'Te rog exportă fişierul din sursa wiki folosind funcţia Special:Export, salvează-l pe discul tău şi trimite-l aici.',
+'importtext'                 => 'Te rog exportă fişierul din sursa wiki folosind [[Special:Export|utilitarul de exportare]].
+Salvează-l pe discul tău şi trimite-l aici.',
 'importstart'                => 'Se importă paginile...',
 'import-revision-count'      => '$1 {{PLURAL:$1|versiune|versiuni}}',
 'importnopages'              => 'Nu există pagini de importat.',
@@ -1708,6 +1908,14 @@
 'importhistoryconflict'      => 'Există istorii contradictorii (se poate să fi importat această pagină înainte)',
 'importnosources'            => 'Nici o sursă de import transwiki a fost definită şi încărcările directe ale istoricului sunt oprite.',
 'importnofile'               => 'Nici un fişier pentru import nu a fost încărcat.',
+'importuploaderrorsize'      => 'Încărcarea fişierului a eşuat.
+Fişierul are o mărime mai mare decât limita de încărcare permisă.',
+'importuploaderrorpartial'   => 'Încărcarea fişierului a eşuat.
+Fişierul a fost incărcat parţial.',
+'importuploaderrortemp'      => 'Încărcarea fişierului a eşuat.
+Un dosar temporar lipseşte.',
+'import-parse-failure'       => 'Eroare la analiza importului XML',
+'import-noarticle'           => 'Nicio pagină de importat!',
 'import-nonewrevisions'      => 'Toate versiunile au fost importate anterior.',
 'xml-error-string'           => '$1 la linia $2, col $3 (octet $4): $5',
 'import-upload'              => 'Încarcă date XML',
@@ -1743,6 +1951,8 @@
 'tooltip-ca-watch'                => 'Adaugă acest document în lista ta de monitorizare.',
 'tooltip-ca-unwatch'              => 'Şterge acest document din lista ta de monitorizare.',
 'tooltip-search'                  => 'Căutare în {{SITENAME}}',
+'tooltip-search-go'               => 'Du-te la pagina cu acest nume dacă există',
+'tooltip-search-fulltext'         => 'Caută paginile pentru acest text',
 'tooltip-p-logo'                  => 'Pagina principală',
 'tooltip-n-mainpage'              => 'Vizitează pagina principală',
 'tooltip-n-portal'                => 'Despre proiect, ce poţi face tu, unde găseşti soluţii.',
@@ -1759,6 +1969,7 @@
 'tooltip-t-upload'                => 'Încarcă fişiere',
 'tooltip-t-specialpages'          => 'Lista tuturor paginilor speciale',
 'tooltip-t-print'                 => 'Versiunea de tipărit a acestei pagini',
+'tooltip-t-permalink'             => 'Legătura permanentă către această versiune a paginii',
 'tooltip-ca-nstab-main'           => 'Vezi articolul',
 'tooltip-ca-nstab-user'           => 'Vezi pagina de utilizator',
 'tooltip-ca-nstab-media'          => 'Vezi pagina media',
@@ -1833,14 +2044,22 @@
 'markedaspatrollederror-noautopatrol' => 'Nu puteţi marca propriile modificări ca patrulate.',
 
 # Patrol log
-'patrol-log-page' => 'Jurnal patrulări',
-'patrol-log-auto' => '(automat)',
+'patrol-log-page'   => 'Jurnal patrulări',
+'patrol-log-header' => 'Mai jos apare o listă a tuturor paginilor marcate ca verificate.',
+'patrol-log-line'   => 'a marcat versiunea $1 a $2 ca verificată $3',
+'patrol-log-auto'   => '(automat)',
 
 # Image deletion
-'deletedrevision'       => 'A fost ştearsă vechea revizie $1.',
-'filedeleteerror-short' => 'Eroare la ştergerea fişierului: $1',
-'filedelete-missing'    => 'Fişierul "$1" nu poate fi şters, deoarece nu există.',
+'deletedrevision'                 => 'A fost ştearsă vechea revizie $1.',
+'filedeleteerror-short'           => 'Eroare la ştergerea fişierului: $1',
+'filedeleteerror-long'            => 'Au apărut erori când se încerca ştergerea fişierului:
 
+$1',
+'filedelete-missing'              => 'Fişierul "$1" nu poate fi şters, deoarece nu există.',
+'filedelete-old-unregistered'     => 'Revizia specificată a fişierului "$1" nu este în baza de date.',
+'filedelete-current-unregistered' => 'Fişierul specificat "$1" nu este în baza de date.',
+'filedelete-archive-read-only'    => 'Directorul arhivei "$1" nu poate fi scris de serverul web.',
+
 # Browsing diffs
 'previousdiff' => '← Diferenţa anterioară',
 'nextdiff'     => 'Diferenţa următoare →',
@@ -1858,9 +2077,10 @@
 'show-big-image'       => 'Măreşte rezoluţia imaginii',
 'show-big-image-thumb' => '<small>Mărimea acestei previzualizări: $1 × $2 pixeli</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galeria de imagini noi',
 'imagelisttext'         => "Mai jos se află lista a '''$1''' {{PLURAL:$1|fişier ordonat|fişiere ordonate}} $2.",
+'newimages-summary'     => 'Această pagină specială arată ultimele fişiere încărcate.',
 'showhidebots'          => '($1 roboţi)',
 'noimages'              => 'Nimic de văzut.',
 'ilsubmit'              => 'Caută',
@@ -1905,11 +2125,13 @@
 'exif-yresolution'                 => 'Rezoluţie verticală',
 'exif-resolutionunit'              => 'Unitate de rezoluţie pentru X şi Y',
 'exif-stripoffsets'                => 'Locaţia datelor imaginii',
+'exif-rowsperstrip'                => 'Numărul de linii per bandă',
 'exif-stripbytecounts'             => 'Biţi corespunzători benzii comprimate',
 'exif-jpeginterchangeformat'       => 'Offset pentru JPEG SOI',
 'exif-jpeginterchangeformatlength' => 'Biţi de date JPEG',
 'exif-transferfunction'            => 'Funcţia de transfer',
 'exif-whitepoint'                  => 'Cromaticitatea punctului alb',
+'exif-primarychromaticities'       => 'Coordonatele cromatice ale culorilor primare',
 'exif-ycbcrcoefficients'           => 'Tăria culorii coeficienţilor matricei de transformare',
 'exif-referenceblackwhite'         => 'Perechile de valori de referinţă albe şi negre',
 'exif-datetime'                    => 'Data şi ora modificării fişierului',
@@ -1945,6 +2167,7 @@
 'exif-aperturevalue'               => 'Diafragmă',
 'exif-brightnessvalue'             => 'Luminozitate',
 'exif-exposurebiasvalue'           => 'Ajustarea expunerii',
+'exif-maxaperturevalue'            => 'Apertura maximă',
 'exif-subjectdistance'             => 'Distanţa faţă de subiect',
 'exif-meteringmode'                => 'Forma de măsurare',
 'exif-lightsource'                 => 'Sursă de lumină',
@@ -1973,6 +2196,7 @@
 'exif-saturation'                  => 'Saturaţie',
 'exif-sharpness'                   => 'Ascuţime',
 'exif-devicesettingdescription'    => 'Descrierea reglajelor aparatului',
+'exif-subjectdistancerange'        => 'Distanţa faţă de subiect',
 'exif-imageuniqueid'               => 'Identificarea imaginii unice',
 'exif-gpsversionid'                => 'Versiunea de conversie GPS',
 'exif-gpslatituderef'              => 'Latitudine nordică sau sudică',
@@ -2039,6 +2263,7 @@
 
 'exif-meteringmode-0'   => 'Necunoscut',
 'exif-meteringmode-1'   => 'Medie',
+'exif-meteringmode-2'   => 'Media ponderată la centru',
 'exif-meteringmode-3'   => 'Punct',
 'exif-meteringmode-4'   => 'MultiPunct',
 'exif-meteringmode-5'   => 'Model',
@@ -2138,7 +2363,7 @@
 
 # External editor support
 'edit-externally'      => 'Editează acest fişier folosind o aplicaţie externă.',
-'edit-externally-help' => 'Vedeţi [http://meta.wikimedia.org/wiki/Help:External_editors instrucţiuni de instalare] pentru mai multe informaţii.',
+'edit-externally-help' => 'Vedeţi [http://www.mediawiki.org/wiki/Manual:External_editors instrucţiuni de instalare] pentru mai multe informaţii.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tot',
@@ -2148,23 +2373,25 @@
 'monthsall'        => 'toate',
 
 # E-mail address confirmation
-'confirmemail'            => 'Confirmă adresa de email',
-'confirmemail_noemail'    => 'Nu aveţi o adresă de email validă setată la [[Special:Preferences|preferinţe]].',
-'confirmemail_text'       => 'Acest wiki necesită validarea adresei de email înaintea folosirii funcţiilor email. Apăsaţi butonul de dedesupt pentru a trimite un email de confirmare către adresa dvs. Acesta va include o legătură care va conţine codul; încărcaţi legătura în browser pentru a valida adresa de email.',
-'confirmemail_send'       => 'Trimite un cod de confirmare',
-'confirmemail_sent'       => 'E-mailul de confirmare a fost trimis.',
-'confirmemail_oncreate'   => 'Un cod de confirmare a fost trimis la adresa de e-mail.
+'confirmemail'             => 'Confirmă adresa de email',
+'confirmemail_noemail'     => 'Nu aveţi o adresă de email validă setată la [[Special:Preferences|preferinţe]].',
+'confirmemail_text'        => 'Acest wiki necesită validarea adresei de email înaintea folosirii funcţiilor email. Apăsaţi butonul de dedesupt pentru a trimite un email de confirmare către adresa dvs. Acesta va include o legătură care va conţine codul; încărcaţi legătura în browser pentru a valida adresa de email.',
+'confirmemail_pending'     => '<div class="error">Un cod de confirmare a fost trimis deja prin e-mail către tine;
+dacă ai creat recent contul, aşteaptă câteva minute să ajungă la tine înainte de a cere un nou cod.</div>',
+'confirmemail_send'        => 'Trimite un cod de confirmare',
+'confirmemail_sent'        => 'E-mailul de confirmare a fost trimis.',
+'confirmemail_oncreate'    => 'Un cod de confirmare a fost trimis la adresa de e-mail.
 Acest cod nu este necesar pentru autentificare, dar trebuie transmis înainte de activarea oricăror proprietăţi bazate pe e-mail din wiki.',
-'confirmemail_sendfailed' => 'Nu am putut trimite e-mailul de confirmare. Verificaţi adresa după caractere invalide.
+'confirmemail_sendfailed'  => 'Nu am putut trimite e-mailul de confirmare. Verificaţi adresa după caractere invalide.
 
 Serverul de mail a returnat: $1',
-'confirmemail_invalid'    => 'Cod de confirmare invalid. Acest cod poate fi expirat.',
-'confirmemail_needlogin'  => 'Trebuie să vă $1 pentru a vă confirma adresa de email.',
-'confirmemail_success'    => 'Adresa de email a fost confirmată. Vă puteţi autentifica şi bucura de wiki.',
-'confirmemail_loggedin'   => 'Adresa de email a fost confirmată.',
-'confirmemail_error'      => 'Ceva nu a funcţionat la salvarea confirmării.',
-'confirmemail_subject'    => 'Confirmare adresă email la {{SITENAME}}',
-'confirmemail_body'       => 'Cineva, probabil dumneavoastră de la adresa IP $1, şi-a înregistrat un cont "$2" cu această adresă de email la {{SITENAME}}.
+'confirmemail_invalid'     => 'Cod de confirmare invalid. Acest cod poate fi expirat.',
+'confirmemail_needlogin'   => 'Trebuie să vă $1 pentru a vă confirma adresa de email.',
+'confirmemail_success'     => 'Adresa de email a fost confirmată. Vă puteţi autentifica şi bucura de wiki.',
+'confirmemail_loggedin'    => 'Adresa de email a fost confirmată.',
+'confirmemail_error'       => 'Ceva nu a funcţionat la salvarea confirmării.',
+'confirmemail_subject'     => 'Confirmare adresă email la {{SITENAME}}',
+'confirmemail_body'        => 'Cineva, probabil dumneavoastră de la adresa IP $1, şi-a înregistrat un cont "$2" cu această adresă de email la {{SITENAME}}.
 
 Pentru a confirma că acest cont aparţine într-adevăr dumneavoastră şi să vă activaţi funcţionalităţile email la {{SITENAME}}, deschideţi această legătură în browser:
 
@@ -2175,6 +2402,8 @@
 $5
 
 Codul de confirmare va expira la $4.',
+'confirmemail_invalidated' => 'Confirmarea adresei de e-mail a fost anulată',
+'invalidateemail'          => 'Anulează confirmarea adresei de e-mail',
 
 # Scary transclusion
 'scarytranscludedisabled' => '[Transcluderea interwiki este dezactivată]',
@@ -2198,7 +2427,7 @@
 'recreate'            => 'Recreează',
 
 # HTML dump
-'redirectingto' => 'Redirecţionând la [[$1]]...',
+'redirectingto' => 'Redirecţionând la [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Doriţi să reîncărcaţi pagina? $1',
@@ -2214,14 +2443,19 @@
 # Multipage image navigation
 'imgmultipageprev' => '← pagina anterioară',
 'imgmultipagenext' => 'pagina următoare →',
+'imgmultigo'       => 'Du-te!',
+'imgmultigoto'     => 'Du-te la pagina $1',
 
 # Table pager
-'table_pager_next'  => 'Pagina următoare',
-'table_pager_prev'  => 'Pagina anterioară',
-'table_pager_first' => 'Prima pagină',
-'table_pager_last'  => 'Ultima pagină',
-'table_pager_limit' => 'Arată $1 itemi pe pagină',
-'table_pager_empty' => 'Nici un rezultat',
+'ascending_abbrev'         => 'cresc',
+'descending_abbrev'        => 'desc',
+'table_pager_next'         => 'Pagina următoare',
+'table_pager_prev'         => 'Pagina anterioară',
+'table_pager_first'        => 'Prima pagină',
+'table_pager_last'         => 'Ultima pagină',
+'table_pager_limit'        => 'Arată $1 itemi pe pagină',
+'table_pager_limit_submit' => 'Du-te',
+'table_pager_empty'        => 'Nici un rezultat',
 
 # Auto-summaries
 'autosumm-blank'   => 'Şters conţinutul paginii',
@@ -2232,46 +2466,91 @@
 # Live preview
 'livepreview-loading' => 'Încărcare…',
 'livepreview-ready'   => 'Încărcare… Gata!',
+'livepreview-failed'  => 'Previzualizarea directă a eşuat! Încearcă previzualizarea normală.',
+'livepreview-error'   => 'Conectarea a eşuat: $1 "$2".
+Încearcă previzualizarea normală.',
 
+# Friendlier slave lag warnings
+'lag-warn-normal' => 'Modificările mai noi de $1 {{PLURAL:$1|secondă|seconde}} pot să nu apară în listă.',
+'lag-warn-high'   => 'Serverul bazei de date este suprasolicitat, astfel încît modificările făcute în ultimele $1 {{PLURAL:$1|secundă|secunde}} pot să nu apară în listă.',
+
 # Watchlist editor
-'watchlistedit-normal-title'  => 'Editează lista de urmărire',
-'watchlistedit-normal-legend' => 'Şterge titluri din lista de urmărire',
-'watchlistedit-normal-submit' => 'Şterge Titluri',
-'watchlistedit-normal-done'   => '{{PLURAL:$1|1 titlu a fost şters|$1 titluri au fost şterse}} din lista de urmărire:',
-'watchlistedit-raw-titles'    => 'Titluri:',
-'watchlistedit-raw-added'     => '{{PLURAL:$1|1 titlu a fost adăugat|$1 titluri au fost adăugate}}:',
-'watchlistedit-raw-removed'   => '{{PLURAL:$1|1 titlu a fost şters|$1 titluri au fost şterse}}:',
+'watchlistedit-numitems'       => 'Lista ta de pagini urmărite conţine {{PLURAL:$1|1 titlu|$1 titluri}}, excluzând paginile de discuţii.',
+'watchlistedit-noitems'        => 'Lista ta de pagini urmărite nu conţine titluri.',
+'watchlistedit-normal-title'   => 'Editează lista de urmărire',
+'watchlistedit-normal-legend'  => 'Şterge titluri din lista de urmărire',
+'watchlistedit-normal-explain' => 'Titlurile din lista ta de pagini urmărite este afişată mai jos.
+Pentru a elimina un titlu, bifează căsuţa din apropierea lui, iar apoi apasă pe Elimină titluri.
+De asemenea poţi [[Special:Watchlist/raw|modifica lista brută]].',
+'watchlistedit-normal-submit'  => 'Şterge Titluri',
+'watchlistedit-normal-done'    => '{{PLURAL:$1|1 titlu a fost şters|$1 titluri au fost şterse}} din lista de urmărire:',
+'watchlistedit-raw-title'      => 'Modifică lista brută a paginilor urmărite',
+'watchlistedit-raw-legend'     => 'Modifică lista brută de pagini urmărite',
+'watchlistedit-raw-explain'    => 'Titlurile din lista paginilor urmărite este afişată mai jos, şi poate fi modificată adăugând şi eliminând pagini;
+un titlu pe linie.
+Când ai terminat de modificat lista, apasă pe Actualizează lista paginilor urmărite.
+Poţi şi să [[Special:Watchlist/edit|foloseşti un editor standard]].',
+'watchlistedit-raw-titles'     => 'Titluri:',
+'watchlistedit-raw-submit'     => 'Actualizează lista paginilor urmărite',
+'watchlistedit-raw-done'       => 'Lista paginilor urmărite a fost actualizată.',
+'watchlistedit-raw-added'      => '{{PLURAL:$1|1 titlu a fost adăugat|$1 titluri au fost adăugate}}:',
+'watchlistedit-raw-removed'    => '{{PLURAL:$1|1 titlu a fost şters|$1 titluri au fost şterse}}:',
 
 # Watchlist editing tools
 'watchlisttools-view' => 'Vizualizează schimbările relevante',
 'watchlisttools-edit' => 'Vezi şi modifică lista paginilor urmărite',
 'watchlisttools-raw'  => 'Modifică lista neprelucrată a paginilor urmărite',
 
+# Core parser functions
+'unknown_extension_tag' => 'Extensie etichetă necunoscută "$1"',
+
 # Special:Version
-'version'                  => 'Versiune', # Not used as normal message but as header for the special page itself
-'version-extensions'       => 'Extensii instalate',
-'version-specialpages'     => 'Pagini speciale',
-'version-variables'        => 'Variabile',
-'version-version'          => 'Versiune',
-'version-license'          => 'Licenţă',
-'version-software'         => 'Software instalat',
-'version-software-product' => 'Produs',
-'version-software-version' => 'Versiune',
+'version'                          => 'Versiune', # Not used as normal message but as header for the special page itself
+'version-extensions'               => 'Extensii instalate',
+'version-specialpages'             => 'Pagini speciale',
+'version-parserhooks'              => 'Hook-uri parser',
+'version-variables'                => 'Variabile',
+'version-other'                    => 'Alta',
+'version-mediahandlers'            => 'Suport media',
+'version-hooks'                    => 'Hook-uri',
+'version-extension-functions'      => 'Funcţiile extensiilor',
+'version-parser-extensiontags'     => 'Taguri extensie parser',
+'version-parser-function-hooks'    => 'Hook-uri funcţii parser',
+'version-skin-extension-functions' => 'Funcţiile extensiei interfeţei',
+'version-hook-name'                => 'Nume hook',
+'version-hook-subscribedby'        => 'Subscris de',
+'version-version'                  => 'Versiune',
+'version-license'                  => 'Licenţă',
+'version-software'                 => 'Software instalat',
+'version-software-product'         => 'Produs',
+'version-software-version'         => 'Versiune',
 
-# Special:Filepath
-'filepath'        => 'Cale fişier',
-'filepath-page'   => 'Fişier:',
-'filepath-submit' => 'Cale',
+# Special:FilePath
+'filepath'         => 'Cale fişier',
+'filepath-page'    => 'Fişier:',
+'filepath-submit'  => 'Cale',
+'filepath-summary' => 'Această pagină specială întoarce calea completă a fişierului.
+Imaginile sunt prezentate la rezoluţia maximă, alte tipuri de fişiere vor porni direct în programele asociate.
 
+Introdu numele fişierului fără prefixul "{{ns:image}}:".',
+
 # Special:FileDuplicateSearch
 'fileduplicatesearch'          => 'Caută fişiere duplicate',
+'fileduplicatesearch-summary'  => 'Caută fişiere duplicat bazate pe valoarea sa hash.
+
+Introdu numele fişierului fără prefixul "{{ns:image}}:".',
 'fileduplicatesearch-legend'   => 'Caută un duplicat',
 'fileduplicatesearch-filename' => 'Nume fişier:',
 'fileduplicatesearch-submit'   => 'Caută',
 'fileduplicatesearch-info'     => '$1 × $2 pixeli<br />Mărime fişier: $3<br />Tip MIME: $4',
+'fileduplicatesearch-result-1' => 'Fişierul "$1" nu are un duplicat identic.',
+'fileduplicatesearch-result-n' => 'Fişierul "$1" are {{PLURAL:$2|1 duplicat identic|$2 duplicate identice}}.',
 
 # Special:SpecialPages
 'specialpages'                   => 'Pagini speciale',
+'specialpages-note'              => '----
+* Pagini speciale normale.
+* <span class="mw-specialpagerestricted">Pagini speciale restricţionate.</span>',
 'specialpages-group-maintenance' => 'Întreţinere',
 'specialpages-group-other'       => 'Alte pagini speciale',
 'specialpages-group-login'       => 'Autentificare / Înregistrare',
@@ -2283,8 +2562,9 @@
 'specialpages-group-pagetools'   => 'Unelte pentru pagini',
 'specialpages-group-wiki'        => 'Date şi unelte wiki',
 'specialpages-group-redirects'   => 'Pagini speciale de redirecţionare',
+'specialpages-group-spam'        => 'Unelte spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pagină goală',
 'intentionallyblankpage' => 'Această pagină este goală în mod intenţionat',
 
Index: languages/messages/MessagesGa.php
===================================================================
--- languages/messages/MessagesGa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,13 +5,10 @@
  * @file
  *
  * @author Alison
+ * @author Kwekubo
  * @author Moilleadóir
- * @author SPQRobin
  * @author Spacebirdy
- * @author Kwekubo
- * @author Siebrand
  * @author לערי ריינהארט
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -561,11 +558,6 @@
 Dá dtarlódh an scéal seo duit, cuir ríomhphost chuig riarthóir le seoladh ríomhphoist AOL. Bheith cinnte tagairt a dhéanamh leis an seoladh IP seo thuas.',
 'whitelistedittitle'     => 'Logáil isteach chun athrú a dhéanamh',
 'whitelistedittext'      => 'Ní mór duit $1 chun ailt a athrú.',
-'whitelistreadtitle'     => 'Logáil isteach chun ailt a léamh',
-'whitelistreadtext'      => 'Ní mór duit [[Special:Userlogin|logáil isteach]] chun ailt a léamh.',
-'whitelistacctitle'      => 'Níl cead agat cuntas a chruthú',
-'whitelistacctext'       => 'Chun cuntais nua a chruthú sa vicí seo, caithfidh tú [[Special:Userlogin|logáil
-isteach]] agus caithfidh go bhfuil an cead riachtanach agat.',
 'loginreqtitle'          => 'Tá logáil isteach de dhíth ort',
 'loginreqlink'           => 'logáil isteach',
 'loginreqpagetext'       => 'Caithfidh tú $1 chun leathanaigh a amharc.',
@@ -580,7 +572,7 @@
 cuntas fós nó nach úsáideann a chuntas phéarsanta. Dá bhrí sin, caithfimid an seoladh IP uimhriúil a úsáid
 chun é/í a ionannaigh. Is féidir cuid mhaith úsáideoirí an seoladh IP céanna a úsáid. Má tá tú
 i do úsáideoir gan ainm agus má tá sé do thuairim go rinneadh léiriuithe neamhfheidhmeacha fút,
-[[Special:Userlogin|cruthaigh cuntas nó logáil isteach]] le do thoil chun mearbhall a héalú
+[[Special:UserLogin|cruthaigh cuntas nó logáil isteach]] le do thoil chun mearbhall a héalú
 le húsáideoirí eile gan ainmneacha amach anseo.''",
 'noarticletext'          => 'Níl aon téacs ar an leathanach seo faoi láthair.  Is féidir [[Special:Search/{{PAGENAME}}|cuardach a dhéanamh le haghaidh an teidil seo]] i leathanaigh eile nó [{{fullurl:{{FULLPAGENAME}}|action=edit}} an leathanach seo a athrú].',
 'clearyourcache'         => "'''Tabhair faoi deara:''' Tar éis duit ábhar a shábháil, ní mór duit
@@ -705,7 +697,7 @@
 'preferences'              => 'Sainroghanna',
 'mypreferences'            => 'Mo shainroghanna',
 'prefsnologin'             => 'Níl tú logáilte isteach',
-'prefsnologintext'         => 'Ní mór duit [[Special:Userlogin|logáil isteach]] chun do chuid sainroghanna phearsanta a shocrú.',
+'prefsnologintext'         => 'Ní mór duit [[Special:UserLogin|logáil isteach]] chun do chuid sainroghanna phearsanta a shocrú.',
 'prefsreset'               => "D'athraíodh do chuid sainroghanna ar ais chuig an leagan bunúsach ón stóras.",
 'qbsettings'               => 'Sainroghanna an bosca uirlisí',
 'qbsettings-none'          => 'Faic',
@@ -815,10 +807,10 @@
 'reupload'          => 'Athuaslódáil',
 'reuploaddesc'      => 'Dul ar ais chuig an fhoirm uaslódála.',
 'uploadnologin'     => 'Nil tú logáilte isteach',
-'uploadnologintext' => 'Ní mór duit [[Special:Userlogin|logáil isteach]] chun comhaid a huaslódáil.',
+'uploadnologintext' => 'Ní mór duit [[Special:UserLogin|logáil isteach]] chun comhaid a huaslódáil.',
 'uploaderror'       => 'Earráid uaslódála',
 'uploadtext'        => "Bain úsáid as an bhfoirm thíos chun comhaid a uaslódáil.
-Chun comhaid atá ann cheana a fheiceáil nó a chuardach téigh chuig an [[Special:Imagelist|liosta comhad uaslódáilte]]. Gheobhaidh tú liosta de chomhaid uaslódáilte nó scriosta sa [[Special:Log/upload|loga uaslódála]] freisin.
+Chun comhaid atá ann cheana a fheiceáil nó a chuardach téigh chuig an [[Special:ImageList|liosta comhad uaslódáilte]]. Gheobhaidh tú liosta de chomhaid uaslódáilte nó scriosta sa [[Special:Log/upload|loga uaslódála]] freisin.
 
 Chun comhad a úsáid ar leathanach, cuir isteach nasc mar seo:
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:comhad.jpg]]</nowiki>''',
@@ -855,7 +847,7 @@
 'upload_source_url'  => ' (URL bailí is féidir a rochtain go poiblí)',
 'upload_source_file' => ' (comhad ar do riomhaire)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist'      => 'Liosta íomhánna',
 'imagelist_user' => 'Úsáideoir',
 
@@ -872,8 +864,8 @@
 'nolinkstoimage'            => 'Níl leathanach ar bith ann a bhfuil nasc chuig an gcomhad seo air.',
 'sharedupload'              => 'Is uaslodáil roinnte atá ann sa comhad seo, agus is féidir le tionscadail eile é a úsáid.',
 'shareduploadwiki'          => 'Féach ar an [leathanach cur síos don comhad $1] le tuilleadh eolais.',
-'noimage'                   => 'Níl aon chomhad ann leis an ainm seo, ba féidir leat [$1 é a uaslódáil]',
-'noimage-linktext'          => 'uaslódáil é',
+'noimage'                   => 'Níl aon chomhad ann leis an ainm seo, ba féidir leat $1',
+'noimage-linktext'          => 'é a uaslódáil',
 'uploadnewversion-linktext' => 'Uaslódáil leagan nua den comhad seo',
 
 # File deletion
@@ -911,7 +903,7 @@
 Is é sin '''$5''' athruithe ar meán do gach leathanach, agus '''$6''' radhairc do gach athrú.
 
 Fad an [http://www.mediawiki.org/wiki/Manual:Job_queue scuaine jabanna]: '''$7'''.",
-'userstatstext' => "Tá {{PLURAL:$1|'''[[Special:Listusers|úsáideoir]] cláraithe amháin'''|'''$1''' [[Special:Listusers|úsáideoirí]] cláraithe}} anseo agus tá {{PLURAL:$2|'''duine amháin'''|'''$2'''}} (nó '''$4%''') díobh leis na cearta $5.",
+'userstatstext' => "Tá {{PLURAL:$1|'''[[Special:ListUsers|úsáideoir]] cláraithe amháin'''|'''$1''' [[Special:ListUsers|úsáideoirí]] cláraithe}} anseo agus tá {{PLURAL:$2|'''duine amháin'''|'''$2'''}} (nó '''$4%''') díobh leis na cearta $5.",
 
 'disambiguations'     => 'Leathanaigh idirdhealaithe',
 'disambiguationspage' => '{{ns:project}}:Naisc_go_leathanaigh_idirdhealaithe',
@@ -977,7 +969,7 @@
 agus oibreoirí córais. Is féidir leat an taispeántas a ghéarú - roghnaigh an saghas loga, an ainm úsáideora, nó an
 leathanach atá i gceist agat.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Gach leathanach',
 'alphaindexline'    => '$1 go $2',
 'nextpage'          => 'An leathanach a leanas ($1)',
@@ -998,7 +990,7 @@
 
 # E-mail user
 'mailnologin'     => 'Níl aon seoladh maith ann',
-'mailnologintext' => 'Ní mór duit bheith  [[Special:Userlogin|logáilte isteach]]
+'mailnologintext' => 'Ní mór duit bheith  [[Special:UserLogin|logáilte isteach]]
 agus bheith le seoladh ríomhphoist bhailí i do chuid [[Special:Preferences|sainroghanna]]
 más mian leat ríomhphost a sheoladh chuig úsáideoirí eile.',
 'emailuser'       => 'Cuir ríomhphost chuig an úsáideoir seo',
@@ -1029,7 +1021,7 @@
 'addedwatch'           => 'Curtha leis an liosta faire',
 'addedwatchtext'       => "Cuireadh an leathanach \"<nowiki>\$1</nowiki>\" le do [[Special:Watchlist|liosta faire]].
 Amach anseo liostálfar athruithe don leathanach seo agus dá leathanach plé ansin,
-agus beidh '''cló trom''' ar a theideal san [[Special:Recentchanges|liosta de na hathruithe is déanaí]] sa chaoi go bhfeicfeá iad go héasca.",
+agus beidh '''cló trom''' ar a theideal san [[Special:RecentChanges|liosta de na hathruithe is déanaí]] sa chaoi go bhfeicfeá iad go héasca.",
 'removedwatch'         => 'Bainte den liosta faire',
 'removedwatchtext'     => 'Baineadh an leathanach "<nowiki>$1</nowiki>" de do liosta faire.',
 'watch'                => 'Fair',
@@ -1126,7 +1118,7 @@
 'revertpage'                  => "Filleadh eagarthóireachtaí le [[Special:Contributions/$2|$2]] ([[User talk:$2|Plé]]); d'athúsáideadh an athrú seo caite le [[User:$1|$1]]", # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'protectlogpage'              => 'Cuntas_cosanta',
 'protectlogtext'              => 'Seo é liosta de glais a cuireadh ar / baineadh de leathanaigh.
-Féach ar [[Special:Protectedpages|Leathanach glasáilte]] chun a thuilleadh eolais a fháil.',
+Féach ar [[Special:ProtectedPages|Leathanach glasáilte]] chun a thuilleadh eolais a fháil.',
 'protectedarticle'            => 'glasáladh "[[$1]]"',
 'unprotectedarticle'          => 'díghlasáladh "[[$1]]"',
 'protect-title'               => 'Ag glasáil "$1"',
@@ -1214,7 +1206,7 @@
 'badipaddress'            => 'Níl aon úsáideoir ann leis an ainm seo.',
 'blockipsuccesssub'       => "D'éirigh leis an cosc",
 'blockipsuccesstext'      => 'Choisceadh [[Special:Contributions/$1|$1]].
-<br />Féach ar an g[[Special:Ipblocklist|liosta coisc IP]] chun coisc a athbhreithniú.',
+<br />Féach ar an g[[Special:IPBlockList|liosta coisc IP]] chun coisc a athbhreithniú.',
 'ipb-unblock-addr'        => 'Díchoisc $1',
 'ipb-unblock'             => 'Díchosc ainm úsáideora ná seoladh IP',
 'unblockip'               => 'Díchoisc úsáideoir',
@@ -1238,7 +1230,7 @@
 'blocklogentry'           => 'coisceadh [[$1]]; is é $2 an am éaga $3',
 'blocklogtext'            => 'Seo é cuntas de gníomhartha coisc úsáideoirí agus míchoisc úsáideoirí. Ní cuirtear
 seoltaí IP a raibh coiscthe go huathoibríoch ar an liosta seo. Féach ar an
-[[Special:Ipblocklist|Liosta coisc IP]] chun
+[[Special:IPBlockList|Liosta coisc IP]] chun
 liosta a fháil de coisc atá i bhfeidhm faoi láthair.',
 'unblocklogentry'         => 'díchoisceadh $1',
 'block-log-flags-noemail' => 'cosc ar ríomhphost',
@@ -1298,8 +1290,6 @@
 
 Sna scéil sin, caithfidh tú an leathanach a aistrigh nó a báigh leis na lámha má tá sin an rud atá uait.",
 'movearticle'             => 'Athainmnigh an leathanach',
-'movenologin'             => 'Níl tú logáilte isteach',
-'movenologintext'         => "Ní mór duit bheith i d'úsáideoir cláraithe agus [[Special:Userlogin|logáilte isteach]] chun leathanach a hathainmniú.",
 'movenotallowed'          => 'Níl cead agat leathanaigh a athainmniú ar {{SITENAME}}.',
 'newtitle'                => 'Go teideal nua',
 'move-watch'              => 'Déan faire an leathanach seo',
@@ -1320,7 +1310,7 @@
 'revertmove'              => 'athúsáid',
 'delete_and_move'         => 'Scrios agus athainmnigh',
 'delete_and_move_text'    => '==Tá scriosadh riachtanach==
-Tá an leathanach sprice ("[[$1]]") ann cheana féin.
+Tá an leathanach sprice ("[[:$1]]") ann cheana féin.
 Ar mhaith leat é a scriosadh chun áit a dhéanamh don athainmniú?',
 'delete_and_move_confirm' => 'Tá, scrios an leathanach',
 'delete_and_move_reason'  => "Scriosta chun áit a dhéanamh d'athainmniú",
@@ -1491,7 +1481,7 @@
 'show-big-image'       => 'Taispeáin leagan ardtaifigh den íomhá',
 'show-big-image-thumb' => '<small>Méid an réamhamhairc seo: $1 × $2 picteilín</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Gailearaí na n-íomhánna nua',
 'imagelisttext' => 'Tá liosta thíos de {{PLURAL:$1|comhad amháin|$1 comhaid $2}}.',
 'showhidebots'  => '($1 róbónna)',
@@ -1758,7 +1748,7 @@
 'edit-externally'      => 'Athraigh an comhad seo le feidhmchlár seachtrach',
 'edit-externally-help' => 'Féach ar na
 
-[http://meta.wikimedia.org/wiki/Help:External_editors treoracha cumraíochta] (as Béarla)
+[http://www.mediawiki.org/wiki/Manual:External_editors treoracha cumraíochta] (as Béarla)
 
 le tuilleadh eolais.',
 
@@ -1820,7 +1810,7 @@
 'recreate' => 'Athchruthaigh',
 
 # HTML dump
-'redirectingto' => 'Ag athdhíriú go [[$1]]...',
+'redirectingto' => 'Ag athdhíriú go [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'An bhfuil tú cinnte go dteastaíonn uait taisce an leathanaigh seo a bhánú?
@@ -1857,7 +1847,7 @@
 'version-license'          => 'Ceadúnas',
 'version-software-version' => 'Leagan',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Comhad:',
 
 # Special:FileDuplicateSearch
Index: languages/messages/MessagesSr_ec.php
===================================================================
--- languages/messages/MessagesSr_ec.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSr_ec.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,14 +4,12 @@
  * @ingroup Language
  * @file
  *
- * @author Sasa Stefanovic
+ * @author Kale
  * @author Millosh
  * @author Red Baron
- * @author Siebrand
- * @author Kale
- * @author לערי ריינהארט
+ * @author Sasa Stefanovic
  * @author Јованвб
- * @author Jon Harald Søby
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -493,7 +491,7 @@
 'nosuchspecialpage' => 'Нема такве посебне странице',
 'nospecialpagetext' => "<big>'''Тражили сте непостојећу посебну страницу.'''</big>
 
-Списак свих посебних страница се може наћи на [[Special:Specialpages|{{int:specialpages}}]].",
+Списак свих посебних страница се може наћи на [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Грешка',
@@ -740,10 +738,6 @@
 'blockededitsource'                => "Текст '''ваших измена''' за '''$1''' је приказан испод:",
 'whitelistedittitle'               => 'Обавезно је пријављивање за мењање',
 'whitelistedittext'                => 'Морате да се $1 да бисте мењали странице.',
-'whitelistreadtitle'               => 'Обавезно је пријављивање за читање',
-'whitelistreadtext'                => 'Морате да се [[Special:Userlogin|пријавите]] да бисте читали чланке.',
-'whitelistacctitle'                => 'Није вам дозвољено да направите налог',
-'whitelistacctext'                 => 'Да би вам било дозвољено да направите налоге на {{SITENAME}} морате да се [[Special:Userlogin|пријавите]] и имате одговарајућа овлашћења.',
 'confirmedittitle'                 => 'Потребна је потврда адресе е-поштe за уређивање',
 'confirmedittext'                  => 'Морате потврдити вашу адресу е-поште пре уређивања страна. Молимо поставите и потврдите адресу ваше е-поште преко ваших [[Special:Preferences|корисничких подешавања]].',
 'nosuchsectiontitle'               => 'Не постоји такав одељак',
@@ -758,7 +752,7 @@
 Да бисте је направили, почните да куцате у пољу испод
 (погледајте [[{{ns:help}}:Садржај|помоћ]] за више информација).
 Ако сте дошли овде грешком, само кликните дугме '''back''' дугме вашег браузера.",
-'anontalkpagetext'                 => '---- Ово је страница за разговор за анонимног корисника који још није направио налог или га не користи. Због тога морамо да користимо бројчану ИП адресу како бисмо идентификовали њега или њу. Такву адресу може делити више корисника. Ако сте анонимни корисник и мислите да су вам упућене небитне примедбе, молимо вас да [[Special:Userlogin|направите налог или се пријавите]] да бисте избегли будућу забуну са осталим анонимним корисницима.',
+'anontalkpagetext'                 => '---- Ово је страница за разговор за анонимног корисника који још није направио налог или га не користи. Због тога морамо да користимо бројчану ИП адресу како бисмо идентификовали њега или њу. Такву адресу може делити више корисника. Ако сте анонимни корисник и мислите да су вам упућене небитне примедбе, молимо вас да [[Special:UserLogin|направите налог или се пријавите]] да бисте избегли будућу забуну са осталим анонимним корисницима.',
 'noarticletext'                    => 'Тренутно не постоји чланак под тим именом, можете [[Special:Search/{{PAGENAME}}|тражити ову страницу]] у другим чланцима или је [{{fullurl:{{FULLPAGENAME}}|action=edit}} уредити].',
 'userpage-userdoesnotexist'        => 'Налог "$1" није регистрован. Проверите да ли желите да правите/уређујете ову страницу.',
 'clearyourcache'                   => "'''Запамтите:''' Након снимања, можда морате очистити кеш вашег браузера да бисте видели промене. '''Mozilla / Firefox / Safari:''' држите ''Shift'' док кликћете ''Reload'' или притисните  ''Shift+Ctrl+R'' (''Cmd-Shift-R'' на ''Apple Mac'' машини); '''IE:''' држите ''Ctrl'' док кликћете ''Refresh'' или притисните ''Ctrl-F5''; '''Konqueror:''': само кликните ''Reload'' дугме или притисните ''F5''; корисници '''Оpera''' браузера можда морају да у потпуности очисте свој кеш преко ''Tools→Preferences''.",
@@ -817,7 +811,7 @@
 'edittools'                        => '<!-- Текст одавде ће бити показан испод формулара за уређивање и слање слика. -->',
 'nocreatetitle'                    => 'Прављење странице лимитирано',
 'nocreatetext'                     => 'На {{SITENAME}} је забрањено прављење нових чланака.
-Можете се вратити назад и уређивати постојећи чланак, или [[Special:Userlogin|се пријавите или направите налог]].',
+Можете се вратити назад и уређивати постојећи чланак, или [[Special:UserLogin|се пријавите или направите налог]].',
 'nocreate-loggedin'                => 'Немате овлашћења да правите нове стране на {{SITENAME}}.',
 'permissionserrors'                => 'Грешке у овлашћењима',
 'permissionserrorstext'            => 'Немате овлашћење да урадите то из {{PLURAL:$1|следећег|следећих}} разлога:',
@@ -932,7 +926,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Лог сакривања',
-'suppressionlogtext' => 'Испод се налази списак блокова и обрисаних страна који су сакривени од сисопа. Погледај [[Special:Ipblocklist|списак блокираних ИП адреса]] за списак тренутно важећих банова и блокова.',
+'suppressionlogtext' => 'Испод се налази списак блокова и обрисаних страна који су сакривени од сисопа. Погледај [[Special:IPBlockList|списак блокираних ИП адреса]] за списак тренутно важећих банова и блокова.',
 
 # History merging
 'mergehistory'                     => 'Уједини историје страна.',
@@ -1014,7 +1008,7 @@
 'mypreferences'            => 'Моја подешавања',
 'prefs-edits'              => 'Број измена:',
 'prefsnologin'             => 'Нисте пријављени',
-'prefsnologintext'         => 'Морате бити [[Special:Userlogin|пријављени]]
+'prefsnologintext'         => 'Морате бити [[Special:UserLogin|пријављени]]
 да бисте подешавали корисничка подешавања.',
 'prefsreset'               => 'Враћена су ускладиштена подешавања.',
 'qbsettings'               => 'Брза палета',
@@ -1089,7 +1083,7 @@
 'userrights-reason'           => 'Разлог измене:',
 'userrights-no-interwiki'     => 'Немате овлашћења да мењате корисничка права на осталим викијима.',
 'userrights-nodatabase'       => 'База података $1 не постоји или је локална.',
-'userrights-nologin'          => 'Морате се [[Special:Userlogin|пријавити]] са администраторским налогом да додате корисничка права.',
+'userrights-nologin'          => 'Морате се [[Special:UserLogin|пријавити]] са администраторским налогом да додате корисничка права.',
 'userrights-notallowed'       => 'Ваш налог нема овлашћења да додаје корисника права.',
 'userrights-changeable-col'   => 'Групе које можете мењати',
 'userrights-unchangeable-col' => 'Групе које не можете мењати',
@@ -1219,13 +1213,13 @@
 'reupload'                    => 'Поново пошаљи',
 'reuploaddesc'                => 'Врати се на упитник за слање.',
 'uploadnologin'               => 'Нисте пријављени',
-'uploadnologintext'           => 'Морате бити [[Special:Userlogin|пријављени]]
+'uploadnologintext'           => 'Морате бити [[Special:UserLogin|пријављени]]
 да бисте слали фајлове.',
 'upload_directory_missing'    => 'Директоријум за прихват фајлова ($1) недостаје, а веб сервер га не може направити.',
 'upload_directory_read_only'  => 'На директоријум за слање ($1) сервер не може да пише.',
 'uploaderror'                 => 'Грешка при слању',
 'uploadtext'                  => "Користите формулар доле да бисте послали фајлове.
-Да бисте видели или тражили претходно послате фајлове идите на [[Special:Imagelist|списак послатих фајлова]], слања и брисања су такође записани у [[Special:Log/upload|историји слања]].
+Да бисте видели или тражили претходно послате фајлове идите на [[Special:ImageList|списак послатих фајлова]], слања и брисања су такође записани у [[Special:Log/upload|историји слања]].
 
 Слику додајете у погодне чланке користећи синтаксу 
 '''<nowiki>[[{{ns:image}}:Фајл.jpg]]</nowiki>''',
@@ -1310,7 +1304,7 @@
 'upload_source_url'  => ' (валидан, јавно доступан УРЛ)',
 'upload_source_file' => ' (фајл на вашем рачунару)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ова посебна страна приказује све послате фајлове. Подразумева се да је последњи послат фајл приказан на врху списка. Кликом на заглавље колоне мења се принцип сортирања.',
 'imagelist_search_for'  => 'Тражи име слике:',
 'imgfile'               => 'фајл',
@@ -1336,7 +1330,7 @@
 'imagelinks'                     => 'Употреба слике',
 'linkstoimage'                   => '{{PLURAL:$1|Следећа страница користи|$1 Следеће странице користе}} овај фајл:',
 'nolinkstoimage'                 => 'Нема страница које користе овај фајл.',
-'morelinkstoimage'               => 'Види [[Special:Whatlinkshere/$1|више веза]] према овом фајлу.',
+'morelinkstoimage'               => 'Види [[Special:WhatLinksHere/$1|више веза]] према овом фајлу.',
 'sharedupload'                   => 'Ова слика је са заједничке оставе и можда је користе остали пројекти.',
 'shareduploadwiki'               => 'Молимо погледајте $1 за даље информације.',
 'shareduploadwiki-desc'          => 'Опис за $1 на дељеном складишту налази се испод.',
@@ -1353,18 +1347,18 @@
 # File reversion
 'filerevert'                => 'Врати $1',
 'filerevert-legend'         => 'Врати фајл',
-'filerevert-intro'          => '<span class="plainlinks">Враћате \'\'\'[[Media:$1|$1]]\'\'\' на [$4 верзију од $3, $2].</span>',
+'filerevert-intro'          => "Враћате '''[[Media:$1|$1]]''' на [$4 верзију од $3, $2].",
 'filerevert-comment'        => 'Коментар:',
 'filerevert-defaultcomment' => 'Враћено на верзију од $2, $1',
 'filerevert-submit'         => 'Врати',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' је враћен на [$4 верзију од $3, $2].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' је враћен на [$4 верзију од $3, $2].",
 'filerevert-badversion'     => 'Не постоји претходна локална верзија фајла са унесеним временом.',
 
 # File deletion
 'filedelete'                  => 'Обриши $1',
 'filedelete-legend'           => 'Обриши фајл',
 'filedelete-intro'            => "Бришете '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Бришете верзију фајла \'\'\'[[Media:$1|$1]]\'\'\' од [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Бришете верзију фајла '''[[Media:$1|$1]]''' од [$4 $3, $2].",
 'filedelete-comment'          => 'Коментар:',
 'filedelete-submit'           => 'Обриши',
 'filedelete-success'          => "'''$1''' је обрисан.",
@@ -1418,7 +1412,7 @@
 У просеку корисници направе '''\$5''' измена по страници и претпрегледаје страницу '''\$6''' пута током једне измене.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Џоб кју] дужина је '''\$7'''.",
-'userstatstext'          => "{{PLURAL:$1|Постоји '''1''' регистровани [[Special:Listusers|корисник]]|Постоје '''$1''' регистрована [[Special:Listusers|корисника]]|Постоји '''$1''' регистрованих [[Special:Listusers|корисника]]}}, од којих '''$2''' (или '''$4%''') {{PLURAL:$2|има|имају|имају}} $5 права.",
+'userstatstext'          => "{{PLURAL:$1|Постоји '''1''' регистровани [[Special:ListUsers|корисник]]|Постоје '''$1''' регистрована [[Special:ListUsers|корисника]]|Постоји '''$1''' регистрованих [[Special:ListUsers|корисника]]}}, од којих '''$2''' (или '''$4%''') {{PLURAL:$2|има|имају|имају}} $5 права.",
 'statistics-mostpopular' => 'Најпосећеније странице',
 
 'disambiguations'      => 'Странице за вишезначне одреднице',
@@ -1514,7 +1508,7 @@
 'logempty'             => 'Протокол је празан.',
 'log-title-wildcard'   => 'Тражи наслове који почињу са овим текстом',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Све странице',
 'alphaindexline'    => '$1 у $2',
 'nextpage'          => 'Следећа страна ($1)',
@@ -1537,12 +1531,12 @@
 'special-categories-sort-count' => 'сортирај по броју',
 'special-categories-sort-abc'   => 'сортирај азбучно',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Прикажи кориснике почевши од:',
 'listusers-submit'   => 'Прикажи',
 'listusers-noresult' => 'Није пронађен корисник.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'права сарадничких група',
 'listgrouprights-group'    => 'Група',
 'listgrouprights-rights'   => 'Права',
@@ -1551,7 +1545,7 @@
 
 # E-mail user
 'mailnologin'     => 'Нема адресе за слање',
-'mailnologintext' => 'Морате бити [[Special:Userlogin|пријављени]] и имати исправну адресу е-поште у вашим [[Special:Preferences|подешавањима]]
+'mailnologintext' => 'Морате бити [[Special:UserLogin|пријављени]] и имати исправну адресу е-поште у вашим [[Special:Preferences|подешавањима]]
 да бисте слали е-пошту другим корисницима.',
 'emailuser'       => 'Пошаљи е-пошту овом кориснику',
 'emailpage'       => 'Пошаљи е-писмо кориснику',
@@ -1582,10 +1576,10 @@
 'nowatchlist'          => 'Немате ништа на свом списку надгледања.',
 'watchlistanontext'    => 'Молимо $1 да бисте гледали или мењали ставке на вашем списку надгледања.',
 'watchnologin'         => 'Нисте пријављени',
-'watchnologintext'     => 'Морате бити [[Special:Userlogin|пријављени]] да бисте мењали списак надгледања.',
+'watchnologintext'     => 'Морате бити [[Special:UserLogin|пријављени]] да бисте мењали списак надгледања.',
 'addedwatch'           => 'Додато списку надгледања',
 'addedwatchtext'       => 'Страница "[[:$1]]" је додата вашем [[Special:Watchlist|списку надгледања]].
-Будуће промене ове странице и њој придружене странице за разговор ће бити наведене овде, и страница ће бити <b>подебљана</b> у [[Special:Recentchanges|списку]] скорашњих измена да би се лакше уочила.
+Будуће промене ове странице и њој придружене странице за разговор ће бити наведене овде, и страница ће бити <b>подебљана</b> у [[Special:RecentChanges|списку]] скорашњих измена да би се лакше уочила.
 
 Ако касније желите да уклоните страницу са вашег списка надгледања, кликните на "прекини надгледање" на бочној палети.',
 'removedwatch'         => 'Уклоњено са списка надгледања',
@@ -1701,7 +1695,7 @@
 Молимо кликните "back" и поново учитајте страну одакле сте дошли, а онда покушајте поново.',
 'protectlogpage'              => 'историја закључавања',
 'protectlogtext'              => 'Испод је списак заштићених страница.<br />
-Погледајте [[Special:Protectedpages|правила о заштити страница]] за више информација.',
+Погледајте [[Special:ProtectedPages|правила о заштити страница]] за више информација.',
 'protectedarticle'            => 'заштитио $1',
 'modifiedarticleprotection'   => 'промењен ниво заштите за „[[$1]]“',
 'unprotectedarticle'          => 'скинуо заштиту са $1',
@@ -1864,7 +1858,7 @@
 'badipaddress'                    => 'Лоша ИП адреса',
 'blockipsuccesssub'               => 'Блокирање је успело',
 'blockipsuccesstext'              => '"[[Special:Contributions/$1|$1]]" је блокиран.
-<br />Погледајте [[Special:Ipblocklist|ИП списак блокираних корисника]] за преглед блокирања.',
+<br />Погледајте [[Special:IPBlockList|ИП списак блокираних корисника]] за преглед блокирања.',
 'ipb-edit-dropdown'               => 'Мењајте разлоге блока',
 'ipb-unblock-addr'                => 'Одблокирај $1',
 'ipb-unblock'                     => 'Одблокирај корисничко име или ИП адресу',
@@ -1896,7 +1890,7 @@
 'blocklogpage'                    => 'историја блокирања',
 'blocklogentry'                   => 'је блокирао "[[$1]]" са временом истицања блокаде од $2 $3',
 'blocklogtext'                    => 'Ово је историја блокирања и деблокирања корисника. Аутоматски
-блокиране ИП адресе нису исписане овде. Погледајте [[Special:Ipblocklist|блокиране ИП адресе]] за списак тренутних забрана и блокирања.',
+блокиране ИП адресе нису исписане овде. Погледајте [[Special:IPBlockList|блокиране ИП адресе]] за списак тренутних забрана и блокирања.',
 'unblocklogentry'                 => 'одблокирао "$1"',
 'block-log-flags-anononly'        => 'само анонимни корисници',
 'block-log-flags-nocreate'        => 'забрањено прављење налога',
@@ -1937,7 +1931,7 @@
 'lockdbsuccesssub'    => 'База је закључана',
 'unlockdbsuccesssub'  => 'База је откључана',
 'lockdbsuccesstext'   => 'База података је закључана.<br />
-Сетите се да је [[Special:Unlockdb|откључате]] када завршите са одржавањем.',
+Сетите се да је [[Special:UnlockDB|откључате]] када завршите са одржавањем.',
 'unlockdbsuccesstext' => 'База података је откључана.',
 'lockfilenotwritable' => 'По фајлу за закључавање базе података не може да се пише. Да бисте закључали или откључали базу, по овом фајлу мора да буде омогућено писање од стране веб сервера.',
 'databasenotlocked'   => 'База података није закључана.',
@@ -1963,9 +1957,6 @@
 
 У тим случајевима, мораћете ручно да преместите или спојите страницу уколико то желите.",
 'movearticle'             => 'Премести страницу',
-'movenologin'             => 'Нисте пријављени',
-'movenologintext'         => 'Морате бити регистровани корисник и [[Special:Userlogin|пријављени]]
-да бисте преместили страницу.',
 'movenotallowed'          => 'Немате облашћења за премештање страница на {{SITENAME}}.',
 'newtitle'                => 'Нови наслов',
 'move-watch'              => 'Надгледај ову страницу',
@@ -1994,7 +1985,7 @@
 'delete_and_move'         => 'Обриши и премести',
 'delete_and_move_text'    => '==Потребно брисање==
 
-Циљани чланак "[[$1]]" већ постоји. Да ли желите да га обришете да бисте направили место за премештање?',
+Циљани чланак "[[:$1]]" већ постоји. Да ли желите да га обришете да бисте направили место за премештање?',
 'delete_and_move_confirm' => 'Да, обриши страницу',
 'delete_and_move_reason'  => 'Обрисано како би се направило место за премештање',
 'selfmove'                => 'Изворни и циљани назив су исти; страна не може да се премести преко саме себе.',
@@ -2224,7 +2215,7 @@
 'show-big-image'       => 'Пуна резолуција',
 'show-big-image-thumb' => '<small>Величина овог приказа: $1 × $2 пиксела</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Галерија нових слика',
 'imagelisttext'         => "Испод је списак од '''$1''' {{PLURAL:$1|фајла|фајла|фајлова}} поређаних $2.",
 'newimages-summary'     => 'Ова посебна страна приказује последње послате фајлове.',
@@ -2516,7 +2507,7 @@
 
 # External editor support
 'edit-externally'      => 'Измените овај фајл користећи спољашњу апликацију',
-'edit-externally-help' => 'Погледајте [http://meta.wikimedia.org/wiki/Help:External_editors упутство за подешавање] за више информација.',
+'edit-externally-help' => 'Погледајте [http://www.mediawiki.org/wiki/Manual:External_editors упутство за подешавање] за више информација.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'све',
@@ -2578,7 +2569,7 @@
 'recreate'            => 'Поново направи',
 
 # HTML dump
-'redirectingto' => 'Преусмеравам на [[$1]]...',
+'redirectingto' => 'Преусмеравам на [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Да ли желите очистити кеш ове странице?
@@ -2667,7 +2658,7 @@
 'version-software-product'         => 'Производ',
 'version-software-version'         => 'Верзија',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Путања фајла',
 'filepath-page'   => 'Фајл:',
 'filepath-submit' => 'Путања',
@@ -2694,7 +2685,7 @@
 'specialpages-group-redirects'   => 'преусмерење посебних страна',
 'specialpages-group-spam'        => 'оруђа против спама',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'празна страна',
 'intentionallyblankpage' => 'Ова страна је намерно остављена празном.',
 
Index: languages/messages/MessagesKk_cyrl.php
===================================================================
--- languages/messages/MessagesKk_cyrl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKk_cyrl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,11 +1,11 @@
 <?php
-/** Kazakh (Cyrillic) (Қазақша (Кирил))
+/** Kazakh (Cyrillic) (Қазақша (Cyrillic))
  *
  * @ingroup Language
  * @file
  *
+ * @author AlefZet
  * @author GaiJin
- * @author AlefZet
  */
 
 /**
@@ -527,7 +527,7 @@
 'mypage'         => 'Жеке бетім',
 'mytalk'         => 'Талқылауым',
 'anontalk'       => 'IP талқылауы',
-'navigation'     => 'Бағыттау',
+'navigation'     => 'Шарлау',
 'and'            => 'және',
 
 # Metadata in edit box
@@ -585,7 +585,7 @@
 'viewcount'         => 'Бұл бет $1 рет қатыналған.',
 'protectedpage'     => 'Қорғалған бет',
 'jumpto'            => 'Мында өту:',
-'jumptonavigation'  => 'бағыттау',
+'jumptonavigation'  => 'шарлау',
 'jumptosearch'      => 'іздеу',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
@@ -881,7 +881,7 @@
 'hr_tip'          => 'Дерелей сызық (үнемді қолданыңыз)',
 
 # Edit pages
-'summary'                          => 'Қысқаша мазмұндамасы',
+'summary'                          => 'Түйіндемесі',
 'subject'                          => 'Тақырыбы/бас жолы',
 'minoredit'                        => 'Бұл шағын өңдеме',
 'watchthis'                        => 'Бетті бақылау',
@@ -930,10 +930,6 @@
 'blockededitsource'                => "'''$1''' дегенге жасалған '''өңдемелеріңіздің''' мәтіні төменде көрсетіледі:",
 'whitelistedittitle'               => 'Өңдеу үшін кіруіңіз жөн.',
 'whitelistedittext'                => 'Беттерді өңдеу үшін $1 жөн.',
-'whitelistreadtitle'               => 'Оқу үшін кіруіңіз жөн',
-'whitelistreadtext'                => 'Беттерді оқу үшін [[{{#special:Userlogin}}|кіруіңіз]] жөн.',
-'whitelistacctitle'                => 'Тіркелгі жасауыңызға рұқсат берілмеген',
-'whitelistacctext'                 => '{{SITENAME}} жобасына тіркелгі жасау үшін [[{{#special:Userlogin}}|кіруіңіз]] керек және жанасымды рұқсаттарыңыз болу керек.',
 'confirmedittitle'                 => 'Құптау хаты қайта өңделуі жөн',
 'confirmedittext'                  => 'Беттерді өңдеу үшін алдын ала Е-пошта мекенжайыңызды құптауыңыз жөн.
 Е-пошта мекенжайыңызды [[{{#special:Preferences}}|пайдаланушылық бапталымдарыңыз]] арқылы қойыңыз да жарамдылығын тексеріп шығыңыз.',
@@ -1419,11 +1415,11 @@
 # Recent changes linked
 'recentchangeslinked'          => 'Қатысты өзгерістер',
 'recentchangeslinked-title'    => '«$1» дегенге қатысты өзгерістер',
-'recentchangeslinked-noresult' => 'Сілтелген беттерде келтірілген мерзімде ешқандай өзгеріс болмаған.',
-'recentchangeslinked-summary'  => "Бұл тізімде өзіндік беттен сілтелген беттердегі (не өзіндік санат мүшелеріндегі) істелген жуықтағы өзгерістер беріледі.
+'recentchangeslinked-noresult' => 'Сілтеген беттерде келтірілген мерзімде ешқандай өзгеріс болмаған.',
+'recentchangeslinked-summary'  => "Бұл тізімде өзіндік бетке сілтеген беттердегі (не өзіндік санат мүшелеріндегі) істелген жуықтағы өзгерістер беріледі.
 [[{{#special:Watchlist}}|Бақылау тізіміңіздегі]] беттер '''жуан''' болып белгіленеді.",
 'recentchangeslinked-page'     => 'Бет атауы:',
-'recentchangeslinked-to'       => 'Бұның орнына келтірілген бетке сілтелген беттердегі өзгерістерді көрсет',
+'recentchangeslinked-to'       => 'Керісінше, келтірілген бетке сілтейтін беттердегі өзгерістерді көрсет',
 
 # Upload
 'upload'                      => 'Қотарып беру',
@@ -1449,8 +1445,8 @@
 'uploadlogpage'               => 'Қотарып беру журналы',
 'uploadlogpagetext'           => 'Төменде ең соңғы қотарып берілген файл тізімі.',
 'filename'                    => 'Файл атауы',
-'filedesc'                    => 'Қысқаша мазмұндамасы',
-'fileuploadsummary'           => 'Қысқаша мазмұндамасы:',
+'filedesc'                    => 'Түйіндемесі',
+'fileuploadsummary'           => 'Түйіндемесі:',
 'filestatus'                  => 'Ауторлық құқықтар күйі:',
 'filesource'                  => 'Қайнар көзі:',
 'uploadedfiles'               => 'Қотарып берілген файлдар',
@@ -1538,7 +1534,7 @@
 'upload_source_url'  => ' (жарамды, баршаға қатынаулы URL)',
 'upload_source_file' => ' (компьютеріңіздегі файл)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Бұл арнайы бетте барлық қотарып берілген файлдар көрсетіледі.
 Соңғы қотарып берілген файлдар тізімде жоғарғы шетімен әдепкіден көрсетіледі.
 Бағанның бас жолын нұқығанда сұрыптаудың реттеуі өзгертіледі.',
@@ -1697,7 +1693,7 @@
 'wantedcategories'        => 'Басталмаған санаттар',
 'wantedpages'             => 'Басталмаған беттер',
 'missingfiles'            => 'Жоқ файлдар',
-'mostlinked'              => 'Ең көп сілтелген беттер',
+'mostlinked'              => 'Ең көп сілтенген беттер',
 'mostlinkedcategories'    => 'Ең көп пайдаланылған санаттар',
 'mostlinkedtemplates'     => 'Ең көп пайдаланылған үлгілер',
 'mostcategories'          => 'Ең көп санаты бар беттер',
@@ -1749,7 +1745,7 @@
 'logempty'             => 'Журналда сәйкес даналар жоқ.',
 'log-title-wildcard'   => 'Мына мәтіннең басталытын тақырып аттарын іздеу',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Барлық беттер',
 'alphaindexline'    => '$1 — $2',
 'nextpage'          => 'Келесі бетке ($1)',
@@ -1773,12 +1769,12 @@
 'special-categories-sort-count' => 'санымен сұрыптау',
 'special-categories-sort-abc'   => 'әліпбимен сұрыптау',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Мына қатысушыдан бастап көрсету:',
 'listusers-submit'   => 'Көрсет',
 'listusers-noresult' => 'Қатысушы табылған жоқ.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Қатысушы тобы құқықтары',
 'listgrouprights-summary'  => 'Келесі тізімде бұл уикиде тағайындалған қатысушы құқықтары (байланысты қатынау құқықтарымен бірге) көрсетіледі.
 Жеке құқықтар туралы көбірек ақпаратты [[{{MediaWiki:Listgrouprights-helppage}}|мында]] таба аласыз.',
@@ -2053,8 +2049,8 @@
 'sp-contributions-submit'      => 'Ізде',
 
 # What links here
-'whatlinkshere'            => 'Сілтелген беттер',
-'whatlinkshere-title'      => '$1 дегенге сілтелген беттер',
+'whatlinkshere'            => 'Мында сілтейтін беттер',
+'whatlinkshere-title'      => '$1 дегенге сілтейтін беттер',
 'whatlinkshere-page'       => 'Бет:',
 'linklistsub'              => '(Сілтемелер тізімі)',
 'linkshere'                => "'''[[:$1]]''' дегенге мына беттер сілтейді:",
@@ -2203,13 +2199,12 @@
 
 Осы орайда, қалауыңыз болса, бетті қолдан жылжыта не қоса аласыз.",
 'movearticle'             => 'Жылжытпақ бет:',
-'movenologin'             => 'Жүйеге кірмегенсіз',
-'movenologintext'         => 'Бетті жылжыту үшін тіркелген болуыңыз және [[{{#special:Userlogin}}|кіруіңіз]] жөн.',
 'movenotallowed'          => '{{SITENAME}} жобасында беттерді жылжыту руқсатыңыз жоқ.',
 'newtitle'                => 'Жаңа тақырып атына:',
 'move-watch'              => 'Бұл бетті бақылау',
 'movepagebtn'             => 'Бетті жылжыт',
 'pagemovedsub'            => 'Жылжыту сәтті аяқталды',
+'movepage-moved'          => '<big>\'\'\'"$1" беті "$2" бетіне жылжытылды\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Осылай аталған бет алдақашан бар, не таңдаған атауыңыз жарамды емес.
 Өзге атауды таңдаңыз',
 'cantmove-titleprotected' => 'Бетті осы орынға жылжыта алмайсыз, себебі жаңа тақырып аты бастаудан қорғалған',
@@ -2231,7 +2226,7 @@
 'revertmove'              => 'қайтару',
 'delete_and_move'         => 'Жою және жылжыту',
 'delete_and_move_text'    => '==Жою керек==
-«[[$1]]» деген нысана бет алдақашан бар.
+«[[:$1]]» деген нысана бет алдақашан бар.
 Жылжытуға жол беру үшін бұны жоясыз ба?',
 'delete_and_move_confirm' => 'Иә, бұл бетті жой',
 'delete_and_move_reason'  => 'Жылжытуға жол беру үшін жойылған',
@@ -2241,6 +2236,7 @@
 беттер бұл есім аясы сыртына және ішіне жылжытылмайды.',
 'imagenocrossnamespace'   => 'Файл емес есім аясына файл жылжытылмайды',
 'imagetypemismatch'       => 'Файлдың жаңа кеңейтімі бұның түріне сәйкес емес',
+'imageinvalidfilename'    => 'Нысана файл атауы жарамсыз',
 
 # Export
 'export'            => 'Беттерді сыртқа беру',
@@ -2486,7 +2482,7 @@
 'show-big-image'       => 'Жоғары ажыратылымды',
 'show-big-image-thumb' => '<small>Қарап шығу мөлшері: $1 × $2 нүкте</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Жаңа файлдар көрмесі',
 'imagelisttext'         => "Төменде $2 сұрыпталған '''$1''' файл тізімі.",
 'newimages-summary'     => 'Бұл арнайы бетінде соңғы қотарып берілген файлдар көрсетіледі',
@@ -2777,7 +2773,7 @@
 
 # External editor support
 'edit-externally'      => 'Бұл файлды шеттік қондырма арқылы өңдеу',
-'edit-externally-help' => 'Көбірек ақпарат үшін [http://meta.wikimedia.org/wiki/Help:External_editors орнату нұсқамаларын] қараңыз.',
+'edit-externally-help' => 'Көбірек ақпарат үшін [http://www.mediawiki.org/wiki/Manual:External_editors орнату нұсқамаларын] қараңыз.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'барлығын',
@@ -2852,7 +2848,7 @@
 'unit-pixel' => ' нүкте',
 
 # HTML dump
-'redirectingto' => '[[$1]] бетіне айдатуда…',
+'redirectingto' => '[[:$1]] бетіне айдатуда…',
 
 # action=purge
 'confirm_purge'        => 'Бұл беттін бүркемесін тазартасыз ба?
@@ -3003,7 +2999,7 @@
 'version-software-product'         => 'Өнім',
 'version-software-version'         => 'Нұсқасы',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Файл орналасуы',
 'filepath-page'    => 'Файл аты:',
 'filepath-submit'  => 'Орналасуын тап',
@@ -3042,4 +3038,8 @@
 'specialpages-group-redirects'   => 'Айдайтын арнайы беттер',
 'specialpages-group-spam'        => 'Спам құралдары',
 
+# Special:BlankPage
+'blankpage'              => 'Бос бет',
+'intentionallyblankpage' => 'Бұл бет әдейі бос қалдырылған',
+
 );
Index: languages/messages/MessagesZu.php
===================================================================
--- languages/messages/MessagesZu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author לערי ריינהארט
- * @author SPQRobin
  */
 
 $messages = array(
@@ -213,7 +212,7 @@
 # Special:Log
 'specialloguserlabel' => 'Umsebenzisi:',
 
-# Special:Allpages
+# Special:AllPages
 'allinnamespace' => 'Onke amakhasi ($1 namespace)',
 'allpagessubmit' => 'Hamba',
 
@@ -268,7 +267,6 @@
 # Move page
 'move-page-legend'        => 'Thuthisa ikhasi',
 'movearticle'             => 'Thuthisa ikhasi',
-'movenologin'             => 'Awungenile',
 'movepagebtn'             => 'Thuthisa ikhasi',
 'movedto'                 => 'Lithuthiselwe e',
 'movereason'              => 'Isizathu',
@@ -296,7 +294,7 @@
 'markaspatrolledtext' => 'Dweba ukuthi lelikhasi liyagadwa',
 'markedaspatrolled'   => 'Dweba ukuthi lelikhasi liyagadwa',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Uhlelo lwamafayela amasha',
 'noimages'  => 'Awuboni lutho.',
 'ilsubmit'  => 'Sesha',
@@ -347,7 +345,7 @@
 # action=purge
 'confirm_purge_button' => 'Kulungile',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-submit' => 'Indlela',
 
 );
Index: languages/messages/MessagesOc.php
===================================================================
--- languages/messages/MessagesOc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesOc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,13 +5,10 @@
  * @file
  *
  * @author Cedric31
- * @author Siebrand
- * @author לערי ריינהארט
  * @author ChrisPtDe
  * @author Spacebirdy
- * @author Jon Harald Søby
  * @author Горан Анђелковић
- * @author SPQRobin
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -500,7 +497,7 @@
 'nosuchspecialpage' => 'Pagina especiala inexistanta',
 'nospecialpagetext' => "<big>'''Avètz demandat una pagina especiala qu'es pas reconeguda pel logicial {{SITENAME}}.'''</big>
 
-Una lista de las paginas especialas pòt èsser trobada sus [[Special:Specialpages|{{int:specialpages}}]].",
+Una lista de las paginas especialas pòt èsser trobada sus [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -528,10 +525,10 @@
 L’administrator qu'a varrolhat la banca de donadas a balhat l’explicacion seguenta : $1",
 'missing-article'      => "La banca de donada a pas trobat lo tèxt d’una pagina qu’auriá degut trobar, intitolada « $1 » $2.
 
-Aquò es, en principi, causar en seguissent un diff perimit o un ligam de l’istoric vèrs una pagina qu'es estada suprimida.
+Aquò es, en principi, causat en seguissent lo ligam perimit d'un diff o de l’istoric cap a una pagina qu'es estada suprimida.
 
-Se es pas lo cas, belèu avètz trobat un bòg dins lo programa.
-Informatz-ne un administrator aprèp aver notada l’adreça del ligam.",
+S'es pas lo cas, belèu avètz trobat un bòg dins lo programa.
+Informatz-ne un [[Special:ListUsers/sysop|administrator]] aprèp aver notada l’adreça cibla del ligam.",
 'missingarticle-rev'   => '(revision#: $1)',
 'missingarticle-diff'  => '(Diff: $1, $2)',
 'readonly_lag'         => 'La banca de donadas es estada automaticament clavada pendent que los servidors segondaris ratrapan lor retard sul servidor principal.',
@@ -580,11 +577,12 @@
 
 # Login and logout pages
 'logouttitle'                => 'Desconnexion',
-'logouttext'                 => "'''Ara, sètz desconnectat(ada).'''<br />
-Podètz contunhar d'utilizar {{SITENAME}} anonimament, o vos tornar connectar, jol meteis nom o amb un autre nom.",
+'logouttext'                 => "<strong>Ara, sètz desconnectat(ada).</strong>
+
+Podètz contunhar d'utilizar {{SITENAME}} anonimament, o vos podètz [[Special:UserLogin|tornar connectar]] jol meteis nom o amb un autre nom.",
 'welcomecreation'            => "== Benvenguda, $1 ! ==
-
-Vòstre compte d'utilizaire es estat creat. Doblidetz pas de personalizar vòstras preferéncias sus {{SITENAME}} en consultant la pagina Preferéncias.",
+Vòstre compte d'utilizaire es estat creat.
+Doblidetz pas de personalizar vòstras [[Special:Preferences|{{SITENAME}} preferéncias]].",
 'loginpagetitle'             => "S'enregistrar/Entrar",
 'yourname'                   => "Vòstre nom d'utilizaire :",
 'yourpassword'               => 'Vòstre senhal :',
@@ -595,7 +593,7 @@
 'loginproblem'               => '<b>Problèma d’identificacion.</b><br />Ensajatz tornarmai !',
 'login'                      => 'Identificacion',
 'nav-login-createaccount'    => 'Crear un compte o se connectar',
-'loginprompt'                => 'Vos cal activar los cookies per vos connectar a {{SITENAME}}.',
+'loginprompt'                => 'Vos cal activar los cookies per [[Special:UserLogin|vos connectar a {{SITENAME}}]].',
 'userlogin'                  => 'Crear un compte o se connectar',
 'logout'                     => 'Se desconnectar',
 'userlogout'                 => 'Desconnexion',
@@ -742,12 +740,8 @@
 'blockednoreason'                  => 'Cap de rason balhada',
 'blockedoriginalsource'            => "Lo còde font de '''$1''' es indicat çaijós :",
 'blockededitsource'                => "Lo contengut de '''vòstras modificacions''' aportadas a '''$1''' es indicat çaijós :",
-'whitelistedittitle'               => 'Connexion necessària per modificar lo contengut',
+'whitelistedittitle'               => '[[Special:UserLogin|Connexion necessària]] per modificar lo contengut',
 'whitelistedittext'                => 'Vos cal èsser $1 per modificar las paginas.',
-'whitelistreadtitle'               => 'Connexion necessària per legir lo contengut',
-'whitelistreadtext'                => 'Vos cal [[Special:Userlogin|vos identificar]] per legir las paginas.',
-'whitelistacctitle'                => 'Vos es pas permés de crear un compte',
-'whitelistacctext'                 => 'Per poder crear un compte dins aqueste Wiki, vos cal [[Special:Userlogin|vos connectar]] e aver las autorizacions apropriadas.',
 'confirmedittitle'                 => "Validacion de l'adreça de corrièr electronic necessària per modificar lo contengut",
 'confirmedittext'                  => "Vos cal confirmar vòstra adreça electronica abans de modificar l'enciclopèdia. Picatz e validatz vòstra adreça electronica amb l'ajuda de la pagina [[Special:Preferences|preferéncias]].",
 'nosuchsectiontitle'               => 'Seccion mancanta',
@@ -762,7 +756,7 @@
 Per crear aquesta pagina, picatz vòstre tèxt dins la bóstia çaijós (podètz consultar [[{{MediaWiki:Helppage}}|la pagina d’ajuda]] per mai d’entresenhas).
 Se sètz arribat(ada) aicí per error, clicatz sul boton '''retorn''' de vòstre navigador.",
 'anontalkpagetext'                 => "---- ''Sètz sus la pagina de discussion d'un utilizaire anonim qu'a pas encara creat un compte o que n'utiliza pas.
-Per aquesta rason, devèm utilizar son adreça IP per l'identificar. Una adreça d'aqueste tipe pòt èsser partejada entre mantuns utilizaires. Se sètz un utilizaire anonim e se constatatz que de comentaris que vos concernisson pas vos son estats adreçats, podètz [[Special:Userlogin|crear un compte o vos connectar]] per evitar tota confusion venenta amb d’autres contributors anonims.''",
+Per aquesta rason, devèm utilizar son adreça IP per l'identificar. Una adreça d'aqueste tipe pòt èsser partejada entre mantuns utilizaires. Se sètz un utilizaire anonim e se constatatz que de comentaris que vos concernisson pas vos son estats adreçats, podètz [[Special:UserLogin/signup|crear un compte]] o [[Special:UserLogin|vos connectar]] per evitar tota confusion venenta amb d’autres contributors anonims.''",
 'noarticletext'                    => "Pel moment, i a pas cap de tèxt sus aquesta pagina ; podètz [[Special:Search/{{PAGENAME}}|aviar una recèrca sul títol d'aquesta pagina]], verificar qu’es pas estada [{{fullurl:Special:Log|type=delete&page={{FULLPAGENAMEE}}}} suprimida] o [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificar aquesta pagina].",
 'userpage-userdoesnotexist'        => "Lo compte d'utilizaire « $1 » es pas enregistrat. Indicatz se volètz crear o editar aquesta pagina.",
 'clearyourcache'                   => "'''Nòta :''' Aprèp publicat la pagina, vos cal forçar son recargament complet tot ignrant lo contengut actual de l'amagatal de vòstre navigador per veire los cambiaments : '''Mozilla / Firefox / Konqueror / Safari :''' mantenètz la tòca ''Majuscula'' (''Shift'') en clicant lo boton ''Actualizar'' (''Reload,'') o quichatz ''Maj-Ctrl-R'' (''Maj-Cmd-R'' sus Apple Mac) ; '''Internet Explorer / Opera :''' mantenètz la tòca ''Ctrl'' en clicant lo boton ''Actualizar'' o quichatz ''Ctrl-F5''.",
@@ -774,12 +768,14 @@
 'note'                             => '<strong>Nòta :</strong>',
 'previewnote'                      => "<strong>Atencion, aqueste tèxt es pas qu'una previsualizacion e es pas encara estat salvat !</strong>",
 'previewconflict'                  => 'Aquesta previsualizacion mòstra lo tèxt de la bóstia de modificacion superiora coma apareisserà se causissètz de lo salvar.',
-'session_fail_preview'             => '<strong>O planhèm ! Podèm pas enregistrar vòstra modificacion a causa d’una pèrda d’informacions concernent vòstra sesilha. Ensajatz tornarmai. Se aquò capita pas encara, desconnectatz-vos, puèi connectatz-vos tornamai.</strong>',
-'session_fail_preview_html'        => "<strong>O planhèm ! Podèm pas enregistrar vòstra modificacion a causa d’una pèrda d’informacions concernent vòstra sesilha.</strong>
+'session_fail_preview'             => "<strong>O planhèm ! Podèm pas enregistrar vòstra modificacion a causa d’una pèrda d’informacions concernent vòstra sesilha. 
+Ensajatz tornarmai.
+S'aquò capita pas encara, desconnectatz-vos, puèi [[Special:UserLogout|connectatz-vos]] tornamai.</strong>",
+'session_fail_preview_html'        => "<strong>O planhèm ! Podèm pas enregistrar vòstra modificacion a causa d’una pèrda d’informacions que concernís vòstra sesilha.</strong>
 
 ''L’HTML brut essent activat sus {{SITENAME}}, la previsualizacion es estada amagada per prevenir un atac per JavaScript.''
 
-<strong>Se la temptativa de modificacion èra legitima, ensajatz encara. Se aquò capita pas un còp de mai, desconnectatz-vos, puèi connectatz-vos tornamai.</strong>",
+<strong>Se la temptativa de modificacion èra legitima, ensajatz encara. S'aquò capita pas un còp de mai, [[Special:UserLogout|desconnectatz-vos]], puèi connectatz-vos tornamai.</strong>",
 'token_suffix_mismatch'            => '<strong>Vòstra modificacion es pas estada acceptada perque vòstre navigador a mesclat los caractèrs de ponctuacion dins l’identificant d’edicion. La modificacion es estada regetada per empachar la corrupcion del tèxt de l’article. Aqueste problèma se produtz quand utilizatz un mandatari (proxy) anonim problematic.</strong>',
 'editing'                          => 'Modificacion de $1',
 'editingsection'                   => 'Modificacion de $1 (seccion)',
@@ -814,10 +810,10 @@
 'template-protected'               => '(protegit)',
 'template-semiprotected'           => '(semiprotegit)',
 'hiddencategories'                 => "{{PLURAL:$1|Categoria amagada|Categorias amagadas}} qu'aquesta pagina ne fa partida :",
-'edittools'                        => '<!-- Tot tèxt picat aicí serà afichat jos las boitas de modificacion o d’impòrt de fichièr. -->',
+'edittools'                        => '<!-- Tot tèxt picat aicí serà afichat jos las bóstias de modificacion o d’impòrt de fichièr. -->',
 'nocreatetitle'                    => 'Creacion de pagina limitada',
 'nocreatetext'                     => '{{SITENAME}} a restrencha la possibilitat de crear de paginas novèlas.
-Podètz tonar en rèire e modificar una pagina existenta, [[Special:Userlogin|vos connectar o crear un compte]].',
+Podètz tonar en rèire e modificar una pagina existenta, [[Special:UserLogin|vos connectar o crear un compte]].',
 'nocreate-loggedin'                => 'Avètz pas la permission de crear de paginas novèlas sus aqueste wiki.',
 'permissionserrors'                => 'Error de permissions',
 'permissionserrorstext'            => 'Avètz pas la permission d’efectuar l’operacion demandada per {{PLURAL:$1|la rason seguenta|las rasons seguentas}} :',
@@ -841,7 +837,7 @@
 'undo-success' => "Aquesta modificacion va èsser desfacha. Confirmatz los cambiaments (visibles en bas d'aquesta pagina), puèi salvatz se sètz d’acòrdi. Mercés de motivar l’anullacion dins la bóstia de resumit.",
 'undo-failure' => 'Aquesta modificacion a pas pogut èsser desfacha a causa de conflictes amb de modificacions intermediàrias.',
 'undo-norev'   => 'La modificacion a pas pogut èsser desfacha perque siá es inexistenta siá es estada suprimida.',
-'undo-summary' => 'Anullacion de las modificacions $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|discutir]])',
+'undo-summary' => 'Anullacion de las modificacions $1 de [[Special:Contributions/$2|$2]] ([[User talk:$2|discutir]]) | [[Special:Contributions/$2|{{MediaWiki:Contribslink}}]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Podètz pas crear de compte.',
@@ -929,7 +925,7 @@
 
 # Suppression log
 'suppressionlog'     => 'Jornal de las supressions',
-'suppressionlogtext' => 'Çaijós, se tròba la tièra de las supressions e dels blocatges que comprenon las revisions amagadas als administrators. Vejatz [[Special:Ipblocklist|la lista dels blocatges de las IP]] per la lista dels fòrabandiments e dels blocatges operacionals.',
+'suppressionlogtext' => 'Çaijós, se tròba la tièra de las supressions e dels blocatges que comprenon las revisions amagadas als administrators. Vejatz [[Special:IPBlockList|la lista dels blocatges de las IP]] per la lista dels fòrabandiments e dels blocatges operacionals.',
 
 # History merging
 'mergehistory'                     => "Fusion dels istorics d'una pagina",
@@ -969,7 +965,7 @@
 # Search results
 'searchresults'             => 'Resultats de la recèrca',
 'searchresulttext'          => "Per mai d'informacions sus la recèrca dins {{SITENAME}}, vejatz [[{{MediaWiki:Helppage}}|{{int:help}}]].",
-'searchsubtitle'            => 'Avètz recercat « [[:$1]] »',
+'searchsubtitle'            => "Avètz recercat « '''[[:$1]]''' » ([[Special:Prefixindex/$1|totas las paginas que començan per « $1 »]] | [[Special:WhatLinksHere/$1|totas las paginas qu'an un ligam cap a « $1 »]])",
 'searchsubtitleinvalid'     => 'Avètz recercat « $1 »',
 'noexactmatch'              => "'''Cap de pagina amb lo títol « $1 » existís pas.
 ''' Podètz [[:$1|crear aqueste article]].",
@@ -1017,7 +1013,7 @@
 'mypreferences'            => 'Mas preferéncias',
 'prefs-edits'              => 'Nombre d’edicions :',
 'prefsnologin'             => 'Vos sètz pas identificat(ada)',
-'prefsnologintext'         => "Vos cal èsser [[Special:Userlogin|connectat(ada)]]
+'prefsnologintext'         => "Vos cal èsser [[Special:UserLogin|connectat(ada)]]
 per modificar vòstras preferéncias d'utilizaire.",
 'prefsreset'               => 'Las preferéncias son estadas restablidas a partir de la version enregistrada.',
 'qbsettings'               => "Barra d'espleches",
@@ -1092,7 +1088,7 @@
 'userrights-reason'           => 'Motiu del cambiament :',
 'userrights-no-interwiki'     => "Sètz pas abilitat per modificar los dreches dels utilizaires sus d'autres wikis.",
 'userrights-nodatabase'       => 'La banca de donadas « $1 » existís pas o es pas en local.',
-'userrights-nologin'          => "Vos cal [[Special:Userlogin|vos connectar]] amb un compte d'administrator per balhar los dreches d'utilizaire.",
+'userrights-nologin'          => "Vos cal [[Special:UserLogin|vos connectar]] amb un compte d'administrator per balhar los dreches d'utilizaire.",
 'userrights-notallowed'       => "Vòstre compte es pas abilitat per modificar de dreches d'utilizaire.",
 'userrights-changeable-col'   => 'Los gropes que podètz cambiar',
 'userrights-unchangeable-col' => 'Los gropes que podètz pas cambiar',
@@ -1140,7 +1136,7 @@
 'right-autoconfirmed'        => 'Modificar las paginas semiprotegidas',
 'right-bot'                  => 'Èsser tractat coma un procediment automatizat',
 'right-nominornewtalk'       => 'Desenclavar pas lo bendèl "Avètz de messatges novèls" al moment d\'un cambiament menor sus una pagina de discussion d\'un utilizaire',
-'right-apihighlimits'        => "Utilizar los limits superiors dins las requèstas l'API",
+'right-apihighlimits'        => "Utilizar de limits superiors dins las requèstas l'API",
 'right-writeapi'             => "Utilizar l'API per modificar lo wiki",
 'right-delete'               => 'Suprimir de paginas',
 'right-bigdelete'            => "Suprimir de paginas amb d'istorics grands",
@@ -1221,24 +1217,25 @@
 'reupload'                    => 'Importar tornarmai',
 'reuploaddesc'                => 'Anullar lo cargament e tornar al formulari.',
 'uploadnologin'               => 'Vos sètz pas identificat(ada)',
-'uploadnologintext'           => 'Vos cal èsser [[Special:Userlogin|connectat(ada)]]
+'uploadnologintext'           => 'Vos cal èsser [[Special:UserLogin|connectat(ada)]]
 per copiar de fichièrs sul servidor.',
 'upload_directory_missing'    => 'Lo repertòri d’impòrt ($1) es mancant e a pas pogut èsser creat pel servidor web.',
 'upload_directory_read_only'  => 'Lo servidor Web pòt escriure dins lo dorsièr cibla ($1).',
 'uploaderror'                 => 'Error',
-'uploadtext'                  => "Utilizatz lo formulari çaijós per mandar de fichièrs sul servidor.
-Per veire o recercar d'imatges precedentament mandats, consultatz [[Special:Imagelist|la lista dels imatges]]. Las còpias e las supressions tanben son enregistradas dins lo [[Special:Log/upload|jornal dels uploads]].
+'uploadtext'                  => "Utilizatz lo formulari çaijós per importar de fichièrs sul servidor.
+Per veire o recercar d'imatges precedentament mandats, consultatz [[Special:ImageList|la tièra dels imatges]]. Las còpias e las supressions tanben son enregistradas dins l'[[Special:Log/upload|istoric dels impòrts]].
 
 Per enclure un imatge dins una pagina, utilizatz un ligam de la forma
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fichièr.jpg]]</nowiki></b>,
-'''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fichièr.png|tèxt alternatiu]]</nowiki></b> o
-'''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:Fichièr.ogg]]</nowiki></b> per ligar dirèctament vèrs lo fichièr.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichièr.jpg]]</nowiki></tt>''',
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:fichièr.png|200px|thumb|left|tèxt descriptiu]]</nowiki></tt>''' per utilizar una miniatura de 200 pixels de larg dins una bóstia a esquèrra amb 'tèxt descriptiu' coma descripcion
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:fichièr.ogg]]</nowiki></tt>''' per ligar dirèctament cap al fichièr sens l'afichar.",
 'upload-permitted'            => 'Formats de fichièrs autorizats : $1.',
 'upload-preferred'            => 'Formats de fichièrs preferits : $1.',
 'upload-prohibited'           => 'Formats de fichièrs interdiches : $1.',
 'uploadlog'                   => 'Istoric de las importacions',
 'uploadlogpage'               => 'Istoric de las importacions de fichièrs multimèdia',
-'uploadlogpagetext'           => 'Vaquí la lista dels darrièrs fichièrs copiats sul servidor.',
+'uploadlogpagetext'           => 'Vaquí la tièra dels darrièrs fichièrs copiats sul servidor.
+Vejatz la [[Special:NewImages|galariá dels imatges novèls]] per una presentacion mai visuala.',
 'filename'                    => 'Nom del fichièr',
 'filedesc'                    => 'Descripcion',
 'fileuploadsummary'           => 'Resumit :',
@@ -1308,9 +1305,11 @@
 'upload-proto-error'      => 'Protocòl incorrècte',
 'upload-proto-error-text' => "L’impòrt requerís d'URLs començant per <code>http://</code> o <code>ftp://</code>.",
 'upload-file-error'       => 'Error intèrna',
-'upload-file-error-text'  => 'Una error intèrna es subrevenguda en volent crear un fichièr temporari sul servidor. Contactatz un administrator de sistèma.',
+'upload-file-error-text'  => 'Una error intèrna es subrevenguda en volent crear un fichièr temporari sul servidor. Contactatz un [[Special:ListUsers/sysop|administrator de sistèma]].',
 'upload-misc-error'       => 'Error d’impòrt desconeguda',
-'upload-misc-error-text'  => 'Una error desconeguda es subrevenguda pendent l’impòrt. Verificatz que l’URL es valida e accessibla, puèi ensajatz tornarmai. Se lo problèma persistís, contactatz un administrator del sistèma.',
+'upload-misc-error-text'  => 'Una error desconeguda es subrevenguda pendent l’impòrt.
+Verificatz que l’URL es valida e accessibla, puèi ensajatz tornarmai.
+Se lo problèma persistís, contactatz un [[Special:ListUsers/sysop|administrator del sistèma]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'Pòt pas aténher l’URL',
@@ -1324,10 +1323,10 @@
 'upload_source_url'  => ' (una URL valida e accessibla publicament)',
 'upload_source_file' => ' (un fichièr sus vòstre ordenador)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Aquesta pagina especiala mòstra totes los fichièrs importats.
 Per defaut, las darrièrs fichièrs importats son afichats en naut de la lista.
-Un clic en tèsta de colomna cambia l’òrdre d’afichatge.',
+Un clic en tèsta de colomna càmbia l’òrdre d’afichatge.',
 'imagelist_search_for'  => 'Recèrca del mèdia nomenat :',
 'imgfile'               => 'fichièr',
 'imagelist'             => 'Lista dels imatges',
@@ -1352,7 +1351,7 @@
 'imagelinks'                     => "Paginas que contenon l'imatge",
 'linkstoimage'                   => '{{PLURAL:$1|La pagina çaijós compòrta|Las paginas çaijós compòrtan}} aqueste imatge :',
 'nolinkstoimage'                 => 'Cap de pagina compòrta pas de ligam vèrs aqueste imatge.',
-'morelinkstoimage'               => 'Vejatz [[Special:Whatlinkshere/$1|mai de ligams]] vèrs aqueste imatge.',
+'morelinkstoimage'               => 'Vejatz [[Special:WhatLinksHere/$1|mai de ligams]] vèrs aqueste imatge.',
 'redirectstofile'                => '{{PLURAL:$1|Lo fichièr seguent redirigís|Los fichièrs seguents redirigisson}} cap a aqueste fichièr :',
 'duplicatesoffile'               => "{{PLURAL:$1|Lo fichièr seguent es un duplicata|Los fichièrs seguents son de duplicatas}} d'aqueste :",
 'sharedupload'                   => 'Aqueste fichièr es partejat e pòt èsser utilizat per d’autres projèctes.',
@@ -1371,18 +1370,18 @@
 # File reversion
 'filerevert'                => 'Revocar $1',
 'filerevert-legend'         => 'Revocar lo fichièr',
-'filerevert-intro'          => '<span class="plainlinks">Anatz revocar \'\'\'[[Media:$1|$1]]\'\'\' fins a [$4 la version del $2 a $3].</span>',
+'filerevert-intro'          => "Anatz revocar '''[[Media:$1|$1]]''' fins a [$4 la version del $2 a $3].",
 'filerevert-comment'        => 'Comentari :',
 'filerevert-defaultcomment' => 'Revocat fins a la version del $1 a $2',
 'filerevert-submit'         => 'Revocar',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' es estat revocat fins a [$4 la version del $2 a $3].</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' es estat revocat fins a [$4 la version del $2 a $3].",
 'filerevert-badversion'     => 'I a pas de version mai anciana del fichièr amb lo Timestamp donat.',
 
 # File deletion
 'filedelete'                  => 'Suprimir $1',
 'filedelete-legend'           => 'Suprimir lo fichièr',
 'filedelete-intro'            => "Sètz a suprimir '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Sètz a escafar la version de \'\'\'[[Media:$1|$1]]\'\'\' del [$4 $2 a $3].</span>',
+'filedelete-intro-old'        => "Sètz a escafar la version de '''[[Media:$1|$1]]''' del [$4 $2 a $3].",
 'filedelete-comment'          => "Motiu de l'escafament :",
 'filedelete-submit'           => 'Suprimir',
 'filedelete-success'          => "'''$1''' es estat suprimit.",
@@ -1438,18 +1437,19 @@
 Aquò representa una mejana de {{PLURAL:\$5|'''\$5''' modificacion|'''\$5''' modificacions}} per pagina e de {{PLURAL:\$6|'''\$6''' consultacion|'''\$6''' consultacions}} per una modificacion.
 
 I a {{PLURAL:\$7|'''\$7''' article|'''\$7''' articles}} dins [http://www.mediawiki.org/wiki/Manual:Job_queue la fila de prètzfaches].",
-'userstatstext'          => "I a {{PLURAL:$1|'''$1''' [[Special:Listusers|utilizaire enregistrat]]. I a '''$2''' (o '''$4%''') que es|'''$1''' [[Special:Listusers|utilizaires enregistrats]]. Demest eles, '''$2''' (o '''$4%''') son}} $5.",
+'userstatstext'          => "I a {{PLURAL:$1|'''$1''' [[Special:ListUsers|utilizaire enregistrat]]. I a '''$2''' (o '''$4%''') que es|'''$1''' [[Special:ListUsers|utilizaires enregistrats]]. Demest eles, '''$2''' (o '''$4%''') son}} $5.",
 'statistics-mostpopular' => 'Paginas mai consultadas',
 
 'disambiguations'      => "Paginas d'omonimia",
 'disambiguationspage'  => 'Template:Omonimia',
-'disambiguations-text' => "Las paginas seguentas ligan vèrs una '''pagina d’omonimia'''.
-Deurián puslèu ligar vèrs una pagina pertinenta.<br />
-Una pagina es tractada coma una pagina d’omonimia se es ligada dempuèi $1.
-Los ligams dempuèi d’autres espacis de noms <i>son pas</i> listats aicí.",
+'disambiguations-text' => "Las paginas seguentas puntan cap a una '''pagina d’omonimia'''.
+Deurián puslèu puntar cap a una pagina apropriada.<br />
+Una pagina es tractada coma una pagina d’omonimia s'utiliza un modèl qu'es ligat a partir de [[MediaWiki:Disambiguationspage]]",
 
-'doubleredirects'     => 'Redireccions doblas',
-'doubleredirectstext' => 'Cada casa conten de ligams vèrs la primièra e la segonda redireccion, e mai la primièra linha de tèxt de la segonda pagina, costumièrament, aquò provesís la « vertadièra » pagina cibla, vèrs laquala la primièra redireccion deuriá redirigir.',
+'doubleredirects'            => 'Redireccions doblas',
+'doubleredirectstext'        => 'Cada casa conten de ligams vèrs la primièra e la segonda redireccion, e mai la primièra linha de tèxt de la segonda pagina, costumièrament, aquò provesís la « vertadièra » pagina cibla, vèrs laquala la primièra redireccion deuriá redirigir.',
+'double-redirect-fixed-move' => '[[$1]] es estat renomenat, aquò es ara una redireccion cap a [[$2]]',
+'double-redirect-fixer'      => 'Corrector de redireccion',
 
 'brokenredirects'        => 'Redireccions copadas',
 'brokenredirectstext'    => "Aquestas redireccions mènan a una pagina qu'existís pas.",
@@ -1535,7 +1535,7 @@
 'logempty'             => 'I a pas res dins l’istoric per aquesta pagina.',
 'log-title-wildcard'   => 'Recercar de títols que començan per aqueste tèxt',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Totas las paginas',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Pagina seguenta ($1)',
@@ -1558,15 +1558,15 @@
 'special-categories-sort-count' => 'triada per compte',
 'special-categories-sort-abc'   => 'triada alfabetica',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Afichar los utilizaires a partir de :',
 'listusers-submit'   => 'Mostrar',
 'listusers-noresult' => "S'es pas trobat de noms d'utilizaires correspondents. Cercatz tanben amb de majusculas e minusculas.",
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => "Dreches dels gropes d'utilizaires",
 'listgrouprights-summary'  => "Aquesta pagina conten una tièra de gropes definits sus aqueste wiki e mai los dreches d'accès qu'i son associats.
-D'entresenhas complementàrias suls dreches pòdon èsser trobats [[{{MediaWiki:Listgrouprights-helppage}}|aicí]].",
+I pòt aver [[{{MediaWiki:Listgrouprights-helppage}}|d'entresenhas complementàrias]] a prepaus dels dreches.",
 'listgrouprights-group'    => 'Grop',
 'listgrouprights-rights'   => 'Dreches associats',
 'listgrouprights-helppage' => 'Help:Dreches dels gropes',
@@ -1574,13 +1574,13 @@
 
 # E-mail user
 'mailnologin'     => "Pas d'adreça",
-'mailnologintext' => 'Vos cal èsser [[Special:Userlogin|connectat(ada)]]
+'mailnologintext' => 'Vos cal èsser [[Special:UserLogin|connectat(ada)]]
 e aver indicat una adreça electronica valida dins vòstras [[Special:Preferences|preferéncias]]
 per poder mandar un messatge a un autre utilizaire.',
 'emailuser'       => 'Mandar un messatge a aqueste utilizaire',
 'emailpage'       => 'Mandar un corrièr electronic a l’utilizaire',
-'emailpagetext'   => 'Se aqueste utilizaire a indicat una adreça electronica valida dins sas preferéncias, lo formulari çaijós li mandarà un messatge.
-L\'adreça electronica qu\'avètz indicada dins vòstras preferéncias apareisserà dins lo camp "Expeditor" de vòstre messatge, per que lo destinatari vos pòsca respondre.',
+'emailpagetext'   => "S'aqueste utilizaire a indicat una adreça electronica valida dins sas preferéncias, lo formulari çaijós li mandarà un messatge.
+L'adreça electronica qu'avètz indicada dins [[Special:Preferences|vòstras preferéncias]] apareisserà dins lo camp « Expeditor » de vòstre messatge, per que lo destinatari vos pòsca respondre.",
 'usermailererror' => 'Error dins lo subjècte del corrièr electronic :',
 'defemailsubject' => 'Corrièr electronic mandat dempuèi {{SITENAME}}',
 'noemailtitle'    => "Pas d'adreça electronica",
@@ -1603,11 +1603,11 @@
 'nowatchlist'          => "Vòstra lista de seguit conten pas cap d'article.",
 'watchlistanontext'    => 'Per poder afichar o editar los elements de vòstra lista de seguit, vos devètz $1.',
 'watchnologin'         => 'Vos sètz pas identificat(ada)',
-'watchnologintext'     => 'Vos cal èsser [[Special:Userlogin|connectat(ada)]]
+'watchnologintext'     => 'Vos cal èsser [[Special:UserLogin|connectat(ada)]]
 per modificar vòstra lista de seguit.',
-'addedwatch'           => 'Ajustat a la lista',
-'addedwatchtext'       => 'La pagina "[[:$1]]" es estada ajustada a vòstra [[Special:Watchlist|lista de seguit]].
-Las modificacions venentas d\'aquesta pagina e de la pagina de discussion associada seràn repertoriadas aicí, e la pagina apareisserà <b>en gras</b> dins la [[Special:Recentchanges|lista dels darrièrs cambiaments]] per èsser localizada mai aisidament.',
+'addedwatch'           => 'Apondut a la tièra',
+'addedwatchtext'       => 'La pagina "[[:$1]]" es estada aponduda a vòstra [[Special:Watchlist|lista de seguit]].
+Las modificacions venentas d\'aquesta pagina e de la pagina de discussion associada seràn repertoriadas aicí, e la pagina apareisserà <b>en gras</b> dins la [[Special:RecentChanges|tièra dels darrièrs cambiaments]] per èsser localizada mai aisidament.',
 'removedwatch'         => 'Suprimida de la lista de seguit',
 'removedwatchtext'     => 'La pagina "[[:$1]]" es estada suprimida de vòstra lista de seguit.',
 'watch'                => 'Seguir',
@@ -1710,9 +1710,9 @@
 'rollbacklink'                => 'anullar',
 'rollbackfailed'              => "L'anullacion a pas capitat",
 'cantrollback'                => "Impossible d'anullar : l'autor es la sola persona a aver efectuat de modificacions sus aqueste article",
-'alreadyrolled'               => "Impossible d'anullar la darrièra modificacion de [[:$1]] per  [[User:$2|$2]] ([[User talk:$2|Discussion]]); qualqu'un d'autre ja a modificat o revocat l'article.
+'alreadyrolled'               => "Impossible d'anullar la darrièra modificacion de l'article « [[$1]] » efectuada per [[User:$2|$2]] ([[User talk:$2|Discussion]]) ; qualqu'un d'autre ja a modificat o revocat l'article.
 
-La darrièra modificacion èra de [[User:$3|$3]] ([[User talk:$3|Discussion]]).",
+La darrièra modificacion es estada efectuada per [[User:$3|$3]] ([[User talk:$3|Discussion]]).",
 'editcomment'                 => 'Lo resumit de la modificacion èra: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Anullacion de las modificacions de [[Special:Contributions/$2|$2]] ([[User talk:$2|Discussion]]) vèrs la darrièra version de [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Anullacion de las modificacions de $1 ; retorn a la version de $2.',
@@ -1720,7 +1720,7 @@
 aquesta accion es estada anullada en prevencion d’un piratatge de sesilha.
 Clicatz sus « Precedent » e tornatz cargar la pagina d’ont venètz, puèi ensajatz tornarmai.',
 'protectlogpage'              => 'Istoric de las proteccions',
-'protectlogtext'              => 'Vejatz las [[Special:Protectedpages|directivas]] per mai d’informacion.',
+'protectlogtext'              => 'Vejatz las [[Special:ProtectedPages|directivas]] per mai d’informacion.',
 'protectedarticle'            => 'a protegit « [[$1]] »',
 'modifiedarticleprotection'   => 'a modificat lo nivèl de proteccion de « [[$1]] »',
 'unprotectedarticle'          => 'a desprotegit « [[$1]] »',
@@ -1831,6 +1831,7 @@
 'whatlinkshere'            => 'Paginas ligadas a aquesta',
 'whatlinkshere-title'      => "Paginas qu'an de ligams puntant vèrs $1",
 'whatlinkshere-page'       => 'Pagina :',
+'whatlinkshere-barrow'     => '>',
 'linklistsub'              => '(Lista de ligams)',
 'linkshere'                => "Las paginas çaijós contenon un ligam vèrs '''[[:$1]]''':",
 'nolinkshere'              => "Cap de pagina conten pas de ligam vèrs '''[[:$1]]'''.",
@@ -1881,7 +1882,7 @@
 'badipaddress'                    => "L'adreça IP es incorrècta",
 'blockipsuccesssub'               => 'Blocatge capitat',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] es estat blocat.<br />
-Podètz consultar la [[Special:Ipblocklist|lista dels comptes e de las adreças IP blocats]].',
+Podètz consultar la [[Special:IPBlockList|lista dels comptes e de las adreças IP blocats]].',
 'ipb-edit-dropdown'               => 'Modificar los motius de blocatge per defaut',
 'ipb-unblock-addr'                => 'Desblocar $1',
 'ipb-unblock'                     => "Desblocar un compte d'utilizaire o una adreça IP",
@@ -1913,7 +1914,7 @@
 La rason balhada per $1 es : « $2 ».',
 'blocklogpage'                    => 'Istoric dels blocatges',
 'blocklogentry'                   => 'a blocat « [[$1]] » - durada : $2 $3',
-'blocklogtext'                    => "Aquò es l'istoric dels blocatges e desblocatges dels utilizaires. Las adreças IP automaticament blocadas son pas listadas. Consultatz la [[Special:Ipblocklist|lista dels utilizaires blocats]] per veire qui es actualament efectivament blocat.",
+'blocklogtext'                    => "Aquò es l'istoric dels blocatges e desblocatges dels utilizaires. Las adreças IP automaticament blocadas son pas listadas. Consultatz la [[Special:IPBlockList|lista dels utilizaires blocats]] per veire qui es actualament efectivament blocat.",
 'unblocklogentry'                 => 'a desblocat « $1 »',
 'block-log-flags-anononly'        => 'utilizaires anonims solament',
 'block-log-flags-nocreate'        => 'creacion de compte interdicha',
@@ -1961,10 +1962,10 @@
 'move-page'               => 'Tornar nomenar $1',
 'move-page-legend'        => 'Tornar nomenar una pagina',
 'movepagetext'            => "Utilizatz lo formulari çaijós per tornar nomenar una pagina, en desplaçant tot son istoric cap al nom novèl.
-Lo títol vendrà una pagina de redireccion cap al títol novèl.
-Los ligams vèrs lo títol de la pagina anciana seràn pas cambiats ;
-verificatz qu'aqueste desplaçament a pas creat de redireccion dobla.
-Vos devètz assegurar que los ligams contunhan de punter cap a lor destinacion supausada.
+Lo títol ancian vendrà una pagina de redireccion cap al títol novèl.
+Los ligams cap al títol de la pagina anciana seràn pas cambiats ;
+verificatz qu'aqueste desplaçament a pas creat de [[Special:DoubleRedirects|redireccion dobla]] o de [[Special:BrokenRedirects|redireccion copada]].
+Avètz la responsabilitat de vos assegurar que los ligams contunhen de punter cap a lor destinacion supausada.
 
 Una pagina serà pas desplaçada se la pagina del títol novèl existís ja, a mens qu'aquesta darrièra siá voida o en redireccion, e qu’aja pas d’istoric.
 Aquò vòl dire que podètz tornar nomenar una pagina vèrs sa posicion d’origina s'avètz fach una error, mas que podètz pas escafar una pagina qu'existís ja amb aqueste procediment.
@@ -1979,9 +1980,6 @@
 
 Dins aqueste cas, deuretz desplaçar o fusionar la pagina manualament se o volètz.",
 'movearticle'             => "Tornar nomenar l'article",
-'movenologin'             => 'Vos sètz pas identificat(ada)',
-'movenologintext'         => "Per poder tornar nomenar un article, vos cal èsser [[Special:Userlogin|connectat(ada)]]
-en tant qu'utilizaire enregistrat.",
 'movenotallowed'          => 'Avètz pas la permission de tornar nomenar de paginas sus {{SITENAME}}.',
 'newtitle'                => 'Títol novèl',
 'move-watch'              => 'Seguir aquesta pagina',
@@ -2010,7 +2008,7 @@
 'revertmove'              => 'anullar',
 'delete_and_move'         => 'Suprimir e tornar nomenar',
 'delete_and_move_text'    => '==Supression requesida==
-L’article de destinacion « [[$1]] » existís ja.
+L’article de destinacion « [[:$1]] » existís ja.
 Lo volètz suprimir per permetre lo cambiament de nom ?',
 'delete_and_move_confirm' => 'Òc, accèpti de suprimir la pagina de destinacion per permetre lo cambiament de nom.',
 'delete_and_move_reason'  => 'Pagina suprimida per permetre un cambiament de nom',
@@ -2019,12 +2017,13 @@
 'imagenocrossnamespace'   => 'Pòt pas desplaçar un imatge vèrs un espaci de nomenatge que siá pas un imatge.',
 'imagetypemismatch'       => "L'extension novèla d'aqueste fichièr reconeis pas aqueste format.",
 'imageinvalidfilename'    => 'Lo nom del fichièr cibla es incorrècte',
+'fix-double-redirects'    => 'Metre a jorn las redireccions que puntant cap al títol ancian',
 
 # Export
 'export'            => 'Exportar de paginas',
 'exporttext'        => "Podètz exportar en XML lo tèxt e l’istoric d’una pagina o d’un ensemble de paginas; lo resultat pòt alara èsser importat dins un autre wiki foncionant amb lo logicial MediaWiki.
 
-Per exportar de paginas, entratz lors títols dins la boita de tèxt çai jos, un títol per linha, e seleccionatz se o desiratz o pas la version actuala amb totas las versions ancianas, amb la pagina d’istoric, o simplament la pagina actuala amb d'informacions sus la darrièra modificacion.
+Per exportar de paginas, entratz lors títols dins la bóstia de tèxt çaijós, un títol per linha, e seleccionatz s'o desiratz o pas la version actuala amb totas las versions ancianas, amb la pagina d’istoric, o simplament la pagina actuala amb d'informacions sus la darrièra modificacion.
 
 Dins aqueste darrièr cas, podètz tanben utilizar un ligam, coma [[{{ns:special}}:Export/{{MediaWiki:Mainpage}}]] per la pagina [[{{MediaWiki:Mainpage}}]].",
 'exportcuronly'     => 'Exportar unicament la version correnta sens l’istoric complet',
@@ -2065,7 +2064,7 @@
 'import-interwiki-history'   => "Copiar totas las versions de l'istoric d'aquesta pagina",
 'import-interwiki-submit'    => 'Importar',
 'import-interwiki-namespace' => 'Transferir las paginas dins l’espaci de nom :',
-'importtext'                 => 'Exportatz lo fichièr dempuèi lo wiki d’origina en utilizant l’esplech Special:Export, lo salvar sus vòstre disc dur e lo copiar aicí.',
+'importtext'                 => 'Exportatz lo fichièr dempuèi lo wiki d’origina en utilizant l’esplech Special:Export, salvatz-lo sus vòstre disc dur e copiatz-lo aicí.',
 'importstart'                => 'Impòrt de las paginas...',
 'import-revision-count'      => '$1 {{PLURAL:$1|version|versions}}',
 'importnopages'              => "Cap de pagina d'importar.",
@@ -2092,7 +2091,7 @@
 'importlogpagetext'                => 'Impòrts administratius de paginas amb l’istoric a partir dels autres wikis.',
 'import-logentry-upload'           => 'a importat (telecargament) [[$1]]',
 'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|version|versions}}',
-'import-logentry-interwiki'        => '$1 version(s) dempuèi $2',
+'import-logentry-interwiki'        => 'a importat (transwiki) [[$1]]',
 'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|version|versions}} dempuèi $2',
 
 # Tooltip help for the actions
@@ -2215,10 +2214,11 @@
 'markedaspatrollederror-noautopatrol' => 'Avètz pas lo drech de marcar vòstras pròprias modificacions coma susvelhadas.',
 
 # Patrol log
-'patrol-log-page' => 'Istoric de las versions patrolhadas',
-'patrol-log-line' => 'a marcat la version $1 de $2 coma verificada $3',
-'patrol-log-auto' => '(automatic)',
-'patrol-log-diff' => '$1',
+'patrol-log-page'   => 'Istoric de las versions patrolhadas',
+'patrol-log-header' => 'Vaquí un jornal de las versions patrolhadas.',
+'patrol-log-line'   => 'a marcat la version $1 de $2 coma verificada $3',
+'patrol-log-auto'   => '(automatic)',
+'patrol-log-diff'   => '$1',
 
 # Image deletion
 'deletedrevision'                 => 'La version anciana $1 es estada suprimida.',
@@ -2247,10 +2247,10 @@
 'show-big-image'       => 'Imatge en resolucion mai nauta',
 'show-big-image-thumb' => "<small>Talha d'aqueste apercebut : $1 × $2 pixèls</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galariá dels fichièrs novèls',
 'imagelisttext'         => "Vaquí una lista de '''$1''' {{PLURAL:$1|fichièr|fichièrs}} classats $2.",
-'newimages-summary'     => 'Aquesta pagina especiala aficha los darrièrs fichièrs importats',
+'newimages-summary'     => 'Aquesta pagina especiala aficha los darrièrs fichièrs importats.',
 'showhidebots'          => '($1 bòts)',
 'noimages'              => "Cap d'imatge d'afichar pas.",
 'ilsubmit'              => 'Cercar',
@@ -2263,9 +2263,40 @@
 Solas las listas d'enumeracion (las linhas començant per *) son presas en compte. Lo primièr ligam d'una linha deu èsser cap a un imatge marrit.
 Los autres ligams sus la meteissa linha son considerats coma d'excepcions, per exemple d'articles sulsquals l'imatge deu aparéisser.",
 
+/*
+Short names for language variants used for language conversion links.
+To disable showing a particular link, set it to 'disable', e.g.
+'variantname-zh-sg' => 'disable',
+Variants for Chinese language
+*/
+'variantname-zh-hans' => 'hans',
+'variantname-zh-hant' => 'hant',
+'variantname-zh-cn'   => 'cn',
+'variantname-zh-tw'   => 'tw',
+'variantname-zh-hk'   => 'hk',
+'variantname-zh-sg'   => 'sg',
+'variantname-zh'      => 'zh',
+
+# Variants for Serbian language
+'variantname-sr-ec' => 'sr-ec',
+'variantname-sr-el' => 'sr-el',
+'variantname-sr'    => 'sr',
+
+# Variants for Kazakh language
+'variantname-kk-kz'   => 'kk-kz',
+'variantname-kk-tr'   => 'kk-tr',
+'variantname-kk-cn'   => 'kk-cn',
+'variantname-kk-cyrl' => 'kk-cyrl',
+'variantname-kk-latn' => 'kk-latn',
+'variantname-kk-arab' => 'kk-arab',
+'variantname-kk'      => 'kk',
+
+# Variants for Kurdish language
+'variantname-ku-arab' => 'ku-Arab',
+
 # Metadata
 'metadata'          => 'Metadonadas',
-'metadata-help'     => "Aqueste fichièr conten d'entresenhas suplementàrias probablament ajustadas per l’aparelh de fòto numeric o l'escanèr que las a aquesas. Se lo fichièr es estat modificat dempuèi son estat original, cèrts detalhs pòdon reflectís pas entièrament l’imatge modificat.",
+'metadata-help'     => "Aqueste fichièr conten d'entresenhas suplementàrias probablament apondudas per l’aparelh de fòto numeric o l'escanèr que las a aquesas. Se lo fichièr es estat modificat dempuèi son estat original, d'unes detalhs pòdon reflectir pas entièrament l’imatge modificat.",
 'metadata-expand'   => 'Mostrar las entresenhas detalhadas',
 'metadata-collapse' => 'Amagar las entresenhas detalhadas',
 'metadata-fields'   => 'Los camps de metadonadas d’EXIF listats dins aqueste message seràn incluses dins la pagina de descripcion de l’imatge quand la taula de metadonadas serà reduccha. Los autres camps seràn amagats per defaut.
@@ -2413,6 +2444,8 @@
 'exif-planarconfiguration-1' => 'Donadas atenentas',
 'exif-planarconfiguration-2' => 'Donadas separadas',
 
+'exif-xyresolution-c' => '$1 dpc',
+
 'exif-colorspace-ffff.h' => 'Pas calibrat',
 
 'exif-componentsconfiguration-0' => 'existís pas',
@@ -2454,6 +2487,8 @@
 'exif-lightsource-17'  => 'Lum estandard A',
 'exif-lightsource-18'  => 'Lum estandard B',
 'exif-lightsource-19'  => 'Lum estandard C',
+'exif-lightsource-22'  => 'D75',
+'exif-lightsource-23'  => 'D50',
 'exif-lightsource-24'  => "Tungstèni ISO d'estudiò",
 'exif-lightsource-255' => 'Autra font de lum',
 
@@ -2534,7 +2569,7 @@
 
 # External editor support
 'edit-externally'      => 'Modificar aqueste fichièr en utilizant una aplicacion extèrna',
-'edit-externally-help' => 'Vejatz [http://meta.wikimedia.org/wiki/Help:External_editors las instruccions] per mai d’informacions.',
+'edit-externally-help' => 'Vejatz [http://www.mediawiki.org/wiki/Manual:External_editors las instruccions] per mai d’informacions.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'totes',
@@ -2599,7 +2634,7 @@
 'recreate'            => 'Tornar crear',
 
 # HTML dump
-'redirectingto' => 'Redireccion vèrs [[$1]]...',
+'redirectingto' => 'Redireccion vèrs [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Volètz refrescar aquesta pagina (purgar l'amagatal) ?
@@ -2656,8 +2691,8 @@
 Ensajatz la previsualizacion normala.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Los cambiaments datant de mens de $1 segondas pòdon aparéisser pas dins aquesta lista.',
-'lag-warn-high'   => 'En rason d’una fòrta carga de las bancas de donadas, los cambiaments datant de mens de $1 segondas pòdon aparéisser pas dins aquesta lista.',
+'lag-warn-normal' => 'Los cambiaments que datan de mens de $1 segondas pòdon aparéisser pas dins aquesta tièra.',
+'lag-warn-high'   => 'En rason d’una fòrta carga de las bancas de donadas, los cambiaments que datan de mens de $1 {{PLURAL:$1|segonda|segondas}} pòdon aparéisser pas dins aquesta tièra.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Vòstra lista de seguit conten {{PLURAL:$1|una pagina|$1 paginas}}, sens comptar las paginas de discussion',
@@ -2673,7 +2708,7 @@
 'watchlistedit-raw-titles'     => 'Títols :',
 'watchlistedit-raw-submit'     => 'Metre la lista a jorn',
 'watchlistedit-raw-done'       => 'Vòstra lista de seguit es estada mesa a jorn.',
-'watchlistedit-raw-added'      => '{{PLURAL:$1|Una pagina es estada ajustada|$1 paginas son estadas ajustadas}} :',
+'watchlistedit-raw-added'      => '{{PLURAL:$1|Una pagina es estada aponduda|$1 paginas son estadas apondudas}} :',
 'watchlistedit-raw-removed'    => '{{PLURAL:$1|Una pagina es estada levada|$1 paginas son estadas levadas}} :',
 
 # Watchlist editing tools
@@ -2705,7 +2740,7 @@
 'version-software-product'         => 'Produch',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => "Camin d'accès d'un fichièr",
 'filepath-page'    => 'Fichièr :',
 'filepath-submit'  => "Camin d'accès",
@@ -2743,7 +2778,7 @@
 'specialpages-group-redirects'   => 'Redireccions',
 'specialpages-group-spam'        => 'Espleches pel spam',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Pagina voida',
 'intentionallyblankpage' => 'Aquesta pagina es intencionalament voida e es utilizada coma un tèst de performància, eca.',
 
Index: languages/messages/MessagesLoz.php
===================================================================
--- languages/messages/MessagesLoz.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLoz.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Litingatinga Silozi
  * @author Ooswesthoesbes
  * @author SF-Language
- * @author Litingatinga Silozi
- * @author Siebrand
- * @author Jon Harald Søby
  */
 
 $messages = array(
@@ -400,7 +398,6 @@
 'blockedoriginalsource'  => "Olige di '''$1''' sa kamukile:",
 'blockededitsource'      => "Selt di '''zwa hloli ye ng'i''' di '''$1''' sa kamukile:",
 'whitelistedittext'      => "A sa $1 di hloli ye ng'i petulo.",
-'whitelistacctitle'      => 'A ni sa di usa di hloli sebelu',
 'nosuchsectiontitle'     => 'Ni di lyangutukezi',
 'loginreqlink'           => 'menuhile',
 'loginreqpagetext'       => 'A sa $1 di kamukile xeti di petulo.',
@@ -428,7 +425,7 @@
 'template-protected'     => '(sa bukelezi)',
 'template-semiprotected' => '(bukelezi di pagafi)',
 'nocreatetext'           => '{{SITENAME}} sa simplekile petulo.
-A afi e kenki/[[Special:Userlogin|menuhile]].',
+A afi e kenki/[[Special:UserLogin|menuhile]].',
 'recreate-deleted-warn'  => "'''!: A sa hloli petulo dy sa afi kulobala.'''
 
 A sa luku a kenki dyangitubilinisize petulo.
@@ -565,7 +562,7 @@
 'uploadbtn'         => 'Imegi uplodezi',
 'reupload'          => 'Uplodezi nca',
 'uploadnologin'     => 'Ni menuhile',
-'uploadnologintext' => 'A sa [[Special:Userlogin|menuhile]]
+'uploadnologintext' => 'A sa [[Special:UserLogin|menuhile]]
 di uplodezi media.',
 'uploaderror'       => 'Bufosi duplodezi',
 'uploadlogpage'     => 'Desu di uplodezi',
@@ -584,7 +581,7 @@
 
 'license-nopreview' => '(PendiBe di nupdeti)',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'imegi',
 'imagelist'      => 'Mukoloko di imegina',
 'imagelist_user' => 'Sebelu',
@@ -699,7 +696,7 @@
 'all-logs-page'        => 'Xete desu',
 'log-search-submit'    => 'Afi',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Mukoloko di petulo',
 'alphaindexline' => '$1 di $2',
 'nextpage'       => 'Lila petulo ($1)',
@@ -714,7 +711,7 @@
 # Special:Categories
 'categories' => 'Kattegori',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Kamukile sebelu di:',
 'listusers-submit'   => 'Kamukile',
 'listusers-noresult' => 'Ni-di sebelu.',
@@ -739,10 +736,10 @@
 'mywatchlist'          => 'Zwa mukoloko di kentezi',
 'watchlistfor'         => "(di '''$1''')",
 'watchnologin'         => 'A ni sa menuhile',
-'watchnologintext'     => "A sa [[Special:Userlogin|menuhile]] di hloli ye ng'i zwa mukoloko di kentezi.",
+'watchnologintext'     => "A sa [[Special:UserLogin|menuhile]] di hloli ye ng'i zwa mukoloko di kentezi.",
 'addedwatch'           => 'Tumbelize a mukoloko di kentezi',
 'addedwatchtext'       => "Petulo \"[[:\$1]]\" sa vugisize di zwa [[Special:Watchlist|mukoloko di kentezi]].
-Petuhoni di bye petulo e sa bulelezi sa mukolokosize ta, e '''ombelu''' kwa [[Special:Recentchanges|petuho nca]] di kwazidisize akusize.
+Petuhoni di bye petulo e sa bulelezi sa mukolokosize ta, e '''ombelu''' kwa [[Special:RecentChanges|petuho nca]] di kwazidisize akusize.
 
 A sa afi kulobala di zwa mukoloko di kentezi, tampi \"ngambu kentezi\".",
 'removedwatch'         => 'Sa afi kulobala di zwa mukoloko di kentezi',
@@ -897,7 +894,6 @@
 
 Teri yaki, a nyanganyisize.",
 'movearticle'      => 'Nyanganyisize petulo:',
-'movenologin'      => 'A ni sa menuhile',
 'newtitle'         => 'Di nca petulo:',
 'move-watch'       => 'Kentezi bye petulo',
 'movepagebtn'      => 'Nyanganyisize petulo',
@@ -1021,7 +1017,7 @@
 'show-big-image'       => 'Risolusi bakisize',
 'show-big-image-thumb' => '<small>PendiBe: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Imegina nca',
 'ilsubmit'              => 'Fatukile',
 'sp-newimages-showfrom' => 'Kamukile nca imegi di $1',
@@ -1050,7 +1046,7 @@
 
 # External editor support
 'edit-externally'      => 'Kenki imegi sebilize pagini lakusi',
-'edit-externally-help' => 'Boniselelize [http://meta.wikimedia.org/wiki/Help:External_editors instruksi setup] kwa informasi.',
+'edit-externally-help' => 'Boniselelize [http://www.mediawiki.org/wiki/Manual:External_editors instruksi setup] kwa informasi.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'xeti',
@@ -1063,7 +1059,7 @@
 'trackbackremove' => ' ([$1 afi kulobala])',
 
 # HTML dump
-'redirectingto' => 'Abezi di [[$1]]...',
+'redirectingto' => 'Abezi di [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Afi',
Index: languages/messages/MessagesArc.php
===================================================================
--- languages/messages/MessagesArc.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesArc.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author 334a
- * @author SPQRobin
- * @author Siebrand
  * @author A2raya07
  * @author The Thadman
  */
@@ -160,7 +158,7 @@
 'upload'   => 'ܛܥܢܐ ܦ̮ܥܝܠ',
 'filename' => 'ܫܡܐ ܕܫܘܦܝܢܐ',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_name' => 'ܫܡܐ',
 
 # Random page
@@ -173,7 +171,7 @@
 'booksources'    => 'ܙܠ',
 'booksources-go' => 'ܙܠ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ܟܠ ܦܐܬܐ',
 'allarticles'    => 'ܟܠ ܡ̈ܓܠܐ',
 'allpagessubmit' => 'ܙܠ',
@@ -204,7 +202,7 @@
 # Namespace 8 related
 'allmessagesname' => 'ܫܡܐ',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ܛܥܘܝܐ',
 
 # 'all' in various places, this might be different for inflected languages
@@ -220,7 +218,7 @@
 # Table pager
 'table_pager_limit_submit' => 'ܙܠ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'ܫܒܝܠܐ ܕܫܘܦܝܢܐ',
 'filepath-submit' => 'ܫܒܝܠܐ',
 
Index: languages/messages/MessagesKl.php
===================================================================
--- languages/messages/MessagesKl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,8 +5,6 @@
  * @file
  *
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author M.M.S.
  */
 
 $fallback = 'da';
@@ -142,12 +140,12 @@
 # Special:Log
 'specialloguserlabel' => 'Pineqartoq:',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Pisuppoq',
 
 # Watchlist
 'addedwatch'     => 'Nakkutilliinermi allattorsimaffimmut ilanngunneqarsimavoq',
-'addedwatchtext' => "Qupperneq \"<nowiki>\$1</nowiki>\" ilanngunneqarsimavoq [[Special:Watchlist|nakkutilliinermut allattorsimaffimmut]] ilanngunneqarsimavoq. Matumani quppernermi siunissami allannguutit, aammalu oqallinnermi qupperneq, maani saqqummersinneqassapput, quppernerlu '''erseqqissagaasoq''' inisseqqassalluni [[Special:Recentchanges|allattorsimaffik kingullermi allannguutinik imalik]] ajornannginnerussammat nassaariniarnissaanut.
+'addedwatchtext' => "Qupperneq \"[[:\$1]]\" ilanngunneqarsimavoq [[Special:Watchlist|nakkutilliinermut allattorsimaffimmut]] ilanngunneqarsimavoq. Matumani quppernermi siunissami allannguutit, aammalu oqallinnermi qupperneq, maani saqqummersinneqassapput, quppernerlu '''erseqqissagaasoq''' inisseqqassalluni [[Special:RecentChanges|allattorsimaffik kingullermi allannguutinik imalik]] ajornannginnerussammat nassaariniarnissaanut.
 
 Qupperneq nakkutilliinermi allattorsimaffik kingusinnerusukkut piissagukku, taava quppernerup sinaatungaani \"Nakkutilliinermi allattorsimaffik peeruk\" tooruk.",
 'watch'          => 'Piggassineq',
Index: languages/messages/MessagesWa.php
===================================================================
--- languages/messages/MessagesWa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesWa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,7 @@
  * @file
  *
  * @author Srtxg
- * @author Siebrand
  * @author לערי ריינהארט
- * @author SPQRobin
  */
 
 $fallback = 'fr';
@@ -302,7 +300,7 @@
 'nosuchaction'      => 'Nole sifwaite accion',
 'nosuchactiontext'  => "L' accion specifieye pal hårdêye n' est nén ricnoxhowe på wiki.",
 'nosuchspecialpage' => 'Nole sifwaite pådje',
-'nospecialpagetext' => 'Vos avoz dmandé ene pådje sipeciåle nén valide, po ene djivêye des pådjes sipeciåles valides, loukîz a [[Special:Specialpages]].',
+'nospecialpagetext' => 'Vos avoz dmandé ene pådje sipeciåle nén valide, po ene djivêye des pådjes sipeciåles valides, loukîz a [[Special:SpecialPages]].',
 
 # General errors
 'error'                => 'Aroke',
@@ -474,10 +472,6 @@
 'blockededitsource'         => "Li tecse des '''candjmints da vosse''' di '''$1''' est håyné chal pa dzo:",
 'whitelistedittitle'        => "S' elodjî po candjî",
 'whitelistedittext'         => 'I vs fåt $1 po pleur candjî les årtikes.',
-'whitelistreadtitle'        => "S' elodjî po lére",
-'whitelistreadtext'         => 'I vs fåt [[Special:Userlogin|elodjî]] po pleur lére les årtikes.',
-'whitelistacctitle'         => "Vos n' avoz nén l' permission d' ahiver on conte chal",
-'whitelistacctext'          => "Po pleur ahiver on conte so ç' Wiki chal, vos dvoz esse [[Special:Userlogin|elodjî]] ey aveur les bounès permissions.",
 'confirmedittitle'          => 'Acertiner vost emile po candjî',
 'confirmedittext'           => "I vs fåt acertiner vost emile po pleur candjî les årtikes. Dinez èn emile eyet l' acertiner dins vos [[Special:Preferences|preferinces d' uzeu]].",
 'loginreqtitle'             => 'I vs fåt esse elodjî',
@@ -489,7 +483,7 @@
 'newarticletext'            => "Vos avoz clitchî so on loyén viè ene pådje ki n' egzistêye nén co.
 Mins '''vos''' l' poloz askepyî! Po çoula, vos n' avoz k' a cmincî a taper vosse tecse dins l' boesse di tecse chal pa dzo (alez vey li [[{{MediaWiki:Helppage}}|pådje d' aidance]] po pus d' infôrmåcion).
 Si vos n' voloz nén scrire cisse pådje chal, clitchîz simplumint sol boton '''En erî''' di vosse betchteu waibe po rivni al pådje di dvant.",
-'anontalkpagetext'          => "---- ''Çouchal, c' est li pådje di copene po èn uzeu anonime ki n' a nén (co) fwait on conte por lu s' elodjî, ou ki n' l' eploye nén. Ça fwait k' on doet eployî si adresse IP limerike po l' idintifyî. Come ene sifwaite adresse IP pout esse eployeye pa pus d' èn uzeu, i s' pout ki vos voeyoz chal des rmåkes et des messaedjes ki n' sont nén por vos. Loukîz s' i vs plait po [[Special:Userlogin|fé on novea conte ou s' elodjî]] po n' pus aveur d' ecramiaedje avou des ôtes uzeus anonimes.''",
+'anontalkpagetext'          => "---- ''Çouchal, c' est li pådje di copene po èn uzeu anonime ki n' a nén (co) fwait on conte por lu s' elodjî, ou ki n' l' eploye nén. Ça fwait k' on doet eployî si adresse IP limerike po l' idintifyî. Come ene sifwaite adresse IP pout esse eployeye pa pus d' èn uzeu, i s' pout ki vos voeyoz chal des rmåkes et des messaedjes ki n' sont nén por vos. Loukîz s' i vs plait po [[Special:UserLogin|fé on novea conte ou s' elodjî]] po n' pus aveur d' ecramiaedje avou des ôtes uzeus anonimes.''",
 'noarticletext'             => "I gn a pol moumint nou tecse e cisse pådje chal, vos ploz [[Special:Search/{{PAGENAME}}|cweri après l' tite di cisse pådje ci]] dins des ôtès pådjes, oudonbén [{{fullurl:{{FULLPAGENAME}}|action=edit}} ahiver l' pådje].",
 'clearyourcache'            => "'''Note:''' après aveur schapé l' pådje, vos l' divoz rafrister, po pleur vey les candjmints dins vosse betchteu waibe: '''Mozilla / Firefox / Safari:''' tchôkîz so ''Shift'' to clitchant so ''Rafrister'', ou co fjhoz ''Ctrl-Shift-R'' (''Cmd-Shift-R'' so on Macintosh); '''IE:''' tchôkîz so ''Ctrl'' tot clitchant so ''Rafrister'', ou co fjhoz ''Ctrl-F5''; '''Konqueror:''' simplumint clitchîz so ''Rafrister'' ou l' tape ''F5''; les uzeus d' '''Opera''' dvront motoit netyî pår leu muchete, dins ''Usteyes→Preferinces''.",
 'usercssjsyoucanpreview'    => "<strong>Racsegne:</strong> eployîz l' boton «Vey divant» po sayî vosse novea CSS/JS divant del schaper.",
@@ -545,7 +539,7 @@
 'template-protected'        => '(protedjî)',
 'template-semiprotected'    => '(dimey-protedjî)',
 'nocreatetitle'             => 'Ahivaedje di pådjes limité',
-'nocreatetext'              => "Cisse waibe ci a limité l' possibilité d' ahiver des novelès pådjes. Vos ploz rivni en erî eyet candjî ene pådje k' egzistêye dedja, oudonbén, [[Special:Userlogin|vos elodjî ou ahiver on conte d' uzeu]].",
+'nocreatetext'              => "Cisse waibe ci a limité l' possibilité d' ahiver des novelès pådjes. Vos ploz rivni en erî eyet candjî ene pådje k' egzistêye dedja, oudonbén, [[Special:UserLogin|vos elodjî ou ahiver on conte d' uzeu]].",
 
 # History pages
 'viewpagelogs'        => 'Vey les djournås po cisse pådje ci',
@@ -634,7 +628,7 @@
 'mypreferences'            => 'Mes preferinces',
 'prefs-edits'              => 'Nombe di candjmints:',
 'prefsnologin'             => "Vos n' estoz nén elodjî",
-'prefsnologintext'         => 'I vs fåt esse [[Special:Userlogin|elodjî]] po pleur candjî vos preferinces.',
+'prefsnologintext'         => 'I vs fåt esse [[Special:UserLogin|elodjî]] po pleur candjî vos preferinces.',
 'prefsreset'               => "Les preferinces ont stî rmetowes come d' avance a pårti des wårdêyès valixhances.",
 'qbsettings'               => 'Apontiaedjes pol bår di menu',
 'qbsettings-none'          => 'Nole bår',
@@ -751,12 +745,12 @@
 'reupload'                    => 'En erî',
 'reuploaddesc'                => "Rivni al pådje d' eberwetaedje.",
 'uploadnologin'               => 'Nén elodjî',
-'uploadnologintext'           => 'I vs fåt esse [[Special:Userlogin|elodjî]] por vos pleur eberweter des fitchîs.',
+'uploadnologintext'           => 'I vs fåt esse [[Special:UserLogin|elodjî]] por vos pleur eberweter des fitchîs.',
 'upload_directory_read_only'  => "Li sierveu waibe èn pout nén scrire sol ridant d' eberwetaedje ($1).",
 'uploaderror'                 => "Aroke d' eberwetaedje",
 'uploadtext'                  => "Eployîz les boesses d' intrêye chal pa dzo po-z eberweter des noveas fitchîs d' imådjes po vos årtikes. Sol plupårt des betchteus, vos voeroz on boton «Foyter...» (ou «Browse...») ki vs permetrè di foyter dins les ridants del deure plake da vosse po tchoezi l' fitchî, çou ki rimplirè otomaticmint li tchamp do no do fitchî k' est a costé.
 
-Po håyner ou cweri des imådjes k' ont ddja stî rçuvowes, alez sol [[Special:Imagelist|djivêye des imådjes dedja eberwetêyes]]. Les eberwetaedjes et disfaçaedjes sont metous èn on [[Special:Log/upload|djournå des eberwetaedjes]].
+Po håyner ou cweri des imådjes k' ont ddja stî rçuvowes, alez sol [[Special:ImageList|djivêye des imådjes dedja eberwetêyes]]. Les eberwetaedjes et disfaçaedjes sont metous èn on [[Special:Log/upload|djournå des eberwetaedjes]].
 
 Po håyner l' imådje dins èn årtike, eployîz on loyén del foûme
 * '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Fitchî.jpg]]</nowiki>'''
@@ -800,7 +794,7 @@
 'nolicense'          => 'Nole licince tchoezeye',
 'upload_source_file' => ' (on fitchî sol copiutrece da vosse)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => "Cweri l' no d' imådje:",
 'imgfile'               => 'fitchî',
 'imagelist'             => 'Djivêye des imådjes',
@@ -934,7 +928,7 @@
 Vos ploz limiter l' håynaedje tot tchoezixhant ene sôre di djournå, on no d' uzeu, ou l' tite d' ene pådje.",
 'logempty'             => "Rén n' corespond dins l' djournå.",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Totes les pådjes',
 'alphaindexline'    => 'di $1 a $2',
 'nextpage'          => 'Pådje shuvante ($1)',
@@ -954,7 +948,7 @@
 
 # E-mail user
 'mailnologin'     => "Nole adresse d' evoyeu",
-'mailnologintext' => "Po-z evoyî èn emile a èn ôte uzeu i vs fåt esse [[Special:Userlogin|elodjî]] eyet aveur ene adresse emile d' evoyeu ki soeye valide dins vos [[Special:Preferences|preferinces]].",
+'mailnologintext' => "Po-z evoyî èn emile a èn ôte uzeu i vs fåt esse [[Special:UserLogin|elodjî]] eyet aveur ene adresse emile d' evoyeu ki soeye valide dins vos [[Special:Preferences|preferinces]].",
 'emailuser'       => "Emiler a l' uzeu",
 'emailpage'       => 'Emilaedje a èn uzeu',
 'emailpagetext'   => "Si cist uzeu chal a dné ene adresse emile valide dins
@@ -983,12 +977,12 @@
 'nowatchlist'          => 'Vosse djivêye des pådjes a shuve est vude.',
 'watchlistanontext'    => 'I vs fåt $1 po vey ou candjî les cayets di vosse djivêye des shuvous.',
 'watchnologin'         => "Vos n' estoz nén elodjî",
-'watchnologintext'     => 'I vs fåt esse [[Special:Userlogin|elodjî]] po pleur candjî vosse djivêye des pådjes a shuve.',
+'watchnologintext'     => 'I vs fåt esse [[Special:UserLogin|elodjî]] po pleur candjî vosse djivêye des pådjes a shuve.',
 'addedwatch'           => 'Radjouté ås shuvous',
 'addedwatchtext'       => "Li pådje «<nowiki>$1</nowiki>» a stî radjoutêye a vosse [[Special:Watchlist|djivêye des pådjes a shuve]].
 Tos les candjmints k' i gn årè di cisse pådje chal,
 eyet di si pådje di copene, seront håynés chal, eyet li pådje serè metowe e '''cråssès letes'''
-el [[Special:Recentchanges|djivêye des dierins candjmints]] po k' ça soeye pus åjhey por vos del rimårker.
+el [[Special:RecentChanges|djivêye des dierins candjmints]] po k' ça soeye pus åjhey por vos del rimårker.
 
 Si vos vloz bodjî l' pådje foû di vosse djivêye des shuvous, clitchîz so «Èn pus shuve li pådje» dins l' bår di menu sol costé.",
 'removedwatch'         => 'Bodjî foû des shuvous',
@@ -1156,7 +1150,7 @@
 'ipbotheroption'              => 'ôte',
 'badipaddress'                => "Nol uzeu avou ç' no la, ou adresse IP nén valide",
 'blockipsuccesssub'           => 'Li blocaedje a stî comifåt',
-'blockipsuccesstext'          => '«[[Special:Contributions/$1|$1]]» a stî bloké.<br />Loukîz li [[Special:Ipblocklist|djivêye des blocaedjes]] po candjî on blocaedje.',
+'blockipsuccesstext'          => '«[[Special:Contributions/$1|$1]]» a stî bloké.<br />Loukîz li [[Special:IPBlockList|djivêye des blocaedjes]] po candjî on blocaedje.',
 'unblockip'                   => 'Disbloker èn uzeu',
 'unblockiptext'               => "Rimplixhoz les tchamps chal pa dzo po ridner accès e scrijhaedje a èn uzeu ou adresse IP k' estént blokés.",
 'ipusubmit'                   => 'Disbloker ciste adresse ci',
@@ -1172,7 +1166,7 @@
 'autoblocker'                 => "Bloké otomaticmint paski vos eployîz li minme adresse IP ki «[[User:$1|$1]]». Råjhon do blocaedje «'''$2'''».",
 'blocklogpage'                => 'Djournå des blocaedjes',
 'blocklogentry'               => '«[[$1]]» a stî bloké po ene termene di $2',
-'blocklogtext'                => "Çouchal, c' est on djournå des blocaedjes eyet disblocaedjes d' uzeus. Les adresses IP blokêyes otomaticmint èn sont nén håynêyes. Loukîz li [[Special:Ipblocklist|djivêye des adresses IP blokêyes]] po vey les blocaedjes d' adresses IP do moumint.",
+'blocklogtext'                => "Çouchal, c' est on djournå des blocaedjes eyet disblocaedjes d' uzeus. Les adresses IP blokêyes otomaticmint èn sont nén håynêyes. Loukîz li [[Special:IPBlockList|djivêye des adresses IP blokêyes]] po vey les blocaedjes d' adresses IP do moumint.",
 'unblocklogentry'             => '«$1» a stî disbloké',
 'range_block_disabled'        => "Li possibilité po les manaedjeus di bloker des fortchetes d' adresses IP a stî dismetowe.",
 'ipb_expiry_invalid'          => 'Tins di blocaedje nén valide.',
@@ -1206,8 +1200,6 @@
 si contnou, si vos l' vloz mete adlé l' novea no
 d' l' årtike.",
 'movearticle'             => 'Displaecî di',
-'movenologin'             => 'Nén elodjî',
-'movenologintext'         => 'I vs fåt esse èn uzeu eredjîstré eyet esse [[Special:Userlogin|elodjî]] por vos pleur displaecî ene pådje.',
 'newtitle'                => "Viè l' novea tite",
 'movepagebtn'             => 'Displaecî',
 'pagemovedsub'            => 'Li displaçaedje a stî comifåt',
@@ -1226,7 +1218,7 @@
 'delete_and_move'         => 'Disfacer et displaecî',
 'delete_and_move_text'    => "==I gn a mezåjhe di disfacer==
 
-L' årtike såme «[[$1]]» egzistêye dedja. El voloz vs disfacer po vs permete di displaecî l' ôte?",
+L' årtike såme «[[:$1]]» egzistêye dedja. El voloz vs disfacer po vs permete di displaecî l' ôte?",
 'delete_and_move_confirm' => "Oyi, disfacer l' pådje",
 'delete_and_move_reason'  => 'Disfacé po permete on displaeçaedje',
 'selfmove'                => 'Les tites sourdant et såme sont les minmes; ene pådje ni pout nén esse displaeceye so leye minme.',
@@ -1380,7 +1372,7 @@
 'imagemaxsize' => "Limite pol håynaedje ezès pådjes d' imådje:",
 'thumbsize'    => 'Grandeu po les imådjetes (thumb):',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galreye des nouvès imådjes',
 'imagelisttext'         => "Chal pa dzo c' est ene djivêye di '''$1''' {{PLURAL:$1|imådje relîte|imådjes relîtes}} $2.",
 'showhidebots'          => '($1 robots)',
@@ -1514,7 +1506,7 @@
 
 # External editor support
 'edit-externally'      => "Candjî ç' fitchî ci avou on dfoûtrin programe",
-'edit-externally-help' => "Loukîz les [http://meta.wikimedia.org/wiki/Help:External_editors instruccions d' apontiaedje] po pus di racsegnes.",
+'edit-externally-help' => "Loukîz les [http://www.mediawiki.org/wiki/Manual:External_editors instruccions d' apontiaedje] po pus di racsegnes.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'totafwait',
@@ -1564,7 +1556,7 @@
 'recreate'            => 'Rifé',
 
 # HTML dump
-'redirectingto' => 'Redjiblant viè [[$1]]...',
+'redirectingto' => 'Redjiblant viè [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => "Netyî l' muchete di cisse pådje ci?
Index: languages/messages/MessagesCv.php
===================================================================
--- languages/messages/MessagesCv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesCv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author PCode
- * @author Siebrand
  * @author Chavash
+ * @author PCode
  */
 
 $fallback = 'ru';
@@ -312,7 +311,7 @@
 'nosuchaction'      => 'Ку ĕçе тăваймастпăр',
 'nosuchactiontext'  => 'URLта çырнă хушăва вики скрипчĕ ăнланмасть',
 'nosuchspecialpage' => 'Вăл ятлă ятарлă страница çук',
-'nospecialpagetext' => 'Эсир ыйтакан ятарлă страница çук. [[Special:Specialpages|Ятарлă страницăсен списокне]] пăхăр.',
+'nospecialpagetext' => 'Эсир ыйтакан ятарлă страница çук. [[Special:SpecialPages|Ятарлă страницăсен списокне]] пăхăр.',
 
 # General errors
 'error'                => 'Йăнăш',
@@ -485,14 +484,13 @@
 
 $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|администраторсем]] патне эсир çыру ярса меншĕн ĕçлеме чарнине сӳтсе явма пултаратăр.
 
-Асăрхар: [[{{ns:special}}:Preferences|хăвăрăн ĕнерлевсенче]] эл. почта адресне çирĕплетмен пулсан, е сайта кĕмен пулсан — администратор патне çыру яраймастăр. Администратор сире çыру яма чарнă пулсан — ку хутĕнче те çыру яраймăр.
+Асăрхар: [[Special:Preferences|хăвăрăн ĕнерлевсенче]] эл. почта адресне çирĕплетмен пулсан, е сайта кĕмен пулсан — администратор патне çыру яраймастăр. Администратор сире çыру яма чарнă пулсан — ку хутĕнче те çыру яраймăр.
 
 Сирĕн IP-адрес — $3, чару идентификаторĕ — #$5. Çырусенче, тархасшăн, вĕсене пĕлтерĕр.",
 'blockednoreason'        => 'сăлтавне пĕлтермен',
 'blockedoriginalsource'  => 'Аяларах «$1» страницăн текстне куратăр.',
 'blockededitsource'      => "Аяларах эсир «$1» страницăра '''хăвсамăр тунă''' улшăнусене куратăр.",
 'whitelistedittitle'     => 'Улăштарма сирĕн авторизациленмелле',
-'whitelistreadtitle'     => 'Вулас тесен малтан сайта кĕмелле',
 'loginreqtitle'          => 'Сайта кĕмелле',
 'loginreqlink'           => 'сайта кĕр',
 'loginreqpagetext'       => 'Ытти страницăсене курмашкăн сирĕн $1.',
@@ -685,7 +683,7 @@
 'upload'             => 'Файла кĕртесси',
 'uploadbtn'          => 'Файла кĕрт',
 'uploadnologin'      => 'Эсир сайта кĕмен.',
-'uploadnologintext'  => 'Файла кĕртес умĕн сирĕн малтан [[Special:Userlogin|сайта кĕмелле]].',
+'uploadnologintext'  => 'Файла кĕртес умĕн сирĕн малтан [[Special:UserLogin|сайта кĕмелле]].',
 'uploaderror'        => 'Файла кĕртне чухне йăнăш пулчĕ',
 'uploadlog'          => 'Файлсене кĕртнин логĕ',
 'uploadlogpage'      => 'Файлсене кĕртнине кăтартакан журнал',
@@ -724,7 +722,7 @@
 'upload_source_url'  => ' (тĕрĕс, пурте курма пултаракан интертетел адресĕ)',
 'upload_source_file' => ' (сирĕн компьютер çинчи файл)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Ку ятарлă страницăра эсир пур кĕртнĕ файлсене куратăр.
 Нумай пулмасть кĕртнисем çулте вырнаçнă.
 Юпа тăррине пуссан йĕркелӳ майĕ улшăнĕ.',
@@ -785,13 +783,11 @@
 'statistics-mostpopular' => 'Чи нумай пăхакан страницăсем',
 
 'disambiguations'      => 'Нумай пĕлтерĕшлĕ статьясене кăтартакан страницăсем',
-'disambiguationspage'  => "Admins, please maintain this page by including links to all disambiguation templates and any redirects to them.
-The list is used by [[Special:Disambiguations]] to show any pages linking to disambiguation articles. The list will also be used by various bots.
+'disambiguationspage'  => 'Template:Disambig',
+'disambiguations-text' => "Çак статьясем '''нумай пĕлтерĕшле страницăсем'''çине куçараççĕ.
+Унта куçарас вырăнне вĕсем кирлĕ страницăсем çине куçармалла пулĕ.<br />
+Енчен те страница çинче [[MediaWiki:Disambiguationspage]] страницăра кăтартнă шаблон ятне вырнаçтарнă пулсан вăл нумай пĕлтерĕшлĕ страница шутланать.",
 
-<small>Note: This page may be translated and reformatted. Any links to '''<nowiki>[[template:...]]</nowiki>''' will be treated as links to disambiguation templates.</small>
-* [[Шаблон:Disambig]]",
-'disambiguations-text' => "Çак статьясем '''нумай пĕлтерĕшле страницăсем''' çине куçараççĕ. Унта куçарас вырăнне вĕсем кирлĕ страницăсем çине куçармалла пулĕ.<br />Енчен те страница çинче [[MediaWiki:disambiguationspage]] страницăра кăтартнă шаблон ятне вырнаçтарнă пулсан вăл нумай пĕлтерĕшлĕ страница шутланать.",
-
 'doubleredirects' => 'Икĕ хут куçаракансем',
 
 'brokenredirects'        => 'Татăк куçару страницисем',
@@ -844,7 +840,7 @@
 'all-logs-page'       => 'Журналсем',
 'log-search-submit'   => 'Туп',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'         => 'Пěтěм страницăсем',
 'alphaindexline'   => '$1-$2',
 'nextpage'         => 'Тепěр страницă ($1)',
@@ -864,11 +860,11 @@
 'special-categories-sort-count' => 'шучĕ тăрăх йĕркеле',
 'special-categories-sort-abc'   => 'алфавит тăрăх йĕркеле',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Кăтарт',
 'listusers-noresult' => 'Хутшăнакансем тупăнмарĕç.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights-group'    => 'Ушкăн',
 'listgrouprights-helppage' => 'Help:Ушкăн прависем',
 
@@ -890,9 +886,9 @@
 'mywatchlist'          => 'Ман сăнав списокĕ',
 'nowatchlist'          => 'Эсир пăхса тăракан страницăсен списокĕ пушă.',
 'watchnologin'         => 'Системăна хăвăр ята каламалла',
-'watchnologintext'     => 'Сăнав списокне улăштармашкăн сирĕн системăна [[Special:Userlogin|хăвăр ята каламалла]].',
+'watchnologintext'     => 'Сăнав списокне улăштармашкăн сирĕн системăна [[Special:UserLogin|хăвăр ята каламалла]].',
 'addedwatch'           => 'Сăнамалли шутне кĕртрĕмĕр',
-'addedwatchtext'       => '«[[:$1]]» страницăна сирĕн [[Special:Watchlist|сăнав списока]] хушрăмăр. Малашне [[Special:Recentchanges|юлашки улшăнусене кăтартакан страницăра]] унпа çыхăннă улшăнусене хылăм шрифтпа курăнĕç.
+'addedwatchtext'       => '«[[:$1]]» страницăна сирĕн [[Special:Watchlist|сăнав списока]] хушрăмăр. Малашне [[Special:RecentChanges|юлашки улшăнусене кăтартакан страницăра]] унпа çыхăннă улшăнусене хылăм шрифтпа курăнĕç.
 Енчен те сирĕн ку страницăна сăнас кăмăл пĕтсен, «ан сăна» пускăч çине пусăр.',
 'removedwatch'         => 'Сăнамалли списокран кăларса пăрахнă',
 'removedwatchtext'     => '«[[:$1]]» страницăна сирĕн сăнамалли списокран кăларса пăрахнă.',
@@ -985,7 +981,7 @@
 'badipaddress'             => 'IP-адрес формачĕ тĕрĕс мар, е ку ятлă хутшăнакан кунта çук.',
 'blockipsuccesssub'        => 'Ĕçлеме чартăмăр',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|«$1»]] ĕçлеме чарнă.
-<br />[[Special:Ipblocklist|ĕçлеме чарнă IP-адрессен списокне]] пăх.',
+<br />[[Special:IPBlockList|ĕçлеме чарнă IP-адрессен списокне]] пăх.',
 'unblockip'                => 'IP-адреса блокировкăран калар',
 'unblocked-id'             => '$1 чарса лартнине ирĕке кăларнă',
 'ipblocklist'              => 'Чарнă IP-адрессемпе хутшăнакансен списокĕ',
@@ -1004,7 +1000,6 @@
 # Move page
 'move-page-legend'        => 'Страницăна куçарнă',
 'movearticle'             => 'Страницăн ятне улăштар',
-'movenologin'             => 'Система сирĕн ята пĕлмест',
 'newtitle'                => 'Çĕнĕ ят',
 'move-watch'              => 'Ку страницăна сăнамаллисем шутне хуш',
 'movepagebtn'             => 'Страницăн ятне улăштар',
@@ -1019,7 +1014,7 @@
 'movereason'              => 'Сăлтавĕ',
 'delete_and_move'         => 'Кăларса пăрахса куçарасси',
 'delete_and_move_text'    => '==Кăларса пăрахмалла==
-[[$1|«$1»]] ятлă страница пур. Урăх ят парас тесе ăна кăларса пăрахмалла-и?',
+[[:$1|«$1»]] ятлă страница пур. Урăх ят парас тесе ăна кăларса пăрахмалла-и?',
 'delete_and_move_confirm' => 'Ку страницăна чăнах та кăларса пăрахмалла',
 'delete_and_move_reason'  => 'Урăх ят памашкăн кăларса парахнă',
 
@@ -1114,7 +1109,7 @@
 'file-info-size' => '($1 × $2 пиксел, файл пысăкăше: $3, MIME-тĕсĕ: $4)',
 'file-nohires'   => '<small>Пысăкрах калăпăшли çук.</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'         => 'Çĕнĕ файлсен галерейи',
 'newimages-summary' => 'Ку ятарлă страницăра эсир нумай пулмасть кĕртнĕ файлсене куратăр',
 'noimages'          => 'Ӳкерчĕксем çук.',
@@ -1159,7 +1154,7 @@
 'recreate'            => 'Çĕнĕрен пуçла',
 
 # HTML dump
-'redirectingto' => '[[$1]] çине куçаракан страница …',
+'redirectingto' => '[[:$1]] çине куçаракан страница …',
 
 # AJAX search
 'searchcontaining' => 'Ăшĕсенче «$1» пур статьясене шыратпăр.',
@@ -1199,7 +1194,7 @@
 # Special:Version
 'version' => 'MediaWiki версийĕ', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath'        => 'Файл çулĕ',
 'filepath-submit' => 'Çул',
 
Index: languages/messages/MessagesGu.php
===================================================================
--- languages/messages/MessagesGu.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesGu.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,11 +4,9 @@
  * @ingroup Language
  * @file
  *
+ * @author Aksi great
  * @author Dsvyas
  * @author לערי ריינהארט
- * @author Aksi great
- * @author Siebrand
- * @author SPQRobin
  */
 
 $digitTransformTable = array(
@@ -120,12 +118,15 @@
 'about'         => 'વિષે',
 'newwindow'     => '(નવા પાનામાં ખુલશે)',
 'cancel'        => 'રદ કરો',
+'qbfind'        => 'શોધો',
+'qbedit'        => 'ફેરફાર કરો',
 'moredotdotdot' => 'વધારે...',
 'mypage'        => 'મારું પાનું',
 'mytalk'        => 'મારી ચર્ચા',
 'navigation'    => 'ભ્રમણ',
 'and'           => 'અને',
 
+'errorpagetitle'   => 'ત્રુટિ',
 'returnto'         => '$1 પર પાછા જાઓ.',
 'tagline'          => '{{SITENAME}} થી',
 'help'             => 'મદદ',
@@ -223,16 +224,31 @@
 'nav-login-createaccount' => 'પ્રવેશ કરો / નવું ખાતું ખોલો',
 'loginprompt'             => '{{SITENAME}}માં પ્રવેશ કરવા માટે તમારા બ્રાઉઝરમાં કુકીઝ એનેબલ કરેલી હોવી જોઇશે.',
 'userlogin'               => 'પ્રવેશ કરો / નવું ખાતું ખોલો',
+'logout'                  => 'બહાર નીકળો',
 'userlogout'              => 'બહાર નીકળો/લૉગ આઉટ',
 'nologin'                 => 'શું તમારૂં ખાતું નથી? $1.',
 'nologinlink'             => 'ખાતું ખોલો',
 'createaccount'           => 'નવું ખાતું ખોલો',
+'gotaccount'              => 'પહેલેથી ખાતું ખોલેલું છે? $1.',
 'gotaccountlink'          => 'પ્રવેશો (લૉગ ઇન કરો)',
 'yourrealname'            => 'સાચું નામ:',
 'yourlanguage'            => 'ભાષા',
+'prefs-help-realname'     => 'સાચું નામ મરજીયાત છે.
+જો આપ સાચું નામ આપવાનું પસંદ કરશો, તો તેનો ઉપયોગ તમારા કરેલાં યોગદાનનું શ્રેય આપવા માટે થશે.',
+'loginsuccesstitle'       => 'પ્રવેશ સફળ',
 'loginsuccess'            => "'''તમે હવે {{SITENAME}}માં \"\$1\" તરીકે પ્રવેશી ચુક્યા છો.'''",
+'nosuchuser'              => '"$1" નામ ધરાવતો કોઇ સભ્ય અસ્તિત્વમાં નથી.
+કૃપા કરી સ્પેલીંગ/જોડણી ચકાસો અથવા નવું ખાતુ ખોલો.',
 'nosuchusershort'         => '"<nowiki>$1</nowiki>" નામનો કોઇ સભ્ય નથી, તમારી જોડણી તપાસો.',
+'nouserspecified'         => 'તમારે સભ્ય નામ દર્શાવવાની જરૂર છે.',
+'wrongpassword'           => 'તમે લખેલી ગુપ્ત સંજ્ઞા ખોટી છે.
+ફરીથી પ્રયત્ન કરો.',
+'wrongpasswordempty'      => 'તમે ગુપ્ત સંજ્ઞા લખવાનું ભુલી ગયા લાગો છો.
+ફરીથી પ્રયત્ન કરો.',
+'passwordtooshort'        => 'તમે દાખલ કરેલી ગુપ્ત સંજ્ઞા ખુબજ ટુંકી છે અથવા અસ્વિકાર્ય છે.
+તેમાં ઓછામાં {{PLURAL:$1|ઓછો એક અક્ષર હોવો |ઓછા $1 અક્ષર હોવા}} જોઇએ અને તેમાં તમારા સભ્ય નામનો સમાવેશ ના થવો જોઇએ.',
 'mailmypassword'          => 'પાસવર્ડ ઇ-મેલમાં મોકલો',
+'passwordremindertitle'   => '{{SITENAME}} માટેની નવી કામચલાઉ ગુપ્ત સંજ્ઞા',
 'accountcreated'          => 'ખાતું ખોલવામાં આવ્યું છે',
 
 # Edit page toolbar
@@ -266,6 +282,19 @@
 'showdiff'               => 'ફેરફારો બતાવો',
 'anoneditwarning'        => "'''ચેતવણી:''' તમે તમારા સભ્ય નામથી પ્રવેશ કર્યો નથી.
 આ પાનાનાં ઇતિહાસમાં તમારૂં આઇ.પી. (IP) એડ્રેસ નોંધવામાં આવશે.",
+'blockedtext'            => "<big>'''આપનાં સભ્ય નામ અથવા આઇ.પી. એડ્રેસ પર પ્રતિબંધ મુકવામાં આવ્યો છે.'''</big>
+
+આ પ્રતિબંધ  $1એ મુક્યો છે.
+જેને માટે કારણ આપવામાં આવ્યું છે કે, ''$2''.
+
+* પ્રતિબંધ મુક્યા તારીખ: $8
+* પ્રતિબંધ ઉઠાવવાની તારીખ: $6
+* જેના ઉપર પ્રતિબંધ મુક્યો છે તે: $7
+
+આપનાં પર મુકવામાં આવેલાં પ્રતિબંધ વિષે ચર્ચા કરવા માટે આપ $1નો કે અન્ય [[{{MediaWiki:Grouppage-sysop}}|પ્રબંધક]]નો સંપર્ક કરી શકો છો.
+આપ 'સભ્યને ઇ-મેલ કરો' ની કડી વાપરી નહી શકો, પરંતુ જો આપનાં [[Special:Preferences|મારી પસંદ]]માં યોગ્ય ઇ-મેલ સરનામું વાપર્યું હશે અને તમારા તે ખાતું વાપરવા ઉપર પ્રતિબંધ નહી મુક્યો હોય તો તમે તે કડીનો ઉપયોગ કરી શકશો.
+તમારૂં હાલનું આઇ.પી સરનામું છે $3, અને જેના પર પ્રતિબંધ મુકવામાં આવ્યો છે તે છે  #$5.
+મહેરબાની કરીને કોઇ પણ પત્ર વ્યવહારમાં ઉપરનાંમાંથી એકનો કે બન્નેનો ઉલ્લેખ કરશો.",
 'blockededitsource'      => "'''$1''' માટે '''તમારા ફેરફારો''' નીચે દેખાય છે:",
 'newarticle'             => '(નવિન)',
 'newarticletext'         => "આપ જે કડીને અનુસરીને અહીં પહોંચ્યા છો તે પાનું અસ્તિત્વમાં નથી.
@@ -281,11 +310,15 @@
 <br />જો આપ ના ચાહતા હોવ કે તમારા યોગદાનમાં અન્ય કોઇ વ્યક્તિ બેધડક પણે ફેરફાર કરે અને તેને પુનઃપ્રકાશિત કરે, તો અહીં યોગદાન કરશો નહી.
 <br />સાથે સાથે તમે અમને એમ પણ ખાતરી આપી રહ્યા છો કે આ લખાણ તમે મૌલિક રીતે લખ્યું છે, અથવાતો પબ્લિક ડોમેઇન કે તેવા અન્ય મુક્ત સ્ત્રોતમાંથી લીધું છે.
 <br /><strong>પરવાનગી વગર પ્રકાશનાધિકાર થી સુરક્ષિત (COPYRIGHTED) કાર્ય અહીં પ્રકાશિત ના કરશો!</strong>',
+'longpagewarning'        => '<strong>ચેતવણી: આ પાનું $1 કિલોબાઇટ્સ લાંબુ છે;
+કેટલાંક બ્રાઉઝરોમાં લગભગ ૩૨ કિલોબાઇટ્સ જેટલાં કે તેથી મોટાં પાનાઓમાં ફેરફાર કરવામાં મુશ્કેલી પડી શકે છે.
+બને ત્યાં સુધી પાનાને નાનાં વિભાગોમાં વિભાજીત કરી નાંખો.</strong>',
 'templatesused'          => 'આ પાનામાં વપરાયેલા ઢાંચાઓ:',
+'templatesusedpreview'   => 'આ પૂર્વાવલોકનમાં વપરાયેલાં ઢાંચાઓ:',
 'template-protected'     => '(સુરક્ષિત)',
 'template-semiprotected' => '(અર્ધ સુરક્ષિત)',
 'nocreatetext'           => '{{SITENAME}}માં નવું પાનુ બનાવવા ઉપર નિયંત્રણ આવી ગયું છે.
-<br />આપ પાછા જઇને હયાત પાનામાં ફેરફાર કરી શકો છો, નહિતર [[Special:Userlogin|પ્રવેશ કરો કે નવું ખાતું ખોલો]].',
+<br />આપ પાછા જઇને હયાત પાનામાં ફેરફાર કરી શકો છો, નહિતર [[Special:UserLogin|પ્રવેશ કરો કે નવું ખાતું ખોલો]].',
 'recreate-deleted-warn'  => "'''ચેતવણી: તમે જે પાનું નવું બનાવવા જઇ રહ્યાં છો તે પહેલાં દૂર કરવામાં આવ્યું છે.'''
 
 આગળ વધતાં બે વખત વિચારજો અને જો તમને લાગે કે આ પાનું ફરી વાર બનાવવું ઉચિત છે, તો જ અહીં ફેરફાર કરજો.
@@ -309,12 +342,16 @@
 'histlast'            => 'સૌથી નવું',
 'historyempty'        => '(ખાલી)',
 
+# Revision feed
+'history-feed-item-nocomment' => '$1, $2 સમયે', # user at time
+
 # Diffs
 'history-title'           => '"$1" નાં ફેરફારોનો ઇતિહાસ',
 'difference'              => '(પુનરાવર્તનો વચ્ચેનો તફાવત)',
 'lineno'                  => 'લીટી $1:',
 'compareselectedversions' => 'પસંદ કરેલા સરખાવો',
 'editundo'                => 'રદ કરો',
+'diff-multi'              => '({{PLURAL:$1|વચગાળાનું એક પુનરાવર્તન|વચગાળાનાં $1 પુનરાવર્તનો}} દર્શાવેલ નથી.)',
 
 # Search results
 'searchresults' => 'પરિણામોમાં શોધો',
@@ -326,6 +363,7 @@
 'powersearch'   => 'શોધો (વધુ પર્યાય સાથે)',
 
 # Preferences page
+'preferences'       => 'પસંદ',
 'mypreferences'     => 'મારી પસંદ',
 'datetime'          => 'તારીખ અને સમય',
 'prefs-watchlist'   => 'ધ્યાનસૂચી',
@@ -345,11 +383,14 @@
 'grouppage-sysop' => '{{ns:project}}:પ્રબંધકો',
 
 # User rights log
+'rightslog'  => 'સભ્ય હક્ક માહિતિ પત્રક',
 'rightsnone' => '(કોઈ નહિ)',
 
 # Recent changes
+'nchanges'          => '$1 {{PLURAL:$1|ફેરફાર|ફેરફારો}}',
 'recentchanges'     => 'હાલ માં થયેલા ફેરફાર',
 'rcnote'            => "નીચે $5, $4 સુધીમાં અને તે પહેલાનાં '''$2''' દિવસમાં {{PLURAL:$1| થયેલો '''1''' માત્ર ફેરફાર|થયેલાં છેલ્લા  '''$1''' ફેરફારો}} દર્શાવ્યાં છે .",
+'rcnotefrom'        => "નીચે '''$2'''થી થયેલાં '''$1''' ફેરફારો દર્શાવ્યાં છે.",
 'rclistfrom'        => '$1 બાદ થયેલા નવા ફેરફારો બતાવો',
 'rcshowhideminor'   => 'નાના ફેરફારો $1',
 'rcshowhidebots'    => 'બૉટો $1',
@@ -374,53 +415,75 @@
 <br />[[Special:Watchlist|તમારી ધ્યાનસૂચિમાં]] હોય તેવા પાનાં '''ઘાટા અક્ષર'''માં વર્ણવ્યાં છે",
 
 # Upload
-'upload'     => 'ફાઇલ ચડાવો',
-'uploadbtn'  => 'ફાઇલ ચડાવો',
-'reupload'   => 'ફરી ચડાવો',
-'filesource' => 'સ્ત્રોત:',
+'upload'        => 'ફાઇલ ચડાવો',
+'uploadbtn'     => 'ફાઇલ ચડાવો',
+'reupload'      => 'ફરી ચડાવો',
+'uploadlogpage' => 'ચઢાવેલી ફાઇલોનું માહિતિ પત્રક',
+'filesource'    => 'સ્ત્રોત:',
 
+# Special:ImageList
+'imagelist' => 'ફાઇલોની યાદી',
+
 # Image description page
-'filehist'            => 'ફાઇલનો ઇતિહાસ',
-'filehist-help'       => 'તારિખ/સમય ઉપર ક્લિક કરવાથી તે સમયે ફાઇલ કેવી હતી તે જોવા મળશે',
-'filehist-current'    => 'વર્તમાન',
-'filehist-datetime'   => 'તારીખ/સમય',
-'filehist-user'       => 'સભ્ય',
-'filehist-dimensions' => 'પરિમાણ',
-'filehist-filesize'   => 'ફાઇલનું કદ',
-'filehist-comment'    => 'ટિપ્પણી',
-'imagelinks'          => 'કડીઓ',
-'linkstoimage'        => 'આ ફાઇલ સાથે {{PLURAL:$1|નીચેનું પાનું જોડાયેલું|$1 નીચેનાં પાનાઓ જોડાયેલાં}} છે',
-'nolinkstoimage'      => 'આ ફાઇલ સાથે કોઇ પાનાં જોડાયેલાં નથી.',
-'sharedupload'        => 'આ ફાઇલ સહિયારી રીતે ચઢાવવામાં આવી છે અને તેનો ઉપયોગ અન્ય પરિયોજનાઓમાં પણ થઇ શકે છે.',
+'filehist'                  => 'ફાઇલનો ઇતિહાસ',
+'filehist-help'             => 'તારિખ/સમય ઉપર ક્લિક કરવાથી તે સમયે ફાઇલ કેવી હતી તે જોવા મળશે',
+'filehist-current'          => 'વર્તમાન',
+'filehist-datetime'         => 'તારીખ/સમય',
+'filehist-user'             => 'સભ્ય',
+'filehist-dimensions'       => 'પરિમાણ',
+'filehist-filesize'         => 'ફાઇલનું કદ',
+'filehist-comment'          => 'ટિપ્પણી',
+'imagelinks'                => 'કડીઓ',
+'linkstoimage'              => 'આ ફાઇલ સાથે {{PLURAL:$1|નીચેનું પાનું જોડાયેલું|$1 નીચેનાં પાનાઓ જોડાયેલાં}} છે',
+'nolinkstoimage'            => 'આ ફાઇલ સાથે કોઇ પાનાં જોડાયેલાં નથી.',
+'sharedupload'              => 'આ ફાઇલ સહિયારી રીતે ચઢાવવામાં આવી છે અને તેનો ઉપયોગ અન્ય પરિયોજનાઓમાં પણ થઇ શકે છે.',
+'noimage'                   => 'આ નામ વાળી કોઇ ફાઇલ અસ્તિત્વમાં નથી, તમે તેને $1 શકો છો.',
+'noimage-linktext'          => 'ચઢાવી',
+'uploadnewversion-linktext' => 'આ ફાઇલની નવી આવૃત્તિ ચઢાવો',
 
+# List redirects
+'listredirects' => 'અન્યત્ર વાળેલાં પાનાંઓની યાદી',
+
 # Unused templates
 'unusedtemplates' => 'વણ વપરાયેલાં ઢાંચા',
 
 # Random page
 'randompage' => 'કોઈ પણ એક લેખ',
 
+# Statistics
+'statistics' => 'આંકડાકિય માહિતિ',
+
 'brokenredirects-edit'   => '(ફેરફાર કરો)',
 'brokenredirects-delete' => '(હટાવો)',
 
+'withoutinterwiki' => 'અન્ય ભાષાઓની કડીઓ વગરનાં પાનાં',
+
 'fewestrevisions' => 'સૌથી ઓછાં ફેરફાર થયેલા પાનાં',
 
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|બાઇટ|બાઇટ્સ}}',
+'nlinks'                  => '$1 {{PLURAL:$1|કડી|કડીઓ}}',
 'nmembers'                => '$1 {{PLURAL:$1|સદસ્ય|સદસ્યો}}',
 'specialpage-empty'       => 'આ પાનું ખાલી છે.',
 'lonelypages'             => 'અનાથ પાના',
+'uncategorizedpages'      => 'અવર્ગિકૃત પાનાં',
 'uncategorizedcategories' => 'અવર્ગિકૃત શ્રેણીઓ',
 'uncategorizedimages'     => 'અવર્ગિકૃત દસ્તાવેજો',
 'uncategorizedtemplates'  => 'અવર્ગિકૃત ઢાંચાઓ',
 'unusedcategories'        => 'વણ વપરાયેલી શ્રેણીઓ',
 'unusedimages'            => 'વણ વપરાયેલાં દસ્તાવેજો',
+'wantedcategories'        => 'ઇચ્છિત શ્રેણીઓ',
+'wantedpages'             => 'ઇચ્છિત પાનાં',
+'mostcategories'          => 'સૌથી વધુ શ્રેણીઓ ધરાવતાં પાનાં',
 'mostrevisions'           => 'સૌથી વધુ ફેરફાર થયેલા પાનાં',
 'shortpages'              => 'નાનાં પાનાં',
 'longpages'               => 'લાંબા પાનાઓ',
 'protectedpages'          => 'સંરક્ષિત પાનાઓ',
+'listusers'               => 'સભ્યોની યાદી',
 'newpages'                => 'નવા પાના',
 'ancientpages'            => 'સૌથી જૂનાં પાના',
 'move'                    => 'નામ બદલો',
+'movethispage'            => 'આ પાનું ખસેડો',
 
 # Book sources
 'booksources'      => 'પુસ્તક સ્ત્રોત',
@@ -428,10 +491,13 @@
 'booksources-go'   => 'જાઓ',
 
 # Special:Log
-'log'               => 'લૉગ',
-'log-search-submit' => 'શોધો',
+'specialloguserlabel'  => 'સભ્ય:',
+'speciallogtitlelabel' => 'શિર્ષક:',
+'log'                  => 'લૉગ',
+'all-logs-page'        => 'બધાં માહિતિ પત્રકો',
+'log-search-submit'    => 'શોધો',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'બધા પાના',
 'alphaindexline' => '$1 થી $2',
 'nextpage'       => 'આગળનું પાનું ($1)',
@@ -445,7 +511,7 @@
 'categories'         => 'શ્રેણીઓ',
 'categoriespagetext' => 'નીચેની શ્રેણીઓમાં પાના કે અન્ય સભ્યો છે.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'બતાવો',
 
 # E-mail user
@@ -460,7 +526,11 @@
 'watchlist'            => 'મારી ધ્યાનસૂચી',
 'mywatchlist'          => 'મારી ધ્યાનસૂચિ',
 'watchlistfor'         => "('''$1'''ને માટે)",
+'addedwatch'           => 'ધ્યાનસૂચિમાં ઉમેરવામાં આવ્યું છે',
+'removedwatch'         => 'ધ્યાનસૂચિમાંથી કાઢી નાંખ્યું છે',
+'removedwatchtext'     => '"[[:$1]]" શિર્ષક હેઠળનું પાનું તમારી ધ્યાનસૂચિમાંથી કાઢી નાંખવામાં આવ્યું છે.',
 'watch'                => 'ધ્યાન માં રાખો',
+'watchthispage'        => 'આ પાનું ધ્યાનમાં રાખો',
 'unwatch'              => 'ધ્યાનસૂચિમાંથી હટાવો',
 'watchlist-details'    => 'ચર્ચા વાળા પાના ન ગણતા {{PLURAL:$1|$1 પાનું|$1 પાનાં}} ધ્યાનસૂચી મા છે.',
 'watchlistcontains'    => 'તમારી ધ્યાનસૂચીમાં $1 {{PLURAL:$1|પાનું|પાનાં}} છે.',
@@ -477,13 +547,29 @@
 'changed'            => 'બદલાયેલું',
 
 # Delete/protect/revert
-'deletepage'     => 'પાનું હટાવો',
-'confirm'        => 'ખાતરી કરો',
-'exblank'        => 'પાનું ખાલી હતું',
-'actioncomplete' => 'કામ પૂરું થઈ ગયું',
-'deletedarticle' => 'હટાવવામાં આવેલા "[[$1]]"',
-'dellogpage'     => 'હટાવેલાઓનું માહિતિ પત્રક (ડિલિશન લૉગ)',
-'rollbacklink'   => 'પાછું વાળો',
+'deletepage'                  => 'પાનું હટાવો',
+'confirm'                     => 'ખાતરી કરો',
+'exblank'                     => 'પાનું ખાલી હતું',
+'actioncomplete'              => 'કામ પૂરું થઈ ગયું',
+'deletedtext'                 => '"<nowiki>$1</nowiki>" દૂર કરવામાં આવ્યું છે.
+તાજેતરમાં દૂર કરેલા લેખોની વિગત માટે $2 જુઓ.',
+'deletedarticle'              => 'હટાવવામાં આવેલા "[[$1]]"',
+'dellogpage'                  => 'હટાવેલાઓનું માહિતિ પત્રક (ડિલિશન લૉગ)',
+'deletecomment'               => 'હટાવવા માટેનું કારણ:',
+'deleteotherreason'           => 'અન્ય/વધારાનું કારણ:',
+'deletereasonotherlist'       => 'અન્ય કારણ',
+'rollbacklink'                => 'પાછું વાળો',
+'protectlogpage'              => 'સુરક્ષા માહિતિ પત્રક',
+'protectcomment'              => 'ટિપ્પણી:',
+'protectexpiry'               => 'સમાપ્તિ:',
+'protect_expiry_invalid'      => 'સમાપ્તિનો સમય માન્ય નથી.',
+'protect_expiry_old'          => 'સમાપ્તિનો સમય ભૂતકાળમાં છે.',
+'protect-level-autoconfirmed' => 'નહી નોંધાયેલા સભ્યો પર પ્રતિબંધ',
+'protect-level-sysop'         => 'માત્ર પ્રબંધકો',
+'protect-expiring'            => '$1 (UTC) એ સમાપ્ત થાય છે',
+'protect-cascade'             => 'આ પાનાંમાં સમાવિષ્ટ પેટા પાનાં પણ સુરક્ષિત કરો (કૅસ્કેડીંગ સુરક્ષા)',
+'protect-cantedit'            => 'આપ આ પાનાનાં સુરક્ષા સ્તરમાં ફેરફાર ના કરી શકો, કેમકે આપને અહિં ફેરફાર કરવાની પરવાનગી નથી.',
+'restriction-type'            => 'પરવાનગી:',
 
 # Restrictions (nouns)
 'restriction-edit' => 'બદલો',
@@ -505,8 +591,9 @@
 'month'         => ':મહિનાથી (અને પહેલાનાં)',
 'year'          => ':વર્ષથી (અને પહેલાનાં)',
 
-'sp-contributions-blocklog' => 'પ્રતિબંધ સૂચિ',
-'sp-contributions-submit'   => 'શોધો',
+'sp-contributions-newbies-sub' => 'નવા ખાતાઓ માટે',
+'sp-contributions-blocklog'    => 'પ્રતિબંધ સૂચિ',
+'sp-contributions-submit'      => 'શોધો',
 
 # What links here
 'whatlinkshere'       => 'અહિયાં શું જોડાય છે',
@@ -525,7 +612,7 @@
 'ipbreason'          => 'કારણ',
 'ipbreasonotherlist' => 'બીજું કારણ',
 'ipbother'           => 'અન્ય સમય',
-'ipboptions'         => '2 hours:૨ કલાક,1 day:૧ દિવસ,3 days:૩ દિવસ,1 week:૧ અઠવાડિયું,2 weeks:૨ અઠવાડિયું,1 month:૧ માસ,3 months:૩ માસ,6 months:૬ માસ,1 year:૧ વર્ષ,infinite:અમર્યાદ', # display1:time1,display2:time2,...
+'ipboptions'         => '૨ કલાક:2 hours,૧ દિવસ:1 day,૩ દિવસ:3 days,૧ સપ્તાહ:1 week,૨ સપ્તાહ:2 weeks,૧ માસ:1 month,૩ માસ:3 months,૬ માસ:6 months,૧ વર્ષ:1 year,અમર્યાદ:infinite', # display1:time1,display2:time2,...
 'ipbotheroption'     => 'બીજું',
 'ipblocklist'        => 'પ્રતિબંધિત IP સરનામા અને સભ્યોની યાદી',
 'ipblocklist-submit' => 'શોધો',
@@ -534,9 +621,21 @@
 'unblocklink'        => 'પ્રતિબંધ હટાવો',
 'contribslink'       => 'યોગદાન',
 'blocklogpage'       => 'પ્રતિબંધ સૂચિ',
+'blocklogentry'      => '[[$1]] પર પ્રતિબંધ $2 $3 સુધી મુકવામાં આવ્યો છે.',
 
 # Move page
+'movearticle'             => 'આ પાનાનું નામ બદલો:',
+'newtitle'                => 'આ નવું નામ આપો:',
+'move-watch'              => 'આ પાનું ધ્યાનમાં રાખો',
+'movepagebtn'             => 'પાનું ખસેડો',
+'pagemovedsub'            => 'પાનું સફળતા પૂર્વક ખસેડવામાં આવ્યું છે',
+'movepage-moved'          => '<big>\'\'\'"$1" નું નામ બદલીને "$2" કરવામાં આવ્યું છે\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'articleexists'           => 'આ નામનું પાનું અસ્તિત્વમાં છે, અથવાતો તમે પસંદ કરેલું નામ અસ્વિકાર્ય છો.
+કૃપા કરી અન્ય નામ પસંદ કરો.',
+'movedto'                 => 'બદલ્યા પછીનું નામ',
+'movetalk'                => 'સંલગ્ન ચર્ચાનું પાનું પણ ખસેડો',
 '1movedto2'               => '[[$1]] નું નામ બદલી ને [[$2]] કરવામાં આવ્યું છે.',
+'movelogpage'             => 'નામ ફેર માહિતિ પત્રક',
 'movereason'              => 'કારણ',
 'revertmove'              => 'પૂર્વવત',
 'delete_and_move'         => 'હટાવો અને નામ બદલો',
@@ -555,6 +654,9 @@
 'thumbnail-more'  => 'વિસ્તૃત કરો',
 'thumbnail_error' => 'નાની છબી (થંબનેઇલ-thumbnail) બનાવવામાં ત્રુટિ: $1',
 
+# Import log
+'importlogpage' => 'આયાત માહિતિ પત્રક',
+
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'મારૂં પાનું',
 'tooltip-pt-mytalk'               => 'મારી ચર્ચાનું પાનું',
@@ -610,13 +712,15 @@
 # Media information
 'file-info-size'       => '($1 × $2 પીક્સલ, ફાઇલનું કદ: $3, MIME પ્રકાર: $4)',
 'file-nohires'         => '<small>આથી વધુ આવર્તન ઉપલબ્ધ નથી.</small>',
+'svg-long-desc'        => '(SVG ફાઇલ, માત્ર $1 × $2 પીક્સલ, ફાઇલનું કદ: $3)',
 'show-big-image'       => 'મહત્તમ આવર્તન',
 'show-big-image-thumb' => '<small>આ પુર્વાવલોકનનું પરિમાણ: $1 × $2 પીક્સલ</small>',
 
-# Special:Newimages
-'noimages' => 'જોવા માટે કશું નથી.',
-'ilsubmit' => 'શોધો',
-'bydate'   => 'તારીખ પ્રમાણે',
+# Special:NewImages
+'newimages' => 'નવી ફાઇલોની ઝાંખી',
+'noimages'  => 'જોવા માટે કશું નથી.',
+'ilsubmit'  => 'શોધો',
+'bydate'    => 'તારીખ પ્રમાણે',
 
 # Metadata
 'metadata'          => 'મૅટાડેટા',
@@ -659,7 +763,7 @@
 
 # External editor support
 'edit-externally'      => 'બાહ્ય સોફ્ટવેર વાપરીને આ ફાઇલમાં ફેરફાર કરો',
-'edit-externally-help' => 'વધુ માહિતિ માટે જુઓ: [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions]',
+'edit-externally-help' => 'વધુ માહિતિ માટે જુઓ: [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'બધા',
@@ -691,6 +795,9 @@
 'watchlisttools-edit' => 'ધ્યાનસૂચી જુઓ અને બદલો',
 'watchlisttools-raw'  => 'કાચી ધ્યાનસૂચિમાં ફેરફાર કરો',
 
+# Special:Version
+'version' => 'આવૃત્તિ', # Not used as normal message but as header for the special page itself
+
 # Special:SpecialPages
 'specialpages' => 'ખાસ પાનાં',
 
Index: languages/messages/MessagesInh.php
===================================================================
--- languages/messages/MessagesInh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesInh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Tagir
- * @author Siebrand
  */
 
 $fallback = 'ru';
Index: languages/messages/MessagesSn.php
===================================================================
--- languages/messages/MessagesSn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,6 +3,8 @@
  *
  * @ingroup Language
  * @file
+ *
+ * @author Hakka
  */
 
 $messages = array(
Index: languages/messages/MessagesOs.php
===================================================================
--- languages/messages/MessagesOs.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesOs.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Amikeco
- * @author Siebrand
  * @author לערי ריינהארט
  */
 
@@ -229,7 +228,7 @@
 'nosuchspecialpage' => 'Ахæм сæрмагонд фарс нæй',
 'nospecialpagetext' => "<big>'''Нæй ахæм сæрмагонд фарс.'''</big>
 
-Кæс [[Special:Specialpages|æппæт сæрмагонд фæрсты номхыгъд]].",
+Кæс [[Special:SpecialPages|æппæт сæрмагонд фæрсты номхыгъд]].",
 
 # General errors
 'error'                => 'Рæдыд',
@@ -357,14 +356,14 @@
 'savefile'      => 'Бавæр æй',
 'uploadvirus'   => 'Файлы разынд вирус! Кæс $1',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Нывты номхыгъд',
 
 # Image description page
 'filehist'         => 'Файлы истори',
 'filehist-current' => 'нырыккон',
 'imagelinks'       => 'Æрвитæнтæ',
-'linkstoimage'     => 'Ацы нывæй чи пайда кæны, ахæм статьятæ:',
+'linkstoimage'     => 'Ацы нывæй пайда {{PLURAL:$1|кæны иу фарс|кæнынц ахæм фæрстæ}}:',
 
 # File deletion
 'filedelete-submit' => 'Аппар',
@@ -374,7 +373,7 @@
 
 # Statistics
 'userstats'     => 'Архайджыты статистикæ',
-'userstatstext' => 'Регистрацигонд æрцыдысты <b>$1</b> архайджыты, уыдонæй <b>$2</b> — админтæ (кæс $3).',
+'userstatstext' => "Регистрацигонд {{PLURAL:$1|æрцыд '''иу архайæг'''|æрцыдысты $1 [[Special:ListUsers|архайæджы]]}}, уыдонæй '''$2''' (ома сæ '''$4%''') {{PLURAL:$2|у|сты}} $5.",
 
 'brokenredirects-edit'   => '(баив æй)',
 'brokenredirects-delete' => '(аппар)',
@@ -382,8 +381,8 @@
 'withoutinterwiki-submit' => 'Равдис',
 
 # Miscellaneous special pages
-'nbytes'            => '$1 байт(ы)',
-'nlinks'            => '$1 æрвитæн(ы)',
+'nbytes'            => '$1 {{PLURAL:$1|байт|байты}}',
+'nlinks'            => '$1 {{PLURAL:$1|æрвитæн|æрвитæны}}',
 'nviews'            => '$1 {{PLURAL:$1|æркаст|æркасты}}',
 'lonelypages'       => 'Сидзæр фæрстæ',
 'wantedpages'       => 'Хъæугæ фæрстæ',
@@ -395,7 +394,7 @@
 'ancientpages'      => 'Зæронддæр фæрстæ',
 'move'              => 'Ном баив',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Æппæт фæрстæ',
 'alphaindexline' => '$1 (уыдоны ’хсæн цы статьятæ ис, фен) $2',
 'allarticles'    => 'Æппæт статьятæ',
@@ -408,11 +407,11 @@
 'special-categories-sort-count' => 'нымæцмæ гæсгæ равæр',
 'special-categories-sort-abc'   => 'алфавитмæ гæсгæ равæр',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'Равдис',
 
 # E-mail user
-'mailnologintext' => 'Фыстæгтæ æрвитынмæ хъуамæ [[Special:Userlogin|системæйæн дæхи бавдисай]] æмæ дæ бæлвырд электронон посты адрис [[Special:Preferences|ныффыссай]].',
+'mailnologintext' => 'Фыстæгтæ æрвитынмæ хъуамæ [[Special:UserLogin|системæйæн дæхи бавдисай]] æмæ дæ бæлвырд электронон посты адрис [[Special:Preferences|ныффыссай]].',
 'emailpage'       => 'Электронон фыстæг йæм барвит',
 
 # Watchlist
@@ -420,7 +419,7 @@
 'mywatchlist'          => 'Дæ цæст кæмæ дарыс, уыцы фæрстæ',
 'nowatchlist'          => 'Иу статьямæ дæр дæ цæст нæ дарыс.',
 'watchnologin'         => 'Системæйæн дæхи нæ бацамыдтай',
-'watchnologintext'     => 'Ацы номхыгъд ивынмæ [[Special:Userlogin|хъуамæ дæхи бацамонай системæйæн]].',
+'watchnologintext'     => 'Ацы номхыгъд ивынмæ [[Special:UserLogin|хъуамæ дæхи бацамонай системæйæн]].',
 'addedwatch'           => 'Дæ цæст кæмæ дарыс, уыцы статьятæм бафтыд.',
 'watch'                => 'Дæ цæст æрдар',
 'watchthispage'        => 'Ацы фарсмæ дæ цæст æрдар',
@@ -463,7 +462,6 @@
 
 # Move page
 'movearticle' => 'Статьяйы ном баив',
-'movenologin' => 'Системæйæн дæхи нæ бацамыдтай',
 'newtitle'    => 'Ног ном',
 
 # Namespace 8 related
@@ -485,7 +483,7 @@
 # Media information
 'widthheightpage' => '$1 × $2, $3 фарсы',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Ног нывты галерей',
 'ilsubmit'  => 'Агур',
 'bydate'    => 'рæстæгмæ гæсгæ',
Index: languages/messages/MessagesKk_latn.php
===================================================================
--- languages/messages/MessagesKk_latn.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesKk_latn.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,11 +1,12 @@
 <?php
-/** Kazakh (Latin) (Qazaqşa (Latın))
+/** Kazakh (Latin) (Қазақша (Latin))
  *
  * @ingroup Language
  * @file
  *
- * @author GaiJin
  * @author AlefZet
+ * @author Atabek
+ * @author GaiJin
  */
 
 /**
@@ -530,7 +531,7 @@
 'mypage'         => 'Jeke betim',
 'mytalk'         => 'Talqılawım',
 'anontalk'       => 'IP talqılawı',
-'navigation'     => 'Bağıttaw',
+'navigation'     => 'Şarlaw',
 'and'            => 'jäne',
 
 # Metadata in edit box
@@ -588,33 +589,33 @@
 'viewcount'         => 'Bul bet $1 ret qatınalğan.',
 'protectedpage'     => 'Qorğalğan bet',
 'jumpto'            => 'Mında ötw:',
-'jumptonavigation'  => 'bağıttaw',
+'jumptonavigation'  => 'şarlaw',
 'jumptosearch'      => 'izdew',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}} twralı',
 'aboutpage'            => '{{ns:project}}:Joba twralı',
 'bugreports'           => 'Qatelik bayanattarı',
-'bugreportspage'       => '{{ns:project}}:Qatelik bayanattarı',
+'bugreportspage'       => 'Project:Qatelik eseptemeleri',
 'copyright'            => 'Mağlumat $1 şartımen jetimdi.',
 'copyrightpagename'    => '{{SITENAME}} awtorlıq quqıqtarı',
 'copyrightpage'        => '{{ns:project}}:Awtorlıq quqıqtar',
 'currentevents'        => 'Ağımdağı oqïğalar',
-'currentevents-url'    => '{{ns:project}}:Ağımdağı oqïğalar',
+'currentevents-url'    => 'Project:Ağımdağı oqïğalar',
 'disclaimers'          => 'Jawapkerşilikten bas tartw',
-'disclaimerpage'       => '{{ns:project}}:Jawapkerşilikten bas tartw',
+'disclaimerpage'       => 'Project:Jawapkerşilikten bas tartw',
 'edithelp'             => 'Öndew anıqtaması',
-'edithelppage'         => '{{ns:help}}:Öñdew',
+'edithelppage'         => 'Help:Öñdew',
 'faq'                  => 'Jïi qoýılğan sawaldar',
-'faqpage'              => '{{ns:project}}:Jïi qoýılğan sawaldar',
-'helppage'             => '{{ns:help}}:Mazmunı',
+'faqpage'              => 'Project:Jïi qoýılğan sawaldar',
+'helppage'             => 'Help:Mazmunı',
 'mainpage'             => 'Bastı bet',
 'mainpage-description' => 'Bastı bet',
-'policy-url'           => '{{ns:project}}:Erejeler',
+'policy-url'           => 'Project:Erejeler',
 'portal'               => 'Qawım portalı',
-'portal-url'           => '{{ns:project}}:Qawım portalı',
+'portal-url'           => 'Project:Qawım portalı',
 'privacy'              => 'Jeke qupïyasın saqtaw',
-'privacypage'          => '{{ns:project}}:Jeke qupïyasın saqtaw',
+'privacypage'          => 'Project:Jeke qupïyasın saqtaw',
 
 'badaccess'        => 'Ruqsat qatesi',
 'badaccess-group0' => 'Suratılğan äreketiñizdi jegwiñizge ruqsat etilmeýdi.',
@@ -884,7 +885,7 @@
 'hr_tip'          => 'Dereleý sızıq (ünemdi qoldanıñız)',
 
 # Edit pages
-'summary'                          => 'Qısqaşa mazmundaması',
+'summary'                          => 'Tüýindemesi',
 'subject'                          => 'Taqırıbı/bas jolı',
 'minoredit'                        => 'Bul şağın öñdeme',
 'watchthis'                        => 'Betti baqılaw',
@@ -933,10 +934,6 @@
 'blockededitsource'                => "'''$1''' degenge jasalğan '''öñdemeleriñizdiñ''' mätini tömende körsetiledi:",
 'whitelistedittitle'               => 'Öñdew üşin kirwiñiz jön.',
 'whitelistedittext'                => 'Betterdi öñdew üşin $1 jön.',
-'whitelistreadtitle'               => 'Oqw üşin kirwiñiz jön',
-'whitelistreadtext'                => 'Betterdi oqw üşin [[{{#special:Userlogin}}|kirwiñiz]] jön.',
-'whitelistacctitle'                => 'Tirkelgi jasawıñızğa ruqsat berilmegen',
-'whitelistacctext'                 => '{{SITENAME}} jobasına tirkelgi jasaw üşin [[{{#special:Userlogin}}|kirwiñiz]] kerek jäne janasımdı ruqsattarıñız bolw kerek.',
 'confirmedittitle'                 => 'Quptaw xatı qaýta öñdelwi jön',
 'confirmedittext'                  => 'Betterdi öñdew üşin aldın ala E-poşta mekenjaýıñızdı quptawıñız jön.
 E-poşta mekenjaýıñızdı [[{{#special:Preferences}}|paýdalanwşılıq baptalımdarıñız]] arqılı qoýıñız da jaramdılığın tekserip şığıñız.',
@@ -955,7 +952,7 @@
 'anontalkpagetext'                 => "----''Bul tirkelgisiz (nemese tirkelgisin qoldanbağan) qatıswşı talqılaw beti. Osı qatıswşını biz tek sandıq IP mekenjaýımen teñdestiremiz.
 Osındaý IP mekenjaý birneşe qatıswşığa ortaqtastırılğan bolwı mümkin.
 Eger siz tirkelgisiz qatıswşı bolsañız jäne sizge qatıssız mändemeler jiberilgenin sezseñiz, basqa tirkelgisiz qatıswşılarmen aralastırmawı üşin [[{{#special:Userlogin}}|tirkeliñiz ne kiriñiz]].''",
-'noarticletext'                    => 'Bul bette ağımda eş mätin joq, degenmen basqa betterden [[{{#special:Search}}/{{PAGENAME}}|bul bet taqırıbı atın izdeý]] ne [{{fullurl:{{FULLPAGENAME}}|action=edit}} bul betti öñdeý] alasız.',
+'noarticletext'                    => 'Bul bette ağımda eş mätin joq, basqa betterden osı bet atawın [[Special:Search/{{PAGENAME}}|izdep körwiñizge]] nemese osı betti [{{fullurl:{{FULLPAGENAME}}|action=edit}} tüzetwiñizge] boladı.',
 'userpage-userdoesnotexist'        => '«$1» qatıswşı tirkelgisi jazıp alınbağan. Bul betti bastaw/öñdew talabıñızdı tekserip şığıñız.',
 'clearyourcache'                   => "'''Añğartpa:''' Saqtağannan keýin, özgeristerdi körw üşin şolğış bürkemesin orağıtw ıqtïmal. '''Mozilla / Firefox / Safari:''' ''Qaýta jüktew'' batırmasın nuqığanda ''Shift'' tutıñız, ne ''Ctrl-Shift-R'' basıñız (Apple Mac — ''Cmd-Shift-R''); '''IE:''' ''Jañartw'' batırmasın nuqığanda ''Ctrl'' tutıñız, ne ''Ctrl-F5'' basıñız; '''Konqueror:''': ''Jañartw'' batırmasın jaý nuqıñız, ne ''F5'' basıñız; '''Opera''' paýdanwşıları ''Quraldar→Baptalımdar'' degenge barıp bürkemesin tolıq tazartw jön.",
 'usercssjsyoucanpreview'           => '<strong>Aqıl-keñes:</strong> Jaña CSS/JS faýlın saqtaw aldında «Qarap şığw» batırmasın qoldanıp sınaqtañız.',
@@ -1047,11 +1044,11 @@
 'undo-success' => 'Bul öñdeme joqqa şığarılwı mümkin. Talabıñızdı quptap aldın ala tömendegi salıstırwdı tekserip şığıñız da, öñdemeni joqqa şığarwın bitirw üşin tömendegi özgeristerdi saqtañız.',
 'undo-failure' => 'Bul öñdeme joqqa şığarılmaýdı, sebebi arada qaqtığıstı öñdemeler bar.',
 'undo-norev'   => 'Bul öñdeme joqqa şığarılmaýdı, sebebi bul joq nemese joýılğan.',
-'undo-summary' => '[[{{#special:Contributions}}/$2|$2]] ([[{{ns:user_talk}}:$2|talqılawı]]) istegen nömir $1 tüzetwin joqqa şığardı',
+'undo-summary' => '[[Special:Contributions/$2|$2]] ([[User_talk:$2|talqılawı]]) istegen nömir $1 nusqasın joqqa şığardı',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Jaña tirkelgi jasalmadı',
-'cantcreateaccount-text' => "Bul IP mekenjaýdan ('''$1''') jaña tirkelgi jasawın [[{{ns:user}}:$3|$3]] buğattağan.
+'cantcreateaccount-text' => "Bul IP jaýdan ('''$1''') jaña tirkelgi jasawın [[User:$3|$3]] buğattağan.
 
 $3 keltirilgen sebebi: ''$2''",
 
@@ -1181,7 +1178,7 @@
 
 # Search results
 'searchresults'             => 'İzdew nätïjeleri',
-'searchresulttext'          => '{{SITENAME}} jobasında izdew twralı köbirek aqparat üşin, [[{{{{ns:mediawiki}}:helppage}}|{{int:help}} betin]] qarañız.',
+'searchresulttext'          => "{{SITENAME}} saytında izlew haqqında ko'birek mag'lıwmat alg'ın'ız kelse, [[{{Mediawiki:helppage}}|{{int:help}} betine]] o'tip qarap ko'rin'.",
 'searchsubtitle'            => "İzdegeniñiz: '''[[:$1]]'''",
 'searchsubtitleinvalid'     => "İzdegeniñiz: '''$1'''",
 'noexactmatch'              => "'''Osı arada bettiñ «$1» taqırıp atı joq.'''
@@ -1212,12 +1209,12 @@
 'showingresults'            => "Tömende nömir '''$2''' ornınan bastap barınşa '''$1''' nätïje körsetiledi.",
 'showingresultsnum'         => "Tömende nömir '''$2''' ornınan bastap '''$3''' nätïje körsetiledi.",
 'showingresultstotal'       => "Tömende {{PLURAL:$3|'''$3''' arasınan '''$1''' nätïje körsetiledi|'''$3''' arasınan '''$1 — $2''' nätïje awqımı körsetiledi}}",
-'nonefound'                 => "'''Añğartpa''': Ädepkiden tek keýbir esim ayalardan izdelinedi. Barlıq mağlumat türin (sonıñ işinde talqılaw betterdi, ülgilerdi t.b.) izdew üşin suranımıñızdı ''barlıq:'' dep bastañız, nemese qalağan esim ayasın bastawış esebinde qoldanıñız.",
+'nonefound'                 => "'''Esletpe''': Defolt boyınsha tek g'ana sheklengen isimler ko'pliginen izlenedi. Barlıq mag'lıwmat tu'rin (sonın' ishinde sa'wbet betlerdi, shablonlardı h.t.b.) izlew ushın izlewin'izdi ''barlıq:'' prefiksi menen baslan', yamasa qa'legen isimler ko'pligin prefiks esabında qollanın'.",
 'powersearch'               => 'Keñeýtilgen izdew',
 'powersearch-legend'        => 'Keñeýtilgen izdew',
-'powersearch-ns'            => 'Mına esim ayalarda izdew:',
-'powersearch-redir'         => 'Aýdatwlardı tizimdew',
-'powersearch-field'         => 'Mınanı izdemek:',
+'powersearch-ns'            => "Usı isimler ko'pliginen izlew:",
+'powersearch-redir'         => "Qayta bag'ıtlawshı betlerdi ko'rset",
+'powersearch-field'         => "İzlenetug'ın so'z (yamasa so'z dizbegi):",
 'search-external'           => 'Şettik izdegiş',
 'searchdisabled'            => '{{SITENAME}} izdew qızmeti öşirilgen.
 Äzirşe Google arqılı izdewge boladı.
@@ -1228,7 +1225,7 @@
 'mypreferences'            => 'Baptalımdarım',
 'prefs-edits'              => 'Öñdeme sanı:',
 'prefsnologin'             => 'Kirmegensiz',
-'prefsnologintext'         => 'Paýdalanwşılıq baptalımdarıñızdı qoyw üşin [[{{#special:Userlogin}}|kirwiñiz]] jön.',
+'prefsnologintext'         => 'Baptawıñızdı qoyw üşin [[Special:UserLogin|kirwiñiz]] tïisti.',
 'prefsreset'               => 'Baptalımdar arqawdan qaýta qoýıldı.',
 'qbsettings'               => 'Mäzir',
 'qbsettings-none'          => 'Eşqandaý',
@@ -1293,7 +1290,7 @@
 'userrights-lookup-user'      => 'Qatıswşı toptarın rettew',
 'userrights-user-editname'    => 'Qatıswşı atın engiziñiz:',
 'editusergroup'               => 'Qatıswşı toptarın öñdew',
-'editinguser'                 => "Qatıswşı quqıqtarın özgertw: '''[[{{ns:user}}:$1|$1]]''' ([[{{ns:user_talk}}:$1|{{int:talkpagelinktext}}]] | [[{{#special:Contributions}}/$1|{{int:contribslink}}]])",
+'editinguser'                 => "Qatıswşı quqıqtarın özgertw: '''[[User:$1|$1]]''' ([[User_talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-editusergroup'    => 'Qatıswşı toptarın öñdew',
 'saveusergroups'              => 'Qatıswşı toptarın saqtaw',
 'userrights-groupsmember'     => 'Müşeligi:',
@@ -1422,11 +1419,11 @@
 # Recent changes linked
 'recentchangeslinked'          => 'Qatıstı özgerister',
 'recentchangeslinked-title'    => '«$1» degenge qatıstı özgerister',
-'recentchangeslinked-noresult' => 'Siltelgen betterde keltirilgen merzimde eşqandaý özgeris bolmağan.',
-'recentchangeslinked-summary'  => "Bul tizimde özindik betten siltelgen betterdegi (ne özindik sanat müşelerindegi) istelgen jwıqtağı özgerister beriledi.
+'recentchangeslinked-noresult' => 'Siltegen betterde keltirilgen merzimde eşqandaý özgeris bolmağan.',
+'recentchangeslinked-summary'  => "Bul tizimde özindik betke siltegen betterdegi (ne özindik sanat müşelerindegi) istelgen jwıqtağı özgerister beriledi.
 [[{{#special:Watchlist}}|Baqılaw tizimiñizdegi]] better '''jwan''' bolıp belgilenedi.",
 'recentchangeslinked-page'     => 'Bet atawı:',
-'recentchangeslinked-to'       => 'Bunıñ ornına keltirilgen betke siltelgen betterdegi özgeristerdi körset',
+'recentchangeslinked-to'       => 'Kerisinşe, keltirilgen betke silteýtin betterdegi özgeristerdi körset',
 
 # Upload
 'upload'                      => 'Qotarıp berw',
@@ -1434,7 +1431,7 @@
 'reupload'                    => 'Qaýta qotarıp berw',
 'reuploaddesc'                => 'Qotarıp berwdi boldırmaw jäne qotarw pişinine qaýta kelw.',
 'uploadnologin'               => 'Kirmegensiz',
-'uploadnologintext'           => 'Faýldardı qotarıp berw üşin [[{{#special:Userlogin}}|kirwiñiz]] jön.',
+'uploadnologintext'           => 'Faýl qotarw üşin [[Special:UserLogin|kirwiñiz]] kerek.',
 'upload_directory_missing'    => 'Qotarıp bermek qaltası ($1) jetispeýdi jäne veb-server jarata almaýdı.',
 'upload_directory_read_only'  => 'Qotarıp bermek qaltasına ($1) veb-server jaza almaýdı.',
 'uploaderror'                 => 'Qotarıp berw qatesi',
@@ -1452,8 +1449,8 @@
 'uploadlogpage'               => 'Qotarıp berw jwrnalı',
 'uploadlogpagetext'           => 'Tömende eñ soñğı qotarıp berilgen faýl tizimi.',
 'filename'                    => 'Faýl atawı',
-'filedesc'                    => 'Qısqaşa mazmundaması',
-'fileuploadsummary'           => 'Qısqaşa mazmundaması:',
+'filedesc'                    => 'Tüýindemesi',
+'fileuploadsummary'           => 'Tüýindemesi:',
 'filestatus'                  => 'Awtorlıq quqıqtar küýi:',
 'filesource'                  => 'Qaýnar közi:',
 'uploadedfiles'               => 'Qotarıp berilgen faýldar',
@@ -1541,7 +1538,7 @@
 'upload_source_url'  => ' (jaramdı, barşağa qatınawlı URL)',
 'upload_source_file' => ' (komp′ywteriñizdegi faýl)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Bul arnaýı bette barlıq qotarıp berilgen faýldar körsetiledi.
 Soñğı qotarıp berilgen faýldar tizimde joğarğı şetimen ädepkiden körsetiledi.
 Bağannıñ bas jolın nuqığanda surıptawdıñ rettewi özgertiledi.',
@@ -1588,17 +1585,17 @@
 # File reversion
 'filerevert'                => '$1 degendi qaýtarw',
 'filerevert-legend'         => 'Faýldı qaýtarw',
-'filerevert-intro'          => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' degendi [$4 $3, $2 kezindegi nusqasına] qaýtarwdasız.</span>',
+'filerevert-intro'          => "'''[[Media:$1|$1]]''' degendi [$4 $3, $2 kezindegi nusqasına] qaýtarwdasız.",
 'filerevert-comment'        => 'Mändemesi:',
 'filerevert-defaultcomment' => '$2, $1 kezindegi nusqasına qaýtarıldı',
 'filerevert-submit'         => 'Qaýtar',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' degen [$4 $3, $2 kezindegi nusqasına] qaýtarıldı.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' degen [$4 $3, $2 kezindegi nusqasına] qaýtarıldı.",
 'filerevert-badversion'     => 'Keltirilgen waqıt belgisimen bul faýldıñ aldıñğı jergilikti nusqası joq.',
 
 # File deletion
 'filedelete'                  => '$1 degendi joyw',
 'filedelete-legend'           => 'Faýldı joyw',
-'filedelete-intro'            => "'''[[{{ns:media}}:$1|$1]]''' degendi joýmaqsız.",
+'filedelete-intro'            => "'''[[Media:$1|$1]]''' degendi joywdasız.",
 'filedelete-intro-old'        => '<span class="plainlinks">\'\'\'[[{{ns:media}}:$1|$1]]\'\'\' — [$4 $3, $2 kezindegi nusqasın] joywdasız.</span>',
 'filedelete-comment'          => 'Joyw sebebi:',
 'filedelete-submit'           => 'Joý',
@@ -1700,7 +1697,7 @@
 'wantedcategories'        => 'Bastalmağan sanattar',
 'wantedpages'             => 'Bastalmağan better',
 'missingfiles'            => 'Joq faýldar',
-'mostlinked'              => 'Eñ köp siltelgen better',
+'mostlinked'              => 'Eñ köp siltengen better',
 'mostlinkedcategories'    => 'Eñ köp paýdalanılğan sanattar',
 'mostlinkedtemplates'     => 'Eñ köp paýdalanılğan ülgiler',
 'mostcategories'          => 'Eñ köp sanatı bar better',
@@ -1752,7 +1749,7 @@
 'logempty'             => 'Jwrnalda säýkes danalar joq.',
 'log-title-wildcard'   => 'Mına mätinneñ bastalıtın taqırıp attarın izdew',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Barlıq better',
 'alphaindexline'    => '$1 — $2',
 'nextpage'          => 'Kelesi betke ($1)',
@@ -1776,12 +1773,12 @@
 'special-categories-sort-count' => 'sanımen surıptaw',
 'special-categories-sort-abc'   => 'älipbïmen surıptaw',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Mına qatıswşıdan bastap körsetw:',
 'listusers-submit'   => 'Körset',
 'listusers-noresult' => 'Qatıswşı tabılğan joq.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Qatıswşı tobı quqıqtarı',
 'listgrouprights-summary'  => 'Kelesi tizimde bul wïkïde tağaýındalğan qatıswşı quqıqtarı (baýlanıstı qatınaw quqıqtarımen birge) körsetiledi.
 Jeke quqıqtar twralı köbirek aqparattı [[{{MediaWiki:Listgrouprights-helppage}}|mında]] taba alasız.',
@@ -1792,7 +1789,7 @@
 
 # E-mail user
 'mailnologin'     => 'Eş mekenjaý jöneltilgen joq',
-'mailnologintext' => 'Basqa qatıswşığa xat jöneltw üşin [[{{#special:Userlogin}}|kirwiñiz]] jön, jäne [[{{#special:Preferences}}|baptalımdarıñızda]] jaramdı e-poşta mekenjaýı bolwı jön.',
+'mailnologintext' => 'Basqa qatıswşığa xat jöneltw üşin [[Special:UserLogin|kirwiñiz]] kerek, jäne [[Special:Preferences|baptawıñızda]] jaramdı e-poşta jaýı bolwı jön.',
 'emailuser'       => 'Qatıswşığa xat jazw',
 'emailpage'       => 'Qatıswşığa xat jazw',
 'emailpagetext'   => 'Eger bul qatıswşı baptawlarında jaramdı e-poşta mekenjaýın engizse, tömendegi pişin arqılı buğan jalğız e-poşta xatın jöneltwge boladı.
@@ -1818,7 +1815,7 @@
 'nowatchlist'          => 'Baqılaw tizimiñizde eş dana joq',
 'watchlistanontext'    => 'Baqılaw tizimiñizdegi danalardı qaraw, ne öñdew üşin $1 kerek.',
 'watchnologin'         => 'Kirmegensiz',
-'watchnologintext'     => 'Baqılaw tizimiñizdi özgertw üşin [[{{#special:Userlogin}}|kirwiñiz]] jön.',
+'watchnologintext'     => 'Baqılaw tizimiñizdi özgertw üşin [[Special:UserLogin|kirwiñiz]] jön.',
 'addedwatch'           => 'Baqılaw tizimine üsteldi',
 'addedwatchtext'       => "«[[:$1]]» beti [[{{#special:Watchlist}}|baqılaw tizimiñizge]] üsteldi.
 Bul bettiñ jäne baýlanıstı talqılaw betiniñ keleşektegi özgeristeri mında tizimdelinedi de, jäne bettiñ atawı jeñil tabılw üşin [[{{#special:Recentchanges}}|jwıqtağı özgerister tiziminde]] '''jwan ärpimen''' körsetiledi.",
@@ -2056,8 +2053,8 @@
 'sp-contributions-submit'      => 'İzde',
 
 # What links here
-'whatlinkshere'            => 'Siltelgen better',
-'whatlinkshere-title'      => '$1 degenge siltelgen better',
+'whatlinkshere'            => 'Mında silteýtin better',
+'whatlinkshere-title'      => '$1 degenge silteýtin better',
 'whatlinkshere-page'       => 'Bet:',
 'linklistsub'              => '(Siltemeler tizimi)',
 'linkshere'                => "'''[[:$1]]''' degenge mına better silteýdi:",
@@ -2206,13 +2203,12 @@
 
 Osı oraýda, qalawıñız bolsa, betti qoldan jıljıta ne qosa alasız.",
 'movearticle'             => 'Jıljıtpaq bet:',
-'movenologin'             => 'Jüýege kirmegensiz',
-'movenologintext'         => 'Betti jıljıtw üşin tirkelgen bolwıñız jäne [[{{#special:Userlogin}}|kirwiñiz]] jön.',
 'movenotallowed'          => '{{SITENAME}} jobasında betterdi jıljıtw rwqsatıñız joq.',
 'newtitle'                => 'Jaña taqırıp atına:',
 'move-watch'              => 'Bul betti baqılaw',
 'movepagebtn'             => 'Betti jıljıt',
 'pagemovedsub'            => 'Jıljıtw sätti ayaqtaldı',
+'movepage-moved'          => '<big>\'\'\'"$1" beti "$2" betine jıljıtıldı\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Osılaý atalğan bet aldaqaşan bar, ne tañdağan atawıñız jaramdı emes.
 Özge atawdı tañdañız',
 'cantmove-titleprotected' => 'Betti osı orınğa jıljıta almaýsız, sebebi jaña taqırıp atı bastawdan qorğalğan',
@@ -2234,7 +2230,7 @@
 'revertmove'              => 'qaýtarw',
 'delete_and_move'         => 'Joyw jäne jıljıtw',
 'delete_and_move_text'    => '==Joyw kerek==
-«[[$1]]» degen nısana bet aldaqaşan bar.
+«[[:$1]]» degen nısana bet aldaqaşan bar.
 Jıljıtwğa jol berw üşin bunı joyasız ba?',
 'delete_and_move_confirm' => 'Ïä, bul betti joý',
 'delete_and_move_reason'  => 'Jıljıtwğa jol berw üşin joýılğan',
@@ -2269,7 +2265,7 @@
 'allmessagescurrent'        => 'Ağımdıq mätini',
 'allmessagestext'           => 'Mında {{ns:mediawiki}} esim ayasında jetimdi jüýe xabar tizimi beriledi.
 Eger ämbebap MediaWiki jersindirwge üles qosqıñız kelse [http://www.mediawiki.org/wiki/Localisation MediaWiki jersindirw betine] jäne [http://translatewiki.net Betawiki jobasına] barıp şığıñız.',
-'allmessagesnotsupportedDB' => "'''\$wgUseDatabaseMessages''' öşirilgen sebebinen '''{{#special:AllMessages}}''' beti qoldanılmaýdı.",
+'allmessagesnotsupportedDB' => "'''\$wgUseDatabaseMessages''' öşirilgen sebebinen '''{{ns:special}}:AllMessages''' beti qoldanılmaýdı.",
 'allmessagesfilter'         => 'Xabardı atawımen süzgilew:',
 'allmessagesmodified'       => 'Tek özgertilgendi körset',
 
@@ -2489,7 +2485,7 @@
 'show-big-image'       => 'Joğarı ajıratılımdı',
 'show-big-image-thumb' => '<small>Qarap şığw mölşeri: $1 × $2 nükte</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Jaña faýldar körmesi',
 'imagelisttext'         => "Tömende $2 surıptalğan '''$1''' faýl tizimi.",
 'newimages-summary'     => 'Bul arnaýı betinde soñğı qotarıp berilgen faýldar körsetiledi',
@@ -2501,7 +2497,6 @@
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
 'video-dims'     => '$1, $2 × $3',
-'seconds-abbrev' => 's',
 'minutes-abbrev' => 'mïn',
 'hours-abbrev'   => 'sağ',
 
@@ -2780,7 +2775,7 @@
 
 # External editor support
 'edit-externally'      => 'Bul faýldı şettik qondırma arqılı öñdew',
-'edit-externally-help' => 'Köbirek aqparat üşin [http://meta.wikimedia.org/wiki/Help:External_editors ornatw nusqamaların] qarañız.',
+'edit-externally-help' => 'Köbirek aqparat üşin [http://www.mediawiki.org/wiki/Manual:External_editors ornatw nusqamaların] qarañız.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'barlığın',
@@ -2855,7 +2850,7 @@
 'unit-pixel' => ' nükte',
 
 # HTML dump
-'redirectingto' => '[[$1]] betine aýdatwda…',
+'redirectingto' => '[[:$1]] betine aýdatwda…',
 
 # action=purge
 'confirm_purge'        => 'Bul bettin bürkemesin tazartasız ba?
@@ -2870,11 +2865,6 @@
 'hideresults'      => 'Nätïjelerdi jasır',
 'useajaxsearch'    => 'AJAX qoldanıp izdew',
 
-# Separators for various lists, etc.
-'semicolon-separator' => ';',
-'comma-separator'     => ',&#32;',
-'colon-separator'     => ':&#32;',
-
 # Multipage image navigation
 'imgmultipageprev' => '← aldıñğı betke',
 'imgmultipagenext' => 'kelesi betke →',
@@ -3006,7 +2996,7 @@
 'version-software-product'         => 'Önim',
 'version-software-version'         => 'Nusqası',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Faýl ornalaswı',
 'filepath-page'    => 'Faýl atı:',
 'filepath-submit'  => 'Ornalaswın tap',
Index: languages/messages/MessagesSr.php
===================================================================
--- languages/messages/MessagesSr.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSr.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -1,9 +1,9 @@
 <?php
-/**
- * Serbian
+/** Serbian (Српски / Srpski)
  *
  * @ingroup Language
  * @file
+ *
  */
 
 $fallback = 'sr-ec';
Index: languages/messages/MessagesDa.php
===================================================================
--- languages/messages/MessagesDa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,18 +4,16 @@
  * @ingroup Language
  * @file
  *
+ * @author Anders Wegge Jakobsen <awegge@gmail.com>
+ * @author Boivie
+ * @author EPO
+ * @author H92
  * @author Jan Friberg
- * @author Morten
  * @author Jon Harald Søby
- * @author M.M.S.
- * @author Siebrand
+ * @author Lars J. Helbo <lars.helbo@gmail.com>
  * @author Peter Andersen
+ * @author Ranveig
  * @author S.Örvarr.S
- * @author H92
- * @author Boivie
- * @author Ranveig
- * @author Lars J. Helbo <lars.helbo@gmail.com>
- * @author Anders Wegge Jakobsen <awegge@gmail.com>
  */
 
 $namespaceNames = array(
@@ -194,10 +192,10 @@
 'tog-nolangconversion'        => 'Deaktiver konverteringer af sprogvarianter',
 'tog-ccmeonemails'            => 'Send mig kopier af e-mails, som jeg sender til andre brugere.',
 'tog-diffonly'                => 'Vis ved versionssammenligninger kun forskelle, ikke hele siden',
-'tog-showhiddencats'          => 'Vis skjulte kategorier',
+'tog-showhiddencats'          => 'Show hidden categories',
 
 'underline-always'  => 'altid',
-'underline-never'   => 'Aldrig',
+'underline-never'   => 'aldrig',
 'underline-default' => 'efter browserindstilling',
 
 'skinpreview' => '(Forhåndsvisning)',
@@ -256,18 +254,18 @@
 
 # Categories related messages
 'pagecategories'                 => '{{PLURAL:$1|Kategori|Kategorier}}',
-'category_header'                => 'Artikler i kategorien »$1«',
+'category_header'                => 'Artikler i kategorien "$1"',
 'subcategories'                  => 'Underkategorier',
 'category-media-header'          => 'Medier i kategorien „$1“',
 'category-empty'                 => "''Denne kategori indeholder for øjeblikket hverken sider eller medie-filer.''",
 'hidden-categories'              => '{{PLURAL:$1|Skjult kategori|Skjulte kategorier}}',
 'hidden-category-category'       => 'Skjulte kategorier', # Name of the category where hidden categories will be listed
-'category-subcat-count'          => '{{PLURAL:$1|Denne kategori har kun følgende underkategori.|Denne kategori har følgende {{PLURAL:$1|underkategori|$1 underkategorier}}, af i alt $2.}}',
-'category-subcat-count-limited'  => 'Denne kategori har følgende {{PLURAL:$1|underkategori|$1 underkategorier}}.',
-'category-article-count'         => '{{PLURAL:$2|Denne kategori indeholder kun følgende side.|Følgende {{PLURAL:$1|side|$1 sider}} er i denne kategorien, af i alt $2.}}',
-'category-article-count-limited' => 'Følgende {{PLURAL:$1|side|$1 sider}} er i denne kategori.',
-'category-file-count'            => '{{PLURAL:$2|Denne kategori indeholder kun følgende fil.|Følgende {{PLURAL:$1|fil|$1 filer}} er i denne kategori, af i alt $2.}}',
-'category-file-count-limited'    => 'Følgende {{PLURAL:$1|fil|$1 filer}} er i denne kategori.',
+'category-subcat-count'          => '{{PLURAL:$2|Denne kategori har en underkategori.|Denne kategori indeholder nedenstående {{PLURAL:$1|underkategori|$1 underkategorier}}, af ialt $2.}}',
+'category-subcat-count-limited'  => 'Denne kategori indeholder {{PLURAL:$1|underkategori|$1 underkategorier}}.',
+'category-article-count'         => 'Denne kategori indeholder {{PLURAL:$2|kun den nedenstående side|{{PLURAL:$1|den nedenstående side|de nedenstående $1 sider}} af ialt $2.}}',
+'category-article-count-limited' => 'Kategorien indeholder {{PLURAL:$1|den nedenstående side|de nedenstående $1 sider}}.',
+'category-file-count'            => 'Denne kategori indeholder {{PLURAL:$2|kun den nedenstående fil|{{PLURAL:$1|den nedenstående fil|de nedenstående $1 filer}} af ialt $2.}}',
+'category-file-count-limited'    => 'Kategorien indeholder {{PLURAL:$1|den nedenstående fil|de nedenstående $1 filer}}.',
 'listingcontinuesabbrev'         => ' forts.',
 
 'mainpagetext'      => 'MediaWiki er nu installeret.',
@@ -310,11 +308,11 @@
 'permalink'         => 'Permanent henvisning',
 'print'             => 'Udskriv',
 'edit'              => 'Redigér',
-'create'            => 'Opret',
+'create'            => 'opret',
 'editthispage'      => 'Redigér side',
-'create-this-page'  => 'Oprette denne side',
+'create-this-page'  => 'opret ny side',
 'delete'            => 'Slet',
-'deletethispage'    => 'Slet denne side',
+'deletethispage'    => 'Slet side',
 'undelete_short'    => 'Fortryd sletning af {{PLURAL:$1|$1 version|$1 versioner}}',
 'protect'           => 'Beskyt',
 'protect_change'    => 'Ændret beskyttelse',
@@ -334,10 +332,10 @@
 'userpage'          => 'Se brugersiden',
 'projectpage'       => 'Se projektsiden',
 'imagepage'         => 'Se billedsiden',
-'mediawikipage'     => 'Vis indholdsside',
-'templatepage'      => 'Vis skabelonside',
-'viewhelppage'      => 'Vis hjælpeside',
-'categorypage'      => 'Vis kategoriside',
+'mediawikipage'     => 'Vise indholdsside',
+'templatepage'      => 'Vise skabelonside',
+'viewhelppage'      => 'Vise hjælpeside',
+'categorypage'      => 'Vise kategoriside',
 'viewtalkpage'      => 'Se diskussion',
 'otherlanguages'    => 'Andre sprog',
 'redirectedfrom'    => '(Omdirigeret fra $1)',
@@ -346,7 +344,7 @@
 'viewcount'         => 'Siden er vist i alt $1 {{PLURAL:$1|gang|gange}}.',
 'protectedpage'     => 'Beskyttet side',
 'jumpto'            => 'Skift til:',
-'jumptonavigation'  => 'navigation',
+'jumptonavigation'  => 'Navigation',
 'jumptosearch'      => 'Søgning',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
@@ -381,7 +379,7 @@
 'badaccess-groups' => 'Denne handling kan kun udføres af brugere, som tilhører en af grupperne „$1“.',
 
 'versionrequired'     => 'Kræver version $1 af MediaWiki',
-'versionrequiredtext' => 'Version $1 af MediaWiki er påkrævet, for at bruge denne side. Se [[Special:Version|Versionssiden]]',
+'versionrequiredtext' => 'Version $1 af MediaWiki er påkrævet, for at bruge denne side. Se [[{{ns:special}}:Version|Versionssiden]]',
 
 'ok'                      => 'OK',
 'retrievedfrom'           => 'Hentet fra "$1"',
@@ -391,54 +389,49 @@
 'youhavenewmessagesmulti' => 'Der er nye meddelelser til dig: $1',
 'editsection'             => 'redigér',
 'editold'                 => 'redigér',
-'viewsourceold'           => 'vis kilden',
+'viewsourceold'           => 'vis kildekode',
 'editsectionhint'         => 'Rediger afsnit: $1',
 'toc'                     => 'Indholdsfortegnelse',
 'showtoc'                 => 'vis',
 'hidetoc'                 => 'skjul',
 'thisisdeleted'           => 'Se eller gendan $1?',
-'viewdeleted'             => 'Vis $1?',
+'viewdeleted'             => 'Vise $1?',
 'restorelink'             => '{{PLURAL:$1|en slettet ændring|$1 slettede ændringer}}',
 'feedlinks'               => 'Feed:',
 'feed-invalid'            => 'Ugyldig abonnementstype.',
-'feed-unavailable'        => 'RSS og Atom feeds er ikke tilgængelige på {{SITENAME}}',
+'feed-unavailable'        => '{{SITENAME}} har ingen syndikerings-feeds',
 'site-rss-feed'           => '$1 RSS-feed',
 'site-atom-feed'          => '$1 Atom-feed',
 'page-rss-feed'           => '"$1" RSS-feed',
 'page-atom-feed'          => '"$1" Atom-feed',
-'red-link-title'          => '$1 (ikke skrevet endnu)',
+'red-link-title'          => '$1 (uoprettet)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
-'nstab-main'      => 'Side',
-'nstab-user'      => 'Brugerside',
+'nstab-main'      => 'artikel',
+'nstab-user'      => 'brugerside',
 'nstab-media'     => 'medie',
 'nstab-special'   => 'speciel',
 'nstab-project'   => 'om',
-'nstab-image'     => 'Fil',
+'nstab-image'     => 'billede',
 'nstab-mediawiki' => 'besked',
-'nstab-template'  => 'Skabelon',
+'nstab-template'  => 'skabelon',
 'nstab-help'      => 'hjælp',
-'nstab-category'  => 'Kategori',
+'nstab-category'  => 'kategori',
 
 # Main script and global functions
 'nosuchaction'      => 'Funktionen findes ikke',
 'nosuchactiontext'  => "Funktion angivet i URL'en kan ikke genkendes af MediaWiki-softwaren",
 'nosuchspecialpage' => 'En sådan specialside findes ikke',
-'nospecialpagetext' => "<big>'''Du har bedt om en ugyldig specialside.'''</big>
+'nospecialpagetext' => 'Du har bedt om en specialside, der ikke kan genkendes af MediaWiki-softwaren.',
 
-En liste over gyldige specialsider kan findes på [[Special:Specialpages|{{int:specialpages}}]].",
-
 # General errors
 'error'                => 'Fejl',
 'databaseerror'        => 'Databasefejl',
-'dberrortext'          => 'Der er opstået en syntaksfejl i en databaseforespørgsel.
-Dette kan betyde en fejl i softwaren.
-Den seneste forsøgte databaseforespørgsel var:
-<blockquote><tt>$1</tt></blockquote>
-fra funktionen "<tt>$2</tt>".
+'dberrortext'          => 'Der er opstået en syntaksfejl i en databaseforespørgsel. Dette kan være på grund af en ugyldig forespørgsel (se $5), eller det kan betyde en fejl i softwaren. 
+Den seneste forsøgte databaseforespørgsel var: <blockquote><tt>$1</tt></blockquote> fra funktionen "<tt>$2</tt>". 
 MySQL returnerede fejlen "<tt>$3: $4</tt>".',
-'dberrortextcl'        => 'Der er opstået en syntaksfejl i en databaseforespørgsel.
-Den seneste forsøgte databaseforespørgsel var: "$1" fra funktionen "$2".
+'dberrortextcl'        => 'Der er opstået en syntaksfejl i en databaseforespørgsel. 
+Den seneste forsøgte databaseforespørgsel var: "$1" fra funktionen "$2". 
 MySQL returnerede fejlen "$3: $4".',
 'noconnect'            => 'Der er problemer med {{SITENAME}}s database, vi kan desværre ikke komme i kontakt med den for øjeblikket. Prøv igen senere. <br />$1',
 'nodb'                 => 'Kunne ikke vælge databasen $1',
@@ -449,9 +442,16 @@
 'readonlytext'         => 'Databasen er midlertidigt skrivebeskyttet. Forsøg venligst senere.
 
 Årsag til spærringen: $1',
-'missingarticle-rev'   => '(version $1)',
-'missingarticle-diff'  => '(forskel: $1, $2)',
-'readonly_lag'         => 'Databasen er automatisk blevet låst mens slavedatabaseserverne synkroniserer med master databasen',
+'missing-article'      => 'Databasen indeholder ikke teksten til en side der burde eksistere med navnet "$1" $2.
+
+Den sandsynlige årsag er at du har fulgt et forældet link til en
+forskel eller en gammel version af en side der er blevet slettet. Hvis
+det ikke er tilfældet, har du muligvis fundet en software-fejl. Gør
+venligst en [[Special:ListUsers/sysop|administrator]] opmærksom på
+det, og husk at fortælle hvilken URL du har fulgt.',
+'missingarticle-rev'   => '(versionsnummer: $1)',
+'missingarticle-diff'  => '(Forskel: $1, $2)',
+'readonly_lag'         => 'Databasen er automatisk blevet låst mens slave database serverne synkronisere med master databasen',
 'internalerror'        => 'Intern fejl',
 'internalerror_info'   => 'Internal fejl: $1',
 'filecopyerror'        => 'Kunne ikke kopiere filen "$1" til "$2".',
@@ -489,6 +489,11 @@
 'ns-specialprotected'  => 'Sider i navnerummet {{ns:special}} kan ikke redigeres.',
 'titleprotected'       => 'Dette sidenavn er beskyttet mod oprettelse af [[User:$1|$1]]. Begrundelsen for beskyttelsen er <i>$2</i>.',
 
+# Virus scanner
+'virus-badscanner'     => 'Konfigurationsfejl: ukendt virus-scanner: <i>$1</i>',
+'virus-scanfailed'     => 'virus-scan fejlede med fejlkode $1',
+'virus-unknownscanner' => 'ukendt virus-scanner:',
+
 # Login and logout pages
 'logouttitle'                => 'Bruger-log-af',
 'logouttext'                 => 'Du er nu logget af.
@@ -497,8 +502,8 @@
 
 Din konto er blevet oprettet. Glem ikke at personliggøre dine {{SITENAME}}-indstillinger.',
 'loginpagetitle'             => 'Bruger log på',
-'yourname'                   => 'Brugernavn:',
-'yourpassword'               => 'Adgangskode:',
+'yourname'                   => 'Dit brugernavn',
+'yourpassword'               => 'Din adgangskode',
 'yourpasswordagain'          => 'Gentag adgangskode',
 'remembermypassword'         => 'Husk min adgangskode til næste gang.',
 'yourdomainname'             => 'Dit domænenavn',
@@ -519,34 +524,34 @@
 'createaccountmail'          => 'via e-mail',
 'badretype'                  => 'De indtastede adgangskoder er ikke ens.',
 'userexists'                 => 'Det brugernavn du har valgt er allerede i brug. Vælg venligst et andet brugernavn.',
-'youremail'                  => 'E-mail:',
+'youremail'                  => 'Din e-mail-adresse *',
 'username'                   => 'Brugernavn:',
 'uid'                        => 'Bruger-ID:',
-'prefs-memberingroups'       => 'Medlemmer af {{PLURAL:$1|gruppe|grupper}}:',
-'yourrealname'               => 'Virkeligt navn:',
-'yourlanguage'               => 'Sprog:',
+'prefs-memberingroups'       => 'Medlem af {{PLURAL:$1|gruppen|grupperne}}:',
+'yourrealname'               => 'Dit rigtige navn*',
+'yourlanguage'               => 'Ønsket sprog',
 'yourvariant'                => 'Sprogvariant',
-'yournick'                   => 'Kaldenavn:',
+'yournick'                   => 'Dit kaldenavn (til signaturer)',
 'badsig'                     => 'Syntaksen i underskriften er ugyldig; kontroller venligst den brugte HTML.',
-'badsiglength'               => 'Underskriften er for lang. Den må højst indeholde $1 {{PLURAL:$1|tegn|tegn}}.',
+'badsiglength'               => 'Underskriften er for lang. Den må højst indeholde {{PLURAL:$1|}}$1 tegn.',
 'email'                      => 'E-mail',
 'prefs-help-realname'        => '* <strong>Dit rigtige navn</strong> (valgfrit): Hvis du vælger at oplyse dit navn vil dette blive brugt til at tilskrive dig dit arbejde.',
-'loginerror'                 => 'Fejl med at logge på',
-'prefs-help-email'           => '** <strong>E-mail-adresse</strong> (valgfrit): Giver andre mulighed for at kontakte dig,
-uden du behøver at afsløre din e-mail-adresse.
+'loginerror'                 => 'Logon mislykket',
+'prefs-help-email'           => '** <strong>E-mail-adresse</strong> (valgfrit): Giver andre mulighed for at kontakte dig, 
+uden du behøver at afsløre din e-mail-adresse. 
 Det kan også bruges til at fremsende en ny adgangskode til dig, hvis du glemmer den du har.',
 'prefs-help-email-required'  => 'E-mail-adresse er krævet.',
 'nocookiesnew'               => 'Din brugerkonto er nu oprettet, men du er ikke logget på. {{SITENAME}} bruger cookies til at logge brugere på. Du har slået cookies fra. Vær venlig at slå cookies til, og derefter kan du logge på med dit nye brugernavn og kodeord.',
 'nocookieslogin'             => '{{SITENAME}} bruger cookies til at logge brugere på. Du har slået cookies fra. Slå dem venligst til og prøv igen.',
 'noname'                     => 'Du har ikke angivet et gyldigt brugernavn.',
 'loginsuccesstitle'          => 'Du er nu logget på',
-'loginsuccess'               => 'Du er nu logget på {{SITENAME}} som »$1«.',
+'loginsuccess'               => 'Du er nu logget på {{SITENAME}} som "$1".',
 'nosuchuser'                 => 'Der er ingen bruger med navnet "$1". Kontrollér stavemåden igen, eller brug formularen herunder til at oprette en ny brugerkonto.',
-'nosuchusershort'            => 'Der er ingen bruger ved navn "<nowiki>$1</nowiki>". Tjek din stavning.',
+'nosuchusershort'            => 'Der er ingen bruger ved navn "$1". Tjek din stavning.',
 'nouserspecified'            => 'Angiv venligst et brugernavn.',
 'wrongpassword'              => 'Den indtastede adgangskode var forkert. Prøv igen.',
 'wrongpasswordempty'         => 'Du glemte at indtaste password. Prøv igen.',
-'passwordtooshort'           => 'Dit kodeord er for kort. Det skal være mindst {{PLURAL:$1|et tegn|$1 tegn}} langt.',
+'passwordtooshort'           => 'Dit kodeord er for kort. Det skal være mindst {{PLURAL:$1|}}$1 tegn langt.',
 'mailmypassword'             => 'Send et nyt password til min e-mail-adresse',
 'passwordremindertitle'      => 'Nyt password til {{SITENAME}}',
 'passwordremindertext'       => 'Nogen (sandsynligvis dig, fra IP-addressen $1)
@@ -554,7 +559,7 @@
 Adgangskoden for bruger "$2" er nu "$3".
 Du bør logge på nu og ændre din adgangskode.,
 
-Hvis en anden har bestilt den nye adgangskode eller hvis du er kommet i tanke om dit gamle password og ikke mere vil ændre det,
+Hvis en anden har bestilt den nye adgangskode eller hvis du er kommet i tanke om dit gamle password og ikke mere vil ændre det, 
 kan du bare ignorere denne mail og fortsætte med at bruge dit gamle password.',
 'noemail'                    => 'Der er ikke oplyst en e-mail-adresse for bruger "$1".',
 'passwordsent'               => 'En ny adgangskode er sendt til e-mail-adressen,
@@ -564,9 +569,9 @@
 'eauthentsent'               => 'En bekrftelsesmail er sendt til den angivne E-mail-adresse.
 
 Før en E-mail kan modtages af andre brugere af {{SITENAME}}-mailfunktionen, skal adressen og dens tilhørsforhold til denne bruger bekræftes. Følg venligst anvisningerne i denne mail.',
-'throttled-mailpassword'     => 'Indenfor de sidste {{PLURAL:$1|time|$1 timer}} er der allerede sendt et nyt password. For at forhindre misbrug af funktionen, kan der kun bestilles et nyt password en gang for hver {{PLURAL:$1|time|$1 timer}}.',
+'throttled-mailpassword'     => 'Indenfor {{PLURAL:$1|den sidste time|de sidste $1 timer}} er der allerede sendt et nyt password. For at forhindre misbrug af funktionen, kan der kun bestilles et nyt password en gang for hver {{PLURAL:$1|time|$1 timer}}.',
 'mailerror'                  => 'Fejl ved afsendelse af e-mail: $1',
-'acct_creation_throttle_hit' => 'Du har allerede oprettet $1 brugerkonti. Du kan ikke oprette flere.',
+'acct_creation_throttle_hit' => 'Du har allerede oprettet $1 kontoer. Du kan ikke oprette flere.',
 'emailauthenticated'         => 'Din e-mail-adresse blev bekræftet på $1.',
 'emailnotauthenticated'      => 'Din e-mail-adresse er endnu ikke bekræftet og de avancerede e-mail-funktioner er slået fra indtil bekræftelse har fundet sted (d.u.a.). Log ind med den midlertidige adgangskode, der er blevet sendt til dig, for at bekræfte, eller bestil et nyt på loginsiden.',
 'noemailprefs'               => 'Angiv en E-mail-adresse, så følgende funktioner er til rådighed.',
@@ -575,10 +580,10 @@
 'accountcreated'             => 'Brugerkonto oprettet',
 'accountcreatedtext'         => 'Brugerkontoen $1 er oprettet.',
 'createaccount-title'        => 'Opret brugerkonto på {{SITENAME}}',
-'createaccount-text'         => 'En bruger har oprettet en konto for $2 på {{SITENAME}} ($4). Password for "$2" er "$3".
-Du opfordres til at logge ind, og ændre kodeordet omgående.
+'createaccount-text'         => 'En bruger ($1) har oprettet en konto for $2 på {{SITENAME}}
+($4). Password for "$2" er "$3". Du opfordres til at logge ind, og ændre kodeordet omgående.
 
-Denne besked kan ignoreres, hvis denne konto er oprettet som følge af en fejl.',
+Denne besked kan ignorewres, hvis denne konto er oprettet som følge af en fejl.',
 'loginlanguagelabel'         => 'Sprog: $1',
 
 # Password reset dialog
@@ -598,7 +603,7 @@
 'italic_tip'      => 'Kursiv tekst',
 'link_sample'     => 'Henvisning',
 'link_tip'        => 'Intern henvisning',
-'extlink_sample'  => 'http://www.example.com Titel på henvisning',
+'extlink_sample'  => 'http://www.eksempel.dk Titel på henvisning',
 'extlink_tip'     => 'Ekstern henvisning (husk http:// præfiks)',
 'headline_sample' => 'Tekst til overskrift',
 'headline_tip'    => 'Type 2 overskrift',
@@ -617,14 +622,14 @@
 'summary'                          => 'Beskrivelse',
 'subject'                          => 'Emne/overskrift',
 'minoredit'                        => 'Dette er en mindre ændring.',
-'watchthis'                        => 'Overvåg denne side',
+'watchthis'                        => 'Overvåg denne artikel',
 'savearticle'                      => 'Gem side',
 'preview'                          => 'Forhåndsvisning',
 'showpreview'                      => 'Forhåndsvisning',
 'showlivepreview'                  => 'Live-forhåndsvisning',
 'showdiff'                         => 'Vis ændringer',
-'anoneditwarning'                  => 'Du arbejder uden at være logget på. Istedet for brugernavn vises så IP-adressen i versionshistorikken.',
-'missingsummary'                   => "'''Bemærk:''' du har ikke angivet en resume. Hvis du atter trykker på „Gem“, gemmes ændringerne uden resume.",
+'anoneditwarning'                  => 'Du arbejder uden at være logget på. Istedet for brugernavn vises din IP-adresse i versionshistorikken.',
+'missingsummary'                   => "'''Bemærk:''' du har ikke angivet en redigeringsbeskrivelse. Hvis du atter trykker på „Gem“, gemmes ændringerne uden resume.",
 'missingcommenttext'               => 'Indtast venligst et resume.',
 'missingcommentheader'             => "'''BEMÆRK:''' du har ikke angivet en overskrift i feltet „Emne:“. Hvis du igen trykker på „Gem side“, gemmes bearbejdningen uden overskrift.",
 'summary-preview'                  => 'Forhåndsvisning af resumelinien',
@@ -632,7 +637,7 @@
 'blockedtitle'                     => 'Brugeren er blokeret',
 'blockedtext'                      => "<big>'''Dit brugernavn eller din IP-adresse er blevet blokeret.'''</big>
 
-Blokeringen er lavet af $1. Begrundelsen er ''$2''.
+Blokeringen er foretaget af $1. Begrundelsen er ''$2''.
 
 Blokeringen starter: $8
 Blokeringen udløber: $6
@@ -659,10 +664,6 @@
 'blockededitsource'                => "Kildekoden fra '''Dine ændringer''' til '''$1''':",
 'whitelistedittitle'               => 'Log på for at redigere',
 'whitelistedittext'                => 'Du skal $1 for at kunne ændre artikler.',
-'whitelistreadtitle'               => 'Log på for at læse',
-'whitelistreadtext'                => 'Du skal [[Special:Userlogin|logge på]] for at læse artikler.',
-'whitelistacctitle'                => 'Du har ikke lov til at oprette en konto',
-'whitelistacctext'                 => 'For at få lov til at lave en konto på denne wiki skal du [[Special:Userlogin|logge på]] og have passende rettigheder.',
 'confirmedittitle'                 => 'For at kunne bearbejde er bekræftelsen af E-mail-adressen nødvendig.',
 'confirmedittext'                  => 'Du skal først bekræfte E-mail-adressen, før du kan lave ændringer. Udfyld og bekræft din E-mail-adresse i dine [[Special:Preferences|Indstillinger]].',
 'nosuchsectiontitle'               => 'Afsnit findes ikke',
@@ -674,7 +675,7 @@
 'accmailtext'                      => "Adgangskoden for '$1' er sendt til $2.",
 'newarticle'                       => '(Ny)',
 'newarticletext'                   => "'''{{SITENAME}} har endnu ikke nogen {{NAMESPACE}}-side ved navn {{PAGENAME}}.'''<br /> Du kan begynde en side ved at skrive i boksen herunder. (se [[{{MediaWiki:Helppage}}|hjælpen]] for yderligere oplysninger).<br /> Eller du kan [[Special:Search/{{PAGENAME}}|søge efter {{PAGENAME}} i {{SITENAME}}]].<br /> Hvis det ikke var din mening, så tryk på '''Tilbage'''- eller '''Back'''-knappen.",
-'anontalkpagetext'                 => "---- ''Dette er en diskussionsside for en anonym bruger, der ikke har oprettet en konto endnu eller ikke bruger den. Vi er derfor nødt til at bruge den nummeriske IP-adresse til at identificere ham eller hende. En IP-adresse kan være delt mellem flere brugere. Hvis du er en anonym bruger og synes, at du har fået irrelevante kommentarer på sådan en side, så vær venlig at oprette en brugerkonto og [[Special:Userlogin|logge på]], så vi undgår fremtidige forvekslinger med andre anonyme brugere.''",
+'anontalkpagetext'                 => "---- ''Dette er en diskussionsside for en anonym bruger, der ikke har oprettet en konto endnu eller ikke bruger den. Vi er derfor nødt til at bruge den nummeriske IP-adresse til at identificere ham eller hende. En IP-adresse kan være delt mellem flere brugere. Hvis du er en anonym bruger og synes, at du har fået irrelevante kommentarer på sådan en side, så vær venlig at oprette en brugerkonto og [[Special:UserLogin|logge på]], så vi undgår fremtidige forvekslinger med andre anonyme brugere.''",
 'noarticletext'                    => "'''{{SITENAME}} har ikke nogen side med præcis dette navn.''' * Du kan '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} starte siden {{PAGENAME}}]''' * Eller [[Special:Search/{{PAGENAME}}|søge efter {{PAGENAME}}]] i andre artikler ---- * Hvis du har oprettet denne artikel indenfor de sidste få minutter, så kan de skyldes at der er lidt forsinkelse i opdateringen af {{SITENAME}}s cache. Vent venligst og tjek igen senere om artiklen dukker op, inden du forsøger at oprette artiklen igen.",
 'userpage-userdoesnotexist'        => 'Brugerkontoen "$1" findes ikke. Overvej om du ønsker at oprette eller redigere denne side.',
 'clearyourcache'                   => "'''Bemærk''', efter at have gemt, er du nødt til at tømme din browsers cache for at kunne se ændringerne. '''Mozilla / Firefox / Safari''': hold ''shifttasten'' nede og klik på ''reload'' eller tryk på ''control-shift-r'' (Mac: ''cmd-shift-r''); '''Internet Explorer''': hold ''controltasten'' nede og klik på ''refresh'' eller tryk på ''control-F5''; '''Konqueror''': klik på ''reload'' eller tryk på ''F5''",
@@ -684,7 +685,7 @@
 'userinvalidcssjstitle'            => "'''Advarsel:''' Der findes intet skin „$1“. Tænk på, at brugerspecifikke .css- og .js-sider begynder med små bogstaver, altså f.eks. ''{{ns:user}}:Hansen/monobook.css'' og ikke ''{{ns:user}}:Hansen/Monobook.css''.",
 'updated'                          => '(Opdateret)',
 'note'                             => '<strong>Bemærk:</strong>',
-'previewnote'                      => '<strong>Husk at dette er kun en forhåndsvisning, siden er ikke gemt endnu!</strong>',
+'previewnote'                      => 'Husk at dette er kun en forhåndsvisning, siden er ikke gemt endnu!',
 'previewconflict'                  => 'Denne forhåndsvisning er resultatet af den redigérbare tekst ovenfor, sådan vil det komme til at se ud hvis du vælger at gemme teksten.',
 'session_fail_preview'             => '<strong>Din ændring kunne ikke gemmes, da dine sessionsdata er gået tabt.
 Prøv venligst igen. Hvis problemet fortsætter, log af og log på igen.</strong>',
@@ -717,7 +718,7 @@
 
 Du bekræfter hermed også, at du selv har skrevet denne tekst eller kopieret den fra en offentlig kilde
 (se $1 for detaljer). <strong>OVERFØR IKKE OPHAVSRETSLIGT BESKYTTET INDHOLD!</strong>',
-'longpagewarning'                  => '<strong>ADVARSEL: Denne side er $1 kilobyte stor; nogle browsere kan have problemer med at redigere sider der nærmer sig eller er større end 32 Kb.
+'longpagewarning'                  => '<strong>ADVARSEL: Denne side er $1 kilobyte stor; nogle browsere kan have problemer med at redigere sider der nærmer sig eller er større end 32 Kb. 
 Overvej om siden kan opdeles i mindre dele.</strong>',
 'longpageerror'                    => '<strong>FEJL: Teksten, som du ville gemme, er $1 kB stor. Det er større end det tilladet maksimum på $2 kB. Det er ikke muligt at gemme.</strong>',
 'readonlywarning'                  => '<strong>ADVARSEL: Databasen er låst på grund af vedligeholdelse,
@@ -731,36 +732,34 @@
 'templatesusedsection'             => 'Følgende skabeloner bruges af dette afsnit:',
 'template-protected'               => '(skrivebeskyttet)',
 'template-semiprotected'           => '(skrivebeskyttet for ikke anmeldte og nye brugere)',
-'hiddencategories'                 => 'Denne side er kategoriseret i {{PLURAL:$1|1 skjult kategorie|$1 skjulte kategorier}}:',
+'hiddencategories'                 => 'Denne side er i {{PLURAL:$1|en skjult kategori|$1 skjulte kategorier}}:',
 'edittools'                        => '<!-- Denne tekst vises under formularen „Ændre“ samt "Upload". -->',
 'nocreatetitle'                    => 'Oprettelse af nye sider er begrænset.',
-'nocreatetext'                     => 'Serveren har begrænset oprettelse af nye sider. Bestående sider kan ændres eller [[Special:Userlogin|logge på]].',
+'nocreatetext'                     => 'Serveren har begrænset oprettelse af nye sider. Bestående sider kan ændres eller [[Special:UserLogin|logge på]].',
 'nocreate-loggedin'                => 'Du har ikke rettigheder til at oprette nye sider.',
 'permissionserrors'                => 'Rettighedskonflikt',
 'permissionserrorstext'            => 'Du har ikke rettigheder til at gennemføre denne handling, {{PLURAL:$1|årsagen|årsagerne}} er:',
-'permissionserrorstext-withaction' => 'Du har ikke tilladelse til $2, af følgene {{PLURAL:$1|grund|grunde}}:',
+'permissionserrorstext-withaction' => 'Du har ikke rettigheder til $2, med nedenstående {{PLURAL:$1|grund|grunde}}:',
 'recreate-deleted-warn'            => "'''Advarsel: Du er ved at genskabe en tidligere slettet side.'''
-
-Overvej om det er passende at genoprette siden. De slettede versioner for
+ 
+Overvej om det er passende at genoprette siden. De slettede versioner for 
 denne side er vist nedenfor:",
 
 # Parser/template warnings
 'expensive-parserfunction-warning'        => 'Advarsel: Denne side indeholder ligeledes mange bekostelig analysere funktion opringninger.
 
 Det burde være mindre end $2, der er nu $1.',
-'expensive-parserfunction-category'       => 'Sider med for mange bekostelige analysere funktion opringninger',
-'post-expand-template-inclusion-warning'  => 'Advarsel: Denne siden indeholder for mange skabeloner.
-Nogle af skabelonerne vil ikke blive inkluderet.',
-'post-expand-template-inclusion-category' => 'Sider som indeholder for mange skabeloner',
-'post-expand-template-argument-warning'   => 'Advarsel: Siden indeholder en eller flere skabelonparametre som bliver for lange når de udvides.
-Disse parametre er blevet udeladt.',
+'expensive-parserfunction-category'       => 'Sider med for mange beregningstunge oversætter-funktioner',
+'post-expand-template-inclusion-warning'  => 'Advarsel: Der er tilføjet for mange skabeloner til denne side, så nogle af dem bliver ikke vist..',
+'post-expand-template-inclusion-category' => 'Sider der indeholder for mange skabeloner',
+'post-expand-template-argument-warning'   => 'Advarsel: Mindst en af skabelonparametrene på denne side fylder mere end det tilladte. Denne parameter er derfor udeladt.',
 'post-expand-template-argument-category'  => 'Sider med udeladte skabelonparametre',
 
 # "Undo" feature
 'undo-success' => 'Ændringen er nu annulleret. Kontroller venligst bearbejdningen i sammenligningen og klik så på „Gem side“, for at gemme den.',
 'undo-failure' => '<span class="error">Ændringen kunne ikke annulleres, da det pågældende afsnit i mellemtiden er ændret.</span>',
-'undo-norev'   => 'Redigeringen kunne ikke fjernes fordi den ikke eksistere eller er slettet.',
-'undo-summary' => 'Ændring af $1 [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussion]]) blev annulleret.',
+'undo-norev'   => 'Ændringen kunne ikke annuleres fordi den ikke eksisterer eller er blevet slettet.',
+'undo-summary' => 'Ændring af $1 [[{{ns:special}}:Contributions/$2|$2]] ([[User_talk:$2|Diskussion]]) blev annulleret.',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Brugerkontoen kan ikke oprettes.',
@@ -777,12 +776,12 @@
 'revision-info'       => 'Version fra $1 til $2',
 'previousrevision'    => '←Ældre version',
 'nextrevision'        => 'Nyere version→',
-'currentrevisionlink' => 'Nuværende version',
+'currentrevisionlink' => 'se nuværende version',
 'cur'                 => 'nuværende',
 'next'                => 'næste',
 'last'                => 'forrige',
 'page_first'          => 'Startem',
-'page_last'           => 'enden',
+'page_last'           => 'Enden',
 'histlegend'          => 'Forklaring: (nuværende) = forskel til den nuværende
 version, (forrige) = forskel til den forrige version, M = mindre ændring',
 'deletedrev'          => '[slettet]',
@@ -806,13 +805,13 @@
 'rev-deleted-text-view'       => '<div class="mw-warning plainlinks">Denne version er slettet og er ikke længere offentligt tilgængelig.
 Som administrator kan du stadig se den.
 Nærmere oplysninger om sletningen samt en begrundelse for den findes i [{{fullurl:Special:Log/delete|page={{FULLPAGENAMEE}}}} slette-loggen].</div>',
-'rev-delundel'                => 'vis/skjul',
+'rev-delundel'                => 'vise/skjule',
 'revisiondelete'              => 'Slette/gendanne versioner',
 'revdelete-nooldid-title'     => 'Ingen version angivet',
 'revdelete-nooldid-text'      => 'Du har ikke angivet en version, som denne handling kan udføres på.',
 'revdelete-selected'          => "{{PLURAL:$2|Valgte version|Valgte versioner}} af '''$1:'''",
-'logdelete-selected'          => '{{PLURAL:$1|Valgte logbogsindførsel|Valgte logbogsindførsler}}:',
-'revdelete-text'              => 'Indholdet eller andre bestanddele er ikke mere offentligt tilgængelige, vises dog fortsat i versionshistorikken.
+'logdelete-selected'          => "{{PLURAL:$2|Valgte logbogsindførsel|Valgte logbogsindførsler}} for '''$1:'''",
+'revdelete-text'              => 'Indholdet eller andre bestanddele er ikke mere offentligt tilgængelige, vises dog fortsat i versionshistorikken. 
 
 Administratorer kan dog fortsat se og gendanne det fjernede indhold, medmindre det er bestemt, at adgangsbegrænsningen også skal gælde for administratorer.',
 'revdelete-legend'            => 'Fastlægge begrænsninger for versionerne:',
@@ -827,30 +826,30 @@
 'revdelete-log'               => 'Kommentar/begrundelse (vises også i logbogen):',
 'revdelete-submit'            => 'Bruge på udvalgte versioner',
 'revdelete-logentry'          => 'Versionsvisning ændret for [[$1]]',
-'logdelete-logentry'          => 'ændrede synligheden for [[$1]]',
+'logdelete-logentry'          => "ændrede [[$1]]'s synlighed",
 'revdelete-success'           => 'Versionsvisning er ændret.',
-'logdelete-success'           => 'Logbogs-aktion er indstillet.',
+'logdelete-success'           => "'''Synlighed ændret med success.'''",
 'revdel-restore'              => 'Ændre synlighed',
 'pagehist'                    => 'Sidehistorik',
 'deletedhist'                 => 'Slettet historik',
 'revdelete-content'           => 'indhold',
-'revdelete-summary'           => 'beskrivelse',
-'revdelete-uname'             => 'brugernavn',
-'revdelete-restricted'        => 'satte begrænsninger for administratorer',
+'revdelete-summary'           => 'redigeringsbeskrivelse',
+'revdelete-uname'             => 'bruger',
+'revdelete-restricted'        => 'tilføjede begrænsninger for administratorer',
 'revdelete-unrestricted'      => 'fjernede begrænsninger for administratorer',
-'revdelete-hid'               => 'skjulte $1',
+'revdelete-hid'               => 'usynliggjorde $1',
 'revdelete-unhid'             => 'synliggjorde $1',
 'revdelete-log-message'       => '$1 for $2 {{PLURAL:$2|version|versioner}}',
-'logdelete-log-message'       => '$1 for $2 {{PLURAL:$2|begivenhed|begivenheder}}',
+'logdelete-log-message'       => '$1 for $2 {{PLURAL:$2|hændelse|hændelser}}',
 
 # Suppression log
-'suppressionlog'     => 'Versionsfjernelseslog',
-'suppressionlogtext' => 'Nedenfor er en liste over sider og blokkeringer med indhold skjult fra administratorer.
-Se [[Special:Ipblocklist|blokeringslisten]] for oversigten over nuværende blokkeringer.',
+'suppressionlog'     => 'Skjulningslog',
+'suppressionlogtext' => 'Nedenfor listes de sletninger og blokeringer der er skjult for almindelige systemadministratorer.Below is a list of deletions and blocks involving content hidden from sysops.
+Se [[Special:IPBlockList|IP blokeringslisten]] for alle blokeringer.',
 
 # History merging
 'mergehistory'                     => 'Sammenflet sidehistorikker',
-'mergehistory-header'              => "Denne sider giver mulighed for at flette historikken fra en kildeside ind i en nyere side.
+'mergehistory-header'              => "Denne sider giver mulighed for at flette historikken fra en kildeside ind i en nyere side. 
 Vær opmæksom på at bevare kontinuiteten i sidehistorikken.
 
 '''Bevar som minimum den nuværende udgave af kildesiden.'''",
@@ -868,8 +867,8 @@
 'mergehistory-no-destination'      => 'Destinationssiden $1 findes ikke.',
 'mergehistory-invalid-source'      => 'Angiv et gyldigt sidenavn som kildeside.',
 'mergehistory-invalid-destination' => 'Angiv et gyldigt sidenavn som destinationsside.',
-'mergehistory-autocomment'         => 'Flettet [[:$1]] ind i [[:$2]]',
-'mergehistory-comment'             => 'Flettet [[:$1]] ind i [[:$2]]: $3',
+'mergehistory-autocomment'         => 'Flettede [[:$1]] ind i [[:$2]]',
+'mergehistory-comment'             => 'Flettede [[:$1]] ind i [[:$2]]: $3',
 
 # Merge log
 'mergelog'           => 'Sammenfletningslog',
@@ -883,7 +882,7 @@
 'lineno'                  => 'Linje $1:',
 'compareselectedversions' => 'Sammenlign valgte versioner',
 'editundo'                => 'annuller',
-'diff-multi'              => '(Versionssammenligningen medtager {{PLURAL:$1|en mellemliggende version|$1 mellemliggende versioner}}.)',
+'diff-multi'              => "<span style='font-size: smaller'>(Versionssammenligningen medtager {{plural:$1|en mellemliggende version|$1 mellemliggende versioner}}.)</span>",
 
 # Search results
 'searchresults'             => 'Søgeresultater',
@@ -892,7 +891,7 @@
 'searchsubtitleinvalid'     => 'Til din søgning „$1“.',
 'noexactmatch'              => '{{SITENAME}} har ingen artikel med dette navn. Du kan [[:$1|oprette en artikel med dette navn]].',
 'noexactmatch-nocreate'     => "'''Der er ingen side med navnet \"\$1\".'''",
-'toomanymatches'            => 'Der blev returneret for mange resultater, prøv en anden søgning',
+'toomanymatches'            => 'Søgningen fandt for mange sider. Prøv venligst med en anden søgning.',
 'titlematches'              => 'Artikeltitler der opfyldte forespørgslen',
 'notitlematches'            => 'Ingen artikeltitler opfyldte forespørgslen',
 'textmatches'               => 'Artikeltekster der opfyldte forespørgslen',
@@ -900,13 +899,13 @@
 'prevn'                     => 'forrige $1',
 'nextn'                     => 'næste $1',
 'viewprevnext'              => 'Vis ($1) ($2) ($3).',
-'search-result-size'        => '$1 ({{PLURAL:$2|1 ord|$2 ord}})',
-'search-result-score'       => 'Relevans: $1&nbsp;%',
-'search-redirect'           => '(omdirigering $1)',
+'search-result-size'        => '$1 ({{PLURAL:$2|et ord|$2 ord}})',
+'search-result-score'       => 'Relevans: $1%',
+'search-redirect'           => '(omdirriger $1)',
 'search-section'            => '(sektion $1)',
 'search-suggest'            => 'Mente du: $1',
 'search-interwiki-caption'  => 'Søsterprojekter',
-'search-interwiki-default'  => '$1 resultater:',
+'search-interwiki-default'  => '{{PLURAL:$1|et resultat|$1 resultater}}:',
 'search-interwiki-more'     => '(mere)',
 'search-mwsuggest-enabled'  => 'med forslag',
 'search-mwsuggest-disabled' => 'ingen forslag',
@@ -916,14 +915,14 @@
 'searchall'                 => 'alle',
 'showingresults'            => 'Nedenfor vises <b>$1</b> {{PLURAL:$1|resultat|resultater}} startende med nummer <b>$2</b>.',
 'showingresultsnum'         => 'Herunder vises <b>$3</b> {{PLURAL:$3|resultat|resultater}} startende med nummer <b>$2</b>.',
-'showingresultstotal'       => "Viser resultat {{PLURAL:$3|'''$1'''|'''$1 - $2'''}} af '''$3''' nedenfor",
+'showingresultstotal'       => "Viser {{PLURAL:$3|resultat '''$1''' af '''$3'''|resultaterne '''$1 - $2''' af '''$3'''}}",
 'nonefound'                 => '<strong>Bemærk</strong>: Søgning uden resultat skyldes at man søger efter almindelige ord som "har" og "fra", der ikke er indekseret, eller at man har angivet mere end ét søgeord (da kun sider indeholdende alle søgeordene vil blive fundet).',
 'powersearch'               => 'Søg',
-'powersearch-legend'        => 'Avanceret søg',
-'powersearch-ns'            => 'Søg i navnerum:',
-'powersearch-redir'         => 'Vis omdirigeringer',
+'powersearch-legend'        => 'Avanceret søgning',
+'powersearch-ns'            => 'Søg i navnerummene:',
+'powersearch-redir'         => 'Vis omdirrigeringer',
 'powersearch-field'         => 'Søg efter',
-'search-external'           => 'Ekstern søgning',
+'search-external'           => 'Brug anden søgemaskine',
 'searchdisabled'            => '<p>Beklager! Fuldtekstsøgningen er midlertidigt afbrudt på grund af for stor belastning på serverne. I mellemtidem kan du anvende Google- eller Yahoo!-søgefelterne herunder. Bemærk at deres kopier af {{SITENAME}}s indhold kan være forældet.</p>',
 
 # Preferences page
@@ -931,7 +930,7 @@
 'mypreferences'            => 'Indstillinger',
 'prefs-edits'              => 'Antal redigeringer:',
 'prefsnologin'             => 'Ikke logget på',
-'prefsnologintext'         => 'Du skal være [[Special:Userlogin|logget på]] for at ændre brugerindstillinger.',
+'prefsnologintext'         => 'Du skal være [[Special:UserLogin|logget på]] for at ændre brugerindstillinger.',
 'prefsreset'               => 'Indstillingerne er blevet gendannet fra lageret.',
 'qbsettings'               => 'Hurtigmenu',
 'qbsettings-none'          => 'Ingen',
@@ -955,11 +954,11 @@
 'math_bad_output'          => 'Kan ikke skrive til eller oprette uddata-mappe til math',
 'math_notexvc'             => 'Manglende eksekvérbar texvc; se math/README for opsætningsoplysninger.',
 'prefs-personal'           => 'Brugerdata',
-'prefs-rc'                 => 'Seneste ændringer',
+'prefs-rc'                 => 'Seneste ændringer og artikelstumper',
 'prefs-watchlist'          => 'Overvågningsliste',
 'prefs-watchlist-days'     => 'Antal dage, som overvågningslisten standardmæssigt skal omfatte:',
 'prefs-watchlist-edits'    => 'Antal redigeringer der vises i udvidet overvågningsliste:',
-'prefs-misc'               => 'Diverse',
+'prefs-misc'               => 'Forskelligt',
 'saveprefs'                => 'Gem indstillinger',
 'resetprefs'               => 'Gendan indstillinger',
 'oldpassword'              => 'Gammel adgangskode',
@@ -977,13 +976,13 @@
 'recentchangescount'       => 'Antallet af titler på siden "seneste ændringer"',
 'savedprefs'               => 'Dine indstillinger er blevet gemt.',
 'timezonelegend'           => 'Tidszone',
-'timezonetext'             => '¹Indtast antal timer din lokale tid er forskellig fra serverens tid (UTC).',
+'timezonetext'             => 'Indtast antal timer din lokale tid er forskellig fra serverens tid (UTC). Der bliver automatisk tilpasset til dansk tid, ellers skulle man for eksempel for dansk vintertid, indtaste "1" (og "2" når vi er på sommertid).',
 'localtime'                => 'Lokaltid',
 'timezoneoffset'           => 'Forskel',
 'servertime'               => 'Serverens tid er nu',
 'guesstimezone'            => 'Hent tidszone fra browseren',
 'allowemail'               => 'Tillade E-mails fra andre brugere.',
-'prefs-searchoptions'      => 'søgemuligheder',
+'prefs-searchoptions'      => 'Søgeindstillinger',
 'prefs-namespaces'         => 'Navnerum',
 'defaultns'                => 'Søg som standard i disse navnerum:',
 'default'                  => 'standard',
@@ -994,21 +993,21 @@
 'userrights-lookup-user'      => 'Administrér brugergrupper',
 'userrights-user-editname'    => 'Skriv et brugernavn:',
 'editusergroup'               => 'Redigér brugergrupper',
-'editinguser'                 => "Ændrer rettigheder for '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'editinguser'                 => 'Redigerer $1',
 'userrights-editusergroup'    => 'Redigér brugergrupper',
 'saveusergroups'              => 'Gem brugergrupper',
 'userrights-groupsmember'     => 'Medlem af:',
-'userrights-groups-help'      => 'Du kan ændre hvilke grupper denne bruger er medlem af:
-* En afkrydset boks betyder at brugeren ikke er medlem af gruppen.
-* En ikke afkrydset boks betyder at brugeren ikke er medlem af gruppen.
-* En * betyder at du ikke kan fjerne gruppen når du har tilføjet den, eller omvendt.',
+'userrights-groups-help'      => 'Du kan ændre denne brugers gruppermedlemsskaber::
+* Et markeret afkrydsningsfelt betyder at brugeren er medlen af den pågældende gruppe..
+* Et umarkeret felt betyder at brugeren ikke er medlem af gruppen.
+* En * betyder at du ikke kan fravælge gruppen, når den først er tilføjet og omvendt.',
 'userrights-reason'           => 'Årsag:',
 'userrights-no-interwiki'     => 'Du kan ikke ændre brugerrettigheder på andre wikier.',
 'userrights-nodatabase'       => 'Databasen $1 eksisterer ikke lokalt.',
-'userrights-nologin'          => 'Du skal [[Special:Userlogin|logge på]] med en administrativ konto, før du kan ændre brugerettigheder.',
+'userrights-nologin'          => 'Du skal [[Special:UserLogin|logge på]] med en administrativ konto, før du kan ændre brugerettigheder.',
 'userrights-notallowed'       => 'Din konto har ikke andgang til at ændre brugerrettigheder.',
-'userrights-changeable-col'   => 'Grupper du kan ændre',
-'userrights-unchangeable-col' => 'Grupper du ikke kan ændre',
+'userrights-changeable-col'   => 'Redigerbare grupper',
+'userrights-unchangeable-col' => 'Uredigerbare grupper',
 
 # Groups
 'group'               => 'Gruppe:',
@@ -1017,88 +1016,88 @@
 'group-bot'           => 'Robotter',
 'group-sysop'         => 'Administratorer',
 'group-bureaucrat'    => 'Bureaukrater',
-'group-suppress'      => 'Oversightere',
+'group-suppress'      => 'Logskjulere',
 'group-all'           => '(alle)',
 
-'group-user-member'          => 'Bruger',
+'group-user-member'          => 'bruger',
 'group-autoconfirmed-member' => 'Registreret bruger',
 'group-bot-member'           => 'Robot',
 'group-sysop-member'         => 'Administrator',
 'group-bureaucrat-member'    => 'Bureaukrat',
-'group-suppress-member'      => 'Oversight',
+'group-suppress-member'      => 'logskjuler',
 
 'grouppage-user'          => '{{ns:project}}:Brugere',
 'grouppage-autoconfirmed' => '{{ns:project}}:Registrerede brugere',
 'grouppage-bot'           => '{{ns:project}}:Robotter',
 'grouppage-sysop'         => '{{ns:project}}:Administratorer',
 'grouppage-bureaucrat'    => '{{ns:project}}:Bureaukrater',
-'grouppage-suppress'      => '{{ns:project}}:Oversight',
+'grouppage-suppress'      => '{{ns:project}}:Logskjulere',
 
 # Rights
 'right-read'                 => 'Se sider',
-'right-edit'                 => 'Redigere sider',
-'right-createpage'           => 'Oprette sider (som ikke er diskussionssider)',
+'right-edit'                 => 'Ændre sider',
+'right-createpage'           => 'Oprette andre sider end diskussionssider',
 'right-createtalk'           => 'Oprette diskussionssider',
-'right-createaccount'        => 'Oprette nye brugerkontoer',
-'right-minoredit'            => 'Marker redigeringer som mindre',
+'right-createaccount'        => 'Oprette nye brugere',
+'right-minoredit'            => 'Markere redigeringer som mindre',
 'right-move'                 => 'Flytte sider',
-'right-move-subpages'        => 'Flytter sider med deres undersider',
-'right-suppressredirect'     => 'Behøver ikke at oprette omdirigering ved sideflytning',
+'right-move-subpages'        => 'Flytte sider og undersider',
+'right-suppressredirect'     => 'Flytte sider uden at oprette en omdirigering fra det gamle navn',
 'right-upload'               => 'Lægge filer op',
-'right-reupload'             => 'Overskriv en eksisterene fil',
-'right-reupload-own'         => 'Overskriv en eksisterene fil lagt op af samme bruger',
-'right-reupload-shared'      => 'Tilsidesæt lokalt filer på delt medielager',
-'right-upload_by_url'        => 'Læg en fil op via en URL',
-'right-purge'                => 'Rens serverens cache for sider uden en godkendelseside',
-'right-autoconfirmed'        => 'Redigér semi-beskyttede sider',
-'right-bot'                  => 'Blive behandlet som en automatiseret proces',
-'right-nominornewtalk'       => 'Mindre ændringer til diskussionssider skal ikke udløse meddelelse om ændring af disse',
-'right-apihighlimits'        => 'Brug højere grænser i API forespørgsler',
-'right-writeapi'             => "Brug af skrive API'et",
+'right-reupload'             => 'Overskrive en allerede eksisterende fil',
+'right-reupload-own'         => 'Overskrive en eksisterende fil brugeren selv har lagt op',
+'right-reupload-shared'      => 'Lægge en lokal fil op, selvom den allerede findes centralt',
+'right-upload_by_url'        => 'Lægge en fil op fra en URL',
+'right-purge'                => 'Nulstille sidens cache uden bekræftelse',
+'right-autoconfirmed'        => 'Ændre delvist beskyttede sider',
+'right-bot'                  => 'Redigeringer markeres som robot',
+'right-nominornewtalk'       => 'Mindre ændringer på diskussionssider markerer ikke disse med nyt indhold',
+'right-apihighlimits'        => 'Bruge højere grænser i API',
+'right-writeapi'             => 'Bruge redigeringsdelen af API',
 'right-delete'               => 'Slette sider',
-'right-bigdelete'            => 'Slet sider med stor historik',
-'right-deleterevision'       => 'Slet og gendan specifikke versioner af sider',
-'right-deletedhistory'       => 'Vis slettede poster i versionshistoriken uden tilhørende tekst',
-'right-browsearchive'        => 'Søg efter slettede sider',
-'right-undelete'             => 'Genopret en side',
-'right-suppressrevision'     => 'Gense og gendan versioner skjult for administratorer',
-'right-suppressionlog'       => 'Se private log',
-'right-block'                => 'Blokere andre brugere fra at redigere',
-'right-blockemail'           => 'Bloker en bruger fra at sende e-mail',
-'right-hideuser'             => 'Blokere et brugernavn og skjul det for offentligheden',
-'right-ipblock-exempt'       => 'Omgå IP-, auto- og intervalblokeringer',
-'right-proxyunbannable'      => 'Omgå automatiske blokeringer af proxymaskiner',
-'right-protect'              => 'Ændre beskyttelsesniveauer og redigér beskyttede sider',
-'right-editprotected'        => 'Redigér beskyttede sider (uden kaskaderende sidebeskyttelse)',
-'right-editinterface'        => 'Redigér brugergrænsefladen',
-'right-editusercssjs'        => 'Redigér andre brugeres CSS- og JS-filer',
-'right-rollback'             => 'Fjern hurtigt en den sidste brugers bidrag på en bestemt side',
-'right-markbotedits'         => 'Markér tilbagerullede redigeringer som robotredigeringer',
-'right-noratelimit'          => 'Ikke påvirket af hastighedsbegrænsninger',
-'right-import'               => 'Indporter sider fra andre wikier',
-'right-importupload'         => 'importer sider fra fil upload',
-'right-patrol'               => 'Markér redigeringer som patruljeret',
-'right-autopatrol'           => 'Få redigeringer automatisk markeret som patruljeret',
-'right-patrolmarks'          => 'Vis patruljerings mærker i seneste ændringer',
-'right-unwatchedpages'       => 'Se en liste over overvågede sider',
-'right-trackback'            => 'Giv respons',
-'right-mergehistory'         => 'Sammenlægge sidehistoriker',
+'right-bigdelete'            => 'Slette sider med mange versioner',
+'right-deleterevision'       => 'Slette og gendanne enkelte versioner af sider',
+'right-deletedhistory'       => 'Se slettede verioner, uden at vise versionens indhold.',
+'right-browsearchive'        => 'Søge i slettede sider',
+'right-undelete'             => 'Gendanne en side',
+'right-suppressrevision'     => 'Skjule og synliggøre sletninger for administratorer',
+'right-suppressionlog'       => 'Se skjulte loglister',
+'right-block'                => 'Blokere brugere',
+'right-blockemail'           => 'Blokere en brugers mulighed for at sende mail',
+'right-hideuser'             => 'Blokere et brugernavn og skjule navnet',
+'right-ipblock-exempt'       => 'Redigere fra blokerede IP-adresser',
+'right-proxyunbannable'      => 'Redigere gennem automatisk blokeret proxy',
+'right-protect'              => 'Ændre beskyttelse og redigere beskyttede sider',
+'right-editprotected'        => 'Ændre beskyttede sider (uden nedarvet sidebeskyttelse)',
+'right-editinterface'        => 'Ændre brugergrænsefladens tekster',
+'right-editusercssjs'        => 'Ændre andre brugeres JS og CSS filer',
+'right-rollback'             => 'Hurtig gendannelse af alle redigeringer foretaget af den seneste bruger',
+'right-markbotedits'         => 'Markere gendannelser som ændringer foretaget af en robot',
+'right-noratelimit'          => 'Upåvirket af hastighedsgrænser',
+'right-import'               => 'Importere sider fra andre wikier',
+'right-importupload'         => 'Importere sider fra en uploadet fil',
+'right-patrol'               => 'Markere andres ændringer som patruljeret',
+'right-autopatrol'           => 'Egne redigeringer vises automatisk som patruljerede',
+'right-patrolmarks'          => 'Se de seneste patruljeringer',
+'right-unwatchedpages'       => 'Se hvilke sider der ikke er på en brugers overvågningsliste',
+'right-trackback'            => 'Tilføje trackback',
+'right-mergehistory'         => 'Sammenflette sidehistorik',
 'right-userrights'           => 'Ændre alle brugerrettigheder',
-'right-userrights-interwiki' => 'Ændre brugerrettigheder for brugere på andre wikisider',
-'right-siteadmin'            => 'Låse og låse op databasen',
+'right-userrights-interwiki' => 'Ændre brugerrettigheder på andre wikier',
+'right-siteadmin'            => 'Låse og frigive databasen',
 
 # User rights log
 'rightslog'      => 'Rettigheds-logbog',
 'rightslogtext'  => 'Dette er en log over ændringer i brugeres rettigheder.',
 'rightslogentry' => 'ændrede grupperettigheder for „[[$1]]“ fra „$2“ til „$3“.',
-'rightsnone'     => '(ingen)',
+'rightsnone'     => '(-)',
 
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|ændring|ændringer}}',
 'recentchanges'                     => 'Seneste ændringer',
 'recentchangestext'                 => "På denne side kan du følge de seneste ændringer på '''{{SITENAME}}'''.",
 'recentchanges-feed-description'    => 'Med dette feed kan du følge de seneste ændringer på {{SITENAME}}.',
-'rcnote'                            => "Herunder ses {{PLURAL:$1|'''1''' ændring|de sidste '''$1''' ændringer}} fra {{PLURAL:$2|i dag|de sidste '''$2''' dage}}, som i $3.",
+'rcnote'                            => "Herunder ses {{PLURAL:$1|'''1''' ændring|de sidste '''$1''' ændringer}} fra {{PLURAL:$2|i dag|de sidste '''$2''' dage}} fra den $4, kl. $5.",
 'rcnotefrom'                        => 'Nedenfor ses ændringerne fra <b>$2</b> til <b>$1</b> vist.',
 'rclistfrom'                        => 'Vis nye ændringer startende fra $1',
 'rcshowhideminor'                   => '$1 mindre ændringer',
@@ -1126,8 +1125,8 @@
 'recentchangeslinked-title'    => 'Ændringer der relaterer til $1',
 'recentchangeslinked-noresult' => 'I det udvalgte tidsrum blev der ikke foretaget ændringer på siderne der henvises til.',
 'recentchangeslinked-summary'  => "Denne specialside viser de seneste ændringer på de sider der henvises til. Sider på din overvågningsliste er vist med '''fed''' skrift.",
-'recentchangeslinked-page'     => 'Sidnavn:',
-'recentchangeslinked-to'       => 'Vis ændringer på sider linket til en given side i stedet',
+'recentchangeslinked-page'     => 'Side:',
+'recentchangeslinked-to'       => 'Vis ændringer i sider der henviser til den angivne side i stedet',
 
 # Upload
 'upload'                      => 'Læg en fil op',
@@ -1135,11 +1134,11 @@
 'reupload'                    => 'Læg en fil op igen',
 'reuploaddesc'                => 'Tilbage til formularen til at lægge filer op.',
 'uploadnologin'               => 'Ikke logget på',
-'uploadnologintext'           => 'Du skal være [[Special:Userlogin|logget på]] for at kunne lægge filer op.',
-'upload_directory_missing'    => 'Oplægningsmappen ($1) mangler og kan ikke oprettes af webserveren.',
+'uploadnologintext'           => 'Du skal være [[Special:UserLogin|logget på]] for at kunne lægge filer op.',
+'upload_directory_missing'    => 'upload-kataloget ($1) findes ikke. Webserveren har ikke mulighed for at oprette kataloget.',
 'upload_directory_read_only'  => 'Webserveren har ingen skriverettigheder for upload-kataloget ($1).',
 'uploaderror'                 => 'Fejl under oplægning af fil',
-'uploadtext'                  => "<strong>STOP!</strong> Før du lægger filer op her, så vær sikker på du har læst og følger {{SITENAME}}s [[{{MediaWiki:Policy-url}}|politik om brug af billeder]]. Følg venligst disse retningslinjer: * Angiv tydeligt hvor filen stammer fra * Brug et beskrivende filnavn, så det er til at se hvad filen indeholder * Tjek i [[Special:Imagelist|listen over filer]] om filen allerede er lagt op
+'uploadtext'                  => "<strong>STOP!</strong> Før du lægger filer op her, så vær sikker på du har læst og følger {{SITENAME}}s [[{{MediaWiki:Policy-url}}|politik om brug af billeder]]. Følg venligst disse retningslinjer: * Angiv tydeligt hvor filen stammer fra * Brug et beskrivende filnavn, så det er til at se hvad filen indeholder * Tjek i [[Special:ImageList|listen over filer]] om filen allerede er lagt op
 
 Brug formularen herunder til at lægge nye filer op, som kan bruges i dine artikler.
 På de fleste browsere vil du se en \"Browse...\" knap eller en \"Gennemse...\" knap, som vil bringe dig til dit styresystems standard-dialog til åbning af filer.
@@ -1164,8 +1163,8 @@
 'filename'                    => 'Filnavn',
 'filedesc'                    => 'Beskrivelse',
 'fileuploadsummary'           => 'Beskrivelse/kilde:',
-'filestatus'                  => 'Status på ophavsret:',
-'filesource'                  => 'Kilde:',
+'filestatus'                  => 'Status på ophavsret',
+'filesource'                  => 'Kilde',
 'uploadedfiles'               => 'Filer som er lagt op',
 'ignorewarning'               => 'Ignorerer advarsler og gemme fil.',
 'ignorewarnings'              => 'Ignorerer advarsler',
@@ -1173,14 +1172,14 @@
 'illegalfilename'             => 'Filnavnet "$1" indeholder tegn, der ikke er tilladte i sidetitler. Omdøb filen og prøv at lægge den op igen.',
 'badfilename'                 => 'Navnet på filen er blevet ændret til "$1".',
 'filetype-badmime'            => 'Filer med MIME-typen „$1“ må ikke uploades.',
-'filetype-unwanted-type'      => "'''\".\$1\"''' er ikke en foretrukken filtype.  De foretrukne filtyper er \$2.",
-'filetype-banned-type'        => "'''\".\$1\"''' er en uønsket filtype.  De tillatdte filtyper er \$2.",
+'filetype-unwanted-type'      => "'''\".\$1\"''' er ikke en foretrukken filtype. {{PLURAL:\$3|Den foretrukne filtype|De foretrukne filtyper}} er \$2.",
+'filetype-banned-type'        => "'''\".\$1\"''' er en uønsket filtype. {{PLURAL:\$3|Den tilladte filtype|De tillatdte filtyper}} er \$2.",
 'filetype-missing'            => 'Filen der skal uploades har ingen endelse (f.eks. „.jpg“).',
 'large-file'                  => 'Filstørrelsen skal så vidt muligt ikke overstige $1. Denne fil er $2 stor.',
 'largefileserver'             => 'Filen er større end den på serveren indstillede maksimale størrelse.',
 'emptyfile'                   => 'Filen du lagde op lader til at være tom. Det kan skyldes en slåfejl i filnavnet. Kontroller om du virkelig ønsker at lægge denne fil op.',
-'fileexists'                  => 'En fil med det navn findes allerede, tjek venligst <strong><tt>$1</tt></strong> om du er sikker på du vil ændre den.',
-'filepageexists'              => 'Beskrivelsessiden for denne fil er allerede oprettet i <strong><tt>$1</tt></strong>, men ingen fil med dette navn eksisterer på nuværende tidspunkt. Den beskrivelse som du indtaster vil ikke blive vist på beskrivelsessiden. For at få beskrivelsen vist her skal du manuelt redigere det.',
+'fileexists'                  => 'En fil med det navn findes allerede, tjek venligst $1 om du er sikker på du vil ændre den.',
+'filepageexists'              => 'Siden med beskrivelse af denne fil er allerede oprettet på <strong><tt>$1</tt></strong>, men der eksisterer ikke en fil med dette navn. Den beskrivelse du kan angive nedenfor vil derfor ikke blive brugt. For at få din beskrivelse vist, skal du selv redigere beskrivelsessiden.',
 'fileexists-extension'        => 'En fil med lignende navn findes allerede:<br />
 Navnet på den valgte fil: <strong><tt>$1</tt></strong><br />
 Navnet på den eksisterende fil: <strong><tt>$2</tt></strong><br />
@@ -1192,7 +1191,7 @@
 Kontroller om du har billedet i fuld størrelse og upload det under det originale navn.',
 'fileexists-forbidden'        => 'Der findes allerede en fil med dette navn. Gå tilbage og upload filen under et andet navn. [[Image:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'Der findes allerede en fil med dette navn. Gå tilbage og upload filen under et andet navn. [[Image:$1|thumb|center|$1]]',
-'file-exists-duplicate'       => 'Denne fil er en dublet at følgene {{PLURAL:$1|fil|filer}}:',
+'file-exists-duplicate'       => 'Denne fil er en bublet af {{PLURAL:$1|den nedenstående fil|de nedenstående $1 filer}}:',
 'successfulupload'            => 'Oplægningen er gennemført',
 'uploadwarning'               => 'Advarsel',
 'savefile'                    => 'Gem fil',
@@ -1203,8 +1202,8 @@
 'uploadscripted'              => 'Denne fil indeholder HTML eller script-kode, der i visse tilfælde can fejlfortolkes af en browser.',
 'uploadcorrupt'               => 'Denne fil er beskadiget eller forsynet med en forkert endelse. Kontroller venligst filen og prøv at lægge den op igen.',
 'uploadvirus'                 => 'Denne fil indeholder en virus! Virusnavn: $1',
-'sourcefilename'              => 'Kildefil:',
-'destfilename'                => 'Målnavn:',
+'sourcefilename'              => 'Kildefil',
+'destfilename'                => 'Målnavn',
 'upload-maxfilesize'          => 'Maksimal filstørrelse: $1',
 'watchthisupload'             => 'Overvåge denne side',
 'filewasdeleted'              => 'En fil med dette navn er tidligere uploadet og i mellemtiden slettet igen. Kontroller først indførslen i $1, før du gemmer filen.',
@@ -1227,17 +1226,17 @@
 'upload-curl-error28'      => 'Tidsoverskridelse ved upload',
 'upload-curl-error28-text' => 'Siden er for længe om at svare. Kontroller om siden er online, vent et øjeblik og prøv igen. Det kan måske hjælpe at prøve på et senere tidspunkt.',
 
-'license'            => 'Licens:',
+'license'            => 'Licens',
 'nolicense'          => 'intet forvalg',
 'license-nopreview'  => '(forhåndsvisning ikke mulig)',
 'upload_source_url'  => ' (gyldig, offentligt tillgængelig URL)',
 'upload_source_file' => ' (en fil på din computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Denne specialside viser alle uploadede filer. Standardmæssigt vises de sidst uploadede filer først. Med et klik på spalteoverskriften kan sorteringen vendes om eller der kan sorteres efter en anden spalte.',
 'imagelist_search_for'  => 'Søge efter fil:',
-'imgfile'               => 'fil',
-'imagelist'             => 'Filliste',
+'imgfile'               => 'Fil',
+'imagelist'             => 'Billedliste',
 'imagelist_date'        => 'Dato',
 'imagelist_name'        => 'Navn',
 'imagelist_user'        => 'Bruger',
@@ -1257,19 +1256,19 @@
 'filehist-filesize'              => 'Filstørrelse',
 'filehist-comment'               => 'Kommentar',
 'imagelinks'                     => 'Billedehenvisninger',
-'linkstoimage'                   => '{{PLURAL:$1|Den følgende side|De følgende $1 sider}} henviser til dette billede:',
+'linkstoimage'                   => '{{Plural:$1|Den følgende side|De følgende $1 sider}} henviser til dette billede:',
 'nolinkstoimage'                 => 'Der er ingen sider der henviser til dette billede.',
-'morelinkstoimage'               => 'Vis [[Special:Whatlinkshere/$1|flere henvisninger]] til denne fil.',
-'redirectstofile'                => '{{PLURAL:$1|Den følgene fil|De følgende $1 filer}} omdirigere til denne fil:',
-'duplicatesoffile'               => '{{PLURAL:$1|Den følgene fil er en dublet|De følgene $1 filer er dubletter}} af denne fil:',
+'morelinkstoimage'               => 'Se [[Special:WhatLinksHere/$1|flere henvisninger]] til denne fil.',
+'redirectstofile'                => '{{PLURAL:$1|Nedenstående fil|De nedenstående $1 filer}} er en omdirigering til denne fil:',
+'duplicatesoffile'               => '{{PLURAL:$1|Nedenstående fil|De nedenstående $1 filer}} er dubletter af denne fil:',
 'sharedupload'                   => 'Denne fil er en fælles upload og kan bruges af andre projekter.',
 'shareduploadwiki'               => 'Se venligst $1 for yderligere information.',
-'shareduploadwiki-desc'          => 'Beskrivelsen som vist på dens $1 vises nedenfor.',
+'shareduploadwiki-desc'          => 'Dens beskrivelse på $1 vises nedenfor.',
 'shareduploadwiki-linktext'      => 'siden med billedbeskrivelsen',
-'shareduploadduplicate'          => 'Denne fil er en dublet af $1 fra delt fillager.',
-'shareduploadduplicate-linktext' => 'en anden fil',
-'shareduploadconflict'           => 'Denne fil har det same navn som  $1 fra delt fillager.',
-'shareduploadconflict-linktext'  => 'en anden fil',
+'shareduploadduplicate'          => 'Denne fil er en dublet af $1 fra den delte server.',
+'shareduploadduplicate-linktext' => 'anden fil',
+'shareduploadconflict'           => 'Denne fil har samme navn som $1 fra den delte server.',
+'shareduploadconflict-linktext'  => 'anden fil',
 'noimage'                        => 'Der eksisterer ingen fil med dette navn, du kan $1',
 'noimage-linktext'               => 'lægge den op',
 'uploadnewversion-linktext'      => 'Læg en ny version af denne fil op',
@@ -1298,13 +1297,12 @@
 'filedelete-nofile-old'       => "Der findes ikke en version af '''$1''' fra $2, $3.",
 'filedelete-iscurrent'        => 'Du har forsøgt at slette den nyeste version. Gendan en tidligere udgave først.',
 'filedelete-otherreason'      => 'Anden/uddybende begrundelse:',
-'filedelete-reason-otherlist' => 'Anden grund',
-'filedelete-reason-dropdown'  => '*Hyppige sletningsårsager
-** Brud på ophavsret
-** Licens ikke oplyst
-** Duplikeret fil
-** Ubrugt fil',
-'filedelete-edit-reasonlist'  => 'Redigér sletningsbegrundelser',
+'filedelete-reason-otherlist' => 'Anden begrundelse',
+'filedelete-reason-dropdown'  => '*Hyppige sletningsbegrundelser
+** Ophavsretskrænkelse
+** Dubletfil
+** Filen er ubrugt',
+'filedelete-edit-reasonlist'  => 'Rediger sletningsårsager',
 
 # MIME search
 'mimesearch'         => 'Søge efter MIME-type',
@@ -1324,7 +1322,7 @@
 'unusedtemplateswlh'  => 'andre henvisninger',
 
 # Random page
-'randompage'         => 'Tilfældig side',
+'randompage'         => 'Tilfældig artikel',
 'randompage-nopages' => 'I dette navnerum findes ingen sider.',
 
 # Random redirect
@@ -1339,7 +1337,7 @@
 Dette tal indeholder \"diskussion\"-sider, sider om {{SITENAME}}, minimale \"stub\"
 sider, omdirigeringssider og andre sider der sikkert ikke kan kaldes artikler.
 Hvis man udelader disse, så er der {{PLURAL:\$2|'''1''' side|'''\$2''' sider}} som sandsynligvis er virkelige
-indholds{{PLURAL:\$2|side|sider}}.
+indholds{{PLURAL:\$2|side|sider}}. 
 
 '''\$8''' {{PLURAL:\$8|fil|filer}} er blevet uploadet.
 
@@ -1347,8 +1345,8 @@
 siden {{SITENAME}} blev oprettet.
 Det bliver til '''\$5''' gennemsnitlige ændringer pr. side, og '''\$6''' visninger pr. ændring.
 
-[http://www.mediawiki.org/wiki/Manual:Job_queue job queue] længden er '''\$7'''.",
-'userstatstext'          => "Der findes '''$1''' {{PLURAL:$1|registreret|registrerede}} [[Special:Listusers|brugere]].
+[http://meta.wikimedia.org/wiki/Help:Job_queue job queue] længden er '''\$7'''.",
+'userstatstext'          => "Der findes '''$1''' {{PLURAL:$1|registreret|registrerede}} [[Special:ListUsers|brugere]].
 deraf har '''$2''' (=$4%) $5-rettigheder.",
 'statistics-mostpopular' => 'Mest besøgte sider',
 
@@ -1356,16 +1354,18 @@
 'disambiguationspage'  => 'Template:Flertydig',
 'disambiguations-text' => 'De følgende sider henviser til en flertydig titel. De bør henvise direkte til det passende emne i stedet. En side behandles som en side med en flertydig titel hvis den bruger en skabelon som er henvist til fra [[MediaWiki:Disambiguationspage]].',
 
-'doubleredirects'     => 'Dobbelte omdirigeringer',
-'doubleredirectstext' => '<b>Bemærk:</b> Denne liste kan indeholde forkerte resultater. Det er som regel, fordi siden indeholder ekstra tekst under den første #REDIRECT.<br /> Hver linje indeholder henvisninger til den første og den anden omdirigering, og den første linje fra den anden omdirigeringstekst, det giver som regel den "rigtige" målartikel, som den første omdirigering skulle have peget på.',
+'doubleredirects'            => 'Dobbelte omdirigeringer',
+'doubleredirectstext'        => '<b>Bemærk:</b> Denne liste kan indeholde forkerte resultater. Det er som regel, fordi siden indeholder ekstra tekst under den første #REDIRECT.<br /> Hver linje indeholder henvisninger til den første og den anden omdirigering, og den første linje fra den anden omdirigeringstekst, det giver som regel den "rigtige" målartikel, som den første omdirigering skulle have peget på.',
+'double-redirect-fixed-move' => '[[$1]] blev flyttet og er nu en omdirigering til [[$2]]',
+'double-redirect-fixer'      => 'Omdirrigerings-retter',
 
 'brokenredirects'        => 'Defekte omdirigeringer',
 'brokenredirectstext'    => 'De følgende omdirigeringer peger på en side der ikke eksisterer.',
-'brokenredirects-edit'   => '(redigér)',
+'brokenredirects-edit'   => '(rediger)',
 'brokenredirects-delete' => '(slet)',
 
 'withoutinterwiki'         => 'Sider uden henvisninger til andre sprog',
-'withoutinterwiki-summary' => 'De følgende sider henviser ikke til andre sprogversioner:',
+'withoutinterwiki-summary' => 'Følgende sider henviser ikke til andre sprog.',
 'withoutinterwiki-legend'  => 'Præfiks',
 'withoutinterwiki-submit'  => 'Vis',
 
@@ -1403,7 +1403,7 @@
 'deadendpages'            => 'Blindgydesider',
 'deadendpagestext'        => 'De følgende sider henviser ikke til andre sider i denne wiki.',
 'protectedpages'          => 'Skrivebeskyttede sider',
-'protectedpages-indef'    => 'Kun beskyttelser på ubestemt tid',
+'protectedpages-indef'    => 'Kun beskyttelser uden udløbadato',
 'protectedpagestext'      => 'De følgende sider er beskyttede mod redigering og flytning.',
 'protectedpagesempty'     => 'I øjeblikket er ingen sider beskyttet på denne måde.',
 'protectedtitles'         => 'Beskyttede sidenavne',
@@ -1414,16 +1414,16 @@
 'newpages-username'       => 'Brugernavn:',
 'ancientpages'            => 'Ældste artikler',
 'move'                    => 'Flyt',
-'movethispage'            => 'Flyt denne side',
+'movethispage'            => 'Flyt side',
 'unusedimagestext'        => '<p>Læg mærke til, at andre websider såsom de andre internationale {{SITENAME}}er måske henviser til et billede med en direkte URL, så det kan stadig være listet her, selvom det er i aktivt brug.',
 'unusedcategoriestext'    => 'Denne specialside viser alle kategorier, som ikke selv er henført til en kategori.',
 'notargettitle'           => 'Sideangivelse mangler',
 'notargettext'            => 'Du har ikke angivet en side eller bruger at udføre denne funktion på.',
-'nopagetitle'             => 'Målsiden findes ikke',
-'nopagetext'              => 'Målsiden som du har andgivet eksistere ikke.',
+'nopagetitle'             => 'Siden findes ikke',
+'nopagetext'              => 'Den angivne side findes ikke.',
 'pager-newer-n'           => '{{PLURAL:$1|1 nyere|$1 nyere}}',
 'pager-older-n'           => '{{PLURAL:$1|1 ældre|$1 ældre}}',
-'suppress'                => 'Oversight',
+'suppress'                => 'Skjul logs',
 
 # Book sources
 'booksources'               => 'Bogkilder',
@@ -1442,12 +1442,12 @@
 'logempty'             => 'Intet passende fundet.',
 'log-title-wildcard'   => 'Titel begynder med …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle artikler',
 'alphaindexline'    => '$1 til $2',
 'nextpage'          => 'Næste side ($1)',
 'prevpage'          => 'Forrige side ($1)',
-'allpagesfrom'      => 'Vis sider startende fra:',
+'allpagesfrom'      => 'Vis sider startende fra: $1',
 'allarticles'       => 'Alle artikler',
 'allinnamespace'    => 'Alle sider (i $1 navnerummet)',
 'allnotinnamespace' => 'Alle sider (ikke i $1 navnerummet)',
@@ -1461,30 +1461,31 @@
 # Special:Categories
 'categories'                    => 'Kategorier',
 'categoriespagetext'            => '{{SITENAME}} har følgende kategorier.',
-'categoriesfrom'                => 'Vis kategorier som starter med:',
+'categoriesfrom'                => 'Vis kategorier startende med:',
 'special-categories-sort-count' => 'sorter efter antal',
 'special-categories-sort-abc'   => 'sorter alfabetisk',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Vis brugere fra:',
 'listusers-submit'   => 'Vis',
 'listusers-noresult' => 'Ingen bruger fundet.',
 
-# Special:Listgrouprights
-'listgrouprights'          => 'Rettigheder for brugergrupper',
-'listgrouprights-summary'  => 'Det følgende er en liste over brugergrubber defineret på denne wiki og med hvilke rettigheder de har.
-Yderlige information omkring individuelle rettigheder kan findes [[{{MediaWiki:Listgrouprights-helppage}}|her]].',
+# Special:ListGroupRights
+'listgrouprights'          => 'Brugergrupperettigheder',
+'listgrouprights-summary'  => 'Denne side vider de brugergrupper der er defineret på denne wiki og de enkelte gruppers rettigheder.
+
+Der findes muligvis [[{{MediaWiki:Listgrouprights-helppage}}|yderligere information]] om de enkelte rettigheder.',
 'listgrouprights-group'    => 'Gruppe',
 'listgrouprights-rights'   => 'Rettigheder',
 'listgrouprights-helppage' => 'Help:Grupperettigheder',
-'listgrouprights-members'  => '(liste over medlemmer)',
+'listgrouprights-members'  => '(vis medlemmer)',
 
 # E-mail user
 'mailnologin'     => 'Du er ikke logget på',
-'mailnologintext' => 'Du skal være [[Special:Userlogin|logget på]] og have en gyldig e-mailadresse sat i dine [[Special:Preferences|indstillinger]] for at sende e-mail til andre brugere.',
+'mailnologintext' => 'Du skal være [[Special:UserLogin|logget på]] og have en gyldig e-mailadresse sat i dine [[Special:Preferences|indstillinger]] for at sende e-mail til andre brugere.',
 'emailuser'       => 'E-mail til denne bruger',
 'emailpage'       => 'E-mail bruger',
-'emailpagetext'   => 'Hvis denne bruger har sat en gyldig e-mail-adresse i sine brugerindstillinger, så vil formularen herunder sende en enkelt besked. Den e-mailadresse, du har sat i dine brugerindstillinger, vil dukke op i "Fra"-feltet på denne mail, så modtageren er i stand til at svare.',
+'emailpagetext'   => 'Hvis denne bruger har sat en gyldig e-mail-adresse i sine brugerindstillinger, så vil formularen herunder sende en enkelt besked. Den e-mailadresse, du har sat i dine brugerindstillinger, vil dukke op i "Fra" feltet på denne mail, så modtageren er i stand til at svare.',
 'usermailererror' => 'E-mail-modulet returnerede en fejl:',
 'defemailsubject' => 'W-mail fra {{SITENAME}}',
 'noemailtitle'    => 'Ingen e-mail-adresse',
@@ -1498,6 +1499,7 @@
 'emailccsubject'  => 'Kopi sendes til $1: $2',
 'emailsent'       => 'E-mail sendt',
 'emailsenttext'   => 'Din e-mail er blevet sendt.',
+'emailuserfooter' => 'Denne e-mail er sendt af $1 til $2 ved hjælp af funktionen "E-mail til denne bruger" på {{SITENAME}}.',
 
 # Watchlist
 'watchlist'            => 'Overvågningsliste',
@@ -1506,17 +1508,17 @@
 'nowatchlist'          => 'Du har ingenting i din overvågningsliste.',
 'watchlistanontext'    => 'Du skal $1, for at se din overvågningsliste eller ændre indholdet af den.',
 'watchnologin'         => 'Ikke logget på',
-'watchnologintext'     => 'Du skal være [[Special:Userlogin|logget på]] for at kunne ændre din overvågningsliste.',
+'watchnologintext'     => 'Du skal være [[Special:UserLogin|logget på]] for at kunne ændre din overvågningsliste.',
 'addedwatch'           => 'Tilføjet til din overvågningsliste',
-'addedwatchtext'       => "Siden \"<nowiki>\$1</nowiki>\" er blevet tilføjet til din [[Special:Watchlist|overvågningsliste]]. Fremtidige ændringer til denne side og den tilhørende diskussionsside vil blive listet der, og siden vil fremstå '''fremhævet''' i [[Special:Recentchanges|listen med de seneste ændringer]] for at gøre det lettere at finde den. Hvis du senere vil fjerne siden fra din overvågningsliste, så klik \"Fjern overvågning\".",
+'addedwatchtext'       => "Siden \"[[:\$1]]\" er blevet tilføjet til din [[Special:Watchlist|overvågningsliste]]. Fremtidige ændringer til denne side og den tilhørende diskussionsside vil blive listet der, og siden vil fremstå '''fremhævet''' i [[Special:RecentChanges|listen med de seneste ændringer]] for at gøre det lettere at finde den. Hvis du senere vil fjerne siden fra din overvågningsliste, så klik \"Fjern overvågning\".",
 'removedwatch'         => 'Fjernet fra overvågningsliste',
-'removedwatchtext'     => 'Siden "<nowiki>$1</nowiki>" er blevet fjernet fra din overvågningsliste.',
+'removedwatchtext'     => 'Siden "$1" er blevet fjernet fra din overvågningsliste.',
 'watch'                => 'Overvåg',
-'watchthispage'        => 'Overvåg denne side',
+'watchthispage'        => 'Overvåg side',
 'unwatch'              => 'Fjern overvågning',
 'unwatchthispage'      => 'Fjern overvågning',
 'notanarticle'         => 'Ikke en artikel',
-'notvisiblerev'        => 'Revisionen er blevet slettet',
+'notvisiblerev'        => 'Versionen er blevet slettet',
 'watchnochange'        => 'Ingen af siderne i din overvågningsliste er ændret i den valgte periode.',
 'watchlist-details'    => 'Du har $1 {{PLURAL:$1|side|sider}} på din overvågningsliste (ekskl. diskussionssider).',
 'wlheader-enotif'      => '* E-mail underretning er slået til.',
@@ -1527,16 +1529,16 @@
 'iteminvalidname'      => "Problem med '$1', ugyldigt navn...",
 'wlnote'               => "Nedenfor ses de seneste $1 {{PLURAL:$1|ændring|ændringer}} i {{PLURAL:$2|den sidste time|'''de sidste $2 timer}}'''.",
 'wlshowlast'           => 'Vis de seneste $1 timer $2 dage $3',
-'watchlist-show-bots'  => 'Vis bot-ændringer',
-'watchlist-hide-bots'  => 'Skjul bot-ændringer',
-'watchlist-show-own'   => 'vis egne ændringer',
-'watchlist-hide-own'   => 'skjul egne ændringer',
-'watchlist-show-minor' => 'vis små ændringer',
-'watchlist-hide-minor' => 'skjul små ændringer',
+'watchlist-show-bots'  => 'Vise bot-ændringer',
+'watchlist-hide-bots'  => 'Skjule bot-ændringer',
+'watchlist-show-own'   => 'vise egne ændringer',
+'watchlist-hide-own'   => 'skjule egne ændringer',
+'watchlist-show-minor' => 'vise små ændringer',
+'watchlist-hide-minor' => 'skjule små ændringer',
 
 # Displayed when you click the "watch" button and it is in the process of watching
-'watching'   => 'Tilføjer overvågning …',
-'unwatching' => 'Fjerner overvågning …',
+'watching'   => 'Overvåge …',
+'unwatching' => 'Ikke overvåge …',
 
 'enotif_mailer'                => '{{SITENAME}} informationsmail',
 'enotif_reset'                 => 'Marker alle sider som besøgt',
@@ -1583,9 +1585,9 @@
 eller et billede sammen med hele den tilhørende historie fra databasen. Bekræft venligst at du virkelig vil gøre dette, at du forstår konsekvenserne, og at du gør dette i overensstemmelse med
 [[{{MediaWiki:Policy-url}}]].',
 'actioncomplete'              => 'Gennemført',
-'deletedtext'                 => '"<nowiki>$1</nowiki>" er slettet. Se $2 for en fortegnelse over de nyeste sletninger.',
+'deletedtext'                 => '"$1" er slettet. Se $2 for en fortegnelse over de nyeste sletninger.',
 'deletedarticle'              => 'slettede "$1"',
-'suppressedarticle'           => 'tilbagehold "[[$1]]"',
+'suppressedarticle'           => 'skjulte "[[$1]]"',
 'dellogpage'                  => 'Sletningslog',
 'dellogpagetext'              => 'Herunder vises de nyeste sletninger. Alle tider er serverens tid (UTC).',
 'deletionlog'                 => 'sletningslog',
@@ -1598,9 +1600,9 @@
 ** Efter forfatters ønske
 ** Overtrædelse af ophavsret
 ** Hærværk',
-'delete-edit-reasonlist'      => 'Redigér sletningsbegrundelser',
-'delete-toobig'               => 'Denne side har en stor historik, over $1 {{PLURAL:$1|version|versioner}}. Sletning af sådanne sider er begrænset blevet for at forhindre utilsigtet forstyrrelse af {{SITENAME}}.',
-'delete-warning-toobig'       => 'Denne side har en stor historik, over $1 {{PLURAL:$1|version|versioner}}, slettes den kan det forstyrre driften af {{SITENAME}}, gå forsigtigt frem.',
+'delete-edit-reasonlist'      => 'Ret sletningsbegrundelser',
+'delete-toobig'               => 'Denne side har en stor historik, over {{PLURAL:$1|en version|$1 versioner}}. Sletning af sådanne sider er begrænset blevet for at forhindre utilsigtet forstyrrelse af {{SITENAME}}.',
+'delete-warning-toobig'       => 'Denne side har en stor historik, over {{PLURAL:$1|en version|$1 versioner}} versioner, slettes den kan det forstyrre driften af {{SITENAME}}, gå forsigtigt frem.',
 'rollback'                    => 'Fjern redigeringer',
 'rollback_short'              => 'Fjern redigering',
 'rollbacklink'                => 'fjern redigering',
@@ -1616,19 +1618,19 @@
 'protectedarticle'            => '[[$1]] beskyttet',
 'modifiedarticleprotection'   => 'ændrede beskyttelsen af "[[$1]]"',
 'unprotectedarticle'          => 'fjernet beskyttelse af [[$1]]',
-'protect-title'               => 'Beskytter "$1"',
+'protect-title'               => 'Ændre beskyttelse af "$1"',
 'protect-legend'              => 'Bekræft beskyttelse',
 'protectcomment'              => 'Begrundelse for beskyttelse',
-'protectexpiry'               => 'Udløb:',
+'protectexpiry'               => 'Udløb',
 'protect_expiry_invalid'      => 'Udløbstiden er ugyldig.',
 'protect_expiry_old'          => 'Udløbstiden ligger i fortiden.',
 'protect-unchain'             => 'Ændre flytningsbeskyttelse',
-'protect-text'                => "Her kan beskyttelsesstatus for siden '''<nowiki>$1</nowiki>''' ses og ændres.",
+'protect-text'                => "Her kan beskyttelsesstatus for siden '''$1''' ses og ændres.",
 'protect-locked-blocked'      => 'Du kan ikke ændre sidens status, da din brugerkonto er spærret. Her er de aktuelle beskyttelsesindstillinger for siden <strong>„$1“:</strong>',
 'protect-locked-dblock'       => 'Databasen er spærret, sidebeskyttelsen kan derfor ikke ændres. her er de aktuelle beskyttelsesindstillinger for siden <strong>„$1“:</strong>',
 'protect-locked-access'       => 'Den brugerkonto har ikke de nødvendige rettigheder til at ændre sidebeskyttelsen. Her er de aktuelle beskyttelsesindstillinger for siden <strong>„$1“:</strong>',
 'protect-cascadeon'           => 'Denne side er del af en nedarvet skrivebeskyttelse. Wen er indeholdt i nedenstående {{PLURAL:$1|side|sider}}, som er skrivebeskyttet med tilvalg af "nedarvende sidebeskyttelse" Sidebeskyttelsen kan ændres for denne side, det påvirker dog ikke kaskadespærringen:',
-'protect-default'             => '(standard)',
+'protect-default'             => 'Alle (Standard)',
 'protect-fallback'            => 'Kræv "$1"-tilladelse',
 'protect-level-autoconfirmed' => 'Spærring for ikke registrerede brugere',
 'protect-level-sysop'         => 'Kun administratorer',
@@ -1639,14 +1641,14 @@
 'restriction-type'            => 'Beskyttelsesstatus',
 'restriction-level'           => 'Beskyttelseshøjde',
 'minimum-size'                => 'Mindste størrelse',
-'maximum-size'                => 'Største størrelse:',
+'maximum-size'                => 'Største størrelse',
 'pagesize'                    => '(bytes)',
 
 # Restrictions (nouns)
-'restriction-edit'   => 'Ændring',
-'restriction-move'   => 'Flytting',
-'restriction-create' => 'Opret',
-'restriction-upload' => 'Læg op',
+'restriction-edit'   => 'ændre',
+'restriction-move'   => 'flytte',
+'restriction-create' => 'oprette',
+'restriction-upload' => 'oplægge',
 
 # Restriction levels
 'restriction-level-sysop'         => 'beskyttet (kun administratorer)',
@@ -1656,9 +1658,10 @@
 # Undelete
 'undelete'                     => 'Gendan en slettet side',
 'undeletepage'                 => 'Se og gendan slettede sider',
-'undeletepagetitle'            => "'''Følgende består af slettede versioner af [[:$1|$1]]'''.",
-'viewdeletedpage'              => 'Vis slettede sider',
+'undeletepagetitle'            => "'''Slettede versioner af [[:$1|$1]]'''.",
+'viewdeletedpage'              => 'Vise slettede sider',
 'undeletepagetext'             => 'De følgende sider er slettede, men de findes stadig i arkivet og kan gendannes. Arkivet blivet periodevis slettet.',
+'undelete-fieldset-title'      => 'Gendan versioner',
 'undeleteextrahelp'            => '* For at gendanne siden komplet med alle versioner, angives en begrundelse før der trykkes på „Gendan“.
 * Hvis der kun skal gendannes bestemte versioner, vælges disse enkeltvis, angiv en begrundelse og klik på „Gendan“.
 * „Afbryde“ tømmer kommentarfeltet og fjerner alle markeringer ved versionerne.',
@@ -1669,26 +1672,27 @@
 dukke op i den tidligere historie, og den nyeste revision vil forblive
 på siden.',
 'undeleterevdel'               => 'Gendannelsen gennemføres ikke, når den mest aktuelle version er skjult eller indeholder skjulte dele.
-I dette tilfælde må den nyeste version ikke markeres eller dens status skal ændres til en normal version.',
+I dette tilfælde må den nyeste version ikke markeres eller dens status skal ændres til en normal version.
+Versioner af filer, som du ikke har adgang til, gendannes ikke.',
 'undeletehistorynoadmin'       => 'Denne side blev ikke slettet. Årsagen til sletningen er angivet i resumeet,
 sammen med oplysninger om den sidste bruger, der ændrede denne side før sletningen.
 Den aktuelle tekst for den slettede side er kun tilgængelig for administratorer.',
 'undelete-revision'            => 'Slettet version fra $1 af $2 slettet af $3:',
 'undeleterevision-missing'     => 'Ugyldig eller manglende version. Enten er henvisningen forkert eller versionen blev fjernet eller gendannet fra arkivet.',
 'undelete-nodiff'              => 'Der findes ingen tidligere version.',
-'undeletebtn'                  => 'Gendan',
+'undeletebtn'                  => 'Gendan!',
 'undeletelink'                 => 'gendan',
 'undeletereset'                => 'Afbryde',
 'undeletecomment'              => 'Begrundelse:',
 'undeletedarticle'             => 'gendannede "$1"',
 'undeletedrevisions'           => '$1 {{PLURAL:$1|version|versioner}} gendannet',
-'undeletedrevisions-files'     => '$1 {{PLURAL:$1|version|versioner}} og $2 {{PLURAL:$2|fil|filer}} gendannet',
-'undeletedfiles'               => '$1 {{PLURAL:$1|fil|filer}} gendannet',
+'undeletedrevisions-files'     => '$1 {{plural:$1|version|versioner}} og $2 {{plural:$2|fil|filer}} gendannet',
+'undeletedfiles'               => '$1 {{plural:$1|fil|filer}} gendannet',
 'cannotundelete'               => 'Gendannelse mislykkedes; en anden har allerede gendannet siden.',
 'undeletedpage'                => "'''$1''' blev gendannet.
 
 I [[Special:Log/delete|slette-loggen]] findes en oversigt over de nyligt slettede og gendannede sider.",
-'undelete-header'              => 'Se [[Special:Log/delete|slette-loggen]] for nyligt slettede og gendannede sider.',
+'undelete-header'              => 'Se [[{{ns:special}}:Log/delete|slette-loggen]] for nyligt slettede og gendannede sider.',
 'undelete-search-box'          => 'Søge efter slettede sider',
 'undelete-search-prefix'       => 'Søgebegreb (odets start uden wildcards):',
 'undelete-search-submit'       => 'Søg',
@@ -1712,7 +1716,7 @@
 'mycontris'     => 'Mine bidrag',
 'contribsub2'   => 'For $1 ($2)',
 'nocontribs'    => 'Ingen ændringer er fundet som opfylder disse kriterier.',
-'uctop'         => '(seneste)',
+'uctop'         => ' (seneste)',
 'month'         => 'Måned:',
 'year'          => 'År:',
 
@@ -1733,26 +1737,26 @@
 'nolinkshere-ns'           => "Ingen side henviser til '''„[[:$1]]“''' i det valgte navnerum.",
 'isredirect'               => 'omdirigeringsside',
 'istemplate'               => 'Skabelonmedtagning',
-'isimage'                  => 'billedelink',
+'isimage'                  => 'fillink',
 'whatlinkshere-prev'       => '{{PLURAL:$1|forrige|forrige $1}}',
 'whatlinkshere-next'       => '{{PLURAL:$1|næste|næste $1}}',
 'whatlinkshere-links'      => '← henvisninger',
-'whatlinkshere-hideredirs' => '$1 omdirigeringer',
-'whatlinkshere-hidetrans'  => '$1 indlejringer',
-'whatlinkshere-hidelinks'  => '$1 links',
-'whatlinkshere-hideimages' => '$1 fillenker',
-'whatlinkshere-filters'    => 'filtre',
+'whatlinkshere-hideredirs' => '$1 omdirrigeringer',
+'whatlinkshere-hidetrans'  => '$1 inkluderinger',
+'whatlinkshere-hidelinks'  => '$1 henvisninger',
+'whatlinkshere-hideimages' => '$1 fillinks',
+'whatlinkshere-filters'    => 'Filtre',
 
 # Block/unblock
-'blockip'                     => 'Bloker bruger',
-'blockip-legend'              => 'Blokér bruger',
-'blockiptext'                 => 'Brug formularen herunder til at blokere for skriveadgangen fra en specifik IP-adresse eller et brugernavn. Dette må kun gøres for at forhindre vandalisme og skal være i overensstemmelse med [[{{MediaWiki:Policy-url}}|{{SITENAME}}s politik]]. Angiv en specifik begrundelse herunder (for eksempel med angivelse af sider der har været udsat for vandalisme). Udløbet (expiry) angives i GNUs standardformat, som er beskrevet i [http://www.gnu.org/software/tar/manual/html_chapter/tar_7.html vejledningen til tar] (på engelsk), fx "1 hour", "2 days", "next Wednesday", "1 January 2017". Alternativt kan en blokering gøres uendelig (skriv "indefinite" eller "infinite"). For oplysninger om blokering af IP-adresseblokke, se [[meta:Range blocks|IP-adresseblokke]] (på engelsk). For at ophæve en blokering, se [[Special:Ipblocklist|listen over blokerede IP-adresser og brugernavne]].',
-'ipaddress'                   => 'IP-adresse:',
-'ipadressorusername'          => 'IP-adresse eller brugernavn',
-'ipbexpiry'                   => 'varighed',
-'ipbreason'                   => 'Begrundelse:',
-'ipbreasonotherlist'          => 'Anden begrundelse',
-'ipbreason-dropdown'          => '
+'blockip'                         => 'Bloker bruger',
+'blockip-legend'                  => 'Bloker bruger',
+'blockiptext'                     => 'Brug formularen herunder til at blokere for skriveadgangen fra en specifik IP-adresse eller et brugernavn. Dette må kun gøres for at forhindre vandalisme og skal være i overensstemmelse med [[{{MediaWiki:Policy-url}}|{{SITENAME}}s politik]]. Angiv en specifik begrundelse herunder (for eksempel med angivelse af sider der har været udsat for vandalisme). Udløbet (expiry) angives i GNUs standardformat, som er beskrevet i [http://www.gnu.org/software/tar/manual/html_chapter/tar_7.html vejledningen til tar] (på engelsk), fx "1 hour", "2 days", "next Wednesday", "1 January 2017". Alternativt kan en blokering gøres uendelig (skriv "indefinite" eller "infinite"). For oplysninger om blokering af IP-adresseblokke, se [[meta:Range blocks|IP-adresseblokke]] (på engelsk). For at ophæve en blokering, se [[Special:IPBlockList|listen over blokerede IP-adresser og brugernavne]].',
+'ipaddress'                       => 'IP-adresse/brugernavn',
+'ipadressorusername'              => 'IP-adresse eller brugernavn',
+'ipbexpiry'                       => 'varighed',
+'ipbreason'                       => 'Begrundelse',
+'ipbreasonotherlist'              => 'Anden begrundelse',
+'ipbreason-dropdown'              => '
 * Generelle begrundelser
 ** Sletning af sider
 ** Oprettelse af tåbelige sider
@@ -1763,70 +1767,71 @@
 ** Ny tilmelding fra en ubegrænset spærret bruger
 * IP-specifikke grunde
 ** Proxy, pga. vandalisme fra enkelte, brugere spærret i længere tid',
-'ipbanononly'                 => 'Kun anonyme brugere spærres',
-'ipbcreateaccount'            => 'Forhindre oprettelse af brugerkonti',
-'ipbemailban'                 => 'Spærre brugerens adgang til at sende mail',
-'ipbenableautoblock'          => 'Spærre den IP-adresse, der bruges af denne bruger samt automatisk alle følgende, hvorfra han foretager ændringer eller forsøger at anlægge brugerkonti',
-'ipbsubmit'                   => 'Bloker denne bruger',
-'ipbother'                    => 'Anden varighed (engelsk)',
-'ipboptions'                  => '1 time:1 hour,2 timer:2 hours,6 timer:6 hours,1 dag:1 day,3 dage:3 days,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
-'ipbotheroption'              => 'Anden varighed',
-'ipbotherreason'              => 'Anden/uddybende begrundelse',
-'ipbhidename'                 => 'Skjul brugernavn/IP-adresse i spærrelog, listen med aktive spærringer og brugerfortegnelsen.',
-'ipbwatchuser'                => 'Overvåg brugerens brugerside og diskussionsside',
-'badipaddress'                => 'IP-adressen/brugernavnet er udformet forkert eller eksistere ikke.',
-'blockipsuccesssub'           => 'Blokeringen er gennemført.',
-'blockipsuccesstext'          => '"$1" er blevet blokeret.
-<br />Se [[Special:Ipblocklist|IP blokeringslisten]] for alle blokeringer.',
-'ipb-edit-dropdown'           => 'Ændre spærreårsager',
-'ipb-unblock-addr'            => 'frigive „$1“',
-'ipb-unblock'                 => 'Frigive IP-adresse/bruger',
-'ipb-blocklist-addr'          => 'Vis aktuelle spærringer for $1',
-'ipb-blocklist'               => 'Vis alle aktuelle spærringer',
-'unblockip'                   => 'Ophæv blokering af bruger',
-'unblockiptext'               => 'Brug formularen herunder for at gendanne skriveadgangen for en tidligere blokeret IP-adresse eller bruger.',
-'ipusubmit'                   => 'Ophæv blokeringen af denne adresse',
-'unblocked'                   => '[[User:$1|$1]] blev frigivet',
-'unblocked-id'                => 'Blokering $1 er blevet fjernet',
-'ipblocklist'                 => 'Blokerede IP-adresser og brugernavne',
-'ipblocklist-legend'          => 'Find en blokeret bruger',
-'ipblocklist-username'        => 'Brugernavn eller IP-addresse:',
-'ipblocklist-submit'          => 'Søg',
-'blocklistline'               => '$1, $2 blokerede $3 ($4)',
-'infiniteblock'               => 'udløber infinite',
-'expiringblock'               => 'udløber $1',
-'anononlyblock'               => 'kun anonyme',
-'noautoblockblock'            => 'Autoblok deaktiveret',
-'createaccountblock'          => 'Oprettelse af brugerkonti spærret',
-'emailblock'                  => 'e-mail blokeret',
-'ipblocklist-empty'           => 'Blokeringslisten er tom.',
-'ipblocklist-no-results'      => 'Den angivene IP-addresse eller brugernavn er ikke blokeret.',
-'blocklink'                   => 'bloker',
-'unblocklink'                 => 'ophæv blokering',
-'contribslink'                => 'bidrag',
-'autoblocker'                 => 'Automatisk blokeret fordi du deler IP-adresse med "$1". Begrundelse "$2".',
-'blocklogpage'                => 'Blokeringslog',
-'blocklogentry'               => 'blokerede "[[$1]]" med en udløbstid på $2 $3',
-'blocklogtext'                => 'Dette er en liste med blokerede brugere og ophævede blokeringer af brugere. Automatisk blokerede IP-adresser er ikke anført her. Se [[Special:Ipblocklist|blokeringslisten]] for den nuværende liste med blokerede brugere.',
-'unblocklogentry'             => 'ophævede blokering af "$1"',
-'block-log-flags-anononly'    => 'kun anonyme',
-'block-log-flags-nocreate'    => 'Oprettelse af brugerkonti blokeret',
-'block-log-flags-noautoblock' => 'Autoblok deaktiveret',
-'block-log-flags-noemail'     => 'e-mail blokeret',
-'range_block_disabled'        => 'Sysop-muligheden for at oprette blokeringsklasser er slået fra.',
-'ipb_expiry_invalid'          => 'Udløbstiden er ugyldig.',
-'ipb_expiry_temp'             => 'Blokeringer af skjulte brugernavne bør var permanente.',
-'ipb_already_blocked'         => '„$1“ er allerede blokeret',
-'ipb_cant_unblock'            => 'Fejl: Spærre-ID $1 ikke fundet. Spærringen er allerede ophævet.',
-'ipb_blocked_as_range'        => 'Fejl: IP-adressen $1 er ikke dirkete blokeret. Derfor kan en blokering ikke ophæves. Adressen er blokeret som en del af intervallet $2. Denne blokering kan ophæves.',
-'ip_range_invalid'            => 'Ugyldigt IP-interval.',
-'blockme'                     => 'Bloker mig',
-'proxyblocker'                => 'Proxy-blokering',
-'proxyblocker-disabled'       => 'Denne funktion er ikke i brug.',
-'proxyblockreason'            => "Din IP-adresse er blevet blokeret fordi den er en såkaldt ''åben proxy''. Kontakt din Internet-udbyder eller tekniske hotline og oplyse dem om dette alvorlige sikkerhedsproblem.",
-'proxyblocksuccess'           => 'Færdig.',
-'sorbsreason'                 => 'IP-adressen er opført i DNSBL på {{SITENAME}} som åben PROXY.',
-'sorbs_create_account_reason' => 'IP-adressen er opført i DNSBL på {{SITENAME}} som åben PROXY. Oprettelse af nye brugere er ikke mulig.',
+'ipbanononly'                     => 'Kun anonyme brugere spærres',
+'ipbcreateaccount'                => 'Forhindre oprettelse af brugerkonti',
+'ipbemailban'                     => 'Spærre brugerens adgang til at sende mail',
+'ipbenableautoblock'              => 'Spærre den IP-adresse, der bruges af denne bruger samt automatisk alle følgende, hvorfra han foretager ændringer eller forsøger at anlægge brugerkonti',
+'ipbsubmit'                       => 'Bloker denne bruger',
+'ipbother'                        => 'Anden varighed (engelsk)',
+'ipboptions'                      => '1 time:1 hour,2 timer:2 hours,6 timer:6 hours,1 dag:1 day,3 dage:3 days,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
+'ipbotheroption'                  => 'Anden varighed',
+'ipbotherreason'                  => 'Anden/uddybende begrundelse',
+'ipbhidename'                     => 'Skjul brugernavn/IP-adresse i spærrelog, listen med aktive spærringer og brugerfortegnelsen.',
+'ipbwatchuser'                    => 'Overvåg denne brugers brugerside og diskussionsside.',
+'badipaddress'                    => 'IP-adressen/brugernavnet er udformet forkert eller eksistere ikke.',
+'blockipsuccesssub'               => 'Blokeringen er gennemført.',
+'blockipsuccesstext'              => '"$1" er blevet blokeret.
+<br />Se [[Special:IPBlockList|IP blokeringslisten]] for alle blokeringer.',
+'ipb-edit-dropdown'               => 'Ændre spærreårsager',
+'ipb-unblock-addr'                => 'frigive „$1“',
+'ipb-unblock'                     => 'Frigive IP-adresse/bruger',
+'ipb-blocklist-addr'              => 'Vise aktuelle spærringer for „$1“',
+'ipb-blocklist'                   => 'Vise alle aktuelle spærringer',
+'unblockip'                       => 'Ophæv blokering af bruger',
+'unblockiptext'                   => 'Brug formularen herunder for at gendanne skriveadgangen for en tidligere blokeret IP-adresse eller bruger.',
+'ipusubmit'                       => 'Ophæv blokeringen af denne adresse',
+'unblocked'                       => '[[User:$1|$1]] blev frigivet',
+'unblocked-id'                    => 'Blokering $1 er blevet fjernet',
+'ipblocklist'                     => 'Blokerede IP-adresser og brugernavne',
+'ipblocklist-legend'              => 'Find en blokeret bruger',
+'ipblocklist-username'            => 'Brugernavn eller IP-addresse:',
+'ipblocklist-submit'              => 'Søg',
+'blocklistline'                   => '$1, $2 blokerede $3 ($4)',
+'infiniteblock'                   => 'udløber infinite',
+'expiringblock'                   => 'udløber $1',
+'anononlyblock'                   => 'kun anonyme',
+'noautoblockblock'                => 'Autoblok deaktiveret',
+'createaccountblock'              => 'Oprettelse af brugerkonti spærret',
+'emailblock'                      => 'e-mail blokeret',
+'ipblocklist-empty'               => 'Blokeringslisten er tom.',
+'ipblocklist-no-results'          => 'Den angivene IP-addresse eller brugernavn er ikke blokeret.',
+'blocklink'                       => 'bloker',
+'unblocklink'                     => 'ophæv blokering',
+'contribslink'                    => 'bidrag',
+'autoblocker'                     => 'Automatisk blokeret fordi du deler IP-adresse med "$1". Begrundelse "$2".',
+'blocklogpage'                    => 'Blokeringslog',
+'blocklogentry'                   => 'blokerede "[[$1]]" med en udløbstid på $2 $3',
+'blocklogtext'                    => 'Dette er en liste med blokerede brugere og ophævede blokeringer af brugere. Automatisk blokerede IP-adresser er ikke anført her. Se [[Special:IPBlockList|blokeringslisten]] for den nuværende liste med blokerede brugere.',
+'unblocklogentry'                 => 'ophævede blokering af "$1"',
+'block-log-flags-anononly'        => 'kun anonyme',
+'block-log-flags-nocreate'        => 'Oprettelse af brugerkonti blokeret',
+'block-log-flags-noautoblock'     => 'Autoblok deaktiveret',
+'block-log-flags-noemail'         => 'e-mail blokeret',
+'block-log-flags-angry-autoblock' => 'udvidet automatisk blokering slået tilenhanced autoblock enabled',
+'range_block_disabled'            => 'Sysop-muligheden for at oprette blokeringsklasser er slået fra.',
+'ipb_expiry_invalid'              => 'Udløbstiden er ugyldig.',
+'ipb_expiry_temp'                 => 'Brugernavnet kan kun skjules ved permanente blokeringer.',
+'ipb_already_blocked'             => '„$1“ er allerede blokeret',
+'ipb_cant_unblock'                => 'Fejl: Spærre-ID $1 ikke fundet. Spærringen er allerede ophævet.',
+'ipb_blocked_as_range'            => 'Fejl: IP-adressen $1 er ikke dirkete blokeret. Derfor kan en blokering ikke ophæves. Adressen er blokeret som en del af intervallet $2. Denne blokering kan ophæves.',
+'ip_range_invalid'                => 'Ugyldigt IP-interval.',
+'blockme'                         => 'Bloker mig',
+'proxyblocker'                    => 'Proxy-blokering',
+'proxyblocker-disabled'           => 'Denne funktion er ikke i brug.',
+'proxyblockreason'                => "Din IP-adresse er blevet blokeret fordi den er en såkaldt ''åben proxy''. Kontakt din Internet-udbyder eller tekniske hotline og oplyse dem om dette alvorlige sikkerhedsproblem.",
+'proxyblocksuccess'               => 'Færdig.',
+'sorbsreason'                     => 'IP-adressen er opført i DNSBL på {{SITENAME}} som åben PROXY.',
+'sorbs_create_account_reason'     => 'IP-adressen er opført i DNSBL på {{SITENAME}} som åben PROXY. Oprettelse af nye brugere er ikke mulig.',
 
 # Developer tools
 'lockdb'              => 'Lås database',
@@ -1854,45 +1859,43 @@
 *Du fjerner markeringen i boksen nedenunder.
 
 I disse tilfælde er du nødt til at flytte eller sammenflette siden manuelt.",
-'movearticle'             => 'Flyt side:',
-'movenologin'             => 'Ikke logget på',
-'movenologintext'         => 'Du skal være registreret bruger og være [[Special:Userlogin|logget på]]
-
-for at flytte en side.',
+'movearticle'             => 'Flyt side',
 'movenotallowed'          => 'Du har ikke rettigheder til at flytte sider.',
 'newtitle'                => 'Til ny titel',
-'move-watch'              => 'Overvåg denne side',
+'move-watch'              => 'Denne side overvåges',
 'movepagebtn'             => 'Flyt side',
 'pagemovedsub'            => 'Flytning gennemført',
-'movepage-moved'          => '<big>\'\'\'"$1" er blevet flyttet til "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => '<big>Siden \'\'\'"$1" er flyttet til "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'En side med det navn eksisterer allerede, eller det
 navn du har valgt er ikke gyldigt. Vælg et andet navn.',
 'cantmove-titleprotected' => 'Du kan ikke omdøbe en side til dette navn. Det nye navn er beskyttet mod oprettelse.',
 'talkexists'              => 'Siden blev flyttet korrekt, men den tilhørende diskussionsside kunne ikke flyttes, fordi der allerede eksisterer en med den nye titel. Du er nødt til at flette dem sammen manuelt.',
 'movedto'                 => 'flyttet til',
-'movetalk'                => 'Flyt også diskussionssiden, hvis den eksisterer.',
-'move-subpages'           => 'Flyt alle undersider, hvis de findes',
-'move-talk-subpages'      => 'Flyt alle undersider af diskussionssiden, hvis de findes',
+'movetalk'                => 'Flyt også "diskussionssiden", hvis den eksisterer.',
+'move-subpages'           => 'Flyt også undersider hvis de findes',
+'move-talk-subpages'      => 'Flyt diskussionssidens undersider hvis de findes',
 'movepage-page-exists'    => 'Siden $1 findes allerede og kan ikke overskrives automatisk.',
-'movepage-page-moved'     => 'Siden $1 er blevet flyttet til $2.',
-'movepage-page-unmoved'   => 'Siden $1 kunne ikke flyttes til $2.',
-'movepage-max-pages'      => 'Grænsen på $1 {{PLURAL:$1|side|sider}} er flyttet og der kan ikke flyttes flere automatisk.',
+'movepage-page-moved'     => 'Siden $1 er flyttet til $2.',
+'movepage-page-unmoved'   => 'Siden $1 kan ikke flyttes til $2.',
+'movepage-max-pages'      => 'Grænsen på $1 {{PLURAL:$1|sideflytning|sideflytninger}} er nået. De resterende sider vil ikke blive flyttet automatisk.',
 '1movedto2'               => '$1 flyttet til $2',
 '1movedto2_redir'         => '$1 flyttet til $2 over en omdirigering',
 'movelogpage'             => 'Flyttelog',
 'movelogpagetext'         => 'Nedenfor vises flyttede sider.',
-'movereason'              => 'Begrundelse:',
+'movereason'              => 'Begrundelse',
 'revertmove'              => 'gendan',
 'delete_and_move'         => 'Slet og flyt',
 'delete_and_move_text'    => '==Sletning nødvendig==
 
-Artiklen "[[$1]]" eksisterer allerede. Vil du slette den for at lave plads til flytningen?',
+Artiklen "[[:$1]]" eksisterer allerede. Vil du slette den for at lave plads til flytningen?',
 'delete_and_move_confirm' => 'Slette eksisterende side før flytning',
 'delete_and_move_reason'  => 'Slet for at lave plads til flyningen',
 'selfmove'                => 'Begge sider har samme navn. Man kan ikke flytte en side oven i sig selv.',
 'immobile_namespace'      => 'Måltitlen er en speciel type; man kan ikke flytte sider ind i det navnerum.',
-'imagenocrossnamespace'   => 'Kan ikke flytte fil til et ikke filnavnerum',
-'imagetypemismatch'       => 'Den ny filendelse passer ikke til filtypen',
+'imagenocrossnamespace'   => 'Filer kan ikke flyttes til et navnerum der ikke indeholder filer',
+'imagetypemismatch'       => 'Den nye filendelse passer ikke til filtypen',
+'imageinvalidfilename'    => 'Destinationsnavnet er ugyldigt',
+'fix-double-redirects'    => 'Opdater henvisninger til det oprindelige navn',
 
 # Export
 'export'            => 'Eksportér sider',
@@ -1903,7 +1906,7 @@
 'export-addcattext' => 'Tilføje sider fra kategori:',
 'export-addcat'     => 'Tilføje',
 'export-download'   => 'Tilbyd at gemme som en fil',
-'export-templates'  => 'Inkludér skabeloner',
+'export-templates'  => 'Medtag skabeloner',
 
 # Namespace 8 related
 'allmessages'               => 'Alle beskeder',
@@ -1949,11 +1952,11 @@
 'importuploaderrorsize'      => 'Upload af importfil mislykkedes da filen er større en den tilladte maksimale uploadstørrelse.',
 'importuploaderrorpartial'   => 'Upload af importfil mislykkedes da filen kun blev delvist uploadet.',
 'importuploaderrortemp'      => 'Upload af importfil mislykkedes da en midlertidig mappe mangler.',
-'import-parse-failure'       => 'XML import parserfejl',
-'import-noarticle'           => 'Ingen side til import!',
-'import-nonewrevisions'      => 'Alle revisioner er tidligere blevet importeret.',
-'xml-error-string'           => '$1 på linje $2, kolonne $3 (byte $4): $5',
-'import-upload'              => 'Læg XML data op',
+'import-parse-failure'       => 'XML fortolkningsfejl under importering',
+'import-noarticle'           => 'Der er ingen sider at importere!',
+'import-nonewrevisions'      => 'Alle versioner er allerede importeret.',
+'xml-error-string'           => '$1 på linie $2, kolonne $3 (byte $4): $5',
+'import-upload'              => 'Upload XML-data',
 
 # Import log
 'importlogpage'                    => 'Importlog',
@@ -2009,7 +2012,7 @@
 'tooltip-ca-nstab-user'           => 'Se brugersiden',
 'tooltip-ca-nstab-media'          => 'Se mediasiden',
 'tooltip-ca-nstab-special'        => 'Dette er en speciel side; man kan ikke redigere sådanne sider.',
-'tooltip-ca-nstab-project'        => 'Vis portalsiden',
+'tooltip-ca-nstab-project'        => 'Vise portalsiden',
 'tooltip-ca-nstab-image'          => 'Se billedsiden',
 'tooltip-ca-nstab-mediawiki'      => 'Se systembeskeden',
 'tooltip-ca-nstab-template'       => 'Se skabelonen',
@@ -2083,10 +2086,11 @@
 'markedaspatrollederror-noautopatrol' => 'Du må ikke markere dine egne ændringer som kontrolleret.',
 
 # Patrol log
-'patrol-log-page' => 'Kontrollog',
-'patrol-log-line' => 'har markeret $1 af $2 som kontrolleret $3.',
-'patrol-log-auto' => '(automatisk)',
-'patrol-log-diff' => 'Version $1',
+'patrol-log-page'   => 'Kontrollog',
+'patrol-log-header' => 'Patruljerede versioner.',
+'patrol-log-line'   => 'har markeret $1 af $2 som kontrolleret $3.',
+'patrol-log-auto'   => '(automatisk)',
+'patrol-log-diff'   => 'Version $1',
 
 # Image deletion
 'deletedrevision'                 => 'Slettede gammel version $1',
@@ -2096,11 +2100,11 @@
 $1',
 'filedelete-missing'              => 'Filen "$1" kan ikke slettes fordi den ikke findes.',
 'filedelete-old-unregistered'     => 'Den angivne version "$1" findes ikke i databasen.',
-'filedelete-current-unregistered' => 'Den angivne fil "$1" findes ikke i databasen.',
+'filedelete-current-unregistered' => 'Den angiovne fil "$1" findes ikke i databasen.',
 'filedelete-archive-read-only'    => 'Webserveren har ikke skriveadgang til arkiv-kataloget "$1".',
 
 # Browsing diffs
-'previousdiff' => '← Gå til forrige forskel',
+'previousdiff' => '← Gå til foregående forskel',
 'nextdiff'     => 'Gå til næste forskel →',
 
 # Media information
@@ -2108,14 +2112,14 @@
 'imagemaxsize'         => 'Begræns størrelsen af billeder på billedsiderne til:',
 'thumbsize'            => 'Thumbnail størrelse :',
 'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|side|sider}}',
-'file-info'            => '(Filstørrelse: $1, MIME-Typ: $2)',
-'file-info-size'       => '($1 × $2 pixel, filstørrelse: $3, MIME-Typ: $4)',
+'file-info'            => '(Filstørrelse: $1, MIME-Type: $2)',
+'file-info-size'       => '($1 × $2 punkter, filstørrelse: $3, MIME-Type: $4)',
 'file-nohires'         => '<small>Ingen højere opløsning fundet.</small>',
-'svg-long-desc'        => '(SVG file, basisstørrelse $1 × $2 pixels, file size: $3)',
+'svg-long-desc'        => '(SVG fil, basisstørrelse $1 × $2 punkters, størrelse: $3)',
 'show-big-image'       => 'Version i større opløsning',
 'show-big-image-thumb' => '<small>Størrelse af forhåndsvisning: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galleri med de nyeste billeder',
 'imagelisttext'         => 'Herunder er en liste med $1 {{PLURAL:$1|billede|billeder}} sorteret $2.',
 'newimages-summary'     => 'Denne specialside viser de nyeste uploadede billeder og filer.',
@@ -2123,7 +2127,7 @@
 'noimages'              => 'Ingen filer fundet.',
 'ilsubmit'              => 'Søg',
 'bydate'                => 'efter dato',
-'sp-newimages-showfrom' => 'Vis nye filer fra $2, $1',
+'sp-newimages-showfrom' => 'Vis nye filer startende med $2, $1',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
 'hours-abbrev' => 't',
@@ -2399,7 +2403,7 @@
 
 # External editor support
 'edit-externally'      => 'Rediger denne fil med en ekstern editor',
-'edit-externally-help' => 'Se [http://meta.wikimedia.org/wiki/Help:External_editors setup instruktionerne] for mere information.',
+'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors setup instruktionerne] for mere information.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alle',
@@ -2425,22 +2429,21 @@
 'confirmemail_loggedin'    => 'E-mail-adressen er nu bekræftet.',
 'confirmemail_error'       => 'Der skete en fejl ved bekræftelsen af E-mail-adressen.',
 'confirmemail_subject'     => '[{{SITENAME}}] - bekræftelse af E-mail-adressen',
-'confirmemail_body'        => 'Nogen med IP-adresse $1, sandsynligvis dig, har oprettet en en brugerkonto "$2" med denne mailadresse på {{SITENAME}}.
+'confirmemail_body'        => 'Hej,
 
-For at aktivere E-mail-funktionen på {{SITENAME}} og for at bekræfte, at denne brugerkonto virkelig hører til din E-mail-adresse og dermed til dig, bedes du åbne det følgende link i din browser:
+Nogen med IP-adresse $1, sandsynligvis dig, har bestilt en bekræftelse af denne E-mail-adresse til brugerkontoen "$2" på {{SITENAME}}.
 
-$3
+For at aktivere E-mail-funktionen for {{SITENAME}} (igen) og for at bekræfte, at denne brugerkonto virkelig hører til din E-mail-adresse og dermed til dig, bedes du åbne det følgende link i din browser: $3
 
-Bekræftelseskoden er gyldig indtil følgende tidspunkt: 
+Bekræftelseskoden er gyldig indtil følgende tidspunkt: $4
 
-$4
+Hvis denne E-mail-adresse *ikke* hører til den anførte brugerkonto, skal du i stedet åbne dette link i din browser: $5
 
-Hvis denne E-mail-adresse *ikke* hører til den anførte brugerkonto, skal du trykke på nedenstående dette link for at afbryde godkendelsen af mailadressen:
+-- 
+{{SITENAME}}: {{fullurl:{{Mediawiki:mainpage}}}}',
+'confirmemail_invalidated' => 'E-mail-bekræftelse afvist',
+'invalidateemail'          => 'Cancel e-mail confirmation',
 
-$5',
-'confirmemail_invalidated' => 'Bekræftelse af e-mail-adresse er afbrudt',
-'invalidateemail'          => 'Afbryd bekræftelse af e-mail-adresse',
-
 # Scary transclusion
 'scarytranscludedisabled' => '[Interwiki-tilkobling er deaktiveret]',
 'scarytranscludefailed'   => '[Skabelonindbinding for $1 mislykkedes]',
@@ -2456,16 +2459,16 @@
 'trackbackdeleteok' => 'Trackback blev slettet.',
 
 # Delete conflict
-'deletedwhileediting' => '<span class="error">Bemærk: Det blev forsøgt at slette denne side, efter at du var begyndt, at ændre den!
-Kig i [{{fullurl:Special:Log|type=delete&page=}}{{FULLPAGENAMEE}} slette-loggen],
+'deletedwhileediting' => '<span class="error">Bemærk: Det blev forsøgt at slette denne side, efter at du var begyndt, at ændre den! 
+Kig i [{{fullurl:Special:Log|type=delete&page=}}{{FULLPAGENAMEE}} slette-loggen], 
 hvorfor siden blev slettet. Hvis du gemmer siden bliver den oprettet igen.</span>',
-'confirmrecreate'     => "Bruger [[User:$1|$1]] ([[User talk:$1|Diskussion]]) har slettet denne side, efter at du begyndte at ændre den. Begrundelsen lyder:
-: ''$2''
+'confirmrecreate'     => "Bruger [[User:$1|$1]] ([[User_talk:$1|Diskussion]]) har slettet denne side, efter at du begyndte at ændre den. Begrundelsen lyder:
+''$2''
 Bekræft venligst, at du virkelig vil oprette denne side igen.",
 'recreate'            => 'Opret igen',
 
 # HTML dump
-'redirectingto' => 'Videresendt til [[$1]]',
+'redirectingto' => 'Videresendt til [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Slette denne side fra serverens cache? $1',
@@ -2508,17 +2511,15 @@
 'livepreview-error'   => 'Forbindelse ikke mulig: $1 "$2". Brug venligst den almindelige forhåndsvisning.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Ændringer, som er nyere end $1 sekunder, vises muligvis ikke i denne liste.',
-'lag-warn-high'   => 'Grundet stor belastning af databaseserveren, vil ændringer, der er nyere end $1 sekunder måske ikke blive vist i denne liste.',
+'lag-warn-normal' => 'Ændringer som er nyere end {{PLURAL:$1|et sekund|$1 sekunder}}, vises muligvis ikke i denne liste.',
+'lag-warn-high'   => 'Grundet stor belastning af databaseserveren, vil ændringer der er nyere end {{PLURAL:$1|et sekund|$1 sekunder}} måske ikke blive vist i denne liste.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Din overvågningsliste indeholder {{PLURAL:$1|1 side|$1 sider}}, diskussionssider fraregnet.',
 'watchlistedit-noitems'        => 'Din overvågningsliste er tom.',
 'watchlistedit-normal-title'   => 'Rediger overvågningsliste',
 'watchlistedit-normal-legend'  => 'Slet sider fra overvågningslisten',
-'watchlistedit-normal-explain' => 'Din overvågningsliste er vist nedenfor.
-Du kan fjerne sider fra den ved at markere den og trykke på Fjern valgte.
-Du har også mulighed for at [[Special:Watchlist/raw|redigere listen direkte]].',
+'watchlistedit-normal-explain' => 'Din overvågningsliste er vist nedenfor. Du kan fjerne sider fra den ved at markere den og trykke på Fjern valgte. Du har også mulighed for at [[Special:Watchlist/raw|redigere listen direkte]], eller [[Special:Watchlist/clear|rydde listen]].',
 'watchlistedit-normal-submit'  => 'Fjern valgte',
 'watchlistedit-normal-done'    => '{{PLURAL:$1|1 side|$1 sider}} er fjernet fra din overvågningsliste:',
 'watchlistedit-raw-title'      => 'Direkte redigering af overvågningsliste',
@@ -2533,25 +2534,25 @@
 # Watchlist editing tools
 'watchlisttools-view' => 'Se ændrede sider i overvågningslisten',
 'watchlisttools-edit' => 'Rediger overvågningsliste',
-'watchlisttools-raw'  => 'Direkte redigering af overvågningsliste',
+'watchlisttools-raw'  => 'Rediger rå overvågningsliste',
 
 # Core parser functions
-'unknown_extension_tag' => 'Ukendt extension-tag: $1',
+'unknown_extension_tag' => 'Unknown extension tag "$1"',
 
 # Special:Version
-'version'                          => 'Information om MediaWiki', # Not used as normal message but as header for the special page itself
+'version'                          => 'Version', # Not used as normal message but as header for the special page itself
 'version-extensions'               => 'Installerede udvidelser',
 'version-specialpages'             => 'Specielle sider',
-'version-parserhooks'              => 'Parser hooks',
+'version-parserhooks'              => 'Oversætter-funktioner',
 'version-variables'                => 'Variabler',
-'version-other'                    => 'Andre',
-'version-mediahandlers'            => 'Mediehåndtere',
-'version-hooks'                    => 'Hooks',
+'version-other'                    => 'Andet',
+'version-mediahandlers'            => 'Specialhåndtering af mediefiler',
+'version-hooks'                    => 'Funktionstilføjelser',
 'version-extension-functions'      => 'Udvidelsesfunktioner',
-'version-parser-extensiontags'     => 'Udvidelsestags til parseren',
-'version-parser-function-hooks'    => 'Parser funktionshooks',
-'version-skin-extension-functions' => 'Funktioner til skin-udvidelser',
-'version-hook-name'                => 'Hook-navn',
+'version-parser-extensiontags'     => 'Tilføjede tags',
+'version-parser-function-hooks'    => 'Oversætter-funktioner',
+'version-skin-extension-functions' => 'Ekstra funktioner til udseende',
+'version-hook-name'                => 'Navn',
 'version-hook-subscribedby'        => 'Brugt af',
 'version-version'                  => 'Version',
 'version-license'                  => 'Licens',
@@ -2559,43 +2560,46 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Filsti',
 'filepath-page'    => 'Fil:',
-'filepath-submit'  => 'Sti',
-'filepath-summary' => 'Denne specielle side returnerer en komplet sti for en fil.
-Billeder bliver vist i fuld opløsning, andre filtyper bliver startet direkte af deres tilknyttede program.
+'filepath-submit'  => 'Vis sti',
+'filepath-summary' => 'Denne specialside giver et direkte link til en fil. Billder vises i fuld opløsning og andre mediatyper vil blive aktiveret med deres tilhærende program.
 
-Indtast filnavnet uden "{{ns:image}}:" præfiks.',
+Angiv filnavnet uden "{{ns:image}}:"-præfix.',
 
 # Special:FileDuplicateSearch
-'fileduplicatesearch'          => 'Søg efter dubletfiler',
-'fileduplicatesearch-summary'  => 'Søg efter dubletfiler baseret på filens hash-værdi.
+'fileduplicatesearch'          => 'Find dubletfiler',
+'fileduplicatesearch-summary'  => 'Find dublerede filer baseret på deres hash-værdi.
 
-Skriv filnavnet uden "{{ns:image}}:" præfikset.',
-'fileduplicatesearch-legend'   => 'Søg efter dublet',
+Angiv filnavnet uden "{{ns:image}}:"-præfix.',
+'fileduplicatesearch-legend'   => 'Find dubletfiler.',
 'fileduplicatesearch-filename' => 'Filnavn:',
-'fileduplicatesearch-submit'   => 'Søg',
-'fileduplicatesearch-info'     => '$1 × $2 pixel<br />Filstørrelse: $3<br />MIME-Typ: $4',
+'fileduplicatesearch-submit'   => 'Find',
+'fileduplicatesearch-info'     => '$1 × $2 punkter<br />Filstørrelse: $3<br />MIME-type: $4',
 'fileduplicatesearch-result-1' => 'Filen "$1" har ingen identiske dubletter.',
-'fileduplicatesearch-result-n' => 'Filen "$1" har {{PLURAL:$2|1 identisk dublet|$2 identiske dubletter}}.',
+'fileduplicatesearch-result-n' => 'Filen "$1" har {{PLURAL:$2|en dublet|$2 dubletter}}.',
 
 # Special:SpecialPages
-'specialpages'                   => 'Specielle sider',
+'specialpages'                   => 'Specialsider',
 'specialpages-note'              => '----
 * Normale specialsider.
 * <span class="mw-specialpagerestricted">Specialsider med begrænset adgang.</span>',
-'specialpages-group-maintenance' => 'Vedligeholdelsesrapporter',
-'specialpages-group-other'       => 'Øvrige specielle sider',
-'specialpages-group-login'       => 'Opret en konto / log på',
-'specialpages-group-changes'     => 'Seneste ændringer og logs',
-'specialpages-group-media'       => 'Medierapporter og uplaods',
+'specialpages-group-maintenance' => 'Vedligeholdesessider',
+'specialpages-group-other'       => 'Andre specialsider',
+'specialpages-group-login'       => 'Opret bruger / logon',
+'specialpages-group-changes'     => 'Seneste ændringer og loglister',
+'specialpages-group-media'       => 'Mediafiler og oplægning',
 'specialpages-group-users'       => 'Brugere og rettigheder',
-'specialpages-group-highuse'     => 'Meget brugte sider',
+'specialpages-group-highuse'     => 'Højt profilerede sider',
 'specialpages-group-pages'       => 'Sidelister',
-'specialpages-group-pagetools'   => 'Sideværktøjer',
-'specialpages-group-wiki'        => 'Data og værktøj for wikien',
-'specialpages-group-redirects'   => 'Omdirigerende specialsider',
+'specialpages-group-pagetools'   => 'Sideærktøjer',
+'specialpages-group-wiki'        => 'Wikidata og værktøjer',
+'specialpages-group-redirects'   => 'Specialsider der viderestiller',
 'specialpages-group-spam'        => 'Spamværktøjer',
 
+# Special:BlankPage
+'blankpage'              => 'Blank side',
+'intentionallyblankpage' => 'Denne side er bevidst uden indhold.',
+
 );
Index: languages/messages/MessagesSv.php
===================================================================
--- languages/messages/MessagesSv.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSv.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,25 +4,22 @@
  * @ingroup Language
  * @file
  *
- * @author Lejonel
- * @author Sannab
  * @author Boivie
- * @author M.M.S.
+ * @author Grillo
  * @author Habj
+ * @author Habjchen
  * @author Jon Harald Søby
- * @author Siebrand
- * @author לערי ריינהארט
+ * @author Lejonel
+ * @author Leo Johannes
  * @author Lokal Profil
- * @author Leo Johannes
- * @author Steinninn
- * @author SPQRobin
- * @author Skalman
- * @author Habjchen
- * @author Gangleri
+ * @author M.M.S.
  * @author Max sonnelid
- * @author Grillo
  * @author Micke
  * @author S.Örvarr.S
+ * @author Sannab
+ * @author Skalman
+ * @author Steinninn
+ * @author לערי ריינהארט
  */
 
 $skinNames = array(
@@ -546,7 +543,7 @@
 'nosuchspecialpage' => 'Någon sådan specialsida finns inte',
 'nospecialpagetext' => "<big>'''Du har begärt en specialsida som inte finns.'''</big>
 
-I [[Special:Specialpages|listan över specialsidor]] kan du se vilka specialsidor som finns.",
+I [[Special:SpecialPages|listan över specialsidor]] kan du se vilka specialsidor som finns.",
 
 # General errors
 'error'                => 'Fel',
@@ -569,7 +566,7 @@
 Detta fel beror oftast på en länk till en jämförelse mellan versioner (diff) eller till en gammal version av en sida som raderats.
 
 Om inte så är fallet, kan du ha hittat en bugg i mjukvaran.
-Rapportera gärna problemet till någon administratör, ange då URL:en (webbadressen).',
+Rapportera gärna problemet till någon [[Special:ListUsers/sysop|administratör]], ange då URL:en (webbadressen).',
 'missingarticle-rev'   => '(version $1)',
 'missingarticle-diff'  => '(jämförelse mellan version $1 och $2)',
 'readonly_lag'         => 'Databasen har automatiskt skrivskyddats medan slavdatabasservrarna synkroniseras med huvudservern.',
@@ -621,11 +618,11 @@
 'logouttitle'                => 'Användarutloggning',
 'logouttext'                 => '<strong>Du är nu utloggad.</strong>
 
-Du kan fortsätta att använda {{SITENAME}} anonymt, eller så kan du logga in igen som samma eller som en annan användare.
+Du kan fortsätta att använda {{SITENAME}} anonymt, eller så kan du [[Special:UserLogin|logga in igen]] som samma eller som en annan användare.
 Observera att det, tills du tömmer din webbläsares cache, på vissa sidor kan se ut som att du fortfarande är inloggad.',
 'welcomecreation'            => '== Välkommen, $1! ==
-
-Ditt konto har skapats. Glöm inte att justera dina inställningar.',
+Ditt konto har skapats.
+Glöm inte att justera dina [[Special:Preferences|{{SITENAME}}-inställningar]].',
 'loginpagetitle'             => 'Användarinloggning',
 'yourname'                   => 'Användarnamn:',
 'yourpassword'               => 'Lösenord:',
@@ -677,7 +674,7 @@
 'wrongpassword'              => 'Lösenordet du angav är felaktigt. Försök igen',
 'wrongpasswordempty'         => 'Lösenordet som angavs var blankt. Var god försök igen.',
 'passwordtooshort'           => 'Ditt lösenord är för kort.
-Det måste innehålla minst $1 tecken och det får inte vara ditt användarnamn.',
+Det måste innehålla minst {{PLURAL:$1|1 tecken|$1 tecken}} och det får inte vara ditt användarnamn.',
 'mailmypassword'             => 'Sänd mig ett nytt lösenord',
 'passwordremindertitle'      => 'Nytt temporärt lösenord från {{SITENAME}}',
 'passwordremindertext'       => 'Någon (förmodligen du, från IP-adressen $1)
@@ -769,9 +766,11 @@
 * Blockeringen gäller till $6.
 * Blockeringen var avsedd för $7.
 
-Du kan kontakta $1 eller någon annan av [[{{MediaWiki:Grouppage-sysop}}|administratörerna]] för att diskutera blockeringen. Om du är inloggad och har uppgivit en e-postadress i dina inställningar så kan du använda funktionen 'skicka e-post till den här användaren', såvida du inte blivit blockerad från funktionen.
+Du kan kontakta $1 eller någon annan av [[{{MediaWiki:Grouppage-sysop}}|administratörerna]] för att diskutera blockeringen.
+Om du är inloggad och har uppgivit en e-postadress i dina [[Special:Preferences|inställningar]] så kan du använda funktionen 'skicka e-post till den här användaren', såvida du inte blivit blockerad från funktionen.
 
-Din IP-adress är $3 och blockerings-ID är #$5. Vänligen ange IP-adress eller blockerings-ID i alla förfrågningar som du gör i ärendet.",
+Din IP-adress är $3 och blockerings-ID är #$5.
+Vänligen ange informationen ovan i alla förfrågningar som du gör i ärendet.",
 'autoblockedtext'                  => 'Din IP-adress har blockerats automatiskt eftersom den har använts av en annan användare som blockerats av $1.
 Motiveringen av blockeringen var:
 
@@ -779,21 +778,19 @@
 
 * Blockeringen startade $8
 * Blockeringen gäller till $6
+* Blockeringen är avsedd för $7
 
 Du kan kontakta $1 eller någon annan [[{{MediaWiki:Grouppage-sysop}}|administratör]] för att diskutera blockeringen.
 
 Observera att du inte kan använda dig av funktionen "skicka e-post till användare" om du inte har registrerat en giltig e-postadress i [[Special:Preferences|dina inställningar]] eller om du har blivit blockerad från att skicka e-post.
 
-Blockeringens ID är $5. Vänligen ange blockerings-ID i alla förfrågningar som du gör i ärendet.',
+Din nuvarande IP-adress är $3, och blockerings-ID är #$5.
+Vänligen ange informationen ovan i alla förfrågningar som du gör i ärendet.',
 'blockednoreason'                  => 'ingen motivering angavs',
 'blockedoriginalsource'            => "Källkoden för '''$1''' visas nedan:",
 'blockededitsource'                => "Texten för '''dina ändringar''' av '''$1''' visas nedanför:",
-'whitelistedittitle'               => 'Redigering kräver inloggning',
+'whitelistedittitle'               => 'Du måste logga in för att redigera',
 'whitelistedittext'                => 'Du måste $1 för att kunna redigera sidor.',
-'whitelistreadtitle'               => 'Läsning kräver inloggning',
-'whitelistreadtext'                => 'För att kunna läsa sidor, måste du [[Special:Userlogin|logga in]].',
-'whitelistacctitle'                => 'Du kan inte skapa konton',
-'whitelistacctext'                 => 'För att kunna skapa konton på {{SITENAME}} måste du vara [[Special:Userlogin|inloggad]] och ha rätt behörighet.',
 'confirmedittitle'                 => 'E-postbekräftelse krävs för redigering',
 'confirmedittext'                  => 'Du måste bekräfta din e-postadress innan du kan redigera sidor. Var vänlig ställ in och validera din e-postadress genom dina [[Special:Preferences|användarinställningar]].',
 'nosuchsectiontitle'               => 'Avsnittet finns inte',
@@ -805,7 +802,10 @@
 'accmailtext'                      => "Lösenordet för '$1' har skickats till $2.",
 'newarticle'                       => '(Ny)',
 'newarticletext'                   => 'Du har klickat på en länk till en sida som inte finns ännu. Du kan själv skapa sidan genom att skriva i fältet nedan (du kan läsa mer på [[{{MediaWiki:Helppage}}|hjälpsidan]]). Om du inte vill skriva något kan du bara trycka på "tillbaka" i din webbläsare.',
-'anontalkpagetext'                 => "---- ''Detta är en diskussionssida för en användare som inte har loggat in. {{SITENAME}} måste därför använda personens numeriska IP-adress för att identifiera honom eller henne. En sådan IP-adress kan ibland användas av flera olika personer. Om du får meddelanden här som inte tycks vara riktade till dig, kan du gärna [[Special:Userlogin|logga in]]. Då undviker du framtida förväxlingar.''",
+'anontalkpagetext'                 => "---- ''Detta är en diskussionssida för en användare som inte har loggat in.
+Därför måste personens numeriska IP-adress användas för att identifiera honom eller henne.
+En sådan IP-adress kan ibland användas av flera olika personer.
+Om du får meddelanden här som inte tycks vara riktade till dig, kan du gärna [[Special:UserLogin/signup|skapa ett konto]] eller [[Special:UserLogin|logga in]]. Då undviker du framtida förväxlingar.''",
 'noarticletext'                    => 'Det finns just nu ingen text på denna sida. Du kan [[Special:Search/{{PAGENAME}}|söka efter denna sidtitel]] i andra sidor eller [{{fullurl:{{FULLPAGENAME}}|action=edit}} redigera denna sida].',
 'userpage-userdoesnotexist'        => '"$1" är inte ett registrerat användarkonto. Tänk efter om du vill skapa/redigera den här sidan.',
 'clearyourcache'                   => "'''Observera: Sedan du sparat sidan kan du behöva tömma din webbläsares cache för att se ändringarna.''' '''Mozilla/Firefox/Safari:''' håll ner ''Skift'' och klicka på ''Reload'' eller tryck antingen ''Ctrl-F5'' eller ''Ctrl-R'' (''Command-R'' på Macintosh); '''Konqueror:''': klicka ''Reload'' eller tryck ''F5;'' '''Opera:''' rensa cachen i ''Tools → Preferences;'' '''Internet Explorer:'''  håll ner ''Ctrl'' och klicka på ''Refresh'' eller tryck ''Ctrl-F5.''",
@@ -820,12 +820,14 @@
 'previewconflict'                  => 'Den här förhandsvisningen är resultatet av den
 redigerbara texten ovanför,
 så som det kommer att se ut om du väljer att spara.',
-'session_fail_preview'             => '<strong>Databasen kunde inte bearbeta redigeringen på grund av ett bortfall av sessionsdata. Försök igen; om det fortfarande inte fungerar, prova att öppna om redigeringssidan, logga ut och logga in igen eller vänta ett tag på att felet fixas.</strong>',
-'session_fail_preview_html'        => "<strong>Beklagar! Vi kunde inte databehandla din redigering på grund av att sessionens data gått förlorad.</strong>
+'session_fail_preview'             => '<strong>Tyvärr kunde inte din redigering behandlas, eftersom sessionsdata gått förlorad.
+Försök igen; om det fortfarande inte fungerar, pröva att [[Special:UserLogout|logga ut]] och logga in igen.</strong>',
+'session_fail_preview_html'        => "<strong>Tyvärr kunde inte din redigering behandlas, eftersom sessionsdata gått förlorad.</strong>
 
 ''Eftersom {{SITENAME}} har aktiverat rå HTML, så döljs förhandsvisningen som en förebyggande säkerhetsåtgärd med syfte att förhindra JavaScript-attacker.''
 
-<strong>Om det är ett försök att göra en rättmätig redigering, så pröva igen. Om det fortfarande inte fungerar, pröva att logga ut och logga in igen.</strong>",
+<strong>Om det är ett försök att göra en rättmätig redigering, så försök igen.
+Om det fortfarande inte fungerar, pröva att [[Special:UserLogout|logga ut]] och logga in igen.</strong>",
 'token_suffix_mismatch'            => '<strong>Din redigering har stoppats eftersom din klient har ändrat tecknen
 i redigeringens "edit token". Redigeringen stoppades för att förhindra att sidtexten skadas.
 Detta händer ibland om du använder buggiga webbaserade anonyma proxytjänster.</strong>',
@@ -868,7 +870,7 @@
 'edittools'                        => '<!-- Denna text kommer att visas nedanför redigeringsrutor och uppladdningsformulär. -->',
 'nocreatetitle'                    => 'Skapande av sidor begränsat',
 'nocreatetext'                     => '{{SITENAME}} har begränsat möjligheterna att skapa nya sidor.
-Du kan redigera existerande sidor, eller [[Special:Userlogin|logga in eller skapa ett användarkonto]].',
+Du kan redigera existerande sidor, eller [[Special:UserLogin|logga in eller skapa ett användarkonto]].',
 'nocreate-loggedin'                => 'Du har inte behörighet att skapa nya sidor på {{SITENAME}}.',
 'permissionserrors'                => 'Behörighetsfel',
 'permissionserrorstext'            => 'Du har inte behörighet att göra det du försöker göra, av följande {{PLURAL:$1|anledning|anledningar}}:',
@@ -894,7 +896,7 @@
 'undo-success' => 'Sidan kan återställas till tidigare version. Var god och kontrollera jämförelsen nedan för att bekräfta att detta är vad du avser att göra och slutför återställningen genom att spara.',
 'undo-failure' => 'Ändringen kunde inte avlägsnas på grund av motstridande ändringar som gjorts sedan dess.',
 'undo-norev'   => 'Ändringen kan inte avlägsnas eftersom den inte finns eller har raderats.',
-'undo-summary' => 'Ta bort version $1 av [[Special:Contributions/$2|$2]] ([[User talk:$2|diskussion]])',
+'undo-summary' => 'Tar bort version $1 av [[Special:Contributions/$2|$2]] ([[User talk:$2|diskussion]])',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Kan inte skapa konto',
@@ -923,7 +925,7 @@
 'deletedrev'          => '[raderad]',
 'histfirst'           => 'Första',
 'histlast'            => 'Senaste',
-'historysize'         => '($1 byte)',
+'historysize'         => '({{PLURAL:$1|1 byte|$1 byte}})',
 'historyempty'        => '(tom)',
 
 # Revision feed
@@ -985,7 +987,7 @@
 # Suppression log
 'suppressionlog'     => 'Versionsraderingslogg',
 'suppressionlogtext' => 'Nedan visas en lista över raderingar och blockeringar som berör innehåll dolt för administratörer.
-Se [[Special:Ipblocklist|blockeringslistan]] för listan över gällande blockeringar.',
+Se [[Special:IPBlockList|blockeringslistan]] för listan över gällande blockeringar.',
 
 # History merging
 'mergehistory'                     => 'Sammanfoga sidhistoriker',
@@ -1025,7 +1027,7 @@
 # Search results
 'searchresults'             => 'Sökresultat',
 'searchresulttext'          => 'Se [[{{MediaWiki:Helppage}}|hjälpsidan]] för mer information om sökning på {{SITENAME}}.',
-'searchsubtitle'            => 'Du sökte efter [[:$1]]',
+'searchsubtitle'            => 'Du sökte efter \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|alla sidor som startar med "$1"]] | [[Special:WhatLinksHere/$1|alla sidor som länkar till "$1"]])',
 'searchsubtitleinvalid'     => 'För sökbegreppet $1',
 'noexactmatch'              => "'''Det finns ingen sida med titeln \"\$1\".''' Du kan  [[:\$1|skapa denna sida]].",
 'noexactmatch-nocreate'     => "'''Det finns ingen sida med titeln \"\$1\".'''",
@@ -1070,7 +1072,7 @@
 'mypreferences'            => 'Mina inställningar',
 'prefs-edits'              => 'Antal redigeringar:',
 'prefsnologin'             => 'Inte inloggad',
-'prefsnologintext'         => 'Du måste vara [[Special:Userlogin|inloggad]] för att kunna ändra i inställningar.',
+'prefsnologintext'         => 'Du måste vara [[Special:UserLogin|inloggad]] för att kunna ändra dina inställningar.',
 'prefsreset'               => 'Inställningarna har återställts till ursprungsvärdena.',
 'qbsettings'               => 'Inställningar för snabbmeny',
 'qbsettings-none'          => 'Ingen',
@@ -1144,7 +1146,7 @@
 'userrights-reason'           => 'Anledning till ändringen:',
 'userrights-no-interwiki'     => 'Du har inte behörighet att ändra användarrättigheter på andra wikis.',
 'userrights-nodatabase'       => 'Databasen $1 finns inte eller så är den inte lokal.',
-'userrights-nologin'          => 'Du måste [[Special:Userlogin|logga in]] med ett administratörskonto för att ändra användarrättigheter.',
+'userrights-nologin'          => 'Du måste [[Special:UserLogin|logga in]] med ett administratörskonto för att ändra användarrättigheter.',
 'userrights-notallowed'       => 'Ditt konto har inte behörighet till att ändra användarrättigheter.',
 'userrights-changeable-col'   => 'Grupper du kan ändra',
 'userrights-unchangeable-col' => 'Grupper du inte kan ändra',
@@ -1156,15 +1158,15 @@
 'group-bot'           => 'Robotar',
 'group-sysop'         => 'Administratörer',
 'group-bureaucrat'    => 'Byråkrater',
-'group-suppress'      => 'Oversightare',
+'group-suppress'      => 'Versionsraderare',
 'group-all'           => '(alla)',
 
-'group-user-member'          => 'Användare',
-'group-autoconfirmed-member' => 'Bekräftad användare',
-'group-bot-member'           => 'Robot',
-'group-sysop-member'         => 'Administratör',
-'group-bureaucrat-member'    => 'Byråkrat',
-'group-suppress-member'      => 'Oversight',
+'group-user-member'          => 'användare',
+'group-autoconfirmed-member' => 'bekräftad användare',
+'group-bot-member'           => 'robot',
+'group-sysop-member'         => 'administratör',
+'group-bureaucrat-member'    => 'byråkrat',
+'group-suppress-member'      => 'versionsraderare',
 
 'grouppage-user'          => '{{ns:project}}:Användare',
 'grouppage-autoconfirmed' => '{{ns:project}}:Bekräftade användare',
@@ -1234,7 +1236,7 @@
 
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|ändring|ändringar}}',
-'recentchanges'                     => 'Senaste ändringar',
+'recentchanges'                     => 'Senaste ändringarna',
 'recentchangestext'                 => 'Följ de senaste ändringarna i wikin på denna sida.',
 'recentchanges-feed-description'    => 'Följ de senaste ändringarna i wikin genom den här matningen.',
 'rcnote'                            => "Nedan visas {{PLURAL:$1|'''1''' ändring|de senaste '''$1''' ändringarna}} från {{PLURAL:$2|den senaste dagen|de senaste '''$2''' dagarna}}, per $4, kl. $5.",
@@ -1275,23 +1277,24 @@
 'reupload'                    => 'Ladda upp på nytt',
 'reuploaddesc'                => 'Avbryt uppladdningen och gå tillbaka till uppladdningsformuläret.',
 'uploadnologin'               => 'Inte inloggad',
-'uploadnologintext'           => 'Du måste vara [[Special:Userlogin|inloggad]] för att kunna ladda upp filer.',
+'uploadnologintext'           => 'Du måste vara [[Special:UserLogin|inloggad]] för att kunna ladda upp filer.',
 'upload_directory_missing'    => 'Uppladdningskatalogen ($1) saknas och kunde inte skapas av webbservern.',
 'upload_directory_read_only'  => 'Webbservern kan inte skriva till uppladdningskatalogen ($1).',
 'uploaderror'                 => 'Fel vid uppladdningen',
 'uploadtext'                  => "Använd formuläret nedan för att ladda upp filer.
-För att titta på eller leta efter filer som redan har laddats upp, se [[Special:Imagelist|listan över uppladdade filer]]. Uppladdningar och borttagningar loggförs också i [[Special:Log/upload|uppladdningsloggen]].
+För att titta på eller leta efter filer som redan har laddats upp, se [[Special:ImageList|listan över uppladdade filer]]. Uppladdningar loggförs även i [[Special:Log/upload|uppladdningsloggen]], och raderingar i [[Special:Log/delete|raderingsloggen]].
 
 Använd en länk på något av följande format för att infoga en bild på en sida:
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''',
-* '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|alternativ text]]</nowiki>''' eller
-* '''<nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki>''' om du vill länka direkt till filen.",
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki></tt>''' för att visa bilden i dess hela storlek
+* '''<tt><nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.png|200px|thumb|left|alternativ text]]</nowiki></tt>''' för att visa en miniatyrbild med bredden 200 pixel i en ruta till vänster med bildtexten 'alternativ text'
+* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' om du vill länka direkt till filen utan att visa den",
 'upload-permitted'            => 'Tillåtna filtyper: $1.',
 'upload-preferred'            => 'Föredragna filtyper: $1.',
 'upload-prohibited'           => 'Förbjudna filtyper: $1.',
 'uploadlog'                   => 'Uppladdningar',
 'uploadlogpage'               => 'Uppladdningslogg',
-'uploadlogpagetext'           => 'Nedan följer en lista med de senaste uppladdade filerna.',
+'uploadlogpagetext'           => 'Det här är en logg över de senast uppladdade filerna.
+Se [[Special:NewImages|galleriet över nya filer]] för en mer visuell översikt.',
 'filename'                    => 'Filnamn',
 'filedesc'                    => 'Beskrivning',
 'fileuploadsummary'           => 'Beskrivning<br />och licens:',
@@ -1369,7 +1372,7 @@
 'upload-misc-error'       => 'Okänt uppladdningsfel',
 'upload-misc-error-text'  => 'Ett okänt fel inträffade under uppladdningen.
 Kontrollera att URL:en giltig och försök igen.
-Om problemet kvarstår, kontakta en systemadministratör.',
+Om problemet kvarstår, kontakta en [[Special:ListUsers/sysop|administratör]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL:en kunde inte nås',
@@ -1383,7 +1386,7 @@
 'upload_source_url'  => ' (en giltig URL som är allmänt åtkomlig)',
 'upload_source_file' => ' (en fil på din dator)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Den här specialsidan visar alla filer som har laddats upp.
 Som standard visas de senast upladdade filerna högst upp i listan.
 Genom att klicka på rubrikerna för kolumnerna kan man ändra sorteringsordningen.',
@@ -1411,7 +1414,7 @@
 'imagelinks'                     => 'Bildlänkar',
 'linkstoimage'                   => 'Följande {{PLURAL:$1|sida|sidor}} länkar till den här filen:',
 'nolinkstoimage'                 => 'Inga sidor länkar till den här filen.',
-'morelinkstoimage'               => 'Visa [[Special:Whatlinkshere/$1|fler länkar]] till den här filen.',
+'morelinkstoimage'               => 'Visa [[Special:WhatLinksHere/$1|fler länkar]] till den här filen.',
 'redirectstofile'                => 'Följande {{PLURAL:$1|fil är en omdirigering|filer är omdirigeringar}} till den här filen:',
 'duplicatesoffile'               => 'Följande {{PLURAL:$1|fil är en dubblett|filer är dubbletter}} till den här filen:',
 'sharedupload'                   => 'Denna fil är uppladdad som delad, och kan användas av andra projekt.',
@@ -1492,7 +1495,7 @@
 Sedan denna wiki startades har sidor visats totalt <b>$3</b> {{PLURAL:$3|gång|gånger}}, och <b>$4</b> {{PLURAL:$4|sida|sidor}} har ändrats. Detta är i genomsnitt <b>$5</b> ändringar per sida, och <b>$6</b> sidvisningar per ändring.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue Jobbkön]s längd är för tillfället '''$7'''.",
-'userstatstext'          => "Det finns '''$1''' {{PLURAL:$1|registrerad|registrerade}} [[Special:Listusers|användare]]. Av dem är '''$2''' (eller '''$4%''') $5.",
+'userstatstext'          => "Det finns '''$1''' {{PLURAL:$1|registrerad|registrerade}} [[Special:ListUsers|användare]]. Av dem är '''$2''' (eller '''$4%''') $5.",
 'statistics-mostpopular' => 'Mest besökta sidor',
 
 'disambiguations'      => 'Sidor som länkar till förgreningssidor',
@@ -1501,8 +1504,10 @@
 Länkarna bör troligtvis ändras så att de länkar till en artikel istället.<br />
 En sida anses vara en förgreningssida om den inkluderar en mall som länkas till från [[MediaWiki:Disambiguationspage]].",
 
-'doubleredirects'     => 'Dubbla omdirigeringar',
-'doubleredirectstext' => 'Det här är en lista över sidor som omdirigerar till andra omdirigeringssidor. Varje rad innehåller länkar till den första och den andra omdirigeringsidan, samt till målet för den andra omdirigeringen. Målet för den andra omdirigeringen är ofta den "riktiga" sidan, som den första omdirigeringen egentligen ska leda till.',
+'doubleredirects'            => 'Dubbla omdirigeringar',
+'doubleredirectstext'        => 'Det här är en lista över sidor som omdirigerar till andra omdirigeringssidor. Varje rad innehåller länkar till den första och den andra omdirigeringsidan, samt till målet för den andra omdirigeringen. Målet för den andra omdirigeringen är ofta den "riktiga" sidan, som den första omdirigeringen egentligen ska leda till.',
+'double-redirect-fixed-move' => '[[$1]] har flyttats, och är nu en omdirigering till [[$2]]',
+'double-redirect-fixer'      => 'Omdirigeringsrättaren',
 
 'brokenredirects'        => 'Dåliga omdirigeringar',
 'brokenredirectstext'    => 'Följande länkar omdirigerar till sidor som inte existerar.',
@@ -1510,14 +1515,14 @@
 'brokenredirects-delete' => '(radera)',
 
 'withoutinterwiki'         => 'Sidor utan språklänkar',
-'withoutinterwiki-summary' => 'Följande sidor innehåller inte några länkar till andra språkversioner:',
+'withoutinterwiki-summary' => 'Följande sidor innehåller inte några länkar till andra språkversioner.',
 'withoutinterwiki-legend'  => 'Prefix',
 'withoutinterwiki-submit'  => 'Visa',
 
 'fewestrevisions' => 'Sidor med minst antal ändringar',
 
 # Miscellaneous special pages
-'nbytes'                  => '$1 byte',
+'nbytes'                  => '$1 {{PLURAL:$1|byte|byte}}',
 'ncategories'             => '$1 {{PLURAL:$1|kategori|kategorier}}',
 'nlinks'                  => '$1 {{PLURAL:$1|länk|länkar}}',
 'nmembers'                => '$1 {{PLURAL:$1|medlem|medlemmar}}',
@@ -1587,7 +1592,7 @@
 'logempty'             => 'Inga matchande träffar i loggen.',
 'log-title-wildcard'   => 'Sök efter sidtitlar som börjar med texten',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alla sidor',
 'alphaindexline'    => '$1 till $2',
 'nextpage'          => 'Nästa sida ($1)',
@@ -1610,15 +1615,15 @@
 'special-categories-sort-count' => 'sortera efter storlek',
 'special-categories-sort-abc'   => 'sortera alfabetiskt',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Visa användare från och med:',
 'listusers-submit'   => 'Visa',
 'listusers-noresult' => 'Ingen användare hittades.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Behörigheter för användargrupper',
 'listgrouprights-summary'  => 'Följande lista visar vilka användargrupper som är definierade på den här wikin och vilka behörigheter grupperna har.
-Mer information om de olika rättigheterna finns på [[{{MediaWiki:Listgrouprights-helppage}}]].',
+Det kan finnas [[{{MediaWiki:Listgrouprights-helppage}}|ytterligare information]] om de olika behörigheterna.',
 'listgrouprights-group'    => 'Grupp',
 'listgrouprights-rights'   => 'Behörigheter',
 'listgrouprights-helppage' => 'Help:Gruppbehörigheter',
@@ -1626,13 +1631,11 @@
 
 # E-mail user
 'mailnologin'     => 'Ingen adress att skicka till',
-'mailnologintext' => 'För att kunna skicka e-post till andra användare, måste du vara [[Special:Userlogin|inloggad]] och ha angivit en korrekt e-postadress i dina [[Special:Preferences|användarinställningar]].',
+'mailnologintext' => 'För att kunna skicka e-post till andra användare, måste du vara [[Special:UserLogin|inloggad]] och ha angivit en korrekt e-postadress i dina [[Special:Preferences|användarinställningar]].',
 'emailuser'       => 'Skicka e-post till den här användaren',
 'emailpage'       => 'Skicka e-post till annan användare',
-'emailpagetext'   => 'Om den här användaren har skrivit in en korrekt e-postadress i sina
-användarinställningar, kommer formuläret nedan att skicka ett meddelande.
-Den e-postadress du har angivit i dina användarinställningar kommer att skrivas
-i "Från"-fältet i detta meddelande, så mottagaren har möjlighet att svara.',
+'emailpagetext'   => 'Om den här användaren har skrivit in en giltig e-postadress i sina användarinställningar, kommer formuläret nedan att skicka ett meddelande.
+Den e-postadress du har angivit i [[Special:Preferences|dina användarinställningar]] kommer att visas i "Från"-fältet i meddelandet, så att mottagaren har möjlighet att svara.',
 'usermailererror' => 'Fel i hanteringen av mail:',
 'defemailsubject' => '{{SITENAME}} e-post',
 'noemailtitle'    => 'Ingen e-postadress',
@@ -1655,12 +1658,12 @@
 'nowatchlist'          => 'Du har inga sidor i din bevakningslista.',
 'watchlistanontext'    => 'Du måste $1 för att se eller redigera din bevakningslista.',
 'watchnologin'         => 'Inte inloggad',
-'watchnologintext'     => 'Du måste vara [[Special:Userlogin|inloggad]] för att kunna ändra din bevakningslista.',
+'watchnologintext'     => 'Du måste vara [[Special:UserLogin|inloggad]] för att kunna ändra din bevakningslista.',
 'addedwatch'           => 'Tillagd på bevakningslistan',
 'addedwatchtext'       => "Sidan \"[[:\$1]]\" har lagts till på din [[Special:Watchlist|bevakningslista]].
-Framtida ändringar av den här sidan och dess diskussionssida kommer att listas där, och sidan kommer att markeras med '''fetstil''' i [[Special:Recentchanges|listan över de senaste ändringarna]] för att lättare kunna hittas.",
+Framtida ändringar av den här sidan och dess diskussionssida kommer att listas där, och sidan kommer att markeras med '''fetstil''' i [[Special:RecentChanges|listan över de senaste ändringarna]] för att lättare kunna hittas.",
 'removedwatch'         => 'Borttagen från bevakningslista',
-'removedwatchtext'     => 'Sidan "[[:$1]]" har tagits bort från din bevakningslista.',
+'removedwatchtext'     => 'Sidan "[[:$1]]" har tagits bort från [[Special:Watchlist|din bevakningslista]].',
 'watch'                => 'bevaka',
 'watchthispage'        => 'Bevaka denna sida',
 'unwatch'              => 'avbevaka',
@@ -1758,9 +1761,9 @@
 'rollbacklink'                => 'rulla tillbaka',
 'rollbackfailed'              => 'Tillbakarullning misslyckades',
 'cantrollback'                => 'Det gick inte att rulla tillbaka, då sidan endast redigerats av en användare.',
-'alreadyrolled'               => 'Det gick inte att rulla tillbaka den sista redigeringen av [[User:$2|$2]] ([[User talk:$2|diskussion]]) på sidan [[:$1|$1]]. Någon annan har redan rullat tillbaka eller redigerat sidan.
+'alreadyrolled'               => 'Det gick inte att rulla tillbaka den sista redigeringen av [[User:$2|$2]] ([[User talk:$2|diskussion]] | [[Special:Contributions/$2|{{int:contribslink}}]]) på sidan [[:$1|$1]]. Någon annan har redan rullat tillbaka eller redigerat sidan.
 
-Sidan ändrades senast av [[User:$3|$3]] ([[User talk:$3|diskussion]]).',
+Sidan ändrades senast av [[User:$3|$3]] ([[User talk:$3|diskussion]] | [[Special:Contributions/$2|{{int:contribslink}}]]).',
 'editcomment'                 => 'Redigeringskommentaren var: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'                  => 'Återställde redigeringar av  [[Special:Contributions/$2|$2]] ([[User talk:$2|användardiskussion]]) till senaste versionen av [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Återställde ändringar av $1 till senaste versionen av $2.',
@@ -1878,7 +1881,7 @@
 
 # What links here
 'whatlinkshere'            => 'Sidor som länkar hit',
-'whatlinkshere-title'      => 'Sidor som länkar till $1',
+'whatlinkshere-title'      => 'Sidor som länkar till "$1"',
 'whatlinkshere-page'       => 'Sida:',
 'linklistsub'              => '(Länklista)',
 'linkshere'                => "Följande sidor länkar till '''[[:$1]]''':",
@@ -1929,7 +1932,7 @@
 'badipaddress'                    => 'Du har inte skrivit IP-adressen korrekt.',
 'blockipsuccesssub'               => 'Blockeringen är utförd',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] har blockerats.
-<br />För att se alla aktuella blockeringar, gå till [[Special:Ipblocklist|listan över blockeringar]].',
+<br />För att se alla aktuella blockeringar, gå till [[Special:IPBlockList|listan över blockeringar]].',
 'ipb-edit-dropdown'               => 'Redigera blockeringsanledningar',
 'ipb-unblock-addr'                => 'Ta bort blockering av $1',
 'ipb-unblock'                     => 'Ta bort blockering av en användare eller IP-adress',
@@ -1940,7 +1943,7 @@
 'ipusubmit'                       => 'Ta bort blockeringen',
 'unblocked'                       => 'Blockeringen av [[User:$1|$1]] har hävts',
 'unblocked-id'                    => 'Blockeringen $1 har hävts',
-'ipblocklist'                     => 'Lista över blockerade IP-adresser och användarnamn',
+'ipblocklist'                     => 'Blockerade IP-adresser och användarnamn',
 'ipblocklist-legend'              => 'Sök efter en blockerad användare',
 'ipblocklist-username'            => 'Användarnamn eller IP-adress',
 'ipblocklist-submit'              => 'Sök',
@@ -1959,7 +1962,9 @@
 'autoblocker'                     => 'Automatisk blockering eftersom du har samma IP-adress som "$1". Motivering till blockeringen: "$2".',
 'blocklogpage'                    => 'Blockeringslogg',
 'blocklogentry'                   => 'blockerade [[$1]] med blockeringstid på $2 $3',
-'blocklogtext'                    => 'Detta är en logg över blockeringar och avblockeringar. Automatiskt blockerade IP-adresser listas ej. En lista över IP-adresser och användare som för närvarande är blockerade finns på [[Special:Ipblocklist|IP-blocklistan]].',
+'blocklogtext'                    => 'Detta är en logg över blockeringar och avblockeringar.
+Automatiskt blockerade IP-adresser listas ej.
+I [[Special:IPBlockList|blockeringslistan]] listas alla IP-adresser och användare som är blockerade för närvarande.',
 'unblocklogentry'                 => 'tog bort blockering av "$1"',
 'block-log-flags-anononly'        => 'bara oinloggade',
 'block-log-flags-nocreate'        => 'hindrar kontoregistrering',
@@ -1995,7 +2000,7 @@
 'lockdbsuccesssub'    => 'Databasen har låsts',
 'unlockdbsuccesssub'  => 'Databasen har låsts upp',
 'lockdbsuccesstext'   => 'Databasen är nu låst.
-<br />Kom ihåg att [[Special:Unlockdb|ta bort låsningen]] när du är färdig med ditt underhåll.',
+<br />Kom ihåg att [[Special:UnlockDB|ta bort låsningen]] när du är färdig med ditt underhåll.',
 'unlockdbsuccesstext' => 'Databasen är upplåst.',
 'lockfilenotwritable' => 'Det går inte att skriva till databasens låsfil. För att låsa eller låsa upp databasen, så måste webbservern kunna skriva till den filen.',
 'databasenotlocked'   => 'Databasen är inte låst.',
@@ -2004,12 +2009,13 @@
 'move-page'               => 'Flytta $1',
 'move-page-legend'        => 'Flytta sida',
 'movepagetext'            => "Med hjälp av formuläret härunder kan du byta namn på en sida, och flytta hela dess historik till ett nytt namn.
-Den gamla sidtiteln kommer att göras om till en omdirigering till den nya titeln;
-kontrollera därför om du skapar några dubbla eller trasiga omdirigeringar.
+Den gamla sidtiteln kommer att göras om till en omdirigering till den nya titeln.
+Du kan välja att automatiskt uppdatera omdirigeringar som leder till den gamla titeln.
+Om du väljer att inte göra det, kontrollera då att du inte skapar några [[Special:DoubleRedirects|dubbla]] eller [[Special:BrokenRedirects|trasiga omdirigeringar]].
 Du bör också se till att länkar fortsätter att peka dit de ska.
 
-Notera att sidan '''inte''' kan flyttas om det redan finns en sida under den nya sidtiteln, såvida inte den sidan är tom eller en omdirigiring till den gamla titeln och saknar annan versionshistorik.
-Det innebär att du kan flytta tillbaks en sida du just flyttat om du råkar göra fel.
+Notera att sidan '''inte''' kan flyttas om det redan finns en sida under den nya sidtiteln, såvida inte den sidan är tom eller en omdirigering till den gamla titeln och saknar annan versionshistorik.
+Det innebär att du kan flytta tillbaks en sida om du råkar göra fel, och att du inte kan skriva över existerande sidor.
 
 '''VARNING!'''
 Att flytta en populär sida kan vara en drastisk och oväntad ändring;
@@ -2020,8 +2026,6 @@
 
 I de fallen måste du flytta eller sammanfoga sidan manuellt, om det önskas.",
 'movearticle'             => 'Flytta sidan:',
-'movenologin'             => 'Inte inloggad',
-'movenologintext'         => 'För att flytta en sida måste du vara registrerad användare och [[Special:Userlogin|inloggad]].',
 'movenotallowed'          => 'Du har inte behörighet att flytta sidor på den här wikin.',
 'newtitle'                => 'Till nya titeln:',
 'move-watch'              => 'Bevaka denna sida',
@@ -2049,7 +2053,7 @@
 'revertmove'              => 'flytta tillbaka',
 'delete_and_move'         => 'Radera och flytta',
 'delete_and_move_text'    => '==Radering krävs==
-Den titel du vill flytta sidan till, "[[$1]]", finns redan. Vill du radera den för att möjliggöra flytt av denna sida dit?',
+Den titel du vill flytta sidan till, "[[:$1]]", finns redan. Vill du radera den för att möjliggöra flytt av denna sida dit?',
 'delete_and_move_confirm' => 'Ja, radera sidan',
 'delete_and_move_reason'  => 'Raderad för att flytta hit en annan sida.',
 'selfmove'                => 'Ursprungstitel och destinationstitel är identiska. Sidan kan inte flyttas till sig själv.',
@@ -2057,6 +2061,7 @@
 'imagenocrossnamespace'   => 'Kan inte flytta bilder till andra namnrymder än bildnamnrymden',
 'imagetypemismatch'       => 'Den nya filändelsen motsvarar inte filtypen',
 'imageinvalidfilename'    => 'Önskat filnamn är ogiltigt',
+'fix-double-redirects'    => 'Uppdatera omdirigeringar som leder till den gamla titeln',
 
 # Export
 'export'            => 'Exportera sidor',
@@ -2105,7 +2110,7 @@
 'import-interwiki-history'   => 'Kopiera hela versionshistoriken för denna sida',
 'import-interwiki-submit'    => 'Importera',
 'import-interwiki-namespace' => 'Överför sidorna till namnrymden:',
-'importtext'                 => 'Exportera filen från ursprungs-wikin genom Special:Export, spara den till din hårddisk och ladda upp den här.',
+'importtext'                 => 'Exportera filen från ursprungs-wikin genom att använda [[Special:Export|exportverktyget]], spara den till din hårddisk och ladda upp den här.',
 'importstart'                => 'Importerar sidor....',
 'import-revision-count'      => '$1 {{PLURAL:$1|version|versioner}}',
 'importnopages'              => 'Det finns inga sidor att importera.',
@@ -2255,10 +2260,11 @@
 'markedaspatrollederror-noautopatrol' => 'Du har inte tillåtelse att markera dina egna redigeringar som patrullerade.',
 
 # Patrol log
-'patrol-log-page' => 'Patrulleringslogg',
-'patrol-log-line' => 'markerade $1 av $2 som patrullerad $3',
-'patrol-log-auto' => '(automatiskt)',
-'patrol-log-diff' => 'version $1',
+'patrol-log-page'   => 'Patrulleringslogg',
+'patrol-log-header' => 'Detta är en logg över patrullerade sidversioner.',
+'patrol-log-line'   => 'markerade $1 av $2 som patrullerad $3',
+'patrol-log-auto'   => '(automatiskt)',
+'patrol-log-diff'   => 'version $1',
 
 # Image deletion
 'deletedrevision'                 => 'Raderade gammal sidversion $1',
@@ -2287,10 +2293,10 @@
 'show-big-image'       => 'Högupplöst version',
 'show-big-image-thumb' => '<small>Storlek på förhandsvisningen: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galleri över nya filer',
 'imagelisttext'         => 'Nedan finns en lista med <strong>$1</strong> {{PLURAL:$1|bild|bilder}} sorterad <strong>$2</strong>.',
-'newimages-summary'     => 'Den här specialsidan visar de senast uppladdade filerna',
+'newimages-summary'     => 'Den här specialsidan visar de senast uppladdade filerna.',
 'showhidebots'          => '($1 robotar)',
 'noimages'              => 'Ingenting att se.',
 'ilsubmit'              => 'Sök',
@@ -2571,7 +2577,7 @@
 
 # External editor support
 'edit-externally'      => 'Redigera denna fil med hjälp av extern programvara',
-'edit-externally-help' => 'Se [http://meta.wikimedia.org/wiki/Help:External_editors instruktioner] för mer information.',
+'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors instruktioner] för mer information.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alla',
@@ -2594,7 +2600,8 @@
 Mailservern meddelade: $1',
 'confirmemail_invalid'     => 'Ogiltig bekräftelsekod. Dess giltighetstid kan ha löpt ut.',
 'confirmemail_needlogin'   => 'Du behöver $1 för att bekräfta din e-postadress',
-'confirmemail_success'     => 'Din e-postadress har bekräftats och du kan logga in på wikin.',
+'confirmemail_success'     => 'Din e-postadress har bekräftats. 
+Du kan nu [[Special:UserLogin|logga in]] och använda wikin.',
 'confirmemail_loggedin'    => 'Din e-postadress är nu bekräftad.',
 'confirmemail_error'       => 'Någonting gick fel när din bekräftelse skulle sparas.',
 'confirmemail_subject'     => 'Bekräftelse av e-postadress på {{SITENAME}}',
@@ -2631,7 +2638,7 @@
 'recreate'            => 'Återskapa',
 
 # HTML dump
-'redirectingto' => 'Omdirigerar till [[$1]]...',
+'redirectingto' => 'Omdirigerar till [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Rensa denna sidas cache?
@@ -2684,8 +2691,8 @@
 Pröva vanlig förhandsgranskning istället.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Ändringar nyare än $1 sekunder kanske inte visas i den här listan.',
-'lag-warn-high'   => 'På grund av stor fördröjning i databasen, så visas kanske inte ändringar nyare än $1 sekunder i den här listan.',
+'lag-warn-normal' => 'Ändringar under {{PLURAL:$1|den senaste sekunden|de $1 senaste sekunderna}} kanske inte visas i den här listan.',
+'lag-warn-high'   => 'På grund av stor fördröjning i databasen, så visas kanske inte ändringar nyare än $1 {{PLURAL:$1|sekund|sekunder}} i den här listan.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Din bevakningslista innehåller {{PLURAL:$1|1 sida|$1 sidor}}, utöver diskussionsidor.',
@@ -2738,7 +2745,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Sökväg till fil',
 'filepath-page'    => 'Fil:',
 'filepath-submit'  => 'Sökväg',
@@ -2776,7 +2783,7 @@
 'specialpages-group-redirects'   => 'Omdirigerande specialsidor',
 'specialpages-group-spam'        => 'Spamverktyg',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Tom sida',
 'intentionallyblankpage' => 'Denna sida har avsiktligen lämnats tom.',
 
Index: languages/messages/MessagesDe.php
===================================================================
--- languages/messages/MessagesDe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesDe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,9 +5,16 @@
  * @file
  *
  * @author Jimmy Collins <jimmy.collins@web.de>
+ * @author MichaelFrey
+ * @author Omnipaedista
+ * @author Pill
+ * @author Purodha
  * @author Raimond Spekking (Raymond) <raimond.spekking@gmail.com> since January 2007
+ * @author Red Baron
+ * @author Revolus
+ * @author Spacebirdy
  * @author Tim Bartel (avatar) <wikipedistik@computerkultur.org> small changes
- * @author Spacebirdy
+ * @author לערי ריינהארט
  */
 
 $namespaceNames = array(
@@ -413,9 +420,10 @@
 'badaccess-groups' => 'Diese Aktion ist beschränkt auf Benutzer, die einer der Gruppen „$1“ angehören.',
 
 'versionrequired'     => 'Version $1 von MediaWiki ist erforderlich',
-'versionrequiredtext' => 'Version $1 von MediaWiki ist erforderlich, um diese Seite zu nutzen. Siehe die [[{{#special:version}}|Versionsseite]]',
+'versionrequiredtext' => 'Version $1 von MediaWiki ist erforderlich, um diese Seite zu nutzen. Siehe die [[Special:Version|Versionsseite]]',
 
 'ok'                      => 'OK',
+'pagetitle'               => '$1 – {{SITENAME}}',
 'retrievedfrom'           => 'Von „$1“',
 'youhavenewmessages'      => 'Du hast $2 auf deiner $1.',
 'newmessageslink'         => 'Diskussionsseite',
@@ -458,7 +466,7 @@
 'nosuchspecialpage' => 'Spezialseite nicht vorhanden',
 'nospecialpagetext' => "<big>'''Die aufgerufene Spezialseite ist nicht vorhanden.'''</big>
 
-Alle verfügbaren Spezialseiten sind in der [[{{ns:special}}:Specialpages|Liste der Spezialseiten]] zu finden.",
+Alle verfügbaren Spezialseiten sind in der [[Special:SpecialPages|Liste der Spezialseiten]] zu finden.",
 
 # General errors
 'error'                => 'Fehler',
@@ -482,7 +490,7 @@
 
 Die Seite ist möglicherweise gelöscht oder verschoben worden.
 
-Falls dies nicht der Fall ist, hast du eventuell einen Fehler in der Software gefunden. Bitte melde dies einem [[{{MediaWiki:Grouppage-sysop}}|Administrator]] unter Nennung der URL.',
+Falls dies nicht der Fall ist, hast du eventuell einen Fehler in der Software gefunden. Bitte melde dies einem [[Special:ListUsers/sysop|Administrator]] unter Nennung der URL.',
 'missingarticle-rev'   => '(Versionsnummer: $1)',
 'missingarticle-diff'  => '(Unterschied zwischen Versionen: $1, $2)',
 'readonly_lag'         => 'Die Datenbank wurde automatisch für Schreibzugriffe gesperrt, damit sich die verteilten Datenbankserver (slaves) mit dem Hauptdatenbankserver (master) abgleichen können.',
@@ -521,7 +529,8 @@
 'namespaceprotected'   => "Du hast keine Berechtigung, die Seite im '''$1'''-Namensraum zu bearbeiten.",
 'customcssjsprotected' => 'Du bist nicht berechtigt, diese Seite zu bearbeiten, da sie zu den persönlichen Einstellungen eines anderen Benutzers gehört.',
 'ns-specialprotected'  => 'Spezialseiten können nicht bearbeitet werden.',
-'titleprotected'       => "Eine Seite mit diesem Namen kann nicht angelegt werden. Die Sperre wurde durch [[{{ns:user}}:$1]] mit der Begründung ''„$2“'' eingerichtet.",
+'titleprotected'       => "Eine Seite mit diesem Namen kann nicht angelegt werden.
+Die Sperre wurde durch [[User:$1|Benutzer:$1]] mit der Begründung ''„$2“'' eingerichtet.",
 
 # Virus scanner
 'virus-badscanner'     => 'Fehlerhafte Konfiguration: unbekannter Virenscanner: <i>$1</i>',
@@ -530,8 +539,9 @@
 
 # Login and logout pages
 'logouttitle'                => 'Benutzer-Abmeldung',
-'logouttext'                 => 'Du bist nun abgemeldet.
-Du kannst {{SITENAME}} jetzt anonym weiterbenutzen, oder dich erneut unter dem selben oder einem anderen Benutzernamen anmelden.',
+'logouttext'                 => '<strong>Du bist nun abgemeldet.</strong>
+
+Du kannst {{SITENAME}} jetzt anonym weiter benutzen, oder dich erneut unter dem selben oder einem anderen Benutzernamen [[Special:UserLogin|anmelden]].',
 'welcomecreation'            => '== Willkommen, $1! ==
 
 Dein Benutzerkonto wurde eingerichtet. Vergiss nicht, deine Einstellungen anzupassen.',
@@ -667,7 +677,7 @@
 'blockedtitle'                     => 'Benutzer ist gesperrt',
 'blockedtext'                      => 'Dein Benutzername oder deine IP-Adresse wurde von $1 gesperrt. Als Grund wurde angegeben:
 
-:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
+:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
 
 <p style="border-style: solid; border-color: red; border-width: 1px; padding:5px;"><b>Ein Lesezugriff ist weiterhin möglich,</b>
 nur die Bearbeitung und Erstellung von Seiten in {{SITENAME}} wurde gesperrt.
@@ -688,7 +698,7 @@
 'autoblockedtext'                  => 'Deine IP-Adresse wurde automatisch gesperrt, da sie von einem anderen Benutzer genutzt wurde, der durch $1 gesperrt wurde.
 Als Grund wurde angegeben:
 
-:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:Ipblocklist|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
+:\'\'$2\'\' (<span class="plainlinks">[{{fullurl:Special:IPBlockList|&action=search&limit=&ip=%23}}$5 Logbucheintrag]</span>)
 
 <p style="border-style: solid; border-color: red; border-width: 1px; padding:5px;"><b>Ein Lesezugriff ist weiterhin möglich,</b>
 nur die Bearbeitung und Erstellung von Seiten in {{SITENAME}} wurde gesperrt.
@@ -703,6 +713,7 @@
 *Beginn der Sperre: $8
 *Sperr-Ende: $6
 *IP-Adresse: $3
+*Sperre betrifft: $7
 *Sperr-ID: #$5
 </div>',
 'blockednoreason'                  => 'keine Begründung angegeben',
@@ -710,10 +721,6 @@
 'blockededitsource'                => "Der Quelltext '''deiner Änderungen''' an '''$1''':",
 'whitelistedittitle'               => 'Zum Bearbeiten ist es erforderlich, angemeldet zu sein',
 'whitelistedittext'                => 'Du musst dich $1, um Seiten bearbeiten zu können.',
-'whitelistreadtitle'               => 'Zum Lesen ist es erforderlich, angemeldet zu sein',
-'whitelistreadtext'                => 'Du musst dich [[Special:Userlogin|hier anmelden]], um Seiten lesen zu können.',
-'whitelistacctitle'                => 'Du bist nicht berechtigt, ein Benutzerkonto anzulegen.',
-'whitelistacctext'                 => 'Um in {{SITENAME}} Benutzerkonten anlegen zu dürfen, musst du dich [[Special:Userlogin|hier anmelden]] und die nötigen Berechtigungen haben.',
 'confirmedittitle'                 => 'Zum Bearbeiten ist die E-Mail-Bestätigung erforderlich.',
 'confirmedittext'                  => 'Du musst deine E-Mail-Adresse erst bestätigen, bevor du Bearbeitungen durchführen kannst. Bitte ergänze und bestätige Deine E-Mail in den [[Special:Preferences|Einstellungen]].',
 'nosuchsectiontitle'               => 'Abschnitt nicht vorhanden',
@@ -725,10 +732,10 @@
 'accmailtext'                      => 'Das Passwort für „$1“ wurde an $2 geschickt.',
 'newarticle'                       => '(Neu)',
 'newarticletext'                   => 'Hier den Text der neuen Seite eintragen. Bitte nur in ganzen Sätzen schreiben und keine urheberrechtsgeschützten Texte anderer kopieren.',
-'anontalkpagetext'                 => "---- ''Diese Seite dient dazu, einem nicht angemeldeten Benutzer Nachrichten zu hinterlassen. Wenn du mit den Kommentaren auf dieser Seite nichts anfangen kannst, richten sie sich vermutlich an einen früheren Inhaber deiner IP-Adresse und du kannst sie ignorieren.''",
+'anontalkpagetext'                 => "---- ''Diese Seite dient dazu, einem nicht angemeldeten Benutzer Nachrichten zu hinterlassen. Es wird seine IP-Adresse zur Identifizierung verwendet. IP-Adressen können von mehreren Benutzerm gemeinsam verwendet werden. Wenn du mit den Kommentaren auf dieser Seite nichts anfangen kannst, richten sie sich vermutlich an einen früheren Inhaber deiner IP-Adresse und du kannst sie ignorieren. Du kannst dir auch ein [[Special:UserLogin/signup|Benutzerkonto erstellen]] oder dich  [[Special:UserLogin|anmelden]], um künftig Verwechslungen mit anderen anonymen Benutzer zu vermeiden.''",
 'noarticletext'                    => '(Diese Seite enthält momentan noch keinen Text)',
 'userpage-userdoesnotexist'        => 'Das Benutzerkonto „$1“ ist nicht vorhanden. Bitte prüfe, ob du diese Seite wirklich erstellen/bearbeiten willst.',
-'clearyourcache'                   => "'''Hinweis:''' Leere nach dem Speichern den Browser-Cache, um die Änderungen zu sehen: '''Mozilla/Firefox:''' ''Shift-Strg-R'', '''Internet Explorer:''' ''Strg-F5'', '''Opera:''' ''F5'', '''Safari:''' ''⌘-R'', '''Konqueror:''' ''Strg-R''.",
+'clearyourcache'                   => "'''Hinweis - Leere nach dem Speichern den Browser-Cache, um die Änderungen sehen zu können:''' '''Mozilla/Firefox/Safari:''' ''Shift'' gedrückt halten und auf ''Aktualisieren'' klicken oder alternativ entweder ''Strg-F5'' oder ''Strg-R'' (''Befehlstaste-R'' bei Macintosh) drücken; '''Konqueror: '''Auf ''Aktualisieren'' klicken oder ''F5'' drücken; '''Opera:''' Cache unter ''Extras → Einstellungen'' leeren; '''Internet Explorer:''' ''Strg-F5'' drücken oder ''Strg'' gedrückt halten und dabei ''Aktualisieren'' anklicken.",
 'usercssjsyoucanpreview'           => '<strong>Tipp:</strong> Benutze den Vorschau-Button, um dein neues CSS/JS vor dem Speichern zu testen.',
 'usercsspreview'                   => "== Vorschau Deines Benutzer-CSS ==
 '''Beachte:''' Nach dem Speichern musst du deinen Browser anweisen, die neue Version zu laden: '''Mozilla/Firefox:''' ''Strg-Shift-R'', '''Internet Explorer:''' ''Strg-F5'', '''Opera:''' ''F5'', '''Safari:''' ''Cmd-Shift-R'', '''Konqueror:''' ''F5''.",
@@ -746,7 +753,7 @@
 
 ''Da in {{SITENAME}} das Speichern von reinem HTML aktiviert ist, wurde die Vorschau ausgeblendet, um JavaScript-Attacken vorzubeugen.''
 
-<strong>Bitte versuche es erneut, indem du unter der folgenden Textvorschau nochmals auf „Seite speichern“ klickst. Sollte das Problem bestehen bleiben, melde dich ab und danach wieder an.</strong>",
+<strong>Bitte versuche es erneut, indem du unter der folgenden Textvorschau nochmals auf „Seite speichern“ klickst. Sollte das Problem bestehen bleiben, [[Special:UserLogout|melde dich ab]] und danach wieder an.</strong>",
 'token_suffix_mismatch'            => '<strong>Deine Bearbeitung wurde zurückgewiesen, da dein Browser Zeichen im Bearbeiten-Token verstümmelt hat.
 Eine Speicherung kann den Seiteninhalt zerstören. Dies geschieht bisweilen durch die Benutzung eines anonymen Proxy-Dienstes, der fehlerhaft arbeitet.</strong>',
 'editing'                          => 'Bearbeiten von $1',
@@ -788,7 +795,7 @@
 'hiddencategories'                 => 'Diese Seite ist Mitglied von {{PLURAL:$1|1 versteckter Kategorie|$1 versteckten Kategorien}}:',
 'edittools'                        => '<!-- Dieser Text wird unter dem „Bearbeiten“-Formular sowie dem "Hochladen"-Formular angezeigt. -->',
 'nocreatetitle'                    => 'Die Erstellung neuer Seiten ist eingeschränkt.',
-'nocreatetext'                     => 'Auf {{SITENAME}} wurde das Erstellen neuer Seiten eingeschränkt. Du kannst bestehende Seiten ändern oder dich [[Special:Userlogin|anmelden]].',
+'nocreatetext'                     => 'Auf {{SITENAME}} wurde das Erstellen neuer Seiten eingeschränkt. Du kannst bestehende Seiten ändern oder dich [[Special:UserLogin|anmelden]].',
 'nocreate-loggedin'                => 'Du hast keine Berechtigung, neue Seiten in {{SITENAME}} anzulegen.',
 'permissionserrors'                => 'Berechtigungsfehler',
 'permissionserrorstext'            => 'Du bist nicht berechtigt, die Aktion auszuführen. {{PLURAL:$1|Grund|Gründe}}:',
@@ -812,7 +819,7 @@
 'undo-success' => 'Die Änderung konnte erfolgreich rückgängig gemacht werden. Bitte die Bearbeitung in der Vergleichsansicht kontrollieren und dann auf „Seite speichern“ klicken, um sie zu speichern.',
 'undo-failure' => '<span class="error">Die Änderung konnte nicht rückgängig gemacht werden, da der betroffene Abschnitt zwischenzeitlich verändert wurde.</span>',
 'undo-norev'   => 'Die Bearbeitung konnte nicht rückgängig gemacht werden, da sie nicht vorhanden ist oder gelöscht wurde.',
-'undo-summary' => 'Änderung $1 von [[{{#special:Contributions}}/$2|$2]] ([[{{ns:user_talk}}:$2|Diskussion]]) wurde rückgängig gemacht.',
+'undo-summary' => 'Änderung $1 von [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussion]]) wurde rückgängig gemacht.',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'Benutzerkonto kann nicht erstellt werden',
@@ -865,7 +872,7 @@
 'revdelete-nooldid-title'     => 'Keine Version angegeben',
 'revdelete-nooldid-text'      => 'Du hast entweder keine Version angegeben, auf die diese Aktion ausgeführt werden soll, die gewählte Version ist nicht vorhanden oder du versuchst, die aktuelle Version zu entfernen.',
 'revdelete-selected'          => "{{PLURAL:$2|Ausgewählte Version|Ausgewählte Versionen}} von '''$1:'''",
-'logdelete-selected'          => "{{PLURAL:$1|Ausgewählter Logbucheintrag|Ausgewählte Logbucheinträge}} für '''$1:'''",
+'logdelete-selected'          => '{{PLURAL:$1|Ausgewählter Logbucheintrag|Ausgewählte Logbucheinträge}}:',
 'revdelete-text'              => 'Der Inhalt oder andere Bestandteile gelöschter Versionen sind nicht mehr öffentlich einsehbar, erscheinen jedoch weiterhin als Einträge in der Versionsgeschichte.
 
 {{SITENAME}}-Administratoren können den entfernten Inhalt oder andere entfernte Bestandteile weiterhin einsehen und wiederherstellen, es sei denn, es wurde festgelegt, dass die Zugangsbeschränkungen auch für Administratoren gelten.',
@@ -894,7 +901,7 @@
 'revdelete-unrestricted'      => 'Einschränkungen für Administratoren aufgehoben',
 'revdelete-hid'               => 'versteckte $1',
 'revdelete-unhid'             => 'machte $1 wieder öffentlich',
-'revdelete-log-message'       => '$1 für $2 {{PLURAL:$2|Version|Versionen}}: $3',
+'revdelete-log-message'       => '$1 für $2 {{PLURAL:$2|Version|Versionen}}',
 'logdelete-log-message'       => '$1 für $2 {{PLURAL:$2|Logbucheintrag|Logbucheinträge}}',
 
 # Suppression log
@@ -939,7 +946,7 @@
 # Search results
 'searchresults'             => 'Suchergebnisse',
 'searchresulttext'          => 'Für mehr Informationen zur Suche siehe die [[{{MediaWiki:Helppage}}|Hilfeseite]].',
-'searchsubtitle'            => 'Deine Suchanfrage: „[[:$1|$1]]“.',
+'searchsubtitle'            => 'Deine Suchanfrage: „[[:$1|$1]]“ ([[Special:Prefixindex/$1|alle mit „$1“ beginnenden Seiten]] | [[Special:WhatLinksHere/$1|alle Seiten, die nach „$1“ verlinken]])',
 'searchsubtitleinvalid'     => 'Deine Suchanfrage: „$1“.',
 'noexactmatch'              => "'''Es existiert keine Seite mit dem Titel „$1“.'''
 
@@ -970,7 +977,7 @@
 'searchrelated'             => 'verwandt',
 'searchall'                 => 'alle',
 'showingresults'            => "Hier {{PLURAL:$1|ist '''1''' Ergebnis|sind '''$1''' Ergebnisse}}, beginnend mit Nummer '''$2.'''",
-'showingresultsnum'         => "Hier {{PLURAL:$3|ist '''1''' Ergebnis|sind '''$1''' Ergebnisse}}, beginnend mit Nummer '''$2.'''",
+'showingresultsnum'         => "Hier {{PLURAL:$3|ist '''1''' Ergebnis|sind '''$3''' Ergebnisse}}, beginnend mit Nummer '''$2.'''",
 'showingresultstotal'       => "Es {{PLURAL:$3|folgt Suchergebnis '''$1''' von '''$3:'''|folgen die Suchergebnisse '''$1–$2''' von '''$3:'''}}",
 'nonefound'                 => "'''Hinweis:''' Es werden standardmäßig nur einige Namensräume durchsucht. Setze ''all:'' vor deinen Suchbegriff, um alle Seiten (inkl. Diskussionsseiten, Vorlagen usw.) zu durchsuchen oder gezielt den Namen des zu durchsuchenden Namensraumes.",
 'powersearch'               => 'Erweiterte Suche',
@@ -983,11 +990,10 @@
 
 # Preferences page
 'preferences'              => 'Einstellungen',
-'preferences-summary'      => 'Auf dieser Spezialseite kannst du deine Zugangsdaten ändern und bestimmte Teile der Oberfläche individuell anpassen.',
 'mypreferences'            => 'Einstellungen',
 'prefs-edits'              => 'Anzahl Bearbeitungen:',
 'prefsnologin'             => 'Nicht angemeldet',
-'prefsnologintext'         => 'Du musst [[Special:Userlogin|angemeldet]] sein, um deine Einstellungen ändern zu können.',
+'prefsnologintext'         => 'Du musst [[Special:UserLogin|angemeldet]] sein, um deine Einstellungen ändern zu können.',
 'prefsreset'               => 'Die Eingaben wurden verworfen, es erfolgte keine Speicherung.',
 'qbsettings'               => 'Seitenleiste',
 'qbsettings-none'          => 'Keine',
@@ -1050,7 +1056,7 @@
 'userrights-lookup-user'      => 'Verwalte Gruppenzugehörigkeit',
 'userrights-user-editname'    => 'Benutzername:',
 'editusergroup'               => 'Benutzerrechte bearbeiten',
-'editinguser'                 => "Ändere Benutzerrechte von '''[[{{ns:user}}:$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[{{#Special:Contributions}}/$1|{{int:contribslink}}]])",
+'editinguser'                 => "Ändere Benutzerrechte von '''[[User:$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-editusergroup'    => 'Benutzer-Gruppenzugehörigkeit bearbeiten',
 'saveusergroups'              => 'Gruppenzugehörigkeit ändern',
 'userrights-groupsmember'     => 'Mitglied von:',
@@ -1060,7 +1066,7 @@
 'userrights-reason'           => 'Grund:',
 'userrights-no-interwiki'     => 'Du hast keine Berechtigung, Benutzerrechte in anderen Wikis zu ändern.',
 'userrights-nodatabase'       => 'Die Datenbank $1 ist nicht vorhanden oder nicht lokal.',
-'userrights-nologin'          => 'Du musst dich mit einem Administrator-Benutzerkonto [[{{#special:Userlogin}}|anmelden]], um Benutzerrechte zu ändern.',
+'userrights-nologin'          => 'Du musst dich mit einem Administrator-Benutzerkonto [[Special:UserLogin|anmelden]], um Benutzerrechte zu ändern.',
 'userrights-notallowed'       => 'Du besitzt nicht die erforderlichen Berechtigungen, um Benutzerrechte zu vergeben.',
 'userrights-changeable-col'   => 'Gruppenzugehörigkeit, die du ändern kannst',
 'userrights-unchangeable-col' => 'Gruppenzugehörigkeit, die du nicht ändern kannst',
@@ -1146,7 +1152,7 @@
 'rightslog'      => 'Rechte-Logbuch',
 'rightslogtext'  => 'Dies ist das Logbuch der Änderungen der Benutzerrechte.',
 'rightslogentry' => 'änderte die Benutzerrechte für „[[$1]]“ von „$2“ auf „$3“',
-'rightsnone'     => '(-)',
+'rightsnone'     => '(–)',
 
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|Änderung|Änderungen}}',
@@ -1190,13 +1196,15 @@
 'reupload'                    => 'Abbrechen',
 'reuploaddesc'                => 'Abbrechen und zurück zur Hochladen-Seite',
 'uploadnologin'               => 'Nicht angemeldet',
-'uploadnologintext'           => 'Du musst [[Special:Userlogin|angemeldet sein]], um Dateien hochladen zu können.',
+'uploadnologintext'           => 'Du musst [[Special:UserLogin|angemeldet sein]], um Dateien hochladen zu können.',
 'upload_directory_missing'    => 'Das Upload-Verzeichnis ($1) fehlt und konnte durch den Webserver auch nicht erstellt werden.',
 'upload_directory_read_only'  => 'Der Webserver hat keine Schreibrechte für das Upload-Verzeichnis ($1).',
 'uploaderror'                 => 'Fehler beim Hochladen',
-'uploadtext'                  => "Gehe zu der [[{{#special:Imagelist}}|Liste hochgeladener Dateien]], um vorhandene Dateien zu suchen und anzuzeigen.
+'uploadtext'                  => "Benutze dieses Formular, um neue Dateien hochzuladen. 
 
-Benutze dieses Formular, um neue Dateien hochzuladen. Klicke auf '''„Durchsuchen …“''', um einen Dateiauswahl-Dialog zu öffnen.
+Gehe zu der [[Special:ImageList|Liste hochgeladener Dateien]], um vorhandene Dateien zu suchen und anzuzeigen. Siehe auch das [[Special:Log/upload|Datei-]] und [[Special:Log/upload|Lösch-Logbuch]].
+
+Klicke auf '''„Durchsuchen …“''', um einen Dateiauswahl-Dialog zu öffnen.
 Nach der Auswahl einer Datei wird der Dateiname im Textfeld '''„Quelldatei“''' angezeigt.
 Bestätige dann die Lizenz-Vereinbarung und klicke anschließend auf '''„Datei hochladen“'''.
 Dies kann eine Weile dauern, besonders bei einer langsamen Internet-Verbindung.
@@ -1215,7 +1223,7 @@
 'upload-prohibited'           => 'Nicht erlaubte Dateitypen: $1.',
 'uploadlog'                   => 'Datei-Logbuch',
 'uploadlogpage'               => 'Datei-Logbuch',
-'uploadlogpagetext'           => 'Dies ist das Logbuch der hochgeladenen Dateien, siehe auch [[{{ns:special}}:Newimages]].',
+'uploadlogpagetext'           => 'Dies ist das Logbuch der hochgeladenen Dateien, siehe auch die [[Special:NewImages|Galerie neuer Dateien]] für einen visuellen Überblick.',
 'filename'                    => 'Dateiname',
 'filedesc'                    => 'Beschreibung',
 'fileuploadsummary'           => 'Beschreibung/Quelle:',
@@ -1228,8 +1236,8 @@
 'illegalfilename'             => 'Der Dateiname „$1“ enthält mindestens ein nicht erlaubtes Zeichen. Bitte benenne die Datei um und versuche sie erneut hochzuladen.',
 'badfilename'                 => 'Der Dateiname wurde in „$1“ geändert.',
 'filetype-badmime'            => 'Dateien mit dem MIME-Typ „$1“ dürfen nicht hochgeladen werden.',
-'filetype-unwanted-type'      => "'''„.$1“''' ist ein unerwünschtes Dateiformat. Erlaubt sind: $2.",
-'filetype-banned-type'        => "'''„.$1“''' ist ein nicht erlaubtes Dateiformat. Erlaubt sind: $2.",
+'filetype-unwanted-type'      => "'''„.$1“''' ist ein unerwünschtes Dateiformat. Erlaubt {{PLURAL:$3|ist das Dateiformat|sind die Dateiformate}}: $2.",
+'filetype-banned-type'        => "'''„.$1“''' ist ein nicht erlaubtes Dateiformat. Erlaubt {{PLURAL:$3|ist das Dateiformat|sind die Dateiformate}}: $2.",
 'filetype-missing'            => 'Die hochzuladende Datei hat keine Erweiterung (z. B. „.jpg“).',
 'large-file'                  => 'Die Dateigröße sollte nach Möglichkeit $1 nicht überschreiten. Diese Datei ist $2 groß.',
 'largefileserver'             => 'Die Datei ist größer als die vom Server eingestellte Maximalgröße.',
@@ -1269,13 +1277,30 @@
 Zu deiner Information folgt das Lösch-Logbuch mit der Begründung für die vorhergehende Löschung:",
 'filename-bad-prefix'         => 'Der Dateiname beginnt mit <strong>„$1“</strong>. Dies ist im allgemeinen der von einer Digitalkamera vorgegebene Dateiname und daher nicht sehr aussagekräftig.
 Bitte gib der Datei einen Namen, der den Inhalt besser beschreibt.',
+'filename-prefix-blacklist'   => ' #<!-- Diese Zeile darf nicht verändert werden! --> <pre>
+#  Syntax:
+#   * Alles von einem #-Zeichen bis zum Ende der Zeile ist ein Kommentar
+#   * Jede nicht-leere Zeile ist ein ist ein Anfang für einen Typischen Dateinamen der automatisch von einer Digitalkamera erzeugt wird
+CIMG # Casio
+DSC_ # Nikon
+DSCF # Fuji
+DSCN # Nikon
+DUW # gewisse Mobiltelefone
+IMG # generisch
+JD # Jenoptik
+MGP # Pentax
+PICT # verschiedene
+ #</pre> <!-- Diese Zeile darf nicht verändert werden!-->',
 
 'upload-proto-error'      => 'Falsches Protokoll',
 'upload-proto-error-text' => 'Die URL muss mit <code>http://</code> oder <code>ftp://</code> beginnen.',
 'upload-file-error'       => 'Interner Fehler',
-'upload-file-error-text'  => 'Bei der Erstellung einer temporären Datei auf dem Server ist ein interner Fehler aufgetreten. Bitte informiere einen System-Administrator.',
+'upload-file-error-text'  => 'Bei der Erstellung einer temporären Datei auf dem Server ist ein interner Fehler aufgetreten.
+Bitte informiere einen [[Special:ListUsers/sysop|System-Administrator]].',
 'upload-misc-error'       => 'Unbekannter Fehler beim Hochladen',
-'upload-misc-error-text'  => 'Beim Hochladen ist ein unbekannter Fehler aufgetreten. Prüfe die URL auf Fehler, den Online-Status der Seite und versuche es erneut. Wenn das Problem weiter besteht, informiere einen System-Administrator.',
+'upload-misc-error-text'  => 'Beim Hochladen ist ein unbekannter Fehler aufgetreten.
+Prüfe die URL auf Fehler, den Online-Status der Seite und versuche es erneut.
+Wenn das Problem weiter besteht, informiere einen [[Special:ListUsers/sysop|System-Administrator]].',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
 'upload-curl-error6'       => 'URL ist nicht erreichbar',
@@ -1289,7 +1314,7 @@
 'upload_source_url'  => ' (gültige, öffentlich zugängliche URL)',
 'upload_source_file' => ' (eine Datei auf deinem Computer)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Diese Spezialseite listet alle hochgeladenen Dateien auf. Standardmäßig werden die zuletzt hochgeladenen Dateien zuerst angezeigt. Durch einen Klick auf die Spaltenüberschriften kann die Sortierung umgedreht werden oder es kann nach einer anderen Spalte sortiert werden.',
 'imagelist_search_for'  => 'Suche nach Datei:',
 'imgfile'               => 'Datei',
@@ -1315,7 +1340,7 @@
 'imagelinks'                     => 'Verwendung',
 'linkstoimage'                   => 'Die {{PLURAL:$1|folgende Seite verwendet|folgenden $1 Seiten verwenden}} diese Datei:',
 'nolinkstoimage'                 => 'Keine Seite benutzt diese Datei.',
-'morelinkstoimage'               => '[[Special:Whatlinkshere/$1|Weitere Links]] für diese Datei.',
+'morelinkstoimage'               => '[[Special:WhatLinksHere/$1|Weitere Links]] für diese Datei.',
 'redirectstofile'                => 'Die {{PLURAL:$1|folgende Datei leitet|folgenden $1 Dateien leiten}} auf diese Datei weiter:',
 'duplicatesoffile'               => 'Die {{PLURAL:$1|folgende Datei ist ein Duplikat|folgenden $1 Dateien sind Duplikate}} dieser Datei:',
 'sharedupload'                   => 'Diese Datei ist ein gemeinsam genutzter Upload und kann von anderen Projekten verwendet werden.',
@@ -1334,24 +1359,24 @@
 # File reversion
 'filerevert'                => 'Zurücksetzen von „$1“',
 'filerevert-legend'         => 'Datei zurücksetzen',
-'filerevert-intro'          => '<span class="plainlinks">Du setzt die Datei \'\'\'[[Media:$1|$1]]\'\'\' auf die [$4 Version vom $2, $3 Uhr] zurück.</span>',
+'filerevert-intro'          => "Du setzt die Datei '''[[Media:$1|$1]]''' auf die [$4 Version vom $2, $3 Uhr] zurück.",
 'filerevert-comment'        => 'Grund:',
 'filerevert-defaultcomment' => 'zurückgesetzt auf die Version vom $1, $2 Uhr',
 'filerevert-submit'         => 'Zurücksetzen',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' wurde auf die [$4 Version vom $2, $3 Uhr] zurückgesetzt.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' wurde auf die [$4 Version vom $2, $3 Uhr] zurückgesetzt.",
 'filerevert-badversion'     => 'Es gibt keine Version der Datei zu dem angegebenen Zeitpunkt.',
 
 # File deletion
 'filedelete'                  => 'Lösche „$1“',
 'filedelete-legend'           => 'Lösche Datei',
 'filedelete-intro'            => "Du löschst die Datei '''„[[Media:$1|$1]]“'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Du löschst von der Datei \'\'\'„[[Media:$1|$1]]“\'\'\' die [$4 Version vom $2, $3 Uhr].</span>',
+'filedelete-intro-old'        => "Du löschst von der Datei '''„[[Media:$1|$1]]“''' die [$4 Version vom $2, $3 Uhr].",
 'filedelete-comment'          => 'Grund:',
 'filedelete-submit'           => 'Löschen',
 'filedelete-success'          => "'''„$1“''' wurde gelöscht.",
 'filedelete-success-old'      => '<span class="plainlinks">Von der Datei \'\'\'„[[Media:$1|$1]]“\'\'\' wurde die Version $2, $3 Uhr gelöscht.</span>',
 'filedelete-nofile'           => "'''„$1“''' ist auf {{SITENAME}} nicht vorhanden.",
-'filedelete-nofile-old'       => "Es gibt von '''„$1“''' keine Version vom $2, $3 Uhr.",
+'filedelete-nofile-old'       => "Es gibt von '''„$1“''' keine archivierte Version mit den angegebenen Attributen.",
 'filedelete-iscurrent'        => 'Du versuchst die aktuelle Version dieser Datei zu löschen. Bitte setze diese vorher auf eine ältere Version zurück.',
 'filedelete-otherreason'      => 'Anderer/ergänzender Grund:',
 'filedelete-reason-otherlist' => 'Anderer Grund',
@@ -1368,18 +1393,15 @@
 'download'           => 'Herunterladen',
 
 # Unwatched pages
-'unwatchedpages'         => 'Nicht beobachtete Seiten',
-'unwatchedpages-summary' => 'Diese Spezialseite zeigt alle Seiten, die von keinem Benutzer auf einer Beobachtungsliste stehen.',
+'unwatchedpages' => 'Nicht beobachtete Seiten',
 
 # List redirects
-'listredirects'         => 'Weiterleitungsliste',
-'listredirects-summary' => 'Diese Spezialseite listet Weiterleitungen auf.',
+'listredirects' => 'Weiterleitungsliste',
 
 # Unused templates
-'unusedtemplates'         => 'Nicht benutzte Vorlagen',
-'unusedtemplates-summary' => 'Diese Seite listet alle Vorlagen auf, die nicht in anderen Seiten eingebunden sind. Überprüfe andere Links zu den Vorlagen, bevor du diese löscht.',
-'unusedtemplatestext'     => '',
-'unusedtemplateswlh'      => 'Andere Links',
+'unusedtemplates'     => 'Unbenutzte Vorlagen',
+'unusedtemplatestext' => 'Diese Seite listet alle Vorlagen auf, die nicht in anderen Seiten eingebunden sind. Überprüfe andere Links zu den Vorlagen, bevor du diese löscht.',
+'unusedtemplateswlh'  => 'Andere Links',
 
 # Random page
 'randompage'         => 'Zufällige Seite',
@@ -1405,7 +1427,7 @@
 Daraus ergeben sich '''$5''' Bearbeitungen pro Seite und '''$6''' Seitenabrufe pro Bearbeitung.
 
 Länge der [http://www.mediawiki.org/wiki/Manual:Job_queue „Job queue“]: '''$7'''",
-'userstatstext'          => "Es gibt '''$1''' {{PLURAL:$1|registrierten|registrierte}} [[Special:Listusers|Benutzer]].
+'userstatstext'          => "Es gibt '''$1''' {{PLURAL:$1|registrierten|registrierte}} [[Special:ListUsers|Benutzer]].
 Davon {{PLURAL:$2|hat|haben}} '''$2''' Benutzer (=$4 %) $5-Rechte.",
 'statistics-mostpopular' => 'Meist besuchte Seiten',
 
@@ -1413,106 +1435,78 @@
 'disambiguationspage'  => 'Template:Begriffsklärung',
 'disambiguations-text' => 'Die folgenden Seiten verlinken auf eine Seite zur Begriffsklärung. Sie sollten statt dessen auf die eigentlich gemeinte Seite verlinken.<br />Eine Seite wird als Begriffsklärungsseite behandelt, wenn [[MediaWiki:Disambiguationspage]] auf sie verlinkt.<br />Links aus Namensräumen werden hier nicht aufgelistet.',
 
-'doubleredirects'         => 'Doppelte Weiterleitungen',
-'doubleredirects-summary' => 'Diese Liste enthält Weiterleitungen, die auf eine weitere Weiterleitungen verlinken.
-Jede Zeile enthält Links zu der ersten und zweiten Weiterleitungs sowie das Ziel der zweiten Weiterleitung, welches für gewöhnlich die gewünschte Zielseite ist,
-auf die bereits die erste Weiterleitung zeigen sollte.',
-'doubleredirectstext'     => '',
+'doubleredirects'            => 'Doppelte Weiterleitungen',
+'doubleredirectstext'        => 'Diese Liste enthält Weiterleitungen, die auf eine weitere Weiterleitungen verlinken.
+Jede Zeile enthält Links zu der ersten und zweiten Weiterleitung sowie das Ziel der zweiten Weiterleitung, welches für gewöhnlich die gewünschte Zielseite ist, auf die bereits die erste Weiterleitung zeigen sollte.',
+'double-redirect-fixed-move' => 'doppelte Weiterleitung aufgelöst: [[$1]] → [[$2]]',
+'double-redirect-fixer'      => 'RedirectBot',
 
-'brokenredirects'         => 'Kaputte Weiterleitungen',
-'brokenredirects-summary' => 'Diese Spezialseite listet Weiterleitungen auf nicht existierende Seiten auf.',
-'brokenredirectstext'     => '',
-'brokenredirects-edit'    => '(bearbeiten)',
-'brokenredirects-delete'  => '(löschen)',
+'brokenredirects'        => 'Kaputte Weiterleitungen',
+'brokenredirectstext'    => 'Diese Spezialseite listet Weiterleitungen auf nicht existierende Seiten auf.',
+'brokenredirects-edit'   => '(bearbeiten)',
+'brokenredirects-delete' => '(löschen)',
 
 'withoutinterwiki'         => 'Seiten ohne Links zu anderen Sprachen',
 'withoutinterwiki-summary' => 'Die folgenden Seiten verlinken nicht auf andere Sprachversionen.',
 'withoutinterwiki-legend'  => 'Präfix',
 'withoutinterwiki-submit'  => 'Zeige',
 
-'fewestrevisions'         => 'Seiten mit den wenigsten Versionen',
-'fewestrevisions-summary' => 'Diese Spezialseite zeigt eine Liste von Seiten mit den wenigsten Bearbeitungen.',
+'fewestrevisions' => 'Seiten mit den wenigsten Versionen',
 
 # Miscellaneous special pages
-'nbytes'                          => '$1 {{PLURAL:$1|Byte|Bytes}}',
-'ncategories'                     => '$1 {{PLURAL:$1|Kategorie|Kategorien}}',
-'nlinks'                          => '{{PLURAL:$1|1 Link|$1 Links}}',
-'nmembers'                        => '{{PLURAL:$1|1 Eintrag|$1 Einträge}}',
-'nrevisions'                      => '{{PLURAL:$1|1 Bearbeitung|$1 Bearbeitungen}}',
-'nviews'                          => '{{PLURAL:$1|1 Abfrage|$1 Abfragen}}',
-'specialpage-empty'               => 'Die Seite enthält aktuell keine Einträge.',
-'lonelypages'                     => 'Verwaiste Seiten',
-'lonelypages-summary'             => 'Diese Spezialseite zeigt Seiten, auf die von keiner anderen Seite verlinkt wird. Diese verwaisten Seiten sind deshalb nicht erwünscht, oder eventuell fragwürdig, weil sie über die normale Navigation durch {{SITENAME}} nie aufgerufen werden können. ',
-'lonelypagestext'                 => '',
-'uncategorizedpages'              => 'Nicht kategorisierte Seiten',
-'uncategorizedpages-summary'      => 'Diese Spezialseite zeigt alle Seiten, die noch keiner Kategorie zugewiesen wurden.',
-'uncategorizedcategories'         => 'Nicht kategorisierte Kategorien',
-'uncategorizedcategories-summary' => 'Diese Spezialseite zeigt alle Kategorien, die selbst noch keiner Kategorie zugewiesen wurden.',
-'uncategorizedimages'             => 'Nicht kategorisierte Dateien',
-'uncategorizedimages-summary'     => 'Diese Spezialseite zeigt alle Dateien, die in keine Kategorie eingeordnet wurden.',
-'uncategorizedtemplates'          => 'Nicht kategorisierte Vorlagen',
-'uncategorizedtemplates-summary'  => 'Diese Spezialseite zeigt alle Vorlagen, die in keine Kategorie eingeordnet wurden.',
-'unusedcategories'                => 'Unbenutzte Kategorien',
-'unusedimages'                    => 'Unbenutzte Dateien',
-'popularpages'                    => 'Beliebteste Seiten',
-'wantedcategories'                => 'Benutzte, aber nicht angelegte Kategorien',
-'wantedcategories-summary'        => 'Diese Spezialseite listet Kategorien auf, die zwar in Seiten verwendet werden, welche aber nicht als Kategorie angelegt worden sind.',
-'wantedpages'                     => 'Gewünschte Seiten',
-'wantedpages-summary'             => 'Diese Spezialseite listet alle Seiten auf, die noch nicht existieren, auf die aber von bestehenden Seiten bereits verlinkt wird.',
-'missingfiles'                    => 'Fehlende Dateien',
-'missingfiles-summary'            => 'Diese Spezialseite listet alle Dateien auf, die auf Seiten verlinkt, jedoch nicht vorhanden sind.',
-'mostlinked'                      => 'Häufig verlinkte Seiten',
-'mostlinked-summary'              => 'Diese Spezialseite zeigt, unabhängig vom Namensraum, alle besonders häufig verlinkten Seiten an.',
-'mostlinkedcategories'            => 'Meistbenutzte Kategorien',
-'mostlinkedcategories-summary'    => 'Diese Spezialseite zeigt eine Liste der meistbenutzten Kategorien.',
-'mostlinkedtemplates'             => 'Meistbenutzte Vorlagen',
-'mostlinkedtemplates-summary'     => 'Diese Spezialseite zeigt eine Liste der meistbenutzten Vorlagen.',
-'mostcategories'                  => 'Meistkategorisierte Seiten',
-'mostcategories-summary'          => 'Diese Spezialseite zeigt besonders häufig kategorisierte Seiten an.',
-'mostimages'                      => 'Meistbenutzte Dateien',
-'mostimages-summary'              => 'Diese Spezialseite zeigt eine Liste der meistbenutzten Dateien.',
-'mostrevisions'                   => 'Seiten mit den meisten Versionen',
-'mostrevisions-summary'           => 'Diese Spezialseite zeigt eine Liste von Seiten mit den meisten Bearbeitungen.',
-'prefixindex'                     => 'Alle Seiten (mit Präfix)',
-'prefixindex-summary'             => 'Diese Spezialseite zeigt alle Seiten, die mit der eingegebenen Zeichenfolge („Präfix“) beginnen. Die Ausgabe kann auf einen Namensraum eingeschränkt werden.',
-'shortpages'                      => 'Kurze Seiten',
-'shortpages-summary'              => 'Diese Liste zeigt die kürzesten Seiten im Hauptnamensraum an. Gezählt werden die Zeichen des Textes wie er im Bearbeitungsfenster dargestellt wird, also in Wiki-Syntax und ohne die Inhalte eingebundener Vorlagen. Grundlage der Zählung ist der UTF-8-kodierte Text, nach dem beispielsweise deutsche Umlaute als zwei Zeichen gelten.',
-'longpages'                       => 'Lange Seiten',
-'longpages-summary'               => 'Diese Liste zeigt die längsten Seiten im Hauptnamensraum an. Gezählt werden die Zeichen des Textes wie er im Bearbeitungsfenster dargestellt wird, also in Wiki-Syntax und ohne die Inhalte eingebundener Vorlagen. Grundlage der Zählung ist der UTF-8-kodierte Text, nach dem beispielsweise deutsche Umlaute als zwei Zeichen gelten.',
-'deadendpages'                    => 'Sackgassenseiten',
-'deadendpages-summary'            => 'Diese Spezialseite zeigt eine Liste von Seiten, die keine Links auf andere Seiten oder nur Links auf noch nicht vorhandene Seiten enthalten.',
-'deadendpagestext'                => '',
-'protectedpages'                  => 'Geschützte Seiten',
-'protectedpages-indef'            => 'Nur unbeschränkt geschützte Seiten zeigen',
-'protectedpages-summary'          => 'Diese Spezialseite zeigt alle vor dem Verschieben oder Bearbeiten geschützten Seiten.',
-'protectedpagestext'              => '',
-'protectedpagesempty'             => 'Aktuell sind keine Seiten mit diesen Parametern geschützt.',
-'protectedtitles'                 => 'Gesperrte Titel',
-'protectedtitles-summary'         => 'Die folgenden Titel wurden zur Neuerstellung gesperrt.',
-'protectedtitlestext'             => '',
-'protectedtitlesempty'            => 'Zur Zeit sind mit den angegebenen Parametern keine Seiten zur Neuerstellung gesperrt.',
-'listusers'                       => 'Benutzerverzeichnis',
-'listusers-summary'               => "Diese Spezialseite listet alle registrierten Benutzer auf; die Gesamtzahl kann [[Special:Statistics|hier]] eingesehen werden. Über das Auswahlfeld ''Gruppe'' lässt sich die Abfrage auf bestimmte Benutzergruppen einschränken.",
-'newpages'                        => 'Neue Seiten',
-'newpages-summary'                => 'Diese Spezialseite listet alle neu erstellten Seiten der letzten Tage auf. Die Ausgabe kann auf einen Namensraum und/oder Benutzernamen eingeschränkt werden.',
-'newpages-username'               => 'Benutzername:',
-'ancientpages'                    => 'Seit längerem unbearbeitete Seiten',
-'ancientpages-summary'            => 'Diese Spezialseite zeigt eine Liste von Seiten, die am längsten nicht mehr geändert worden sind.',
-'move'                            => 'Verschieben',
-'movethispage'                    => 'Seite verschieben',
-'unusedimagestext'                => 'Bitte beachte, dass andere Webseiten diese Datei mit einer direkten URL verlinken können. Diese wird nicht als Verwendung erkannt, so dass die Datei hier aufgeführt wird.',
-'unusedcategoriestext'            => 'Diese Spezialseite zeigt alle Kategorien, die leer sind, also selbst keine Kategorien oder Seiten enthalten.',
-'notargettitle'                   => 'Keine Seite angegeben',
-'notargettext'                    => 'Du hast nicht angegeben, auf welche Seite diese Funktion angewendet werden soll.',
-'nopagetitle'                     => 'Zielseite nicht vorhanden',
-'nopagetext'                      => 'Die angegebene Zielseite ist nicht vorhanden.',
-'pager-newer-n'                   => '{{PLURAL:$1|nächster|nächste $1}}',
-'pager-older-n'                   => '{{PLURAL:$1|vorheriger|vorherige $1}}',
-'suppress'                        => 'Oversight',
+'nbytes'                  => '$1 {{PLURAL:$1|Byte|Bytes}}',
+'ncategories'             => '$1 {{PLURAL:$1|Kategorie|Kategorien}}',
+'nlinks'                  => '{{PLURAL:$1|1 Link|$1 Links}}',
+'nmembers'                => '{{PLURAL:$1|1 Eintrag|$1 Einträge}}',
+'nrevisions'              => '{{PLURAL:$1|1 Bearbeitung|$1 Bearbeitungen}}',
+'nviews'                  => '{{PLURAL:$1|1 Abfrage|$1 Abfragen}}',
+'specialpage-empty'       => 'Die Seite enthält aktuell keine Einträge.',
+'lonelypages'             => 'Verwaiste Seiten',
+'uncategorizedpages'      => 'Nicht kategorisierte Seiten',
+'uncategorizedcategories' => 'Nicht kategorisierte Kategorien',
+'uncategorizedimages'     => 'Nicht kategorisierte Dateien',
+'uncategorizedtemplates'  => 'Nicht kategorisierte Vorlagen',
+'unusedcategories'        => 'Unbenutzte Kategorien',
+'unusedimages'            => 'Unbenutzte Dateien',
+'popularpages'            => 'Beliebteste Seiten',
+'wantedcategories'        => 'Benutzte, aber nicht angelegte Kategorien',
+'wantedpages'             => 'Gewünschte Seiten',
+'missingfiles'            => 'Fehlende Dateien',
+'mostlinked'              => 'Häufig verlinkte Seiten',
+'mostlinkedcategories'    => 'Meistbenutzte Kategorien',
+'mostlinkedtemplates'     => 'Meistbenutzte Vorlagen',
+'mostcategories'          => 'Meistkategorisierte Seiten',
+'mostimages'              => 'Meistbenutzte Dateien',
+'mostrevisions'           => 'Seiten mit den meisten Versionen',
+'prefixindex'             => 'Alle Seiten (mit Präfix)',
+'shortpages'              => 'Kurze Seiten',
+'longpages'               => 'Lange Seiten',
+'deadendpages'            => 'Sackgassenseiten',
+'protectedpages'          => 'Geschützte Seiten',
+'protectedpages-indef'    => 'Nur unbeschränkt geschützte Seiten zeigen',
+'protectedpagestext'      => 'Diese Spezialseite zeigt alle vor dem Verschieben oder Bearbeiten geschützten Seiten.',
+'protectedpagesempty'     => 'Aktuell sind keine Seiten mit diesen Parametern geschützt.',
+'protectedtitles'         => 'Gesperrte Titel',
+'protectedtitlestext'     => 'Die folgenden Titel wurden zur Neuerstellung gesperrt.',
+'protectedtitlesempty'    => 'Zur Zeit sind mit den angegebenen Parametern keine Seiten zur Neuerstellung gesperrt.',
+'listusers'               => 'Benutzerverzeichnis',
+'newpages'                => 'Neue Seiten',
+'newpages-username'       => 'Benutzername:',
+'ancientpages'            => 'Seit längerem unbearbeitete Seiten',
+'move'                    => 'Verschieben',
+'movethispage'            => 'Seite verschieben',
+'unusedimagestext'        => 'Bitte beachte, dass andere Webseiten diese Datei mit einer direkten URL verlinken können. Diese wird nicht als Verwendung erkannt, so dass die Datei hier aufgeführt wird.',
+'unusedcategoriestext'    => 'Diese Spezialseite zeigt alle Kategorien, die leer sind, also selbst keine Kategorien oder Seiten enthalten.',
+'notargettitle'           => 'Keine Seite angegeben',
+'notargettext'            => 'Du hast nicht angegeben, auf welche Seite diese Funktion angewendet werden soll.',
+'nopagetitle'             => 'Zielseite nicht vorhanden',
+'nopagetext'              => 'Die angegebene Zielseite ist nicht vorhanden.',
+'pager-newer-n'           => '{{PLURAL:$1|nächster|nächste $1}}',
+'pager-older-n'           => '{{PLURAL:$1|vorheriger|vorherige $1}}',
+'suppress'                => 'Oversight',
 
 # Book sources
 'booksources'               => 'ISBN-Suche',
-'booksources-summary'       => 'Auf dieser Spezialseite kannst du eine ISBN eingeben und erhältst dann eine Liste mit Onlinekatalogen und Bezugsmöglichkeiten zur gesuchten ISBN. Bindestriche oder Leerzeichen zwischen den Ziffern spielen für die Suche keine Rolle.',
 'booksources-search-legend' => 'Suche nach Bezugsquellen für Bücher',
 'booksources-go'            => 'Suchen',
 'booksources-text'          => 'Dies ist eine Liste mit Links zu Internetseiten, die neue und gebrauchte Bücher verkaufen. Dort kann es auch weitere Informationen über die Bücher geben. {{SITENAME}} ist mit keinem dieser Anbieter geschäftlich verbunden.',
@@ -1528,9 +1522,8 @@
 'logempty'             => 'Keine passenden Einträge.',
 'log-title-wildcard'   => 'Titel beginnt mit …',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Alle Seiten',
-'allpages-summary'  => "Diese Spezialseite listet den Seitenbestand von {{SITENAME}} von A bis Z auf. Sortiert wird alphabetisch, erst Zahlen, dann Großbuchstaben, Kleinbuchstaben und schließlich Sonderzeichen. ''A&nbsp;10'' findet sich vor ''AZ'', der ''Aal'' ist jedoch noch dahinter eingeordnet.",
 'alphaindexline'    => '$1 bis $2',
 'nextpage'          => 'Nächste Seite ($1)',
 'prevpage'          => 'Vorherige Seite ($1)',
@@ -1552,12 +1545,12 @@
 'special-categories-sort-count' => 'Sortierung nach Anzahl',
 'special-categories-sort-abc'   => 'Sortierung nach Alphabet',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Zeige Benutzer ab:',
 'listusers-submit'   => 'Zeige',
 'listusers-noresult' => 'Keinen Benutzer gefunden.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'Benutzergruppen-Rechte',
 'listgrouprights-summary'  => 'Dies ist eine Liste der in diesem Wiki definierten Benutzergruppen und der damit verbundenen Rechte.
 Zusätzliche Informationen über einzelne Rechte können [[{{MediaWiki:Listgrouprights-helppage}}|hier]] gefunden werden.',
@@ -1568,10 +1561,10 @@
 
 # E-mail user
 'mailnologin'     => 'Fehler beim E-Mail-Versand',
-'mailnologintext' => 'Du musst [[{{#special:Userlogin}}|angemeldet sein]] und eine [[{{#special:Confirmemail}}|bestätigte]] E-Mail-Adresse haben, um anderen Benutzern E-Mails schicken zu können.',
+'mailnologintext' => 'Du musst [[Special:UserLogin|angemeldet sein]] und eine bestätigte E-Mail-Adresse in deinen [[Special:Preferences|Einstellungen]] eingetragen haben, um anderen Benutzern E-Mails schicken zu können.',
 'emailuser'       => 'E-Mail an diesen Benutzer',
 'emailpage'       => 'E-Mail an Benutzer',
-'emailpagetext'   => 'Wenn dieser Benutzer eine gültige E-Mail-Adresse angegeben hat, kannst du ihm mit dem untenstehenden Formular eine E-Mail senden. Als Absender wird die E-Mail-Adresse aus deinen Einstellungen eingetragen, damit der Benutzer dir antworten kann.',
+'emailpagetext'   => 'Wenn dieser Benutzer eine gültige E-Mail-Adresse angegeben hat, kannst du ihm mit dem untenstehenden Formular eine E-Mail senden. Als Absender wird die E-Mail-Adresse aus deinen [[Special:Preferences|Einstellungen]] eingetragen, damit der Benutzer dir antworten kann.',
 'usermailererror' => 'Das E-Mail-Objekt gab einen Fehler zurück:',
 'defemailsubject' => '{{SITENAME}}-E-Mail',
 'noemailtitle'    => 'Keine E-Mail-Adresse',
@@ -1585,7 +1578,7 @@
 'emailccsubject'  => 'Kopie deiner Nachricht an $1: $2',
 'emailsent'       => 'E-Mail verschickt',
 'emailsenttext'   => 'Deine E-Mail wurde verschickt.',
-'emailuserfooter' => 'Diese E-Mail wurde von „Benutzer:$1“ an „Benutzer:$2“ mit Hilfe der „E-Mail an diesen Benutzer“-Funktion von {{SITENAME}} versandt.',
+'emailuserfooter' => 'Diese E-Mail wurde von dem {{SITENAME}}-Benutzer „$1“ an „$2“ gesendet.',
 
 # Watchlist
 'watchlist'            => 'Beobachtungsliste',
@@ -1594,16 +1587,16 @@
 'nowatchlist'          => 'Du hast keine Einträge auf deiner Beobachtungsliste.',
 'watchlistanontext'    => 'Du musst dich $1, um deine Beobachtungsliste zu sehen oder Einträge auf ihr zu bearbeiten.',
 'watchnologin'         => 'Du bist nicht angemeldet',
-'watchnologintext'     => 'Du musst [[Special:Userlogin|angemeldet]] sein, um deine Beobachtungsliste zu bearbeiten.',
+'watchnologintext'     => 'Du musst [[Special:UserLogin|angemeldet]] sein, um deine Beobachtungsliste zu bearbeiten.',
 'addedwatch'           => 'Zur Beobachtungsliste hinzugefügt',
 'addedwatchtext'       => 'Die Seite „<nowiki>$1</nowiki>“ wurde zu deiner [[Special:Watchlist|Beobachtungsliste]] hinzugefügt.
 
 Spätere Änderungen an dieser Seite und der dazugehörigen Diskussionsseite werden dort gelistet und
-in der Übersicht der [[Special:Recentchanges|letzten Änderungen]] in Fettschrift dargestellt.
+in der Übersicht der [[Special:RecentChanges|letzten Änderungen]] in Fettschrift dargestellt.
 
 Wenn du die Seite wieder von deiner Beobachtungsliste entfernen möchtest, klicke auf der jeweiligen Seite auf „nicht mehr beobachten“.',
 'removedwatch'         => 'Von der Beobachtungsliste entfernt',
-'removedwatchtext'     => 'Die Seite „<nowiki>$1</nowiki>“ wurde von deiner Beobachtungsliste entfernt.',
+'removedwatchtext'     => 'Die Seite „[[:$1]]“ wurde von deiner [[Special:Watchlist|Beobachtungsliste]] entfernt.',
 'watch'                => 'Beobachten',
 'watchthispage'        => 'Seite beobachten',
 'unwatch'              => 'nicht mehr beobachten',
@@ -1639,7 +1632,7 @@
 'created'                      => 'erzeugt',
 'enotif_subject'               => '[{{SITENAME}}] Die Seite "$PAGETITLE" wurde von $PAGEEDITOR $CHANGEDORCREATED',
 'enotif_lastvisited'           => 'Alle Änderungen auf einen Blick: $1',
-'enotif_lastdiff'              => 'Siehe $1 für diese Änderung.',
+'enotif_lastdiff'              => 'Siehe $1 nach dieser Änderung.',
 'enotif_anon_editor'           => 'Anonymer Benutzer $1',
 'enotif_body'                  => 'Liebe/r $WATCHINGUSERNAME,
 
@@ -1666,7 +1659,7 @@
 'deletepage'                  => 'Seite löschen',
 'confirm'                     => 'Bestätigen',
 'excontent'                   => "Alter Inhalt: '$1'",
-'excontentauthor'             => "Inhalt war: '$1' (einziger Bearbeiter: [[{{ns:User}}:$2|$2]] – [[{{ns:user_talk}}:$2|Diskussion]])",
+'excontentauthor'             => 'Inhalt war: „$1“ (einziger Bearbeiter: [[Special:Contributions/$2|$2]])',
 'exbeforeblank'               => "Inhalt vor dem Leeren der Seite: '$1'",
 'exblank'                     => 'Seite war leer',
 'delete-confirm'              => 'Löschen von „$1“',
@@ -1697,16 +1690,18 @@
 'rollbacklink'                => 'Zurücksetzen',
 'rollbackfailed'              => 'Zurücksetzen gescheitert',
 'cantrollback'                => 'Die Änderung kann nicht zurückgesetzt werden, da es keine früheren Autoren gibt.',
-'alreadyrolled'               => "Das Zurücksetzen der Änderungen von [[{{ns:user}}:$2|$2]] <span style='font-size: smaller'>([[{{ns:user talk}}:$2|Diskussion]], [[{{#special:Contributions}}/$2|Beiträge]])</span> an Seite [[:$1]] war nicht erfolgreich, da in der Zwischenzeit bereits ein anderer Benutzer
-Änderungen an dieser Seite vorgenommen hat.<br />Die letzte Änderung stammt von [[{{ns:user}}:$3|$3]] <span style='font-size: smaller'>([[{{ns:user talk}}:$3|Diskussion]])</span>.",
+'alreadyrolled'               => "Das Zurücksetzen der Änderungen von [[User:$2|$2]] <span style='font-size: smaller'>([[User talk:$2|Diskussion]], [[Special:Contributions/$2|{{int:contribslink}}]])</span> an Seite [[:$1]] war nicht erfolgreich, da in der Zwischenzeit bereits ein anderer Benutzer Änderungen an dieser Seite vorgenommen hat.
+
+Die letzte Änderung stammt von [[User:$3|$3]] <span style='font-size: smaller'>([[User talk:$3|{{int:contribslink}}]])</span>.",
 'editcomment'                 => 'Der Änderungskommentar lautet: „<i>$1</i>“.', # only shown if there is an edit comment
-'revertpage'                  => 'Änderungen von [[User:$2|$2]] ([[{{ns:special}}:Contributions/$2|Beiträge]]) rückgängig gemacht und letzte Version von $1 wiederhergestellt', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'revertpage'                  => 'Änderungen von [[User:$2|$2]] ([[Special:Contributions/$2|Beiträge]]) rückgängig gemacht und letzte Version von [[User:$1|$1]] wiederhergestellt', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'Die Änderungen von $1 wurden rückgängig gemacht und die letzte Version von $2 wurde wiederhergestellt.',
-'sessionfailure'              => 'Es gab ein Problem mit deiner Benutzersitzung.
-Diese Aktion wurde aus Sicherheitsgründen abgebrochen, um eine falsche Zuordnung deiner Änderungen zu einem anderen Benutzer zu verhindern.
+'sessionfailure'              => 'Es gab ein Problem mit der Übertragung deiner Benutzerdaten.
+Diese Aktion wurde daher sicherheitshalber abgebrochen, um eine falsche Zuordnung deiner Änderungen zu einem anderen Benutzer zu verhindern.
 Bitte gehe zurück und versuche den Vorgang erneut auszuführen.',
 'protectlogpage'              => 'Seitenschutz-Logbuch',
-'protectlogtext'              => 'Dies ist das Seitenschutz-Logbuch. Siehe die [[{{ns:special}}:Protectedpages|Liste der geschützten Seiten]] für alle aktuell geschützten Seiten.',
+'protectlogtext'              => 'Dies ist das Seitenschutz-Logbuch.
+Siehe die [[Special:ProtectedPages|Liste der geschützten Seiten]] für alle aktuell geschützten Seiten.',
 'protectedarticle'            => 'schützte „[[$1]]“',
 'modifiedarticleprotection'   => 'änderte den Schutz von „[[$1]]“',
 'unprotectedarticle'          => 'hob den Schutz von „[[$1]]“ auf',
@@ -1779,10 +1774,10 @@
 'undeletedrevisions-files'     => '{{PLURAL:$1|1 Version|$1 Versionen}} und {{PLURAL:$2|1 Datei|$2 Dateien}} wurden wiederhergestellt',
 'undeletedfiles'               => '{{PLURAL:$1|1 Datei wurde|$1 Dateien wurden}} wiederhergestellt',
 'cannotundelete'               => 'Wiederherstellung fehlgeschlagen; jemand anderes hat die Seite bereits wiederhergestellt.',
-'undeletedpage'                => "'''$1''' wurde wiederhergestellt.
+'undeletedpage'                => "'''„$1“''' wurde wiederhergestellt.
 
 Im [[Special:Log/delete|Lösch-Logbuch]] findest du eine Übersicht der gelöschten und wiederhergestellten Seiten.",
-'undelete-header'              => 'Siehe das [[{{ns:special}}:Log/delete|Lösch-Logbuch]] für kürzlich gelöschte Seiten.',
+'undelete-header'              => 'Siehe im [[Special:Log/delete|Lösch-Logbuch]] nach kürzlich gelöschten Seiten.',
 'undelete-search-box'          => 'Suche nach gelöschten Seiten',
 'undelete-search-prefix'       => 'Suchbegriff (Wortanfang ohne Wildcards):',
 'undelete-search-submit'       => 'Suchen',
@@ -1820,7 +1815,6 @@
 # What links here
 'whatlinkshere'            => 'Links auf diese Seite',
 'whatlinkshere-title'      => 'Seiten, die auf „$1“ verlinken',
-'whatlinkshere-summary'    => 'Diese Spezialseite listet alle internen Links auf eine bestimmte Seite auf. Die möglichen Zusätze „(Vorlageneinbindung)“ und „(Weiterleitungsseite)“ zeigen jeweils an, dass die Seite nicht durch einen normalen Wikilink eingebunden ist. ',
 'whatlinkshere-page'       => 'Seite:',
 'linklistsub'              => '(Linkliste)',
 'linkshere'                => "Die folgenden Seiten verlinken auf '''„[[:$1]]“''':",
@@ -1873,9 +1867,9 @@
 'ipbwatchuser'                    => 'Benutzer(diskussions)seite beobachten',
 'badipaddress'                    => 'Die IP-Adresse hat ein falsches Format.',
 'blockipsuccesssub'               => 'Sperre erfolgreich',
-'blockipsuccesstext'              => 'Der Benutzer/die IP-Adresse [[{{ns:special}}:Contributions/$1|$1]] wurde gesperrt und die Aktion im [[{{ns:special}}:Log/block|Benutzersperr-Logbuch]] protokolliert
+'blockipsuccesstext'              => 'Der Benutzer/die IP-Adresse [[Special:Contributions/$1|$1]] wurde gesperrt und die Aktion im [[Special:Log/block|Benutzersperr-Logbuch]] protokolliert.
 
-Zur Aufhebung der Sperre siehe die [[{{ns:special}}:Ipblocklist|Liste aller aktiven Sperren]].',
+Zur Aufhebung der Sperre siehe die [[Special:IPBlockList|Liste aller aktiven Sperren]].',
 'ipb-edit-dropdown'               => 'Sperrgründe bearbeiten',
 'ipb-unblock-addr'                => '„$1“ freigeben',
 'ipb-unblock'                     => 'IP-Adresse/Benutzer freigeben',
@@ -1886,10 +1880,9 @@
 'ipusubmit'                       => 'Freigeben',
 'unblocked'                       => '[[User:$1|$1]] wurde freigegeben',
 'unblocked-id'                    => 'Sperr-ID $1 wurde freigegeben',
-'ipblocklist'                     => 'Liste gesperrter Benutzer/IP-Adressen',
+'ipblocklist'                     => 'Gesperrte IP-Adressen und Benutzernamen',
 'ipblocklist-legend'              => 'Suche nach einem gesperrten Benutzer',
 'ipblocklist-username'            => 'Benutzername oder IP-Adresse:',
-'ipblocklist-summary'             => "Diese Spezialseite führt – ergänzend zum [[Special:Log/block|Benutzersperr-Logbuch]], das alle manuell vorgenommenen (Ent-)Sperrungen protokolliert – die '''aktuell''' gesperrten Benutzer und IP-Adressen auf, einschließlich automatisch gesperrter IP-Adressen in anonymisierter Form.",
 'ipblocklist-submit'              => 'Suchen',
 'blocklistline'                   => '$1, $2 sperrte $3 (bis $4)',
 'infiniteblock'                   => 'unbegrenzt',
@@ -1903,10 +1896,12 @@
 'blocklink'                       => 'Sperren',
 'unblocklink'                     => 'Freigeben',
 'contribslink'                    => 'Beiträge',
-'autoblocker'                     => 'Automatische Sperre, da du eine gemeinsame IP-Adresse mit [[Benutzer:$1]] benutzt. Grund: „$2“.',
+'autoblocker'                     => 'Automatische Sperre, da du eine gemeinsame IP-Adresse mit [[User:$1|Benutzer:$1]] benutzt. Grund: „$2“.',
 'blocklogpage'                    => 'Benutzersperr-Logbuch',
 'blocklogentry'                   => 'sperrte „[[$1]]“ für den Zeitraum: $2 $3',
-'blocklogtext'                    => 'Dies ist das Logbuch über Sperrungen und Entsperrungen von Benutzern und IP-Adressen. Automatisch gesperrte IP-Adressen werden nicht erfasst. Siehe die [[{{ns:special}}:Ipblocklist|{{int:ipblocklist}}]] für alle aktiven Sperren.',
+'blocklogtext'                    => 'Dies ist das Logbuch über Sperrungen und Entsperrungen von Benutzern und IP-Adressen.
+Automatisch gesperrte IP-Adressen werden nicht erfasst.
+Siehe die [[Special:IPBlockList|{{int:ipblocklist}}]] für alle aktiven Sperren.',
 'unblocklogentry'                 => 'hat die Sperre von „[[$1]]“ aufgehoben',
 'block-log-flags-anononly'        => 'nur Anonyme',
 'block-log-flags-nocreate'        => 'Erstellung von Benutzerkonten gesperrt',
@@ -1940,7 +1935,7 @@
 'locknoconfirm'       => 'Du hast das Bestätigungsfeld nicht markiert.',
 'lockdbsuccesssub'    => 'Datenbank wurde erfolgreich gesperrt',
 'unlockdbsuccesssub'  => 'Datenbank wurde erfolgreich freigegeben',
-'lockdbsuccesstext'   => 'Die {{SITENAME}}-Datenbank wurde gesperrt.<br />Bitte gib die Datenbank [[Special:Unlockdb|wieder frei]], sobald die Wartung abgeschlossen ist.',
+'lockdbsuccesstext'   => 'Die {{SITENAME}}-Datenbank wurde gesperrt.<br />Bitte gib die Datenbank [[Special:UnlockDB|wieder frei]], sobald die Wartung abgeschlossen ist.',
 'unlockdbsuccesstext' => 'Die {{SITENAME}}-Datenbank wurde freigegeben.',
 'lockfilenotwritable' => 'Die Datenbank-Sperrdatei ist nicht beschreibbar. Zum Sperren oder Freigeben der Datenbank muss diese für den Webserver beschreibbar sein.',
 'databasenotlocked'   => 'Die Datenbank ist nicht gesperrt.',
@@ -1948,7 +1943,17 @@
 # Move page
 'move-page'               => 'Verschiebe „$1“',
 'move-page-legend'        => 'Seite verschieben',
-'movepagetext'            => 'Mit diesem Formular kannst du eine Seite umbenennen (mitsamt allen Versionen). Der alte Titel wird zum neuen weiterleiten. Links auf den alten Titel werden nicht geändert.',
+'movepagetext'            => "Mit diesem Formular kannst du eine Seite umbenennen (mitsamt allen Versionen).
+Der alte Titel wird zum neuen weiterleiten.
+Du kannst Weiterleitungen, die auf den Originaltitel verlinken, automatisch korrigieren lassen.
+Falls du dies nicht tust, prüfe auf [[Special:DoubleRedirects|doppelte]] oder [[Special:BrokenRedirects|defekte Weiterleitungen]].
+Du bist dafür verantwortlich, dass Links weiterhin auf das korrekte Ziel zeigen.
+
+Die Seite wird '''nicht''' verschoben, wenn es bereits eine Seite mit demselben Namen gibt, sofern diese nicht leer oder eine Weiterleitung ohne Versionsgeschichte ist. Dies bedeutet, dass du die Seite zurück verschieben kannst, wenn du einen Fehler gemacht hast. Du kannst hingegen keine Seite überschreiben.
+
+'''Warnung'''
+Die Verschiebung kann weitreichende und unerwartete Folgen für beliebte Seiten haben.
+Du solltest daher die Konsequenzen verstanden haben, bevor du fortfährst.",
 'movepagetalktext'        => "Die dazugehörige Diskussionsseite wird, sofern vorhanden, mitverschoben, '''es sei denn:'''
 *Es existiert bereits eine Diskussionsseite mit diesem Namen, oder
 *du wählst die unten stehende Option ab.
@@ -1957,8 +1962,6 @@
 
 Bitte den '''neuen''' Titel unter '''Ziel''' eintragen, darunter die Umbenennung bitte '''begründen.'''",
 'movearticle'             => 'Seite verschieben:',
-'movenologin'             => 'Du bist nicht angemeldet',
-'movenologintext'         => 'Du musst ein registrierter Benutzer und [[Special:Userlogin|angemeldet]] sein, um eine Seite zu verschieben.',
 'movenotallowed'          => 'Du hast in diesem Wiki keine Berechtigung, Seiten zu verschieben.',
 'newtitle'                => 'Ziel:',
 'move-watch'              => 'Diese Seite beobachten',
@@ -1969,7 +1972,7 @@
 'cantmove-titleprotected' => 'Die Verschiebung kann nicht durchgeführt werden, da der Zieltitel zur Erstellung gesperrt ist.',
 'talkexists'              => 'Die Seite selbst wurde erfolgreich verschoben, aber die zugehörige Diskussions-Seite nicht, da bereits eine mit dem neuen Titel existiert. Bitte gleiche die Inhalte von Hand ab.',
 'movedto'                 => 'verschoben nach',
-'movetalk'                => 'Die Diskussionsseite mitverschieben, wenn möglich.',
+'movetalk'                => 'Die Diskussionsseite mitverschieben, wenn möglich',
 'move-subpages'           => 'Alle Unterseiten, falls vorhanden, mitverschieben',
 'move-talk-subpages'      => 'Alle Unterseiten von Diskussionsseiten, falls vorhanden, mitverschieben',
 'movepage-page-exists'    => 'Die Seite „$1“ ist bereits vorhanden und kann nicht automatisch überschrieben werden.',
@@ -1985,7 +1988,7 @@
 'delete_and_move'         => 'Löschen und Verschieben',
 'delete_and_move_text'    => '==Zielseite vorhanden, löschen?==
 
-Die Seite „[[$1]]“ existiert bereits. Möchtest du diese löschen, um die Seite verschieben zu können?',
+Die Seite „[[:$1]]“ existiert bereits. Möchtest du diese löschen, um die Seite verschieben zu können?',
 'delete_and_move_confirm' => 'Zielseite für die Verschiebung löschen',
 'delete_and_move_reason'  => 'gelöscht, um Platz für Verschiebung zu machen',
 'selfmove'                => 'Ursprungs- und Zielname sind gleich; eine Seite kann nicht auf sich selbst verschoben werden.',
@@ -1993,6 +1996,7 @@
 'imagenocrossnamespace'   => 'Dateien können nicht aus dem {{ns:image}}-Namensraum heraus verschoben werden',
 'imagetypemismatch'       => 'Die neue Dateierweiterung ist nicht mit der alten identisch',
 'imageinvalidfilename'    => 'Der Ziel-Dateiname ist ungültig',
+'fix-double-redirects'    => 'Nach dem Verschieben doppelte Weiterleitungen auflösen',
 
 # Export
 'export'            => 'Seiten exportieren',
@@ -2039,7 +2043,7 @@
 'import-interwiki-history'   => 'Importiere alle Versionen dieser Seite',
 'import-interwiki-submit'    => 'Import',
 'import-interwiki-namespace' => 'Importiere die Seite in den Namensraum:',
-'importtext'                 => 'Auf dieser Spezialseite können über [[{{ns:special}}:Export]] exportierte Seiten in dieses Wiki importiert werden.',
+'importtext'                 => 'Auf dieser Spezialseite können über die [[Special:Export|Exportfunktion]] im Quellwiki exportierte Seiten in dieses Wiki importiert werden.',
 'importstart'                => 'Importiere Seite …',
 'import-revision-count'      => '– {{PLURAL:$1|1 Version|$1 Versionen}}',
 'importnopages'              => 'Keine Seite zum Importieren vorhanden.',
@@ -2098,7 +2102,7 @@
 'tooltip-n-mainpage'              => 'Hauptseite anzeigen',
 'tooltip-n-portal'                => 'Über das Portal, was du tun kannst, wo was zu finden ist',
 'tooltip-n-currentevents'         => 'Hintergrundinformationen zu aktuellen Ereignissen',
-'tooltip-n-recentchanges'         => 'Liste der letzten Änderungen in {{SITENAME}}.',
+'tooltip-n-recentchanges'         => 'Liste der letzten Änderungen in {{SITENAME}}',
 'tooltip-n-randompage'            => 'Zufällige Seite',
 'tooltip-n-help'                  => 'Hilfeseite anzeigen',
 'tooltip-t-whatlinkshere'         => 'Liste aller Seiten, die hierher zeigen',
@@ -2210,10 +2214,11 @@
 'markedaspatrollederror-noautopatrol' => 'Es ist nicht erlaubt, eigene Bearbeitungen als kontrolliert zu markieren.',
 
 # Patrol log
-'patrol-log-page' => 'Kontroll-Logbuch',
-'patrol-log-line' => 'hat $1 von „$2“ als kontrolliert markiert $3',
-'patrol-log-auto' => '(automatisch)',
-'patrol-log-diff' => 'Version $1',
+'patrol-log-page'   => 'Kontroll-Logbuch',
+'patrol-log-header' => 'Dies ist das Kontroll-Logbuch.',
+'patrol-log-line'   => 'hat $1 von „$2“ als kontrolliert markiert $3',
+'patrol-log-auto'   => '(automatisch)',
+'patrol-log-diff'   => 'Version $1',
 
 # Image deletion
 'deletedrevision'                 => 'alte Version: $1',
@@ -2242,7 +2247,7 @@
 'show-big-image'       => 'Version in höherer Auflösung',
 'show-big-image-thumb' => '<small>Größe der Voransicht: $1 × $2 Pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Neue Dateien',
 'imagelisttext'         => "Hier ist eine Liste von '''$1''' {{PLURAL:$1|Datei|Dateien}}, sortiert $2.",
 'newimages-summary'     => 'Diese Spezialseite zeigt die zuletzt hochgeladenen Dateien an.',
@@ -2395,12 +2400,12 @@
 'exif-unknowndate' => 'Unbekanntes Datum',
 
 'exif-orientation-1' => 'Normal', # 0th row: top; 0th column: left
-'exif-orientation-2' => 'Horizontal gedreht', # 0th row: top; 0th column: right
+'exif-orientation-2' => 'Horizontal gespiegelt', # 0th row: top; 0th column: right
 'exif-orientation-3' => 'Um 180° gedreht', # 0th row: bottom; 0th column: right
-'exif-orientation-4' => 'Vertikal gedreht', # 0th row: bottom; 0th column: left
-'exif-orientation-5' => 'Entgegen dem Uhrzeigersinn um 90° gedreht und vertikal gewendet', # 0th row: left; 0th column: top
+'exif-orientation-4' => 'Vertikal gespiegelt', # 0th row: bottom; 0th column: left
+'exif-orientation-5' => 'Entgegen dem Uhrzeigersinn um 90° gedreht und dann vertikal gespiegelt', # 0th row: left; 0th column: top
 'exif-orientation-6' => 'Um 90° in Uhrzeigersinn gedreht', # 0th row: right; 0th column: top
-'exif-orientation-7' => 'Um 90° in Uhrzeigersinn gedreht und vertikal gewendet', # 0th row: right; 0th column: bottom
+'exif-orientation-7' => 'Um 90° in Uhrzeigersinn gedreht und dann vertikal gespiegelt', # 0th row: right; 0th column: bottom
 'exif-orientation-8' => 'Um 90° entgegen dem Uhrzeigersinn gedreht', # 0th row: left; 0th column: bottom
 
 'exif-planarconfiguration-1' => 'Grobformat',
@@ -2520,7 +2525,7 @@
 
 # External editor support
 'edit-externally'      => 'Diese Datei mit einem externen Programm bearbeiten',
-'edit-externally-help' => '<span class="plainlinks">Siehe die [http://meta.wikimedia.org/wiki/Help:External_editors Installationsanweisungen] für weitere Informationen</span>',
+'edit-externally-help' => 'Siehe die [http://www.mediawiki.org/wiki/Manual:External_editors Installationsanweisungen] für weitere Informationen',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'alle',
@@ -2583,13 +2588,13 @@
 'deletedwhileediting' => '<span class="error">Achtung: Diese Seite wurde gelöscht, nachdem du angefangen hast, sie zu bearbeiten!
 Siehe im [{{fullurl:Special:Log|type=delete&page=}}{{FULLPAGENAMEE}} Lösch-Logbuch] nach,
 warum die Seite gelöscht wurde. Wenn du die Seite speicherst, wird sie neu angelegt.</span>',
-'confirmrecreate'     => "Benutzer [[User:$1|$1]] ([[User_talk:$1|Diskussion]]) hat diese Seite gelöscht, nachdem du angefangen hast, sie zu bearbeiten. Die Begründung lautete:
-''$2''
+'confirmrecreate'     => "Benutzer [[User:$1|$1]] ([[User talk:$1|Diskussion]]) hat diese Seite gelöscht, nachdem du angefangen hast, sie zu bearbeiten. Die Begründung lautete:
+:''$2''
 Bitte bestätige, dass du diese Seite wirklich neu erstellen möchten.",
 'recreate'            => 'Erneut anlegen',
 
 # HTML dump
-'redirectingto' => 'Weitergeleitet nach [[$1]]',
+'redirectingto' => 'Weitergeleitet nach [[:$1]]',
 
 # action=purge
 'confirm_purge'        => 'Diese Seite aus dem Server-Cache löschen? $1',
@@ -2635,8 +2640,8 @@
 'livepreview-error'   => 'Verbindung nicht möglich: $1 „$2“. Bitte die normale Vorschau benutzen.',
 
 # Friendlier slave lag warnings
-'lag-warn-normal' => 'Bearbeitungen der letzten $1 Sekunden werden in dieser Liste noch nicht angezeigt.',
-'lag-warn-high'   => 'Auf Grund hoher Datenbankauslastung werden die Bearbeitungen der letzten $1 Sekunden in dieser Liste noch nicht angezeigt.',
+'lag-warn-normal' => 'Bearbeitungen der letzten {{PLURAL:$1|Sekunde|$1 Sekunden}} werden in dieser Liste noch nicht angezeigt.',
+'lag-warn-high'   => 'Auf Grund hoher Datenbankauslastung werden die Bearbeitungen der letzten {{PLURAL:$1|Sekunde|$1 Sekunden}} in dieser Liste noch nicht angezeigt.',
 
 # Watchlist editor
 'watchlistedit-numitems'       => 'Deine Beobachtungsliste enthält {{PLURAL:$1|1 Eintrag |$1 Einträge}}, Diskussionsseiten werden nicht gezählt.',
@@ -2687,7 +2692,7 @@
 'version-software-product'         => 'Produkt',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Dateipfad',
 'filepath-page'    => 'Datei:',
 'filepath-submit'  => 'Pfad suchen',
@@ -2709,7 +2714,6 @@
 
 # Special:SpecialPages
 'specialpages'                   => 'Spezialseiten',
-'specialpages-summary'           => 'Diese Seite bietet einen Überblick aller Spezialseiten. Diese werden automatisch generiert und können nicht bearbeitet werden.',
 'specialpages-note'              => '----
 * Spezialseiten für Jedermann
 * <span class="mw-specialpagerestricted">Spezialseiten für Benutzer mit erweiterten Rechten</span>',
@@ -2726,7 +2730,7 @@
 'specialpages-group-redirects'   => 'Weiterleitende Spezialseiten',
 'specialpages-group-spam'        => 'Spam-Werkzeuge',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Leere Seite',
 'intentionallyblankpage' => 'Diese Seite ist absichtlich ohne Inhalt. Sie wird für Benchmarks verwendet.',
 
Index: languages/messages/MessagesTpi.php
===================================================================
--- languages/messages/MessagesTpi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTpi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,18 +5,10 @@
  * @file
  *
  * @author Wantok
- * @author Niklas Laxström
- * @author לערי ריינהארט
- * @author Siebrand
  * @author Wytukaze
- * @author Wantok
  * @author לערי ריינהארט
- * @author Siebrand
- * @author Wytukaze
  */
 
-
-
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Putim lain ananit long ol link:',
@@ -176,7 +168,7 @@
 'movethispage'            => 'Surikim dispela pes',
 'unusedcategoriestext'    => 'Ol dispela grup istap yet, tasol i no gat wanpela pes o grup i stap insait long ol.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages' => 'Olgeta pes',
 
 # Special:Categories
@@ -189,11 +181,11 @@
 'watchlistfor'         => "(bilong '''$1''')",
 'nowatchlist'          => 'Nogat wanpela samting istap long lukautbuk bilong yu.',
 'watchlistanontext'    => 'Yu mas $1 long lukim o senisim ol samting long lukautbuk bilong yu.',
-'watchnologintext'     => 'Yu mas [[Special:Userlogin|login]] long senisim lukautbuk bilong yu.',
+'watchnologintext'     => 'Yu mas [[Special:UserLogin|login]] long senisim lukautbuk bilong yu.',
 'addedwatch'           => 'Igo insait long lukautbuk',
 'addedwatchtext'       => "Pes \"[[:\$1]]\" igo insait long [[Special:Watchlist|lukautbuk]] bilong yu nau.
 Bai yu lukim ol nupela senis long dispela pes, na pes toktok bilong en, long lukautbuk, 
-na dispela pes bai kamap '''strongpela''' long [[Special:Recentchanges|pes bilong ol nupela senis]]
+na dispela pes bai kamap '''strongpela''' long [[Special:RecentChanges|pes bilong ol nupela senis]]
 na olsem bai isi long lukim em.
 
 Sapos yu laik rausim dispela pes long lukautbuk bilong yu bihain, paitim \"Pinis long lukautim\" taim yu lukim pes.",
Index: languages/messages/MessagesLad.php
===================================================================
--- languages/messages/MessagesLad.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLad.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,10 +5,9 @@
  * @file
  *
  * @author ILVI
+ * @author Runningfridgesrule
  * @author Taichi
  * @author לערי ריינהארט
- * @author SPQRobin
- * @author Runningfridgesrule
  */
 
 $fallback = 'es';
@@ -212,7 +211,7 @@
 'ancientpages' => 'Artikolos mas viejos',
 'move'         => 'Trasladar',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Todas las pajinas',
 'alphaindexline' => '$1 a $2',
 'allarticles'    => 'Todos los artikolos',
@@ -280,7 +279,7 @@
 'recreate' => 'Krear de muevo',
 
 # HTML dump
-'redirectingto' => 'Redirijiendo a [[$1]]...',
+'redirectingto' => 'Redirijiendo a [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'Akseptár',
Index: languages/messages/MessagesLg.php
===================================================================
--- languages/messages/MessagesLg.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLg.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,7 +5,6 @@
  * @file
  *
  * @author Kizito
- * @author Siebrand
  */
 
 $messages = array(
@@ -269,7 +268,7 @@
 'templatesused'          => 'Olupapula luno entiba ze lukozesa ze:',
 'template-protected'     => '(luno lusibidwa)',
 'template-semiprotected' => '(ebimu ku lupapula luno bisibidwa)',
-'nocreatetext'           => "Ku {{SITENAME}} tosobola okukolawo empapula mpya nga tokozesa buyinza obw'obwamemba. Kati oyinza kugenda n'okyusamu olupapula olulala olwakolebwa dda, oba oyinza [[Special:Userlogin|okufuna obuyinza obw'obwamemba]].",
+'nocreatetext'           => "Ku {{SITENAME}} tosobola okukolawo empapula mpya nga tokozesa buyinza obw'obwamemba. Kati oyinza kugenda n'okyusamu olupapula olulala olwakolebwa dda, oba oyinza [[Special:UserLogin|okufuna obuyinza obw'obwamemba]].",
 'recreate-deleted-warn'  => "'''Kulabula: Ogenda okuzzaawo olupapuka olwagyibwawo.'''
 
 Okakasa nti kisaanira okuluzzaawo?
@@ -340,7 +339,7 @@
 'upload'        => 'Teekayo fayiro',
 'uploadlogpage' => 'Likooda eya fayiro eziteekedwa ku wiki',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_user' => 'Memba',
 
 # Image description page
@@ -372,7 +371,7 @@
 'specialloguserlabel' => 'Memba:',
 'log'                 => "Empapula ez'ebyafaayo eby'emirimu egitaligimu",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Empapula zonna',
 'alphaindexline'    => 'okuva ku $1 kutuuka ku $2',
 'allpagesfrom'      => 'Laga empapula okuva ku:',
@@ -393,7 +392,7 @@
 'addedwatch'     => "Kigattiddwa ku by'ogoberera",
 'addedwatchtext' => 'Olupapula "[[:$1]]" kati luli mu [[Special:Watchlist|by\'ogoberera]].
 Buli olupapula olwo oba olw\'emboozi lwalwo lwe binaakyuusibwamu, enkyuukakyuka ezo
-zijjakulabika wano. Era erinnya lyalwo mu [[Special:Recentchanges|lukalala olw\'ebyakakyuuisbwa]]
+zijjakulabika wano. Era erinnya lyalwo mu [[Special:RecentChanges|lukalala olw\'ebyakakyuuisbwa]]
 lijja okuba mu nukuta enziggumivu oyanguyirwe okuliraba.
 
 Bw\'oba oyagala okulekerawo okulugoberera, nyiga ku kigambo "Suula" awo ku bbali.',
@@ -542,7 +541,7 @@
 
 # External editor support
 'edit-externally'      => 'Fayiro eno gikolereko mu pulogulamu endala',
-'edit-externally-help' => '[http://meta.wikimedia.org/wiki/Help:External_editors Nyiga wano] okuyiga ebisingawo ku kukozesa pulogulamu endala okukola enkyukakyuka.',
+'edit-externally-help' => '[http://www.mediawiki.org/wiki/Manual:External_editors Nyiga wano] okuyiga ebisingawo ku kukozesa pulogulamu endala okukola enkyukakyuka.',
 
 # 'all' in various places, this might be different for inflected languages
 'namespacesall' => 'Gonna',
Index: languages/messages/MessagesZh_hk.php
===================================================================
--- languages/messages/MessagesZh_hk.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesZh_hk.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -36,7 +36,7 @@
 # Tooltip help for the actions
 'tooltip-t-print' => '這個頁面的可打印版本',
 
-# Special:Newimages
+# Special:NewImages
 'showhidebots' => '($1機械人)',
 
 );
Index: languages/messages/MessagesTa.php
===================================================================
--- languages/messages/MessagesTa.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTa.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,12 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author Trengarasu
  * @author Mayooranathan
- * @author Siebrand
  * @author Sundar
+ * @author Trengarasu
  * @author לערי ריינהארט
- * @author Jon Harald Søby
  */
 
 $skinNames = array(
@@ -325,7 +323,7 @@
 'nospecialpagetext' => "<big>'''நீங்கள் செல்லுபடியற்ற சிறப்புப் பக்கமொன்றை கோரியிருக்கிறீர்கள்.'''</big>
 
 
-செல்லுபடியான எல்லாச் சிறப்புப் பக்கங்களினதும் பட்டியல் [[Special:Specialpages|இங்கே]] தரப்பட்டுள்ளது.",
+செல்லுபடியான எல்லாச் சிறப்புப் பக்கங்களினதும் பட்டியல் [[Special:SpecialPages|இங்கே]] தரப்பட்டுள்ளது.",
 
 # General errors
 'error'                => 'தவறு',
@@ -549,10 +547,6 @@
 'blockededitsource'         => "'''$1''' பக்கத்துக்கான '''உங்கள் தொகுப்புகள்''' கீழே கொடுக்கப்பட்டுள்ளன:",
 'whitelistedittitle'        => 'தொகுப்பதற்கு புகுபதிகை செய்யப்படவேண்டும்.',
 'whitelistedittext'         => 'நீங்கள் பக்கங்களத் தொகுக்க $1 செய்யவேண்டும்.',
-'whitelistreadtitle'        => 'வாசிப்பதற்கு புகுபதிகை செய்ய வேண்டும்',
-'whitelistreadtext'         => 'பக்கங்களை வாசிக்க நீங்கள் [[Special:Userlogin|புகுபதிகை]] செய்யவேண்டும்.',
-'whitelistacctitle'         => 'கணக்கொன்று உருவாக்குவதற்கு நீங்கள் அனுமதிக்கப்படவில்லை.',
-'whitelistacctext'          => '{{SITENAME}} தளத்தில் கணக்குகளைத் தொடங்க நீங்கள் [[Special:Userlogin|புகுபதிகைச்]] செய்து உரிய அனுமதிகளைக் கொண்டிருக்க வேண்டும்.',
 'confirmedittitle'          => 'தொகுப்புக்கு மின்னஞ்சல் உறுதிப்படுத்தப்பட வேண்டும்',
 'confirmedittext'           => 'நீங்கள் பக்கங்களைத் தொகுக்க முன்னர் மின்னஞ்சல் முகவரியை உறுதிப்படுத்த வேண்டும். உங்கள் [[Special:Preferences|விருப்பத்தேர்வுகள்]] பக்கத்தில் செல்லுபடியான மின்னஞ்சலைக் கொடுத்து அதனை உறுதிப்படுத்துங்கள்.',
 'nosuchsectiontitle'        => 'அப்படியொரு பகுதி கிடையாது',
@@ -581,9 +575,9 @@
 'session_fail_preview'      => '<strong>உங்கள் அமர்வுத் தரவுகள் அழிந்துப்போனமையால் உங்கள் தொகுப்பை செயற்படுத்த முடியவில்லை. அருள் கூர்ந்து மீண்டும் முயலவும். அதுவும் பலனளிக்காவிட்டால் விடுபதிகைச் செய்து மீண்டும் புகுபதிகைச் செய்யவும்</strong>',
 'session_fail_preview_html' => '<strong>உங்கள் அமர்வுத் தரவுகள் அழிந்துப்போனமையால் உங்கள் தொகுப்பை செயற்படுத்த முடியவில்லை.</strong>
 
-கரணியம்:{{SITENAME}} தளத்தில் எச்.டி.எம்.எல். முடுக்கிவிடப்பட்டுள்ளமையால் ஜாவா நிரல்த் தாக்குதல்களைத் தவிர்க்கும் பொருட்டு முன்தோற்றம் முடக்கப்பட்டுள்ளது.
+கரணியம்:{{SITENAME}} தளத்தில் எச்.டி.எம்.எல். முடுக்கிவிடப்பட்டுள்ளமையால் ஜாவா நிரல் தாக்குதல்களைத் தவிர்க்கும் பொருட்டு முன்தோற்றம் முடக்கப்பட்டுள்ளது.
 
-<strong>இது ஒரு முறையான தொகுப்பாயின், அருள் கூர்ந்து மீண்டும் முயலவும். அதுவும் பலனளிக்காவிட்டால் விடுபதிகைச் செய்து மீண்டும் புகுபதிகைச் செய்யவும்</strong>',
+<strong>இது ஒரு முறையான தொகுப்பாயின், அருள் கூர்ந்து மீண்டும் முயலவும். அதுவும் பலனளிக்காவிட்டால் விடுபதிகை செய்து மீண்டும் புகுபதிகை செய்யவும்</strong>',
 'token_suffix_mismatch'     => '<strong>உங்கள் தொகுப்பினுள் சேவையாளர் நிறுத்தக்குறியீடுகளை செறுகியுள்ளனதன் காரணமாக உங்களது தொகுப்பு நிராகரிக்கப்பட்டுள்ளது. இது வலைத்தளத்தை மையமாகக் கொண்ட அடையாளம் காட்டாத புரொக்சி சேவைகளிலிருந்து தொகுக்கும் போது ஏற்படலாம்.</strong>',
 'editing'                   => 'தொகுப்பு $1',
 'editingsection'            => 'தொகுப்பு $1 (பிரிவு)',
@@ -619,7 +613,7 @@
 'hiddencategories'          => 'இப்பக்கம் {{PLURAL:$1|ஒரு மறைக்கப்பட்ட பகுப்பில்|$1 மறைக்கப்பட்ட பகுப்புகளில்}} அடங்குகிறது:',
 'nocreatetitle'             => 'பக்கத் தொடக்கம் மட்டுப்படுத்தப்பட்டுள்ளது',
 'nocreatetext'              => '{{SITENAME}} புதிய பக்கங்களை ஆக்குவதற்கான அனுமதியை மட்டுப்படுத்தியுள்ளது.
-நீங்கள் ஏற்கனவே இருக்கும் பக்கங்களைத் தொகுக்க முடியும் அல்லது [[Special:Userlogin|புகுபதிகை செய்யவும் அல்லது கணக்கொன்றை தொடங்குங்கள்]].',
+நீங்கள் ஏற்கனவே இருக்கும் பக்கங்களைத் தொகுக்க முடியும் அல்லது [[Special:UserLogin|புகுபதிகை செய்யவும் அல்லது கணக்கொன்றை தொடங்குங்கள்]].',
 'nocreate-loggedin'         => '{{SITENAME}} தளத்தில் புதியப் பக்கங்களைத் தொடங்குவதற்கு உங்களுக்கு அனுமதி கிடையாது.',
 'permissionserrors'         => 'அனுமதி தவறுகள்',
 'permissionserrorstext'     => 'பின்வரும் {{PLURAL:$1|காரணத்துக்காக|காரணங்களுக்காக}} நீங்கள் அதைச் செய்ய முடியாது:',
@@ -729,7 +723,7 @@
 # Suppression log
 'suppressionlog'     => 'அடக்கல் பதிகை',
 'suppressionlogtext' => 'பின்வருவது நிர்வாகிகளிடமிருந்து மறைக்கப்பட்ட நீக்கல்களதும் தடுப்புகளதும் பட்டியலாகும்.
-நடைமுறையிலுள்ள தடுப்புகளைக் காண [[Special:Ipblocklist|ஐ.பி. தடைப் பட்டியலைப்]] பார்க்க',
+நடைமுறையிலுள்ள தடுப்புகளைக் காண [[Special:IPBlockList|ஐ.பி. தடைப் பட்டியலைப்]] பார்க்க',
 
 # History merging
 'mergehistory'                     => 'பக்க வரலாறுகளை இணை',
@@ -801,6 +795,7 @@
 'nonefound'                 => '<strong>குறிப்பு</strong>: "அல்லது", "கொண்ட" போன்ற பொதுவான, அட்டவணைப்படுத்தப்படாத, சொற்களைத் தேடும்போதோ அல்லது ஒன்றுக்கு மேற்பட்ட தேடலுக்கான சொற்களைக் குறிப்பிடுதல் தேடல்கள் தோல்வியில் முடிய காரணமாகிறது (எல்லாத் தேடுதலுக்கான சொற்களையும் கொண்ட பக்கங்கள் மட்டுமே தேடல் முடிவில் காணப்படும்).',
 'powersearch'               => 'மேம்படுத்தப்பட்ட தேடல்',
 'powersearch-legend'        => 'மேம்பட்ட தேடல்',
+'powersearch-redir'         => 'வழிமாற்றுகளைப் பட்டியலிடவும்',
 'search-external'           => 'வெளித்தேடல்',
 'searchdisabled'            => '{{SITENAME}} தளத்தின் தேடல் வசதிகள் தற்காலிகமாக முடக்கப்பட்டுள்ளது. அதுவரை நீங்கள் கீழேயுள்ள கூகிள் தேடலைப் பயன்படுத்தலாம். இது சில சமயம் இற்றைப்படுத்தப்படாததாய் இருக்கக்கூடும்.',
 
@@ -809,7 +804,7 @@
 'mypreferences'            => 'என் விருப்பத்தேர்வுகள்',
 'prefs-edits'              => 'தொகுப்புகளின் எண்ணிக்கை:',
 'prefsnologin'             => 'புகுபதிகை செய்யப்படவில்லை',
-'prefsnologintext'         => 'பயனர் விருப்பத் தேர்வுகளை அமைப்பதற்கு நீங்கள் [[Special:Userlogin|புகுபதிகை செய்ய வேண்டும்]].',
+'prefsnologintext'         => 'பயனர் விருப்பத் தேர்வுகளை அமைப்பதற்கு நீங்கள் [[Special:UserLogin|புகுபதிகை செய்ய வேண்டும்]].',
 'prefsreset'               => 'உங்கள் விருப்புகள் சேமிப்பிலிருந்து மீட்டமைக்கப்பட்டுள்ளன.',
 'qbsettings'               => 'விரைவுச் சட்ட அமைவுகள்',
 'qbsettings-none'          => 'எதுவுமில்லை',
@@ -859,6 +854,7 @@
 'servertime'               => 'வழங்கன் நேரம்',
 'guesstimezone'            => 'உலாவியிலிருந்து நிரப்பு',
 'allowemail'               => 'ஏனைய பயனர்களிடம் இருந்தான மின்னஞ்சல்களை அனுமதி',
+'prefs-searchoptions'      => 'தேடல் விருப்பத் தேர்வுகள்',
 'defaultns'                => 'இயல்பிருப்பாக இந்தப் பெயர்வெளிகளில் தேடவும்:',
 'default'                  => 'இயல்பிருப்பு',
 'files'                    => 'கோப்புகள்',
@@ -875,7 +871,7 @@
 'userrights-reason'           => 'மாற்றத்துக்கான காரணம்:',
 'userrights-no-interwiki'     => 'ஏனைய விக்கிகளில் பயனர் உரிமைகளை மாற்றும் அனுமதி உங்களுக்குக் கிடையாது.',
 'userrights-nodatabase'       => '$1 தரவுத்தளம் கிடையாது அல்லது உள்ளக விக்கியில் கிடையாது.',
-'userrights-nologin'          => 'பயனர் உரிமைகளை வழங்குவதற்கு நீங்கள் நிர்வாகி கணக்கில் [[Special:Userlogin|புகுபதிகை]] செய்ய வேண்டும்.',
+'userrights-nologin'          => 'பயனர் உரிமைகளை வழங்குவதற்கு நீங்கள் நிர்வாகி கணக்கில் [[Special:UserLogin|புகுபதிகை]] செய்ய வேண்டும்.',
 'userrights-notallowed'       => 'பயனர் உரிமைகளை மாற்றும் அனுமதி உங்கள் பயனர் கணக்குக் கிடையாது.',
 'userrights-changeable-col'   => 'நீங்கள் மாற்றக்கூடிய குழுக்கள்',
 'userrights-unchangeable-col' => 'நீங்கள் மாற்ற முடியாத குழுக்கள்',
@@ -909,6 +905,7 @@
 'right-createaccount'        => 'புதிய பயனர் கணக்குகளை தொடங்கல்',
 'right-minoredit'            => 'தொகுப்புகளை சிறியதாக குறிக்க',
 'right-move'                 => 'பக்கத்தை நகர்த்து',
+'right-move-subpages'        => 'துணைப் பக்கங்களுடன் பக்கத்தை நகர்த்தவும்',
 'right-upload'               => 'கோப்புகளைப் பதிவேற்றுக',
 'right-reupload'             => 'தற்போதுள்ள கோப்பை மேழெழுழுதுக',
 'right-upload_by_url'        => 'யூ.ஆர்.எல். ஒன்றிலிருந்து கோப்பை பதிவேற்றல்',
@@ -932,6 +929,7 @@
 'right-autopatrol'           => 'தொகுப்புகளை தானியக்கமாக ரோந்திடப்பட்டதாக குறித்தல்',
 'right-unwatchedpages'       => 'கவனிக்கப்படாத பக்கங்களின் பட்டியலைப் பார்த்தல்',
 'right-mergehistory'         => 'பக்கங்களின் வரலாற்றை இணைத்தல்',
+'right-userrights'           => 'எல்லாப் பயனர் உரிமைகளையும் தொகுக்கவும்',
 'right-userrights-interwiki' => 'ஏனைய விக்கி தளங்களின் பயனர் உரிமைகளை தொகுத்தல்',
 'right-siteadmin'            => 'தரவுத்தளத்தை பூட்டல் திறத்தல்',
 
@@ -981,11 +979,11 @@
 'reupload'                    => 'மீளப் பதிவேற்று',
 'reuploaddesc'                => 'பதிவேற்றத்தை நிறுத்திவிட்டு பதிவேற்றும் படிவத்துக்கு மீளச் செல்க',
 'uploadnologin'               => 'புகுபதிகை செய்யப்படவில்லை',
-'uploadnologintext'           => 'கோப்புகளைப் பதிவேற்றம் செய்வதற்கு நீங்கள் [[Special:Userlogin|புகுபதிகை]] செய்திருக்க வேண்டும்.',
+'uploadnologintext'           => 'கோப்புகளைப் பதிவேற்றம் செய்வதற்கு நீங்கள் [[Special:UserLogin|புகுபதிகை]] செய்திருக்க வேண்டும்.',
 'upload_directory_read_only'  => 'பதிவேற்ற அடைவு ($1) வழங்கனால் எழுதப்படமுடியாது.',
 'uploaderror'                 => 'பதிவேற்றத் தவறு',
 'uploadtext'                  => "கோப்புக்களை பதிவேற்ற பின்வரும் படிமத்தைப் பயன்படுத்தவும்.
-முன்னர் பதிவேற்றம் செய்யப்பட்ட படிமங்களைப் பார்ப்பதற்கு அல்லது தேடுவதற்கு, [[Special:Imagelist|பதிவேற்றம் செய்யப்பட்ட படிமங்களின் பட்டிய]]லுக்குச் செல்லவும். பதிவேற்றங்களும் நீக்கல்களும் [[Special:Log/upload|பதிவேற்றப் பதிகையில்]] பதியப்பட்டுள்ளன.
+முன்னர் பதிவேற்றம் செய்யப்பட்ட படிமங்களைப் பார்ப்பதற்கு அல்லது தேடுவதற்கு, [[Special:ImageList|பதிவேற்றம் செய்யப்பட்ட படிமங்களின் பட்டிய]]லுக்குச் செல்லவும். பதிவேற்றங்களும் நீக்கல்களும் [[Special:Log/upload|பதிவேற்றப் பதிகையில்]] பதியப்பட்டுள்ளன.
 
 உங்கள் கட்டுரைகளில் படிமங்களைச் சேர்ப்பதற்கு,
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:File.jpg]]</nowiki>''' அல்லது 
@@ -1051,7 +1049,7 @@
 'upload-proto-error'      => 'பிழையான நெறி',
 'upload-proto-error-text' => 'தொலைவுப் பதிவேற்றத்துக்கு யு.ஆர்.எல். <code>http://</code> அல்லது <code>ftp://</code> என்ற முன்னொட்டுடன் தொடங்கவேண்டும்.',
 'upload-file-error'       => 'உள்ளகத் தவறு',
-'upload-file-error-text'  => 'வழங்கனில் தற்காலிக கோப்பை உருவாக்க முயற்சித்தப் போது உள்ளகத் தவறொன்று ஏற்பட்டது. அருள் கூர்ந்து முறைமை செயற்படுத்துனரை அனுகவும்.',
+'upload-file-error-text'  => 'வழங்கனில் தற்காலிக கோப்பை உருவாக்க முயற்சித்த போது உள்ளகத் தவறொன்று ஏற்பட்டது. அருள் கூர்ந்து முறைமைச் செயற்படுத்துனரை அணுகவும்.',
 'upload-misc-error'       => 'இனந்தெரியாத பதிவேற்றல் தவறு',
 
 # Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
@@ -1066,7 +1064,7 @@
 'upload_source_url'  => ' (செல்லுபடியான, இணைய முகவரி)',
 'upload_source_file' => ' (உங்கள் கணணியில் உள்ள கோப்பு)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'பின்வரும் பெயருள்ள ஊடகக் கோப்பைத் தேடு:',
 'imgfile'               => 'கோப்பு',
 'imagelist'             => 'படிமங்களின் பட்டியல்',
@@ -1108,18 +1106,18 @@
 # File reversion
 'filerevert'                => '$1 ஐ முன்நிலையாக்கு',
 'filerevert-legend'         => 'கோப்பை முன்நிலையாக்கு',
-'filerevert-intro'          => '<span class="plainlinks">நீங்கள் [$3, $2 இன் திருத்தம் $4க்கு] \'\'\'[[Media:$1|$1]]\'\'\' ஊடகத்தை முன்நிலையாக்குகிறீர்கள்.</span>',
+'filerevert-intro'          => "நீங்கள் [$3, $2 இன் திருத்தம் $4க்கு] '''[[Media:$1|$1]]''' ஊடகத்தை முன்நிலையாக்குகிறீர்கள்.",
 'filerevert-comment'        => 'கருத்து:',
 'filerevert-defaultcomment' => '$2, $1 இல் உள்ளபடியான பதிப்புக்கு முன்நிலையாக்கப்பட்டது',
 'filerevert-submit'         => 'முன்நிலையாக்கு',
-'filerevert-success'        => '<span class="plainlinks">ஊடகம் \'\'\'[[Media:$1|$1]]\'\'\' $3, $2 இல் உள்ளபடியான $4 பதிப்புக்கு முன்நிலையாக்கப்பட்டது.</span>',
+'filerevert-success'        => "ஊடகம் '''[[Media:$1|$1]]''' $3, $2 இல் உள்ளபடியான $4 பதிப்புக்கு முன்நிலையாக்கப்பட்டது.",
 'filerevert-badversion'     => 'குறித்த நேர முத்திரையுடன் கூடிய முந்தைய உள்ளக திருத்தங்கள் காணப்படவில்லை.',
 
 # File deletion
 'filedelete'                  => '$1 கோப்பை நீக்கு',
 'filedelete-legend'           => 'கோப்பை நீக்கு',
 'filedelete-intro'            => "நீங்கள் '''[[Media:$1|$1]]''' கோப்பை நீக்குகிறீர்கள்.",
-'filedelete-intro-old'        => '<span class="plainlinks"> \'\'\'[[Media:$1|$1]]\'\'\' என்றப் பெயருள்ள ஊடகத்தின் [$4 $3, $2] இல் உள்ளப் படியான பதிப்பை நீக்குகிறீர்கள்.</span>',
+'filedelete-intro-old'        => "'''[[Media:$1|$1]]''' என்றப் பெயருள்ள ஊடகத்தின் [$4 $3, $2] இல் உள்ளப் படியான பதிப்பை நீக்குகிறீர்கள்.",
 'filedelete-comment'          => 'நீக்கலுக்கான காரணம்:',
 'filedelete-submit'           => 'நீக்கு',
 'filedelete-success'          => "'''$1''' நீக்கப்பட்டுவிட்டது.",
@@ -1173,7 +1171,7 @@
 
 
 தற்போதைய [http://www.mediawiki.org/wiki/Manual:Job_queue வேலைக் காத்திருப்பு வரிசை] '''$7''' ஆகும்.",
-'userstatstext'          => "இத்தளத்தில் {{PLURAL:$1|ஒரு பதிவு செய்த [[Special:Listusers|பயனர்]] உள்ளார்|'''$1''' பதிவு செய்த [[Special:Listusers|பயனர்கள்]] உள்ளனர்}}, இதில் '''$2''' (அல்லது '''$4%''') {{PLURAL:$2|பயனர்|பயனர்கள்}} $5 அனுமதியைக் கொண்டுள்ளனர்.",
+'userstatstext'          => "இத்தளத்தில் {{PLURAL:$1|ஒரு பதிவு செய்த [[Special:ListUsers|பயனர்]] உள்ளார்|'''$1''' பதிவு செய்த [[Special:ListUsers|பயனர்கள்]] உள்ளனர்}}, இதில் '''$2''' (அல்லது '''$4%''') {{PLURAL:$2|பயனர்|பயனர்கள்}} $5 அனுமதியைக் கொண்டுள்ளனர்.",
 'statistics-mostpopular' => 'அதிகம் பார்க்கப்பட்ட பக்கங்கள்',
 
 'disambiguations'      => 'பக்கவழி நெறிப்படுத்தல் பக்கங்கள்',
@@ -1241,6 +1239,7 @@
 'unusedcategoriestext'    => 'பின்வரும் பகுப்புகள் உருவாக்கப்பட்டுள்ளன எனினும் வேறு எந்தப் பக்கமோ அல்லது பகுப்போ இதைப் பயன்படுத்தவில்லை.',
 'notargettitle'           => 'இலக்கு இல்லை',
 'notargettext'            => 'நீங்கள் இந்தச் செயலை எந்தப் பயனர் அல்லது பக்கம் தொடர்பில் செய்வது என்பதைக் குறிப்பிடவில்லை.',
+'nopagetitle'             => 'அவ்வாறான இலக்குப் பக்கம் எதுவும் இல்லை',
 'pager-newer-n'           => '{{PLURAL:$1|புதிய ஒரு|புதிய $1}}',
 'pager-older-n'           => '{{PLURAL:$1|பழைய ஒரு|பழைய $1}}',
 
@@ -1261,7 +1260,7 @@
 'logempty'             => 'பொருத்தமான பதிவுகள் யாதுமில்லை.',
 'log-title-wildcard'   => 'இவ்வுரையுடன் தொடங்கும் தலைப்புகளைத் தேடு',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'அனைத்துப் பக்கங்கள்',
 'alphaindexline'    => '$1 தொடக்கம் $2 வரை',
 'nextpage'          => 'அடுத்த பக்கம் ($1)',
@@ -1283,12 +1282,12 @@
 'special-categories-sort-count' => 'எண்ணிக்கையின் படி ஒழுங்குப் படுத்துக',
 'special-categories-sort-abc'   => 'அகரவரிசைப்படி ஒழுங்குப் படுத்துக',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'பின்வரும் எழுத்துடன் தொடங்கும் பயனர்களைக் காட்டு:',
 'listusers-submit'   => 'காட்டு',
 'listusers-noresult' => 'ஒரு பயனரும் இல்லை.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'பயனர் குழு உரிமைகள்',
 'listgrouprights-group'    => 'குழு',
 'listgrouprights-rights'   => 'உரிமைகள்',
@@ -1297,7 +1296,7 @@
 
 # E-mail user
 'mailnologin'     => 'அனுப்பும் முகவரி இல்லை',
-'mailnologintext' => 'நீங்கள்[[Special:Userlogin|புகுபதிகை செய்திருப்பதுடன்]]
+'mailnologintext' => 'நீங்கள்[[Special:UserLogin|புகுபதிகை செய்திருப்பதுடன்]]
 ஏனைய பயனர்களுக்கு மின்னஞ்சல் அனுப்பக்கூடியத்தாக செல்லுபடியாகக்கூடிய மின்னஞ்சல் முகவரியொன்றும் உங்களுடைய  [[Special:Preferences|விருப்பத் தெரிவுகளில்]] கொடுபட்டிருக்கவேண்டும்.',
 'emailuser'       => 'இப் பயனருக்கு மின்னஞ்சல் செய்',
 'emailpage'       => 'மின்னஞ்சல் பயனர்',
@@ -1324,9 +1323,9 @@
 'nowatchlist'          => 'உங்களுடைய கவனிப்புப் பட்டியலில் ஒரு விடயமும் இல்லை.',
 'watchlistanontext'    => 'உமது கவனிப்புப் பட்டியலை பார்க அல்லது தொகுக்க அருள் கூர்ந்து $1.',
 'watchnologin'         => 'புகுபதிகை செயப்படவில்லை',
-'watchnologintext'     => 'உங்கள் கவனிப்புப் பட்டியலில் திருத்தம் செய்வதற்கு, நீங்கள்[[Special:Userlogin|புகுபதிகை செய்திருக்கவேண்டும்]].',
+'watchnologintext'     => 'உங்கள் கவனிப்புப் பட்டியலில் திருத்தம் செய்வதற்கு, நீங்கள்[[Special:UserLogin|புகுபதிகை செய்திருக்கவேண்டும்]].',
 'addedwatch'           => 'கவனிப்புப் பட்டியலில் சேர்க்கப்பட்டது',
-'addedwatchtext'       => "\"[[:\$1]]\" பக்கம் உங்கள் [[Special:Watchlist|கவனிப்புப் பக்கத்தில்]] சேர்க்கப்பட்டுள்ளது. இந்தப் பக்கத்துக்கு எதிகாலத்தில் செய்யப்படவுள்ள மாற்றங்களும், அதனோடிணைந்த பேச்சுப் பக்கமும், அங்கே பட்டியலிடப்படும். அத்துடன் தெரிந்தெடுக்க வசதியாக [[Special:Recentchanges|அண்மைய மாற்றங்களின் பட்டியலில்]] இது தடித்த எழுத்துக்களில் காட்டப்படும். பின்னர், இப் பக்கத்தை உங்கள் கவனிப்புப் பட்டியலிலிருந்து நீக்க விரும்பினால், பக்கச் சட்டத்திலுள்ள ''கவனிப்பு நீக்கு'' என்ற இணைப்பைச் சொடுக்கவும்.",
+'addedwatchtext'       => "\"[[:\$1]]\" பக்கம் உங்கள் [[Special:Watchlist|கவனிப்புப் பக்கத்தில்]] சேர்க்கப்பட்டுள்ளது. இந்தப் பக்கத்துக்கு எதிகாலத்தில் செய்யப்படவுள்ள மாற்றங்களும், அதனோடிணைந்த பேச்சுப் பக்கமும், அங்கே பட்டியலிடப்படும். அத்துடன் தெரிந்தெடுக்க வசதியாக [[Special:RecentChanges|அண்மைய மாற்றங்களின் பட்டியலில்]] இது தடித்த எழுத்துக்களில் காட்டப்படும். பின்னர், இப் பக்கத்தை உங்கள் கவனிப்புப் பட்டியலிலிருந்து நீக்க விரும்பினால், பக்கச் சட்டத்திலுள்ள ''கவனிப்பு நீக்கு'' என்ற இணைப்பைச் சொடுக்கவும்.",
 'removedwatch'         => 'கவனிப்புப் பட்டியலிலிருந்து நீக்கப்பட்டது',
 'removedwatchtext'     => '"[[:$1]]" பக்கம் உங்கள் கவனிப்புப் பட்டியலிலிருந்து நீக்கப்பட்டது.',
 'watch'                => 'கவனி',
@@ -1433,7 +1432,7 @@
 'rollback-success'            => '$1 செய்தத் தொகுப்புகள் நீக்கப்பட்டு $2 இன் பதிப்புக்கு முன்நிலையாக்கப்பட்டது.',
 'sessionfailure'              => 'உங்கள் புகுபதிகை அமர்வில் பிரச்சினை உள்ளது போல தோன்றுகிறது. செல்வழி திருட்டுக் கெதிரான முன்னெச்செரிக்கையாக இந்த நடவடிக்கை இரத்துச் செய்யப்பட்டது. உங்கள் உலாவியின் பின் செல்வதற்கான பொத்தானைச் செருகி மீண்டும் முயலவும்.',
 'protectlogpage'              => 'காப்புப் பதிகை',
-'protectlogtext'              => 'பின்வருவது பக்க திறப்புக்களதும் பூட்டுக்களதும் பட்டியலாகும். தற்போது நடைமுறையிலுள்ள காக்கப்பட்டப் பக்கங்களைக் காண [[Special:Protectedpages|காக்கப்பட்ட பக்கங்களின் பட்டியலைப்]] பார்க்கவும்.',
+'protectlogtext'              => 'பின்வருவது பக்க திறப்புக்களதும் பூட்டுக்களதும் பட்டியலாகும். தற்போது நடைமுறையிலுள்ள காக்கப்பட்டப் பக்கங்களைக் காண [[Special:ProtectedPages|காக்கப்பட்ட பக்கங்களின் பட்டியலைப்]] பார்க்கவும்.',
 'protectedarticle'            => '"[[$1]]" காக்கப்பட்டது',
 'modifiedarticleprotection'   => '"[[$1]]" பக்கத்திற்கான காப்பின் அளவு மாற்றப்பட்டது',
 'unprotectedarticle'          => '"[[$1]]" பக்கத்தின் காப்பு நீக்கப்பட்டது',
@@ -1583,7 +1582,7 @@
 'badipaddress'                => 'செல்லுபடியற்ற ஐ.பி. முகவரி',
 'blockipsuccesssub'           => 'தடுப்பு வெற்றி',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] தடுக்கப்பட்டுள்ளார்.<br />
-தடுப்பை மீளாய்வு செய்ய [[Special:Ipblocklist|தடுக்கப்பட்ட ஐ.பி. முகவரிகளின் பட்டியலைப்]] பார்.',
+தடுப்பை மீளாய்வு செய்ய [[Special:IPBlockList|தடுக்கப்பட்ட ஐ.பி. முகவரிகளின் பட்டியலைப்]] பார்.',
 'ipb-edit-dropdown'           => 'தடை காரணங்கள் தொகு',
 'ipb-unblock-addr'            => '$1 இன் தடையை நீக்கு',
 'ipb-unblock'                 => 'ஐ.பி. அல்லது பயனருக்கான தடையை நீக்கு',
@@ -1613,7 +1612,7 @@
 'autoblocker'                 => 'நீங்கள் "[[User:$1|$1]]" உடன் ஒரே ஐ.பி. முகவரியைப் பகிர்ந்துகொள்வதால் தானியங்கித் தடை விதிக்கப்பட்டுள்ளது. $1இன் தடுப்புக்காக கொடுக்கப்பட்டக் காரணம்: "$2".',
 'blocklogpage'                => 'தடைப் பதிகை',
 'blocklogentry'               => '$2, $3 அன்று காலாவதியாகும் வகையில் [[$1]] தடுக்கப்பட்டது',
-'blocklogtext'                => 'இது ஒரு பயனரின் தடுப்பு தடை நீக்கல் செயற்பாடுகளுக்கான பதிவாகும். தானியங்கி முறையில் தடுக்கப்படும் ஐபி முகவரிகள் இப்பட்டியலில் இடம்பெறா.  தற்போது செயற்பாட்டிலுள்ள தடைகளையும் முடக்கங்களையும் [[Special:Ipblocklist|ஐ.பி. தடுப்பு பட்டியலில்]] பார்க்க.',
+'blocklogtext'                => 'இது ஒரு பயனரின் தடுப்பு தடை நீக்கல் செயற்பாடுகளுக்கான பதிவாகும். தானியங்கி முறையில் தடுக்கப்படும் ஐபி முகவரிகள் இப்பட்டியலில் இடம்பெறா.  தற்போது செயற்பாட்டிலுள்ள தடைகளையும் முடக்கங்களையும் [[Special:IPBlockList|ஐ.பி. தடுப்பு பட்டியலில்]] பார்க்க.',
 'unblocklogentry'             => '"$1" தொடர்பான தடுப்பு நீக்கப்பட்டது',
 'block-log-flags-anononly'    => 'அடையாளம் காட்டாத பயனர் மட்டும்',
 'block-log-flags-nocreate'    => 'கணக்கு தொடக்கம் முடக்கப்பட்டுள்ளது',
@@ -1642,7 +1641,7 @@
 'locknoconfirm'       => 'நீங்கள் உறுதிப்படுத்தல் கட்டத்துள் குறியிடவில்லை.',
 'lockdbsuccesssub'    => 'தரவுத்தளப் பூட்டல் வெற்றி',
 'unlockdbsuccesssub'  => 'தரவுத்தளப் பூட்டு நீக்கப்பட்டது',
-'lockdbsuccesstext'   => 'தரவுத்தளம் பூட்டப் பட்டது.<br />பராமரிப்பு முடிவடைந்ததும் [[Special:Unlockdb|பூட்டை நீக்க]] மறவாதீர்.',
+'lockdbsuccesstext'   => 'தரவுத்தளம் பூட்டப் பட்டது.<br />பராமரிப்பு முடிவடைந்ததும் [[Special:UnlockDB|பூட்டை நீக்க]] மறவாதீர்.',
 'unlockdbsuccesstext' => 'தரவுத்தளம் திறக்கப்பட்டது.',
 'databasenotlocked'   => 'தரவுத்தளம் பூட்டப்படவில்லை.',
 
@@ -1666,8 +1665,6 @@
 '''இல்லாவிடில்''' சேர்ந்திருக்கும் பேச்சுப் பக்கம், ஏதாவது இருந்தால், தன்னியக்கமாக அதனுடன் நகர்த்தப்படும்.
 இப்படியான சந்தர்ப்பங்களில், விரும்பினால், நகர்த்தலையோ அல்லது ஒன்றிணைத்தலையோ நீங்கள் கைவினையாகச் செய்யவேண்டியிருக்கும்.",
 'movearticle'             => 'பக்கத்தை நகர்து',
-'movenologin'             => 'புகுபதிகை செய்யப்படவில்லை',
-'movenologintext'         => 'இப் பக்கத்தை நகர்த்துவதற்கு, நீங்கள் ஒரு பதிவு செய்யப்பட்ட பயனராயும் [[Special:Userlogin|புகுபதிகை செய்தும்]] இருக்க வேண்டும்.',
 'movenotallowed'          => 'உமக்கு {{SITENAME}} தளத்தில் பக்கங்களை நகர்த்த அனுமதி கிடையாது.',
 'newtitle'                => 'புதிய தலைப்பு',
 'move-watch'              => 'இப்பக்கத்தைக் கவனி',
@@ -1688,7 +1685,7 @@
 'delete_and_move'         => 'நீக்கிவிட்டு நகர்த்து',
 'delete_and_move_text'    => '==நீக்கம் தேவை==
 
-நகர்த்தப்படவேண்டியப் பக்கம் "[[$1]]" ஏற்கனவே உள்ளது. நகர்த்தலுக்கு வழி ஏற்படுத்த அப்பக்கத்தை நீக்க வேண்டுமா?',
+நகர்த்தப்படவேண்டியப் பக்கம் "[[:$1]]" ஏற்கனவே உள்ளது. நகர்த்தலுக்கு வழி ஏற்படுத்த அப்பக்கத்தை நீக்க வேண்டுமா?',
 'delete_and_move_confirm' => 'ஆம், இப்பக்கத்தை நீக்குக',
 'delete_and_move_reason'  => 'நகர்த்துவதற்கு இடமளிப்பதற்காக நீக்கப்பட்டது',
 'selfmove'                => 'நகர்தலின் தொடக்கப் பக்கத்தலைப்பும் முடிவுப் பக்கத்தலைப்பும் ஒன்றாகும்; ஒரு தலைப்பை அதன் மீதே நகர்த்த முடியாது.',
@@ -1903,7 +1900,7 @@
 'show-big-image'       => 'முழு அளவிலான படிமம்',
 'show-big-image-thumb' => '<small>இந்த முன்தோற்றத்தின் பரிமாணம்: $1 × $2 பிக்சல்கள்</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'புதிய படிமங்கள் பக்கம்',
 'imagelisttext'         => 'கீழ் வருவது $2 பாகுபடுத்தப்பட்ட $1 {{PLURAL:$1|படிமத்தின்|படிமங்களின்}} பட்டியலாகும்.',
 'newimages-summary'     => 'இச்சிறப்புப் பக்கம் கடைசியாக பதிவேற்றப்பட்ட பக்களைப் பட்டியலிடுகிறது',
@@ -2132,7 +2129,7 @@
 
 # External editor support
 'edit-externally'      => 'இக்கோப்பை வெளி மென்பொருள் கொண்டு தொகுக்க',
-'edit-externally-help' => 'மேலதிக தகவல்களுக்கு [http://meta.wikimedia.org/wiki/Help:External_editors அறிவுறுத்தல்கள்] பக்கத்தைப் பார்க்கவும்.',
+'edit-externally-help' => 'மேலதிக தகவல்களுக்கு [http://www.mediawiki.org/wiki/Manual:External_editors அறிவுறுத்தல்கள்] பக்கத்தைப் பார்க்கவும்.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'அனைத்து',
@@ -2190,7 +2187,7 @@
 'recreate'            => 'மீள உருவாக்கு',
 
 # HTML dump
-'redirectingto' => '[[$1]] பக்கத்துக்கு வழிமாற்றப்படுகிறது...',
+'redirectingto' => '[[:$1]] பக்கத்துக்கு வழிமாற்றப்படுகிறது...',
 
 # action=purge
 'confirm_purge'        => 'இப்பக்கத்தின் இடைமாற்றை நீக்கவா?
@@ -2287,7 +2284,7 @@
 'version-software-product'         => 'உற்பத்திப்பொருள்',
 'version-software-version'         => 'பதிப்பு',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'கோப்பு வழி',
 'filepath-page'    => 'கோப்பு:',
 'filepath-submit'  => 'வழி',
Index: languages/messages/MessagesVls.php
===================================================================
--- languages/messages/MessagesVls.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesVls.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,8 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
- * @author Siebrand
  * @author Tbc
  * @author לערי ריינהארט
  */
@@ -97,7 +95,7 @@
 # Tooltip help for the actions
 'tooltip-n-mainpage' => "Noar 't voorblad goane",
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Nieuwe ofbeeldiengn',
 
 );
Index: languages/messages/MessagesTe.php
===================================================================
--- languages/messages/MessagesTe.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTe.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,15 +4,13 @@
  * @ingroup Language
  * @file
  *
- * @author Veeven
- * @author Mpradeep
  * @author Chaduvari
+ * @author Mpradeep
  * @author Sunil Mohan
- * @author Siebrand
- * @author వైజాసత్య
- * @author לערי ריינהארט
- * @author SPQRobin
+ * @author Veeven
  * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+ * @author לערי ריינהארט
+ * @author వైజాసత్య
  */
 
 $namespaceNames = array(
@@ -338,7 +336,7 @@
 'nosuchspecialpage' => 'అటువంటి ప్రత్యేక పేజీ లేదు',
 'nospecialpagetext' => "<big>'''మీరు అడిగిన ప్రత్యేకపేజీ సరైనది కాదు.'''</big>
 
-సరైన ప్రత్యేకపేజీల జాబితా [[Special:Specialpages|{{int:specialpages}}]] వద్ద ఉంది.",
+సరైన ప్రత్యేకపేజీల జాబితా [[Special:SpecialPages|{{int:specialpages}}]] వద్ద ఉంది.",
 
 # General errors
 'error'                => 'లోపం',
@@ -580,10 +578,6 @@
 'blockededitsource'                => "'''$1''' లో '''మీ దిద్దుబాట్ల''' పూర్తి పాఠాన్ని కింద ఇచ్చాం:",
 'whitelistedittitle'               => 'మార్పులు చెయ్యడానికి లాగిన్‌ అయి ఉండాలి',
 'whitelistedittext'                => 'పేజీలకి మార్పులు చెయ్యడానికి మీరు $1 అయి ఉండాలి.',
-'whitelistreadtitle'               => 'చదవడానికి లాగిన్‌ అయి వుండాలి',
-'whitelistreadtext'                => 'పేజీలు చదవడానికి [[Special:Userlogin|లాగిన్‌]] అయి ఉండాలి.',
-'whitelistacctitle'                => 'మీకు అకౌంటు సృష్టించే అనుమతి లేదు',
-'whitelistacctext'                 => '{{SITENAME}}లో అకౌంట్లను సృష్టించడానికి మీరు [[Special:Userlogin|లాగిన్‌]] అయి ఉండాలి, మరియు తగువిధమైన అనుమతులు ఉండాలి.',
 'confirmedittitle'                 => 'మార్పులు చేసేముందు ఈ-మెయిలు చిరునామా ధృవీకరణ తప్పనిసరి',
 'confirmedittext'                  => 'పేజీల్లో మార్పులు చేసేముందు మీ ఈ-మెయిలు చిరునామా ధృవీకరించాలి. [[Special:Preferences|మీ అభిరుచుల]]లో మీ ఈ-మెయిలు చిరునామా రాసి, ధృవీకరించండి.',
 'nosuchsectiontitle'               => 'అటువంటి విభాగం లేదు',
@@ -596,7 +590,7 @@
 'newarticle'                       => '(కొత్తది)',
 'newarticletext'                   => "ఈ లింకుకు సంబంధించిన పేజీ ఉనికిలొ లేదు.
 కింది పెట్టెలో మీ రచనను టైపు చేసి ఆ పేజీని సృష్టించండి (దీనిపై సమాచారం కొరకు [[{{MediaWiki:Helppage}}|సహాయం]] పేజీ చూడండి). మీరిక్కడికి పొరపాటున వచ్చి ఉంటే, మీ బ్రౌజరు '''back''' మీట నొక్కండి.",
-'anontalkpagetext'                 => "----''ఇది ఒక అజ్ఞాత సభ్యుని చర్చా పేజీ, కాబట్టి ఇంకా ఖాతా సృష్టించ లేదు, లేదా దానిని ఉపయోగించడం లేదు. కాబట్టి వారి ఐ.పీ. అడ్రసే ఆ సభ్యుని గుర్తింపు. ఆ ఐ.పి. అడ్రసు చాలా మంది సభ్యులు వాడే అవకాశం ఉంది. మీరూ ఓ అజ్ఞాత సభ్యులైతే, ఒకే ఐ.పీ. అడ్రసు కారణంగా వేరే సభ్యులకు ఉద్దేశించిన వ్యాఖ్యానాలు మీకూ వర్తించే అవకాశం ఉంది. ఇకనుండి ఈ అయోమయం లేకుండా ఉండాలంటే, [[Special:Userlogin|అకౌంటు సృష్టించండి లేదా లాగిన్‌ అవండి]].''",
+'anontalkpagetext'                 => "----''ఇది ఒక అజ్ఞాత సభ్యుని చర్చా పేజీ, కాబట్టి ఇంకా ఖాతా సృష్టించ లేదు, లేదా దానిని ఉపయోగించడం లేదు. కాబట్టి వారి ఐ.పీ. అడ్రసే ఆ సభ్యుని గుర్తింపు. ఆ ఐ.పి. అడ్రసు చాలా మంది సభ్యులు వాడే అవకాశం ఉంది. మీరూ ఓ అజ్ఞాత సభ్యులైతే, ఒకే ఐ.పీ. అడ్రసు కారణంగా వేరే సభ్యులకు ఉద్దేశించిన వ్యాఖ్యానాలు మీకూ వర్తించే అవకాశం ఉంది. ఇకనుండి ఈ అయోమయం లేకుండా ఉండాలంటే, [[Special:UserLogin|అకౌంటు సృష్టించండి లేదా లాగిన్‌ అవండి]].''",
 'noarticletext'                    => 'ప్రస్తుతం ఈ పేజీ ఖాళీగా ఉంది, మీరు ఈ పేజీ శీర్షిక కొసం వెరె పెజీలు [[Special:Search/{{PAGENAME}}|వెతకవచ్చు]] లేదా [{{fullurl:{{FULLPAGENAME}}|action=edit}} ఈ పెజీని మార్చ] వచ్చు.',
 'userpage-userdoesnotexist'        => '"$1" అనే వాడుకరి ఖాతా నమోదయిలేదు. మీరు ఈ పేజీని సృష్టించ/సరిదిద్దాలనుకుంటే, సరిచూసుకోండి.',
 'clearyourcache'                   => "'''గమనిక - భద్రపరచిన తర్వాత, మార్పులను చూడడానికి మీ విహారిణి యొక్క కోశాన్ని తీసేయాల్సిరావచ్చు.''' '''మొజిల్లా/ ఫైర్‌ఫాక్స్‌ / సఫారి:''' ''Shift'' మీటని నొక్కిపట్టి ''రీలోడ్''ని నొక్కండి లేదా ''Ctrl-F5'' అనే మీటల్ని లేదా ''Ctrl-R'' (మాకింటోషులో ''Command-R'') అనే మీటల్ని కలిపి నొక్కండి; '''కాంకరర్: '''''రీలోడ్''ని నొక్కండి లేదా ''F5'' మీటని నొక్కండి; '''ఒపెరా:''' ''Tools → Preferences'' ద్వారా కోశాన్ని శుభ్రపరచండి; '''ఇంటర్నెట్ ఎక్ప్లోరర్:'''''Ctrl'' మీటని నొక్కిపట్టి ''రీఫ్రెష్''ని నొక్కండి లేదా ''Ctrl-F5'' మీటల్ని కలిపి నొక్కండి.",
@@ -649,7 +643,7 @@
 'hiddencategories'                 => 'ఈ పేజీ {{PLURAL:$1|ఒక దాచిన వర్గంలో|$1 దాచిన వర్గాల్లో}} ఉంది:',
 'nocreatetitle'                    => 'పేజీని సృష్టించడాన్ని నియంత్రించాం.',
 'nocreatetext'                     => '{{SITENAME}}లో కొత్త పేజీలు సృష్టించడాన్ని నియంత్రించారు.
-మీరు వెనక్కి వెళ్ళి వేరే పేజీలు మార్చవచ్చు, లేదా [[Special:Userlogin|లోనికి ప్రవేశించండి లేదా ఖాతా సృష్టించుకోండి]].',
+మీరు వెనక్కి వెళ్ళి వేరే పేజీలు మార్చవచ్చు, లేదా [[Special:UserLogin|లోనికి ప్రవేశించండి లేదా ఖాతా సృష్టించుకోండి]].',
 'nocreate-loggedin'                => '{{SITENAME}}లో కొత్త పేజీలను సృష్టించేందుకు మీకు అనుమతి లేదు.',
 'permissionserrors'                => 'అనుమతుల తప్పిదాలు',
 'permissionserrorstext'            => 'కింద పేర్కొన్న {{PLURAL:$1|కారణం|కారణాల}} మూలంగా, ఆ పని చెయ్యడానికి మీకు అనుమతిలేదు:',
@@ -766,7 +760,7 @@
 # Suppression log
 'suppressionlog'     => 'అణచివేత లాగ్',
 'suppressionlogtext' => 'నిర్వాహకులకు కనబడని విషయం కలిగిన తొలగింపులు, నిరోధాల జాబితా ఇది. 
-ప్రస్తుతం అమల్లో ఉన్న నిషేధాలు, నిరోధాల జాబితా కోసం [[Special:Ipblocklist|ఐపీ నిరోధాల జాబితా]] చూడండి.',
+ప్రస్తుతం అమల్లో ఉన్న నిషేధాలు, నిరోధాల జాబితా కోసం [[Special:IPBlockList|ఐపీ నిరోధాల జాబితా]] చూడండి.',
 
 # History merging
 'mergehistory'                     => 'పేజీ చరితాలను విలీనం చెయ్యి',
@@ -849,7 +843,7 @@
 'mypreferences'            => 'నా అభిరుచులు',
 'prefs-edits'              => 'దిద్దుబాట్ల సంఖ్య:',
 'prefsnologin'             => 'లాగిన్‌ అయిలేరు',
-'prefsnologintext'         => 'అభిరుచులను మార్చుకోడానికి, మీరు [[Special:Userlogin|లాగిన్‌]] అయి ఉండాలి.',
+'prefsnologintext'         => 'అభిరుచులను మార్చుకోడానికి, మీరు [[Special:UserLogin|లాగిన్‌]] అయి ఉండాలి.',
 'prefsreset'               => 'ఇదివరకటి అభిరుచులు పునరుధ్ధరించబడ్డాయి.',
 'qbsettings'               => 'క్విక్‌బార్',
 'qbsettings-none'          => 'ఏదీకాదు',
@@ -923,7 +917,7 @@
 'userrights-reason'           => 'మార్పుకు కారణం:',
 'userrights-no-interwiki'     => 'ఇతర వికీలలో వాడుకరి హక్కులను మార్చడానికి మీకు అనుమతి లేదు.',
 'userrights-nodatabase'       => '$1 అనే డేటాబేసు లేదు లేదా అది స్థానికం కాదు.',
-'userrights-nologin'          => 'వాడుకరి హక్కులను ఇవ్వడానికి మీరు తప్పనిసరిగా ఓ నిర్వాహక ఖాతాతో [[Special:Userlogin|లోనికి ప్రవేశించాలి]].',
+'userrights-nologin'          => 'వాడుకరి హక్కులను ఇవ్వడానికి మీరు తప్పనిసరిగా ఓ నిర్వాహక ఖాతాతో [[Special:UserLogin|లోనికి ప్రవేశించాలి]].',
 'userrights-notallowed'       => 'వాడుకరి హక్కులను మార్చగలిగే అనుమతి మీ ఖాతాకు లేదు.',
 'userrights-changeable-col'   => 'మీరు మార్చదగిన గుంపులు',
 'userrights-unchangeable-col' => 'మీరు మార్చలేని గుంపులు',
@@ -1052,12 +1046,12 @@
 'reupload'                    => 'మళ్ళీ అప్‌లోడు చెయ్యి',
 'reuploaddesc'                => 'మళ్ళీ అప్‌లోడు ఫారంకు వెళ్ళు.',
 'uploadnologin'               => 'లాగిన్‌ అయిలేరు',
-'uploadnologintext'           => 'ఫైలు అప్‌లోడు చెయ్యాలంటే, మీరు [[Special:Userlogin|లాగిన్‌]] కావాలి',
+'uploadnologintext'           => 'ఫైలు అప్‌లోడు చెయ్యాలంటే, మీరు [[Special:UserLogin|లాగిన్‌]] కావాలి',
 'upload_directory_missing'    => 'ఎగుమతి డైరెక్టరీ ($1) తప్పింది మరియు వెబ్ సర్వర్ దాన్ని సృష్టించలేకున్నది.',
 'upload_directory_read_only'  => 'అప్‌లోడు డైరెక్టరీ ($1), వెబ్‌సర్వరు రాసేందుకు అనుకూలంగా లేదు.',
 'uploaderror'                 => 'అప్‌లోడు లోపం',
 'uploadtext'                  => "కింది ఫారంను ఉపయోగించి ఫైళ్ళు అప్‌లోడు చెయ్యండి.
-ఇదివరలో అప్‌లోడు చేసిన బొమ్మలను చూడడానికి లేదా వెతకడానికి [[Special:Imagelist|అప్‌లోడు అయిన ఫైళ్ళ జాబితా]]కు వెళ్ళండి,
+ఇదివరలో అప్‌లోడు చేసిన బొమ్మలను చూడడానికి లేదా వెతకడానికి [[Special:ImageList|అప్‌లోడు అయిన ఫైళ్ళ జాబితా]]కు వెళ్ళండి,
 ఎగుమతులు మరియు తొలగింపులు [[Special:Log/upload|అప్‌లోడు దినచర్య]]లో కూడా నమోదవుతాయి.
 
 ఫైలును ఏదైనా పేజీలో చేర్చడానికి, ఈ విధంగా లింకుని వాడండి
@@ -1146,7 +1140,7 @@
 'upload_source_url'  => ' (సార్వజనికంగా అందుబాటులో ఉన్న, సరైన URL)',
 'upload_source_file' => ' (మీ కంప్యూటర్లో ఒక ఫైలు)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'ఈ ప్రత్యేక పేజీ ఇప్పటి వరకూ అప్లోడయిన ఫైళ్లను చూపిస్తుంది.
 ఏ క్రమాన్నీ పేర్కొనకపోతే ఇటీవలే అప్లోడయిన ఫైళ్లను ముందుగా చూపిస్తుంది.
 నిలువు వరుసలకున్న శీర్షికలపై నొక్కితే క్రమపరిచే విధానం మారుతుంది.',
@@ -1174,7 +1168,7 @@
 'imagelinks'                     => 'లింకులు',
 'linkstoimage'                   => 'కింది {{PLURAL:$1|పేజీ|$1 పేజీల}} నుండి ఈ ఫైలుకి లింకులు ఉన్నాయి:',
 'nolinkstoimage'                 => 'ఈ ఫైలుకు లింకున్న పేజీలు లేవు.',
-'morelinkstoimage'               => 'ఈ ఫైలుకు ఇంకా [[Special:Whatlinkshere/$1| లింకులను]] చూడు',
+'morelinkstoimage'               => 'ఈ ఫైలుకు ఇంకా [[Special:WhatLinksHere/$1| లింకులను]] చూడు',
 'redirectstofile'                => 'క్రింద పేర్కొన్న {{PLURAL:$1|ఫైలు ఈ ఫైలుకి దారిమార్పు చెందుతుంది|$1 ఫైళ్ళు ఈ ఫైలుకి దారిమార్పు చెందుతాయి}}:',
 'duplicatesoffile'               => 'క్రింద పేర్కొన్న {{PLURAL:$1|ఫైలు ఈ ఫైలుకి నకలు|$1 ఫైళ్ళు ఈ ఫైలుకి నకళ్ళు}}:',
 'sharedupload'                   => 'ఈ ఫైలు ఒక ఉమ్మడి అప్లోడు, దీనిని ఇతర ప్రాజెక్టులలో కూడా ఉపయోగిస్తూ ఉండవచ్చు.',
@@ -1193,18 +1187,18 @@
 # File reversion
 'filerevert'                => '$1 ను వెనక్కు తీసుకుపో',
 'filerevert-legend'         => 'ఫైలును వెనక్కు తీసుకుపో',
-'filerevert-intro'          => '<span class="plainlinks">మీరు \'\'\'[[Media:$1|$1]]\'\'\' ను [$3, $2 నాటి $4 కూర్పు]కు తీసుకు వెళ్తున్నారు.</span>',
+'filerevert-intro'          => "మీరు '''[[Media:$1|$1]]''' ను [$3, $2 నాటి $4 కూర్పు]కు తీసుకు వెళ్తున్నారు.",
 'filerevert-comment'        => 'వ్యాఖ్య:',
 'filerevert-defaultcomment' => '$2, $1 నాటి కూర్పుకు తీసుకువెళ్ళాం',
 'filerevert-submit'         => 'వెనక్కు తీసుకువెళ్ళు',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' ను  [$3, $2 నాటి $4 కూర్పు]కు తీసుకువెళ్ళాం.</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' ను  [$3, $2 నాటి $4 కూర్పు]కు తీసుకువెళ్ళాం.",
 'filerevert-badversion'     => 'మీరిచ్చిన టైముస్టాంపుతో ఈ ఫైలుకు స్థానిక కూర్పేమీ లేదు.',
 
 # File deletion
 'filedelete'                  => '$1ని తొలగించు',
 'filedelete-legend'           => 'ఫైలుని తొలగించు',
 'filedelete-intro'            => "'''[[Media:$1|$1]]'''ని మీరు తొలగిస్తున్నారు.",
-'filedelete-intro-old'        => '<span class="plainlinks">మీరు \'\'\'[[Media:$1|$1]]\'\'\' యొక్క  [$4 $3, $2] నాటి కూర్పును తొలగిస్తున్నారు.</span>',
+'filedelete-intro-old'        => "మీరు '''[[Media:$1|$1]]''' యొక్క  [$4 $3, $2] నాటి కూర్పును తొలగిస్తున్నారు.",
 'filedelete-comment'          => 'వ్యాఖ్య:',
 'filedelete-submit'           => 'తొలగించు',
 'filedelete-success'          => "'''$1'''ని తొలగించాం.",
@@ -1257,7 +1251,7 @@
 అంటే, సగటున ప్రతీ పేజీకి '''\$5''' మార్పులు మరియు ప్రతీ మార్పుకి '''\$6''' దర్శనలు.
 
 [http://www.mediawiki.org/wiki/Manual:Job_queue చేయవలసిన పనుల జాబితా] పొడవు '''\$7'''.",
-'userstatstext'          => "ప్రస్తుతము {{PLURAL:$1|ఒక వాడుకరి మాత్రమే|'''$1''' మంది సభ్యులు}}, సభ్యునిగా [[Special:Listusers|నమోదు చేసుకున్నారు]]. వారిలో {{PLURAL:$2|ఒక్క సభునికి|'''$2''' సభ్యులకు}} (లేదా '''$4%''') $5 హక్కులు ఉన్నాయి.",
+'userstatstext'          => "ప్రస్తుతము {{PLURAL:$1|ఒక వాడుకరి మాత్రమే|'''$1''' మంది సభ్యులు}}, సభ్యునిగా [[Special:ListUsers|నమోదు చేసుకున్నారు]]. వారిలో {{PLURAL:$2|ఒక్క సభునికి|'''$2''' సభ్యులకు}} (లేదా '''$4%''') $5 హక్కులు ఉన్నాయి.",
 'statistics-mostpopular' => 'ఎక్కువగా చూసిన పేజీలు',
 
 'disambiguations'      => 'అయోమయ నివృత్తి పేజీలు',
@@ -1350,7 +1344,7 @@
 'logempty'             => 'దినచర్యలో సరిపోలిన అంశాలు లేవు.',
 'log-title-wildcard'   => 'ఈ పాఠ్యంతో మొదలయ్యే పుస్తకాల కొరకు వెతుకు',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'అన్ని పేజీలు',
 'alphaindexline'    => '$1 నుండి $2',
 'nextpage'          => 'తరువాతి పేజీ ($1)',
@@ -1373,12 +1367,12 @@
 'special-categories-sort-count' => 'సంఖ్యల ప్రకారం క్రమపరచు',
 'special-categories-sort-abc'   => 'అకారాది క్రమంలో అమర్చు',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'ఇక్కడ మొదలుపెట్టి సభ్యులను చూపించు:',
 'listusers-submit'   => 'చూపించు',
 'listusers-noresult' => 'వాడుకరి దొరకలేదు.',
 
-# Special:Listgrouprights
+# Special:ListGroupRights
 'listgrouprights'          => 'వాడుకరి గుంపుల హక్కులు',
 'listgrouprights-summary'  => 'కింది జాబితాలో ఈ వికీలో నిర్వచించిన వాడుకరి గుంపులు, వాటికి సంబంధించిన హక్కులు ఉన్నాయి. 
 విడివిడిగా హక్కులకు సంబంధించిన మరింత సమాచారం [[{{MediaWiki:Listgrouprights-helppage}}]] వద్ద లభిస్తుంది.',
@@ -1389,7 +1383,7 @@
 
 # E-mail user
 'mailnologin'     => 'పంపించవలసిన చిరునామా లేదు',
-'mailnologintext' => 'ఇతరులకు ఈ-మెయిలు పంపించాలంటే, మీరు [[Special:Userlogin|లాగిన్‌]] అయి ఉండాలి, మరియు మీ [[Special:Preferences|అభిరుచుల]]లో సరైన ఈ-మెయిలు చిరునామా ఇచ్చి ఉండాలి.',
+'mailnologintext' => 'ఇతరులకు ఈ-మెయిలు పంపించాలంటే, మీరు [[Special:UserLogin|లాగిన్‌]] అయి ఉండాలి, మరియు మీ [[Special:Preferences|అభిరుచుల]]లో సరైన ఈ-మెయిలు చిరునామా ఇచ్చి ఉండాలి.',
 'emailuser'       => 'ఈ సభ్యునికి ఈ-మెయిలు పంపు',
 'emailpage'       => 'సభ్యునికి ఈ-మెయిలు పంపు',
 'emailpagetext'   => 'ఈ వాడుకరి తన అభిరుచులలో సరైన ఈ-మెయిలు చిరునామా ఇచ్చి ఉంటే, కింది ఫారం మీ సందేశాన్ని పంపిస్తుంది. మీ అభిరుచులలో మీరిచ్చిన ఈ-మెయిలు చిరునామా "నుండి" ఆ సందేశంలో వచ్చినట్లుగా ఉంటుంది. ఆ వాడుకరి మీ చిరునామాకు జవాబు పంపుగలరు.',
@@ -1415,9 +1409,9 @@
 'nowatchlist'          => 'మీ వీక్షణ జాబితా ఖాళీగా ఉంది.',
 'watchlistanontext'    => 'మీ వీక్షణ జాబితా లోని అంశాలను చూసేందుకు, మార్చేందుకు $1 చెయ్యండి.',
 'watchnologin'         => 'లాగిన్‌ అయిలేరు',
-'watchnologintext'     => 'మీ వీక్షణ జాబితాను మార్చడానికి మీరు [[Special:Userlogin|లాగిన్‌]] అయి ఉండాలి.',
+'watchnologintext'     => 'మీ వీక్షణ జాబితాను మార్చడానికి మీరు [[Special:UserLogin|లాగిన్‌]] అయి ఉండాలి.',
 'addedwatch'           => 'వీక్షణ జాబితాలో చేరింది',
-'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" పేజీ మీ [[Special:Watchlist|వీక్షణ జాబితా]]కు చేరింది. ఇకముందు ఈ పేజీలోను, దీని చర్చా పేజీలోను జరిగే మార్పుచేర్పులన్నీ అక్కడ చేరతాయి. సులభంగా గుర్తించడానికై [[Special:Recentchanges|ఇటీవలి మార్పుల జాబితా]]లో ఈ పేజీ పేరు '''బొద్దుగా''' కనపడుతుంది.
+'addedwatchtext'       => "\"<nowiki>\$1</nowiki>\" పేజీ మీ [[Special:Watchlist|వీక్షణ జాబితా]]కు చేరింది. ఇకముందు ఈ పేజీలోను, దీని చర్చా పేజీలోను జరిగే మార్పుచేర్పులన్నీ అక్కడ చేరతాయి. సులభంగా గుర్తించడానికై [[Special:RecentChanges|ఇటీవలి మార్పుల జాబితా]]లో ఈ పేజీ పేరు '''బొద్దుగా''' కనపడుతుంది.
 
 వీక్షణ జాబితా నుండి ఈ పేజీ తొలగించాలంటే, \"వీక్షించ వద్దు\"ను నొక్కండి.",
 'removedwatch'         => 'వీక్షణ జాబితా నుండి తొలగించబడినది',
@@ -1698,7 +1692,7 @@
 'badipaddress'                    => 'సరైన ఐ.పి. అడ్రసు కాదు',
 'blockipsuccesssub'               => 'నిరోధం విజయవంతం అయింది',
 'blockipsuccesstext'              => '[[Special:Contributions/$1|$1]] నిరోధించబడింది.
-<br />నిరోధాల సమీక్ష కొరకు [[Special:Ipblocklist|ఐ.పి. నిరొధాల జాబితా]] చూడండి.',
+<br />నిరోధాల సమీక్ష కొరకు [[Special:IPBlockList|ఐ.పి. నిరొధాల జాబితా]] చూడండి.',
 'ipb-edit-dropdown'               => 'నిరోధపు కారణాలను మార్చండి',
 'ipb-unblock-addr'                => '$1 పై ఉన్న నిరోధాన్ని తొలగించండి',
 'ipb-unblock'                     => 'సభ్యనామం లేక ఐపీ అడ్రసుపై ఉన్న నిరోధాన్ని తొలగించండి',
@@ -1728,7 +1722,7 @@
 'autoblocker'                     => 'మీ ఐ.పీ. అడ్రసును "[[User:$1|$1]]" ఇటీవల వాడుట చేత, అది ఆటోమాటిక్‌గా నిరోధించబడినది. $1ను నిరోధించడానికి కారణం: "\'\'\'$2\'\'\'"',
 'blocklogpage'                    => 'నిరోద దినచర్య పేజి',
 'blocklogentry'                   => '"[[$1]]" పై నిరోధం అమలయింది. నిరోధ కాలం $2 $3',
-'blocklogtext'                    => 'సభ్యుల నిరోధాలు, పునస్థాపనల దినచర్య పేజీ ఇది. ఆటోమాటిక్‌గా నిరోధానికి గురైన ఐ.పి. అడ్రసులు ఈ జాబితాలో ఉండవు. ప్రస్తుతం అమల్లో ఉన్న నిరోధాలు, నిషేధాల కొరకు [[Special:Ipblocklist|ఐ.పి. నిరోధాల జాబితా]]ను చూడండి.',
+'blocklogtext'                    => 'సభ్యుల నిరోధాలు, పునస్థాపనల దినచర్య పేజీ ఇది. ఆటోమాటిక్‌గా నిరోధానికి గురైన ఐ.పి. అడ్రసులు ఈ జాబితాలో ఉండవు. ప్రస్తుతం అమల్లో ఉన్న నిరోధాలు, నిషేధాల కొరకు [[Special:IPBlockList|ఐ.పి. నిరోధాల జాబితా]]ను చూడండి.',
 'unblocklogentry'                 => '$1పై నిరోధం తొలగించబడింది',
 'block-log-flags-anononly'        => 'అజ్ఞాత వాడుకర్లు మాత్రమే',
 'block-log-flags-nocreate'        => 'ఖాతా సృష్టించడాన్ని అశక్తం చేసాం',
@@ -1792,8 +1786,6 @@
 
 ఆ సందర్భాలలో, మీరు చర్చా పేజీని కూడా పనిగట్టుకుని తరలించవలసి ఉంటుంది, లేదా ఏకీకృత పరచవలసి ఉంటుంది.",
 'movearticle'             => 'పేజీని తరలించు',
-'movenologin'             => 'లాగిన్‌ అయిలేరు',
-'movenologintext'         => 'పేజీని తరలించడానికి మీరు [[Special:Userlogin|లాగిన్‌]] అయిఉండాలి.',
 'movenotallowed'          => '{{SITENAME}}లో పేజీలను తరలించడానికి మీకు అనుమతి లేదు.',
 'newtitle'                => 'కొత్త పేరుకి',
 'move-watch'              => 'ఈ పేజీని గమనించు',
@@ -1820,7 +1812,7 @@
 'delete_and_move'         => 'తొలగించి, తరలించు',
 'delete_and_move_text'    => '==తొలగింపు అవసరం==
 
-ఉద్దేశించిన వ్యాసం "[[$1]]" ఇప్పటికే ఉనికిలో ఉంది. ప్రస్తుత తరలింపుకు వీలుగా దాన్ని తొలగించేయమంటారా?',
+ఉద్దేశించిన వ్యాసం "[[:$1]]" ఇప్పటికే ఉనికిలో ఉంది. ప్రస్తుత తరలింపుకు వీలుగా దాన్ని తొలగించేయమంటారా?',
 'delete_and_move_confirm' => 'అవును, పేజీని తొలగించు',
 'delete_and_move_reason'  => 'తరలింపుకు వీలుగా తొలగించబడింది',
 'selfmove'                => 'మూలం, గమ్యం పేర్లు ఒకటే; పేజీని దాని పైకే తరలించడం కుదరదు.',
@@ -2049,7 +2041,7 @@
 'show-big-image'       => 'అసలు పరిమాణం',
 'show-big-image-thumb' => '<small>ఈ మునుజూపు సైజు: $1 × $2 pixels</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'కొత్త ఫైళ్ళ కొలువు',
 'imagelisttext'         => "ఇది $2 వారీగా పేర్చిన  '''$1''' {{PLURAL:$1|పైలు|ఫైళ్ళ}} జాబితా.",
 'newimages-summary'     => 'ఈ ప్రత్యేక పేజీ ఇటీవలే అప్లోడయిన బొమలను చూపిస్తుంది',
@@ -2333,7 +2325,7 @@
 
 # External editor support
 'edit-externally'      => 'బయటి అప్లికేషను వాడి ఈ ఫైలును మార్చు',
-'edit-externally-help' => 'మరింత సమాచారం కొరకు [http://meta.wikimedia.org/wiki/Help:External_editors సెటప్‌ సూచనలు] చూడండి.',
+'edit-externally-help' => 'మరింత సమాచారం కొరకు [http://www.mediawiki.org/wiki/Manual:External_editors సెటప్‌ సూచనలు] చూడండి.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'అన్నీ',
@@ -2399,7 +2391,7 @@
 'recreate'            => 'మళ్లీ సృష్టించు',
 
 # HTML dump
-'redirectingto' => '[[$1]]కు మళ్ళించబడుతుంది...',
+'redirectingto' => '[[:$1]]కు మళ్ళించబడుతుంది...',
 
 # action=purge
 'confirm_purge'        => 'ఈ పేజీ యొక్క పాత కాపీని తొలగించమంటారా?
@@ -2494,7 +2486,7 @@
 'version-software-product'         => 'ప్రోడక్టు',
 'version-software-version'         => 'వెర్షను',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'పూర్తి చిరునామా',
 'filepath-page'    => '{{ns:image}}:',
 'filepath-submit'  => 'చిరునామా',
@@ -2531,7 +2523,7 @@
 'specialpages-group-redirects'   => 'ప్రత్యేక పేజీల దారిమార్పులు',
 'specialpages-group-spam'        => 'స్పామ్ పనిముట్లు',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'ఖాళీ పేజీ',
 'intentionallyblankpage' => 'బెంచిమార్కింగు, మొదలగు వాటికై ఈ పేజీని కావాలనే ఖాళీగా వదిలాము.',
 
Index: languages/messages/MessagesLo.php
===================================================================
--- languages/messages/MessagesLo.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLo.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,10 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Tuinui
  * @author Passawuth
- * @author Siebrand
- * @author Jon Harald Søby
+ * @author Tuinui
  */
 
 $namespaceNames = array(
@@ -339,8 +337,6 @@
 'blockededitsource'        => "ເນື້ອໃນ ຂອງ '''ການດັດແປງໂດຍທ່ານ '''ຕໍ່ກັບ '''$1''' ມີດັ່ງລຸ່ມນີ້:",
 'whitelistedittitle'       => 'ຕ້ອງເຊັນເຂົ້າ ຈຶ່ງຈະສາມາດດັດແກ້ໄດ້',
 'whitelistedittext'        => 'ທ່ານ ຈະຕ້ອງ  $1 ເພື່ອ ຈະດັດແກ້.',
-'whitelistreadtitle'       => 'ຈະຕ້ອງ ເຊັນເຂົ້າ ເພື່ອອ່ານໜ້ານີ້',
-'whitelistacctitle'        => 'ທ່ານຖືກຫ້າມສ້າງບັນຊີ',
 'confirmedittitle'         => 'ຕ້ອງຢືນຢັນ ທີ່ຢູ່ ອີເມລ ຈຶ່ງຈະສາມາດ ດັດແກ້',
 'loginreqtitle'            => 'ຈຳເປັນຕ້ອງ ເຊັນເຂົ້າ',
 'loginreqlink'             => 'ເຊັນເຂົ້າ',
@@ -369,7 +365,7 @@
 'template-protected'       => '(ປົກປ້ອງ)',
 'template-semiprotected'   => '(ເຄິ່ງປົກປ້ອງ)',
 'nocreatetext'             => '{{SITENAME}} ໄດ້ຈຳກັດການສ້າງໜ້າໃໝ່.
-ທ່ານສາມາດກັບໄປ ດັດແກ້ ໜ້າທີ່ມີແລ້ວ ຫຼື [[Special:Userlogin|ເຊັນເຂົ້າ ຫຼື ສ້າງບັນຊີ]].',
+ທ່ານສາມາດກັບໄປ ດັດແກ້ ໜ້າທີ່ມີແລ້ວ ຫຼື [[Special:UserLogin|ເຊັນເຂົ້າ ຫຼື ສ້າງບັນຊີ]].',
 
 # Account creation failure
 'cantcreateaccounttitle' => 'ບໍ່ສາມາດສ້າງ ບັນຊີ ໄດ້',
@@ -495,7 +491,7 @@
 'savefile'          => 'ບັນທຶກໄຟລ໌',
 'watchthisupload'   => 'ຕິດຕາມໜ້ານີ້',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'ລາຍຊື່ໄຟລ໌',
 
 # Image description page
@@ -584,7 +580,7 @@
 'log-search-submit' => 'ໄປ',
 'logempty'          => 'ຍັງບໍ່ພົບເນື້ອໃນບັນທຶກ.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'ທຸກໆໜ້າ',
 'alphaindexline' => '$1 ຫາ $2',
 'nextpage'       => 'ໜ້າຕໍ່ໄປ ($1)',
@@ -600,7 +596,7 @@
 'categories'         => 'ໝວດ',
 'categoriespagetext' => 'ມີ ບັນດາ ໝວດ ຕໍ່ໄປນີ້ ຢູ່ ວິກີ.',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit' => 'ສະແດງ',
 
 # E-mail user
@@ -736,7 +732,6 @@
 'movepagetext'            => 'ທ່ານສາມາດ ປ່ຽນຊື່ໜ້າ ແລະ ຍ້າຍປະຫວັດການດັດແກ້ ຂອງໜ້າໃດໜຶ່ງ ໄປ ໜ້າໃໝ',
 'movepagetalktext'        => "ໜ້າສົນທະນາຈະຖືກຍ້າຍໄປພ້ອມກັນ '''ເວັ້ນເສຍແຕ່:''",
 'movearticle'             => 'ຍ້າຍໜ້າ:',
-'movenologin'             => 'ຍັງບໍ່ໄດ້ເຊັນເຂົ້າເທື່ອ',
 'newtitle'                => 'ຫາ ຫົວຂໍ້ໃໝ່',
 'move-watch'              => 'ຕິດຕາມໜ້ານີ້',
 'movepagebtn'             => 'ຍ້າຍໜ້າ',
@@ -821,7 +816,7 @@
 'show-big-image'       => 'ເຕັມຂະໜາດ',
 'show-big-image-thumb' => '<small>ຂະໜາດລອງເບິ່ງ: $1 × $2 ປິກເຊລ</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'         => 'ໄຟລ໌ຮູບໃໝ່',
 'newimages-summary' => 'ໜ້າພິເສດນີ້ສະແດງໄຟລ໌ທີ່ຖຶກອັປໂຫຼດຫຼ້າສຸດ',
 'noimages'          => 'ບໍ່ມີຫຍັງເບິ່ງ.',
@@ -840,7 +835,7 @@
 
 # External editor support
 'edit-externally'      => 'ດັດແກ້ໄຟລ໌ນີ້ໂດຍໂປແກຣມພາຍນອກ',
-'edit-externally-help' => 'ເບິ່ງ ຂໍ້ມູນເພີ່ມຕື່ມ ຢູ່ [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions]',
+'edit-externally-help' => 'ເບິ່ງ ຂໍ້ມູນເພີ່ມຕື່ມ ຢູ່ [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions]',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ທັງໝົດ',
@@ -875,7 +870,7 @@
 'recreate' => 'ສ້າງຄືນ',
 
 # HTML dump
-'redirectingto' => 'ພວມໂອນໄປ ຫາ [[$1]]...',
+'redirectingto' => 'ພວມໂອນໄປ ຫາ [[:$1]]...',
 
 # action=purge
 'confirm_purge_button' => 'ຕົກລົງ',
@@ -904,7 +899,7 @@
 # Special:Version
 'version' => 'ສະບັບ', # Not used as normal message but as header for the special page itself
 
-# Special:Filepath
+# Special:FilePath
 'filepath' => 'ທາງໄປຫາໄຟລ໌',
 
 # Special:SpecialPages
Index: languages/messages/MessagesHt.php
===================================================================
--- languages/messages/MessagesHt.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHt.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,9 +4,8 @@
  * @ingroup Language
  * @file
  *
- * @author Masterches
  * @author Jvm
- * @author Siebrand
+ * @author Masterches
  */
 
 $fallback = 'fr';
@@ -312,7 +311,7 @@
 'nosuchspecialpage' => 'Pa gen paj especial konsa',
 'nospecialpagetext' => "<big>'''Paj espesial ou demande-a envalid.'''</big>
 
-Ou ka jwenn yon lis paj espesial ki valid yo la [[Special:Specialpages|{{int:specialpages}}]].",
+Ou ka jwenn yon lis paj espesial ki valid yo la [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Erè',
@@ -551,10 +550,6 @@
 'blockededitsource'                => "Kontni '''modifikasyon ou yo''' nan '''$1''' ekri pli ba :",
 'whitelistedittitle'               => 'Ou dwèt konekte w pou ou kapab edite ak modifye atik sa, kontni sa',
 'whitelistedittext'                => 'Ou dwèt gen fonksyon sa $1 pou ou kapab genyen dwa pou modifye kontni sa.',
-'whitelistreadtitle'               => 'Ou dwèt konekte w si ou ta vle kontni sa',
-'whitelistreadtext'                => 'Ou dwèt [[Special:Userlogin|konekte]] pou ou kapab li kontni sa.',
-'whitelistacctitle'                => 'Ou pa otorize kreye yon kont.',
-'whitelistacctext'                 => 'Pou ou kapab kreye yon kont sou Wiki sa, ou dwèt [[Special:Userlogin|konekte]] epitou genyen pèmisyon ou dwèt genyen yo.',
 'confirmedittitle'                 => 'Adrès imèl ou an dwèt valide pou ou kapab modifye kontni sa',
 'confirmedittext'                  => 'Ou dwèt konfime adrès imèl ou an anvan ou modifye paj {{SITENAME}} sa. Antre epi valide adrès elektwonik ou an ak èd ou kapab twouve nan paj sa [[Special:Preferences|preferans]].',
 'nosuchsectiontitle'               => 'Seksyon sa pa gen anyen sou li',
@@ -570,7 +565,7 @@
 Pou ou kapab kreye paj sa a, komanse ap ekri nan bwat sa a ki anba (gade [[{{MediaWiki:Helppage}}|paj èd an]] pou konnen plis, pou plis enfòmasyon).
 
 Si se paske ou komèt yon erè ke ou ap twouve ou nan paj sa a, klike anlè bouton '''ritounen''' nan bwozè ou a.",
-'anontalkpagetext'                 => "---- ''Ou nan paj diskisyon yon itilizatè anonim, ki pa gen non, ki poko kreye yon kont oubyen ki pa itilize pyès kont nan sistèm sa. Pou rezon sa, nou dwèt itilize adrès IP l pou nou kapab lokalize l, sitye l, montre kote l rete, idantifye l. Yon adrès IP kapab pataje ant plizyè moun, plizyè itilizatè. Si ou se yon itilizatè anonim e si ou wè ke ou resevwa komantè ki pa te pou ou, ou mèt [[Special:Userlogin|kreye yon kont oubyen konekte w]] pou ou kapab anpeche difikilte sa yo, move bagay sa yo ant lòt itilizatè yo, kontribitè anonim yo.''",
+'anontalkpagetext'                 => "---- ''Ou nan paj diskisyon yon itilizatè anonim, ki pa gen non, ki poko kreye yon kont oubyen ki pa itilize pyès kont nan sistèm sa. Pou rezon sa, nou dwèt itilize adrès IP l pou nou kapab lokalize l, sitye l, montre kote l rete, idantifye l. Yon adrès IP kapab pataje ant plizyè moun, plizyè itilizatè. Si ou se yon itilizatè anonim e si ou wè ke ou resevwa komantè ki pa te pou ou, ou mèt [[Special:UserLogin|kreye yon kont oubyen konekte w]] pou ou kapab anpeche difikilte sa yo, move bagay sa yo ant lòt itilizatè yo, kontribitè anonim yo.''",
 'noarticletext'                    => 'Poko genyen tèks nan paj sa a, ou mèt [[Special:Search/{{PAGENAME}}|fè yon rechèch, fouye ak non paj sa a]] oubyen [{{fullurl:{{FULLPAGENAME}}|action=edit}} modifye li].',
 'userpage-userdoesnotexist'        => 'Kont itilizatè « $1 » sa pa anrejistre. Verifye toutbon ke ou vle kreye paj sa.',
 'clearyourcache'                   => "'''Note bagay sa:''' depi ou pibliye paj sa, ou dwèt fòse chajman, rafrechi paj an; ou mèt bliye kontni kach sistèm bwozè (navigatè entènèt ou an) kounye a pou ou kapab wè chanjman yo : '''Mozilla / Firefox / Konqueror / Safari :''' mentni touch ''lèt kapital'' ak klike sou bouton ''Rafrechi/Aktyalize'' oubyen peze ''Maj-Ctrl-R'' (''Maj-Cmd-R'' sou sistèm Apple Mac) ; '''Internet Explorer / Opera :''' mentni touch ''Ctrl'' pandan ou ap prese bouton ''Rafrechi/Aktyalize'' oubyen peze ''Ctrl-F5''.",
@@ -608,7 +603,7 @@
 'template-semiprotected'           => '(semi-pwoteje)',
 'hiddencategories'                 => 'Paj sa ap fè pati {{PLURAL:$1|Kategori kache|Kategori yo ki kache}} :',
 'nocreatetitle'                    => 'Kreyasyon paj yo limite',
-'nocreatetext'                     => 'Pajwèb sa a anpeche kreyasyon nouvo paj sou li. Ou mèt ritounen nan brozè ou epi modifye yon paj ki deja egziste oubyen  [[Special:Userlogin|konekte ou oubyen kreye yon kont]].',
+'nocreatetext'                     => 'Pajwèb sa a anpeche kreyasyon nouvo paj sou li. Ou mèt ritounen nan brozè ou epi modifye yon paj ki deja egziste oubyen  [[Special:UserLogin|konekte ou oubyen kreye yon kont]].',
 'nocreate-loggedin'                => 'Ou gen lè pa gen pèmisyon pou ou kapab kreye paj nan wiki sa.',
 'permissionserrors'                => 'Erè nan pèmisyon yo',
 'permissionserrorstext'            => 'Ou pa gen otorizasyon pou fè operasyon ke ou mande a pou {{PLURAL:$1|rezon sa|rezon sa yo}} :',
@@ -669,6 +664,7 @@
 'revdelete-unsuppress'      => 'Anlve restriksyon yo sou vèsyon yo ki restore',
 'revdelete-log'             => 'Komantè pou istorik paj sa :',
 'revdelete-submit'          => 'Aplike sou vèsyon ki seleksyone a',
+'revdelete-logentry'        => 'Vizibilite pou vèsyon sa modifye pou [[$1]]',
 'revdel-restore'            => 'Modifye, chanje vizibilite a',
 'pagehist'                  => 'Istorik paj sa',
 'deletedhist'               => 'Istorik sipresyon yo',
@@ -738,7 +734,7 @@
 'uploadlogpage' => 'Istorik chajman pou fichye miltimedya',
 'uploadedimage' => 'chaje « [[$1]] »',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Lis fichye yo',
 
 # Image description page
@@ -825,7 +821,7 @@
 'log'                  => 'Jounal yo',
 'all-logs-page'        => 'Tout jounal yo (istorik yo)',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'       => 'Tout paj yo',
 'alphaindexline' => '$1 jiska $2',
 'nextpage'       => 'Paj swivan ($1)',
@@ -850,7 +846,7 @@
 'watchlistfor'         => "(pou itilizatè '''$1''')",
 'addedwatch'           => 'Ajoute nan lis swivi',
 'addedwatchtext'       => 'Paj « <nowiki>$1</nowiki> » an byen ajoute nan [[Special:Watchlist|lis swivi ou an]].
-Pwochen modifikasyon nan paj sa a ke make na lis swivi ou an, paj an ke parèt <b>fonse </b> nan [[Special:Recentchanges|chanjman ki fèk fèt]] pou ou kapab wè yo pli fasilman.',
+Pwochen modifikasyon nan paj sa a ke make na lis swivi ou an, paj an ke parèt <b>fonse </b> nan [[Special:RecentChanges|chanjman ki fèk fèt]] pou ou kapab wè yo pli fasilman.',
 'removedwatch'         => 'Retire nan lis swivi',
 'removedwatchtext'     => 'Paj « [[:$1]] » byen retire nan lis swivi ou an.',
 'watch'                => 'Swiv',
@@ -1041,7 +1037,7 @@
 'show-big-image'       => 'Imaj pli gwo, pli fin',
 'show-big-image-thumb' => '<small>Lajè kout zye sa a : $1 × $2 piksèl</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Galri pou nouvo fichye yo',
 
 # Bad image list
@@ -1065,7 +1061,7 @@
 
 # External editor support
 'edit-externally'      => 'Modifye fichye sa a epi yon aplikasyon pa ou (ki pa nan sistèm an, sou machin ou pa egzanp).',
-'edit-externally-help' => 'Wè [http://meta.wikimedia.org/wiki/Help:External_editors komannd ak enstriksyon yo] pou plis enfòmasyon oubyen pou konnen plis.',
+'edit-externally-help' => 'Wè [http://www.mediawiki.org/wiki/Manual:External_editors komannd ak enstriksyon yo] pou plis enfòmasyon oubyen pou konnen plis.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'tout',
Index: languages/messages/MessagesHil.php
===================================================================
--- languages/messages/MessagesHil.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesHil.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,7 +6,6 @@
  *
  * @author Jose77
  * @author Kguirnela
- * @author Siebrand
  */
 
 $messages = array(
@@ -217,7 +216,7 @@
 # Special:Log
 'log-search-submit' => 'Lakat',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 sa $2',
 'allpagessubmit' => 'Sige',
 
@@ -255,7 +254,6 @@
 # Move page
 'move-page-legend' => 'Saylohon ining panid',
 'movearticle'      => 'Saylohon ining panid:',
-'movenologin'      => 'Wala naka-sulod',
 'move-watch'       => 'Bantayan ining panid',
 'movepagebtn'      => 'Saylohon ining panid',
 'movedto'          => 'gin saylo sa',
@@ -288,7 +286,7 @@
 # Media information
 'show-big-image' => 'Kabilogan nga resolusyon',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Pangita-a',
 
 # 'all' in various places, this might be different for inflected languages
Index: languages/messages/MessagesTi.php
===================================================================
--- languages/messages/MessagesTi.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTi.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -117,7 +117,7 @@
 # Upload
 'savefile' => 'ምስሊ ኣቐምጥ',
 
-# Special:Imagelist
+# Special:ImageList
 'imgfile'        => 'ምስሊ',
 'imagelist'      => 'ምስልታት',
 'imagelist_name' => 'ሽም',
@@ -137,7 +137,7 @@
 'specialloguserlabel' => 'ኣባል:',
 'log-search-submit'   => 'ኪድ',
 
-# Special:Allpages
+# Special:AllPages
 'alphaindexline' => '$1 ናብ $2',
 'nextpage'       => 'ዝቕጽል ፅሑፍ ($1)',
 'prevpage'       => 'ናይ ቀደም ፅሑፍ ($1)',
@@ -169,7 +169,7 @@
 # Tooltip help for the actions
 'tooltip-pt-preferences' => 'ናተይ ኣማረጽቲ',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'ድሉይ',
 
 # Metadata
Index: languages/messages/MessagesLij.php
===================================================================
--- languages/messages/MessagesLij.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesLij.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,10 @@
  * @ingroup Language
  * @file
  *
- * @author ZeneizeForesto
- * @author Siebrand
- * @author SPQRobin
- * @author Malafaya
- * @author Jon Harald Søby
  * @author Dario vet
  * @author Dedee
+ * @author Malafaya
+ * @author ZeneizeForesto
  */
 
 $fallback = 'it';
@@ -369,9 +366,6 @@
 'blockededitsource'      => "O testo de i '''teu cangiamenti''' a '''$1''' o l'è chi sotta:",
 'whitelistedittitle'     => "Bezêugna registrâse pe modificâ 'na pagina.",
 'whitelistedittext'      => 'Pe cangia sta pagina devvi $1.',
-'whitelistreadtitle'     => 'Besêugna registrâse pe poéi lêze.',
-'whitelistreadtext'      => "Ti dêvi [[Special:Userlogin|intrâ]] pe lêze 'sta pagina.",
-'whitelistacctitle'      => 'Ti non ti peu registräte',
 'loginreqtitle'          => "Besêugna registrâse primma de modificâ 'sta paggina.",
 'accmailtitle'           => 'Pòula segretta spedïa',
 'accmailtext'            => 'A pòula segretta pe-o utente "$1" a l\'è stæta spedïa a o indirisso $2.',
@@ -399,7 +393,7 @@
 'template-protected'     => '(protezûo)',
 'template-semiprotected' => '(semiprotezûo)',
 'nocreatetext'           => "A poscibilitæ de creâ nêuve paggine insce {{SITENAME}} a l'è stæta limitâ solo a-i ûtenti registræ.
-O se pêu tornâ inderê e modificâ 'na paggina escistente, oppûre [[Special:Userlogin|intrâ ò creâ 'n accesso nêuvo]].",
+O se pêu tornâ inderê e modificâ 'na paggina escistente, oppûre [[Special:UserLogin|intrâ ò creâ 'n accesso nêuvo]].",
 'recreate-deleted-warn'  => "'''Attension: o se sta pe ricreâ 'na paggina zà scassâa into passòu.'''
 
 O se deive consciderâ se o l'è davvei corretto continuâ avanti a modificâ 'sta paggina.
@@ -529,7 +523,7 @@
 'license'   => 'Permisso:',
 'nolicense' => 'Nisciûnn-a liçensa indicâa',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for' => "Çerca pe nomme de l'imàgine:",
 'imgfile'              => 'papê',
 'imagelist'            => "Lista d'archivvi",
@@ -635,7 +629,7 @@
 'alllogstext'          => 'Presentaçion unega de tutti i registri do scito {{SITENAME}}.
 Ti te peu strinza a vista se ti te çerni un tipo de registro, un nomme de un utente o de pagina.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tûtte e paggine',
 'alphaindexline'    => 'Da $1 a $2',
 'nextpage'          => 'Proscima paggina ($1)',
@@ -656,7 +650,7 @@
 'special-categories-sort-count' => 'ordenâ pe nûmmero',
 'special-categories-sort-abc'   => 'ordenâ arfabeticamente',
 
-# Special:Listusers
+# Special:ListUsers
 'listusers-submit'   => 'Fanni vedde',
 'listusers-noresult' => 'Utente non trovöo.',
 
@@ -679,9 +673,9 @@
 'mywatchlist'          => 'Lista in osservaçion',
 'watchlistfor'         => "(pe '''$1''')",
 'watchnologin'         => "Non ti t'æ entroö",
-'watchnologintext'     => 'Devvi [[Special:Userlogin|entrâ]] pe cangiâ a toa lista in osservaçion.',
+'watchnologintext'     => 'Devvi [[Special:UserLogin|entrâ]] pe cangiâ a toa lista in osservaçion.',
 'addedwatch'           => 'Azzonto a a lista in osservaçion',
-'addedwatchtext'       => "A paggina \"[[:\$1]]\" a l'è stæta azzonta a-a pròpia [[Special:Watchlist|lista in osservaçion]]. De chì in avanti, i cangiamenti fæti a-a paggina e a-a sêu discûxon sajàn missi in lista lì; o tittolo da paggina o sajà scrîo in '''grascietto''' inta paggina di [[Special:Recentchanges|ûrtimi cangiamenti]] coscì ti o veddi megio. Se ti vêu eliminâla da-a lista in osservaçion ciû târdi, sciacca \"no seguî\" inscia barra de d'âto.",
+'addedwatchtext'       => "A paggina \"[[:\$1]]\" a l'è stæta azzonta a-a pròpia [[Special:Watchlist|lista in osservaçion]]. De chì in avanti, i cangiamenti fæti a-a paggina e a-a sêu discûxon sajàn missi in lista lì; o tittolo da paggina o sajà scrîo in '''grascietto''' inta paggina di [[Special:RecentChanges|ûrtimi cangiamenti]] coscì ti o veddi megio. Se ti vêu eliminâla da-a lista in osservaçion ciû târdi, sciacca \"no seguî\" inscia barra de d'âto.",
 'removedwatch'         => 'Scassæ da a lista in osservaçion',
 'removedwatchtext'     => 'A paggina "[[:$1]]" a l\'è stæta scassâa da-a têu lista in osservaçion.',
 'watch'                => 'Inta lista in osservaçion',
@@ -802,7 +796,7 @@
 'badipaddress'                => 'Indirisso IP non valido',
 'blockipsuccesssub'           => 'Affermaçion arriescïa',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] o l'è stæto affermoö.
-<br />Veddi [[Special:Ipblocklist|Lista de i indirissi IP affermæ]] te cangia e affermaçioin.",
+<br />Veddi [[Special:IPBlockList|Lista de i indirissi IP affermæ]] te cangia e affermaçioin.",
 'ipblocklist'                 => "Lista de l'indirissi IP e nommi d'ûtenti bloccæ",
 'blocklistline'               => "$1, $2 o l'ha affermoö $3 fin a $4",
 'anononlyblock'               => 'Non ti tè registroö. Non ti peu fanni de i cangiamenti! (Registräse o non vegne ninte!)',
@@ -817,7 +811,7 @@
 'blocklogentry'               => "O s'ha bloccòu [[$1]] scinn-a $2 $3",
 'blocklogtext'                => "Sta chie a l'è unn-a lista de affermaçioin fæte e levæ.
 I indirissi IP affermæ automaticamente non son  consideræ.
-Veddi a [[Special:Ipblocklist|Lista de i indirissi IP affermæ]] pe e informaçioin neuve.",
+Veddi a [[Special:IPBlockList|Lista de i indirissi IP affermæ]] pe e informaçioin neuve.",
 'block-log-flags-anononly'    => 'Utenti anonimmi soö',
 'block-log-flags-nocreate'    => 'Neuve registrascioin non son permisse',
 'block-log-flags-noautoblock' => "O blocco automatego o non l'è attïvo",
@@ -947,7 +941,7 @@
 'show-big-image'       => "Verscion d'ærta resolûxon",
 'show-big-image-thumb' => "<small>Dimensioîn de 'st'anteprimma: $1 × $2 pixel</small>",
 
-# Special:Newimages
+# Special:NewImages
 'newimages' => 'Gallerîa de nêuvi archivvi',
 'ilsubmit'  => 'Çerca',
 'bydate'    => 'pe dâta',
@@ -979,7 +973,7 @@
 
 # External editor support
 'edit-externally'      => "Modiffica 'st'archivvio co unn-a applicassion esterna",
-'edit-externally-help' => "Pe ciû informassion consûltâ l' [http://meta.wikimedia.org/wiki/Help:External_editors istrûssioîn] (in ingleise)",
+'edit-externally-help' => "Pe ciû informassion consûltâ l' [http://www.mediawiki.org/wiki/Manual:External_editors istrûssioîn] (in ingleise)",
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'Tùtti',
Index: languages/messages/MessagesXh.php
===================================================================
--- languages/messages/MessagesXh.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesXh.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -116,7 +116,7 @@
 'move'         => 'Dlulisa',
 'movethispage' => 'Dlulisa eliphepha',
 
-# Special:Allpages
+# Special:AllPages
 'allinnamespace' => 'Amanqaku onke ($1 namespace)',
 
 # Watchlist
@@ -141,7 +141,7 @@
 '1movedto2'        => '[[$1]] lidluliselwe [[$2]]',
 'movereason'       => 'Isizathu',
 
-# Special:Newimages
+# Special:NewImages
 'ilsubmit' => 'Khangela',
 
 # Special:SpecialPages
Index: languages/messages/MessagesSco.php
===================================================================
--- languages/messages/MessagesSco.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesSco.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,13 +4,11 @@
  * @ingroup Language
  * @file
  *
- * @author OchAyeTheNoo
- * @author SPQRobin
- * @author Siebrand
- * @author לערי ריינהארט
  * @author Malafaya
+ * @author OchAyeTheNoo
  * @author Ushanka
  * @author sco.wikipedia.org editors
+ * @author לערי ריינהארט
  */
 
 $messages = array(
@@ -279,7 +277,7 @@
 'nosuchspecialpage' => 'Nae sic byordinar page',
 'nospecialpagetext' => "<big>'''Ye hae requestit an invalid byordinar page.'''</big>
 
-A leet o valid byordinar pages can be funnd at [[Special:Specialpages|{{int:specialpages}}]].",
+A leet o valid byordinar pages can be funnd at [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Error',
@@ -508,10 +506,6 @@
 'blockededitsource'         => "The text o '''your edits''' tae '''$1''' is shawn ablo:",
 'whitelistedittitle'        => 'Login needit tae edit',
 'whitelistedittext'         => 'Ye hae tae $1 tae edit pages.',
-'whitelistreadtitle'        => 'Login requirit tae leuk at this',
-'whitelistreadtext'         => 'Ye hae tae [[Special:Userlogin|login]] tae leuk at pages.',
-'whitelistacctitle'         => 'Ye arnae alloued tae mak an accoont',
-'whitelistacctext'          => 'Tae be alloued tae mak accoonts in this wiki ye hae tae [[Special:Userlogin|log in]] an hae the richt leave.',
 'confirmedittitle'          => 'E-mail confirmation needit for tae edit',
 'confirmedittext'           => 'Ye maun confirm yer e-mail address afore editin pages. Please set an validate yer e-mail address throu yer [[Special:Preferences|uiser settins]].',
 'nosuchsectiontitle'        => 'There isnae a section wi that teetle',
@@ -523,7 +517,7 @@
 'accmailtext'               => "The Password for '$1' haes been sent tae $2.",
 'newarticle'                => '(New)',
 'newarticletext'            => "Ye'v follaed an airtin til a page that disna exist yet. Tae create the page, stert typin in the box ablo (see the [[{{MediaWiki:Helppage}}|help page]] for mair info). Gin ye'r here by mistak, juist dab yer brouser's '''back''' button.",
-'anontalkpagetext'          => "----''This is the collogue page for a nameless uiser that haesna made an accoont yet or that disna uise it. We syne hiv tae uise the numerical IP address tae identifee thaim. Sic an IP address can be shared bi a wheen o uisers. Gin you ar a nameless uiser an feel that irrelevant comments haes been directit at ye, please [[Special:Userlogin|mak an accoont or log in]] tae evyte futur confusion wi ither nameless uisers.''",
+'anontalkpagetext'          => "----''This is the collogue page for a nameless uiser that haesna made an accoont yet or that disna uise it. We syne hiv tae uise the numerical IP address tae identifee thaim. Sic an IP address can be shared bi a wheen o uisers. Gin you ar a nameless uiser an feel that irrelevant comments haes been directit at ye, please [[Special:UserLogin|mak an accoont or log in]] tae evyte futur confusion wi ither nameless uisers.''",
 'noarticletext'             => "The'r nae text on this page the nou. Ye can [[Special:Search/{{PAGENAME}}|rake for this page teitle]] in ither pages or [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page].",
 'userpage-userdoesnotexist' => 'Uiser accoont "$1" hasnae been registerit. Please check gin ye wint tae mak or edit this page.',
 'clearyourcache'            => "'''Tak tent:''' Efter hainin, ye micht hae tae bypass yer brouser's cache for tae see the chynges. '''Mozilla / Firefox / Safari:''' haud doun ''Shift'' while dabbin on ''Reload'', or press ''Ctrl-Shift-R'' (''Cmd-Shift-R'' on Apple Mac); '''IE:''' haud doun ''Ctrl'' while dabbin on ''Refresh'', or press ''Ctrl-F5''; '''Konqueror:''' juist dab on the ''Reload'' button, or press ''F5''; '''Opera''' users micht hae tae haillie dicht thair cache in ''Tools&rarr;Preferences''.",
@@ -575,7 +569,7 @@
 'template-semiprotected'    => '(semi-protectit)',
 'nocreatetitle'             => 'Page makkin limitit',
 'nocreatetext'              => 'This site haes restrictit the ability to mak new pages.
-Ye can go back an eik tae an existing page, or [[Special:Userlogin|log in or mak an accoont]].',
+Ye can go back an eik tae an existing page, or [[Special:UserLogin|log in or mak an accoont]].',
 'nocreate-loggedin'         => 'Ye dinnae hae the richts tae mak new pages on this wiki.',
 'permissionserrors'         => 'Richts Errors',
 'permissionserrorstext'     => 'Ye dinnae hae the richts tae dae that, acause o the followin {{PLURAL:$1|grund|grunds}}:',
@@ -668,7 +662,7 @@
 # Preferences page
 'mypreferences'      => 'Ma preferences',
 'prefsnologin'       => 'No loggit in',
-'prefsnologintext'   => 'Ye maun be [[Special:Userlogin|loggit in]] tae set uiser preferences.',
+'prefsnologintext'   => 'Ye maun be [[Special:UserLogin|loggit in]] tae set uiser preferences.',
 'prefsreset'         => 'Preferences haes been reset frae storage.',
 'changepassword'     => 'Chynge password',
 'math'               => 'Renderin math',
@@ -723,10 +717,10 @@
 'reupload'                    => 'Re-uplaid',
 'reuploaddesc'                => 'Gang back tae the uplaid form.',
 'uploadnologin'               => 'Nae loggit in',
-'uploadnologintext'           => 'Ye maun be [[Special:Userlogin|loggit in]] til uplaid files.',
+'uploadnologintext'           => 'Ye maun be [[Special:UserLogin|loggit in]] til uplaid files.',
 'uploaderror'                 => 'Uplaid error',
 'uploadtext'                  => "Uise the form ablo tae uplaid new files;
-tae keek at or rake throu aareadies uplaidit eimages gang tae the [[Special:Imagelist|leet o uplaidit files]];
+tae keek at or rake throu aareadies uplaidit eimages gang tae the [[Special:ImageList|leet o uplaidit files]];
 uplaids an deletions is recordit in the [[Special:Log|project log]].
 
 Tae pit the eimage intae a page, uise an airtin i the form
@@ -758,7 +752,7 @@
 
 'nolicense' => 'Nane selected',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist' => 'Eimage leet',
 
 # Image description page
@@ -793,7 +787,7 @@
 That comes tae '''\$5''' average edits per page, and '''\$6''' views per edit.
 
 The [http://www.mediawiki.org/wiki/Manual:Job_queue job queue] length is '''\$7'''.",
-'userstatstext' => "{{PLURAL:$1|There is '''1''' registert [[Special:Listusers|uiser]]|The'r '''$1''' registert [[Special:Listusers|uisers]]}}.
+'userstatstext' => "{{PLURAL:$1|There is '''1''' registert [[Special:ListUsers|uiser]]|The'r '''$1''' registert [[Special:ListUsers|uisers]]}}.
 '''$2''' (or '''$4%''') o thaim {{PLURAL:$2|has|have}} $5 rights.",
 
 'doubleredirects'     => 'Dooble reguidals',
@@ -838,7 +832,7 @@
 'alllogstext'          => 'Combined display o uplaid, deletion, protection, blockin, an administrator logs. Ye can narra doon the view bi walin a log type, the uiser name, or the affectit page.',
 'logempty'             => 'Nae matchin items in log.',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Aa pages',
 'alphaindexline'    => '$1 tae $2',
 'nextpage'          => 'Neist page ($1)',
@@ -861,7 +855,7 @@
 
 # E-mail user
 'mailnologin'     => 'Nae send address',
-'mailnologintext' => 'Ye maun be [[Special:Userlogin|loggit in]] an hae a valid e-mail address in yer [[Special:Preferences|preferences]] tae send e-mail til ither uisers.',
+'mailnologintext' => 'Ye maun be [[Special:UserLogin|loggit in]] an hae a valid e-mail address in yer [[Special:Preferences|preferences]] tae send e-mail til ither uisers.',
 'noemailtitle'    => 'Nae e-mail address',
 'noemailtext'     => "This uiser haesna specifee'd a valid e-mail address, or haes chuisen no tae receive e-mail frae ither uisers.",
 
@@ -870,9 +864,9 @@
 'mywatchlist'          => 'Ma watchleet',
 'nowatchlist'          => 'Ye hivna onie eitems on yer watchleet.',
 'watchnologin'         => 'Nae loggit in',
-'watchnologintext'     => 'Ye maun be [[Special:Userlogin|loggit in]] tae modify yer watchleet.',
+'watchnologintext'     => 'Ye maun be [[Special:UserLogin|loggit in]] tae modify yer watchleet.',
 'addedwatch'           => 'Eikit ti watchleet',
-'addedwatchtext'       => "The page \"<nowiki>\$1</nowiki>\" haes been eikit ti yer [[Special:Watchlist|watchleet]]. Futur chynges ti this page an its associate Collogue page will be leetit thare, an the page will kythe '''bauldit''' in the [[Special:Recentchanges|leet o recent chynges]] ti mak it mair eith tae pick oot. <p>Gin ye want ti remuve the page frae yer watchleet later, dab \"Stop watching\" in the sidebar.",
+'addedwatchtext'       => "The page \"<nowiki>\$1</nowiki>\" haes been eikit ti yer [[Special:Watchlist|watchleet]]. Futur chynges ti this page an its associate Collogue page will be leetit thare, an the page will kythe '''bauldit''' in the [[Special:RecentChanges|leet o recent chynges]] ti mak it mair eith tae pick oot. <p>Gin ye want ti remuve the page frae yer watchleet later, dab \"Stop watching\" in the sidebar.",
 'removedwatch'         => 'Remuved frae watchleet',
 'removedwatchtext'     => 'The page "[[:$1]]" haes been remuved frae yer watchleet.',
 'notanarticle'         => 'No a content page',
@@ -912,7 +906,7 @@
 'alreadyrolled'       => 'Canna rowback last edit o [[$1]] bi [[User:$2|$2]] ([[User talk:$2|Talk]]); some ither bodie haes editit or rowed back the page aareadies. Last edit wis bi [[User:$3|$3]] ([[User talk:$3|Talk]]).',
 'editcomment'         => 'The edit comment wis: "<i>$1</i>".', # only shown if there is an edit comment
 'revertpage'          => 'Revertit edit o [[Special:Contributions/$2|$2]] ([[User talk:$2|Talk]]), chynged back tae last version bi [[User:$1|$1]]', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
-'protectlogtext'      => 'Ablo is a leet o page locks/unlocks. See the [[Special:Protectedpages|protected pages list]] for the list of currently operational page protections.',
+'protectlogtext'      => 'Ablo is a leet o page locks/unlocks. See the [[Special:ProtectedPages|protected pages list]] for the list of currently operational page protections.',
 'protectedarticle'    => 'protectit "[[$1]]"',
 'unprotectedarticle'  => 'unprotectit "[[$1]]"',
 'protect-title'       => 'Protectin "$1"',
@@ -963,7 +957,7 @@
 'badipaddress'                => 'That IP address is nae guid',
 'blockipsuccesssub'           => 'Block succeedit',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] haes been blockit.
-<br />See [[Special:Ipblocklist|IP block leet]] tae review blocks.',
+<br />See [[Special:IPBlockList|IP block leet]] tae review blocks.',
 'unblockip'                   => 'Unblock uiser',
 'unblockiptext'               => 'Uise the form ablo tae restore screivin richts
 tae an afore-blockit IP address or uisername.',
@@ -974,7 +968,7 @@
 'contribslink'                => 'contreibs',
 'autoblocker'                 => 'Autaematically blockit syne yer IP address haes been uised recently bi "[[User:$1|$1]]". The raeson gien for $1\'s block is "\'\'$2\'\'"',
 'blocklogentry'               => 'blockit [[$1]] wi an expiry time o $2 $3',
-'blocklogtext'                => 'This is a log o uiser blockin an unblockin actions. Autaematically blockit IP addresses isna leetit. See the [[Special:Ipblocklist|IP block leet]] for the leet o bans and blocks on the gae the nou.',
+'blocklogtext'                => 'This is a log o uiser blockin an unblockin actions. Autaematically blockit IP addresses isna leetit. See the [[Special:IPBlockList|IP block leet]] for the leet o bans and blocks on the gae the nou.',
 'unblocklogentry'             => 'unblockit $1',
 'range_block_disabled'        => 'The administrator abeility tae mak range blocks is disabled.',
 'proxyblockreason'            => 'Yer IP address haes been blockit sith it is an open proxy. Please contact yer Internet service provider or tech support an inform them o this serious security problem.',
@@ -1011,8 +1005,6 @@
 please be siccar ye unnerstaun the consequences o this afore proceedin.",
 'movepagetalktext'        => "The associate Collogue page, gin onie, will be autaematically flittit alang wi it '''unless:''' *Ye'r flittin the page across namespaces, *A collogue page that isna tuim aareadies exists unner the new name, or *Ye tak the tick oot o the box ablo. In thae cases, ye maun flit or merge the page manually later gin ye hae saicont thochts.",
 'movearticle'             => 'Flit page:',
-'movenologin'             => 'No loggit in',
-'movenologintext'         => 'Ye maun be a registert uiser an [[Special:Userlogin|loggit in]] tae flit a page.',
 'newtitle'                => 'Tae new teitle',
 'movepagebtn'             => 'Flit page',
 'pagemovedsub'            => 'Flittin succeedit',
@@ -1028,7 +1020,7 @@
 'delete_and_move'         => 'Delete an flit',
 'delete_and_move_text'    => '==Deletion caad for==
 
-The destination airticle "[[$1]]" aareadies exists. Div ye want tae delete it for tae mak wey for the flittin?',
+The destination airticle "[[:$1]]" aareadies exists. Div ye want tae delete it for tae mak wey for the flittin?',
 'delete_and_move_confirm' => 'Aye, delete the page',
 'delete_and_move_reason'  => 'Delete for tae mak wey for flittin',
 'selfmove'                => 'Ootgaun an incomin teitles is the same; canna flit a page ower itsel.',
@@ -1122,7 +1114,7 @@
 'mediawarning' => "'''Warnin''': This file micht haud mislushious code; bi executin it yer seestem micht be compromised.<hr />",
 'imagemaxsize' => 'Limit eimages on eimage description pages tae:',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'     => 'Gallery o new files',
 'imagelisttext' => 'Ablo is a leet o $1 {{PLURAL:$1|eimage|eimages}} sortit $2.',
 'noimages'      => 'Naething tae see.',
@@ -1148,7 +1140,7 @@
 
 # External editor support
 'edit-externally'      => 'Edit this file uisin an external application',
-'edit-externally-help' => 'See the [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] for mair guidance.',
+'edit-externally-help' => 'See the [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] for mair guidance.',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'aa',
@@ -1192,7 +1184,7 @@
 Please confirm that ye really want tae recreate this airticle.",
 
 # HTML dump
-'redirectingto' => 'Reguidin tae [[$1]]...',
+'redirectingto' => 'Reguidin tae [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Clair the cache o this page?
Index: languages/messages/MessagesTy.php
===================================================================
--- languages/messages/MessagesTy.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesTy.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,7 +4,6 @@
  * @ingroup Language
  * @file
  *
- * @author SPQRobin
  * @author Sab
  */
 
@@ -124,7 +123,7 @@
 # Recent changes
 'recentchanges' => 'Te mau fa’ahuru-’ē-ra’a ’āpī',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_user' => 'Ta’ata fa’a’ohipa',
 
 # Image description page
@@ -136,7 +135,7 @@
 # Special:Log
 'specialloguserlabel' => 'Ta’ata fa’a’ohipa :',
 
-# Special:Allpages
+# Special:AllPages
 'allpagessubmit' => 'Haere',
 
 # Special:Categories
@@ -158,7 +157,7 @@
 # Tooltip help for the actions
 'tooltip-search' => 'Roromā’imi {{SITENAME}}',
 
-# Special:Filepath
+# Special:FilePath
 'filepath-page' => 'Putu’ite:',
 
 # Special:SpecialPages
Index: languages/messages/MessagesAm.php
===================================================================
--- languages/messages/MessagesAm.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesAm.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -6,12 +6,27 @@
  *
  * @author Codex Sinaiticus
  * @author Teferra
- * @author Siebrand
- * @author SPQRobin
- * @author M.M.S.
- * @author Jon Harald Søby
  */
 
+$namespaceNames = array(
+	'NS_MEDIA'          => 'ፋይል',
+	'NS_SPECIAL'        => 'ልዩ',
+	'NS_TALK'           => 'ውይይት',
+	'NS_USER'           => 'አባል',
+	'NS_USER_TALK'      => 'አባል_ውይይት',
+	'NS_PROJECT_TALK'   => '$1_ውይይት',
+	'NS_IMAGE'          => 'ስዕል',
+	'NS_IMAGE_TALK'     => 'ስዕል_ውይይት',
+	'NS_MEDIAWIKI'      => 'መልዕክት',
+	'NS_MEDIAWIKI_TALK' => 'መልዕክት_ውይይት',
+	'NS_TEMPLATE'       => 'መልጠፊያ',
+	'NS_TEMPLATE_TALK'  => 'መልጠፊያ_ውይይት',
+	'NS_HELP'           => 'እርዳታ',
+	'NS_HELP_TALK'      => 'እርዳታ_ውይይት',
+	'NS_CATEGORY'       => 'መደብ',
+	'NS_CATEGORY_TALK'  => 'መደብ_ውይይት',
+);
+
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'በመያያዣ ስር አስምር',
@@ -156,7 +171,7 @@
 'errorpagetitle'    => 'ስህተት',
 'returnto'          => '(ወደ $1 ለመመለስ)',
 'tagline'           => 'ከ{{SITENAME}}',
-'help'              => 'መመሪያ',
+'help'              => 'እርዳታ ገጽ',
 'search'            => 'ፈልግ',
 'searchbutton'      => 'ፈልግ',
 'go'                => 'ሂድ',
@@ -273,7 +288,7 @@
 'nstab-project'   => 'የፕሮጀክት ገጽ',
 'nstab-image'     => 'ፋይል',
 'nstab-mediawiki' => 'መልዕክት',
-'nstab-template'  => 'ሰም',
+'nstab-template'  => 'መልጠፊያ',
 'nstab-help'      => 'የመመሪያ ገጽ',
 'nstab-category'  => 'ምድብ',
 
@@ -283,7 +298,7 @@
 'nosuchspecialpage' => 'እንዲህ የተባለ ልዩ ገጽ የለም',
 'nospecialpagetext' => "<big>'''ለማይኖር ልዩ ገጽ ጠይቀዋል።'''</big>
 
-የሚኖሩ ልዩ ገጾች ዝርዝር በ[[Special:Specialpages|{{int:specialpages}}]] ሊገኝ ይችላል።",
+የሚኖሩ ልዩ ገጾች ዝርዝር በ[[Special:SpecialPages|{{int:specialpages}}]] ሊገኝ ይችላል።",
 
 # General errors
 'error'                => 'ስኅተት',
@@ -459,7 +474,7 @@
 'showpreview'               => 'ቅድመ እይታ',
 'showlivepreview'           => 'የቀጥታ ቅድመ-ዕይታ',
 'showdiff'                  => 'ማነጻጸሪያ',
-'anoneditwarning'           => "'''ማስታወቂያ:''' እርስዎ አሁን በአባል ስምዎ ያልገቡ ነዎት። ማዘጋጀት ይቻሎታል፤ ነገር ግን ለውጦችዎ በአባል ስም ሳይሆን በቁጥር አድራሻዎ ይመዘገባሉ። ከፈለጉ፥ በአባልነት [[Special:Userlogin|መግባት]] ይችላሉ።",
+'anoneditwarning'           => "'''ማስታወቂያ:''' እርስዎ አሁን በአባል ስምዎ ያልገቡ ነዎት። ማዘጋጀት ይቻሎታል፤ ነገር ግን ለውጦችዎ በአባል ስም ሳይሆን በቁጥር አድራሻዎ ይመዘገባሉ። ከፈለጉ፥ በአባልነት [[Special:UserLogin|መግባት]] ይችላሉ።",
 'missingsummary'            => "'''ማስታወሻ፦''' ማጠቃለያ ገና አላቀረቡም። እንደገና «ገጹን ለማቅረብ» ቢጫኑ፣ ያለ ማጠቃለያ ይላካል።",
 'missingcommenttext'        => 'እባክዎ አስተያየት ከዚህ በታች ያስግቡ።',
 'missingcommentheader'      => "'''ማስታወሻ፦''' ለዚሁ አስተያየት ምንም አርእስት አላቀረቡም። 'ለማቅረብ' እንደገና ቢጫኑ ለውጥዎ ያለ አርዕስት ይሆናል።",
@@ -492,10 +507,6 @@
 'blockededitsource'         => "በ'''$1''' ላይ '''የእርስዎ ለውጦች''' ጽሕፈት ከዚህ ታች ይታያሉ፦",
 'whitelistedittitle'        => 'ለማዘጋጀት መግባት አስቀድሞ ያስፈልጋል',
 'whitelistedittext'         => 'ገጾችን ለማዘጋጀት $1 አስቀድሞ ያስፈልግዎታል።',
-'whitelistreadtitle'        => 'ለማንበብ መግባት አስቀድሞ ያስፈልጋል',
-'whitelistreadtext'         => 'ገጾችን ለማንበብ [[Special:Userlogin|መግባት]] አስቀድሞ ያስፈልግዎታል።',
-'whitelistacctitle'         => 'ብዕር ስም ለመፍጠር ፈቃድ የለዎም።',
-'whitelistacctext'          => 'በ{{SITENAME}} ላይ ብዕር ስም ለመፍጠር፣ አስቀድመው [[Special:Userlogin|መግባት]]ና የሚገባውን ፈቃድ እንዲኖርዎ ያስፈልጋል።',
 'confirmedittitle'          => 'ለማዘጋጀት የኢ-ሜል ማረጋገጫ ያስፈልጋል።',
 'confirmedittext'           => 'ገጽ ማዘጋጀት ሳይችሉ፣ አስቀድመው የኢ-ሜል አድራሻዎን ማረጋገጥ አለብዎት። እባክዎ፣ በ[[Special:Preferences|ምርጫዎችዎ]] በኩል ኢ-ሜል አድራሻዎን ያረጋግጡ።',
 'nosuchsectiontitle'        => 'የማይኖር ክፍል',
@@ -509,7 +520,7 @@
 'newarticletext'            => 'እርስዎ የተከተሉት መያያዣ እስካሁን ወደማይኖር ገጽ የሚወስድ ነው። ገጹን አሁን ለመፍጠር፣ ከታች በሚገኘው ሳጥን ውስጥ መተየብ ይጀምሩ። ለተጨማሪ መረጃ፣ [[{{MediaWiki:Helppage}}|የእርዳታ ገጽን]] ይመልከቱ።
 
 ወደዚህ በስሕተት ከሆነ የመጡት፣ የቃኝውን «Back» ቁልፍ ይጫኑ።',
-'anontalkpagetext'          => "----''ይኸው ገጽ ገና ያልገባ ወይም ብዕር ስም የሌለው ተጠቃሚ ውይይት ገጽ ነው። መታወቂያው በ[[ቁጥር አድራሻ]] እንዲሆን ያስፈልጋል። አንዳንዴ ግን አንድ የቁጥር አድራሻ በሁለት ወይም በብዙ ተጠቃሚዎች የጋራ ሊሆን ይችላል። ስለዚህ ለርስዎ የማይገባ ውይይት እንዳይደርስልዎ፣ [[Special:Userlogin|«መግቢያ»]] በመጫን የብዕር ስም ለማውጣት ይችላሉ።''",
+'anontalkpagetext'          => "----''ይኸው ገጽ ገና ያልገባ ወይም ብዕር ስም የሌለው ተጠቃሚ ውይይት ገጽ ነው። መታወቂያው በ[[ቁጥር አድራሻ]] እንዲሆን ያስፈልጋል። አንዳንዴ ግን አንድ የቁጥር አድራሻ በሁለት ወይም በብዙ ተጠቃሚዎች የጋራ ሊሆን ይችላል። ስለዚህ ለርስዎ የማይገባ ውይይት እንዳይደርስልዎ፣ [[Special:UserLogin|«መግቢያ»]] በመጫን የብዕር ስም ለማውጣት ይችላሉ።''",
 'noarticletext'             => 'በአሁኑ ወቅት በዚህ ገጽ ላይ ምንም ጽሑፍ የለም፤ በሌላ ገጾች [[Special:Search/{{PAGENAME}}|የዚህን ገጽ አርዕስት መፈለግ]] ወይም [{{fullurl:{{FULLPAGENAME}}|action=edit}} አዲስ ገፅ ማዘጋጀት ይችላሉ].',
 'userpage-userdoesnotexist' => 'የብዕር ስም «$1» አልተመዘገበም። እባክዎ ይህን ገጽ ለመፍጠር/ ለማስተካከል የፈለጉ እንደ ሆነ ያረጋግጡ።',
 'usercssjsyoucanpreview'    => "<strong>ምክር፦</strong> ሳይቆጠብ አዲስ CSS/JSዎን ለመሞከር 'ቅድመ እይታ' የሚለውን ይጫኑ።",
@@ -551,7 +562,7 @@
 'template-semiprotected'    => '(በከፊል የተቆለፈ)',
 'hiddencategories'          => 'ይህ ገጽ በ{{PLURAL:$1|1 የተደበቀ መደብ|$1 የተደበቁ መድቦች}} ውስጥ ይገኛል።',
 'nocreatetitle'             => 'የገጽ መፍጠር ተወሰነ',
-'nocreatetext'              => '{{SITENAME}} አዳዲስ ገጾችን ለመፍጠር ያሚያስችል ሁኔታ ከለክሏል። ተመልሰው የቆየውን ገጽ ማዘጋጀት ይችላሉ፤ አለዚያ [[Special:Userlogin|በብዕር ስም መግባት]] ይችላሉ።',
+'nocreatetext'              => '{{SITENAME}} አዳዲስ ገጾችን ለመፍጠር ያሚያስችል ሁኔታ ከለክሏል። ተመልሰው የቆየውን ገጽ ማዘጋጀት ይችላሉ፤ አለዚያ [[Special:UserLogin|በብዕር ስም መግባት]] ይችላሉ።',
 'nocreate-loggedin'         => 'አዲስ ገጽ በ{{SITENAME}} ለመፍጠር ፈቃድ የለዎም።',
 'permissionserrors'         => 'የፈቃድ ስሕተቶች',
 'permissionserrorstext'     => 'ያ አድራጎት አይቻልም - {{PLURAL:$1|ምክንያቱም|ምክንያቶቹም}}፦',
@@ -675,7 +686,7 @@
 'mypreferences'            => 'ምርጫዎች፤',
 'prefs-edits'              => 'የለውጦች ቁጥር:',
 'prefsnologin'             => 'ገና አልገቡም',
-'prefsnologintext'         => 'ምርጫዎችዎን ለማስተካከል አስቀድሞ [[Special:Userlogin|መግባት]] ያስፈልግዎታል።',
+'prefsnologintext'         => 'ምርጫዎችዎን ለማስተካከል አስቀድሞ [[Special:UserLogin|መግባት]] ያስፈልግዎታል።',
 'prefsreset'               => 'ምርጫዎች ከመቆጠቢያ ታድሰዋል።',
 'qbsettings-none'          => 'የለም',
 'qbsettings-fixedleft'     => 'በግራ የተለጠፈ',
@@ -738,7 +749,7 @@
 'userrights-reason'        => 'የመቀየሩ ምክንያት፦',
 'userrights-no-interwiki'  => 'ማዕረጎችን በሌላ ዊኪ ላይ ለማስተካከል ፈቃድ የለዎም።',
 'userrights-nodatabase'    => 'መረጃ-ቤቱ $1 አይኖርም ወይም የቅርብ አካባቢ አይደለም።',
-'userrights-nologin'       => 'የአባል መብቶች ለመወሰን መጋቢ ሆነው [[Special:Userlogin|መግባት]] ያስፈልግዎታል።',
+'userrights-nologin'       => 'የአባል መብቶች ለመወሰን መጋቢ ሆነው [[Special:UserLogin|መግባት]] ያስፈልግዎታል።',
 'userrights-notallowed'    => 'የአባል መብቶች ለማስተካከል ፈቃድ የለዎም።',
 
 # Groups
@@ -807,9 +818,9 @@
 'reupload'                    => 'እንደገና ለመላክ',
 'reuploaddesc'                => 'ለመሰረዝና ወደ መላኪያ ማመልከቻ ለመመለስ',
 'uploadnologin'               => 'ገና አልገቡም',
-'uploadnologintext'           => 'ፋይል ለመላክ አስቀድሞ [[Special:Userlogin|መግባት]] ያስፈልግዎታል።',
+'uploadnologintext'           => 'ፋይል ለመላክ አስቀድሞ [[Special:UserLogin|መግባት]] ያስፈልግዎታል።',
 'uploaderror'                 => 'የመላክ ስሕተት',
-'uploadtext'                  => "በዚህ ማመልከቻ ላይ ፋይል ለመላክ ይችላሉ። ቀድሞ የተላኩት ስዕሎች [[Special:Imagelist|በፋይል / ሥዕሎች ዝርዝር]] ናቸው፤ ከዚህ በላይ የሚጨመረው ፋይል ሁሉ [[Special:Log/upload|በፋይሎች መዝገብ]] ይዘረዝራሉ።
+'uploadtext'                  => "በዚህ ማመልከቻ ላይ ፋይል ለመላክ ይችላሉ። ቀድሞ የተላኩት ስዕሎች [[Special:ImageList|በፋይል / ሥዕሎች ዝርዝር]] ናቸው፤ ከዚህ በላይ የሚጨመረው ፋይል ሁሉ [[Special:Log/upload|በፋይሎች መዝገብ]] ይዘረዝራሉ።
 
 ስዕልዎ በጽሑፍ እንዲታይ '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Filename.jpg]]</nowiki>''' ወይም
 '''<nowiki>[[</nowiki>{{ns:image}}<nowiki>:Filename.png|thumb|ሌላ ጽሑፍ]]</nowiki>''' በሚመስል መልክ ይጠቅሙ።",
@@ -817,7 +828,7 @@
 'upload-preferred'            => 'የተመረጡት የፋይል አይነቶች፦  $1።',
 'upload-prohibited'           => 'ያልተፈቀዱት የፋይል አይነቶች፦ $1።',
 'uploadlog'                   => 'የፋይሎች መዝገብ',
-'uploadlogpage'               => 'የፋይሎች መዝገብ (filelog)',
+'uploadlogpage'               => 'የፋይሎች መዝገብ',
 'uploadlogpagetext'           => 'ይህ መዝገብ በቅርቡ የተላኩት ፋይሎች ሁሉ ያሳያል።',
 'filename'                    => 'የፋይል ስም',
 'filedesc'                    => 'ማጠቃለያ',
@@ -882,7 +893,7 @@
 'upload_source_url'  => ' (ትክክለኛ፣ በግልጽ የሚገኝ URL)',
 'upload_source_file' => ' (በኮምፒውተርዎ ላይ ያለበት ፋይል)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist_search_for'  => 'ለMedia ፋይል ስም ፍለጋ፦',
 'imgfile'               => 'ፋይሉ',
 'imagelist'             => 'የፋይል / ሥዕሎች ዝርዝር',
@@ -921,13 +932,13 @@
 'filerevert-comment'        => 'ማጠቃለያ፦',
 'filerevert-defaultcomment' => 'በ$2፣ $1 ወደ ነበረው ዕትም መለሰው',
 'filerevert-submit'         => 'ማገልበጥ',
-'filerevert-success'        => '<span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' [በ$3፣ $2 ወደ ነበረው $4 እትም] ተመልሷል።</span>',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' [በ$3፣ $2 ወደ ነበረው $4 እትም] ተመልሷል።",
 
 # File deletion
 'filedelete'                  => '$1 ለማጥፋት',
 'filedelete-legend'           => 'ፋይልን ለማጥፋት',
 'filedelete-intro'            => "'''[[Media:$1|$1]]''' ሊያጥፉ ነው።",
-'filedelete-intro-old'        => '<span class="plainlinks">በ[$4 $3፣ $2] እ.ኤ.አ. የነበረው የ\'\'\'[[Media:$1|$1]]\'\'\' እትም ሊያጥፉ ነው።</span>',
+'filedelete-intro-old'        => "በ[$4 $3፣ $2] እ.ኤ.አ. የነበረው የ'''[[Media:$1|$1]]''' እትም ሊያጥፉ ነው።",
 'filedelete-comment'          => 'የማጥፋቱ ምክንያት፦',
 'filedelete-submit'           => 'ይጥፋ',
 'filedelete-success'          => "'''$1''' ጠፍቷል።",
@@ -1064,7 +1075,7 @@
 'logempty'             => '(በመዝገቡ ምንም የለም...)',
 'log-title-wildcard'   => 'ከዚህ ፊደል ጀምሮ አርዕስቶችን ለመፈልግ',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'ገጾች ሁሉ በሙሉ',
 'alphaindexline'    => '$1 እስከ $2 ድረስ',
 'nextpage'          => 'የሚቀጥለው ገጽ (ከ$1 ጀምሮ)',
@@ -1083,14 +1094,14 @@
 'categories'         => 'ምድቦች',
 'categoriespagetext' => 'በዚሁ ሥራ ዕቅድ ውስጥ የሚከተሉ መደቦች ይኖራሉ።',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'ከዚሁ ፊደል ጀምሮ፦',
 'listusers-submit'   => 'ይታይ',
 'listusers-noresult' => 'ማንም ተጠቃሚ አልተገኘም።',
 
 # E-mail user
 'mailnologin'     => 'ምንም መነሻ አድራሻ የለም',
-'mailnologintext' => 'ኢ-ሜል ወደ ሌላ አባል ለመላክ [[Special:Userlogin|መግባት]]ና በ[[Special:Preferences|ምርጫዎችዎ]] ትክክለኛ የኢሜል አድራሻዎ መኖር ያስፈልጋል።',
+'mailnologintext' => 'ኢ-ሜል ወደ ሌላ አባል ለመላክ [[Special:UserLogin|መግባት]]ና በ[[Special:Preferences|ምርጫዎችዎ]] ትክክለኛ የኢሜል አድራሻዎ መኖር ያስፈልጋል።',
 'emailuser'       => 'ለዚህ/ች ሰው ኢሜል መላክ',
 'emailpage'       => 'ወደዚህ/ች አባል ኢ-ሜል ለመላክ',
 'emailpagetext'   => 'አባሉ በሳቸው «ምርጫዎች» ክፍል ተግባራዊ ኢ-ሜል አድራሻ ያስገቡ እንደሆነ፣ ከታች ያለው ማመልከቻ አንድን ደብዳቤ በቀጥታ ይልካቸዋል።
@@ -1116,9 +1127,9 @@
 'nowatchlist'          => 'ዝርዝርዎ ባዶ ነው። ምንም ገጽ ገና አልተጨመረም።',
 'watchlistanontext'    => 'የሚከታተሉት ገጾች ዝርዝርዎን ለመመልከት ወይም ለማስተካከል እባክዎ $1።',
 'watchnologin'         => 'ገና አልገቡም',
-'watchnologintext'     => 'የሚከታተሏቸውን ገጾች ዝርዝር ለመቀየር [[Special:Userlogin|መግባት]] ይኖርብዎታል።',
+'watchnologintext'     => 'የሚከታተሏቸውን ገጾች ዝርዝር ለመቀየር [[Special:UserLogin|መግባት]] ይኖርብዎታል።',
 'addedwatch'           => 'ወደሚከታተሉት ገጾች ተጨመረ',
-'addedwatchtext'       => "ገጹ «$1» [[Special:Watchlist|ለሚከታተሉት ገጾች]] ተጨምሯል። ወደፊት ይህ ገጽ ወይም የውይይቱ ገጽ ሲቀየር፣ በዚያ ዝርዝር ላይ ይታያል። በተጨማሪም [[Special:Recentchanges|«በቅርብ ጊዜ በተለወጡ» ገጾች]] ዝርዝር፣ በቀላሉ እንዲታይ በ'''ጨለማ ጽህፈት''' ተጽፎ ይገኛል።
+'addedwatchtext'       => "ገጹ «$1» [[Special:Watchlist|ለሚከታተሉት ገጾች]] ተጨምሯል። ወደፊት ይህ ገጽ ወይም የውይይቱ ገጽ ሲቀየር፣ በዚያ ዝርዝር ላይ ይታያል። በተጨማሪም [[Special:RecentChanges|«በቅርብ ጊዜ በተለወጡ» ገጾች]] ዝርዝር፣ በቀላሉ እንዲታይ በ'''ጨለማ ጽህፈት''' ተጽፎ ይገኛል።
 
 በኋላ ጊዜ ገጹን ከሚከታተሉት ገጾች ለማስወግድ የፈለጉ እንደሆነ፣ በጫፉ ዳርቻ «አለመከታተል» የሚለውን ይጫኑ።",
 'removedwatch'         => 'ከሚከታተሉት ገጾች ተወገደ',
@@ -1198,7 +1209,7 @@
 
 (የጠፉትን ገጾች ሁሉ ለመመልከት $2 ይዩ።)',
 'deletedarticle'              => '«[[$1]]» አጠፋ',
-'dellogpage'                  => 'የማጥፋት መዝገብ (del log)',
+'dellogpage'                  => 'የማጥፋት መዝገብ',
 'dellogpagetext'              => 'በቅርቡ የጠፉት ገጾች ከዚህ ታች የዘረዝራሉ።',
 'deletionlog'                 => 'የማጥፋት መዝገብ',
 'reverted'                    => 'ወደ ቀድመኛ ዕትም ገለበጠው።',
@@ -1221,8 +1232,8 @@
 'editcomment'                 => 'ማጠቃለያው፦ «<i>$1</i>» ነበረ።', # only shown if there is an edit comment
 'revertpage'                  => 'የ$2ን ለውጦች ወደ $1 እትም መለሰ።', # Additional available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
 'rollback-success'            => 'የ$1 ለውጦች ተገለበጡ፣ ወደ $2 ዕትም ተመልሷል።',
-'protectlogpage'              => 'የማቆለፍ መዝገብ (prot. log)',
-'protectlogtext'              => 'ይህ መዝገብ ገጽ ሲቆለፍ ወይም ሲከፈት ይዘረዝራል። ለአሁኑ የተቆለፈውን ለመመልከት፣ [[Special:Protectedpages|የቆለፉትን ገጾች]] ደግሞ ያዩ።',
+'protectlogpage'              => 'የማቆለፍ መዝገብ',
+'protectlogtext'              => 'ይህ መዝገብ ገጽ ሲቆለፍ ወይም ሲከፈት ይዘረዝራል። ለአሁኑ የተቆለፈውን ለመመልከት፣ [[Special:ProtectedPages|የቆለፉትን ገጾች]] ደግሞ ያዩ።',
 'protectedarticle'            => 'ገጹን «[[$1]]» ቆለፈው።',
 'modifiedarticleprotection'   => 'የመቆለፍ ደረጃ ለ«[[$1]]» ቀየረ።',
 'unprotectedarticle'          => 'ገጹን «[[$1]]» ፈታ።',
@@ -1359,7 +1370,7 @@
 'badipaddress'                => 'የማይሆን የቁ. አድራሻ',
 'blockipsuccesssub'           => 'ማገጃ ተከናወነ',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]] ታግዷል።<br />
-ማገጃዎች ለማመልከት [[Special:Ipblocklist|የማገጃ ዝርዝሩን]] ይዩ።',
+ማገጃዎች ለማመልከት [[Special:IPBlockList|የማገጃ ዝርዝሩን]] ይዩ።',
 'ipb-edit-dropdown'           => "'ተራ የማገጃ ምክንያቶች' ለማስተካከል",
 'ipb-unblock-addr'            => 'ከ$1 መገጃ ለማንሣት',
 'ipb-unblock'                 => 'ከብዕር ስም ወይም ከቁ. አድራሻ ማገጃ ለማንሣት',
@@ -1386,9 +1397,9 @@
 'blocklink'                   => 'ማገጃ',
 'unblocklink'                 => 'ማገጃ ለማንሣት',
 'contribslink'                => 'አስተዋጽኦች',
-'blocklogpage'                => 'የማገጃ መዝገብ (blocklog)',
+'blocklogpage'                => 'የማገጃ መዝገብ',
 'blocklogentry'               => 'እስከ $2 ድረስ [[$1]] አገዳ $3',
-'blocklogtext'                => 'ይህ መዝገብ ተጠቃሚዎች መቸም ሲታገዱ ወይም ማገጃ ሲነሣ የሚዘረዝር ነው። ለአሁኑ የታገዱት ሰዎች [[Special:Ipblocklist|በአሁኑ ማገጃዎች ዝርዝር]] ይታያሉ።',
+'blocklogtext'                => 'ይህ መዝገብ ተጠቃሚዎች መቸም ሲታገዱ ወይም ማገጃ ሲነሣ የሚዘረዝር ነው። ለአሁኑ የታገዱት ሰዎች [[Special:IPBlockList|በአሁኑ ማገጃዎች ዝርዝር]] ይታያሉ።',
 'unblocklogentry'             => 'የ$1 ማገጃ አነሣ',
 'block-log-flags-anononly'    => 'ያልገቡት የቁ. አድራሻዎች ብቻ',
 'block-log-flags-nocreate'    => 'አዲስ ብዕር ስም ከማውጣት ተከለከለ',
@@ -1410,7 +1421,7 @@
 'lockdbsuccesssub'    => 'የመረጃ-ቤት መቆለፍ ተከናወነ',
 'unlockdbsuccesssub'  => 'የመረጃ-ቤት መቆለፍ ተጨረሰ',
 'lockdbsuccesstext'   => 'መረጃ-ቤቱ ተቆልፏል።<br />
-ሥራዎን እንደጨረሱ [[Special:Unlockdb|መቆለፉን ለመፍታት]] እንዳይረሱ።',
+ሥራዎን እንደጨረሱ [[Special:UnlockDB|መቆለፉን ለመፍታት]] እንዳይረሱ።',
 'unlockdbsuccesstext' => 'መረጃ-ቤቱ ተፈታ።',
 'databasenotlocked'   => 'መረጃ-ቤቱ የተቆለፈ አይደለም።',
 
@@ -1423,11 +1434,11 @@
 ይህ ማለት ወደዚያ የሚያያዝ መያያዣ ሁሉ በቀጥታ ወደ አዲሱ ሥፍራ ይወስዳል።
 ነገር ግን ገጹን እርስዎ ካዛወሩ፣ መያያዣዎቹ ድርብ ወይም ሰባራ እንዳይሆኑ ለማረጋገጥ ኃላፊነትዎ ነው።
 
-ባዲሱ አርእስት ሥፍራ ሌላ ገጽ ቀድሞ ካለ፤ ሌላው ገጽ ታሪክ የሌለው፣ ባዶ ወይም መምሪያ መንገድ ካልሆነ በቀር፣
+ባዲሱ አርእስት ሥፍራ ሌላ ገጽ ቀድሞ ካለ፤ ሌላው ገጽ ታሪክ የሌለው፣ ባዶ ወይም መምሪያ መንገድ ካልሆነ በስተቀር፣
 ይህ ገጽ ወደዚያ ለማዛወር '''የማይቻል''' ነው።  ስለዚህ ስሕተት ካደረጉ ወደ ቆየው አርእስት ገጹን መመለስ ይችላሉ፤ የኖረውን ገጽ በስሕተት ለመደምሰስ አይቻልም ማለት ነው።
 
 '''ማስጠንቀቂያ፦'''
-በጣም ለተወደደ ወይም ብዙ ጊዜ ለሚነበብ ገጽ፣ እንዲህ ያለ ለውጥ በፍጹም ያልተጠበቀ ወይም ከባድ ውጤት ሊሆን ይችላል።  ስለዚህ እባክዎ የሚገባ መደምደሚያ መሆኑን አስቀድመው ያረጋግጡ።",
+በጣም ለተወደደ ወይም ብዙ ጊዜ ለሚነበብ ገጽ፣ እንዲህ ያለ ለውጥ በፍጹም ያልተጠበቀ ወይም ከባድ ውጤት ያለው ሊሆን ይችላል።  ስለዚህ እባክዎ የሚገባ መደምደሚያ መሆኑን አስቀድመው ያረጋግጡ።",
 'movepagetalktext'        => "አብዛኛው ጊዜ፣ ከዚሁ ገጽ ጋራ የሚገናኘው የውይይት ገጽ አንድላይ ይዛወራል፤ '''ነገር ግን፦'''
 
 * ገጹን ወደማይመሳስል ክፍለ-ዊኪ (ለምሳሌ Mediawiki:) ቢያዛውሩት፤
@@ -1436,13 +1447,12 @@
 :
 :ከነውይይቱ ገጽ አንድላይ አይዛወሩም። የዚያን ጊዜ የውይይቱን ገጽ ለማዛወር ከወደዱ በእጅ ማድረግ ያስፈልግዎታል።",
 'movearticle'             => 'የቆየ አርእስት፡',
-'movenologin'             => 'ገና አልገቡም',
-'movenologintext'         => 'ገጽ ለማዛወር [[Special:Userlogin|በብዕር ስም መግባት]] ይኖርብዎታል።',
 'movenotallowed'          => 'በ{{SITENAME}} ላይ ገጾችን ለማዛወር ፈቃድ የለዎም።',
 'newtitle'                => 'አዲሱ አርእስት',
 'move-watch'              => 'ይህ ገጽ በተከታተሉት ገጾች ይጨመር',
 'movepagebtn'             => 'ገጹ ይዛወር',
 'pagemovedsub'            => 'መዛወሩ ተከናወነ',
+'movepage-moved'          => "<big>'''«$1» ወደ «$2» ተዛውሯል'''</big>", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'በዚያ አርዕሥት ሌላ ገጽ አሁን አለ። አለበለዚያ የመረጡት ስም ልክ አይደለም - ሌላ አርእስት ይምረጡ።',
 'cantmove-titleprotected' => 'አዲሱ አርዕስት ከመፈጠር ስለተጠበቀ፣ ገጽ ወደዚያው ሥፍራ ለማዛወር አይችሉም።',
 'talkexists'              => "'''ገጹ ወደ አዲሱ አርዕስት ተዛወረ፤ እንጂ በአዲሱ አርዕስት የቆየ ውይይት ገጽ አስቀድሞ ስለ ኖረ የዚህ ውይይት ገጽ ሊዛወር አልተቻለም። እባክዎ፣ በእጅ ያጋጥሙአቸው።'''",
@@ -1450,14 +1460,14 @@
 'movetalk'                => 'ከተቻለ፣ ከነውይይቱ ገጽ ጋራ ይዛወር',
 '1movedto2'               => '«$1» ወደ «[[$2]]» አዛወረ',
 '1movedto2_redir'         => '«$1» ወደ «[[$2]]» አዛወረ -- በመምሪያ መንገድ ፈንታ',
-'movelogpage'             => 'የማዛወር መዝገብ (movelog)',
+'movelogpage'             => 'የማዛወር መዝገብ',
 'movelogpagetext'         => 'ይህ መዝገብ ገጽ ሲዛወር ይመዝገባል። <ይመለስ> ቢጫኑ ኖሮ መዛወሩን ይገለብጣል!',
 'movereason'              => 'ምክንያት',
 'revertmove'              => 'ይመለስ',
 'delete_and_move'         => 'ማጥፋትና ማዛወር',
 'delete_and_move_text'    => '==ማጥፋት ያስፈልጋል==
 
-መድረሻው ገጽ ሥፍራ «[[$1]]» የሚለው ገጽ አሁን ይኖራል። ሌላው ገጽ ወደዚያ እንዲዛወር እሱን ለማጥፋት ይወድዳሉ?',
+መድረሻው ገጽ ሥፍራ «[[:$1]]» የሚለው ገጽ አሁን ይኖራል። ሌላው ገጽ ወደዚያ እንዲዛወር እሱን ለማጥፋት ይወድዳሉ?',
 'delete_and_move_confirm' => 'አዎን፣ ገጹ ይጥፋ',
 'delete_and_move_reason'  => 'ለመዛወሩ ሥፍራ እንዲገኝ ጠፋ',
 'selfmove'                => 'የመነሻ እና የመድረሻ አርዕስቶች አንድ ናቸው፤ ገጽ ወደ ራሱ ለማዛወር አይቻልም።',
@@ -1642,7 +1652,7 @@
 'show-big-image'       => 'በሙሉ ጒልህነት ለመመልከት',
 'show-big-image-thumb' => '<small>የዚህ ናሙና ቅጂ ክልል፦ $1 × $2 ፒክሰል</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'የአዳዲስ ሥዕሎች ማሳያ አዳራሽ',
 'imagelisttext'         => '$1 የተጨመሩ ሥእሎች ወይም ፋይሎች ከታች ይዘረዝራሉ ($2)።',
 'showhidebots'          => '(«bots» $1)',
@@ -1868,7 +1878,7 @@
 
 # External editor support
 'edit-externally'      => 'ይህንን ፋይል በአፍአዊ ሶፍትዌር ለማዘጋጀት',
-'edit-externally-help' => 'ስለ አፍአዊ የስዕል ማዘጋጀት ሶፍትዌር በተጨማሪ ለመረዳት [http://meta.wikimedia.org/wiki/Help:External_editors የመመስረት ትዕዛዝ] ያንብቡ።',
+'edit-externally-help' => 'ስለ አፍአዊ የስዕል ማዘጋጀት ሶፍትዌር በተጨማሪ ለመረዳት [http://www.mediawiki.org/wiki/Manual:External_editors የመመስረት ትዕዛዝ] ያንብቡ።',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'ሁሉ',
@@ -1918,7 +1928,7 @@
 'recreate'            => 'እንደገና ይፈጠር',
 
 # HTML dump
-'redirectingto' => 'ወደ [[$1]] መምሪያ መንገድ ማድረግ...',
+'redirectingto' => 'ወደ [[:$1]] መምሪያ መንገድ ማድረግ...',
 
 # action=purge
 'confirm_purge'        => 'የዚሁ ገጽ ካሽ (cache) ይጠረግ?
@@ -2012,7 +2022,7 @@
 'version-software-product'         => 'ሶፍትዌር',
 'version-software-version'         => 'ዝርያ',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'የፋይል መንገድ',
 'filepath-page'    => 'ፋይሉ፦',
 'filepath-submit'  => 'መንገድ',
Index: languages/messages/MessagesPms.php
===================================================================
--- languages/messages/MessagesPms.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesPms.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -5,13 +5,10 @@
  * @file
  *
  * @author Bèrto 'd Sèra
- * @author Siebrand
- * @author לערי ריינהארט
  * @author SabineCretella
- * @author Jon Harald Søby
- * @author SPQRobin
- * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>, Jens Frank
  * @author Teak
+ * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>, Jens Frank
+ * @author לערי ריינהארט
  */
 
 $fallback = 'it';
@@ -539,10 +536,6 @@
 'blockededitsource'         => "Ël test ëd le '''soe modìfiche''' a '''$1''' a së s-ciàira ambelessì sota:",
 'whitelistedittitle'        => 'Sòn as peul pa fesse nen rintrand ant ël sistema',
 'whitelistedittext'         => 'A venta $1 për podej fé dle modìfiche.',
-'whitelistreadtitle'        => 'Sòn as peul pa fesse nen rintrand ant ël sistema',
-'whitelistreadtext'         => "A l'ha da [[Special:Userlogin|rintré ant ël sistema]] për podej lese dle pàgine.",
-'whitelistacctitle'         => 'Che a në scusa, ma a peul nen creésse un cont.',
-'whitelistacctext'          => "Për podej creé dij cont ant sta wiki-sì a l'ha da [[Special:Userlogin|rintré ant ël sistema]] e avej ël drit da creéje.",
 'confirmedittitle'          => "Confermé l'adrëssa postal për podej fé dle modìfiche",
 'confirmedittext'           => 'A dev confermé soa adrëssa ëd pòsta eletrònica, anans che modifiché dle pàgine. Për piasì, che a convalida soa adrëssa ën dovrand la pàgina [[Special:Preferences|mè gust]].',
 'nosuchsectiontitle'        => 'Pa gnun-a session parèj',
@@ -554,7 +547,7 @@
 'accmailtext'               => 'La paròla ciav për "$1" a l\'é staita mandà a $2.',
 'newarticle'                => '(Neuv)',
 'newarticletext'            => 'Che a scriva sò test ambelessì.',
-'anontalkpagetext'          => "----''Costa a l'é la pàgina ëd ciaciarade che a s-ciàira n'utent anònim che a l'é ancó pa dorbusse un cont, ò pura che a lo dòvra nen. Nen savend chi che a sia chiel (chila) i l'oma da dovré ël nùmer IP address për deje n'identificassion. Belavans, ës nùmer-sì a peul esse dovrà da vàire Utent. J'Utent anònim che a l'han l'impression d'arsèive dij coment sensa sust a dovrìo [[Special:Userlogin|creésse sò cont ò pura rintré ant ël sistema]] për evité dë fé confusion con dj'àutri Utent che a peulo avej l'istess nùmer IP.''",
+'anontalkpagetext'          => "----''Costa a l'é la pàgina ëd ciaciarade che a s-ciàira n'utent anònim che a l'é ancó pa dorbusse un cont, ò pura che a lo dòvra nen. Nen savend chi che a sia chiel (chila) i l'oma da dovré ël nùmer IP address për deje n'identificassion. Belavans, ës nùmer-sì a peul esse dovrà da vàire Utent. J'Utent anònim che a l'han l'impression d'arsèive dij coment sensa sust a dovrìo [[Special:UserLogin|creésse sò cont ò pura rintré ant ël sistema]] për evité dë fé confusion con dj'àutri Utent che a peulo avej l'istess nùmer IP.''",
 'noarticletext'             => "(St'artìcol-sì a l'é veujd, a podrìa për gentilëssa anandielo chiel, ò pura ciamé la scancelassion dë sta pàgina)",
 'userpage-userdoesnotexist' => 'Lë stranòm "$1" a l\'é pa registrà. Për piasì ch\'a varda se da bon a veul creé/modifiché sta pàgina.',
 'clearyourcache'            => "'''Nòta:''' na vira che i l'ha salvà, a peul esse che a-j fasa da manca da passé via la memorisassion (cache) dël sò programa ëd navigassion (browser) për podej ës-ciairé le modìfiche.
@@ -624,7 +617,7 @@
 'edittools'                 => "<!-- Test ch'a së s-ciàira sot a ij mòduj ëd mòdifica e 'd càrich d'archivi. -->",
 'nocreatetitle'             => 'Creassion ëd pàgine limità',
 'nocreatetext'              => "Cost sit-sì a l'ha limità la possibilità ëd creé dle pàgine neuve.
-A peul torné andaré e modifiché na pàgine che a-i é già, ò pura [[Special:Userlogin|rintré ant ël sistema ò deurb-se un cont]].",
+A peul torné andaré e modifiché na pàgine che a-i é già, ò pura [[Special:UserLogin|rintré ant ël sistema ò deurb-se un cont]].",
 'nocreate-loggedin'         => "A l'ha pa ij përmess dont a fa da manca për podej creé dle pàgine neuve an {{SITENAME}}.",
 'permissionserrors'         => 'Eror ant ij përmess',
 'permissionserrorstext'     => "A l'ha pa ij përmess dont a fa da manca për {{PLURAL:$1|via che|via che}}:",
@@ -788,7 +781,7 @@
 'mypreferences'            => 'mè gust',
 'prefs-edits'              => 'Modìfiche faite:',
 'prefsnologin'             => "A l'é ancó pa rintrà ant ël sistema",
-'prefsnologintext'         => 'A dev [[Special:Userlogin|rintré ant ël sistema]]
+'prefsnologintext'         => 'A dev [[Special:UserLogin|rintré ant ël sistema]]
 për podej specifiché ij sò gust.',
 'prefsreset'               => 'Ij "sò gust" a son stait pijait andré da \'nt la memòria dël server ëd {{SITENAME}}.',
 'qbsettings'               => 'Regolassion dla bara dij menù',
@@ -857,7 +850,7 @@
 'userrights-reason'        => 'Rason dla modìfica:',
 'userrights-no-interwiki'  => "A l'ha pa ij përmess dont a fa da manca për podej cambieje ij drit a dj'utent ansima a dj'àutre wiki.",
 'userrights-nodatabase'    => "La base dat $1 a-i é pa, ò pura a l'é nen local.",
-'userrights-nologin'       => "A l'ha da [[Special:Userlogin|rintré ant ël sistema]] con un cont da aministrator për podej-je dé dij drit a j'utent.",
+'userrights-nologin'       => "A l'ha da [[Special:UserLogin|rintré ant ël sistema]] con un cont da aministrator për podej-je dé dij drit a j'utent.",
 'userrights-notallowed'    => "A l'ha pa ij përmess dont a fa da manca për podej-je dé dij drit a j'utent.",
 
 # Groups
@@ -923,14 +916,14 @@
 'reupload'                    => 'Caria torna',
 'reuploaddesc'                => 'Torné al mòdulo ëd domanda për carié archivi',
 'uploadnologin'               => "A dev rintré ant ël sistema për podej fé st'operassion-sì",
-'uploadnologintext'           => "A dev [[Special:Userlogin|rintré ant ël sistema]]
+'uploadnologintext'           => "A dev [[Special:UserLogin|rintré ant ël sistema]]
 për podej carié dj'archivi.",
 'upload_directory_read_only'  => 'Ël programa webserver a-i la fa nen a scrive ansima a la diretriss ëd càrich ($1).',
 'uploaderror'                 => 'Eror dëmentré che as cariava',
 'uploadtext'                  => "'''DOSMAN!''' Anans che carié dla ròba ansima a {{SITENAME}}, che a sia motobin sigur d'avej bin lesù e capì
 [[{{MediaWiki:Policy-url}}|ël regolament ëd {{SITENAME}} ansima al dovré dle figure]].
 
-Për vardé ò pura sërché figure già carià ant sla {{SITENAME}}, che a vada ant sla [[Special:Imagelist|lista dle figure]].
+Për vardé ò pura sërché figure già carià ant sla {{SITENAME}}, che a vada ant sla [[Special:ImageList|lista dle figure]].
 Lòn che as caria e së scancela a resta marcà ant ël [[Special:Log/upload|registr dij càrich]].
 
 Che a dòvra ël mòdulo ambelessì sota për carié neuv archivi con figure da dovré për fé pì bej e bin spiegà ij sò artìcoj.
@@ -1045,7 +1038,7 @@
 'upload_source_url'  => "  (n'anliura bon-a e che as peula dovresse)",
 'upload_source_file' => " (n'archivi da sò calcolator)",
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => "Sta pàgina special-sì a la smon tuti j'archivi ch'a ëstàit carià.
 Për sòlit j'ùltim carià a resto an sima.
 Ch'a-i bata 'n colp col rat ansima a j'antestassion dle colòne për cangé órdin.",
@@ -1085,18 +1078,18 @@
 # File reversion
 'filerevert'                => "Buta torna $1 tanme ch'a l'era",
 'filerevert-legend'         => "Buté torna l'archivi tanme ch'a l'era",
-'filerevert-intro'          => "<span class=\"plainlinks\">A l'é dapress a buté torna l'archivi  '''[[Media:\$1|\$1]]''' com a l'era ant la [version \$4 dël \$2, \$3].</span>",
+'filerevert-intro'          => "A l'é dapress a buté torna l'archivi  '''[[Media:$1|$1]]''' com a l'era ant la [version $4 dël $2, $3].",
 'filerevert-comment'        => 'Oget:',
 'filerevert-defaultcomment' => 'Version dël $1, $2 butà torna coma corenta.',
 'filerevert-submit'         => "Buté tanme ch'a l'era",
-'filerevert-success'        => "<span class=\"plainlinks\">'''L<nowiki>'</nowiki>archivi [[Media:\$1|\$1]]''' a l'é stait torna butà com a l'era ant la [\$4 version dël \$2, \$3].</span>",
+'filerevert-success'        => "'''L<nowiki>'</nowiki>archivi [[Media:$1|$1]]''' a l'é stait torna butà com a l'era ant la [$4 version dël $2, $3].",
 'filerevert-badversion'     => "A-i é pa gnun-a version locala dl'archivi ch'a l'abia un marcatemp parej.",
 
 # File deletion
 'filedelete'                  => 'Dëscancelé $1',
 'filedelete-legend'           => "Dëscancelé l'archivi",
 'filedelete-intro'            => "A l'é an brova dë scancelé '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => "<span class=\"plainlinks\">A l'é dapress ch'a scancela l'archivi '''[[Media:\$1|\$1]]''' dël [\$4 \$3, \$2].</span>",
+'filedelete-intro-old'        => "A l'é dapress ch'a scancela l'archivi '''[[Media:$1|$1]]''' dël [$4 $3, $2].",
 'filedelete-comment'          => 'Rason:',
 'filedelete-submit'           => 'Dëscancelé',
 'filedelete-success'          => "A l'é dëscancelasse l'archivi '''$1'''.",
@@ -1241,7 +1234,7 @@
 'logempty'             => 'Pa gnun element parej che a sia trovasse ant ij registr.',
 'log-title-wildcard'   => "Sërca ant ij tìtoj ch'as anandio për",
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Tute le pàgine',
 'alphaindexline'    => '$1 a $2',
 'nextpage'          => 'Pàgina che a-i ven ($1)',
@@ -1263,14 +1256,14 @@
 'special-categories-sort-count' => 'ordiné për nùmer',
 'special-categories-sort-abc'   => 'òrdiné për alfabétich',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => "Smon-me j'utent a parte da:",
 'listusers-submit'   => 'Smon',
 'listusers-noresult' => 'Pa gnun utent parej.',
 
 # E-mail user
 'mailnologin'     => 'A-i é pa gnun-a adrëssa për mandé ël messagi',
-'mailnologintext' => "A dev [[Special:Userlogin|rintré ant ël sistema]]
+'mailnologintext' => "A dev [[Special:UserLogin|rintré ant ël sistema]]
 e avej registrà n'adrëssa ëd pòsta eletrònica vàlida ant ij [[Special:Preferences|sò gust]] për podej mandé dij messagi ëd pòsta eletrònica a j'àutri Utent.",
 'emailuser'       => "Mand-je un messagi eletrònich a st'Utent-sì",
 'emailpage'       => "Mand-je un messagi ëd pòsta eletrònica a st'utent-sì",
@@ -1297,11 +1290,11 @@
 'nowatchlist'          => 'A l\'ha ancó pa marcà dj\'artìcoj coma "ròba da tnì sot euj".',
 'watchlistanontext'    => "Për piasì, $1 për ës-ciairé ò pura modifiché j'element ëd soa lista dla ròba che as ten sot euj.",
 'watchnologin'         => "A l'é ancó nen rintrà ant ël sistema",
-'watchnologintext'     => "A l'ha da manca prima ëd tut dë [[Special:Userlogin|rintré ant ël sistema]]
+'watchnologintext'     => "A l'ha da manca prima ëd tut dë [[Special:UserLogin|rintré ant ël sistema]]
 për podej modifiché soa lista dla ròba dë tnì sot euj.",
 'addedwatch'           => "Sòn a l'é stait giontà a le pàgine che it ten-e sot euj",
 'addedwatchtext'       => " La pàgina  \"<nowiki>\$1</nowiki>\" a l'é staita giontà a tua [[Special:Watchlist|lista dla ròba da tnì sot euj]].
-Le modìfiche che a-i vniran ant costa pàgina-sì e ant soa pàgina ëd discussion a saran listà ambelessì, e la pàgina a së s-ciairerà ën <b>grassèt</b> ant la pàgina ëd j'[[Special:Recentchanges|ùltime modìfiche]] përchè che a resta belfé a ten-la d'euj.
+Le modìfiche che a-i vniran ant costa pàgina-sì e ant soa pàgina ëd discussion a saran listà ambelessì, e la pàgina a së s-ciairerà ën <b>grassèt</b> ant la pàgina ëd j'[[Special:RecentChanges|ùltime modìfiche]] përchè che a resta belfé a ten-la d'euj.
 
 Se a vorèissa mai gavé st'articol-sì da 'nt la lista dij ''Sot Euj'', che a sgnaca \" Chita da tnì sot euj \" ant sla bara dij menù.",
 'removedwatch'         => "Gavà via da 'nt la lista dla ròba da tnì sot euj",
@@ -1413,7 +1406,7 @@
 'sessionfailure'              => "A-i son ëstaje dle gran-e con la session che a identìfica sò acess; ël sistema a l'ha nen eseguì l'ordin che a l'ha daje për precaussion. Che a torna andaré a la pàgina prima con ël boton \"andaré\" ëd sò programa ëd navigassion (browser), peuj che as carìa n'àutra vira costa pàgina-sì e che a preuva torna a fé lòn che vorìa fé.",
 'protectlogpage'              => 'Registr dle protession',
 'protectlogtext'              => "Ambelessì sota a-i é na lista d'event ëd protession e dësprotession ëd pàgine.
-Ch'a varda la [[Special:Protectedpages|Lista dle pàgine protegiùe]] për ës-ciairé le protession corente.",
+Ch'a varda la [[Special:ProtectedPages|Lista dle pàgine protegiùe]] për ës-ciairé le protession corente.",
 'protectedarticle'            => '"[[$1]]" a l\'é protet',
 'modifiedarticleprotection'   => 'A l\'é cambia-ie ël livel ëd protession për "[[$1]]"',
 'unprotectedarticle'          => 'Dësprotegiù "[[$1]]"',
@@ -1569,7 +1562,7 @@
 'badipaddress'                => "L'adrëssa IP che a l'ha dane a l'é nen giusta.",
 'blockipsuccesssub'           => 'Blocagi fait',
 'blockipsuccesstext'          => ' L\'adrëssa IP "$1" a l\'é staita blocà.<br />
-Che a varda la [[Special:Ipblocklist|lista dj\'IP blocà]].',
+Che a varda la [[Special:IPBlockList|lista dj\'IP blocà]].',
 'ipb-edit-dropdown'           => 'Motiv dël blòch',
 'ipb-unblock-addr'            => 'Dësbloché $1',
 'ipb-unblock'                 => "Dësbloché n'utent ò n'adrëssa IP",
@@ -1601,7 +1594,7 @@
 'blocklogentry'               => '"[[$1]]" a l\'é stait blocà për $2 $3',
 'blocklogtext'                => "Sossì a l'é ël registr dij blocagi e dësblocagi dj'Utent. J'adrësse che
 a son staite blocà n'automàtich ambelessì a së s-ciàiro nen.
-Che a varda la [[Special:Ipblocklist|lista dj'adrësse IP blocà]] për vëdde
+Che a varda la [[Special:IPBlockList|lista dj'adrësse IP blocà]] për vëdde
 coj che sio ij blocagi ativ al dì d'ancheuj.",
 'unblocklogentry'             => "a l'ha dësblocà $1",
 'block-log-flags-anononly'    => 'mach utent anònim',
@@ -1666,9 +1659,6 @@
 *a l'ha deselessionà ël quadrèt ëd conferma ambelessì sota.
 Ant costi cas-sì, se a chërd dë felo, a-j farà da manca dë tramudesse la pàgina ëd discussion daspërchiel, a man.",
 'movearticle'             => "Cang-je nòm a l'artìcol",
-'movenologin'             => "Che a varda che chiel (chila) a l'è pa rintrà ant ël sistema",
-'movenologintext'         => "A venta esse n'Utent registrà e esse [[Special:Userlogin|rintrà ant ël sistema]]
-për podej tramudé na pàgina.",
 'movenotallowed'          => "A l'ha pa ij përmess dont a fa da manca për tramudé pàgine an {{SITENAME}}.",
 'newtitle'                => 'Neuv tìtol ëd',
 'move-watch'              => 'Ten sot euj sta pàgina-sì',
@@ -1689,7 +1679,7 @@
 'delete_and_move'         => 'Scancela e tramuda',
 'delete_and_move_text'    => '==A fa da manca dë scancelé==
 
-L\'artìcol ëd destinassion "[[$1]]" a-i é già. Veul-lo scancelelo për avej ëd pòst për tramudé l\'àutr?',
+L\'artìcol ëd destinassion "[[:$1]]" a-i é già. Veul-lo scancelelo për avej ëd pòst për tramudé l\'àutr?',
 'delete_and_move_confirm' => 'É, scancela la pàgina',
 'delete_and_move_reason'  => "Scancelà për liberé ël pòst për tramudene n'àutra",
 'selfmove'                => "Tìtol neuv e tìtol vej a resto midem antra lor; as peul pa tramudesse na pàgina butand-la andoa che a l'é già.",
@@ -1925,10 +1915,10 @@
 'show-big-image'       => 'Version a amzura pijn-a',
 'show-big-image-thumb' => '<small>Amzure dë sta figurin-a: $1 × $2 pixel</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Galerìa ëd figure e son neuv',
 'imagelisttext'         => "Ambelessì sota a-i é {{PLURAL:$1|l'ùnica figura che a-i sia|na lista ëd '''$1''' figure, ordinà për $2}}.",
-'newimages-summary'     => "Sta pàgina special-sì a la smon j'ùltim archivi carià",
+'newimages-summary'     => "Sta pàgina special-sì a la smon j'ùltim archivi carià.",
 'showhidebots'          => '($1 trigomiro)',
 'noimages'              => 'Pa gnente da vëdde.',
 'ilsubmit'              => 'Sërca',
@@ -2216,7 +2206,7 @@
 
 # External editor support
 'edit-externally'      => "Modifiché st'archivi con un programa estern",
-'edit-externally-help' => "Che a varda [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions] për avej pì d'anformassion.",
+'edit-externally-help' => "Che a varda [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] për avej pì d'anformassion.",
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'tute',
@@ -2289,7 +2279,7 @@
 'recreate'            => "Créa n'àutra vira",
 
 # HTML dump
-'redirectingto' => 'I soma antramentr che i foma na ridiression a [[$1]]...',
+'redirectingto' => 'I soma antramentr che i foma na ridiression a [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Veujdé la memorisassion dë sta pàgina-sì?
@@ -2407,7 +2397,7 @@
 'version-software-product'         => 'Prodot',
 'version-software-version'         => 'Version',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => "Përcors d'archivi",
 'filepath-page'    => 'Archivi:',
 'filepath-submit'  => 'Përcors',
Index: languages/messages/MessagesEl.php
===================================================================
--- languages/messages/MessagesEl.php	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ languages/messages/MessagesEl.php	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -4,23 +4,20 @@
  * @ingroup Language
  * @file
  *
+ * @author Assassingr
+ * @author Badseed
+ * @author Consta
  * @author Dead3y3
- * @author Badseed
- * @author Απεργός
+ * @author Demmy
+ * @author Flyax
+ * @author Geraki
  * @author Lou
- * @author Consta
+ * @author MF-Warburg
+ * @author Omnipaedista
+ * @author Sinopeus
  * @author ZaDiak
- * @author Omnipaedista
- * @author Assassingr
- * @author MF-Warburg
- * @author Siebrand
- * @author Geraki
+ * @author Απεργός
  * @author לערי ריינהארט
- * @author Sinopeus
- * @author Demmy
- * @author Jon Harald Søby
- * @author Flyax
- * @author SPQRobin
  */
 
 /**
@@ -506,7 +503,7 @@
 'nosuchspecialpage' => 'Δεν υπάρχει τέτοια σελίδα λειτουργιών.',
 'nospecialpagetext' => "<big>'''Ζητήσατε μια άκυρη σελίδα λειτουργιών.'''</big>
 
-Ένας κατάλογος έγκυρων σελίδων λειτουργιών βρίσκεται στο [[Special:Specialpages|{{int:specialpages}}]].",
+Ένας κατάλογος έγκυρων σελίδων λειτουργιών βρίσκεται στο [[Special:SpecialPages|{{int:specialpages}}]].",
 
 # General errors
 'error'                => 'Σφάλμα',
@@ -572,9 +569,9 @@
 Μπορείτε να παραμείνετε στο {{SITENAME}} ανώνυμα, ή μπορείτε να συνδεθείτε ξανά με το ίδιο ή με διαφορετικό (εάν έχετε) όνομα χρήστη. Έχετε υπόψη σας πως αρκετές σελίδες θα συνεχίσουν να εμφανίζονται κανονικά, σαν να μην έχετε αποσυνδεθεί, μέχρι να καθαρίσετε τη λανθάνουσα μνήμη του φυλλομετρητή σας.',
 'welcomecreation'            => '== Καλώς ήλθατε, $1! ==
 Ο λογαριασμός σας έχει δημιουργηθεί.
-Μπορείτε να εξατομικεύσετε το {{SITENAME}} σύμφωνα με τις ανάγκες σας μέσα από το σύνδεσμο προτιμήσεις.',
+Μην ξεχάσετε να ρυθμίσετε τις [[Special:Preferences|προτιμήσεις]] σας στο {{SITENAME}}.',
 'loginpagetitle'             => 'Είσοδος χρήστη',
-'yourname'                   => 'Όνομα χρήστη',
+'yourname'                   => 'Όνομα χρήστη:',
 'yourpassword'               => 'Κωδικός:',
 'yourpasswordagain'          => 'Πληκτρολογήστε ξανά τον κωδικό',
 'remembermypassword'         => 'Διατήρηση του κωδικού πρόσβασης σε αυτόν τον υπολογιστή',
@@ -735,10 +732,6 @@
 'blockededitsource'                => "Το κείμενο των '''επεξεργασιών σας''' στο '''$1''' φαίνεται παρακάτω:",
 'whitelistedittitle'               => 'Για να επεξεργαστείτε μια σελίδα πρέπει πρώτα να συνδεθείτε.',
 'whitelistedittext'                => 'Πρέπει να $1 για να επεξεργαστείτε σελίδες.',
-'whitelistreadtitle'               => 'Για να διαβάσετε πρέπει πρώτα να συνδεθείτε.',
-'whitelistreadtext'                => 'Πρέπει να [[Special:Userlogin|συνδεθείτε]] για να διαβάσετε σελίδες.',
-'whitelistacctitle'                => 'Δεν έχετε το δικαίωμα να δημιουργήσετε λογαριασμό.',
-'whitelistacctext'                 => 'Για να σας επιτραπεί η δημιουργία λογαριασμού σε αυτό το Wiki πρέπει να [[Special:Userlogin|συνδεθείτε]] και να κατέχετε την κατάλληλη άδεια.',
 'confirmedittitle'                 => 'Απαιτείται επιβεβαίωση e-mail για την επεξεργασία',
 'confirmedittext'                  => 'Πρέπει να επιβεβαιώσετε την διεύθυνση e-mail σας πριν μπορέσετε να επεξεργαστείτε σελίδες. Παρακαλώ θέστε και επικυρώστε την διεύθυνση e-mail σας μέσω των [[Special:Preferences|προτιμήσεων χρήστη]] σας.',
 'nosuchsectiontitle'               => 'Δεν υπάρχει τέτοια ενότητα',
@@ -751,7 +744,7 @@
 'newarticle'                       => '(Νέο)',
 'newarticletext'                   => "Ακολουθήσατε ένα σύνδεσμο προς μια σελίδα που δεν υπάρχει ακόμα. Για να δημιουργήσετε τη σελίδα, αρχίστε να γράφετε το κείμενό σας στο πλαίσιο (δείτε τη [[{{MediaWiki:Helppage}}|Σελίδα βοήθειας]] για περισσότερες πληροφορίες).
 Αν έχετε βρεθεί εδώ κατά λάθος, απλώς πατήστε '''επιστροφή (back)''' στον browser του υπολογιστή σας.",
-'anontalkpagetext'                 => "----''Αυτή η σελίδα συζήτησης προορίζεται για ανώνυμο χρήστη που δεν έχει δημιουργήσει ακόμα λογαριασμό ή που δεν τον χρησιμοποιεί. Έτσι για την ταυτοποίηση ενός ανώνυμου χρήστη χρησιμοποιείται η διεύθυνση IP του. Είναι όμως πιθανόν η διεύθυνση αυτή να είναι κοινή για πολλούς διαφορετικούς χρήστες.  Αν είστε ανώνυμος χρήστης και νομίζετε ότι άσχετα σχόλια απευθύνθηκαν σε σας, παρακαλούμε να [[Special:Userlogin|δημιουργήσετε ένα λογαριασμό ή να συνδεθείτε]] για να αποφεύγεται η σύγχυση με άλλους ανώνυμους χρήστες στο μέλλον''.",
+'anontalkpagetext'                 => "----''Αυτή η σελίδα συζήτησης προορίζεται για ανώνυμο χρήστη που δεν έχει δημιουργήσει ακόμα λογαριασμό ή που δεν τον χρησιμοποιεί. Έτσι για την ταυτοποίηση ενός ανώνυμου χρήστη χρησιμοποιείται η διεύθυνση IP του. Είναι όμως πιθανόν η διεύθυνση αυτή να είναι κοινή για πολλούς διαφορετικούς χρήστες.  Αν είστε ανώνυμος χρήστης και νομίζετε ότι άσχετα σχόλια απευθύνθηκαν σε σας, παρακαλούμε να [[Special:UserLogin|δημιουργήσετε ένα λογαριασμό ή να συνδεθείτε]] για να αποφεύγεται η σύγχυση με άλλους ανώνυμους χρήστες στο μέλλον''.",
 'noarticletext'                    => 'Δεν υπάρχει τώρα κείμενο σε αυτή τη σελίδα, μπορείτε να [[Special:Search/{{PAGENAME}}|αναζητήσετε αυτόν τον τίτλο σελίδας]] σε άλλες σελίδες ή να [{{fullurl:{{FULLPAGENAME}}|action=edit}} επεξεργαστείτε τη σελίδα αυτή].',
 'userpage-userdoesnotexist'        => 'Ο Λογαριασμός του χρήστη "$1" δεν είναι καταχωρημένος. Παρακαλώ δείτε αν θα θέλατε να δημιουργήσετε/επεξεργαστείτε αυτή τη σελίδα.',
 'clearyourcache'                   => "'''Σημείωση:''' Μετά την αποθήκευση, θα χρειαστεί να καθαρίσετε  το cache στον browser για να μπορέσετε να δείτε τις αλλαγές: '''Mozilla:''' πατήστε ''Reload'' (ή ''Ctrl-R''), '''IE / Opera:''' ''Ctrl-F5'', '''Safari:''' ''Cmd-R'', '''Konqueror''' ''Ctrl-R''.<br />",
@@ -807,7 +800,7 @@
 'edittools'                        => '<!-- Το κείμενο εδώ θα φαίνεται κάτω από τις φόρμες επεξεργασίας και επιφόρτωσης. -->',
 'nocreatetitle'                    => 'Περιορισμένη δημιουργία σελίδων',
 'nocreatetext'                     => 'Το {{SITENAME}} έχει περιορίσει την ικανότητα δημιουργίας νέων σελίδων.
-Μπορείτε να πάτε πίσω και να επεξεργαστείτε μια υπάρχουσα σελίδα, ή να [[Special:Userlogin|συνδεθείτε ή να δημιουργήσετε ένα λογαριασμό]].',
+Μπορείτε να πάτε πίσω και να επεξεργαστείτε μια υπάρχουσα σελίδα, ή να [[Special:UserLogin|συνδεθείτε ή να δημιουργήσετε ένα λογαριασμό]].',
 'nocreate-loggedin'                => 'Δεν έχετε άδεια να δημιουργήσετε νέες σελίδες στο {{SITENAME}}.',
 'permissionserrors'                => 'Σφάλματα άδειας.',
 'permissionserrorstext'            => 'Δεν έχετε άδεια να το κάνετε αυτό, για {{PLURAL:$1|τον εξής λόγο|τους εξής λόγους}}:',
@@ -891,10 +884,10 @@
 'revdelete-hide-comment'      => 'Κρύψε σχόλιο επεξεργασίας',
 'revdelete-hide-user'         => 'Κρύψε όνομα χρήστη/IP συντάκτη',
 'revdelete-hide-restricted'   => 'Εφαρμογή αυτών των περιορισμών σε Διαχειριστές και κλείδωμα αυτής της διεπαφής',
-'revdelete-suppress'          => 'Απέκρυψε δεδομένα από διαχειριστές όπως και από άλλους',
+'revdelete-suppress'          => 'Απόκρυψε δεδομένα από διαχειριστές όπως και από άλλους',
 'revdelete-hide-image'        => 'Κρύψε περιεχόμενο αρχείου',
 'revdelete-unsuppress'        => 'Αφαίρεσε περιορισμούς στις αποκατεστημένες αναθεωρήσεις',
-'revdelete-log'               => 'Κατέγραψε σχόλιο:',
+'revdelete-log'               => 'Κατάγραψε σχόλιο:',
 'revdelete-submit'            => 'Εφάρμοσε στην επιλεγμένη αναθεώρηση',
 'revdelete-logentry'          => 'η ορατότητα της αναθεώρησης του [[$1]] αλλάχθηκε',
 'logdelete-logentry'          => 'η ορατότητα γεγονότος του [[$1]] αλλάχθηκε',
@@ -965,6 +958,7 @@
 'search-suggest'            => 'Μήπως εννοούσατε: $1',
 'search-interwiki-caption'  => 'Αδελφά πρότζεκτ',
 'search-interwiki-default'  => '$1 αποτελέσματα:',
+'search-interwiki-more'     => '(περισσότερα)',
 'search-mwsuggest-enabled'  => 'με υποδείξεις',
 'search-mwsuggest-disabled' => 'χωρίς υποδείξεις',
 'search-relatedarticle'     => 'Σχετικά',
@@ -984,7 +978,7 @@
 'mypreferences'            => 'Οι προτιμήσεις μου',
 'prefs-edits'              => 'Αριθμός επεξεργασιών:',
 'prefsnologin'             => 'Δεν έχετε συνδεθεί.',
-'prefsnologintext'         => 'Πρέπει να έχετε [[Special:Userlogin|συνδεθεί]]
+'prefsnologintext'         => 'Πρέπει να έχετε [[Special:UserLogin|συνδεθεί]]
 για να καθορίσετε τις προτιμήσεις χρήστη.',
 'prefsreset'               => 'Οι προτιμήσεις σας έχουν αποκατασταθεί σύμφωνα με την αποθηκευμένη έκδοσή τους.',
 'qbsettings'               => 'Γρήγορη πρόσβαση',
@@ -1014,7 +1008,7 @@
 'prefs-watchlist-days'     => 'Ημέρες προς εμφάνιση στη λίστα παρακολούθησης:',
 'prefs-watchlist-edits'    => 'Αριθμός επεξεργασιών προς εμφάνιση στην εκτεταμένη λίστα παρακολούθησης:',
 'prefs-misc'               => 'Διάφορες ρυθμίσεις',
-'saveprefs'                => 'Αποθήκευση προτιμήσεων',
+'saveprefs'                => 'Αποθηκεύστε',
 'resetprefs'               => 'Επαναφορά προτιμήσεων',
 'oldpassword'              => 'Παλιός κωδικός',
 'newpassword'              => 'Νέος κωδικός πρόσβασης',
@@ -1054,7 +1048,7 @@
 'userrights-reason'        => 'Λόγος για αλλαγή:',
 'userrights-no-interwiki'  => 'Δεν έχετε άδεια να επεξεργαστείτε τα δικαιώματα χρηστών σε άλλα wiki.',
 'userrights-nodatabase'    => 'Η βάση δεδομένων $1 δεν υπάρχει ή δεν είναι τοπική.',
-'userrights-nologin'       => 'Πρέπει να [[Special:Userlogin|συνδεθείτε]] με έναν λογαριασμό διαχειριστή συστήματος ώστε να ορίσετε δικαιώματα χρηστών.',
+'userrights-nologin'       => 'Πρέπει να [[Special:UserLogin|συνδεθείτε]] με έναν λογαριασμό διαχειριστή συστήματος ώστε να ορίσετε δικαιώματα χρηστών.',
 'userrights-notallowed'    => 'Ο λογαριασμός σας δεν έχει άδεια για να ορίσει δικαιώματα χρηστών.',
 
 # Groups
@@ -1105,7 +1099,7 @@
 'recentchanges'                     => 'Πρόσφατες αλλαγές',
 'recentchangestext'                 => 'Παρακολουθείστε σε αυτή τη σελίδα τις πιο πρόσφατες αλλαγές στο Wiki.',
 'recentchanges-feed-description'    => 'Παρακολούθησε τις πιο πρόσφατες αλλαγές στο wiki σε αυτή την περίληψη.',
-'rcnote'                            => "Παρακάτω είναι {{PLURAL:$1|'''1''' αλλαγή|οι τελευταίες '''$1''' αλλαγές}} στο διάστημα {{PLURAL:$2|της τελευταίας ημέρας|των τελευταίων '''$2''' ημερών}}, από τις $3 και εξής.",
+'rcnote'                            => "Παρακάτω {{PLURAL:$1|υπάρχει '''1''' αλλαγή|υπάρχουν οι τελευταίες '''$1''' αλλαγές}} στο διάστημα {{PLURAL:$2|της τελευταίας ημέρας|των τελευταίων '''$2''' ημερών}}, από τις $5, $4 και εξής.",
 'rcnotefrom'                        => 'Ακολουθούν οι αλλαγές από <b>$2</b> (εμφάνιση <b>$1</b> αλλαγών max).',
 'rclistfrom'                        => 'Εμφάνιση νέων αλλαγών αρχίζοντας από $1',
 'rcshowhideminor'                   => '$1 μικρής σημασίας επεξεργασιών',
@@ -1141,12 +1135,12 @@
 'reupload'                    => 'Επανάληψη φόρτωσης',
 'reuploaddesc'                => 'Επιστροφή στη φόρμα φόρτωσης',
 'uploadnologin'               => 'Δεν έχετε συνδεθεί!',
-'uploadnologintext'           => 'Για να φορτώσετε αρχεία πρέπει πρώτα να [[Special:Userlogin|συνδεθείτε]].',
+'uploadnologintext'           => 'Για να φορτώσετε αρχεία πρέπει πρώτα να [[Special:UserLogin|συνδεθείτε]].',
 'upload_directory_read_only'  => 'Δεν είναι δυνατή η εγγραφή στον κατάλογο ($1) από τον server.',
 'uploaderror'                 => 'Σφάλμα στη φόρτωση αρχείου',
 'uploadtext'                  => "'''ΠΕΡΙΜΕΝΕΤΕ!''' Πριν προχωρήσετε στη φόρτωση αρχείων σε αυτό το χώρο βεβαιωθείτε πως διαβάσατε και πως ακολουθείτε τους [[{{ns:project}}:Κανόνες_χρήσης_εικόνων|Κανόνες χρήσης εικόνων]].
 
-Μπορείτε να δείτε ή να αναζητήσετε εικόνες που έχουν φορτωθεί κατά το παρελθόν κάτω από το σύνδεσμο [[Special:Imagelist|Κατάλογος εικόνων που έχουν φορτωθεί]].
+Μπορείτε να δείτε ή να αναζητήσετε εικόνες που έχουν φορτωθεί κατά το παρελθόν κάτω από το σύνδεσμο [[Special:ImageList|Κατάλογος εικόνων που έχουν φορτωθεί]].
 Οι φορτώσεις και οι διαγραφές έχουν καταγραφεί στη σελίδα
 [[{{ns:project}}:Καταγραφές_φόρτωσης|Καταγραφές φόρτωσης]].
 
@@ -1240,7 +1234,7 @@
 'upload_source_url'  => ' (ένα έγκυρο, δημόσια προσβάσιμο URL)',
 'upload_source_file' => ' (ένα αρχείο στον υπολογιστή σας)',
 
-# Special:Imagelist
+# Special:ImageList
 'imagelist-summary'     => 'Αυτή η ειδική σελίδα δείχνει όλα τα ανεβασμένα αρχεία.
 Τα πιο πρόσφατα είναι στην κορυφή της λίστας.
 Πατήστε στην επικεφαλίδα μιας σειράς για αλλάξει η ιεράρχηση.',
@@ -1266,7 +1260,7 @@
 'filehist-filesize'              => 'Μέγεθος',
 'filehist-comment'               => 'Σχόλια',
 'imagelinks'                     => 'Σύνδεσμοι εικόνων',
-'linkstoimage'                   => 'Οι ακόλουθες σελίδες συνδέονται με αυτή την εικόνα:',
+'linkstoimage'                   => '{{PLURAL:$1|Οι ακόλουθες σελίδες συνδέονται|$1 Η ακόλουθη σελίδα συνδέεται}} με αυτή την εικόνα:',
 'nolinkstoimage'                 => 'Δεν υπάρχουν σελίδες που συνδέονται με αυτήν την εικόνα.',
 'sharedupload'                   => 'Το αρχείο αυτό φορτώθηκε για κοινή χρήση και είναι δυνατόν να χρησιμοποιείται ταυτοχρόνως σε περισσότερα από ένα έργα.',
 'shareduploadwiki'               => 'Παρακαλούμε συμβουλευθείτε την [$1 σελίδα περιγραφής αρχείου] για περισσότερες πληροφορίες.',
@@ -1282,18 +1276,18 @@
 # File reversion
 'filerevert'                => 'Επαναφορά $1',
 'filerevert-legend'         => 'Επαναφορά αρχείου',
-'filerevert-intro'          => '<span class="plainlinks">Επαναφέρετε το \'\'\'[[Media:$1|$1]]\'\'\' στην [$4 εκδοχή της $3, $2].</span>',
+'filerevert-intro'          => "Επαναφέρετε το '''[[Media:$1|$1]]''' στην [$4 εκδοχή της $3, $2].",
 'filerevert-comment'        => 'Σχόλιο:',
 'filerevert-defaultcomment' => 'Αναστράφηκε στην εκδοχή της $2, $1',
 'filerevert-submit'         => 'Αναστροφή',
-'filerevert-success'        => 'Το <span class="plainlinks">\'\'\'[[Media:$1|$1]]\'\'\' έχει αναστραφεί στην [$4 εκδοχή της $3, $2].</span>',
+'filerevert-success'        => "Το '''[[Media:$1|$1]]''' έχει αναστραφεί στην [$4 εκδοχή της $3, $2].",
 'filerevert-badversion'     => 'Δεν υπάρχει προηγούμενη τοπική έκδοση αυτού του αρχείου με την χρονική σφραγίδα που παραχωρήθηκε.',
 
 # File deletion
 'filedelete'                  => 'Διαγραφή του $1',
 'filedelete-legend'           => 'Διαγραφή αρχείου',
 'filedelete-intro'            => "Διαγράφετε το '''[[Media:$1|$1]]'''.",
-'filedelete-intro-old'        => '<span class="plainlinks">Διαγράφετε την έκδοση του \'\'\'[[Media:$1|$1]]\'\'\' από τις [$4 $3, $2].</span>',
+'filedelete-intro-old'        => "Διαγράφετε την έκδοση του '''[[Media:$1|$1]]''' από τις [$4 $3, $2].",
 'filedelete-comment'          => 'Λόγος διαγραφής:',
 'filedelete-submit'           => 'Διαγραφή',
 'filedelete-success'          => "Το αρχείο '''$1''' έχει διαγραφεί.",
@@ -1439,7 +1433,7 @@
 'logempty'             => 'Δεν υπάρχουν στοιχεία που να ταιριάζουν στο αρχείο καταγραφών.',
 'log-title-wildcard'   => 'Αναζήτησε τίτλους που αρχίζουν με αυτό το κείμενο',
 
-# Special:Allpages
+# Special:AllPages
 'allpages'          => 'Όλες οι σελίδες',
 'alphaindexline'    => '$1 έως $2',
 'nextpage'          => 'Επόμενη σελίδα ($1)',
@@ -1462,20 +1456,21 @@
 'special-categories-sort-count' => 'ταξινόμηση κατά απαρίθμηση',
 'special-categories-sort-abc'   => 'αλφαβητική ταξινόμηση',
 
-# Special:Listusers
+# Special:ListUsers
 'listusersfrom'      => 'Προβολή χρηστών ξεκινώντας από:',
 'listusers-submit'   => 'Δείξε',
 'listusers-noresult' => 'Δεν βρέθηκε χρήστης.',
 
-# Special:Listgrouprights
-'listgrouprights'         => 'Δικαιώματα ομάδων χρηστών',
-'listgrouprights-group'   => 'Ομάδα',
-'listgrouprights-rights'  => 'Δικαιώματα',
-'listgrouprights-members' => '(κατάλογος μελών)',
+# Special:ListGroupRights
+'listgrouprights'          => 'Δικαιώματα ομάδων χρηστών',
+'listgrouprights-group'    => 'Ομάδα',
+'listgrouprights-rights'   => 'Δικαιώματα',
+'listgrouprights-helppage' => 'Help:Δικαιώματα ομάδων',
+'listgrouprights-members'  => '(κατάλογος μελών)',
 
 # E-mail user
 'mailnologin'     => 'Δεν υπάρχει διεύθυνση παραλήπτη.',
-'mailnologintext' => 'Πρέπει να έχετε [[Special:Userlogin|συνδεθεί]] και να έχετε δηλώσει
+'mailnologintext' => 'Πρέπει να έχετε [[Special:UserLogin|συνδεθεί]] και να έχετε δηλώσει
 μια έγκυρη ηλεκτρονική διεύθυνση στις [[Special:Preferences|Προτιμήσεις]]
 για να στείλετε e-mail σε άλλους χρήστες.',
 'emailuser'       => 'Στείλτε μήνυμα σε αυτό τον χρήστη',
@@ -1502,10 +1497,10 @@
 'nowatchlist'          => 'Δεν υπάρχουν εγγραφές στη λίστα παρακολούθησης.',
 'watchlistanontext'    => 'Παρακαλώ $1 για να δείτε ή να επεξεργαστείτε στοιχεία στη λίστα παρακολούθησής σας.',
 'watchnologin'         => 'Δεν έχετε συνδεθεί.',
-'watchnologintext'     => 'Για να κάνετε αλλαγές στη λίστα παρακολούθησης πρέπει να <a href="{{localurl:Special:Userlogin}}"> συνδεθείτε </a>.',
+'watchnologintext'     => 'Για να κάνετε αλλαγές στη λίστα παρακολούθησης πρέπει να <a href="{{localurl:Special:UserLogin}}"> συνδεθείτε </a>.',
 'addedwatch'           => 'Η σελίδα έχει προστεθεί στη λίστα παρακολούθησης.',
 'addedwatchtext'       => "Η σελίδα \"<nowiki>\$1</nowiki>\" έχει προστεθεί στη [[Special:Watchlist|λίστα παρακολούθησης]].
-Μελλοντικές αλλαγές στη σελίδα καθώς και στη σχετική με τη σελίδα συζήτηση θα φαίνονται '''με έντονα γράμματα''' στη [[Special:Recentchanges|λίστα πρόσφατων αλλαγών]] έτσι ώστε να διευκολύνεται η παρακολούθηση.
+Μελλοντικές αλλαγές στη σελίδα καθώς και στη σχετική με τη σελίδα συζήτηση θα φαίνονται '''με έντονα γράμματα''' στη [[Special:RecentChanges|λίστα πρόσφατων αλλαγών]] έτσι ώστε να διευκολύνεται η παρακολούθηση.
 
 
 <p>Αν θελήσετε να αφαιρέσετε τη σελίδα αυτή από τη λίστα παρακολούθησης, κάνετε κλικ στην επιλογή \"παύση παρακολούθησης\" στην μπάρα ενεργειών.",
@@ -1599,8 +1594,10 @@
 ** Παραβίαση των πνευματικών δικαιωμάτων
 ** Βανδαλισμός',
 'delete-edit-reasonlist'      => 'Επεξεργασία λόγων διαγραφής',
-'delete-toobig'               => 'Αυτή η σελίδα έχει μεγάλο ιστορικό τροποποιήσεων, πάνω από $1. Η διαγραφή τέτοιων σελίδων έχει περιοριστεί για την αποφυγή τυχαίας αναστάτωσης του {{SITENAME}}.',
-'delete-warning-toobig'       => 'Αυτή η σελίδα έχει μεγάλο ιστορικό τροποποιήσεων, πάνω από $1. Η διαγραφή της μπορεί να αναστατώσει τη λειτουργία της βάσης δεδομένων του {{SITENAME}}. Συνιστούμε μεγάλη προσοχή.',
+'delete-toobig'               => 'Αυτή η σελίδα έχει μεγάλο ιστορικό τροποποιήσεων, πάνω από $1 {{PLURAL:$1|τροποποίηση|τροποποιήσεις}}.
+Η διαγραφή τέτοιων σελίδων έχει περιοριστεί για την αποφυγή τυχαίας αναστάτωσης του {{SITENAME}}.',
+'delete-warning-toobig'       => 'Αυτή η σελίδα έχει μεγάλο ιστορικό τροποποιήσεων, πάνω από $1 {{PLURAL:$1|τροποποίηση|τροποποιήσεις}}.
+Η διαγραφή της μπορεί να αναστατώσει τη λειτουργία της βάσης δεδομένων του {{SITENAME}}. Συνιστούμε μεγάλη προσοχή.',
 'rollback'                    => 'Επαναφορά επεξεργασιών',
 'rollback_short'              => 'Επαναφορά',
 'rollbacklink'                => 'Επαναφορά στην προηγούμενη',
@@ -1633,7 +1630,7 @@
 'protect-locked-dblock'       => 'Τα επίπεδα προστασίας δεν μπορούν να αλλαχθούν λόγω ενός ενεργού κλεδώματος της βάσης δεδομένων.
 Εδώ είναι οι τρέχουσες ρυθμίσεις για τη σελίδα <strong>$1</strong>:',
 'protect-locked-access'       => 'Ο λογαριασμός σας δεν έχει δικαίωμα να αλλάξει τα επίπεδα προστασίας σελίδας.
-Εδώ είναι οι τρέχουσες ρυθμίσεις γαι τη σελίδα <strong>$1</strong>:',
+Εδώ είναι οι τρέχουσες ρυθμίσεις για τη σελίδα <strong>$1</strong>:',
 'protect-cascadeon'           => 'Αυτή η σελίδα είναι προς το παρόν προστατευμένη επειδή περιλαμβάνεται {{PLURAL:$1|στην ακόλουθη σελίδα, η οποία έχει|στις ακόλουθες σελίδες, οι οποίες έχουν}} τη διαδοχική προστασία ενεργοποιημένη. Μπορείτε να αλλάξετε το επίπεδο προστασίας αυτής της σελίδας, αλλά δεν θα επηρεάσει τη διαδοχική προστασία.',
 'protect-default'             => '(προεπιλεγμένο)',
 'protect-fallback'            => 'Αίτηση δικαιωμάτων "$1"',
@@ -1669,7 +1666,7 @@
 κάντε κλικ στο κουμπί '''''Επαναφορά'''''. Για να εκτελέσετε μια επιλεκτική επαναφορά, τσεκάρετε τα κουτιά που αντιστοιχούν στις
 αναθεωρήσεις προς επαναφορά, και κάντε κλικ στο κουμπί '''''Επαναφορά'''''. Κάνοντας κλικ στην '''''Ανανέωση''''' θα καθαρίσετε το
 πεδίο σχολίων και όλα τα κουτιά επιλογής.",
-'undeleterevisions'            => '$1 {{PLURAL:$1|αναθεώρηση|αναθεωρήσεις}} αρχειοθετήθηκαν.',
+'undeleterevisions'            => '$1 {{PLURAL:$1|τροποποίηση|τροποποιήσεις}} αρχειοθετήθηκαν.',
 'undeletehistory'              => 'Αν επαναφέρετε την σελίδα, όλες οι εκδόσεις θα επαναφερθούν στο ιστορικό.
 
 Αν μια νέα σελίδα με το ίδιο όνομα δημιουργήθηκε μετά την διαγραφή, οι επαναφερμένες εκδόσεις θα εμφανιστούν στο πρότερο ιστορικό.
@@ -1688,7 +1685,7 @@
 'undeletereset'                => 'Ανανέωση',
 'undeletecomment'              => 'Σχόλιο:',
 'undeletedarticle'             => 'αποκατάσταση "$1"',
-'undeletedrevisions'           => '{{PLURAL:$1|1 αναθεώρηση|$1 αναθεωρήσεις}} αποκαταστάθηκαν',
+'undeletedrevisions'           => '{{PLURAL:$1|τροποποίηση|τροποποιήσεις}} αποκαταστάθηκαν',
 'undeletedrevisions-files'     => '$1 {{PLURAL:$1|αναθεώρηση|αναθεωρήσεις}} και $2 {{PLURAL:$2|αρχείο|αρχεία}} επαναφέρθηκαν',
 'undeletedfiles'               => '$1 {{PLURAL:$1|αρχείο|αρχεία}} επαναφέρθηκαν',
 'cannotundelete'               => 'Η επαναφορά απέτυχε: κάποιος άλλος μπορεί να έχει επαναφέρει τη σελίδα πρώτος.',
@@ -1779,7 +1776,7 @@
 'ipbhidename'                     => 'Απόκρυψη ονόματος χρήστη από το αρχείο καταγραφής φραγών, την ενεργή λίστα φραγών και τη λίστα χρηστών.',
 'badipaddress'                    => 'Άκυρη διεύθυνση IP.',
 'blockipsuccesssub'               => 'Η φραγή ολοκληρώθηκε επιτυχώς.',
-'blockipsuccesstext'              => 'Η διεύθυνση "$1" έχει υποστεί φραγή. <br />Δείτε τη [[Special:Ipblocklist|λίστα διευθύνσεων IP που έχουν υποστεί φραγή]] για να το επιβεβαιώσετε.',
+'blockipsuccesstext'              => 'Η διεύθυνση "$1" έχει υποστεί φραγή. <br />Δείτε τη [[Special:IPBlockList|λίστα διευθύνσεων IP που έχουν υποστεί φραγή]] για να το επιβεβαιώσετε.',
 'ipb-edit-dropdown'               => 'Επεξεργασία λόγων φραγής',
 'ipb-unblock-addr'                => 'Τερμάτισε τη φραγή του/της $1',
 'ipb-unblock'                     => 'Τερμάτισε τη φραγή για ένα όνομα χρήστη ή μια διεύθυνση IP',
@@ -1800,7 +1797,7 @@
 'anononlyblock'                   => 'μόνο τους ανώνυμους',
 'noautoblockblock'                => 'αυτόματη φραγή απενεργοποιημένη',
 'createaccountblock'              => 'δημιουργία λογαριασμού μπλοκαρισμένη',
-'emailblock'                      => 'Το e-mail έχει φραγεί',
+'emailblock'                      => 'Το ηλεκτρονικό ταχυδρομείο έχει φραγεί',
 'ipblocklist-empty'               => 'Η λίστα φραγών είναι άδεια.',
 'ipblocklist-no-results'          => 'Η ζητούμενη διεύθυνση IP ή το όνομα χρήστη δεν είναι φραγμένα.',
 'blocklink'                       => 'φραγή',
@@ -1811,12 +1808,12 @@
 'blocklogentry'                   => 'O/H "[[$1]]" φράχθηκε με χρόνο λήξης $2 $3',
 'blocklogtext'                    => 'Σε αυτή τη σελίδα υπάρχουν οι καταγραφές φραγής και κατάργησης φραγής των χρηστών (αρχείο γεγονότων).
 
-<br />Δεν συμπεριλαμβάνονται οι διευθύνσεις IP που υπέστησαν αυτόματα φραγή. <br />Στο σύνδεσμο [[Special:Ipblocklist|διευθύνεις IP που έχουν υποστεί φραγή]] θα βρείτε τον πλήρη κατάλογο με τις τρέχουσες φραγές.',
+<br />Δεν συμπεριλαμβάνονται οι διευθύνσεις IP που υπέστησαν αυτόματα φραγή. <br />Στο σύνδεσμο [[Special:IPBlockList|διευθύνεις IP που έχουν υποστεί φραγή]] θα βρείτε τον πλήρη κατάλογο με τις τρέχουσες φραγές.',
 'unblocklogentry'                 => 'Άρση φραγής του "$1"',
 'block-log-flags-anononly'        => 'μόνο ανώνυμοι χρήστες',
 'block-log-flags-nocreate'        => 'δημιουργία λογαριασμού απενεργοποιημένη',
 'block-log-flags-noautoblock'     => 'αυτόματη φραγή απενεργοποιημένη',
-'block-log-flags-noemail'         => 'Το e-mail έχει φραγεί',
+'block-log-flags-noemail'         => 'Το ηλεκτρονικό ταχυδρομείο έχει φραγεί',
 'block-log-flags-angry-autoblock' => 'ενισχυμένος αυτόματος αποκλεισμός ενεργοποιημένος',
 'range_block_disabled'            => 'Η δυνατότητα του διαχειριστή να δημιουργεί περιοχές φραγής είναι απενεργοποιημένη.',
 'ipb_expiry_invalid'              => 'Άκυρος χρόνος λήξης',
@@ -1853,12 +1850,17 @@
 # Move page
 'move-page'               => 'Μετακίνηση $1',
 'move-page-legend'        => 'Μετακίνηση σελίδας',
-'movepagetext'            => "Χρησιμοποιήστε τη φόρμα που ακολουθεί για να μετονομάσετε σελίδες και για να μεταφέρετε όλο το ιστορικό τους κάτω από το νέο όνομα. Κάτω από τον παλιό τίτλο της σελίδας θα παραμείνει μια σελίδα ανακατεύθυνσης στο νέο τίτλο. Οι τυχόν σύνδεσμοι που οδηγούσαν στην παλιά σελίδα δεν θα επηρεαστούν. Βεβαιωθείτε πως [[Special:Maintenance|ελέγξατε]] τα διπλά διαστήματα και τους κατεστραμένους συνδέσμους. Αναλαμβάνετε την ευθύνη να επιβεβαιώσετε ότι οι συνδεσμοι εξακολουθούν να οδηγούν προς τις κατευθύνσεις που πρέπει.
+'movepagetext'            => "Χρησιμοποιόντας τη φόρμα που ακολουθεί μπορείτε να μετονομάσετε σελίδες και να μεταφέρετε όλο το ιστορικό τους στο νέο όνομα.
+Ο παλιός τίτλος της σελίδας θα γίνει μια σελίδα ανακατεύθυνσης στο νέο τίτλο.
+Οι σύνδεσμοι που οδηγούσαν στην παλιά σελίδα δεν θα επηρεαστούν αν και θα πρέπει να βεβαιωθείτε πως ελέγξατε τις διπλές και τις κατεστραμμένες ανακατευθύνσεις.
+Είστε υπεύθυνος να επιβεβαιώσετε ότι οι συνδεσμοι εξακολουθούν να οδηγούν προς τις κατευθύνσεις που πρέπει.
 
-Λάβετε υπ` όψη σας ότι η σελίδα '''δεν''' θα μετακινηθεί αν υπάρχει ήδη μια άλλη σελίδα κάτω από το νέο τίτλο, εκτός αν η σελίδα αυτή είναι κενή '''και''' χωρίς ιστορικό επεξεργασίας. Αυτό σημαίνει ότι, στην περίπτωση που έχετε κάνει λάθος, μπορείτε να μετονομάσετε μια σελίδα ξαναδίνοντας της την αρχική της ονομασία αλλά δεν μπορείτε να αντικαταστήσετε μια υπάρχουσα σελίδα.
+Λάβετε υπόψη σας ότι η σελίδα '''δεν''' θα μετακινηθεί αν υπάρχει ήδη μια άλλη σελίδα κάτω από το νέο τίτλο, εκτός αν η σελίδα αυτή είναι κενή ή είναι ανακατεύθυνση χωρίς ιστορικό επεξεργασίας.
+Αυτό σημαίνει ότι, στην περίπτωση που έχετε κάνει λάθος, μπορείτε να μετονομάσετε μια σελίδα ξαναδίνοντας της την αρχική της ονομασία αλλά δεν μπορείτε να αντικαταστήσετε μια υπάρχουσα σελίδα.
 
 '''ΠΡΟΣΟΧΗ!'''
-Η μετονομασία σελίδας είναι μια αιφνίδια και δραστική αλλαγή όταν πρόκειται για δημοφιλείς σελίδες. Παρακαλούμε, πριν το αποφασίσετε, να εξετάσετε προσεκτικά τις πιθανές επιπτώσεις αυτής της ενέργειας .",
+Η μετονομασία σελίδας είναι μια αιφνίδια και δραστική αλλαγή όταν πρόκειται για δημοφιλείς σελίδες.
+Παρακαλούμε, πριν το αποφασίσετε, να εξετάσετε προσεκτικά τις πιθανές επιπτώσεις αυτής της ενέργειας.",
 'movepagetalktext'        => "Η σελίδα συζήτησης που αντιστοιχεί, εάν υπάρχει, θα μετακινηθεί αυτόματα μαζί με αυτήν '''έκτός αν:'''
 *Μετακινείτε τη σελίδα σε διαφορετική περιοχή (namespace),
 *Υπάρχει κάτω από το νέο όνομα μια σελίδα συζήτησης που δεν είναι κενή, ή
@@ -1866,13 +1868,12 @@
 
 Σε αυτές τις περιπτώσεις, θα πρέπει να μετακινήσετε (ή να ενσωματώσετε αν το θέλετε) τη σελίδα με αντιγραφή-και-επικόλληση.",
 'movearticle'             => 'Μετακίνηση σελίδας',
-'movenologin'             => 'Δεν έχετε συνδεθεί.',
-'movenologintext'         => 'Για να μετακινήσετε μια σελίδα πρέπει να είστε εγγεγραμένος χρήστης και [[Special:Userlogin|να έχετε συνδεθεί]] στο Wiκi.',
 'movenotallowed'          => 'Δεν έχετε άδεια να μετακινείτε σελίδες στο {{SITENAME}}.',
 'newtitle'                => 'νέος τίτλος',
 'move-watch'              => 'Παρακολούθησε αυτή τη σελίδα',
 'movepagebtn'             => 'Μετακίνηση σελίδας',
 'pagemovedsub'            => 'Η μετακίνηση ήταν επιτυχής',
+'movepage-moved'          => '<big>\'\'\'"$1" μεταφέρθηκε στο "$2"\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
 'articleexists'           => 'Υπάρχει ήδη σελίδα με αυτό το όνομα. Παρακαλούμε δώστε άλλο όνομα στη σελίδα.',
 'cantmove-titleprotected' => "Δεν μπορείτε να μετακινήσετε μια σελίδα σ' αυτή τη θέση διότι έχει απαγορευθεί η δημιουργία αυτού του τίτλου",
 'talkexists'              => "Η ίδια η σελίδα μετακινήθηκε επιτυχώς αλλά όχι και η σελίδα συζήτησης, λόγω του ότι υπάρχει ήδη άλλη σελίδα συζήτησης κάτω από το νέο τίτλο. Παρακαλούμε ενοποιήστε τις δύο σελίδες με 'αντιγραφή-και-επικόλληση'.",
@@ -1889,7 +1890,7 @@
 'delete_and_move'         => 'Διαγραφή και μετακίνηση',
 'delete_and_move_text'    => '==Χρειάζεται διαγραφή.==
 
-Το άρθρο [[$1]] υπάρχει ήδη. Θέλετε να το διαγράψετε για να εκτελεσθεί η μετακίνηση;',
+Το άρθρο [[:$1]] υπάρχει ήδη. Θέλετε να το διαγράψετε για να εκτελεσθεί η μετακίνηση;',
 'delete_and_move_confirm' => 'Ναι, διέγραψε τη σελίδα',
 'delete_and_move_reason'  => 'Διαγράφηκε για να εκτελεσθεί μετακίνηση.',
 'selfmove'                => 'Ο τίτλος προέλευσης είναι ο ίδιος με τον τίτλο προορισμού -δεν είναι δυνατόν να μετακινηθεί μια σελίδα προς τον εαυτό της.',
@@ -2122,10 +2123,10 @@
 'show-big-image'       => 'Πλήρης ανάλυση',
 'show-big-image-thumb' => '<small>Μέγεθος αυτής της προεπισκόπησης: $1 × $2 εικονοστοιχεία</small>',
 
-# Special:Newimages
+# Special:NewImages
 'newimages'             => 'Πινακοθήκη νέων εικόνων',
 'imagelisttext'         => "Ακολουθεί κατάλογος '''$1''' {{PLURAL:$1|αρχείου|αρχείων}} ταξινομημένων κατά σειρά $2.",
-'newimages-summary'     => 'Αυτή η ειδική σελίδα δείχνει τα πιο πρόσφατα φορτωμένα αρχεία',
+'newimages-summary'     => 'Αυτή η ειδική σελίδα δείχνει τα πιο πρόσφατα φορτωμένα αρχεία.',
 'showhidebots'          => '($1 bots)',
 'noimages'              => 'Δεν υπάρχουν εικόνες.',
 'ilsubmit'              => 'Αναζήτηση',
@@ -2406,7 +2407,7 @@
 
 # External editor support
 'edit-externally'      => 'Επεξεργαστείτε το συγκεκριμένο αρχείο χρησιμοποιώντας μια από τις εξωτερικές εφαρμογές.',
-'edit-externally-help' => 'Για περισσότερες πληροφορίες ακολουθήστε το σύνδεσμο: [http://meta.wikimedia.org/wiki/Help:External_editors setup instructions].',
+'edit-externally-help' => 'Για περισσότερες πληροφορίες ακολουθήστε το σύνδεσμο: [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions].',
 
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'όλες',
@@ -2474,7 +2475,7 @@
 'recreate'            => 'Επαναδημιουργία',
 
 # HTML dump
-'redirectingto' => 'Ανακατεύθυνση στη σελίδα [[$1]]...',
+'redirectingto' => 'Ανακατεύθυνση στη σελίδα [[:$1]]...',
 
 # action=purge
 'confirm_purge'        => 'Καθαρισμός της λανθάνουσας μνήμης αυτής της σελίδας;
@@ -2565,7 +2566,7 @@
 'version-software-product'    => 'Προϊόν',
 'version-software-version'    => 'Έκδοση',
 
-# Special:Filepath
+# Special:FilePath
 'filepath'         => 'Διαδρομή αρχείου',
 'filepath-page'    => 'Αρχείο:',
 'filepath-submit'  => 'Διαδρομή',
@@ -2594,8 +2595,9 @@
 'specialpages-group-pagetools'   => 'Εργαλεία σελίδων',
 'specialpages-group-wiki'        => 'Βικι δεδομένα και εργαλεία',
 'specialpages-group-redirects'   => 'Ανακατεύθυνση ειδικών σελίδων',
+'specialpages-group-spam'        => 'Εργαλεία κατά των ανεπιθύμητων διαφημιστικών',
 
-# Special:Blankpage
+# Special:BlankPage
 'blankpage'              => 'Κενή σελίδα',
 'intentionallyblankpage' => 'Αυτή η σελίδα έχει αφεθεί σκοπίμως κενή',
 
Index: RELEASE-NOTES
===================================================================
--- RELEASE-NOTES	(.../REL1_13_0RC1/phase3)	(revision 39329)
+++ RELEASE-NOTES	(.../REL1_13_0RC2/phase3)	(revision 39329)
@@ -3,7 +3,7 @@
 Security reminder: MediaWiki does not require PHP's register_globals
 setting since version 1.2.0. If you have it on, turn it *off* if you can.
 
-== MediaWiki 1.13.0rc1 ==
+== MediaWiki 1.13.0rc2 ==
 
 This is a release candidate of the Summer 2008 quarterly snapshot release 
 of MediaWiki.
@@ -19,6 +19,29 @@
 Those wishing to use the latest code instead of a branch release can obtain
 it from source control: http://www.mediawiki.org/wiki/Download_from_SVN
 
+== Changes since 1.13.0rc1 ==
+
+* $wgForwardSearchUrl has been removed entirely. Documented setting since 1.4
+  has been $wgSearchForwardUrl.
+* (bug 14907) DatabasePostgres::fieldType now defined.
+* (bug 14966) Fix SearchEngineDummy class for silently non-functional search
+  on Sqlite instead of horribly fatal error breaky one.
+* (bug 14987) Only fix double redirects on page move when the checkbox is
+  checked
+* (bug 13376) Use $wgPasswordSender, not $wgEmergencyContact, as return
+  address for page update notification mails.
+* API: Registration time of users registered before the DB field was created is now
+  shown as empty instead of the current time.
+* (bug 14904): fragments were lost when redirects were fixed.
+* Added magic word __STATICREDIRECT__ to suppress the redirect fixer
+* (bug 15035) Revert English linkTrail to /^([a-z]+)(.*)$/sD, as it was before 
+  r36253. Multiple reports of breakage due to old (pre-5.0) PCRE libraries, 
+  both bundled with PHP and packaged with distros such as RHEL. 
+* (bug 14944) Shell invocation of external programs such as ImageMagick convert 
+  was broken in PHP 5.2.6, if the server had a non-UTF-8 locale.
+
+== Changes since 1.12 ==
+
 === Configuration changes in 1.13 ===
 
 * New option $wgFeed can be set false to turn off syndication feeds
